(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    269236,       7342]*)
(*NotebookOutlinePosition[    270149,       7373]*)
(*  CellTagsIndexPosition[    270105,       7369]*)
(*WindowFrame->Normal*)



Notebook[{
Cell["FOURIER DESCRIPTORS", "Title"],

Cell["\<\
Mariusz Jankowski \[Copyright]
Department of Electrical Engineering
University of Southern Maine
mjkcc@usm.maine.edu\
\>", "Address"],

Cell[CellGroupData[{

Cell["CHAIN CODE", "Section"],

Cell[TextData[{
  "The chain code [Freeman, 1974] is a simple representation of a polygonal \
approximation of a boundary, where the direction of each fixed-length, \
straight line segment is coded using a simple numbering scheme. Eight symbols \
{0,7} are used to denote directions on an 8-connected sampling grid, with ",
  Cell[BoxData[
      \(TraditionalForm\`\[Pi]\/4\)]],
  " resolution. The eight digits correspond to the following directions on \
the x-y plane:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \({{3, 2, 1}, {4, \[CapitalTheta], 0}, {5, 6, 7}}\  // MatrixForm\)], 
  "Input",
  CellLabel->"In[169]:="],

Cell[BoxData[
    TagBox[
      RowBox[{"(", GridBox[{
            {"3", "2", "1"},
            {"4", "\[CapitalTheta]", "0"},
            {"5", "6", "7"}
            }], ")"}],
      (MatrixForm[ #]&)]], "Output",
  CellLabel->"Out[169]//MatrixForm="]
}, Open  ]],

Cell["Here is a binary image of a handwritten letter.", "Text"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0192308 0.0192308 0.0192308 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
50 string
50 50 8 [50 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
0000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
0000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
0000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
0000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
0000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
0000
0000000000000000FFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000000000
0000
0000000000000000FF000000000000FFFFFFFF0000000000
000000000000000000000000000000000000000000000000
0000
0000000000000000FF00000000000000000000FFFFFF0000
000000000000000000000000000000000000000000000000
0000
0000000000000000FF00000000000000000000000000FFFF
FF0000000000000000000000000000000000000000000000
0000
0000000000000000FF000000000000000000000000000000
00FF00000000000000000000000000000000000000000000
0000
0000000000000000FF000000000000000000000000000000
0000FFFF0000000000000000000000000000000000000000
0000
0000000000000000FF000000000000000000000000000000
00000000FF00000000000000000000000000000000000000
0000
0000000000000000FF000000000000000000000000000000
00000000FF00000000000000000000000000000000000000
0000
0000000000000000FF000000000000000000000000000000
0000000000FF000000000000000000000000000000000000
0000
0000000000000000FF000000000000000000000000000000
0000000000FF000000000000000000000000000000000000
0000
0000000000000000FF000000000000000000000000000000
0000000000FF000000000000000000000000000000000000
0000
00000000000000FF00000000000000000000000000000000
0000000000FF000000000000000000000000000000000000
0000
00000000000000FF00000000000000000000000000000000
0000000000FF000000000000000000000000000000000000
0000
00000000000000FF00000000000000000000000000000000
00000000FF00000000000000000000000000000000000000
0000
00000000000000FF00000000000000000000000000000000
00000000FF00000000000000000000000000000000000000
0000
00000000000000FF00000000000000000000000000000000
000000FF0000000000000000000000000000000000000000
0000
00000000000000FF00000000000000000000000000000000
0000FF000000000000000000000000000000000000000000
0000
00000000000000FF00000000000000000000000000000000
00FF00000000000000000000000000000000000000000000
0000
000000000000FF00000000000000000000000000000000FF
FF0000000000000000000000000000000000000000000000
0000
000000000000FF000000000000000000000000000000FF00
000000000000000000000000000000000000000000000000
0000
000000000000FF000000000000000000000000FFFFFF0000
000000000000000000000000000000000000000000000000
0000
000000000000FF0000000000000000FFFFFFFF0000000000
000000000000000000000000000000000000000000000000
0000
0000000000FF000000000000000000FFFFFF000000000000
000000000000000000000000000000000000000000000000
0000
0000000000FF000000000000000000000000FF0000000000
000000000000000000000000000000000000000000000000
0000
0000000000FF00000000000000000000000000FFFF000000
000000000000000000000000000000000000000000000000
0000
0000000000FF0000000000000000000000000000FF000000
000000000000000000000000000000000000000000000000
0000
0000000000FF000000000000000000000000000000FF0000
000000000000000000000000000000000000000000000000
0000
0000000000FF000000000000000000000000000000FF0000
000000000000000000000000000000000000000000000000
0000
0000000000FF000000000000000000000000000000FF0000
000000000000000000000000000000000000000000000000
0000
00000000FF00000000000000000000000000000000FF0000
000000000000000000000000000000000000000000000000
0000
00000000FF000000000000000000000000000000FF000000
000000000000000000000000000000000000000000000000
0000
00000000FF000000000000000000000000000000FF000000
000000000000000000000000000000000000000000000000
0000
00000000FF0000000000000000000000000000FF00000000
000000000000000000000000000000000000000000000000
0000
00000000FFFF000000000000000000000000FF0000000000
000000000000000000000000000000000000000000000000
0000
000000000000FFFF00000000000000FFFFFF000000000000
000000000000000000000000000000000000000000000000
0000
0000000000000000FFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000000000
0000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
0000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
0000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
0000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
0000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
0000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
0000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
0000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
0000
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[168]:=",
  ImageSize->{213, 213},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003E0000eA000`40O003h00OeGoo003EOol00=Eo
o`00eGoo003EOol00=Eoo`0017oob`001Woo0004Ooo;0006Ool000Aool/000Ioo`0017oob`001Woo
0004Ooo;0006Ool000Aool/000Ioo`0017oob`001Woo0004Ooo;0006Ool000Aool/000Ioo`0017oo
b`001Woo0004Ooo;0006Ool000Aool/000Ioo`0017oob`001Woo0004Ooo;0006Ool000Aool/000Io
o`0017oob`001Woo0004Ooo;0006Ool000Aool/000Ioo`0017oob`001Woo0004Ooo;0006Ool000Ao
ol/000Ioo`0017oob`001Woo0004Ooo;0006Ool000Aool/000Ioo`0017oo80007GooSP001Woo0004
OolP000MOon>0006Ool000Aoob0001eoohh000Ioo`0017oo80007GooSP001Woo0004OolP0005OolH
000@Oomn0006Ool000Aoob0000EooaP0011oogh000Ioo`0017oo80001Goo600047ooOP001Woo0004
OolP0005OolH000@Oomn0006Ool000Aoob0000EoobP000aoog8000Ioo`0017oo80001Goo:00037oo
LP001Woo0004OolP0005OolX000<Oomb0006Ool000Aoob0000EoobP000aoog8000Ioo`0017oo8000
1Goo:00037ooLP001Woo0004OolP0005Oold000<OomV0006Ool000Aoob0000Eooc@000aoofH000Io
o`0017oo80001Goo=00037ooIP001Woo0004OolP0005Oold000<OomV0006Ool000Aoob0000Eood00
00Eoof4000Ioo`0017oo80001Goo@0001GooH@001Woo0004OolP0005Oom00005OomQ0006Ool000Ao
ob0000Eood0000Eoof4000Ioo`0017oo80001GooA@0027ooF@001Woo0004OolP0005Oom50008OomI
0006Ool000Aoob0000EoodD000QooeT000Ioo`0017oo80001GooA@0027ooF@001Woo0004OolP0005
Oom=0004OomE0006Ool000Aoob0000Eoodd000AooeD000Ioo`0017oo80001GooC@0017ooE@001Woo
0004OolP0005Oom=0004OomE0006Ool000Aoob0000Eoodd000AooeD000Ioo`0017oo80001GooC@00
17ooE@001Woo0004OolP0005Oom=0004OomE0006Ool000Aoob0000Eoodd000AooeD000Ioo`0017oo
80001GooD@0017ooD@001Woo0004OolP0005OomA0004OomA0006Ool000Aoob0000Eooe4000Aooe40
00Ioo`0017oo80001GooD@0017ooD@001Woo0004OolP0005OomA0004OomA0006Ool000Aoob0000Eo
oe4000Aooe4000Ioo`0017oo80001GooD@0017ooD@001Woo0004OolP0005OomA0004OomA0006Ool0
00Aoob0000Eooe4000Aooe4000Ioo`0017oo80001GooD@0017ooD@001Woo0004OolP0005OomA0004
OomA0006Ool000Aoob0000Eooe4000Aooe4000Ioo`0017oo700017ooEP0017ooD@001Woo0004OolL
0004OomF0004OomA0006Ool000Aooa`000AooeH000Aooe4000Ioo`0017oo700017ooEP0017ooD@00
1Woo0004OolL0004OomF0004OomA0006Ool000Aooa`000AooeH000Aooe4000Ioo`0017oo700017oo
EP0017ooD@001Woo0004OolL0004OomF0004OomA0006Ool000Aooa`000Aooe8000AooeD000Ioo`00
17oo700017ooDP0017ooE@001Woo0004OolL0004OomB0004OomE0006Ool000Aooa`000Aooe8000Ao
oeD000Ioo`0017oo700017ooDP0017ooE@001Woo0004OolL0004OomB0004OomE0006Ool000Aooa`0
00Aooe8000AooeD000Ioo`0017oo700017ooDP0017ooE@001Woo0004OolL0004Oom>0004OomI0006
Ool000Aooa`000Aoodh000AooeT000Ioo`0017oo700017ooCP0017ooF@001Woo0004OolL0004Oom>
0004OomI0006Ool000Aooa`000AoodX000Aooed000Ioo`0017oo700017ooBP0017ooG@001Woo0004
OolL0004Oom:0004OomM0006Ool000Aooa`000AoodX000Aooed000Ioo`0017oo700017ooA@001Goo
H@001Woo0004OolL0004Oom50005OomQ0006Ool000Aooa`000AoodD000Eoof4000Ioo`0017oo7000
17ooA@001GooH@001Woo0004OolH0004Oom10008OomV0006Ool000AooaP000Aood4000QoofH000Io
o`0017oo600017oo@@0027ooIP001Woo0004OolH0004Oom10008OomV0006Ool000AooaP000Aood40
00QoofH000Ioo`0017oo600017oo?@0017ooKP001Woo0004OolH0004Oolm0004Oom^0006Ool000Ao
oaP000Aoocd000Aoofh000Ioo`0017oo600017oo?@0017ooKP001Woo0004OolH0004Oola000<Oomb
0006Ool000AooaP000Aooc4000aoog8000Ioo`0017oo600017oo<@0037ooLP001Woo0004OolH0004
Oola000<Oomb0006Ool000AooaP000Aoob40011oogh000Ioo`0017oo600017oo8@0047ooOP001Woo
0004OolH0004OolQ000@Oomn0006Ool000AooaP000Aoob40011oogh000Ioo`0017oo500017oo9@00
37ooPP001Woo0004OolD0004OolU000<Oon20006Ool000Aooa@000AoobD000aooh8000Ioo`0017oo
500017oo9@0037ooPP001Woo0004OolD0004Oola0004Oomn0006Ool000Aooa@000Aooc4000Aoogh0
00Ioo`0017oo500017oo<@0017ooOP001Woo0004OolD0004Oola0004Oomn0006Ool000Aooa@000Ao
ocD000QoogH000Ioo`0017oo500017oo=@0027ooMP001Woo0004OolD0004Oole0008Oomf0006Ool0
00Aooa@000AoocD000QoogH000Ioo`0017oo500017oo>@0017ooMP001Woo0004OolD0004Ooli0004
Oomf0006Ool000Aooa@000AoocT000AoogH000Ioo`0017oo500017oo>@0017ooMP001Woo0004OolD
0004Oolm0004Oomb0006Ool000Aooa@000Aoocd000Aoog8000Ioo`0017oo500017oo?@0017ooLP00
1Woo0004OolD0004Oolm0004Oomb0006Ool000Aooa@000Aoocd000Aoog8000Ioo`0017oo500017oo
?@0017ooLP001Woo0004OolD0004Oolm0004Oomb0006Ool000Aooa@000Aoocd000Aoog8000Ioo`00
17oo500017oo?@0017ooLP001Woo0004OolD0004Oolm0004Oomb0006Ool000Aooa@000Aoocd000Ao
og8000Ioo`0017oo500017oo?@0017ooLP001Woo0004Ool@0004Oom10004Oomb0006Ool000Aooa00
00Aood4000Aoog8000Ioo`0017oo400017oo@@0017ooLP001Woo0004Ool@0004Oom10004Oomb0006
Ool000Aooa0000Aoocd000AoogH000Ioo`0017oo400017oo?@0017ooMP001Woo0004Ool@0004Oolm
0004Oomf0006Ool000Aooa0000Aoocd000AoogH000Ioo`0017oo400017oo?@0017ooMP001Woo0004
Ool@0004Oolm0004Oomf0006Ool000Aooa0000Aoocd000AoogH000Ioo`0017oo400017oo?@0017oo
MP001Woo0004Ool@0004Ooli0004Oomj0006Ool000Aooa0000AoocT000AoogX000Ioo`0017oo4000
17oo>@0017ooNP001Woo0004Ool@0004Ooli0004Oomj0006Ool000Aooa0000Qooc4000Aoogh000Io
o`0017oo400027oo<@0017ooOP001Woo0004Ool@0008Oola0004Oomn0006Ool000Aooa0000Qooc40
00Aoogh000Ioo`0017oo600027oo7@0037ooPP001Woo0004OolH0008OolM000<Oon20006Ool000Ao
oaP000Qooad000aooh8000Ioo`0017oo600027oo7@0037ooPP001Woo0004OolP000MOon>0006Ool0
00Aoob0001eoohh000Ioo`0017oo80007GooSP001Woo0004OolP000MOon>0006Ool000Aoob0001eo
ohh000Ioo`0017oob`001Woo0004Ooo;0006Ool000Aool/000Ioo`0017oob`001Woo0004Ooo;0006
Ool000Aool/000Ioo`0017oob`001Woo0004Ooo;0006Ool000Aool/000Ioo`0017oob`001Woo0004
Ooo;0006Ool000Aool/000Ioo`0017oob`001Woo0004Ooo;0006Ool000Aool/000Ioo`0017oob`00
1Woo0004Ooo;0006Ool000Aool/000Ioo`0017oob`001Woo0004Ooo;0006Ool000Aool/000Ioo`00
17oob`001Woo0004Ooo;0006Ool000Aool/000Ioo`0017oob`001Woo0004Ooo;0006Ool000Aool/0
00Ioo`0017oob`001Woo0004Ooo;0006Ool000Aool/000Ioo`0017oob`001Woo0004Ooo;0006Ool0
0=Eoo`00eGoo003EOol00=Eoo`00\
\>"],
  ImageRangeCache->{{{0, 212}, {212, 0}} -> {-1.00026, -1.00026, 0.245285, 
  0.245285}}],

Cell["\<\
The following is the Freeman chain code representing the shown character. The \
code begins in the left-most top corner of the letter.\
\>", "Text"],

Cell[BoxData[
    \(\(chain = {0, 1, 0, 1, 0, 0, 0, 0, 0, 0, 7, 0, 0, 7, 7, 7, 6, 7, 6, 6, 
        \n\t6, 5, 6, 4, 5, 5, 4, 4, 6, 0, 0, 0, 7, 0, 0, 7, 7, 0, 7, 7, 7, 7, 
        6, 7, 6, 6, 6, 6, 5, 6, 5, 4, 5, 5, 4, 4, 5, 4, 4, 5, 4, 4, 4, 5, 4, 
        4, 4, 4, 4, 4, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 3, 2, 2, 2, 2, 2, 2, 3, 
        2, 2, 2, 3, 2, 2, 2, 2, 2, 2, 3, 2, 2, 2, 2}; \)\)], "Input",
  CellLabel->"In[1]:="],

Cell["\<\
Obtain the x-y coordinates of the boundary, uniformly resample and normalize. \
The coordinate sequence is in effect parametrized with respect to arc length. \
Normalization introduces the desirable property of size invariance.\
\>", "Text"],

Cell[BoxData[
    \(\(<< fd`; \)\)], "Input",
  CellLabel->"In[170]:="],

Cell[BoxData[
    \(\(dataxy = XYBoundary[chain, L = 128]; \)\)], "Input",
  CellLabel->"In[18]:="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[
      ListPlot[dataxy, PlotJoined \[Rule] True, 
        DisplayFunction \[Rule] Identity], 
      Graphics[{PointSize[0.03], 
          Point[dataxy\[LeftDoubleBracket]1\[RightDoubleBracket]]}], 
      AspectRatio \[Rule] Automatic, 
      DisplayFunction \[Rule] $DisplayFunction]; \)\)], "Input",
  CellLabel->"In[41]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.48365 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00639182 1.35855 0.00639182 [
[.15165 1.34605 -6 -9 ]
[.15165 1.34605 6 0 ]
[.27948 1.34605 -6 -9 ]
[.27948 1.34605 6 0 ]
[.40732 1.34605 -6 -9 ]
[.40732 1.34605 6 0 ]
[.53516 1.34605 -6 -9 ]
[.53516 1.34605 6 0 ]
[.66299 1.34605 -9 -9 ]
[.66299 1.34605 9 0 ]
[.79083 1.34605 -9 -9 ]
[.79083 1.34605 9 0 ]
[.91866 1.34605 -9 -9 ]
[.91866 1.34605 9 0 ]
[.01131 .08018 -24 -4.5 ]
[.01131 .08018 0 4.5 ]
[.01131 .39977 -24 -4.5 ]
[.01131 .39977 0 4.5 ]
[.01131 .71936 -24 -4.5 ]
[.01131 .71936 0 4.5 ]
[.01131 1.03896 -18 -4.5 ]
[.01131 1.03896 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1.48365 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.15165 1.35855 m
.15165 1.3648 L
s
[(20)] .15165 1.34605 0 1 Mshowa
.27948 1.35855 m
.27948 1.3648 L
s
[(40)] .27948 1.34605 0 1 Mshowa
.40732 1.35855 m
.40732 1.3648 L
s
[(60)] .40732 1.34605 0 1 Mshowa
.53516 1.35855 m
.53516 1.3648 L
s
[(80)] .53516 1.34605 0 1 Mshowa
.66299 1.35855 m
.66299 1.3648 L
s
[(100)] .66299 1.34605 0 1 Mshowa
.79083 1.35855 m
.79083 1.3648 L
s
[(120)] .79083 1.34605 0 1 Mshowa
.91866 1.35855 m
.91866 1.3648 L
s
[(140)] .91866 1.34605 0 1 Mshowa
.125 Mabswid
.05577 1.35855 m
.05577 1.3623 L
s
.08773 1.35855 m
.08773 1.3623 L
s
.11969 1.35855 m
.11969 1.3623 L
s
.1836 1.35855 m
.1836 1.3623 L
s
.21556 1.35855 m
.21556 1.3623 L
s
.24752 1.35855 m
.24752 1.3623 L
s
.31144 1.35855 m
.31144 1.3623 L
s
.3434 1.35855 m
.3434 1.3623 L
s
.37536 1.35855 m
.37536 1.3623 L
s
.43928 1.35855 m
.43928 1.3623 L
s
.47124 1.35855 m
.47124 1.3623 L
s
.5032 1.35855 m
.5032 1.3623 L
s
.56711 1.35855 m
.56711 1.3623 L
s
.59907 1.35855 m
.59907 1.3623 L
s
.63103 1.35855 m
.63103 1.3623 L
s
.69495 1.35855 m
.69495 1.3623 L
s
.72691 1.35855 m
.72691 1.3623 L
s
.75887 1.35855 m
.75887 1.3623 L
s
.82279 1.35855 m
.82279 1.3623 L
s
.85475 1.35855 m
.85475 1.3623 L
s
.88671 1.35855 m
.88671 1.3623 L
s
.95062 1.35855 m
.95062 1.3623 L
s
.98258 1.35855 m
.98258 1.3623 L
s
.25 Mabswid
0 1.35855 m
1 1.35855 L
s
.02381 .08018 m
.03006 .08018 L
s
[(-200)] .01131 .08018 1 0 Mshowa
.02381 .39977 m
.03006 .39977 L
s
[(-150)] .01131 .39977 1 0 Mshowa
.02381 .71936 m
.03006 .71936 L
s
[(-100)] .01131 .71936 1 0 Mshowa
.02381 1.03896 m
.03006 1.03896 L
s
[(-50)] .01131 1.03896 1 0 Mshowa
.125 Mabswid
.02381 .1441 m
.02756 .1441 L
s
.02381 .20802 m
.02756 .20802 L
s
.02381 .27194 m
.02756 .27194 L
s
.02381 .33586 m
.02756 .33586 L
s
.02381 .46369 m
.02756 .46369 L
s
.02381 .52761 m
.02756 .52761 L
s
.02381 .59153 m
.02756 .59153 L
s
.02381 .65545 m
.02756 .65545 L
s
.02381 .78328 m
.02756 .78328 L
s
.02381 .8472 m
.02756 .8472 L
s
.02381 .91112 m
.02756 .91112 L
s
.02381 .97504 m
.02756 .97504 L
s
.02381 1.10287 m
.02756 1.10287 L
s
.02381 1.16679 m
.02756 1.16679 L
s
.02381 1.23071 m
.02756 1.23071 L
s
.02381 1.29463 m
.02756 1.29463 L
s
.02381 .01626 m
.02756 .01626 L
s
.02381 1.42246 m
.02756 1.42246 L
s
.25 Mabswid
.02381 0 m
.02381 1.48365 L
s
0 0 m
1 0 L
1 1.48365 L
0 1.48365 L
closepath
clip
newpath
.5 Mabswid
.02381 1.35855 m
.05247 1.35815 L
.08114 1.38391 L
.1098 1.40329 L
.13846 1.40922 L
.16713 1.43794 L
.19579 1.44803 L
.22445 1.44803 L
.25312 1.44803 L
.28178 1.44803 L
.31044 1.44803 L
.33911 1.44803 L
.36777 1.44833 L
.39643 1.42057 L
.4251 1.40329 L
.45376 1.40329 L
.48242 1.39875 L
.51109 1.36983 L
.53975 1.34117 L
.56841 1.31251 L
.59708 1.28384 L
.61186 1.25518 L
.62244 1.22652 L
.65125 1.19785 L
.6566 1.16919 L
.6566 1.14053 L
.6566 1.11186 L
.64332 1.0832 L
.61424 1.05454 L
.61191 1.02582 L
.58929 1.01978 L
.56062 1.0005 L
.53196 .97184 L
.5033 .94318 L
.47463 .93029 L
.44597 .93029 L
.42649 .92111 L
.4323 .89825 L
.46105 .89834 L
.48971 .89834 L
.51838 .89868 L
.54704 .87367 L
.5757 .85359 L
.60437 .85359 L
.63303 .85198 L
.66169 .82293 L
.69036 .79427 L
.71902 .76527 L
.74768 .76436 L
.77635 .74024 L
Mistroke
.80501 .71157 L
.83367 .68291 L
.86234 .65425 L
.891 .62558 L
.91966 .59692 L
.93145 .56826 L
.94503 .53959 L
.9741 .51093 L
.97619 .48227 L
.97619 .4536 L
.97619 .42494 L
.97619 .39628 L
.96321 .36761 L
.93414 .33895 L
.93145 .31029 L
.90918 .28163 L
.88051 .25912 L
.85185 .25667 L
.82319 .22759 L
.79452 .19893 L
.76586 .1701 L
.7372 .16967 L
.70853 .16967 L
.67987 .1482 L
.65121 .12476 L
.62254 .12493 L
.59388 .12522 L
.56522 .09746 L
.53655 .08018 L
.50789 .08018 L
.47923 .08018 L
.45056 .07902 L
.4219 .05002 L
.39324 .03544 L
.36457 .03544 L
.33591 .03544 L
.30725 .03544 L
.27858 .03544 L
.24992 .03544 L
.22114 .03533 L
.21556 .05841 L
.21556 .08707 L
.21556 .11574 L
.21556 .1444 L
.21556 .17306 L
.21556 .20173 L
.21556 .23039 L
.21556 .25905 L
.21556 .28772 L
.21556 .31638 L
Mistroke
.21556 .34504 L
.19689 .37371 L
.17041 .40237 L
.17082 .43103 L
.17082 .4597 L
.17082 .48836 L
.17082 .51702 L
.17082 .54569 L
.17082 .57435 L
.15934 .60301 L
.1304 .63168 L
.12608 .66034 L
.12608 .689 L
.12608 .71767 L
.1119 .74633 L
.08285 .77499 L
.08134 .80366 L
.08134 .83232 L
.08134 .86098 L
.08134 .88965 L
.08134 .91831 L
.08134 .94697 L
.07434 .97564 L
.04568 1.0043 L
.03659 1.03296 L
.03659 1.06163 L
.03659 1.09029 L
.03659 1.11895 L
Mfstroke
.03 w
.02381 1.35855 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[41]:=",
  ImageSize->{194.063, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`400032000181000`40O003h00O`Woo0032Ool00<9o
o`00`Woo0032Ool00<9oo`00`Woo0032Ool00<9oo`00`Woo0032Ool00<9oo`00`Woo0032Ool00<9o
o`00`Woo0032Ool001Yoo`03001oogoo0:Eoo`006Woo00<007ooOol0YGoo000JOol00`00Oomoo`2U
Ool001Yoo`03001oogoo0:Eoo`006Woo00<007ooOol0YGoo000JOol00`00Oomoo`2UOol001Yoo`03
001oogoo01iooal006Qoo`006Woo00<007ooOol07Woo00<007ooOol077oo0P00IWoo000JOol00`00
Oomoo`0MOol00`00Oomoo`0OOol2001TOol001Yoo`03001oogoo01eoo`03001oogoo025oo`03001o
ogoo065oo`006Woo00<007ooOol07Goo00<007ooOol08Woo00<007ooOol0H7oo000JOol00`00Oomo
o`0MOol00`00Oomoo`0SOol00`00Oomoo`1OOol000Yoo`<000=oo`03001oogoo009oo`03001oogoo
009oo`03001oogoo01eoo`03001oogoo02Aoo`03001oogoo05ioo`002Woo00<007ooOol00Woo00<0
07oo00000Woo00<007oo00000goo00<007ooOol07Goo00<007ooOol09Goo00<007ooOol0GGoo0005
Ool30003Ool01`00Oomoogoo001oo`00009oo`03001oo`0000=oo`8001ioo`03001oogoo02Ioo`l0
051oo`002goo00L007ooOomoo`00Ool00002Ool00`00Ool00003Ool00`00Oomoo`0MOol00`00Oomo
o`0eOol2001>Ool000Yoo`03001oo`00009oo`03001oo`00009oo`03001oo`0000=oo`03001oogoo
01eoo`03001oogoo03Moo`8004aoo`002goo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol0
0Woo00<007ooOol07Goo00<007ooOol0>Goo00<007ooOol0BGoo000JOol00`00Oomoo`0MOol00`00
Oomoo`0jOol00`00Oomoo`18Ool001Yoo`03001oogoo01eoo`03001oogoo03]oo`03001oogoo04Mo
o`006Woo00<007ooOol07Goo00<007ooOol0?7oo00<007ooOol0AWoo000JOol00`00Oomoo`0MOol0
0`00Oomoo`0mOol00`00Oomoo`06Ool3000lOol001Yoo`03001oogoo01eoo`03001oogoo03ioo`P0
00=oo`03001oogoo03Uoo`006Woo00<007ooOol07Goo00<007ooOol0BWoo0P00>Goo000JOol00`00
Oomoo`0MOol00`00Oomoo`1<Ool00`00Oomoo`0fOol001Yoo`03001oogoo01eoo`03001oogoo04eo
o`03001oogoo03Eoo`006Woo00<007ooOol07Goo00<007ooOol0CWoo00<007ooOol0=7oo000JOol0
0`00Oomoo`0MOol00`00Oomoo`1?Ool2000dOol001Yoo`03001oogoo01eoo`03001oogoo055oo`03
001oogoo035oo`006Woo00<007ooOol07Goo00<007ooOol0DWoo2`00:7oo000JOol00`00Oomoo`0M
Ool00`00Oomoo`1MOol00`00Oomoo`0UOol001Yoo`03001oogoo01eoo`03001oogoo05ioo`03001o
ogoo02Aoo`006Woo00<007ooOol07Goo00<007ooOol0GWoo00<007ooOol097oo000JOol00`00Oomo
o`0MOol00`00Oomoo`1OOol00`00Oomoo`0SOol001Yoo`03001oogoo01eoo`03001oogoo061oo`03
001oogoo029oo`006Woo00<007ooOol07Goo00<007ooOol0HGoo00<007ooOol08Goo000JOol00`00
Oomoo`0MOol00`00Oomoo`1ROol00`00Oomoo`0POol001Yoo`03001oogoo01eoo`03001oogoo06=o
o`03001oogoo01moo`006Woo00<007ooOol07Goo00<007ooOol0I7oo00<007ooOol07Woo000JOol0
0`00Oomoo`0MOol00`00Oomoo`1UOol00`00Oomoo`0MOol001Yoo`03001oogoo01eoo`03001oogoo
06Ioo`03001oogoo01aoo`006Woo00<007ooOol07Goo00<007ooOol0Igoo00<007ooOol06goo000J
Ool00`00Oomoo`0MOol00`00Oomoo`1XOol00`00Oomoo`0JOol001Yoo`03001oogoo01eoo`03001o
ogoo06Uoo`03001oogoo01Uoo`006Woo00<007ooOol07Goo00<007ooOol0JWoo1P005Goo000JOol0
0`00Oomoo`0MOol00`00Oomoo`1`Ool00`00Oomoo`0BOol001Yoo`03001oogoo01eoo`03001oogoo
075oo`80019oo`006Woo00<007ooOol07Goo00<007ooOol0Lgoo00<007ooOol03goo000JOol00`00
Oomoo`0MOol00`00Oomoo`1dOol00`00Oomoo`0>Ool001Yoo`03001oogoo01eoo`03001oogoo07Eo
o`03001oogoo00eoo`006Woo00<007ooOol07Goo00<007ooOol0MWoo00<007ooOol037oo000JOol0
0`00Oomoo`0MOol00`00Oomoo`1fOol00`00Oomoo`0<Ool001Yoo`03001oogoo01eoo`03001oogoo
07Moo`03001oogoo00]oo`006Woo00<007ooOol07Goo00<007ooOol0N7oo00<007ooOol02Woo000J
Ool00`00Oomoo`0MOol00`00Oomoo`1hOol00`00Oomoo`0:Ool001Yoo`03001oogoo01eoo`03001o
ogoo07Qoo`03001oogoo00Yoo`006Woo00<007ooOol07Goo00<007ooOol0N7oo00<007ooOol02Woo
000JOol00`00Oomoo`0MOol00`00Oomoo`1hOol00`00Oomoo`0:Ool001Yoo`03001oogoo01eoo`03
001oogoo07Qoo`03001oogoo00Yoo`006Woo00<007ooOol07Goo00<007ooOol0NGoo00<007ooOol0
2Goo000JOol00`00Oomoo`0LOol00`00Oomoo`1kOol00`00Oomoo`08Ool001Yoo`03001oogoo01ao
o`03001oogoo07aoo`03001oogoo00Moo`006Woo00<007ooOol06goo00<007ooOol0OWoo00<007oo
Ool01Woo000JOol00`00Oomoo`0KOol00`00Oomoo`1oOol00`00Oomoo`05Ool001Yoo`03001oogoo
01Yoo`03001oogoo081oo`03001oogoo00Eoo`006Woo00<007ooOol06Goo00<007ooOol0PWoo00<0
07ooOol017oo000JOol00`00Oomoo`0HOol00`00Oomoo`23Ool00`00Oomoo`04Ool000Uoo`D0009o
o`03001oogoo009oo`03001oogoo009oo`03001oogoo01Qoo`03001oogoo08Aoo`03001oogoo00=o
o`002goo00L007ooOomoo`00Ool00002Ool00`00Ool00003Ool00`00Oomoo`0GOol00`00Oomoo`25
Ool00`00Oomoo`03Ool000Eoo`<000=oo`03001oogoo00=oo`06001oogoo001oo`000goo0P005goo
00<007ooOol0QWoo00<007ooOol00goo000;Ool01000Oomoogoo0P000goo00<007oo00000goo00<0
07ooOol05Woo00<007ooOol0QWoo00<007ooOol00goo000;Ool01@00Oomoogoo000017oo00<007oo
00000goo00<007ooOol05Woo00<007ooOol0QWoo00<007ooOol00goo000:Ool20003Ool30003Ool0
0`00Oomoo`02Ool00`00Oomoo`0FOol00`00Oomoo`26Ool00`00Oomoo`03Ool001Yoo`03001oogoo
01Ioo`03001oogoo08Ioo`03001oogoo00=oo`006Woo00<007ooOol05Woo00<007ooOol0QWoo00<0
07ooOol00goo000JOol00`00Oomoo`0FOol00`00Oomoo`26Ool00`00Oomoo`03Ool001Yoo`03001o
ogoo01Ioo`03001oogoo08Ioo`03001oogoo00=oo`006Woo00<007ooOol05Woo00<007ooOol0QWoo
00<007ooOol00goo000JOol00`00Oomoo`0FOol00`00Oomoo`26Ool00`00Oomoo`03Ool001Yoo`03
001oogoo01Ioo`03001oogoo08Ioo`03001oogoo00=oo`006Woo00<007ooOol05Woo00<007ooOol0
QWoo00<007ooOol00goo000JOol00`00Oomoo`0FOol00`00Oomoo`26Ool00`00Oomoo`03Ool001Yo
o`03001oogoo01Ioo`03001oogoo08Ioo`03001oogoo00=oo`006Woo00<007ooOol05Woo00<007oo
Ool0QWoo00<007ooOol00goo000JOol00`00Oomoo`0FOol00`00Oomoo`26Ool00`00Oomoo`03Ool0
01Yoo`03001oogoo01Ioo`03001oogoo08Ioo`03001oogoo00=oo`006Woo00<007ooOol05Woo00<0
07ooOol0QWoo00<007ooOol00goo000JOol00`00Oomoo`0FOol00`00Oomoo`26Ool00`00Oomoo`03
Ool001Yoo`03001oogoo01Ioo`03001oogoo08Ioo`03001oogoo00=oo`006Woo00<007ooOol05Woo
00<007ooOol0QGoo00<007ooOol017oo000JOol00`00Oomoo`0FOol00`00Oomoo`23Ool20007Ool0
01Yoo`03001oogoo01Ioo`03001oogoo089oo`03001oogoo00Moo`006Woo00<007ooOol05Woo00<0
07ooOol0PGoo00<007ooOol027oo000JOol00`00Oomoo`0FOol00`00Oomoo`21Ool00`00Oomoo`08
Ool001Yoo`03001oogoo01Ioo`03001oogoo081oo`03001oogoo00Uoo`006Woo00<007ooOol05Woo
00<007ooOol0P7oo00<007ooOol02Goo000JOol00`00Oomoo`0FOol00`00Oomoo`1oOol00`00Oomo
o`0:Ool001Yoo`03001oogoo01Ioo`03001oogoo07moo`03001oogoo00Yoo`006Woo00<007ooOol0
5Woo00<007ooOol0Ogoo00<007ooOol02Woo000JOol00`00Oomoo`0FOol00`00Oomoo`1nOol00`00
Oomoo`0;Ool001Yoo`03001oogoo01Eoo`03001oogoo07moo`03001oogoo00]oo`006Woo00<007oo
Ool05Goo00<007ooOol0OWoo00<007ooOol037oo000JOol00`00Oomoo`0DOol00`00Oomoo`1oOol0
0`00Oomoo`0<Ool001Yoo`03001oogoo01Aoo`03001oogoo07ioo`03001oogoo00eoo`006Woo00<0
07ooOol04goo00<007ooOol0OWoo00<007ooOol03Woo000JOol00`00Oomoo`0BOol00`00Oomoo`1n
Ool00`00Oomoo`0?Ool001Yoo`03001oogoo015oo`03001oogoo07ioo`03001oogoo011oo`006Woo
00<007ooOol047oo00<007ooOol0OWoo00<007ooOol04Goo000JOol00`00Oomoo`0?Ool00`00Oomo
o`1nOol00`00Oomoo`0BOol001Yoo`03001oogoo00moo`03001oogoo07eoo`03001oogoo01=oo`00
6Woo00<007ooOol03goo00<007ooOol0O7oo00<007ooOol057oo000JOol00`00Oomoo`0>Ool00`00
Oomoo`1lOol00`00Oomoo`0EOol001Yoo`03001oogoo00ioo`03001oogoo07]oo`03001oogoo01Io
o`006Woo00<007ooOol03Woo00<007ooOol0NWoo00<007ooOol05goo000JOol00`00Oomoo`0>Ool0
0`00Oomoo`1iOol00`00Oomoo`0HOol001Yoo`03001oogoo00ioo`03001oogoo07Qoo`03001oogoo
01Uoo`006Woo00<007ooOol03Woo00<007ooOol0Mgoo00<007ooOol06Woo000JOol00`00Oomoo`0>
Ool00`00Oomoo`1fOol00`00Oomoo`0KOol001Yoo`03001oogoo00ioo`03001oogoo07Eoo`03001o
ogoo01aoo`006Woo00<007ooOol03Woo00<007ooOol0M7oo00<007ooOol07Goo000JOol00`00Oomo
o`0>Ool00`00Oomoo`1cOol00`00Oomoo`0NOol000Uoo`D0009oo`03001oogoo009oo`03001oogoo
009oo`03001oogoo00ioo`03001oogoo079oo`03001oogoo01moo`002goo00L007ooOomoo`00Ool0
0002Ool00`00Ool00003Ool00`00Oomoo`0>Ool00`00Oomoo`1aOol00`00Oomoo`0POol000Eoo`<0
00=oo`07001oogooOol007oo00000Woo00<007oo00000goo0P003goo00<007ooOol0L7oo00<007oo
Ool08Goo000;Ool01`00Oomoogoo001oo`00009oo`03001oo`0000=oo`03001oogoo00ioo`03001o
ogoo06moo`03001oogoo029oo`002goo00L007ooOomoo`00Ool00002Ool00`00Ool00003Ool00`00
Oomoo`0=Ool00`00Oomoo`1_Ool00`00Oomoo`0SOol000Yoo`8000Aoo`03001oogoo009oo`03001o
ogoo009oo`03001oogoo00eoo`03001oogoo06ioo`03001oogoo02Aoo`006Woo00<007ooOol037oo
00<007ooOol0KWoo00<007ooOol09Goo000JOol00`00Oomoo`0<Ool00`00Oomoo`1]Ool00`00Oomo
o`0VOol001Yoo`03001oogoo00]oo`03001oogoo06aoo`8002Uoo`006Woo00<007ooOol02Woo00<0
07ooOol0K7oo00<007ooOol0:Goo000JOol00`00Oomoo`09Ool00`00Oomoo`1XOol5000/Ool001Yo
o`03001oogoo00Qoo`03001oogoo06Qoo`03001oogoo02moo`006Woo00<007ooOol01goo00<007oo
Ool0J7oo00<007ooOol0<7oo000JOol00`00Oomoo`07Ool00`00Oomoo`1WOol00`00Oomoo`0aOol0
01Yoo`03001oogoo00Moo`03001oogoo06Ioo`03001oogoo039oo`006Woo00<007ooOol01Woo00<0
07ooOol0IWoo00<007ooOol0<goo000JOol00`00Oomoo`06Ool00`00Oomoo`1UOol00`00Oomoo`0d
Ool001Yoo`03001oogoo00Ioo`03001oogoo06Aoo`03001oogoo03Eoo`006Woo00<007ooOol01Woo
00<007ooOol0Hgoo00<007ooOol0=Woo000JOol00`00Oomoo`06Ool00`00Oomoo`1ROol00`00Oomo
o`0gOol001Yoo`03001oogoo00Ioo`03001oogoo065oo`03001oogoo03Qoo`006Woo00<007ooOol0
1Woo00<007ooOol0H7oo00<007ooOol0>Goo000JOol00`00Oomoo`06Ool00`00Oomoo`1OOol00`00
Oomoo`0jOol001Yoo`03001oogoo00Ioo`03001oogoo05ioo`03001oogoo03]oo`006Woo00<007oo
Ool01Woo00<007ooOol0GGoo00<007ooOol0?7oo000JOol00`00Oomoo`06Ool00`00Oomoo`1BOol;
000oOol001Yoo`03001oogoo00Ioo`03001oogoo055oo`03001oogoo04Qoo`006Woo00<007ooOol0
1Woo00<007ooOol0Cgoo0P00Bgoo000JOol00`00Oomoo`06Ool00`00Oomoo`1>Ool00`00Oomoo`1;
Ool001Yoo`03001oogoo00Ioo`03001oogoo04eoo`03001oogoo04aoo`006Woo00<007ooOol01Woo
00<007ooOol0C7oo00<007ooOol0CGoo000JOol00`00Oomoo`06Ool00`00Oomoo`1:Ool2001@Ool0
01Yoo`03001oogoo00Ioo`03001oogoo04Uoo`03001oogoo051oo`006Woo00<007ooOol01Woo00<0
07ooOol0>Goo4000Dgoo000JOol00`00Oomoo`06Ool00`00Oomoo`0iOol00`00Oomoo`1POol001Yo
o`03001oogoo00Ioo`03001oogoo03Qoo`03001oogoo065oo`006Woo00<007ooOol01Woo00<007oo
Ool0>7oo00<007ooOol0HGoo000JOol00`00Oomoo`06Ool00`00Oomoo`0hOol2001ROol001Yoo`03
001oogoo00Ioo`03001oogoo03Yoo`T005Uoo`006Woo00<007ooOol01Woo00<007ooOol0@goo0P00
Egoo000JOol00`00Oomoo`06Ool00`00Oomoo`15Ool2001EOol001Yoo`03001oogoo00Ioo`03001o
ogoo04Moo`03001oogoo059oo`006Woo00<007ooOol01Woo00<007ooOol0B7oo00<007ooOol0DGoo
000JOol00`00Oomoo`06Ool00`00Oomoo`19Ool00`00Oomoo`1@Ool001Yoo`03001oogoo00Eoo`03
001oogoo04]oo`03001oogoo04moo`006Woo00<007ooOol01Goo00<007ooOol0C7oo00<007ooOol0
CWoo000JOol00`00Oomoo`05Ool00`00Oomoo`1=Ool00`00Oomoo`1=Ool001Yoo`03001oogoo00Ao
o`03001oogoo04moo`03001oogoo04aoo`006Woo00<007ooOol00goo00<007ooOol0D7oo00<007oo
Ool0C7oo000JOol00`00Oomoo`02Ool00`00Oomoo`1BOol00`00Oomoo`1;Ool001Yoo`05001oogoo
Ool0001FOol00`00Oomoo`1:Ool001Yoo`04001oogoo001HOol00`00Oomoo`19Ool001Yoo`04001o
ogoo001IOol20019Ool001Yoo`04001oogoo001KOol00`00Oomoo`16Ool001Yoo`03001oo`0005eo
o`8004Ioo`0047oo00<007ooOol00Woo00<007ooOol00Woo00<007oo0000Ggoo0`00@goo000?Ool0
0`00Ool00002Ool00`00Ool00003Ool00`00Ool0001QOol00`00Oomoo`11Ool000Yoo`<000Aoo`06
001oogoo001oo`000goo0`00HWoo00<007ooOol0@7oo000?Ool20003Ool00`00Ool00003Ool00`00
Ool0001ROol00`00Oomoo`10Ool000moo`03001oogoo009oo`03001oo`0000=oo`03001oo`00069o
o`03001oogoo041oo`003goo0`000goo00<007ooOol00Woo00<007oo0000Hgoo00<007ooOol0?goo
000JOol00`00Ool0001TOol00`00Oomoo`0nOol001Yoo`03001oo`0006Eoo`03001oogoo03eoo`00
6Woo00<007oo0000IWoo00<007ooOol0?7oo000JOol00`00Ool0001WOol00`00Oomoo`0kOol001Yo
o`03001oo`0006Moo`03001oogoo03]oo`006Woo00<007oo0000J7oo00<007ooOol0>Woo000JOol0
0`00Ool0001XOol00`00Oomoo`0jOol001Yoo`03001oo`0006Uoo`03001oogoo03Uoo`006Woo00<0
07oo0000JGoo00<007ooOol0>Goo000JOol00`00Ool0001YOol00`00Oomoo`0iOol001Yoo`03001o
ogoo06Uoo`03001oogoo03Uoo`006Woo00<007ooOol0JGoo00<007ooOol0>Goo000JOol00`00Oomo
o`1YOol00`00Oomoo`0iOol001Yoo`03001oogoo06Uoo`03001oogoo03Uoo`006Woo00<007ooOol0
JGoo00<007ooOol0>Goo000JOol00`00Oomoo`1YOol00`00Oomoo`0iOol001Yoo`03001oogoo06Uo
o`03001oogoo03Uoo`006Woo00<007ooOol0JGoo00<007ooOol0>Goo000JOol00`00Oomoo`1YOol0
0`00Oomoo`0iOol001Yoo`03001oogoo06Uoo`03001oogoo03Uoo`006Woo00<007ooOol0JGoo00<0
07ooOol0>Goo000JOol00`00Oomoo`1XOol00`00Oomoo`0jOol001Yoo`03001oogoo06Qoo`03001o
ogoo03Yoo`006Woo00<007ooOol0J7oo00<007ooOol0>Woo000JOol00`00Oomoo`1WOol00`00Oomo
o`0kOol001Yoo`03001oogoo06Ioo`03001oogoo03aoo`006Woo00<007ooOol0IGoo00<007ooOol0
?Goo000JOol00`00Oomoo`1TOol00`00Oomoo`0nOol001Yoo`03001oogoo06=oo`03001oogoo03mo
o`006Woo00<007ooOol0Hgoo00<007ooOol0?goo000JOol00`00Oomoo`1ROol00`00Oomoo`10Ool0
01Yoo`03001oogoo069oo`03001oogoo041oo`006Woo00<007ooOol0HGoo00<007ooOol0@Goo000J
Ool00`00Oomoo`1QOol00`00Oomoo`11Ool001Yoo`03001oogoo065oo`03001oogoo045oo`006Woo
00<007ooOol0H7oo00<007ooOol0@Woo000JOol00`00Oomoo`1POol00`00Oomoo`12Ool001Yoo`03
001oogoo05moo`03001oogoo04=oo`006Woo00<007ooOol0Ggoo00<007ooOol0@goo000JOol00`00
Oomoo`1NOol00`00Oomoo`14Ool001Yoo`03001oogoo00moo`<000=oo`03001oogoo00eoo`<0009o
o`03001oogoo00eoo`8000Aoo`03001oogoo00ioo`03001oogoo009oo`03001oogoo00Aoo`03001o
ogoo009oo`D0009oo`03001oogoo009oo`03001oogoo00Moo`D00004Ool000000003Ool00`00Oomo
o`07Ool50002Ool30002Ool00`00Oomoo`08Ool001Yoo`03001oogoo00moo`03001oogoo009oo`03
001oo`0000moo`06001oogoo001oo`003Woo00<007oo00000Woo00<007oo00003Woo00<007oo0000
0Woo00<007oo000017oo00<007ooOol01Goo00L007ooOomoo`00Ool00002Ool00`00Ool0000:Ool0
1@00Oomoogoo000017oo00<007oo00002Woo00<007ooOol00goo00H007ooOol007oo0009Ool001Yo
o`03001oogoo011oo`07001oogooOol007oo00003Goo100000Aoo`00Ool000ioo`03001oo`00009o
o`03001oo`0000ioo`03001oo`00009oo`03001oo`0000=oo`03001oogoo00Ioo`07001oogooOol0
07oo00000Woo00<007oo00002Woo00<007ooOol00Woo00L007ooOomoo`00Ool0000:Ool01000Oomo
ogoo100000Aoo`00Ool000Uoo`006Woo00<007ooOol047oo00L007ooOomoo`00Ool0000=Ool00`00
Ool00002Ool00`00Ool0000>Ool20003Ool00`00Ool0000?Ool01`00Oomoogoo001oo`00009oo`03
001oogoo00Moo`07001oogooOol007oo00000Woo00<007oo00002Woo00<007ooOol00Woo00L007oo
Oomoo`00Ool0000:Ool01`00Oomoogoo001oo`00009oo`03001oo`0000Uoo`006Woo00<007ooOol0
3goo00<007oo00000Woo00<007oo00003Woo0P000Woo00<007oo00003Woo00<007ooOol00Woo00<0
07oo00003Woo00<007oo00000Woo00D007oo001oo`0000Yoo`07001oogooOol007oo00000Woo00<0
07oo00002Woo00L007ooOomoo`00Ool00002Ool00`00Ool0000:Ool00`00Oomoo`02Ool20002Ool0
0`00Ool00009Ool001Yoo`03001oogoo011oo`03001oogoo009oo`03001oogoo00ioo`05001oogoo
Ool0000@Ool20003Ool00`00Oomoo`0>Ool00`00Oomoo`02Ool3000:Ool20004Ool00`00Oomoo`02
Ool00`00Oomoo`08Ool20004Ool00`00Oomoo`02Ool00`00Oomoo`08Ool20005Ool01@00Oomoogoo
00002Woo000JOol00`00Oomoo`1FOol00`00Oomoo`1<Ool001Yoo`03001oogoo05Eoo`03001oogoo
04eoo`006Woo00<007ooOol0E7oo00<007ooOol0CWoo000IOol3001DOol00`00Oomoo`1?Ool001Io
oj`0000067oo1@000Woo0P0017oo00<007ooOol00Woo00<007ooOol00goo00<007ooOol00Woo00<0
07ooOol00Woo00<007ooOol00goo00<007ooOol00Woo00<007ooOol00goo00<007ooOol00Woo00<0
07ooOol00goo00<007ooOol00Woo00<007ooOol00goo00<007ooOol00Woo00<007ooOol00goo00<0
07oo00000Woo00<007ooOol00goo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol00goo00<0
07ooOol00Woo00<007ooOol00goo00<007ooOol00Woo00<007ooOol00goo00<007ooOol00Woo00<0
07ooOol00goo00<007ooOol00Woo00<007ooOol00goo00<007ooOol00Woo00<007ooOol00goo00<0
07ooOol00Goo000HOol50004Ool00`00Oomoo`0<Ool00`00Oomoo`0BOol00`00Oomoo`0COol00`00
Oomoo`0?Ool01@00Oomoogoo00005Goo00<007ooOol04goo00<007ooOol04goo00<007ooOol037oo
000IOol30005Ool00`00Oomoo`18Ool00`00Oomoo`1COol001Yoo`03001oogoo00Eoo`03001oogoo
04Ioo`03001oogoo05Aoo`006Woo00<007ooOol01Woo00<007ooOol0A7oo00<007ooOol0EGoo000J
Ool00`00Oomoo`07Ool20013Ool00`00Oomoo`1FOol001Yoo`03001oogoo00Uoo`8003ioo`<005Uo
o`006Woo00<007ooOol02goo0`00<goo2000G7oo000JOol00`00Oomoo`0>Ool3000^Ool2001TOol0
01Yoo`03001oogoo015oo`03001oogoo02Uoo`8006Ioo`006Woo00<007ooOol04Woo00<007ooOol0
9goo00<007ooOol0IWoo000JOol00`00Oomoo`0COol00`00Oomoo`0UOol00`00Oomoo`1WOol001Yo
o`03001oogoo01Aoo`03001oogoo02=oo`03001oogoo06Qoo`006Woo00<007ooOol05Goo0P008Woo
00<007ooOol0JGoo000JOol00`00Oomoo`0GOol2000OOol00`00Oomoo`1ZOol001Yoo`03001oogoo
01Uooal006eoo`006Woo00<007ooOol0YGoo000JOol00`00Oomoo`2UOol001Yoo`03001oogoo0:Eo
o`006Woo00<007ooOol0YGoo000JOol00`00Oomoo`2UOol001Yoo`03001oogoo0:Eoo`00`Woo0032
Ool00<9oo`00`Woo0032Ool00<9oo`00`Woo0032Ool00<9oo`00`Woo0032Ool00<9oo`00`Woo0032
Ool00<9oo`00`Woo0000\
\>"],
  ImageRangeCache->{{{0, 193.063}, {287, 0}} -> {-23.9149, -227.781, 0.91494, 
  0.91494}}]
}, Open  ]],

Cell["\<\
Consider the effect of three transformations of the boundary: planar \
translation, planar rotation and change in starting position.\
\>", "Text"],

Cell[BoxData[
    \(\[Theta] = 2\ \[Pi]\ Random[]; \n
    T = Table[Random[Integer, {1, 50}], {2}]; \n
    data = N[RotateRight[\((# + T\ &)\)\ /@\ dataxy, 
            Random[Integer, {1, L - 1}]] . {{Cos[\[Theta]], 
              \(-Sin[\[Theta]]\)}, {Sin[\[Theta]], Cos[\[Theta]]}}]; \)], 
  "Input",
  CellLabel->"In[30]:="],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[
      ListPlot[data, PlotJoined \[Rule] True, 
        DisplayFunction \[Rule] Identity], 
      Graphics[{PointSize[0.03], 
          Point[data\[LeftDoubleBracket]1\[RightDoubleBracket]]}], 
      AspectRatio \[Rule] Automatic, 
      DisplayFunction \[Rule] $DisplayFunction]; \)\)], "Input",
  CellLabel->"In[31]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .60404 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.196689 0.00428319 0.0143819 0.00428319 [
[.41085 .00188 -6 -9 ]
[.41085 .00188 6 0 ]
[.62501 .00188 -9 -9 ]
[.62501 .00188 9 0 ]
[.83917 .00188 -9 -9 ]
[.83917 .00188 9 0 ]
[.18419 .10005 -12 -4.5 ]
[.18419 .10005 0 4.5 ]
[.18419 .18571 -12 -4.5 ]
[.18419 .18571 0 4.5 ]
[.18419 .27137 -12 -4.5 ]
[.18419 .27137 0 4.5 ]
[.18419 .35704 -12 -4.5 ]
[.18419 .35704 0 4.5 ]
[.18419 .4427 -18 -4.5 ]
[.18419 .4427 0 4.5 ]
[.18419 .52837 -18 -4.5 ]
[.18419 .52837 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .60404 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.41085 .01438 m
.41085 .02063 L
s
[(50)] .41085 .00188 0 1 Mshowa
.62501 .01438 m
.62501 .02063 L
s
[(100)] .62501 .00188 0 1 Mshowa
.83917 .01438 m
.83917 .02063 L
s
[(150)] .83917 .00188 0 1 Mshowa
.125 Mabswid
.23952 .01438 m
.23952 .01813 L
s
.28235 .01438 m
.28235 .01813 L
s
.32519 .01438 m
.32519 .01813 L
s
.36802 .01438 m
.36802 .01813 L
s
.45368 .01438 m
.45368 .01813 L
s
.49651 .01438 m
.49651 .01813 L
s
.53934 .01438 m
.53934 .01813 L
s
.58218 .01438 m
.58218 .01813 L
s
.66784 .01438 m
.66784 .01813 L
s
.71067 .01438 m
.71067 .01813 L
s
.7535 .01438 m
.7535 .01813 L
s
.79634 .01438 m
.79634 .01813 L
s
.15386 .01438 m
.15386 .01813 L
s
.11103 .01438 m
.11103 .01813 L
s
.06819 .01438 m
.06819 .01813 L
s
.02536 .01438 m
.02536 .01813 L
s
.882 .01438 m
.882 .01813 L
s
.92483 .01438 m
.92483 .01813 L
s
.96766 .01438 m
.96766 .01813 L
s
.25 Mabswid
0 .01438 m
1 .01438 L
s
.19669 .10005 m
.20294 .10005 L
s
[(20)] .18419 .10005 1 0 Mshowa
.19669 .18571 m
.20294 .18571 L
s
[(40)] .18419 .18571 1 0 Mshowa
.19669 .27137 m
.20294 .27137 L
s
[(60)] .18419 .27137 1 0 Mshowa
.19669 .35704 m
.20294 .35704 L
s
[(80)] .18419 .35704 1 0 Mshowa
.19669 .4427 m
.20294 .4427 L
s
[(100)] .18419 .4427 1 0 Mshowa
.19669 .52837 m
.20294 .52837 L
s
[(120)] .18419 .52837 1 0 Mshowa
.125 Mabswid
.19669 .0358 m
.20044 .0358 L
s
.19669 .05721 m
.20044 .05721 L
s
.19669 .07863 m
.20044 .07863 L
s
.19669 .12146 m
.20044 .12146 L
s
.19669 .14288 m
.20044 .14288 L
s
.19669 .16429 m
.20044 .16429 L
s
.19669 .20713 m
.20044 .20713 L
s
.19669 .22854 m
.20044 .22854 L
s
.19669 .24996 m
.20044 .24996 L
s
.19669 .29279 m
.20044 .29279 L
s
.19669 .31421 m
.20044 .31421 L
s
.19669 .33562 m
.20044 .33562 L
s
.19669 .37845 m
.20044 .37845 L
s
.19669 .39987 m
.20044 .39987 L
s
.19669 .42129 m
.20044 .42129 L
s
.19669 .46412 m
.20044 .46412 L
s
.19669 .48553 m
.20044 .48553 L
s
.19669 .50695 m
.20044 .50695 L
s
.19669 .54978 m
.20044 .54978 L
s
.19669 .5712 m
.20044 .5712 L
s
.19669 .59261 m
.20044 .59261 L
s
.25 Mabswid
.19669 0 m
.19669 .60404 L
s
0 0 m
1 0 L
1 .60404 L
0 .60404 L
closepath
clip
newpath
.5 Mabswid
.34305 .43518 m
.36147 .4294 L
.36206 .41372 L
.3704 .39213 L
.38488 .36914 L
.39935 .34616 L
.40352 .32551 L
.39926 .30678 L
.40238 .29269 L
.41817 .2931 L
.42239 .31189 L
.42664 .33062 L
.43067 .34941 L
.45127 .36442 L
.46864 .38018 L
.47289 .39891 L
.4782 .4174 L
.50144 .43182 L
.52442 .44629 L
.54763 .46072 L
.55248 .47931 L
.57249 .49446 L
.59548 .50894 L
.61846 .52342 L
.64145 .53789 L
.66443 .55237 L
.68742 .56684 L
.7079 .57029 L
.72864 .57491 L
.75169 .58966 L
.77073 .58677 L
.78946 .58251 L
.80819 .57826 L
.82692 .574 L
.84372 .56127 L
.85814 .53802 L
.87647 .532 L
.89189 .5132 L
.90235 .49113 L
.8997 .47203 L
.91444 .44899 L
.92891 .426 L
.9435 .40299 L
.93953 .3842 L
.93527 .36547 L
.94505 .34355 L
.95611 .32134 L
.95175 .30263 L
.9473 .28395 L
.96119 .2611 L
Mistroke
.96822 .2398 L
.96397 .22107 L
.95972 .20234 L
.95622 .18344 L
.97092 .1604 L
.97619 .13951 L
.97194 .12078 L
.96768 .10205 L
.96343 .08332 L
.95917 .06459 L
.95492 .04586 L
.95072 .02704 L
.93481 .02682 L
.91608 .03107 L
.89735 .03533 L
.87862 .03958 L
.85989 .04383 L
.84116 .04809 L
.82243 .05234 L
.8037 .0566 L
.78497 .06085 L
.76624 .0651 L
.74751 .06936 L
.726 .06141 L
.70334 .04836 L
.68467 .05288 L
.66594 .05714 L
.64721 .06139 L
.62848 .06565 L
.60975 .0699 L
.59102 .07416 L
.57059 .0709 L
.54756 .05625 L
.52819 .05768 L
.50946 .06193 L
.49073 .06619 L
.46989 .06118 L
.44685 .04645 L
.4279 .04971 L
.40917 .05397 L
.39044 .05822 L
.37171 .06248 L
.35298 .06673 L
.33425 .07098 L
.31448 .07067 L
.29149 .05619 L
.27141 .05451 L
.25268 .05876 L
.23395 .06302 L
.21522 .06727 L
Mistroke
.05676 .09448 L
.06127 .11315 L
.04869 .13571 L
.04028 .15731 L
.04067 .17692 L
.02615 .19992 L
.02381 .22014 L
.02806 .23887 L
.03232 .2576 L
.03657 .27633 L
.04083 .29506 L
.04508 .3138 L
.04914 .33257 L
.07154 .34718 L
.08708 .36335 L
.09134 .38208 L
.09856 .40013 L
.12171 .41457 L
.14469 .42905 L
.16768 .44352 L
.19066 .458 L
.21158 .4634 L
.23189 .46607 L
.25489 .48064 L
.27442 .47988 L
.29315 .47562 L
.31188 .47137 L
.32864 .45844 L
Mfstroke
.03 w
.34305 .43518 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[31]:=",
  ImageSize->{288, 173.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004U0000/A000`40O003h00Oogoo9Woo001fOol0
0`00Oomoo`02Ool00`00Oomoo`0_Ool50002Ool00`00Oomoo`02Ool00`00Oomoo`0/Ool50002Ool0
0`00Oomoo`02Ool00`00Oomoo`0^Ool007Eoo`03001oo`00009oo`03001oo`00039oo`07001oogoo
Ool007oo00000Woo00<007oo0000;goo00L007ooOomoo`00Ool00002Ool00`00Ool0000_Ool007Mo
o`06001oogoo001oo`00<Woo00L007ooOomoo`00Ool00002Ool00`00Ool0000_Ool00`00Oomoo`03
Ool01P00Oomoo`00Ool002moo`00MGoo0P000goo00<007oo0000<Woo00L007ooOomoo`00Ool00002
Ool00`00Ool0000_Ool01000Oomoogoo0P000goo00<007oo0000;goo001eOol00`00Oomoo`02Ool0
0`00Ool0000bOol01`00Oomoogoo001oo`00009oo`03001oo`0002moo`05001oogooOol00004Ool0
0`00Ool0000_Ool007Eoo`<000=oo`03001oogoo031oo`8000Aoo`03001oogoo009oo`03001oogoo
02eoo`8000=oo`<000=oo`03001oogoo02ioo`00ogoo9Woo003oOolVOol003eoo`03001oogoo0>Eo
o`00?Goo00<007ooOol0iGoo000mOol00`00Oomoo`3UOol003eoo`03001oogoo0>Eoo`001gooo`00
5`0027oo000>Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`08Ool0
0`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`09Ool0
0`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`08Ool00`00Oomoo`09Ool0
0`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`09Ool0
0`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`08Ool00`00Oomoo`0?Ool003eoo`03001oogoo
03Uoo`03001oogoo03Qoo`03001oogoo03Uoo`03001oogoo039oo`00?Goo00<007ooOol0b7oo2000
5Goo000mOol00`00Oomoo`34Ool40007Ool00`00Oomoo`0COol003eoo`03001oogoo0<9oo`8000]o
o`03001oogoo01=oo`00?Goo0`00_Woo10003Woo00<007ooOol04Woo000mOol00`00Oomoo`2iOol5
000BOol00`00Oomoo`0BOol003eoo`03001oogoo0;Aoo`D001Moo`03001oogoo019oo`00?Goo00<0
07ooOol0@Goo0`00AGoo0P008goo1P0077oo00<007ooOol04Woo000mOol00`00Oomoo`0lOol50003
Ool20011Ool20002Ool2000MOol4000ROol00`00Oomoo`0BOol003eoo`03001oogoo011oo`T001eo
o`H000Yoo`03001oogoo01Aoo`<002=oo`@000Ioo`03001oogoo01Qoo`8002Ioo`03001oogoo019o
o`00?Goo0`002goo1@002Goo0P005Woo1@004Goo0P003Woo1P000goo00<007ooOol06goo1@002goo
0P0057oo1000:Goo00<007ooOol04Goo000mOol00`00Oomoo`07Ool4000@Ool00`00Oomoo`0>Ool5
000HOol30006Ool5000:Ool00`00Oomoo`0EOol5000BOol2000=Ool5000]Ool00`00Oomoo`0AOol0
03eoo`03001oogoo00Eoo`8001Eoo`8000Yoo`@0021oo`H0011oo`8000moo`H001Uoo`<000Eoo`D0
039oo`03001oogoo015oo`00?Goo00<007ooOol01@006Goo0`001Goo0P00?7oo00<007ooOol01goo
1@008Woo1@00=goo00<007ooOol04Goo000jOol6000QOol5000oOol9001SOol00`00Oomoo`0AOol0
03Aoo`H000=oo`03001oogoo0=9oo`03001oogoo011oo`00;Woo1P002Goo0`00dWoo00<007ooOol0
47oo000WOol7000?Ool00`00Oomoo`3BOol00`00Oomoo`0@Ool0025oo`H001Ioo`03001oogoo0=9o
o`03001oogoo011oo`006goo1P0077oo00<007ooOol0dWoo00<007ooOol047oo000GOol4000FOol3
0003Ool00`00Oomoo`03Ool00`00Oomoo`3COol00`00Oomoo`0?Ool001Moo`03001oogoo01Moo`03
001oogoo009oo`03001oo`0000Aoo`03001oogoo0==oo`03001oogoo00moo`005goo00<007ooOol0
67oo00L007ooOomoo`00Ool00004Ool3003COol00`00Oomoo`0?Ool001Qoo`03001oogoo01Moo`07
001oogooOol007oo000017oo00<007ooOol0dgoo00<007ooOol03goo000HOol00`00Oomoo`0FOol0
0`00Ool00002Ool00`00Ool00004Ool00`00Oomoo`3DOol00`00Oomoo`0>Ool001Qoo`03001oogoo
01Moo`03001oogoo009oo`03001oogoo00=oo`03001oogoo0=Aoo`03001oogoo00ioo`005goo00<0
07ooOol08goo00<007ooOol0eGoo00<007ooOol03Goo000GOol00`00Oomoo`0SOol00`00Oomoo`3E
Ool00`00Oomoo`0=Ool001Ioo`03001oogoo02Aoo`<00=Eoo`03001oogoo00eoo`005Woo00<007oo
Ool097oo00<007ooOol0eGoo00<007ooOol03Goo000EOol00`00Oomoo`0UOol00`00Oomoo`3FOol0
0`00Oomoo`0<Ool001Eoo`03001oogoo02Eoo`03001oogoo0=Ioo`03001oogoo00aoo`0057oo00<0
07ooOol09Woo00<007ooOol0eWoo00<007ooOol037oo000DOol00`00Oomoo`0VOol00`00Oomoo`3F
Ool00`00Oomoo`0<Ool001=oo`03001oogoo02Moo`<00=Ioo`03001oogoo00aoo`004goo00<007oo
Ool09goo00<007ooOol0eGoo00<007ooOol03Goo000COol00`00Oomoo`0WOol00`00Oomoo`3EOol0
0`00Oomoo`0=Ool0019oo`03001oogoo02Qoo`03001oogoo0=Aoo`03001oogoo00ioo`004Woo00<0
07ooOol0:7oo00<007ooOol0e7oo00<007ooOol03Woo000BOol00`00Oomoo`0XOol3003COol00`00
Oomoo`0?Ool0019oo`03001oogoo02Qoo`03001oogoo0==oo`03001oogoo00moo`004Woo00<007oo
Ool0:7oo00<007ooOol0dWoo00<007ooOol047oo000BOol00`00Oomoo`0XOol00`00Oomoo`3BOol0
0`00Oomoo`0@Ool0019oo`03001oogoo01eoo`<0009oo`03001oogoo00=oo`03001oogoo0=5oo`03
001oogoo015oo`004Goo00<007ooOol07goo00H007ooOol007oo0004Ool00`00Oomoo`3AOol00`00
Oomoo`0AOol0015oo`03001oogoo01eoo`@00004Ool007oo0004Ool3003@Ool00`00Oomoo`0BOol0
011oo`03001oogoo01ioo`03001oo`00009oo`03001oo`0000Aoo`03001oogoo0=1oo`03001oogoo
019oo`003goo00<007ooOol087oo0P000Woo00<007oo000017oo00<007ooOol0d7oo00<007ooOol0
4Woo000?Ool00`00Oomoo`0QOol01@00Oomoogoo00001Goo00<007ooOol0dGoo00<007ooOol04Goo
000>Ool00`00Oomoo`0/Ool00`00Oomoo`3AOol00`00Oomoo`0AOol000ioo`03001oogoo02aoo`03
001oogoo0=5oo`03001oogoo015oo`003Woo00<007ooOol0;7oo0`00dGoo00<007ooOol04Goo000=
Ool00`00Oomoo`0]Ool00`00Oomoo`3AOol00`00Oomoo`0AOol000eoo`03001oogoo02eoo`03001o
ogoo0=9oo`03001oogoo011oo`003Goo00<007ooOol0;Goo00<007ooOol0dWoo00<007ooOol047oo
000=Ool00`00Oomoo`0]Ool00`00Oomoo`3BOol00`00Oomoo`0@Ool000eoo`03001oogoo02eoo`03
001oogoo0=9oo`03001oogoo011oo`003Woo00<007ooOol0;7oo0`00dgoo00<007ooOol03goo000>
Ool00`00Oomoo`0/Ool00`00Oomoo`3COol00`00Oomoo`0?Ool000moo`03001oogoo02]oo`03001o
ogoo0=Aoo`03001oogoo00ioo`003goo00<007ooOol0:goo00<007ooOol0e7oo00<007ooOol03Woo
000?Ool00`00Oomoo`0[Ool00`00Oomoo`3DOol00`00Oomoo`0>Ool000moo`03001oogoo02]oo`03
001oogoo0==oo`03001oogoo00moo`0047oo00<007ooOol0:Woo0`00dgoo00<007ooOol03goo000@
Ool00`00Oomoo`0ZOol00`00Oomoo`3COol00`00Oomoo`0?Ool0011oo`03001oogoo02Yoo`03001o
ogoo0=9oo`03001oogoo011oo`0047oo00<007ooOol0:Woo00<007ooOol0dWoo00<007ooOol047oo
000@Ool00`00Oomoo`0NOol20004Ool00`00Oomoo`03Ool00`00Oomoo`3AOol00`00Oomoo`0AOol0
015oo`03001oogoo01eoo`03001oo`00009oo`03001oo`0000Aoo`03001oogoo0=5oo`03001oogoo
015oo`004Goo00<007ooOol07Goo00<007oo00000Woo00<007oo000017oo0`00d7oo00<007ooOol0
4Woo000AOol00`00Oomoo`0MOol20003Ool00`00Ool00004Ool00`00Oomoo`3@Ool00`00Oomoo`0B
Ool0015oo`03001oogoo01eoo`03001oogoo009oo`03001oo`0000Aoo`03001oogoo0<moo`03001o
ogoo01=oo`004Goo00<007ooOol07Woo0P000goo00<007ooOol00goo00<007ooOol0cgoo00<007oo
Ool04goo000AOol00`00Oomoo`0YOol00`00Oomoo`3>Ool00`00Oomoo`0DOol0019oo`03001oogoo
02Qoo`03001oogoo0<ioo`03001oogoo01Aoo`004Woo00<007ooOol0:7oo0`00=goo1@00TWoo00<0
07ooOol057oo000BOol00`00Oomoo`0XOol00`00Oomoo`0gOol01@00Oomoogoo0000Tgoo00<007oo
Ool04goo000BOol00`00Oomoo`0XOol00`00Oomoo`0fOol00`00Oomoo`02Ool00`00Oomoo`2AOol0
0`00Oomoo`0COol0019oo`03001oogoo02Qoo`03001oogoo03Ioo`03001oogoo00=oo`03001oogoo
091oo`03001oogoo01=oo`004goo00<007ooOol09goo00<007ooOol0=Woo00<007ooOol00goo00<0
07ooOol0T7oo00<007ooOol04goo000COol00`00Oomoo`0WOol00`00Oomoo`0fOol00`00Oomoo`03
Ool00`00Oomoo`2@Ool00`00Oomoo`0COol001=oo`03001oogoo02Moo`<003Ioo`03001oogoo00=o
o`03001oogoo095oo`03001oogoo019oo`004goo00<007ooOol09goo00<007ooOol0=goo00<007oo
Ool00Woo00<007ooOol0TGoo00<007ooOol04Woo000DOol00`00Oomoo`0VOol00`00Oomoo`0gOol0
0`00Oomoo`03Ool00`00Oomoo`2@Ool00`00Oomoo`0BOol001Aoo`03001oogoo02Ioo`03001oogoo
03Moo`03001oogoo00=oo`03001oogoo08moo`03001oogoo01=oo`005Goo00<007ooOol09Goo00<0
07ooOol0=goo00<007ooOol00goo00<007ooOol0Sgoo00<007ooOol04goo000EOol00`00Oomoo`0U
Ool00`00Oomoo`0gOol00`00Oomoo`03Ool00`00Oomoo`2>Ool00`00Oomoo`0DOol001Ioo`8002Eo
o`<003Ioo`03001oogoo00Aoo`03001oogoo08ioo`03001oogoo01Aoo`0067oo00<007ooOol08Woo
00<007ooOol0=Woo00<007ooOol017oo00<007ooOol0SGoo00<007ooOol05Goo000IOol2000ROol0
0`00Oomoo`0fOol00`00Oomoo`05Ool00`00Oomoo`2<Ool00`00Oomoo`0EOol001]oo`03001oogoo
01moo`03001oogoo03Ioo`03001oogoo00Eoo`03001oogoo08]oo`03001oogoo01Ioo`0077oo00<0
07ooOol04goo00<007ooOol00Woo00<007ooOol00goo00<007ooOol0=Goo00<007ooOol01Woo00<0
07ooOol0Rgoo00<007ooOol05Woo000MOol00`00Oomoo`0AOol00`00Ool00002Ool00`00Ool00004
Ool00`00Oomoo`0eOol00`00Oomoo`07Ool2002:Ool00`00Oomoo`0GOol001eoo`03001oogoo015o
o`03001oo`00009oo`03001oo`0000Aoo`<003Aoo`03001oogoo00Yoo`03001oogoo08Moo`03001o
ogoo01Moo`007Woo00<007ooOol04Goo00L007ooOomoo`00Ool00004Ool00`00Oomoo`0cOol00`00
Oomoo`0<Ool20026Ool00`00Oomoo`0HOol001moo`03001oogoo00moo`03001oo`00009oo`03001o
o`0000Aoo`03001oogoo03=oo`03001oogoo00ioo`03001oogoo08=oo`03001oogoo01Qoo`007goo
00<007ooOol047oo00<007ooOol00Woo00<007ooOol00goo00<007ooOol0<Woo00<007ooOol047oo
00<007ooOol0PWoo00<007ooOol067oo000OOol00`00Oomoo`0KOol00`00Oomoo`0aOol00`00Oomo
o`0BOol20023Ool00`00Oomoo`0GOol0021oo`03001oogoo01Yoo`03001oogoo035oo`03001oogoo
01Aoo`03001oogoo081oo`03001oogoo01Moo`0087oo00<007ooOol06Woo0`00<7oo00<007ooOol0
5Woo00<007ooOol0P7oo00<007ooOol05Woo000POol00`00Oomoo`0JOol00`00Oomoo`0`Ool00`00
Oomoo`0FOol00`00Oomoo`20Ool00`00Oomoo`0FOol0021oo`03001oogoo01Yoo`03001oogoo02mo
o`03001oogoo01Moo`03001oogoo081oo`03001oogoo01Ioo`008Goo00<007ooOol06Goo00<007oo
Ool0;goo00<007ooOol067oo00<007ooOol0Ogoo00<007ooOol05Woo000QOol00`00Oomoo`0IOol0
0`00Oomoo`0^Ool00`00Oomoo`0IOol00`00Oomoo`20Ool00`00Oomoo`0EOol0029oo`03001oogoo
01Qoo`03001oogoo02eoo`03001oogoo01Yoo`03001oogoo081oo`03001oogoo01Eoo`008Woo00<0
07ooOol067oo0`00;Goo00<007ooOol06Woo00<007ooOol0P7oo00<007ooOol05Goo000SOol2000H
Ool00`00Oomoo`0/Ool00`00Oomoo`0KOol00`00Oomoo`20Ool00`00Oomoo`0EOol002Eoo`8001Io
o`03001oogoo02aoo`03001oogoo01aoo`03001oogoo07ioo`03001oogoo01Ioo`009goo0P0057oo
00<007ooOol0:goo00<007ooOol07Goo00<007ooOol0OWoo00<007ooOol05Woo000YOol00`00Oomo
o`0AOol00`00Oomoo`0[Ool00`00Oomoo`0NOol00`00Oomoo`1lOol00`00Oomoo`0GOol002Yoo`80
015oo`03001oogoo02]oo`03001oogoo01ioo`03001oogoo07]oo`03001oogoo01Qoo`00;7oo00<0
07ooOol03Woo0`0097oo10000goo00<007ooOol07goo0P00Ngoo00<007ooOol067oo000]Ool2000>
Ool00`00Oomoo`0SOol60002Ool00`00Oomoo`0QOol00`00Oomoo`1gOol00`00Oomoo`0IOol002mo
o`03001oogoo00]oo`03001oogoo029oo`X002Aoo`8007Ioo`03001oogoo01Yoo`00<7oo0P002goo
00<007ooOol08Woo2000:7oo00<007ooOol0Lgoo00<007ooOol06Woo000[Ool50002Ool00`00Oomo
o`02Ool00`00Oomoo`03Ool00`00Oomoo`0ROol8000YOol2001bOol00`00Oomoo`0KOol002eoo`06
001oogooOol007oo0P0000Aoo`00Ool000Aoo`03001oogoo029oo`P002]oo`03001oogoo06ioo`03
001oogoo01aoo`00;Goo00P007ooOomoo`00Ool007oo0P0000=oo`00Ool00goo0`008goo1P00;Goo
0P00KWoo00<007ooOol077oo000]Ool01`00Oomoogoo001oo`00009oo`<000Aoo`03001oogoo02Ao
o`@0031oo`03001oogoo06Yoo`03001oogoo01eoo`00;Goo00L007ooOomoo`00Ool00002Ool01000
Ool000000goo00<007ooOol0FGoo0P00JGoo00<007ooOol07Woo000/Ool20004Ool00`00Oomoo`02
Ool00`00Oomoo`0200000goo001oo`1LOol2001WOol00`00Oomoo`0NOol003aoo`<002=oo`03001o
ogoo03Qoo`8006Aoo`03001oogoo01moo`00?Goo00<007oo00001@0077oo00<007ooOol0>goo00<0
07ooOol0HGoo00<007ooOol07goo000mOol30005Ool3000GOol2000nOol00`00Oomoo`1POol00`00
Oomoo`0POol003eoo`03001oogoo00Qoo`8001Aoo`03001oogoo03ioo`03001oogoo061oo`03001o
ogoo021oo`00?Goo00<007ooOol02Woo0P003goo0`00@Woo00<007ooOol0GWoo00<007ooOol08Goo
000mOol00`00Oomoo`0<Ool20008Ool50015Ool00`00Oomoo`1NOol00`00Oomoo`0QOol003eoo`03
001oogoo00ioo`P004Yoo`03001oogoo05ioo`03001oogoo025oo`00?Goo00<007ooOol0HGoo0P00
GWoo00<007ooOol08Goo000mOol3001SOol00`00Oomoo`1KOol00`00Oomoo`0QOol003eoo`03001o
ogoo06Aoo`8005]oo`03001oogoo025oo`00?Goo00<007ooOol0IWoo00<007ooOol0Egoo00<007oo
Ool08Woo000mOol00`00Oomoo`1WOol2001GOol00`00Oomoo`0ROol003eoo`03001oogoo06Uoo`03
001oogoo05=oo`03001oogoo02=oo`00?Goo00<007ooOol0JWoo0P00Dgoo00<007ooOol08goo000m
Ool3001/Ool00`00Oomoo`1?Ool00`00Oomoo`0TOol003eoo`03001oogoo06eoo`8004moo`03001o
ogoo02Aoo`00?Goo00<007ooOol0Kgoo0P00C7oo00<007ooOol09Goo000[Ool5000017oo00000000
0goo00<007ooOol00goo00<007ooOol0LGoo0P00BWoo00<007ooOol09Goo000]Ool01@00Oomoogoo
000017oo00<007oo000017oo00<007ooOol0Lgoo00<007ooOol0AWoo00<007ooOol09Woo000]Ool0
0`00Oomoo`02Ool01`00Oomoogoo001oo`0000Aoo`<007Aoo`8004Eoo`03001oogoo02Moo`00;Goo
00<007ooOol00Woo00L007ooOomoo`00Ool00004Ool00`00Oomoo`1fOol00`00Oomoo`12Ool00`00
Oomoo`0WOol002eoo`07001oogooOol007oo00000Woo00<007oo000017oo00<007ooOol0Mgoo0P00
?goo0`00:Woo000/Ool20004Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`1iOol00`00
Oomoo`0iOol3000]Ool003eoo`03001oogoo07Yoo`8003Qoo`03001oogoo02ioo`00?Goo00<007oo
Ool0O7oo00<007ooOol0=Goo00<007ooOol0;Woo000mOol3001mOol2000dOol00`00Oomoo`0_Ool0
03eoo`03001oogoo07moo`03001oogoo035oo`03001oogoo02moo`00?Goo00<007ooOol0P7oo0P00
<7oo00<007ooOol0<7oo000mOol00`00Oomoo`22Ool2000^Ool00`00Oomoo`0`Ool003eoo`03001o
ogoo08Aoo`8002]oo`03001oogoo035oo`00?Goo00<007ooOol0QWoo0`009Woo0P00=7oo000mOol3
0029Ool5000OOol2000fOol003eoo`03001oogoo08ioo`@001Qoo`<003Qoo`00?Goo00<007ooOol0
TWoo0P004Woo1000>goo000mOol00`00Oomoo`2DOol00`00Oomoo`0=Ool2000oOol003eoo`03001o
ogoo09Eoo`03001oogoo00Qoo`@0045oo`00?Goo00<007ooOol0UWoo0P000goo1@00AGoo000mOol3
002HOol3001:Ool003eoo`03001oogoo0>Eoo`00?Goo00<007ooOol0iGoo000mOol00`00Oomoo`3U
Ool00001\
\>"],
  ImageRangeCache->{{{0, 292.313}, {176.125, 0}} -> {-52.1347, -10.4905, 
  0.841216, 0.841216}}]
}, Open  ]],

Cell["GRANLUND (1972)", "Section"],

Cell["Boundary representation", "Subsection"],

Cell["\<\
We assume that the boundary is a clockwise oriented, simple closed curve \
parametrized with respect to arc length. A point moving along the boundary \
generates a periodic, complex function.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(u = \((Complex\ @@\ #\ &)\)\ /@\ dataxy\ ; \ u // \ Short\)], "Input",
  CellLabel->"In[42]:="],

Cell[BoxData[
    TagBox[
      \({0, \[LeftSkeleton]126\[RightSkeleton], 
        \(2.`\[InvisibleSpace]\) - 37.4843750000000008`\ I}\),
      Short]], "Output",
  CellLabel->"Out[42]//Short="]
}, Open  ]],

Cell["Fourier analysis", "Subsection"],

Cell["\<\
It is well known that periodic sequences have a Fourier series expansion. The \
Fourier coefficients therefore form an equivalent boundary representation. \
Given such a function, the energy compaction property of the Fourier \
transform permits an approximate representation by using a few low-order \
Fourier coefficients. The retained coefficients may be considered a compact \
boundary feature set, or descriptor. Reconstruction is possible, as will be \
demonstrated below.\
\>", "Text"],

Cell["Analysis: the Fourier descriptors.", "Subsubsection"],

Cell[BoxData[
    \(\(U = InverseFourier[u]; \)\)], "Input",
  CellLabel->"In[43]:="],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(DiscretePlot[Abs[Drop[U, \(-L\)\/2]], PlotRange -> {0, 200}]; \)\)], 
  "Input",
  CellLabel->"In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0151172 0 0.00309017 [
[.17498 -0.0125 -6 -9 ]
[.17498 -0.0125 6 0 ]
[.32615 -0.0125 -6 -9 ]
[.32615 -0.0125 6 0 ]
[.47732 -0.0125 -6 -9 ]
[.47732 -0.0125 6 0 ]
[.6285 -0.0125 -6 -9 ]
[.6285 -0.0125 6 0 ]
[.77967 -0.0125 -6 -9 ]
[.77967 -0.0125 6 0 ]
[.93084 -0.0125 -6 -9 ]
[.93084 -0.0125 6 0 ]
[.01131 .07725 -12 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -12 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -12 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -18 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -18 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -18 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -18 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.17498 0 m
.17498 .00625 L
s
[(10)] .17498 -0.0125 0 1 Mshowa
.32615 0 m
.32615 .00625 L
s
[(20)] .32615 -0.0125 0 1 Mshowa
.47732 0 m
.47732 .00625 L
s
[(30)] .47732 -0.0125 0 1 Mshowa
.6285 0 m
.6285 .00625 L
s
[(40)] .6285 -0.0125 0 1 Mshowa
.77967 0 m
.77967 .00625 L
s
[(50)] .77967 -0.0125 0 1 Mshowa
.93084 0 m
.93084 .00625 L
s
[(60)] .93084 -0.0125 0 1 Mshowa
.125 Mabswid
.05404 0 m
.05404 .00375 L
s
.08428 0 m
.08428 .00375 L
s
.11451 0 m
.11451 .00375 L
s
.14475 0 m
.14475 .00375 L
s
.20522 0 m
.20522 .00375 L
s
.23545 0 m
.23545 .00375 L
s
.26568 0 m
.26568 .00375 L
s
.29592 0 m
.29592 .00375 L
s
.35639 0 m
.35639 .00375 L
s
.38662 0 m
.38662 .00375 L
s
.41686 0 m
.41686 .00375 L
s
.44709 0 m
.44709 .00375 L
s
.50756 0 m
.50756 .00375 L
s
.53779 0 m
.53779 .00375 L
s
.56803 0 m
.56803 .00375 L
s
.59826 0 m
.59826 .00375 L
s
.65873 0 m
.65873 .00375 L
s
.68896 0 m
.68896 .00375 L
s
.7192 0 m
.7192 .00375 L
s
.74943 0 m
.74943 .00375 L
s
.8099 0 m
.8099 .00375 L
s
.84014 0 m
.84014 .00375 L
s
.87037 0 m
.87037 .00375 L
s
.9006 0 m
.9006 .00375 L
s
.96107 0 m
.96107 .00375 L
s
.99131 0 m
.99131 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .07725 m
.03006 .07725 L
s
[(25)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(50)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(75)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(100)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(125)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(150)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(175)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(200)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 0 m
0 0 rlineto s
.02381 0 m
.02381 .61803 L
s
.03893 0 m
0 0 rlineto s
.03893 0 m
.03893 .61803 L
s
.05404 0 m
.05404 .25987 L
s
.06916 0 m
.06916 .18716 L
s
.08428 0 m
.08428 .08055 L
s
.0994 0 m
.0994 .07707 L
s
.11451 0 m
.11451 .01567 L
s
.12963 0 m
.12963 .02364 L
s
.14475 0 m
.14475 .03482 L
s
.15986 0 m
.15986 .02468 L
s
.17498 0 m
.17498 .00709 L
s
.1901 0 m
.1901 .00502 L
s
.20522 0 m
.20522 .0152 L
s
.22033 0 m
.22033 .01105 L
s
.23545 0 m
.23545 .00742 L
s
.25057 0 m
.25057 .01407 L
s
.26568 0 m
.26568 .01139 L
s
.2808 0 m
.2808 .00971 L
s
.29592 0 m
.29592 .01631 L
s
.31104 0 m
.31104 .01655 L
s
.32615 0 m
.32615 .00433 L
s
.34127 0 m
.34127 .01195 L
s
.35639 0 m
.35639 .00668 L
s
.3715 0 m
.3715 .00836 L
s
.38662 0 m
.38662 .00941 L
s
.40174 0 m
.40174 .0119 L
s
.41686 0 m
.41686 .01145 L
s
.43197 0 m
.43197 .01403 L
s
.44709 0 m
.44709 .00789 L
s
.46221 0 m
.46221 .01277 L
s
.47732 0 m
.47732 .00316 L
s
.49244 0 m
.49244 .0031 L
s
.50756 0 m
.50756 .00925 L
s
.52268 0 m
.52268 .00778 L
s
.53779 0 m
.53779 .0072 L
s
.55291 0 m
.55291 .00486 L
s
.56803 0 m
.56803 .00268 L
s
.58314 0 m
.58314 .00594 L
s
.59826 0 m
.59826 .00664 L
s
.61338 0 m
.61338 .00502 L
s
.6285 0 m
.6285 .00313 L
s
.64361 0 m
.64361 .00526 L
s
.65873 0 m
.65873 .00841 L
s
.67385 0 m
.67385 .00734 L
s
.68896 0 m
.68896 .00677 L
s
.70408 0 m
.70408 .00375 L
s
.7192 0 m
.7192 .00545 L
s
.73432 0 m
.73432 .00871 L
s
.74943 0 m
.74943 .00741 L
s
.76455 0 m
.76455 .00613 L
s
.77967 0 m
.77967 .00469 L
s
.79478 0 m
.79478 .0061 L
s
.8099 0 m
.8099 .00511 L
s
.82502 0 m
.82502 .00509 L
s
.84014 0 m
.84014 .00649 L
s
.85525 0 m
.85525 .00636 L
s
.87037 0 m
.87037 .00637 L
s
.88549 0 m
.88549 .00488 L
s
.9006 0 m
.9006 .00406 L
s
.91572 0 m
.91572 .00394 L
s
.93084 0 m
.93084 .004 L
s
.94596 0 m
.94596 .00589 L
s
.96107 0 m
.96107 .00357 L
s
.97619 0 m
.97619 .00503 L
s
.02 w
.05404 .25987 Mdot
.06916 .18716 Mdot
.08428 .08055 Mdot
.0994 .07707 Mdot
.11451 .01567 Mdot
.12963 .02364 Mdot
.14475 .03482 Mdot
.15986 .02468 Mdot
.17498 .00709 Mdot
.1901 .00502 Mdot
.20522 .0152 Mdot
.22033 .01105 Mdot
.23545 .00742 Mdot
.25057 .01407 Mdot
.26568 .01139 Mdot
.2808 .00971 Mdot
.29592 .01631 Mdot
.31104 .01655 Mdot
.32615 .00433 Mdot
.34127 .01195 Mdot
.35639 .00668 Mdot
.3715 .00836 Mdot
.38662 .00941 Mdot
.40174 .0119 Mdot
.41686 .01145 Mdot
.43197 .01403 Mdot
.44709 .00789 Mdot
.46221 .01277 Mdot
.47732 .00316 Mdot
.49244 .0031 Mdot
.50756 .00925 Mdot
.52268 .00778 Mdot
.53779 .0072 Mdot
.55291 .00486 Mdot
.56803 .00268 Mdot
.58314 .00594 Mdot
.59826 .00664 Mdot
.61338 .00502 Mdot
.6285 .00313 Mdot
.64361 .00526 Mdot
.65873 .00841 Mdot
.67385 .00734 Mdot
.68896 .00677 Mdot
.70408 .00375 Mdot
.7192 .00545 Mdot
.73432 .00871 Mdot
.74943 .00741 Mdot
.76455 .00613 Mdot
.77967 .00469 Mdot
.79478 .0061 Mdot
.8099 .00511 Mdot
.82502 .00509 Mdot
.84014 .00649 Mdot
.85525 .00636 Mdot
.87037 .00637 Mdot
.88549 .00488 Mdot
.9006 .00406 Mdot
.91572 .00394 Mdot
.93084 .004 Mdot
.94596 .00589 Mdot
.96107 .00357 Mdot
.97619 .00503 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo000mOol5
0002Ool00`00Oomoo`0NOol30003Ool00`00Oomoo`0OOol20004Ool00`00Oomoo`0OOol30002Ool0
0`00Oomoo`0OOol00`00Oomoo`02Ool00`00Oomoo`0NOol20004Ool00`00Oomoo`0EOol003moo`07
001oogooOol007oo00007goo00<007ooOol00Woo00<007oo00008Woo00H007ooOol007oo000QOol0
1P00Oomoo`00Ool001moo`03001oo`00009oo`03001oo`0001moo`03001oo`00009oo`03001oo`00
01Ioo`00?goo00L007ooOomoo`00Ool0000POol01`00Oomoogoo001oo`00025oo`07001oogooOol0
07oo00007goo100000Aoo`00Ool0025oo`06001oogoo001oo`007goo00<007oo00000Woo00<007oo
00005Woo000oOol01`00Oomoogoo001oo`00021oo`07001oogooOol007oo00008Woo00H007ooOol0
07oo000OOol00`00Ool00002Ool00`00Ool0000OOol20003Ool00`00Ool0000OOol20003Ool00`00
Ool0000FOol003moo`07001oogooOol007oo00007goo00<007oo00000Woo00<007oo000087oo00<0
07oo00000Woo00<007oo000087oo0P000Woo00<007oo00007goo00<007ooOol00Woo00<007oo0000
7goo00<007ooOol00Woo00<007oo00005Woo000nOol20004Ool00`00Oomoo`0OOol00`00Oomoo`02
Ool00`00Oomoo`0POol00`00Oomoo`02Ool00`00Oomoo`0POol01@00Oomoogoo000087oo0`000goo
00<007ooOol07goo0P000goo00<007ooOol05Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool004Eoo`<0021oo`<002Eoo`<00004Ool00000000<Ool300001Goo00000000Ool00`001Goo0`00
00Eoo`00000007oo00<000aoo`<00004Ool000000009Ool300001Goo00000000Ool00`0000Eoo`00
000007oo00<000aoo`<00005Ool00000001oo`0300001Goo00000000Ool00`0000Eoo`00000007oo
00<000aoo`005Gooo`001@001goo000KOol01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05
001oogooOol00003Ool01@00Oomoogoo00000Woo00H007ooOomoo`00Ool9000017oo001oogoo2000
00Aoo`00Oomoo`P00003Ool007oo009ooaT00004Ool000000002Ool00`00Ool0002=00000goo001o
o`08Ool001]oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomoo`00009oo`<0
009oo`04001oogoo0003Ool00`00Ool0003D000;Ool001]oo`05001oogooOol00003Ool01@00Oomo
ogoo00000goo00H007ooOomoo`00Ool500001Goo001oogoo00000goo00<007oo0000DP0000=oo`00
0000400000Eoo`00000007oo00/00005Ool00000001oo`0B00000goo0000000=00001Goo00000000
Ool00`0000Eoo`00000007oo01800005Ool00000001oo`0300001Goo00000000Ool00`0000Eoo`00
000007oo00<000aoo`006goo0P000Woo00D007ooOomoo`0000=oo`05001oogooOol00003Ool00`00
Ool000060002Ool00`00Oomoo`03000017oo0000000017oo80000goo200000Eoo`00000007oo01P0
00Moo`<00005Ool00000001oo`03000=Ool3000=Ool300000goo000000040009Ool3000017oo0000
00005Goo0`0000=oo`0000001000:7oo000KOol01@00Oomoogoo00000goo00D007ooOomoo`0000=o
o`06001oogooOol007oo200000=oo`00Ool01@001goo200017oo200017oo200017oo0`003Goo0`00
00=oo`0000001P0017oo0`00TGoo000KOol01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05
001oogooOol00002Ool700000goo001oo`050008Ool30009Ool30009Ool6000MOol3002IOol001]o
o`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000Aoo`d00=moo`006goo
0P000Woo00D007ooOomoo`0000=oo`05001oogooOol00003Ool00`00Oomoo`03Ool;003POol001]o
o`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000Qoo`D00>=oo`006goo
00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo000027oo1@00hgoo000KOol0
1@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00009Ool3003TOol001]oo`80
009oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00<007ooOol0kWoo000KOol01@00Oomo
ogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol0003`Ool001]oo`05001oogooOol00003
Ool01@00Oomoogoo00000goo00D007ooOomoo`000?1oo`006goo00D007ooOomoo`0000=oo`05001o
ogooOol00003Ool01@00Oomoogoo0000l7oo000KOol20002Ool01@00Oomoogoo00000goo00D007oo
Oomoo`0000=oo`03001oogoo0>ioo`006goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool0
1@00Oomoogoo0000l7oo000?Ool30003Ool00`00Oomoo`03Ool01@00Oomoogoo00000goo00D007oo
Oomoo`0000=oo`03001oogoo00<00>moo`003goo00<007ooOol00Woo00<007oo000017oo00D007oo
Oomoo`0000=oo`05001oogooOol00002Ool8003^Ool0011oo`03001oogoo00=oo`03001oogoo009o
o`<00003Ool007oo009oo`06001oogooOol007oo2@00kWoo000@Ool01000Oomoogoo0P001Goo00D0
07ooOomoo`0000=oo`06001oogooOol007oo2@00kWoo000?Ool00`00Ool00002Ool00`00Oomoo`04
Ool01@00Oomoogoo00000goo00H007ooOomoo`00Ool8003_Ool0011oo`04001oogooOol30004Ool0
1@00Oomoogoo00000goo00D007ooOomoo`00009oo`<00?=oo`006goo0P000Woo00D007ooOomoo`00
00=oo`03001oogoo0?Ioo`006goo00D007ooOomoo`0000=oo`05001oogooOol0003hOol001]oo`05
001oogooOol00003Ool01@00Oomoogoo0000n7oo000KOol01@00Oomoogoo00000goo00D007ooOomo
o`000?Qoo`006goo0P000Woo00D007ooOomoo`0000=oo`03001oogoo0?Ioo`006goo00D007ooOomo
o`0000=oo`05001oogooOol0003hOol001]oo`05001oogooOol00003Ool01@00Oomoogoo0000n7oo
000KOol01@00Oomoogoo00000goo00D007ooOomoo`000?Qoo`006goo0P000Woo00D007ooOomoo`00
00=oo`03001oogoo0?Ioo`006goo00D007ooOomoo`0000=oo`05001oogooOol0003hOol001]oo`05
001oogooOol00003Ool01@00Oomoogoo0000n7oo000KOol01@00Oomoogoo00000goo00D007ooOomo
o`000?Qoo`006goo0P000Woo00D007ooOomoo`0000=oo`03001oogoo0?Ioo`006goo00D007ooOomo
o`0000=oo`05001oogooOol0003hOol0011oo`03001oogoo009oo`03001oogoo00=oo`05001oogoo
Ool00003Ool01@00Oomoogoo0000n7oo000?Ool00`00Ool00002Ool00`00Ool00004Ool01@00Oomo
ogoo00000goo00D007ooOomoo`000?Qoo`004Goo00H007ooOol007oo0004Ool300000goo001oo`02
Ool01@00Oomoogoo0000n7oo000?Ool20003Ool00`00Ool00004Ool01@00Oomoogoo00000goo00D0
07ooOomoo`000?Qoo`003goo00<007ooOol00Woo00<007oo000017oo00D007ooOomoo`0000=oo`05
001oogooOol0003hOol000moo`<000=oo`03001oogoo00=oo`05001oogooOol00003Ool01@00Oomo
ogoo0000n7oo000KOol20002Ool01@00Oomoogoo00000goo00<007ooOol0mWoo000KOol01@00Oomo
ogoo00000goo00D007ooOomoo`000?Qoo`006goo00D007ooOomoo`0000=oo`03001oogoo00<00?Mo
o`006goo00D007ooOomoo`0000=oo`03001oo`0000@00?Ioo`006goo0P000Woo00H007ooOomoo`00
Ool5003fOol001]oo`05001oogooOol00003Ool00`00Ool00004003fOol001]oo`05001oogooOol0
0003Ool00`00Oomoo`03003gOol001]oo`05001oogooOol00003Ool00`00Oomoo`3jOol001]oo`80
009oo`05001oogooOol0003lOol001]oo`05001oogooOol00003Ool00`00Oomoo`3jOol001]oo`05
001oogooOol00003Ool00`00Oomoo`3jOol001]oo`05001oogooOol00003Ool00`00Oomoo`3jOol0
01]oo`80009oo`05001oogooOol0003lOol001]oo`05001oogooOol00003Ool00`00Oomoo`3jOol0
011oo`03001oogoo009oo`03001oogoo00=oo`05001oogooOol00003Ool00`00Oomoo`3jOol0011o
o`07001oogooOol007oo000017oo00D007ooOomoo`0000=oo`03001oogoo0?Yoo`0047oo00<007oo
Ool00goo00<007ooOol00Woo0`0000=oo`00Ool00Woo00<007ooOol0nWoo000AOol00`00Oomoo`02
0005Ool01@00Oomoogoo00000goo00<007ooOol0nWoo000?Ool00`00Ool00002Ool00`00Oomoo`04
Ool01@00Oomoogoo00000goo00<007ooOol0nWoo000?Ool30002Ool30004Ool01@00Oomoogoo0000
0goo00<007ooOol0nWoo000KOol20002Ool01@00Oomoogoo0000o7oo000KOol01@00Oomoogoo0000
0Woo0`00ngoo000KOol01P00Oomoogoo001oo`D00?Yoo`006goo00H007ooOomoo`00Ool5003jOol0
01]oo`80009oo`03001oo`0000@00?Yoo`006goo00D007ooOomoo`00009oo`<00?]oo`006goo00D0
07ooOomoo`000?moo`5oo`006goo00D007ooOomoo`000?moo`5oo`006goo0P000Woo00<007ooOol0
oWoo000KOol01@00Oomoogoo0000ogoo0Goo000KOol01@00Oomoogoo0000ogoo0Goo000KOol01@00
Oomoogoo0000ogoo0Goo000KOol20002Ool00`00Oomoo`3nOol001]oo`05001oogooOol0003oOol1
Ool000Uoo`D0009oo`03001oogoo009oo`03001oogoo00=oo`05001oogooOol0003oOol1Ool000]o
o`07001oogooOol007oo00000Woo00<007oo000017oo00D007ooOomoo`000?moo`5oo`002goo00L0
07ooOomoo`00Ool00002Ool00`00Ool00004Ool300000goo001oo`3oOol000]oo`07001oogooOol0
07oo00000Woo00<007oo000017oo00D007ooOomoo`000?moo`5oo`002goo00L007ooOomoo`00Ool0
0002Ool00`00Ool00004Ool01@00Oomoogoo0000ogoo0Goo000:Ool20004Ool00`00Oomoo`02Ool0
0`00Oomoo`03Ool01@00Oomoogoo0000ogoo0Goo000KOol20002Ool00`00Oomoo`3nOol001]oo`05
001oogooOol0003oOol1Ool001]oo`05001oogooOol0003oOol1Ool001]oo`05001oogooOol0003o
Ool1Ool001]oo`80009oo`03001oogoo0?ioo`006goo00D007ooOomoo`000?moo`5oo`006goo00D0
07ooOomoo`000?moo`5oo`006goo00D007ooOomoo`000?moo`5oo`006goo0P000Woo00<007ooOol0
oWoo000KOol01@00Oomoogoo0000ogoo0Goo000KOol01@00Oomoogoo0000ogoo0Goo000KOol01@00
Oomoogoo0000ogoo0Goo000KOol20002Ool00`00Oomoo`3nOol001]oo`05001oogooOol0003oOol1
Ool000Uoo`D00004Ool000000003Ool00`00Oomoo`03Ool01@00Oomoogoo0000ogoo0Goo000;Ool0
1@00Oomoogoo000017oo00<007oo000017oo00D007ooOomoo`000?moo`5oo`002goo00<007ooOol0
0Woo00<007ooOol00goo00<007ooOol00Woo0`0000=oo`00Ool0ogoo000;Ool00`00Oomoo`02Ool0
1000Oomoogoo0P001Goo00D007ooOomoo`000?moo`5oo`002goo00L007ooOomoo`00Ool00002Ool0
0`00Oomoo`04Ool01@00Oomoogoo0000ogoo0Goo000:Ool20004Ool01000Oomoogoo0`0017oo00D0
07ooOomoo`000?moo`5oo`006goo0P000Woo00<007ooOol0oWoo000KOol01@00Oomoogoo0000ogoo
0Goo000KOol01@00Oomoogoo0000ogoo0Goo000KOol01@00Oomoogoo0000ogoo0Goo000KOol20002
Ool00`00Oomoo`3nOol001]oo`05001oogooOol0003oOol1Ool001]oo`05001oogooOol0003oOol1
Ool001]oo`05001oogooOol0003oOol1Ool001]oo`80009oo`03001oogoo0?ioo`006goo00D007oo
Oomoo`000?moo`5oo`006goo00D007ooOomoo`000?moo`5oo`006goo00D007ooOomoo`000?moo`5o
o`006goo0P000Woo00<007ooOol0oWoo000KOol01@00Oomoogoo0000ogoo0Goo0009Ool50002Ool0
0`00Oomoo`02Ool00`00Oomoo`03Ool01@00Oomoogoo0000ogoo0Goo000;Ool01`00Oomoogoo001o
o`00009oo`03001oo`0000Aoo`05001oogooOol0003oOol1Ool000]oo`03001oogoo00=oo`06001o
ogoo001oo`0017oo0`0000=oo`00Ool0ogoo000;Ool01000Oomoogoo0P000goo00<007oo000017oo
00D007ooOomoo`000?moo`5oo`002goo00D007ooOomoo`0000Aoo`03001oo`0000Aoo`05001oogoo
Ool0003oOol1Ool000Yoo`8000=oo`<000=oo`03001oogoo00=oo`05001oogooOol0003oOol1Ool0
01]oo`80009oo`03001oogoo0?ioo`006goo00D007ooOomoo`000?moo`5oo`006goo00D007ooOomo
o`000?moo`5oo`006goo00D007ooOomoo`000?moo`5oo`006goo0P000Woo00<007ooOol0oWoo000K
Ool01@00Oomoogoo0000ogoo0Goo000KOol01@00Oomoogoo0000ogoo0Goo000KOol01@00Oomoogoo
0000ogoo0Goo000KOol20002Ool00`00Oomoo`3nOol001]oo`05001oogooOol0003oOol1Ool001]o
o`05001oogooOol0003oOol1Ool001]oo`05001oogooOol0003oOol1Ool001]oo`80009oo`03001o
ogoo0?ioo`006goo00D007ooOomoo`000?moo`5oo`002Goo1@000Woo00<007ooOol00Woo00<007oo
Ool00goo00D007ooOomoo`000?moo`5oo`002goo00<007ooOol00Woo00L007ooOomoo`00Ool00004
Ool01@00Oomoogoo0000ogoo0Goo000;Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`02
Ool300000goo001oo`3oOol000]oo`03001oogoo00=oo`03001oogoo008000Eoo`05001oogooOol0
003oOol1Ool000]oo`07001oogooOol007oo00000Woo00<007ooOol017oo00D007ooOomoo`000?mo
o`5oo`002Woo0P000goo0`000Woo0`0017oo00D007ooOomoo`000?moo`5oo`006goo0P000Woo00<0
07ooOol0oWoo000KOol01@00Oomoogoo0000ogoo0Goo000KOol01@00Oomoogoo0000ogoo0Goo000K
Ool01@00Oomoogoo0000ogoo0Goo000KOol20002Ool00`00Oomoo`3nOol001]oo`05001oogooOol0
003oOol1Ool001]oo`05001oogooOol0003oOol1Ool001]oo`05001oogooOol0003oOol1Ool001]o
o`80009oo`03001oogoo0?ioo`006goo00D007ooOomoo`000?moo`5oo`006goo00D007ooOomoo`00
0?moo`5oo`006goo00D007ooOomoo`000?moo`5oo`006goo0P000Woo00<007ooOol0oWoo000KOol0
1@00Oomoogoo0000ogoo0Goo000:Ool30003Ool00`00Oomoo`02Ool00`00Oomoo`03Ool01@00Oomo
ogoo0000ogoo0Goo000:Ool00`00Oomoo`02Ool00`00Ool00002Ool00`00Ool00004Ool01@00Oomo
ogoo0000ogoo0Goo000;Ool01`00Oomoogoo001oo`00009oo`03001oo`0000Aoo`<00003Ool007oo
0?moo`002goo00L007ooOomoo`00Ool00002Ool00`00Ool0003oOol:Ool000Yoo`03001oo`00009o
o`03001oo`00009oo`03001oo`000?moo`Yoo`002goo00<007ooOol00Woo00<007ooOol00Woo00<0
07ooOol0ogoo2Goo003oOolQOol00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-7.04458, -15.2823, 
  0.255204, 1.24846}}]
}, Open  ]],

Cell["\<\
FDs are invariant to change in starting point, translation and rotation. This \
can be easily verified. Compare the lowest eight Fourier coefficients \
(excluding the first coefficient value which is affected by planar \
translation).\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(newU = InverseFourier[\((Complex\ @@\ #\ &)\)\ /@\ data]; \n
    Abs[Take[U, {2, 8}]] == Abs[Take[newU, {2, 8}]]\)], "Input",
  CellLabel->"In[36]:="],

Cell[BoxData[
    \(True\)], "Output",
  CellLabel->"Out[36]="],

Cell[BoxData[
    \(True\)], "Input",
  CellLabel->"Out[36]="]
}, Open  ]],

Cell["Synthesis: boundary reconstruction.", "Subsubsection"],

Cell["\<\
Here, the boundary will be reconstructed from a few low-order coefficients. \
Low-pass filtering is performed with a rectangular window, leading to \
significant ringing distortion. However, as can be seen below, the boundary \
is recognizable.\
\>", "Text"],

Cell[BoxData[
    \(low = 8; \n
    datalow = 
      Fourier[Join[Take[U, low], Table[0, {L - 2  low + 1}], 
            Take[U, \(-low\) + 1]]]\  // Chop; \)], "Input",
  CellLabel->"In[45]:="],

Cell["\<\
The reconstruction of the boundary from the FDs is especialy simple and leads \
to closed curves.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(ListPlot[Transpose[{Re[datalow], Im[datalow]}], 
      PlotJoined \[Rule] True, \ AspectRatio -> Automatic]; \)\)], "Input",
  CellLabel->"In[48]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.51953 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00639965 1.36972 0.00639965 [
[.1518 1.35722 -6 -9 ]
[.1518 1.35722 6 0 ]
[.2798 1.35722 -6 -9 ]
[.2798 1.35722 6 0 ]
[.40779 1.35722 -6 -9 ]
[.40779 1.35722 6 0 ]
[.53578 1.35722 -6 -9 ]
[.53578 1.35722 6 0 ]
[.66377 1.35722 -9 -9 ]
[.66377 1.35722 9 0 ]
[.79177 1.35722 -9 -9 ]
[.79177 1.35722 9 0 ]
[.91976 1.35722 -9 -9 ]
[.91976 1.35722 9 0 ]
[.01131 .08979 -24 -4.5 ]
[.01131 .08979 0 4.5 ]
[.01131 .40977 -24 -4.5 ]
[.01131 .40977 0 4.5 ]
[.01131 .72975 -24 -4.5 ]
[.01131 .72975 0 4.5 ]
[.01131 1.04973 -18 -4.5 ]
[.01131 1.04973 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1.51953 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.1518 1.36972 m
.1518 1.37597 L
s
[(20)] .1518 1.35722 0 1 Mshowa
.2798 1.36972 m
.2798 1.37597 L
s
[(40)] .2798 1.35722 0 1 Mshowa
.40779 1.36972 m
.40779 1.37597 L
s
[(60)] .40779 1.35722 0 1 Mshowa
.53578 1.36972 m
.53578 1.37597 L
s
[(80)] .53578 1.35722 0 1 Mshowa
.66377 1.36972 m
.66377 1.37597 L
s
[(100)] .66377 1.35722 0 1 Mshowa
.79177 1.36972 m
.79177 1.37597 L
s
[(120)] .79177 1.35722 0 1 Mshowa
.91976 1.36972 m
.91976 1.37597 L
s
[(140)] .91976 1.35722 0 1 Mshowa
.125 Mabswid
.05581 1.36972 m
.05581 1.37347 L
s
.08781 1.36972 m
.08781 1.37347 L
s
.1198 1.36972 m
.1198 1.37347 L
s
.1838 1.36972 m
.1838 1.37347 L
s
.2158 1.36972 m
.2158 1.37347 L
s
.2478 1.36972 m
.2478 1.37347 L
s
.31179 1.36972 m
.31179 1.37347 L
s
.34379 1.36972 m
.34379 1.37347 L
s
.37579 1.36972 m
.37579 1.37347 L
s
.43979 1.36972 m
.43979 1.37347 L
s
.47179 1.36972 m
.47179 1.37347 L
s
.50378 1.36972 m
.50378 1.37347 L
s
.56778 1.36972 m
.56778 1.37347 L
s
.59978 1.36972 m
.59978 1.37347 L
s
.63178 1.36972 m
.63178 1.37347 L
s
.69577 1.36972 m
.69577 1.37347 L
s
.72777 1.36972 m
.72777 1.37347 L
s
.75977 1.36972 m
.75977 1.37347 L
s
.82377 1.36972 m
.82377 1.37347 L
s
.85576 1.36972 m
.85576 1.37347 L
s
.88776 1.36972 m
.88776 1.37347 L
s
.95176 1.36972 m
.95176 1.37347 L
s
.98376 1.36972 m
.98376 1.37347 L
s
.25 Mabswid
0 1.36972 m
1 1.36972 L
s
.02381 .08979 m
.03006 .08979 L
s
[(-200)] .01131 .08979 1 0 Mshowa
.02381 .40977 m
.03006 .40977 L
s
[(-150)] .01131 .40977 1 0 Mshowa
.02381 .72975 m
.03006 .72975 L
s
[(-100)] .01131 .72975 1 0 Mshowa
.02381 1.04973 m
.03006 1.04973 L
s
[(-50)] .01131 1.04973 1 0 Mshowa
.125 Mabswid
.02381 .15378 m
.02756 .15378 L
s
.02381 .21778 m
.02756 .21778 L
s
.02381 .28178 m
.02756 .28178 L
s
.02381 .34577 m
.02756 .34577 L
s
.02381 .47377 m
.02756 .47377 L
s
.02381 .53776 m
.02756 .53776 L
s
.02381 .60176 m
.02756 .60176 L
s
.02381 .66575 m
.02756 .66575 L
s
.02381 .79375 m
.02756 .79375 L
s
.02381 .85774 m
.02756 .85774 L
s
.02381 .92174 m
.02756 .92174 L
s
.02381 .98574 m
.02756 .98574 L
s
.02381 1.11373 m
.02756 1.11373 L
s
.02381 1.17773 m
.02756 1.17773 L
s
.02381 1.24172 m
.02756 1.24172 L
s
.02381 1.30572 m
.02756 1.30572 L
s
.02381 .02579 m
.02756 .02579 L
s
.02381 1.43371 m
.02756 1.43371 L
s
.02381 1.49771 m
.02756 1.49771 L
s
.25 Mabswid
.02381 0 m
.02381 1.51953 L
s
0 0 m
1 0 L
1 1.51953 L
0 1.51953 L
closepath
clip
newpath
.5 Mabswid
.05149 1.26288 m
.06722 1.30902 L
.08699 1.35164 L
.11017 1.3895 L
.13602 1.42159 L
.16374 1.44722 L
.19258 1.46602 L
.22191 1.47796 L
.25126 1.48335 L
.28034 1.48278 L
.30907 1.47704 L
.33755 1.46702 L
.36597 1.45366 L
.39457 1.43783 L
.42358 1.42028 L
.45308 1.40154 L
.48298 1.38199 L
.51297 1.36174 L
.5425 1.34078 L
.57077 1.31892 L
.59682 1.29594 L
.61959 1.27161 L
.638 1.24577 L
.65106 1.21841 L
.65803 1.18966 L
.65844 1.15985 L
.65222 1.12949 L
.63973 1.0992 L
.62174 1.06972 L
.59943 1.04179 L
.57431 1.0161 L
.5481 .99321 L
.52263 .9735 L
.49967 .9571 L
.48087 .94393 L
.46757 .93361 L
.46075 .92558 L
.46096 .91911 L
.46833 .91334 L
.48254 .90741 L
.50293 .9005 L
.52853 .89191 L
.55819 .88111 L
.59071 .86777 L
.62488 .85176 L
.65962 .83319 L
.69402 .8123 L
.72739 .78947 L
.75927 .76514 L
.78938 .73977 L
Mistroke
.81761 .71376 L
.84396 .68742 L
.86844 .66094 L
.89104 .6344 L
.91168 .60774 L
.93016 .58086 L
.94616 .55358 L
.95927 .52575 L
.96897 .49725 L
.97477 .46808 L
.97619 .43834 L
.97288 .40827 L
.96465 .37825 L
.95152 .34872 L
.93372 .32021 L
.91173 .29323 L
.88619 .26826 L
.85792 .24565 L
.82778 .22562 L
.79664 .20818 L
.76528 .1932 L
.73435 .18031 L
.70428 .16907 L
.67529 .15889 L
.64736 .14918 L
.62027 .13941 L
.59367 .12912 L
.56711 .11807 L
.54014 .10617 L
.51239 .09361 L
.48362 .08076 L
.45383 .06821 L
.42319 .05669 L
.39215 .04698 L
.36134 .03991 L
.33151 .03618 L
.30351 .03639 L
.27817 .04092 L
.2562 .04994 L
.23815 .06335 L
.2243 .08086 L
.21466 .10196 L
.20894 .12602 L
.20659 .15233 L
.20681 .18018 L
.20869 .20892 L
.21125 .23802 L
.21353 .26709 L
.21471 .29592 L
.21417 .32445 L
Mistroke
.21153 .35275 L
.20668 .38101 L
.19979 .40943 L
.19124 .43823 L
.18158 .46754 L
.17144 .49742 L
.16148 .52779 L
.15224 .55847 L
.14415 .58919 L
.1374 .61958 L
.132 .64929 L
.12772 .67802 L
.12416 .70557 L
.12079 .73187 L
.11705 .75708 L
.11241 .78152 L
.10645 .80571 L
.09896 .83034 L
.08995 .85616 L
.07969 .88395 L
.06869 .91441 L
.05768 .9481 L
.04753 .98533 L
.03919 1.02614 L
.03358 1.07024 L
.03151 1.11699 L
.0336 1.16549 L
.04023 1.21456 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[48]:=",
  ImageSize->{189.5, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002g00015a000`40O003h00O]goo002gOol00;Mo
o`00]goo002gOol00;Moo`00]goo002gOol00;Moo`00]goo002gOol00;Moo`00]goo002gOol00;Mo
o`00]goo002gOol00;Moo`006Woo00<007ooOol0VWoo000JOol00`00Oomoo`2JOol001Yoo`03001o
ogoo09Yoo`006Woo00<007ooOol0VWoo000JOol00`00Oomoo`2JOol001Yoo`03001oogoo02Qoo`T0
06Uoo`006Woo00<007ooOol09Goo0`002Goo1@00I7oo000JOol00`00Oomoo`0SOol2000AOol4001P
Ool001Yoo`03001oogoo029oo`03001oogoo01Eoo`8005ioo`006Woo00<007ooOol087oo0P006Woo
0P00G7oo000JOol00`00Oomoo`0OOol00`00Oomoo`0LOol2001JOol001Yoo`03001oogoo01ioo`03
001oogoo01moo`<005Moo`002Woo0`000goo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol0
7Woo00<007ooOol08Woo0P00EGoo000:Ool00`00Oomoo`02Ool00`00Ool00002Ool00`00Ool00003
Ool00`00Oomoo`0MOol00`00Oomoo`0UOol3001BOol000Eoo`<000=oo`07001oogooOol007oo0000
0Woo00<007oo00000goo0P007Goo00<007ooOol0:Goo0P00D7oo000;Ool01`00Oomoogoo001oo`00
009oo`03001oo`0000=oo`03001oogoo01aoo`03001oogoo02]oo`8004ioo`002Woo00<007oo0000
0Woo00<007oo00000Woo00<007oo00000goo00<007ooOol06goo00<007ooOol0;Woo0P00C7oo000;
Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`0KOol00`00Oomoo`0`
Ool30019Ool001Yoo`03001oogoo01Yoo`03001oogoo03Aoo`8004Moo`006Woo00<007ooOol06Woo
00<007ooOol0=Woo0`00A7oo000JOol00`00Oomoo`0JOol00`00Oomoo`0iOol30011Ool001Yoo`03
001oogoo01Yoo`03001oogoo03aoo`8003moo`006Woo00<007ooOol06Woo00<007ooOol0?Woo0`00
?7oo000JOol00`00Oomoo`0JOol00`00Oomoo`11Ool2000jOol001Yoo`03001oogoo01Yoo`03001o
ogoo04=oo`<003Moo`006Woo00<007ooOol06Woo00<007ooOol0AWoo1000<goo000JOol00`00Oomo
o`0JOol00`00Oomoo`1:Ool2000aOol001Yoo`03001oogoo01Yoo`03001oogoo04aoo`<002ioo`00
6Woo00<007ooOol06Woo00<007ooOol0Cgoo0P00;7oo000JOol00`00Oomoo`0JOol00`00Oomoo`1A
Ool2000ZOol001Yoo`03001oogoo01Yoo`03001oogoo05=oo`8002Qoo`006Woo00<007ooOol06Woo
00<007ooOol0EGoo0`009Goo000JOol00`00Oomoo`0JOol00`00Oomoo`1HOol2000SOol001Yoo`03
001oogoo01Yoo`03001oogoo05Yoo`80025oo`006Woo00<007ooOol06Woo00<007ooOol0G7oo0P00
7goo000JOol00`00Oomoo`0JOol00`00Oomoo`1NOol2000MOol001Yoo`03001oogoo01]oo`03001o
ogoo05moo`03001oogoo01Yoo`006Woo00<007ooOol06goo00<007ooOol0H7oo0P006Woo000JOol0
0`00Oomoo`0KOol00`00Oomoo`1ROol2000HOol001Yoo`03001oogoo01]oo`03001oogoo06Aoo`03
001oogoo01Eoo`006Woo00<007ooOol06goo00<007ooOol0IGoo00<007ooOol057oo000JOol00`00
Oomoo`0KOol00`00Oomoo`1VOol2000DOol001Yoo`03001oogoo01]oo`03001oogoo06Qoo`03001o
ogoo015oo`006Woo00<007ooOol06goo00<007ooOol0JGoo00<007ooOol047oo000JOol00`00Oomo
o`0KOol00`00Oomoo`1ZOol00`00Oomoo`0?Ool001Yoo`03001oogoo01]oo`03001oogoo06]oo`03
001oogoo00ioo`006Woo00<007ooOol06goo00<007ooOol0K7oo00<007ooOol03Goo000JOol00`00
Oomoo`0KOol00`00Oomoo`1]Ool00`00Oomoo`0<Ool001Yoo`03001oogoo01]oo`03001oogoo06io
o`03001oogoo00]oo`006Woo00<007ooOol06goo00<007ooOol0Kgoo00<007ooOol02Woo000JOol0
0`00Oomoo`0KOol00`00Oomoo`1_Ool00`00Oomoo`0:Ool001Yoo`03001oogoo01]oo`03001oogoo
071oo`03001oogoo00Uoo`006Woo00<007ooOol06goo00<007ooOol0LGoo00<007ooOol027oo000J
Ool00`00Oomoo`0KOol00`00Oomoo`1aOol00`00Oomoo`08Ool001Yoo`03001oogoo01]oo`03001o
ogoo079oo`03001oogoo00Moo`006Woo00<007ooOol06goo00<007ooOol0LWoo00<007ooOol01goo
000JOol00`00Oomoo`0KOol00`00Oomoo`1cOol00`00Oomoo`06Ool001Yoo`03001oogoo01]oo`03
001oogoo07Aoo`03001oogoo00Eoo`006Woo00<007ooOol06goo00<007ooOol0M7oo00<007ooOol0
1Goo000JOol00`00Oomoo`0JOol00`00Oomoo`1fOol00`00Oomoo`04Ool001Yoo`03001oogoo01Yo
o`03001oogoo07Ioo`03001oogoo00Aoo`006Woo00<007ooOol06Woo00<007ooOol0MWoo00<007oo
Ool017oo000JOol00`00Oomoo`0JOol00`00Oomoo`1gOol00`00Oomoo`03Ool000Uoo`D0009oo`03
001oogoo009oo`03001oogoo009oo`03001oogoo01Uoo`03001oogoo07Qoo`03001oogoo00=oo`00
2goo00L007ooOomoo`00Ool00002Ool00`00Ool00003Ool00`00Oomoo`0IOol00`00Oomoo`1iOol0
0`00Oomoo`02Ool000Eoo`<000=oo`03001oogoo00=oo`06001oogoo001oo`000goo0P006Woo00<0
07ooOol0NGoo00<007ooOol00Woo000;Ool01000Oomoogoo0P000goo00<007oo00000goo00<007oo
Ool06Goo00<007ooOol0NGoo00<007ooOol00Woo000;Ool01@00Oomoogoo000017oo00<007oo0000
0goo00<007ooOol067oo00<007ooOol0NWoo00<007ooOol00Woo000:Ool20003Ool30003Ool00`00
Oomoo`02Ool00`00Oomoo`0HOol00`00Oomoo`1jOol00`00Oomoo`02Ool001Yoo`03001oogoo01Mo
o`03001oogoo07]oo`03001oogoo009oo`006Woo00<007ooOol05goo00<007ooOol0Ngoo00<007oo
Ool00Woo000JOol00`00Oomoo`0GOol00`00Oomoo`1kOol00`00Oomoo`02Ool001Yoo`03001oogoo
01Moo`03001oogoo07]oo`03001oogoo009oo`006Woo00<007ooOol05Woo00<007ooOol0O7oo00<0
07ooOol00Woo000JOol00`00Oomoo`0FOol00`00Oomoo`1lOol00`00Oomoo`02Ool001Yoo`03001o
ogoo01Ioo`03001oogoo07aoo`03001oogoo009oo`006Woo00<007ooOol05Goo00<007ooOol0OGoo
00<007ooOol00Woo000JOol00`00Oomoo`0EOol00`00Oomoo`1lOol00`00Oomoo`03Ool001Yoo`03
001oogoo01Aoo`03001oogoo07eoo`03001oogoo00=oo`006Woo00<007ooOol057oo00<007ooOol0
OGoo00<007ooOol00goo000JOol00`00Oomoo`0DOol00`00Oomoo`1mOol00`00Oomoo`03Ool001Yo
o`03001oogoo01Aoo`03001oogoo07eoo`03001oogoo00=oo`006Woo00<007ooOol04goo00<007oo
Ool0OGoo00<007ooOol017oo000JOol00`00Oomoo`0COol00`00Oomoo`1mOol00`00Oomoo`04Ool0
01Yoo`03001oogoo01=oo`03001oogoo07eoo`03001oogoo00Aoo`006Woo00<007ooOol04goo00<0
07ooOol0O7oo00<007ooOol01Goo000JOol00`00Oomoo`0BOol00`00Oomoo`1lOol00`00Oomoo`06
Ool001Yoo`03001oogoo019oo`03001oogoo07aoo`03001oogoo00Ioo`006Woo00<007ooOol04Goo
00<007ooOol0O7oo00<007ooOol01goo000JOol00`00Oomoo`0AOol00`00Oomoo`1lOol00`00Oomo
o`07Ool001Yoo`03001oogoo015oo`03001oogoo07]oo`03001oogoo00Qoo`006Woo00<007ooOol0
4Goo00<007ooOol0Ngoo00<007ooOol027oo000JOol00`00Oomoo`0@Ool00`00Oomoo`1kOol00`00
Oomoo`09Ool001Yoo`03001oogoo011oo`03001oogoo07]oo`03001oogoo00Uoo`006Woo00<007oo
Ool047oo00<007ooOol0NWoo00<007ooOol02Woo000JOol00`00Oomoo`0@Ool00`00Oomoo`1iOol0
0`00Oomoo`0;Ool001Yoo`03001oogoo011oo`03001oogoo07Uoo`03001oogoo00]oo`006Woo00<0
07ooOol03goo00<007ooOol0NGoo00<007ooOol037oo000JOol00`00Oomoo`0?Ool00`00Oomoo`1h
Ool00`00Oomoo`0=Ool001Yoo`03001oogoo00moo`03001oogoo07Moo`03001oogoo00ioo`006Woo
00<007ooOol03goo00<007ooOol0Mgoo00<007ooOol03Woo000JOol00`00Oomoo`0?Ool00`00Oomo
o`1fOol00`00Oomoo`0?Ool001Yoo`03001oogoo00ioo`03001oogoo07Ioo`03001oogoo011oo`00
6Woo00<007ooOol03Woo00<007ooOol0MGoo00<007ooOol04Goo000JOol00`00Oomoo`0>Ool00`00
Oomoo`1eOol00`00Oomoo`0AOol001Yoo`03001oogoo00ioo`03001oogoo07Aoo`03001oogoo019o
o`006Woo00<007ooOol03Goo00<007ooOol0M7oo00<007ooOol04goo000JOol00`00Oomoo`0=Ool0
0`00Oomoo`1cOol00`00Oomoo`0DOol001Yoo`03001oogoo00eoo`03001oogoo079oo`03001oogoo
01Eoo`006Woo00<007ooOol03Goo00<007ooOol0LGoo00<007ooOol05Woo000JOol00`00Oomoo`0=
Ool00`00Oomoo`1`Ool00`00Oomoo`0GOol001Yoo`03001oogoo00eoo`03001oogoo06moo`03001o
ogoo01Qoo`006Woo00<007ooOol03Goo00<007ooOol0KWoo00<007ooOol06Goo000JOol00`00Oomo
o`0=Ool00`00Oomoo`1]Ool00`00Oomoo`0JOol001Yoo`03001oogoo00eoo`03001oogoo06aoo`03
001oogoo01]oo`002Goo1@000Woo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol037oo00<0
07ooOol0K7oo00<007ooOol077oo000;Ool01`00Oomoogoo001oo`00009oo`03001oo`0000=oo`03
001oogoo00aoo`03001oogoo06Yoo`8001moo`001Goo0`000goo00L007ooOomoo`00Ool00002Ool0
0`00Ool00003Ool2000=Ool00`00Oomoo`1YOol00`00Oomoo`0OOol000]oo`07001oogooOol007oo
00000Woo00<007oo00000goo00<007ooOol037oo00<007ooOol0J7oo00<007ooOol087oo000;Ool0
1`00Oomoogoo001oo`00009oo`03001oo`0000=oo`03001oogoo00]oo`03001oogoo06Qoo`03001o
ogoo025oo`002Woo0P0017oo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol02goo00<007oo
Ool0Igoo00<007ooOol08Woo000JOol00`00Oomoo`0;Ool00`00Oomoo`1VOol00`00Oomoo`0SOol0
01Yoo`03001oogoo00]oo`03001oogoo06Eoo`03001oogoo02Aoo`006Woo00<007ooOol02goo00<0
07ooOol0Hgoo0P009goo000JOol00`00Oomoo`0;Ool00`00Oomoo`1ROol00`00Oomoo`0WOol001Yo
o`03001oogoo00]oo`03001oogoo061oo`8002Yoo`006Woo00<007ooOol02goo00<007ooOol0Ggoo
00<007ooOol0:Woo000JOol00`00Oomoo`0:Ool00`00Oomoo`1OOol00`00Oomoo`0[Ool001Yoo`03
001oogoo00Yoo`03001oogoo05eoo`8002ioo`006Woo00<007ooOol02Woo00<007ooOol0G7oo00<0
07ooOol0;Woo000JOol00`00Oomoo`0:Ool00`00Oomoo`1KOol00`00Oomoo`0_Ool001Yoo`03001o
ogoo00Uoo`03001oogoo05Yoo`80039oo`006Woo00<007ooOol02Goo00<007ooOol0F7oo0P00=7oo
000JOol00`00Oomoo`09Ool00`00Oomoo`1GOol00`00Oomoo`0dOol001Yoo`03001oogoo00Qoo`03
001oogoo05Ioo`8003Moo`006Woo00<007ooOol027oo00<007ooOol0E7oo0P00>Goo000JOol00`00
Oomoo`07Ool00`00Oomoo`1COol2000kOol001Yoo`03001oogoo00Moo`03001oogoo055oo`8003eo
o`006Woo00<007ooOol01Woo00<007ooOol0D7oo0P00?goo000JOol00`00Oomoo`06Ool00`00Oomo
o`1=Ool30011Ool001Yoo`03001oogoo00Eoo`03001oogoo04aoo`8004Aoo`006Woo00<007ooOol0
1Goo00<007ooOol0BGoo0`00AWoo000JOol00`00Oomoo`05Ool00`00Oomoo`17Ool20019Ool001Yo
o`03001oogoo00Eoo`03001oogoo04Aoo`<004]oo`006Woo00<007ooOol017oo00<007ooOol0@Goo
1000CWoo000JOol00`00Oomoo`04Ool00`00Oomoo`0oOol2001BOol001Yoo`03001oogoo00Aoo`03
001oogoo03eoo`8005Aoo`006Woo00<007ooOol017oo00<007ooOol0?7oo00<007ooOol0E7oo000J
Ool00`00Oomoo`03Ool00`00Oomoo`0mOol00`00Oomoo`1DOol001Yoo`03001oogoo00=oo`03001o
ogoo03ioo`03001oogoo05=oo`006Woo00<007ooOol00goo00<007ooOol0?goo00<007ooOol0DWoo
000JOol00`00Oomoo`02Ool00`00Oomoo`11Ool00`00Oomoo`1AOol001Yoo`03001oogoo009oo`03
001oogoo049oo`80055oo`006Woo00<007ooOol00Woo00<007ooOol0A7oo00<007ooOol0CWoo000J
Ool01@00Oomoogoo0000B7oo00<007ooOol0CGoo000JOol01@00Oomoogoo0000BGoo0P00CGoo000J
Ool01@00Oomoogoo0000Bgoo00<007ooOol0BWoo000JOol01000Oomoo`00CGoo00<007ooOol0BGoo
000JOol01000Oomoo`00CWoo0P00BGoo000JOol01000Oomoo`00D7oo00<007ooOol0AWoo000JOol0
1000Oomoo`00DGoo00<007ooOol0AGoo000JOol00`00Ool0001COol00`00Oomoo`14Ool001Yoo`03
001oo`0005Aoo`03001oogoo04=oo`006Woo00<007oo0000EGoo00<007ooOol0@Woo000JOol00`00
Ool0001FOol00`00Oomoo`11Ool001Yoo`03001oo`0005Moo`03001oogoo041oo`0047oo00<007oo
Ool00Woo00<007ooOol00Woo00<007oo0000F7oo00<007ooOol0?goo000?Ool00`00Ool00002Ool0
0`00Ool00003Ool00`00Ool0001IOol00`00Oomoo`0nOol000Yoo`<000Aoo`06001oogoo001oo`00
0goo0P00Fgoo00<007ooOol0?Goo000?Ool20003Ool00`00Ool00003Ool2001LOol00`00Oomoo`0l
Ool000moo`03001oogoo009oo`03001oo`0000=oo`8005aoo`03001oogoo03aoo`003goo0`000goo
00<007ooOol00Woo0P00GGoo00<007ooOol0>goo000JOol2001NOol00`00Oomoo`0jOol001Yoo`80
05ioo`03001oogoo03Yoo`006Woo0P00Ggoo00<007ooOol0>Goo000JOol2001OOol00`00Oomoo`0i
Ool001Yoo`80061oo`03001oogoo03Qoo`006Woo0P00H7oo00<007ooOol0>7oo000JOol2001QOol0
0`00Oomoo`0gOol001Yoo`80065oo`03001oogoo03Moo`006Woo0P00HWoo00<007ooOol0=Woo000J
Ool2001ROol00`00Oomoo`0fOol001Yoo`80069oo`03001oogoo03Ioo`006Woo0P00HWoo00<007oo
Ool0=Woo000JOol2001SOol00`00Oomoo`0eOol001Yoo`8006=oo`03001oogoo03Eoo`006Woo0P00
Hgoo00<007ooOol0=Goo000JOol2001SOol00`00Oomoo`0eOol001Yoo`8006=oo`03001oogoo03Eo
o`006Woo0P00Hgoo00<007ooOol0=Goo000JOol2001SOol00`00Oomoo`0eOol001Yoo`03001oo`00
069oo`03001oogoo03Eoo`006Woo00<007oo0000HWoo00<007ooOol0=Goo000JOol00`00Ool0001Q
Ool00`00Oomoo`0fOol001Yoo`03001oo`00065oo`03001oogoo03Ioo`006Woo00<007ooOol0HGoo
00<007ooOol0=Woo000JOol00`00Oomoo`1POol00`00Oomoo`0gOol001Yoo`03001oogoo061oo`03
001oogoo03Moo`006Woo00<007ooOol0Ggoo00<007ooOol0>7oo000JOol00`00Oomoo`1OOol00`00
Oomoo`0hOol001Yoo`03001oogoo05ioo`03001oogoo03Uoo`006Woo00<007ooOol0GWoo00<007oo
Ool0>Goo000JOol01@00Oomoogoo0000Fgoo00<007ooOol0>Woo000JOol01@00Oomoogoo0000Fgoo
00<007ooOol0>Woo000JOol00`00Oomoo`02Ool00`00Oomoo`1GOol00`00Oomoo`0kOol001Yoo`03
001oogoo009oo`03001oogoo05Ioo`03001oogoo03aoo`006Woo00<007ooOol00Woo00<007ooOol0
EGoo00<007ooOol0?Goo000JOol00`00Oomoo`02Ool00`00Oomoo`1DOol00`00Oomoo`0nOol001Yo
o`03001oogoo00=oo`03001oogoo059oo`03001oogoo03moo`006Woo00<007ooOol00goo00<007oo
Ool01goo0`000goo00<007ooOol03Goo0`000Woo00<007ooOol02goo0P0017oo00<007ooOol03Goo
00<007ooOol00Woo00<007ooOol00goo00<007ooOol00Woo1@000Woo00<007ooOol00Woo00<007oo
Ool01Goo1@0000Aoo`00000000=oo`03001oogoo00Ioo`D0009oo`<0009oo`03001oogoo00Ioo`00
6Woo00<007ooOol00goo00<007ooOol01goo00<007ooOol00Woo00<007oo00003goo00H007ooOol0
07oo000<Ool00`00Ool00002Ool00`00Ool0000=Ool00`00Ool00002Ool00`00Ool00002Ool20007
Ool01`00Oomoogoo001oo`00009oo`03001oo`0000Qoo`05001oogooOol00004Ool00`00Ool00009
Ool00`00Oomoo`03Ool01P00Oomoo`00Ool000Moo`006Woo00<007ooOol017oo00<007ooOol01goo
00L007ooOomoo`00Ool0000=Ool4000017oo001oo`0037oo00<007oo00000Woo00<007oo00003Goo
00<007oo00000Woo00D007oo001oo`0000Uoo`07001oogooOol007oo00000Woo00<007oo000027oo
00<007ooOol00Woo00L007ooOomoo`00Ool00009Ool01000Oomoogoo100000Aoo`00Ool000Moo`00
6Woo00<007ooOol017oo00<007ooOol01goo00L007ooOomoo`00Ool0000=Ool00`00Ool00002Ool0
0`00Ool0000<Ool20003Ool00`00Ool0000>Ool01P00Oomoogoo001oo`8000Yoo`07001oogooOol0
07oo00000Woo00<007oo000027oo00<007ooOol00Woo00L007ooOomoo`00Ool00009Ool01`00Oomo
ogoo001oo`00009oo`03001oo`0000Moo`006Woo00<007ooOol01Goo00<007ooOol01Goo00<007oo
00000Woo00<007oo00003Woo0P000Woo00<007oo000037oo00<007ooOol00Woo00<007oo00003Goo
00<007oo00000Woo00<007oo00002goo00L007ooOomoo`00Ool00002Ool00`00Ool00008Ool01`00
Oomoogoo001oo`00009oo`03001oo`0000Uoo`03001oogoo009oo`80009oo`03001oo`0000Moo`00
6Woo00<007ooOol01Woo00<007ooOol01Goo00<007ooOol00Woo00<007ooOol03Woo00D007ooOomo
o`0000ioo`8000=oo`03001oogoo00eoo`03001oogoo009oo`03001oogoo00Uoo`8000Aoo`03001o
ogoo009oo`03001oogoo00Ioo`8000Aoo`03001oogoo009oo`03001oogoo00Moo`8000Eoo`05001o
ogooOol00008Ool001Yoo`03001oogoo00Ioo`03001oogoo04Moo`03001oogoo04Moo`006Woo00<0
07ooOol01goo00<007ooOol0A7oo0P00BWoo000JOol00`00Oomoo`07Ool00`00Oomoo`12Ool2001<
Ool001Yoo`03001oogoo00Qoo`03001oogoo041oo`03001oogoo04aoo`005WooX@00000JOol00`00
Oomoo`02Ool00`00Oomoo`02Ool00`00Ool00002Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00
Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00
Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`0200000goo
001oo`03Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00
Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00
Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`03Ool10001
Ool1Ool001Yoo`03001oogoo00Uoo`03001oogoo03Yoo`03001oogoo055oo`006Woo00<007ooOol0
2Woo00<007ooOol0=goo0P00E7oo000JOol00`00Oomoo`0:Ool00`00Oomoo`0eOol2001FOol001Yo
o`03001oogoo00]oo`03001oogoo03=oo`03001oogoo05Ioo`006Woo00<007ooOol037oo00<007oo
Ool0<Goo00<007ooOol0Egoo000JOol00`00Oomoo`0=Ool00`00Oomoo`0^Ool2001JOol001Yoo`03
001oogoo00ioo`03001oogoo02aoo`03001oogoo05Yoo`006Woo00<007ooOol03goo00<007ooOol0
:Goo0P00GGoo000JOol00`00Oomoo`0@Ool00`00Oomoo`0VOol2001OOol001Yoo`03001oogoo015o
o`03001oogoo02Aoo`03001oogoo05moo`006Woo00<007ooOol04Woo00<007ooOol08Goo0P00HWoo
000JOol00`00Oomoo`0COol00`00Oomoo`0NOol2001TOol001Yoo`03001oogoo01Aoo`8001eoo`03
001oogoo06Aoo`006Woo00<007ooOol05Woo0P006Goo0P00Igoo000JOol00`00Oomoo`0HOol00`00
Oomoo`0COol3001YOol001Yoo`03001oogoo01Uoo`80015oo`8006aoo`006Woo00<007ooOol06goo
10001Goo2000KWoo000JOol00`00Oomoo`0OOol5001fOol001Yoo`03001oogoo09Yoo`006Woo00<0
07ooOol0VWoo000JOol00`00Oomoo`2JOol001Yoo`03001oogoo09Yoo`006Woo00<007ooOol0VWoo
002gOol00;Moo`00]goo002gOol00;Moo`00]goo002gOol00;Moo`00]goo002gOol00;Moo`00]goo
002gOol00;Moo`00]goo002gOol00;Moo`00\
\>"],
  ImageRangeCache->{{{0, 182.625}, {278, 0}} -> {-25.3287, -230.69, 0.97395, 
  0.97395}}]
}, Open  ]],

Cell["ZAHN AND ROSKIES (1972)", "Section"],

Cell["\<\
The Fourier shape descriptors presented in this section differ from \
Granlund's FDs in that the boundary function itself will have many desirable \
shape invariant features. The boundary is represented by a normalized \
function of arc length called the cumulative angular bend.\
\>", "Text"],

Cell[CellGroupData[{

Cell["Boundary representation: cumulative angular bend function.", 
  "Subsection"],

Cell["\<\
In this section, a sequence of functions of arc length will be computed. The \
goal is to represent the boundary with a function exhibiting desirable shape \
invariant properties. The functions depict the slope, first order \
approximation to derivative of slope (i.e. curvature), net angular bend (i.e. \
cumulative curvature), and finally, normalized net angular bend.\
\>", "Text"],

Cell[BoxData[{
    \(slope[{{x1_, y1_}, {x2_, y2_}}] := 
      ArcTan[x2 - x1, y2 - y1]\  /; \ \((x1\  != \ x2)\)\), 
    \(slope[{{x1_, y1_}, {x2_, y2_}}] := 
      Sign[y2 - y1] \[Pi]\/2\  /; \ \((x1\  == \ x2)\)\t\)}], "Input",
  CellLabel->"In[64]:="],

Cell["This calculates the slope.", "Text"],

Cell[BoxData[
    \(\(dy = slope\ /@\ Partition[Join[dataxy, {Last[dataxy]}], 2, 1]; \)\)], 
  "Input",
  CellLabel->"In[72]:="],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(ListPlot[dy, PlotJoined \[Rule] True]; \)\)], "Input",
  CellLabel->"In[73]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00744048 0.30883 0.0937389 [
[.17262 .29633 -6 -9 ]
[.17262 .29633 6 0 ]
[.32143 .29633 -6 -9 ]
[.32143 .29633 6 0 ]
[.47024 .29633 -6 -9 ]
[.47024 .29633 6 0 ]
[.61905 .29633 -6 -9 ]
[.61905 .29633 6 0 ]
[.76786 .29633 -9 -9 ]
[.76786 .29633 9 0 ]
[.91667 .29633 -9 -9 ]
[.91667 .29633 9 0 ]
[.01131 .02761 -12 -4.5 ]
[.01131 .02761 0 4.5 ]
[.01131 .12135 -12 -4.5 ]
[.01131 .12135 0 4.5 ]
[.01131 .21509 -12 -4.5 ]
[.01131 .21509 0 4.5 ]
[.01131 .40257 -6 -4.5 ]
[.01131 .40257 0 4.5 ]
[.01131 .49631 -6 -4.5 ]
[.01131 .49631 0 4.5 ]
[.01131 .59005 -6 -4.5 ]
[.01131 .59005 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.17262 .30883 m
.17262 .31508 L
s
[(20)] .17262 .29633 0 1 Mshowa
.32143 .30883 m
.32143 .31508 L
s
[(40)] .32143 .29633 0 1 Mshowa
.47024 .30883 m
.47024 .31508 L
s
[(60)] .47024 .29633 0 1 Mshowa
.61905 .30883 m
.61905 .31508 L
s
[(80)] .61905 .29633 0 1 Mshowa
.76786 .30883 m
.76786 .31508 L
s
[(100)] .76786 .29633 0 1 Mshowa
.91667 .30883 m
.91667 .31508 L
s
[(120)] .91667 .29633 0 1 Mshowa
.125 Mabswid
.06101 .30883 m
.06101 .31258 L
s
.09821 .30883 m
.09821 .31258 L
s
.13542 .30883 m
.13542 .31258 L
s
.20982 .30883 m
.20982 .31258 L
s
.24702 .30883 m
.24702 .31258 L
s
.28423 .30883 m
.28423 .31258 L
s
.35863 .30883 m
.35863 .31258 L
s
.39583 .30883 m
.39583 .31258 L
s
.43304 .30883 m
.43304 .31258 L
s
.50744 .30883 m
.50744 .31258 L
s
.54464 .30883 m
.54464 .31258 L
s
.58185 .30883 m
.58185 .31258 L
s
.65625 .30883 m
.65625 .31258 L
s
.69345 .30883 m
.69345 .31258 L
s
.73065 .30883 m
.73065 .31258 L
s
.80506 .30883 m
.80506 .31258 L
s
.84226 .30883 m
.84226 .31258 L
s
.87946 .30883 m
.87946 .31258 L
s
.95387 .30883 m
.95387 .31258 L
s
.99107 .30883 m
.99107 .31258 L
s
.25 Mabswid
0 .30883 m
1 .30883 L
s
.02381 .02761 m
.03006 .02761 L
s
[(-3)] .01131 .02761 1 0 Mshowa
.02381 .12135 m
.03006 .12135 L
s
[(-2)] .01131 .12135 1 0 Mshowa
.02381 .21509 m
.03006 .21509 L
s
[(-1)] .01131 .21509 1 0 Mshowa
.02381 .40257 m
.03006 .40257 L
s
[(1)] .01131 .40257 1 0 Mshowa
.02381 .49631 m
.03006 .49631 L
s
[(2)] .01131 .49631 1 0 Mshowa
.02381 .59005 m
.03006 .59005 L
s
[(3)] .01131 .59005 1 0 Mshowa
.125 Mabswid
.02381 .04636 m
.02756 .04636 L
s
.02381 .06511 m
.02756 .06511 L
s
.02381 .08386 m
.02756 .08386 L
s
.02381 .1026 m
.02756 .1026 L
s
.02381 .1401 m
.02756 .1401 L
s
.02381 .15885 m
.02756 .15885 L
s
.02381 .1776 m
.02756 .1776 L
s
.02381 .19634 m
.02756 .19634 L
s
.02381 .23384 m
.02756 .23384 L
s
.02381 .25259 m
.02756 .25259 L
s
.02381 .27133 m
.02756 .27133 L
s
.02381 .29008 m
.02756 .29008 L
s
.02381 .32758 m
.02756 .32758 L
s
.02381 .34633 m
.02756 .34633 L
s
.02381 .36507 m
.02756 .36507 L
s
.02381 .38382 m
.02756 .38382 L
s
.02381 .42132 m
.02756 .42132 L
s
.02381 .44006 m
.02756 .44006 L
s
.02381 .45881 m
.02756 .45881 L
s
.02381 .47756 m
.02756 .47756 L
s
.02381 .51506 m
.02756 .51506 L
s
.02381 .5338 m
.02756 .5338 L
s
.02381 .55255 m
.02756 .55255 L
s
.02381 .5713 m
.02756 .5713 L
s
.02381 .00887 m
.02756 .00887 L
s
.02381 .60879 m
.02756 .60879 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.03125 .30754 m
.03869 .37746 L
.04613 .36455 L
.05357 .32794 L
.06101 .38256 L
.06845 .34055 L
.07589 .30883 L
.08333 .30883 L
.09077 .30883 L
.09821 .30883 L
.10565 .30883 L
.1131 .30979 L
.12054 .23671 L
.12798 .25798 L
.13542 .30883 L
.14286 .29409 L
.1503 .2348 L
.15774 .23521 L
.16518 .23521 L
.17262 .23521 L
.18006 .20622 L
.1875 .19475 L
.19494 .23545 L
.20238 .17887 L
.20982 .16158 L
.21726 .16158 L
.2247 .12091 L
.23214 .0873 L
.23958 .15397 L
.24702 .03881 L
.25446 .06983 L
.2619 .08796 L
.26935 .08796 L
.27679 .05394 L
.28423 .60332 L
.29167 .05566 L
.29911 .18492 L
.30655 .3091 L
.31399 .30883 L
.32143 .30995 L
.32887 .24157 L
.33631 .25156 L
.34375 .30883 L
.35119 .30357 L
.35863 .23458 L
.36607 .23521 L
.37351 .23466 L
.38095 .30585 L
.38839 .24326 L
.39583 .23521 L
Mistroke
.40327 .23521 L
.41071 .23521 L
.41815 .23521 L
.4256 .23521 L
.43304 .19815 L
.44048 .20307 L
.44792 .23587 L
.45536 .1684 L
.4628 .16158 L
.47024 .16158 L
.47768 .16158 L
.48512 .12172 L
.49256 .08731 L
.5 .1528 L
.50744 .09966 L
.51488 .07673 L
.52232 .02235 L
.52976 .08863 L
.5372 .08796 L
.54464 .08824 L
.55208 .01574 L
.55952 .60332 L
.56696 .07461 L
.5744 .07858 L
.58185 .60279 L
.58929 .60236 L
.59673 .08646 L
.60417 .06519 L
.61161 .60332 L
.61905 .60332 L
.62649 .01813 L
.63393 .08851 L
.64137 .05845 L
.64881 .60332 L
.65625 .60332 L
.66369 .60332 L
.67113 .60332 L
.67857 .60332 L
.68601 .01472 L
.69345 .4783 L
.70089 .45607 L
.70833 .45607 L
.71577 .45607 L
.72321 .45607 L
.73065 .45607 L
.7381 .45607 L
.74554 .45607 L
.75298 .45607 L
.76042 .45607 L
.76786 .45607 L
Mistroke
.7753 .51021 L
.78274 .52598 L
.79018 .45473 L
.79762 .45607 L
.80506 .45607 L
.8125 .45607 L
.81994 .45607 L
.82738 .45607 L
.83482 .4918 L
.84226 .53015 L
.8497 .47009 L
.85714 .45607 L
.86458 .45607 L
.87202 .49914 L
.87946 .53031 L
.8869 .46104 L
.89435 .45607 L
.90179 .45607 L
.90923 .45607 L
.91667 .45607 L
.92411 .45607 L
.93155 .4785 L
.93899 .5297 L
.94643 .48486 L
.95387 .45607 L
.96131 .45607 L
.96875 .45607 L
.97619 .30883 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[73]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo003oOolQ
Ool000moo`03001oogoo0?moo`moo`003goo00<007ooOol0ogoo3goo000?Ool00`00Oomoo`3oOol?
Ool000moo`800?mooa1oo`003goo00<007ooOol0T7oo00<007ooOol08Woo00<007ooOol0EWoo000?
Ool00`00Oomoo`2@Ool00`00Oomoo`0BOol00`00Oomoo`0=Ool00`00Oomoo`1FOol000Qoo`8000Eo
o`03001oogoo08Qoo`03001oogoo00Eoo`03001oogoo019oo`03001oogoo00eoo`03001oogoo05Io
o`002Woo00<007ooOol00Woo00<007ooOol0R7oo00<007ooOol01Goo00<007ooOol04Woo00<007oo
Ool03Goo00<007ooOol0EWoo0003Ool30003Ool00`00Oomoo`03Ool30028Ool00`00Oomoo`05Ool0
0`00Oomoo`0BOol00`00Oomoo`0=Ool00`00Oomoo`1FOol000Yoo`03001oogoo009oo`03001oogoo
08Qoo`03001oogoo00Eoo`03001oogoo019oo`03001oogoo00eoo`03001oogoo05Ioo`0027oo00<0
07oo000017oo00<007ooOol0Qgoo0P001Woo0P0057oo0P003Woo00<007ooOol0EWoo0009Ool00`00
Oomoo`03Ool00`00Oomoo`0kOol00`00Oomoo`19Ool00`00Ool00005Ool2000DOol2000>Ool00`00
Oomoo`1FOol000moo`03001oogoo03]oo`03001oogoo04Uoo`03001oo`0000Eoo`8001Aoo`8000io
o`03001oogoo05Ioo`003goo0P00?7oo00<007ooOol0BGoo00<007oo00001Goo0P0057oo0P003Woo
00<007ooOol0EWoo000?Ool00`00Oomoo`0kOol2001:Ool00`00Ool00005Ool2000DOol2000>Ool0
0`00Oomoo`1FOol000moo`03001oogoo03]oo`8000Ioo`03001oogoo045oo`03001oo`0000Eoo`80
01Aoo`8000ioo`03001oogoo05Ioo`003goo00<007ooOol0>goo0P001Woo00D007ooOomoo`0003mo
o`03001oo`0000Eoo`8001Aoo`80009oo`03001oogoo00Uoo`03001oogoo05Ioo`003goo00<007oo
Ool0>goo0P001Woo00D007ooOomoo`0003moo`03001oo`0000Eoo`8001Aoo`80009oo`03001oogoo
00Uoo`03001oogoo05Ioo`003goo0P00?7oo00<007oo000017oo0P000goo00<007ooOol0?7oo00@0
07ooOol000Eoo`8000eoo`03001oogoo00Aoo`80009oo`03001oogoo00Uoo`03001oogoo05Ioo`00
3goo00<007ooOol0>Woo00@007ooOol000Aoo`8000=oo`03001oogoo03aoo`04001oogoo0005Ool2
000=Ool00`00Oomoo`04Ool200000goo0000000;Ool00`00Oomoo`1FOol000moo`03001oogoo03Yo
o`04001oogoo0004Ool20003Ool00`00Oomoo`0lOol01000Oomoo`0017oo00<007oo000037oo0P00
1Woo00<007oo00000P002goo00<007ooOol0EWoo000?Ool00`00Oomoo`0jOol01000Oomoo`0017oo
0P000goo00<007ooOol0?7oo00D007ooOomoo`0000=oo`03001oo`0000=oo`03001oogoo00Ioo`80
00Ioo`03001oo`00008000]oo`03001oogoo05Ioo`003goo00<007ooOol0>Woo00D007ooOomoo`00
00=oo`8000=oo`8003eoo`05001oogooOol00003Ool00`00Ool00003Ool30006Ool20006Ool00`00
Ool00002000;Ool00`00Oomoo`1FOol000moo`8003]oo`05001oogooOol00002Ool00`00Ool00003
Ool2000lOol00`00Oomoo`02Ool01`00Oomoogoo001oo`0000=oo`03001oo`0000Eoo`03001oo`00
00Ioo`05001oo`00Ool0000;Ool00`00Oomoo`1FOol000moo`03001oogoo03Moo`04001oogoo0004
Ool01@00Ool007oo00000goo0P00=Woo00<007ooOol00goo00<007ooOol00Woo00L007ooOomoo`00
Ool00003Ool00`00Ool00005Ool00`00Ool00006Ool01@00Ool007oo00002goo00<007ooOol0EWoo
000?Ool00`00Oomoo`0gOol01000Oomoo`0017oo0`0000=oo`00Ool00Woo0P00=Woo00<007ooOol0
0Woo00<007ooOol00goo1@0000=oo`00Ool00Woo00<007oo00001Goo00<007oo00001Woo00D007oo
001oo`0000]oo`03001oogoo05Ioo`003goo00<007ooOol0=goo00@007ooOol000Qoo`04001oogoo
Ool2000fOol00`00Oomoo`02Ool00`00Oomoo`09Ool01`00Oomoogoo001oo`0000Eoo`03001oo`00
00Ioo`05001oogooOol0000;Ool00`00Oomoo`1FOol000moo`03001oogoo03Ioo`80009oo`03001o
ogoo00Ioo`04001oogooOol2000eOol20003Ool00`00Oomoo`0:Ool01`00Oomoogoo001oo`0000Eo
o`03001oo`0000Ioo`05001oogooOol0000;Ool00`00Oomoo`1FOol000moo`03001oogoo03Ioo`80
009oo`03001oogoo00Ioo`04001oogooOol2000eOol20003Ool00`00Oomoo`0:Ool01`00Oomoogoo
001oo`0000Eoo`03001oo`0000Ioo`05001oogooOol0000;Ool00`00Oomoo`1FOol000moo`8003Mo
o`05001oo`00Ool00008Ool01000Oomoogoo0P00=Goo00<007oo00000Woo00<007ooOol02Woo00L0
07ooOomoo`00Ool00005Ool00`00Ool00006Ool01@00Oomoogoo00002goo00<007ooOol0EWoo000?
Ool00`00Oomoo`0fOol01@00Ool007oo000027oo00@007ooOomoo`8003Eoo`03001oo`00009oo`03
001oogoo00Yoo`07001oogooOol007oo00001Goo00<007oo00001Woo00D007ooOomoo`0000]oo`03
001oogoo05Ioo`003goo00<007ooOol0=Woo00D007oo001oo`0000Qoo`04001oogooOol2000eOol0
0`00Ool00002Ool00`00Oomoo`0:Ool01`00Oomoogoo001oo`0000Eoo`03001oo`0000Ioo`05001o
ogooOol0000;Ool00`00Oomoo`1FOol000Qoo`<000Aoo`03001oogoo03Eoo`06001oogoo001oo`00
27oo00@007ooOomoo`8003Aoo`06001oogoo001oo`003Goo00L007ooOomoo`00Ool00005Ool00`00
Ool00006Ool01@00Oomoogoo00002goo00<007ooOol0EWoo0008Ool00`00Oomoo`04Ool00`00Oomo
o`0eOol01P00Oomoo`00Ool000Qoo`04001oogooOol2000dOol01P00Oomoo`00Ool000eoo`07001o
ogooOol007oo00001Goo00<007oo00001Woo00D007ooOomoo`0000]oo`03001oogoo05Ioo`000goo
0`000goo00<007ooOol00goo0`00=Goo00H007ooOol007oo0008Ool01`00Oomoogoo001oo`0003=o
o`06001oogoo001oo`003Goo00L007ooOomoo`00Ool00005Ool00`00Ool00006Ool01@00Oomoogoo
00002goo00<007ooOol0EWoo0009Ool00`00Oomoo`03Ool00`00Oomoo`0eOol00`00Oomoo`020009
Ool01`00Oomoogoo001oo`0003=oo`06001oogoo001oo`003Goo00L007ooOomoo`00Ool00005Ool0
0`00Ool00006Ool01@00Oomoogoo00002goo00<007ooOol0EWoo0008Ool00`00Ool00004Ool00`00
Oomoo`0eOol00`00Oomoo`020009Ool01`00Oomoogoo001oo`0003=oo`06001oogoo001oo`003Goo
00L007ooOomoo`00Ool00005Ool00`00Ool00006Ool01@00Oomoogoo00002goo00<007ooOol0EWoo
0009Ool00`00Oomoo`03Ool00`00Oomoo`0dOol01000Oomoogoo0P002Goo00L007ooOomoo`00Ool0
000bOol01`00Oomoogoo001oo`0000eoo`07001oogooOol007oo00001Goo00<007oo00001Woo00D0
07ooOomoo`0000]oo`8005Moo`003goo00<007ooOol0=7oo00@007ooOomoo`8000Uoo`07001oogoo
Ool007oo0000<Woo00L007ooOomoo`00Ool0000=Ool01`00Oomoogoo001oo`0000Eoo`03001oo`00
00Ioo`05001oogooOol0000;Ool2001GOol000moo`8003Eoo`03001oogoo009oo`03001oogoo00Mo
o`07001oogooOol007oo0000<Woo00<007ooOol00Woo0P003Goo00L007ooOomoo`00Ool00005Ool0
0`00Ool00006Ool01@00Oomoogoo00002goo0P00Egoo000?Ool00`00Oomoo`0dOol00`00Oomoo`02
Ool00`00Oomoo`07Ool01`00Oomoogoo001oo`00039oo`03001oogoo009oo`03001oogoo00aoo`07
001oogooOol007oo00001Goo00<007oo00001Woo00D007ooOomoo`0000]oo`8005Moo`003goo00<0
07ooOol0=7oo00<007ooOol00Woo00<007ooOol01goo00L007ooOomoo`00Ool0000bOol00`00Oomo
o`02Ool00`00Oomoo`0<Ool01`00Oomoogoo001oo`0000Eoo`03001oo`0000Ioo`05001oogooOol0
000;Ool2001GOol000moo`03001oogoo03Aoo`03001oogoo009oo`03001oogoo00Moo`07001oogoo
Ool007oo0000<Woo00<007ooOol00Woo00<007ooOol037oo00L007ooOomoo`00Ool00005Ool00`00
Ool00006Ool01@00Oomoogoo00002goo0P00Egoo000?Ool00`00Oomoo`0cOol00`00Oomoo`03Ool0
0`00Oomoo`07Ool01`00Oomoogoo001oo`00035oo`03001oogoo00=oo`03001oogoo00aoo`07001o
ogooOol007oo00001Goo00<007oo00001Woo00D007ooOomoo`0000]oo`8005Moo`003goo0P00=7oo
00<007ooOol03Goo00L007ooOomoo`00Ool0000aOol00`00Oomoo`0BOol01`00Oomoogoo001oo`00
00Eoo`03001oo`0000Ioo`05001oogooOol0000;Ool2001GOol000moo`03001oogoo035oo`<000mo
o`07001oogooOol007oo0000;Goo1@005Goo00H007ooOol007oo0005Ool00`00Ool00006Ool01@00
Oomoogoo00002Woo00<007oo0000Egoo000?Ool00`00Oomoo`0aOol00`00Oomoo`0?Ool01@00Oomo
ogoo00000Woo00<007ooOol0:Goo00<007ooOol067oo00H007ooOol007oo0005Ool00`00Ool00005
Ool00`00Oomoo`02Ool00`00Oomoo`08Ool00`00Ool0001GOol000moo`03001oogoo031oo`03001o
ogoo011oo`05001oogooOol00002Ool00`00Oomoo`0XOol00`00Oomoo`0IOol01P00Oomoo`00Ool0
00Eoo`03001oo`0000Eoo`03001oogoo009oo`03001oogoo00Qoo`03001oo`0005Moo`003goo00<0
07ooOol0<7oo00<007ooOol047oo00D007ooOomoo`00009oo`03001oogoo02Qoo`03001oogoo01Uo
o`06001oogoo001oo`001Goo00<007oo00001Goo00<007ooOol00Woo00<007ooOol027oo00<007oo
0000Egoo000?Ool2000`Ool00`00Oomoo`0AOol01@00Oomoogoo00000Woo00<007ooOol0:7oo00<0
07ooOol06Goo00H007ooOol007oo0005Ool00`00Ool00005Ool00`00Oomoo`02Ool00`00Oomoo`08
Ool00`00Ool0001GOol000moo`03001oogoo02moo`03001oogoo015oo`05001oogooOol00002Ool0
0`00Oomoo`0XOol00`00Oomoo`0IOol01P00Oomoo`00Ool000Eoo`03001oo`0000Eoo`03001oogoo
009oo`03001oogoo00Qoo`03001oo`0005Moo`003goo00<007ooOol0;goo00<007ooOol04Goo00D0
07ooOomoo`00009oo`03001oogoo02Qoo`03001oogoo01Uoo`06001oogoo001oo`001Goo00<007oo
00001Goo00<007ooOol00Woo00<007ooOol027oo00<007oo0000Egoo000?Ool00`00Oomoo`0_Ool0
0`00Oomoo`0AOol01@00Oomoogoo00000Woo00<007ooOol09goo00<007ooOol06Woo00H007ooOol0
07oo0005Ool00`00Ool00005Ool00`00Oomoo`02Ool00`00Oomoo`08Ool00`00Ool0001GOol000mo
o`03001oogoo02moo`03001oogoo015oo`05001oogooOol00002Ool00`00Oomoo`0WOol00`00Oomo
o`0JOol01P00Oomoo`00Ool000Eoo`03001oo`0000Eoo`03001oogoo009oo`03001oogoo00Qoo`03
001oo`0005Moo`003goo00<007ooOol0:goo00@007ooOol001Eoo`03001oo`0000=oo`03001oogoo
02Moo`03001oogoo01Yoo`06001oogoo001oo`001Goo00<007oo00001Goo00<007ooOol00goo00<0
07ooOol01goo00<007oo0000Egoo000?Ool2000[Ool20002Ool00`00Oomoo`0COol00`00Ool00003
Ool00`00Oomoo`0ROol00`00Oomoo`02Ool00`00Oomoo`0JOol01P00Oomoo`00Ool000Eoo`03001o
o`0000Eoo`03001oogoo00=oo`03001oogoo00Moo`03001oo`0005Moo`003goo00<007ooOol0:Goo
00<007oo00000Woo00<007ooOol04goo00<007oo00000goo00<007ooOol08Woo0P000goo00<007oo
Ool06Woo00H007ooOol007oo0005Ool01000Oomoo`0017oo00<007ooOol00goo00<007ooOol01goo
00<007oo0000Egoo000?Ool00`00Oomoo`0XOol01`00Oomoogoo001oo`0001Eoo`03001oo`0000=o
o`03001oogoo029oo`03001oo`00009oo`03001oogoo01Yoo`06001oogoo001oo`001Goo00@007oo
Ool000Aoo`03001oogoo00=oo`03001oogoo00Moo`03001oo`0005Moo`001goo1@000goo00<007oo
Ool0:7oo00L007ooOomoo`00Ool0000EOol00`00Ool00003Ool00`00Oomoo`0QOol01000Oomoo`00
0Woo00<007ooOol06Woo00<007oo00000Woo00<007ooOol00goo00@007ooOol000Aoo`03001oogoo
00=oo`03001oogoo00Moo`03001oo`0005Moo`002Goo00<007ooOol00goo00<007ooOol0:7oo00L0
07ooOomoo`00Ool0000EOol00`00Ool00003Ool00`00Oomoo`0QOol01000Oomoo`000Woo00<007oo
Ool06Woo00<007oo00000goo00<007ooOol00Woo00@007ooOol000Aoo`03001oogoo00=oo`03001o
ogoo00Moo`03001oo`0005Moo`000goo0`000goo00<007ooOol00goo0`009goo00<007ooOol00Woo
00<007oo00005Goo00<007oo00000goo00<007ooOol08Goo00L007ooOomoo`00Ool0000LOol00`00
Ool00003Ool01@00Oomoogoo00000goo00<007ooOol00Woo00<007ooOol00goo00<007ooOol01goo
00<007oo0000Egoo0009Ool00`00Oomoo`03Ool00`00Oomoo`0WOol00`00Oomoo`02Ool00`00Ool0
000EOol00`00Ool00004Ool00`00Oomoo`0POol01`00Oomoogoo001oo`0001aoo`03001oo`0000=o
o`05001oogooOol00003Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`07Ool00`00Ool0
001GOol000Uoo`03001oogoo00=oo`03001oogoo02Moo`03001oogoo009oo`8001Ioo`03001oo`00
00Aoo`03001oogoo021oo`04001oogooOol2000MOol00`00Ool00003Ool01@00Oomoogoo00000goo
00<007ooOol00Woo00<007ooOol00goo00<007ooOol01goo00<007oo0000Egoo0008Ool20005Ool0
0`00Oomoo`0WOol00`00Oomoo`03Ool00`00Oomoo`0DOol00`00Ool00004Ool00`00Oomoo`0POol0
1000Oomoogoo0P007Goo00<007oo00000goo00D007ooOomoo`0000=oo`03001oogoo009oo`03001o
ogoo00=oo`03001oogoo00Moo`03001oo`0005Moo`003goo00<007ooOol09Woo00<007ooOol017oo
00<007ooOol057oo00<007oo000017oo00<007ooOol07goo00<007ooOol00goo00<007ooOol06goo
00<007oo00000goo00D007ooOomoo`0000=oo`03001oogoo009oo`03001oogoo00=oo`03001oogoo
00Moo`03001oo`0005Moo`003goo0P008Goo00<007ooOol00goo00<007ooOol017oo00<007ooOol0
57oo00<007oo000017oo00<007ooOol037oo00D007ooOomoo`0000ioo`03001oogoo00=oo`03001o
ogoo01]oo`03001oo`0000=oo`05001oogooOol00003Ool00`00Oomoo`02Ool00`00Oomoo`03Ool0
0`00Oomoo`07Ool00`00Ool0001GOol000moo`03001oogoo01Qoo`03001oogoo00Eoo`L000Ioo`03
001oogoo01Aoo`03001oo`0000Aoo`03001oogoo00aoo`D000Eoo`X000Eoo`03001oogoo01]oo`03
001oo`0000=oo`05001oogooOol00003Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`07
Ool00`00Ool0001GOol000moo`03001oogoo01Qoo`03001oogoo00Eoo`03001oogoo025oo`03001o
o`0000Aoo`03001oogoo00Aoo`03001oogoo00Eoo`05001oogooOol00004Ool00`00Oomoo`0[Ool0
0`00Ool00003Ool01@00Oomoogoo00000goo00<007ooOol00Woo00<007ooOol00goo00<007ooOol0
1goo00<007oo0000Egoo000?Ool00`00Oomoo`0HOol20006Ool00`00Oomoo`0QOol00`00Ool00004
Ool00`00Oomoo`04Ool20006Ool01@00Oomoogoo00000goo00<007ooOol0;7oo00<007oo00000goo
00D007ooOomoo`0000=oo`03001oogoo009oo`03001oogoo00=oo`03001oogoo00Moo`03001oo`00
05Moo`003goo00<007ooOol067oo0P001Woo00<007ooOol08Goo00<007oo000017oo00<007ooOol0
17oo0P001Woo00D007ooOomoo`0000=oo`03001oogoo02aoo`03001oo`0000=oo`05001oogooOol0
0003Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`07Ool00`00Ool0001GOol000moo`80
01Uoo`8000Eoo`03001oogoo029oo`03001oo`0000Aoo`03001oogoo00Aoo`03001oo`0000Aoo`03
001oogoo00=oo`04001oogoo000^Ool00`00Ool00003Ool01@00Oomoogoo00000goo00<007ooOol0
0Woo00<007ooOol00goo00<007ooOol01goo00<007oo0000Egoo000?Ool00`00Oomoo`0GOol01000
Oomoo`0017oo00<007ooOol08Woo00<007oo000017oo00<007ooOol017oo00<007oo000017oo00<0
07ooOol00goo00@007ooOol002ioo`03001oo`0000=oo`05001oogooOol00003Ool00`00Oomoo`02
Ool00`00Oomoo`03Ool00`00Oomoo`07Ool00`00Ool0001GOol000moo`03001oogoo01Moo`04001o
ogoo0004Ool00`00Oomoo`0ROol00`00Ool00004Ool00`00Oomoo`03Ool01000Oomoo`0017oo00<0
07ooOol00goo00@007ooOol002ioo`03001oo`0000=oo`05001oogooOol00003Ool00`00Oomoo`02
Ool00`00Oomoo`03Ool00`00Oomoo`07Ool00`00Ool0001GOol000moo`03001oogoo01Moo`04001o
ogoo0004Ool00`00Oomoo`0ROol00`00Ool00004Ool00`00Oomoo`03Ool01000Oomoo`0017oo00<0
07ooOol00goo00<007oo0000;goo00<007oo00000goo00D007ooOomoo`0000=oo`03001oogoo009o
o`03001oogoo00=oo`03001oogoo00Moo`03001oo`0005Moo`003goo00<007ooOol05goo00@007oo
Ool000Aoo`03001oogoo029oo`03001oo`0000Aoo`03001oogoo00=oo`05001oogooOol00003Ool0
0`00Oomoo`03Ool00`00Ool0000_Ool00`00Ool00003Ool01@00Oomoogoo00000goo00<007ooOol0
0Woo00<007ooOol00goo00<007ooOol01goo00<007oo0000Egoo000?Ool00`00Oomoo`0GOol01000
Oomoo`0017oo00<007ooOol00`000goo00<007ooOol06Goo00<007oo000017oo00<007oo00000P00
00=oo`0000000Woo00D007ooOomoo`0000Eoo`03001oo`0001=oo`8000Aoo`03001oogoo01=oo`03
001oo`0000=oo`05001oogooOol00003Ool20003Ool20004Ool00`00Oomoo`07Ool00`00Ool0000=
Ool50002Ool00`00Oomoo`02Ool00`00Oomoo`0KOol5000017oo000000000goo00<007ooOol04Goo
000?Ool2000HOol01@00Oomoogoo00000goo00@007ooOol000Aoo`03001oo`0001Yoo`03001oo`00
00Aoo`04001oogoo0002Ool01@00Ool007oo00000goo00<007ooOol00goo00<007oo00004goo00<0
07oo00000Woo00<007oo000057oo00<007oo00000goo00D007ooOomoo`0000=oo`03001oo`00009o
o`03001oo`0000=oo`03001oogoo00Moo`03001oo`0000moo`07001oogooOol007oo00000Woo00<0
07oo00007Woo00D007ooOomoo`0000Aoo`03001oo`00019oo`003goo00<007ooOol05goo00D007oo
Oomoo`0000=oo`05001oogooOol00003Ool00`00Ool0000JOol00`00Ool00004Ool500001Woo001o
o`00Ool000=oo`03001oogoo00=oo`03001oo`0001=oo`03001oo`00009oo`03001oo`0001Aoo`03
001oo`0000=oo`05001oogooOol00003Ool00`00Ool00002Ool00`00Ool00003Ool00`00Oomoo`07
Ool00`00Ool0000?Ool01`00Oomoogoo001oo`00009oo`03001oo`0001ioo`03001oogoo009oo`07
001oogooOol007oo00004Woo000?Ool00`00Oomoo`0GOol01@00Oomoogoo00000Woo00<007ooOol0
0Woo00L007ooOomoo`00Ool0000JOol00`00Ool00005Ool00`00Ool00002Ool01@00Ool007oo0000
0goo00<007ooOol00goo00<007oo00004goo0P000goo00<007oo000057oo00<007oo00000goo00D0
07ooOomoo`0000=oo`8000=oo`03001oo`0000=oo`03001oogoo00Moo`03001oo`0000moo`07001o
ogooOol007oo00000Woo00<007oo00007Woo00<007ooOol00Woo00L007ooOomoo`00Ool0000BOol0
00moo`03001oogoo01Moo`05001oogooOol00002Ool01`00Oomoogoo001oo`00009oo`03001oo`00
01Yoo`03001oo`0000Eoo`<0009oo`05001oo`00Ool00003Ool00`00Oomoo`03Ool00`00Ool0000C
Ool00`00Oomoo`02Ool00`00Ool0000DOol00`00Ool00003Ool01@00Oomoogoo00000goo00<007oo
00000Woo00<007oo00000goo00<007ooOol01goo00<007oo00003goo00L007ooOomoo`00Ool00002
Ool00`00Ool0000NOol01`00Oomoogoo001oo`00009oo`03001oo`00019oo`003goo00<007ooOol0
5goo00D007ooOomoo`00009oo`03001oogoo009oo`03001oogoo009oo`03001oogoo01Uoo`03001o
o`0000Eoo`03001oo`00009oo`80009oo`04001oogoo0007Ool2000DOol20003Ool00`00Oomoo`0C
Ool00`00Ool00003Ool01@00Oomoogoo00000goo0P000goo0P0017oo00<007ooOol01goo00<007oo
00003Woo0P0017oo00<007ooOol00Woo00<007ooOol077oo0P0017oo00<007ooOol00Woo00<007oo
Ool04Goo000?Ool2000GOol00`00Oomoo`02Ool01000Oomoo`009Goo00<007oo00001Goo00<007oo
Ool00Woo00D007ooOomoo`00009oo`03001oogoo00Eoo`03001oogoo02ioo`03001oo`0000=oo`05
001oogooOol00003Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`07Ool00`00Ool0001G
Ool000moo`03001oogoo01Ioo`03001oogoo009oo`04001oogoo000UOol00`00Ool00005Ool01@00
Oomoogoo00001Goo00<007oo00001goo00<007ooOol0;Woo00<007oo00000goo00D007ooOomoo`00
00=oo`03001oogoo009oo`03001oogoo00=oo`03001oogoo00Moo`03001oo`0005Moo`003goo00<0
07ooOol05Woo00<007ooOol00goo0P009Woo00<007oo00001Goo00D007ooOomoo`0000Eoo`03001o
o`0000Moo`03001oogoo02ioo`03001oo`0000=oo`05001oogooOol00003Ool00`00Oomoo`02Ool0
0`00Oomoo`03Ool00`00Oomoo`07Ool00`00Ool0001GOol000moo`03001oogoo01Ioo`03001oogoo
00=oo`8002Ioo`03001oo`0000Eoo`05001oogooOol00005Ool00`00Ool00007Ool00`00Oomoo`0^
Ool00`00Ool00003Ool01@00Oomoogoo00000goo00<007ooOol00Woo00<007ooOol00goo00<007oo
Ool01goo00<007oo0000Egoo000?Ool00`00Oomoo`0FOol00`00Oomoo`03Ool00`00Oomoo`0UOol0
0`00Ool00005Ool01@00Oomoogoo00001Goo00<007oo00001goo00<007ooOol0;Woo00<007oo0000
0goo00D007ooOomoo`0000=oo`03001oogoo009oo`03001oogoo00=oo`03001oogoo00Moo`03001o
o`0005Moo`0027ooo`006@00000?Ool00`00Ool00007Ool01@00Oomoogoo00001Woo00<007ooOol0
1goo00<007ooOol01goo00<007ooOol027oo00<007ooOol01goo00<007ooOol01Woo0`002Goo00<0
07ooOol01goo00<007ooOol01goo00<007ooOol027oo00<007ooOol01goo00<007ooOol01goo00<0
07ooOol027oo00H007ooOol007oo0003Ool20002Ool01@00Oomoogoo00000goo0P001Goo00@007oo
Ool000Ioo`04001oo`00000:Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`08Ool00`00
Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`08Ool00`00Oomoo`03Ool01@00Oomoogoo00000goo
000?Ool00`00Ool0000;Ool00`00Oomoo`0HOol00`00Oomoo`0KOol00`00Ool00009Ool00`00Oomo
o`0VOol00`00Oomoo`0EOol00`00Ool00003Ool01@00Oomoogoo00000goo00@007ooOomoo`8000Eo
o`03001oogoo00Moo`03001oo`0001Eoo`03001oogoo02Ioo`03001oogoo00ioo`03001oogoo00Eo
o`003goo00<007oo00002Woo00<007ooOol0=goo00<007oo0000BWoo00<007oo00000goo00D007oo
Oomoo`0000=oo`03001oogoo009oo`03001oogoo00=oo`03001oogoo00Moo`03001oo`0004moo`03
001oogoo00Eoo`003goo00<007oo00002Woo00<007ooOol0=goo00<007oo0000BWoo00<007oo0000
0goo00D007ooOomoo`0000=oo`03001oogoo009oo`03001oogoo00=oo`03001oogoo00Moo`03001o
o`0004moo`03001oogoo00Eoo`003goo0P0000=oo`00Ool00goo00<007ooOol00Woo00<007ooOol0
=goo00<007oo0000BWoo00<007oo00000goo00D007ooOomoo`0000=oo`03001oogoo009oo`03001o
ogoo00=oo`03001oogoo00Moo`03001oo`0004moo`03001oogoo00Eoo`003goo00@007ooOol000Ao
o`03001oogoo009oo`03001oogoo03Moo`03001oo`0004Yoo`03001oo`0000=oo`05001oogooOol0
0003Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`07Ool00`00Ool0001?Ool00`00Oomo
o`05Ool000moo`04001oogoo0004Ool01@00Oomoogoo0000>Woo00<007oo0000BWoo00<007oo0000
0goo00D007ooOomoo`0000=oo`03001oogoo009oo`03001oogoo00=oo`03001oogoo00Moo`03001o
o`0004moo`03001oogoo00Eoo`003goo00@007ooOol000=oo`8000=oo`03001oogoo03Qoo`03001o
o`0004Yoo`03001oo`0000=oo`05001oogooOol00003Ool00`00Oomoo`02Ool00`00Oomoo`03Ool0
0`00Oomoo`07Ool00`00Ool0001?Ool00`00Oomoo`05Ool000moo`04001oogoo0003Ool00`00Ool0
0002Ool00`00Oomoo`0hOol00`00Ool0001:Ool00`00Ool00003Ool01@00Oomoogoo00000goo00<0
07ooOol00Woo00<007ooOol00goo00<007ooOol01goo00<007oo0000Cgoo00<007ooOol01Goo000?
Ool200000goo001oo`02Ool00`00Ool00002Ool00`00Oomoo`0hOol00`00Ool0001:Ool00`00Ool0
0003Ool01@00Oomoogoo00000goo00<007ooOol00Woo00<007ooOol00goo00<007ooOol01goo00<0
07oo0000Cgoo00<007ooOol01Goo000?Ool01000Oomoo`000goo00<007oo00000Woo00<007ooOol0
>7oo00<007oo0000BWoo00<007oo00000goo00D007ooOomoo`0000=oo`03001oogoo009oo`03001o
ogoo00=oo`03001oogoo00Moo`03001oo`0004ioo`03001oogoo00Ioo`003goo00@007ooOol000=o
o`05001oo`00Ool0000kOol00`00Ool0001:Ool00`00Ool00003Ool01@00Oomoogoo00000goo00<0
07ooOol00Woo00<007ooOol00goo00<007ooOol01goo00<007oo0000CWoo00<007ooOol01Woo000?
Ool01000Oomoo`000Woo00H007ooOol007oo000kOol00`00Ool0001:Ool00`00Ool00003Ool01@00
Oomoogoo00000goo00<007ooOol00Woo00<007ooOol00goo00<007ooOol01goo00<007oo0000CWoo
00<007ooOol01Woo000?Ool01000Oomoo`000Woo00H007ooOol007oo000kOol00`00Ool0001:Ool0
0`00Ool00003Ool01@00Oomoogoo00000goo00<007ooOol00Woo00<007ooOol00goo00<007ooOol0
1goo00<007oo0000CWoo00<007ooOol01Woo000?Ool01`00Oomoogoo001oo`00009oo`03001oo`00
03]oo`03001oo`0004Yoo`03001oo`0000=oo`05001oogooOol00003Ool00`00Oomoo`02Ool00`00
Oomoo`03Ool00`00Oomoo`07Ool01000Oomoo`00CGoo00<007ooOol01Woo000?Ool20002Ool20003
Ool00`00Ool0000kOol00`00Ool0001:Ool00`00Ool00003Ool01@00Oomoogoo00000goo00<007oo
Ool00Woo00<007ooOol00goo00<007ooOol01goo00@007ooOol004eoo`03001oogoo00Ioo`003goo
00@007ooOomoo`8000Aoo`8003]oo`03001oo`0004Yoo`03001oo`0000=oo`05001oogooOol00003
Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`07Ool01000Oomoo`00CGoo00<007ooOol0
1Woo000?Ool01@00Oomoogoo00001Goo00<007ooOol0>Woo00<007oo0000BWoo00<007oo00000goo
00D007ooOomoo`0000=oo`03001oogoo009oo`03001oogoo00=oo`03001oogoo00Moo`04001oogoo
001=Ool00`00Oomoo`06Ool000moo`05001oogooOol00005Ool00`00Oomoo`0jOol00`00Ool0001:
Ool00`00Ool00003Ool01@00Oomoogoo00000goo00<007ooOol00Woo00<007ooOol00goo00<007oo
Ool01goo00@007ooOol004eoo`03001oogoo00Ioo`003goo00<007ooOol01goo00<007ooOol0>Woo
00<007oo0000BWoo00<007oo00000goo00D007ooOomoo`0000=oo`03001oogoo009oo`03001oogoo
00=oo`03001oogoo00Moo`04001oogoo001=Ool00`00Oomoo`06Ool000moo`8004Eoo`03001oo`00
04Yoo`03001oo`0000=oo`05001oogooOol00003Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00
Oomoo`07Ool01000Oomoo`00CGoo00<007ooOol01Woo000?Ool00`00Oomoo`14Ool00`00Ool0001:
Ool00`00Ool00003Ool01@00Oomoogoo00000goo00<007ooOol00Woo00<007ooOol00goo00<007oo
Ool01goo00@007ooOol004eoo`03001oogoo00Ioo`003goo00<007ooOol0A7oo00<007oo0000BWoo
00<007oo00000goo00D007ooOomoo`0000=oo`03001oogoo009oo`03001oogoo00=oo`03001oogoo
00Moo`04001oogoo001=Ool00`00Oomoo`06Ool000Moo`D000=oo`03001oogoo04Aoo`03001oo`00
04Yoo`03001oo`0000=oo`05001oogooOol00003Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00
Oomoo`07Ool01000Oomoo`00CGoo00<007ooOol01Woo0009Ool00`00Oomoo`03Ool00`00Oomoo`14
Ool00`00Ool0001:Ool00`00Ool00003Ool01@00Oomoogoo00000goo00<007ooOol00Woo00<007oo
Ool00goo00<007ooOol01goo00@007ooOol004eoo`03001oogoo00Ioo`002Goo00<007ooOol00goo
0`00A7oo00<007oo0000BWoo00<007oo00000goo00D007ooOomoo`0000=oo`03001oogoo009oo`03
001oogoo00=oo`03001oogoo00Moo`04001oogoo001=Ool00`00Oomoo`06Ool000Uoo`03001oogoo
00=oo`03001oogoo04Aoo`03001oo`0004Yoo`03001oo`0000=oo`05001oogooOol00003Ool00`00
Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`07Ool01000Oomoo`00CGoo00<007ooOol01Woo0009
Ool00`00Oomoo`03Ool00`00Oomoo`14Ool00`00Ool0001:Ool00`00Ool00003Ool01@00Oomoogoo
00000goo00<007ooOol00Woo00<007ooOol00goo00<007ooOol01goo00@007ooOol004eoo`03001o
ogoo00Ioo`0027oo0P001Goo00<007ooOol0A7oo00<007oo0000BWoo00<007oo00000goo00D007oo
Oomoo`0000=oo`03001oogoo009oo`03001oogoo00=oo`03001oogoo00Moo`04001oogoo001=Ool0
0`00Oomoo`06Ool000moo`03001oogoo04Aoo`03001oo`0004Yoo`03001oo`0000=oo`05001oogoo
Ool00003Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`07Ool01000Oomoo`00CGoo00<0
07ooOol01Woo000?Ool20015Ool00`00Ool0001:Ool00`00Ool00003Ool01@00Oomoogoo00000goo
00<007ooOol00Woo00<007ooOol00goo00<007ooOol01goo00@007ooOol004aoo`03001oogoo00Mo
o`003goo00<007ooOol0A7oo00<007oo0000BWoo00<007oo00000goo00D007ooOomoo`0000=oo`03
001oogoo009oo`03001oogoo00=oo`03001oogoo00Moo`04001oogoo001<Ool00`00Oomoo`07Ool0
00moo`03001oogoo04Aoo`03001oo`0004Yoo`03001oo`0000=oo`05001oogooOol00003Ool00`00
Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`07Ool01000Oomoo`00C7oo00<007ooOol01goo000?
Ool00`00Oomoo`14Ool00`00Ool0001:Ool00`00Ool00003Ool01@00Oomoogoo00000goo00<007oo
Ool00Woo00<007ooOol00goo00<007ooOol01goo00@007ooOol004aoo`03001oogoo00Moo`003goo
00<007ooOol0A7oo00<007oo0000BWoo00<007oo00000goo00D007ooOomoo`0000=oo`03001oogoo
009oo`03001oogoo00=oo`03001oogoo00Moo`04001oogoo001<Ool00`00Oomoo`07Ool000moo`80
04Eoo`03001oo`0004Yoo`03001oo`0000=oo`05001oogooOol00003Ool00`00Oomoo`02Ool00`00
Oomoo`03Ool00`00Oomoo`07Ool01000Oomoo`00C7oo00<007ooOol01goo000?Ool00`00Oomoo`14
Ool00`00Ool0001:Ool00`00Ool00003Ool01@00Oomoogoo00000goo00<007ooOol00Woo00<007oo
Ool00goo00<007ooOol01goo00@007ooOol004aoo`03001oogoo00Moo`003goo00<007ooOol0A7oo
00<007oo0000BWoo00<007oo00000goo00D007ooOomoo`0000=oo`03001oogoo009oo`03001oogoo
00=oo`03001oogoo00Moo`04001oogoo001<Ool00`00Oomoo`07Ool000moo`03001oogoo04Aoo`03
001oo`0004Yoo`03001oo`0000=oo`05001oogooOol00003Ool00`00Oomoo`02Ool00`00Oomoo`03
Ool00`00Oomoo`07Ool01000Oomoo`00C7oo00<007ooOol01goo000?Ool00`00Oomoo`14Ool00`00
Ool0001:Ool00`00Ool00003Ool01@00Oomoogoo00000goo00<007ooOol00Woo00<007ooOol00goo
00<007ooOol01goo00@007ooOol004aoo`03001oogoo00Moo`003goo00<007ooOol0A7oo00<007oo
0000Bgoo0P000goo00D007ooOomoo`0000=oo`03001oogoo009oo`03001oogoo00=oo`03001oogoo
00Ioo`06001oogooOol007oo50001Goo2`0027oo0`001goo2@0027oo1@002Goo000?Ool20015Ool0
0`00Ool0001;Ool20003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000Ioo`03001oogoo00Io
o`07001oogooOol007oo00004Woo00<007ooOol00goo00<007ooOol01goo00<007ooOol01Goo00@0
07ooOol000Eoo`8000Qoo`03001oogoo00Ioo`03001oogoo00]oo`003goo00<007ooOol0A7oo00<0
07oo0000Bgoo0P000goo00D007ooOomoo`0000=oo`05001oogooOol00006Ool00`00Oomoo`06Ool0
1000Oomoogoo0P004goo00<007ooOol00goo00<007ooOol027oo00<007ooOol017oo00@007ooOol0
00Eoo`03001oogoo00Qoo`03001oogoo00Aoo`03001oogoo00aoo`003goo00<007ooOol0AGoo00<0
07ooOol0BWoo0P000goo00D007ooOomoo`0000=oo`05001oogooOol00007Ool00`00Oomoo`05Ool0
1000Oomoogoo0P004goo00<007ooOol00goo00<007ooOol027oo00<007ooOol00goo00<007ooOol0
0Woo00<007ooOol00Woo00<007ooOol027oo00<007ooOol017oo00<007ooOol037oo000?Ool00`00
Oomoo`15Ool00`00Oomoo`1:Ool20003Ool01@00Oomoogoo000017oo00@007ooOol000Moo`03001o
ogoo00Eoo`04001oogooOol2000DOol00`00Oomoo`02Ool00`00Oomoo`08Ool00`00Oomoo`03Ool0
0`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`08Ool00`00Oomoo`04Ool00`00Oomoo`0<Ool0
00moo`03001oogoo04Eoo`03001oogoo04Yoo`03001oogoo00=oo`03001oo`0000Eoo`04001oogoo
0007Ool00`00Oomoo`05Ool01@00Oomoogoo00005Goo00D007ooOomoo`0000aoo`03001oogoo009o
o`03001oogoo009oo`03001oogoo009oo`03001oogoo00Uoo`03001oogoo00=oo`03001oogoo00ao
o`003goo0P00AWoo00<007ooOol0BWoo00<007ooOol00goo00<007oo00001Goo00@007ooOol000Mo
o`03001oogoo00Eoo`05001oogooOol0000EOol01@00Oomoogoo000037oo00<007ooOol00Woo00<0
07ooOol00Woo00D007ooOomoo`0000aoo`03001oogoo009oo`03001oogoo00eoo`003goo00<007oo
Ool0AGoo00<007ooOol0BWoo00<007ooOol00goo00<007oo00001Goo00@007ooOol000Moo`03001o
ogoo00Eoo`03001oogoo01Moo`05001oogooOol0000<Ool00`00Oomoo`02Ool00`00Oomoo`02Ool0
1@00Oomoogoo000037oo00<007ooOol00Woo00<007ooOol03Goo000?Ool00`00Oomoo`15Ool00`00
Oomoo`1:Ool00`00Oomoo`03Ool00`00Ool00005Ool01000Oomoo`001goo00<007ooOol01Goo00<0
07ooOol05goo00D007ooOomoo`0000aoo`03001oogoo009oo`03001oogoo009oo`05001oogooOol0
000<Ool00`00Oomoo`02Ool00`00Oomoo`0=Ool000Qoo`<000Aoo`03001oogoo04Eoo`03001oogoo
04Yoo`03001oogoo00=oo`03001oo`0000Eoo`04001oogoo0007Ool00`00Oomoo`05Ool00`00Oomo
o`0GOol01@00Oomoogoo00003Goo00@007ooOol000Ioo`04001oogoo000=Ool01@00Oomoogoo0000
3goo0008Ool00`00Oomoo`04Ool00`00Oomoo`15Ool00`00Oomoo`1:Ool00`00Oomoo`03Ool00`00
Ool00005Ool01000Oomoo`001goo00<007ooOol01Goo00<007ooOol05goo00D007ooOomoo`0000eo
o`04001oogoo0006Ool01000Oomoo`003Goo00D007ooOomoo`0000moo`002Goo00<007ooOol00goo
0`00AGoo00<007ooOol0BWoo00<007ooOol00goo00<007oo00001Goo00@007ooOol000Moo`03001o
ogoo00Eoo`03001oogoo01Moo`05001oogooOol0000=Ool01000Oomoo`001Woo00@007ooOol000eo
o`04001oogoo000@Ool000Uoo`03001oogoo00=oo`03001oogoo04Eoo`03001oogoo04Yoo`03001o
ogoo00=oo`03001oo`0000Eoo`04001oogoo0007Ool00`00Oomoo`05Ool00`00Oomoo`0HOol01000
Oomoo`003Goo00@007ooOol000Ioo`04001oogoo000=Ool01000Oomoo`0047oo0008Ool00`00Ool0
0004Ool00`00Oomoo`15Ool00`00Oomoo`1:Ool00`00Oomoo`03Ool00`00Ool00005Ool01000Oomo
o`001goo00<007ooOol01Goo00<007ooOol067oo00@007ooOol000ioo`03001oo`0000Ioo`04001o
ogoo000>Ool00`00Ool0000@Ool000Uoo`03001oogoo00=oo`03001oogoo04Eoo`03001oogoo04Yo
o`03001oogoo00=oo`03001oo`0000Eoo`04001oogoo0007Ool00`00Oomoo`05Ool00`00Oomoo`0H
Ool01000Oomoo`003Woo00<007oo00001Woo00@007ooOol000ioo`03001oo`00011oo`003goo00<0
07ooOol0AGoo00<007ooOol0BWoo00<007ooOol00goo00<007oo00001Goo00@007ooOol000Moo`03
001oogoo00Eoo`03001oogoo01Qoo`03001oo`0000moo`03001oo`0000Moo`03001oo`0000ioo`03
001oo`00011oo`003goo0P00AWoo00<007ooOol0BWoo00<007ooOol00goo00<007oo00001Goo00@0
07ooOol000Moo`03001oogoo00Eoo`03001oogoo01Uoo`8000moo`03001oo`0000Moo`8000moo`03
001oo`00011oo`003goo00<007ooOol0AGoo00<007ooOol0BWoo00<007ooOol00goo00<007oo0000
1Goo00@007ooOol000Moo`03001oogoo00Eoo`03001oogoo01Uoo`8000moo`8000Qoo`8000moo`80
015oo`003goo00<007ooOol0AGoo00<007ooOol0BWoo00<007ooOol00goo00<007oo00001Goo00@0
07ooOol000Moo`03001oogoo00Eoo`03001oogoo01Yoo`03001oogoo00eoo`8000Qoo`80011oo`03
001oogoo00moo`003goo00<007ooOol0AGoo00<007ooOol0BWoo00<007ooOol00goo00<007oo0000
1Goo00@007ooOol000Moo`03001oogoo00Eoo`03001oogoo01Yoo`03001oogoo00ioo`03001oogoo
00Moo`03001oogoo00ioo`03001oogoo00moo`003goo00<007ooOol0AGoo00<007ooOol0BWoo00<0
07ooOol00goo00<007oo00001Goo00@007ooOol000Moo`03001oogoo00Eoo`03001oogoo02]oo`03
001oogoo00Moo`03001oogoo00ioo`03001oogoo00moo`003goo00<007ooOol0AGoo00<007ooOol0
BWoo00<007ooOol00goo00<007oo00001Goo00@007ooOol000Moo`03001oogoo00Eoo`03001oogoo
02]oo`03001oogoo00Moo`03001oogoo021oo`003goo0P00AWoo00<007ooOol0BWoo00<007ooOol0
0goo00<007oo00001Goo00@007ooOol000Moo`03001oogoo00Eoo`03001oogoo05Qoo`003goo00<0
07ooOol0AGoo00<007ooOol0BWoo00<007ooOol00goo00<007oo00001Goo00@007ooOol000Moo`03
001oogoo00Eoo`03001oogoo05Qoo`003goo00<007ooOol0AGoo00<007ooOol0BWoo00<007ooOol0
0goo00<007oo00001Goo00@007ooOol000Moo`03001oogoo00Eoo`03001oogoo05Qoo`003goo00<0
07ooOol0AGoo00<007ooOol0BWoo00<007ooOol00goo00<007oo00001Goo00@007ooOol000Moo`03
001oogoo00Eoo`03001oogoo05Qoo`003goo00<007ooOol0AGoo00<007ooOol0BWoo00<007ooOol0
0goo00<007oo00001Goo00@007ooOol000Moo`03001oogoo00Eoo`03001oogoo05Qoo`003goo0P00
AWoo00<007ooOol0BWoo00<007ooOol00goo00<007oo00001Goo00@007ooOol000Moo`03001oogoo
00Eoo`03001oogoo05Qoo`003goo00<007ooOol0AGoo00<007ooOol0BWoo00<007ooOol00goo00<0
07oo00001Goo00@007ooOol000Moo`03001oogoo00Eoo`03001oogoo05Qoo`003goo00<007ooOol0
AGoo00<007ooOol0BWoo00<007ooOol00goo00<007oo00001Goo00@007ooOol000Moo`03001oogoo
00Eoo`03001oogoo05Qoo`003goo00<007ooOol0AGoo00<007ooOol0BWoo00<007ooOol00goo00<0
07oo00001Goo00@007ooOol000Moo`03001oogoo00Eoo`03001oogoo05Qoo`003goo00<007ooOol0
AGoo00<007ooOol0BWoo00<007ooOol00goo00<007oo00001Goo00@007ooOol000Moo`03001oogoo
00Eoo`03001oogoo05Qoo`003goo0P00AWoo00<007ooOol0BWoo00<007ooOol00goo00<007oo0000
1Goo00@007ooOol000Moo`03001oogoo00Eoo`03001oogoo05Qoo`003goo00<007ooOol0AGoo00<0
07ooOol0BWoo00<007ooOol00goo00<007oo00001Goo00@007ooOol000Moo`03001oogoo00Eoo`03
001oogoo05Qoo`003goo00<007ooOol0AGoo00<007ooOol0BWoo00<007ooOol00goo00<007oo0000
1Goo00@007ooOol000Moo`03001oogoo00Eoo`03001oogoo05Qoo`0027oo0P001Goo00<007ooOol0
AGoo00<007ooOol0BWoo00<007ooOol00goo00<007oo00001Goo00@007ooOol000Moo`03001oogoo
00Eoo`03001oogoo05Qoo`002Woo00<007ooOol00Woo00<007ooOol0AGoo00<007ooOol0BWoo00<0
07ooOol00goo00<007oo00001Goo00@007ooOol000Moo`03001oogoo00Eoo`03001oogoo05Qoo`00
2Goo00<007ooOol00goo0`00AGoo00<007ooOol0BWoo00<007ooOol00goo00<007oo00001Goo00@0
07ooOol000Moo`03001oogoo00Eoo`03001oogoo05Qoo`002Woo00<007ooOol00Woo00<007ooOol0
AGoo00<007ooOol0BWoo00<007ooOol00goo00<007oo00001Goo00@007ooOol000Moo`03001oogoo
00Eoo`03001oogoo05Qoo`0027oo00<007oo000017oo00<007ooOol0AGoo00<007ooOol0BWoo00<0
07ooOol00goo00<007oo00001Goo00@007ooOol000Moo`03001oogoo00Eoo`03001oogoo05Qoo`00
2Goo00<007ooOol00goo00<007ooOol0AGoo00<007ooOol0BWoo00<007ooOol00goo00<007oo0000
1Goo00@007ooOol000Moo`03001oogoo00Eoo`03001oogoo05Qoo`003goo00<007ooOol0AGoo00<0
07ooOol0BWoo00<007ooOol00goo0`001Goo10001goo2@00FWoo000?Ool2003oOol@Ool000moo`03
001oogoo0?moo`moo`003goo00<007ooOol0ogoo3goo000?Ool00`00Oomoo`3oOol?Ool00?moob5o
o`00ogoo8Goo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-7.47905, -3.39117, 
  0.483204, 0.0383541}}]
}, Open  ]],

Cell["This calculates the first-order approximation of curvature.", "Text"],

Cell[BoxData[{
    \(curvature[{a_, b_}] := 
      b - a\  /; \ Abs[b - a]\  \[LessEqual] \ \[Pi]\), 
    \(curvature[{a_, b_}] := With[{d = b - a}, d - 2\ Sign[d]\ \[Pi]]\)}], 
  "Input",
  CellLabel->"In[126]:="],

Cell[BoxData[
    \(\(d2y = curvature\ /@\ Partition[Join[dy, {Last[dy]}], 2, 1]; \)\)], 
  "Input",
  CellLabel->"In[129]:="],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(ListPlot[d2y, PlotJoined \[Rule] True, PlotRange \[Rule] All]; \)\)], 
  "Input",
  CellLabel->"In[130]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0163105 0.00749906 0.328162 0.199547 [
[.16629 .31566 -6 -9 ]
[.16629 .31566 6 0 ]
[.31627 .31566 -6 -9 ]
[.31627 .31566 6 0 ]
[.46625 .31566 -6 -9 ]
[.46625 .31566 6 0 ]
[.61624 .31566 -6 -9 ]
[.61624 .31566 6 0 ]
[.76622 .31566 -9 -9 ]
[.76622 .31566 9 0 ]
[.9162 .31566 -9 -9 ]
[.9162 .31566 9 0 ]
[.00381 .02884 -24 -4.5 ]
[.00381 .02884 0 4.5 ]
[.00381 .12862 -12 -4.5 ]
[.00381 .12862 0 4.5 ]
[.00381 .22839 -24 -4.5 ]
[.00381 .22839 0 4.5 ]
[.00381 .42794 -18 -4.5 ]
[.00381 .42794 0 4.5 ]
[.00381 .52771 -6 -4.5 ]
[.00381 .52771 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.16629 .32816 m
.16629 .33441 L
s
[(20)] .16629 .31566 0 1 Mshowa
.31627 .32816 m
.31627 .33441 L
s
[(40)] .31627 .31566 0 1 Mshowa
.46625 .32816 m
.46625 .33441 L
s
[(60)] .46625 .31566 0 1 Mshowa
.61624 .32816 m
.61624 .33441 L
s
[(80)] .61624 .31566 0 1 Mshowa
.76622 .32816 m
.76622 .33441 L
s
[(100)] .76622 .31566 0 1 Mshowa
.9162 .32816 m
.9162 .33441 L
s
[(120)] .9162 .31566 0 1 Mshowa
.125 Mabswid
.05381 .32816 m
.05381 .33191 L
s
.0913 .32816 m
.0913 .33191 L
s
.1288 .32816 m
.1288 .33191 L
s
.20379 .32816 m
.20379 .33191 L
s
.24128 .32816 m
.24128 .33191 L
s
.27878 .32816 m
.27878 .33191 L
s
.35377 .32816 m
.35377 .33191 L
s
.39126 .32816 m
.39126 .33191 L
s
.42876 .32816 m
.42876 .33191 L
s
.50375 .32816 m
.50375 .33191 L
s
.54124 .32816 m
.54124 .33191 L
s
.57874 .32816 m
.57874 .33191 L
s
.65373 .32816 m
.65373 .33191 L
s
.69123 .32816 m
.69123 .33191 L
s
.72872 .32816 m
.72872 .33191 L
s
.80371 .32816 m
.80371 .33191 L
s
.84121 .32816 m
.84121 .33191 L
s
.8787 .32816 m
.8787 .33191 L
s
.95369 .32816 m
.95369 .33191 L
s
.99119 .32816 m
.99119 .33191 L
s
.25 Mabswid
0 .32816 m
1 .32816 L
s
.01631 .02884 m
.02256 .02884 L
s
[(-1.5)] .00381 .02884 1 0 Mshowa
.01631 .12862 m
.02256 .12862 L
s
[(-1)] .00381 .12862 1 0 Mshowa
.01631 .22839 m
.02256 .22839 L
s
[(-0.5)] .00381 .22839 1 0 Mshowa
.01631 .42794 m
.02256 .42794 L
s
[(0.5)] .00381 .42794 1 0 Mshowa
.01631 .52771 m
.02256 .52771 L
s
[(1)] .00381 .52771 1 0 Mshowa
.125 Mabswid
.01631 .0488 m
.02006 .0488 L
s
.01631 .06875 m
.02006 .06875 L
s
.01631 .08871 m
.02006 .08871 L
s
.01631 .10866 m
.02006 .10866 L
s
.01631 .14857 m
.02006 .14857 L
s
.01631 .16852 m
.02006 .16852 L
s
.01631 .18848 m
.02006 .18848 L
s
.01631 .20843 m
.02006 .20843 L
s
.01631 .24834 m
.02006 .24834 L
s
.01631 .2683 m
.02006 .2683 L
s
.01631 .28825 m
.02006 .28825 L
s
.01631 .30821 m
.02006 .30821 L
s
.01631 .34812 m
.02006 .34812 L
s
.01631 .36807 m
.02006 .36807 L
s
.01631 .38803 m
.02006 .38803 L
s
.01631 .40798 m
.02006 .40798 L
s
.01631 .44789 m
.02006 .44789 L
s
.01631 .46784 m
.02006 .46784 L
s
.01631 .4878 m
.02006 .4878 L
s
.01631 .50775 m
.02006 .50775 L
s
.01631 .00889 m
.02006 .00889 L
s
.01631 .54766 m
.02006 .54766 L
s
.01631 .56762 m
.02006 .56762 L
s
.01631 .58757 m
.02006 .58757 L
s
.01631 .60753 m
.02006 .60753 L
s
.25 Mabswid
.01631 0 m
.01631 .61803 L
s
.5 Mabswid
.02381 .47701 m
.03131 .30068 L
.03881 .25023 L
.04631 .44443 L
.05381 .23873 L
.0613 .26064 L
.0688 .32816 L
.0763 .32816 L
.0838 .32816 L
.0913 .32816 L
.0988 .33021 L
.1063 .17259 L
.1138 .37344 L
.1213 .43641 L
.1288 .29679 L
.1363 .20195 L
.14379 .32903 L
.15129 .32816 L
.15879 .32816 L
.16629 .26645 L
.17379 .30375 L
.18129 .4148 L
.18879 .20772 L
.19629 .29137 L
.20379 .32816 L
.21129 .24157 L
.21879 .25662 L
.22628 .4701 L
.23378 .08301 L
.24128 .39421 L
.24878 .36675 L
.25628 .32816 L
.26378 .25573 L
.27128 .24387 L
.27878 .41613 L
.28628 .60332 L
.29378 .59251 L
.30127 .32759 L
.30877 .33055 L
.31627 .1826 L
.32377 .34942 L
.33127 .45008 L
.33877 .31696 L
.34627 .18131 L
.35377 .3295 L
.36127 .32699 L
.36877 .47971 L
.37627 .19492 L
.38376 .31102 L
.39126 .32816 L
Mistroke
.39876 .32816 L
.40626 .32816 L
.41376 .32816 L
.42126 .24928 L
.42876 .33863 L
.43626 .39799 L
.44376 .18454 L
.45126 .31365 L
.45876 .32816 L
.46625 .32816 L
.47375 .24329 L
.48125 .25491 L
.48875 .46759 L
.49625 .21504 L
.50375 .27935 L
.51125 .21239 L
.51875 .46925 L
.52625 .32675 L
.53375 .32876 L
.54124 .17381 L
.54874 .32519 L
.55624 .45646 L
.56374 .33662 L
.57124 .19028 L
.57874 .32724 L
.58624 .48374 L
.59374 .28288 L
.60124 .21991 L
.60874 .32816 L
.61624 .33624 L
.62373 .47798 L
.63123 .26418 L
.63873 .23426 L
.64623 .32816 L
.65373 .32816 L
.66123 .32816 L
.66873 .32816 L
.67623 .32896 L
.68373 .06122 L
.69123 .28086 L
.69873 .32816 L
.70622 .32816 L
.71372 .32816 L
.72122 .32816 L
.72872 .32816 L
.73622 .32816 L
.74372 .32816 L
.75122 .32816 L
.75872 .32816 L
.76622 .4434 L
Mistroke
.77372 .36174 L
.78121 .1765 L
.78871 .33101 L
.79621 .32816 L
.80371 .32816 L
.81121 .32816 L
.81871 .32816 L
.82621 .40421 L
.83371 .40979 L
.84121 .20032 L
.84871 .29832 L
.85621 .32816 L
.8637 .41985 L
.8712 .39451 L
.8787 .18069 L
.8862 .3176 L
.8937 .32816 L
.9012 .32816 L
.9087 .32816 L
.9162 .32816 L
.9237 .3759 L
.9312 .43715 L
.9387 .23271 L
.94619 .26689 L
.95369 .32816 L
.96119 .32816 L
.96869 .01472 L
.97619 .32816 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[130]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`006goo00<007ooOol0ogoo0goo000KOol0
0`00Oomoo`3oOol3Ool001]oo`03001oogoo0?moo`=oo`006goo0P00ogoo17oo000KOol00`00Oomo
o`3hOol00`00Oomoo`07Ool001]oo`03001oogoo0?Qoo`03001oogoo00Moo`002Goo1@000Woo00<0
07ooOol00Woo00<007ooOol00goo00<007ooOol0n7oo00<007ooOol01goo000;Ool00`00Oomoo`06
Ool00`00Ool00004Ool00`00Oomoo`3hOol00`00Oomoo`07Ool000Eoo`<000=oo`03001oogoo00Qo
o`03001oogoo009oo`800?Uoo`03001oogoo00Moo`002goo00<007ooOol01Woo0P001Goo00<007oo
Ool0n7oo00<007ooOol01goo000;Ool00`00Oomoo`06Ool00`00Oomoo`04Ool00`00Oomoo`3hOol0
0`00Oomoo`07Ool000Yoo`8000Qoo`<000Aoo`03001oogoo0?Qoo`03001oogoo00Moo`006goo00<0
07ooOol0n7oo00<007ooOol01goo000KOol2003iOol00`00Oomoo`07Ool001]oo`03001oogoo0?Qo
o`03001oogoo00Moo`006goo00<007ooOol0n7oo00<007ooOol01goo000KOol00`00Oomoo`3hOol0
0`00Oomoo`07Ool001]oo`03001oogoo0:eoo`03001oogoo04Qoo`03001oogoo00Moo`006goo00<0
07ooOol0[Goo00<007ooOol0B7oo00<007ooOol01goo000KOol2002^Ool00`00Oomoo`18Ool00`00
Oomoo`07Ool001]oo`03001oogoo0:eoo`03001oogoo04Qoo`03001oogoo00Moo`006goo00<007oo
Ool0[Goo00<007ooOol0B7oo00<007ooOol01goo000KOol00`00Oomoo`0fOol00`00Oomoo`1dOol0
0`00Oomoo`18Ool00`00Oomoo`07Ool001]oo`03001oogoo03Ioo`03001oogoo07Aoo`03001oogoo
04Qoo`03001oogoo00Moo`006goo0P00=goo00<007ooOol0M7oo00<007ooOol0B7oo00<007ooOol0
1goo000KOol00`00Oomoo`0fOol00`00Oomoo`1dOol00`00Oomoo`17Ool00`00Ool00008Ool001]o
o`03001oogoo03Ioo`03001oogoo07Aoo`03001oogoo04Moo`03001oo`0000Qoo`006goo00<007oo
Ool0=Woo00<007ooOol0M7oo00<007ooOol0Agoo00<007oo000027oo000KOol00`00Oomoo`0fOol0
0`00Oomoo`1dOol00`00Oomoo`17Ool00`00Ool00008Ool001]oo`8003Moo`03001oogoo07Aoo`03
001oogoo04Moo`03001oo`0000Qoo`006goo00<007ooOol0=Woo00<007ooOol0M7oo00<007ooOol0
Agoo00<007oo000027oo000KOol00`00Oomoo`0fOol00`00Oomoo`1dOol00`00Oomoo`17Ool00`00
Ool00008Ool001=oo`D000=oo`03001oogoo03Ioo`03001oogoo07Aoo`8004Qoo`03001oo`0000Qo
o`005Goo00<007ooOol00goo00<007ooOol0=Woo00<007ooOol0M7oo0P00B7oo00<007oo000027oo
000?Ool30003Ool00`00Oomoo`03Ool2000gOol00`00Oomoo`1dOol20018Ool00`00Ool00008Ool0
01Eoo`03001oogoo00=oo`03001oogoo03Ioo`03001oogoo07=oo`03001oo`0004Qoo`03001oo`00
00Qoo`005Goo00<007ooOol00goo00<007ooOol0=Woo00<007ooOol0Lgoo00<007oo0000B7oo00<0
07oo000027oo000DOol20005Ool00`00Oomoo`0fOol00`00Oomoo`1cOol00`00Ool00018Ool00`00
Ool00008Ool001]oo`03001oogoo03Ioo`03001oogoo07=oo`03001oo`0004Qoo`03001oo`0000Qo
o`006goo00<007ooOol0=Woo00<007ooOol0Lgoo00<007oo0000B7oo00<007oo000027oo000KOol2
000gOol00`00Oomoo`1cOol00`00Ool00018Ool00`00Ool00008Ool001]oo`03001oogoo03Ioo`03
001oogoo07=oo`03001oo`0004Qoo`03001oo`0000Qoo`006goo00<007ooOol0=Woo00<007ooOol0
Lgoo00<007oo0000B7oo00<007oo000027oo000KOol00`00Oomoo`0fOol2001dOol00`00Ool00018
Ool00`00Ool00008Ool001]oo`03001oogoo03Ioo`8007Aoo`03001oo`0004Qoo`03001oo`0000Qo
o`006goo0P00=goo0P00M7oo00<007oo0000B7oo00<007oo000027oo000KOol00`00Oomoo`0EOol0
0`00Oomoo`0NOol2001?Ool00`00Oomoo`0ROol00`00Ool00018Ool00`00Ool00008Ool001]oo`03
001oogoo01Eoo`03001oogoo01ioo`8004moo`03001oogoo029oo`03001oo`0001Qoo`03001oogoo
02eoo`03001oo`0000Qoo`006goo00<007ooOol05Goo00<007ooOol07Goo00<007oo000077oo00<0
07ooOol0<7oo00<007ooOol08Woo00<007oo000067oo00<007ooOol05Woo00<007ooOol057oo00<0
07oo000027oo000KOol00`00Oomoo`0EOol00`00Oomoo`0MOol00`00Ool0000DOol00`00Oomoo`05
Ool00`00Oomoo`0GOol00`00Oomoo`0FOol00`00Oomoo`0ROol00`00Ool0000HOol00`00Oomoo`0F
Ool00`00Oomoo`0DOol00`00Ool00008Ool001]oo`8001Ioo`03001oogoo01eoo`03001oo`0001Ao
o`03001oogoo00Eoo`03001oogoo01Moo`03001oogoo01Ioo`03001oogoo029oo`03001oo`0001Qo
o`03001oogoo01Ioo`03001oogoo01Aoo`03001oo`0000Qoo`006goo00<007ooOol05Goo00<007oo
Ool07Goo00<007oo000057oo00<007ooOol01Goo00<007ooOol05goo00<007ooOol05Woo00<007oo
Ool01Goo00<007ooOol06Woo00<007oo000067oo00<007ooOol05Woo00<007ooOol057oo00<007oo
000027oo000KOol00`00Oomoo`0EOol00`00Oomoo`0MOol00`00Ool0000DOol00`00Oomoo`05Ool0
0`00Oomoo`05Ool00`00Oomoo`0?Ool00`00Oomoo`0FOol00`00Oomoo`05Ool00`00Oomoo`0JOol0
0`00Ool0000HOol00`00Oomoo`0FOol00`00Oomoo`0DOol00`00Ool00008Ool001]oo`03001oogoo
01Eoo`03001oogoo01eoo`03001oo`0001Aoo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo
00moo`03001oogoo01Ioo`03001oogoo00Eoo`03001oogoo01Yoo`03001oo`0001Qoo`03001oogoo
00eoo`03001oogoo00Ioo`03001oogoo01Aoo`03001oo`0000Qoo`006goo00<007ooOol05Goo00<0
07ooOol017oo00<007ooOol05Woo00<007oo000057oo00<007ooOol01Goo00<007ooOol01Goo00<0
07ooOol03goo00<007ooOol05Woo00<007ooOol01Goo00<007ooOol06Woo00<007oo000067oo00<0
07ooOol03Goo00<007ooOol01Woo00<007ooOol057oo00<007oo000027oo000KOol2000FOol00`00
Oomoo`04Ool00`00Oomoo`0;Ool00`00Oomoo`08Ool00`00Ool0000DOol00`00Oomoo`05Ool00`00
Oomoo`05Ool00`00Oomoo`0?Ool00`00Oomoo`0FOol00`00Oomoo`05Ool00`00Oomoo`0JOol00`00
Ool0000HOol00`00Oomoo`0=Ool00`00Oomoo`06Ool00`00Oomoo`0DOol00`00Ool00008Ool001]o
o`03001oogoo01Eoo`03001oogoo00Aoo`03001oogoo00]oo`03001oogoo00Qoo`03001oo`0001Ao
o`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00moo`03001oogoo01Ioo`8000Ioo`03001o
ogoo01Yoo`03001oo`0001Qoo`03001oogoo00eoo`03001oogoo00Ioo`03001oogoo01Aoo`03001o
o`0000Qoo`006goo00<007ooOol057oo0P001Woo00<007ooOol02goo00<007ooOol027oo00<007oo
000057oo00<007ooOol017oo0P001goo00<007ooOol03goo00<007ooOol02goo00@007ooOol000Io
o`03001oo`0000Ioo`03001oogoo01Yoo`03001oo`0001Qoo`03001oogoo00eoo`03001oogoo00Io
o`8001Eoo`03001oo`0000Qoo`006goo00<007ooOol057oo0P001Woo00<007ooOol02goo00<007oo
Ool027oo00<007oo000057oo00<007ooOol017oo00<007oo00001Woo00<007ooOol03goo0P0037oo
00@007ooOol000Ioo`03001oo`0000Ioo`03001oogoo01Yoo`03001oo`0001Qoo`8000ioo`03001o
ogoo00Ioo`8001Eoo`03001oo`0000Qoo`002goo00<007ooOol00Woo00<007ooOol00Woo00<007oo
Ool00goo00<007ooOol057oo0P001Woo00<007ooOol02goo00<007ooOol027oo00<007oo00004goo
0P001Woo00<007oo00001Woo00<007ooOol03goo0P0037oo00@007ooOol000Ioo`03001oo`0000Io
o`03001oogoo00Eoo`03001oogoo019oo`03001oo`0001Qoo`8000ioo`03001oogoo00Ioo`8001Eo
o`03001oo`0000Qoo`002Woo00<007oo00001goo00<007oo000017oo00<007ooOol057oo00<007oo
00001Goo00<007ooOol02goo00<007ooOol027oo00<007oo00004goo00<007oo00001Goo00<007oo
00001Woo0P0047oo0P0037oo00@007ooOol000Ioo`03001oo`0000Ioo`8000Ioo`03001oogoo019o
o`03001oo`0001Moo`03001oo`0000ioo`8000Moo`8001Eoo`03001oo`0000Qoo`001Goo0`000Woo
00<007oo00002Goo00<007ooOol00Woo0P005Goo00<007oo00001Goo00<007ooOol02goo0P002Goo
00<007oo00004goo00<007oo00001Goo00<007oo00001Woo0P0047oo0P0037oo00@007ooOol000Io
o`03001oo`0000Eoo`03001oo`0000Ioo`03001oogoo019oo`04001oogoo000FOol00`00Ool0000>
Ool20007Ool2000EOol00`00Ool00008Ool000Yoo`03001oo`0000Moo`8000Eoo`03001oogoo01Ao
o`03001oo`0000Eoo`03001oogoo00]oo`8000Uoo`03001oo`0001=oo`03001oo`0000Eoo`03001o
o`0000Ioo`80011oo`8000aoo`04001oo`000006Ool00`00Ool00005Ool00`00Ool00006Ool00`00
Oomoo`07Ool00`00Oomoo`08Ool01000Oomoo`005Woo00<007oo00003Woo0P001goo0P003Woo00<0
07ooOol017oo00<007oo000027oo000:Ool00`00Ool00007Ool00`00Oomoo`04Ool00`00Oomoo`07
Ool00`00Oomoo`0:Ool00`00Ool00005Ool2000<Ool20009Ool00`00Ool0000COol00`00Ool00005
Ool00`00Ool00006Ool2000@Ool2000<Ool01000Ool000001Woo00<007oo00001Goo00<007oo0000
1Goo0P002Goo00<007ooOol027oo00@007ooOol001Ioo`03001oo`0000ioo`8000Ioo`03001oo`00
00ioo`03001oogoo00Aoo`03001oo`0000Qoo`002goo00<007ooOol01Woo0`0017oo00<007ooOol0
1goo00<007ooOol02Woo00<007oo00001Goo0P0037oo0P0017oo00<007ooOol00Woo00<007oo0000
4goo00<007oo00001Goo00<007oo00001Woo0P003goo00<007oo000037oo00@007oo000000Ioo`03
001oo`0000Eoo`03001oo`0000Eoo`8000Qoo`8000Yoo`04001oogoo000FOol00`00Ool0000>Ool2
0006Ool00`00Ool0000>Ool00`00Oomoo`04Ool00`00Ool00008Ool001]oo`03001oogoo00Moo`80
00]oo`03001oo`0000Eoo`8000aoo`8000Aoo`8000=oo`03001oo`0000Qoo`03001oogoo00Qoo`03
001oo`0000Eoo`03001oo`0000Ioo`8000moo`03001oo`0000Ioo`03001oogoo00=oo`04001oo`00
0006Ool00`00Ool00005Ool00`00Ool00005Ool20008Ool2000:Ool01000Oomoo`005Woo00<007oo
00003Woo0P001Woo00<007oo00003Woo0P001Goo00<007oo000027oo000KOol20008Ool2000;Ool0
0`00Ool00005Ool2000<Ool20004Ool20003Ool00`00Ool00007Ool2000:Ool00`00Ool00005Ool0
0`00Ool00006Ool2000:Ool00`00Oomoo`02Ool00`00Ool00006Ool20004Ool40006Ool00`00Ool0
0005Ool00`00Ool00005Ool00`00Ool00007Ool2000:Ool01000Oomoo`005Woo00<007oo00003Woo
0P001Woo00<007oo00003Woo0P001Goo00<007oo000027oo000KOol00`00Oomoo`03Ool01000Oomo
ogoo0P002goo00<007oo000017oo00<007oo000037oo0P0017oo00<007oo00000Woo00<007oo0000
1goo0P002Woo00<007oo00001Goo00<007oo00001Woo0P002Woo00<007ooOol00Woo00<007oo0000
1Woo0P0017oo10001Woo00<007oo00001Goo00<007oo00001Goo00<007oo00001goo0P002Woo00@0
07ooOol001Ioo`03001oo`0000eoo`03001oo`0000Ioo`03001oo`0000ioo`8000Aoo`05001oogoo
Ool00007Ool001]oo`03001oogoo00=oo`07001oogooOol007oo00002Woo00<007oo000017oo00<0
07oo000037oo0P0017oo00<007oo00000Woo00<007oo00001Woo00<007oo00002Woo00<007oo0000
1Goo00<007oo00001Woo0P002Woo00<007ooOol00Woo00<007oo00001Woo00<007oo00000goo1000
1Woo00<007oo00001Goo00<007oo00001Goo00<007oo00001Woo00<007oo00002Woo00@007ooOol0
01Ioo`03001oo`0000eoo`03001oo`0000Ioo`03001oo`0000ioo`8000Aoo`05001oogooOol00007
Ool001]oo`03001oogoo00=oo`07001oogooOol007oo00002Woo00<007oo000017oo00<007oo0000
2goo00<007oo000017oo00<007oo00000Woo00<007oo00001Woo00<007oo00002Woo00<007oo0000
1Goo00<007oo00001Woo0P002Woo00<007ooOol00Woo00<007oo00001Woo00<007oo00000goo1000
1Woo00<007oo00001Goo00<007oo00001Goo00<007oo00001Woo00@007ooOol000Uoo`04001oogoo
000FOol00`00Ool0000=Ool00`00Ool00006Ool00`00Ool0000>Ool00`00Ool00003Ool01@00Oomo
ogoo00001goo000KOol00`00Oomoo`03Ool01`00Oomoogoo001oo`0000Yoo`03001oo`0000Aoo`03
001oo`0000]oo`03001oo`0000=oo`04001oogoo0002Ool00`00Ool00006Ool00`00Ool0000:Ool0
0`00Ool00005Ool00`00Ool00006Ool2000:Ool00`00Oomoo`02Ool00`00Ool00006Ool00`00Ool0
0003Ool200000goo001oo`05Ool00`00Ool00005Ool00`00Ool00005Ool00`00Ool00006Ool01000
Oomoo`0027oo00D007ooOomoo`0001Ioo`03001oo`0000eoo`03001oo`0000Ioo`03001oo`0000io
o`03001oo`0000=oo`05001oogooOol00007Ool001]oo`8000=oo`8000=oo`03001oo`0000Yoo`03
001oo`0000Aoo`03001oo`0000Ioo`03001oogoo009oo`03001oo`0000=oo`04001oogoo0002Ool0
0`00Ool00006Ool00`00Ool0000:Ool00`00Ool00005Ool00`00Ool00005Ool00`00Ool0000:Ool0
0`00Oomoo`02Ool00`00Ool00005Ool01000Oomoo`000goo0P0000=oo`00Ool01Goo00<007oo0000
1Goo00<007oo000017oo00@007ooOol000Ioo`04001oogoo0008Ool01@00Oomoogoo00005Woo00<0
07oo00003Goo00<007oo00001Woo00<007oo00003Woo00<007oo00000goo00D007ooOomoo`0000Mo
o`006goo00<007ooOol00Woo0P000goo00<007oo00002Woo00<007oo000017oo00<007oo00001Woo
00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0002Ool00`00Ool00006Ool00`00Ool0000:
Ool00`00Ool00005Ool00`00Ool00005Ool00`00Ool00009Ool00`00Ool00003Ool00`00Ool00005
Ool01000Oomoo`000goo0P0000=oo`00Ool01Goo00<007oo00001Goo00<007oo000017oo00@007oo
Ool000Ioo`04001oogoo0008Ool01@00Oomoogoo00005Woo00<007oo00003Goo00<007oo00001Woo
00<007oo00003Woo00<007oo00000goo00D007ooOomoo`0000Moo`006goo00<007ooOol00Woo0P00
0goo00<007oo00002Woo00<007oo000017oo00<007oo00001Woo00<007ooOol00Woo00@007ooOol0
009oo`04001oogoo0002Ool00`00Ool00005Ool01000Oomoo`002Woo00<007oo00001Goo00<007oo
00001Goo00<007oo00002Goo00<007oo00000goo00<007oo00001Goo00@007ooOol000=oo`800003
Ool007oo00Eoo`03001oo`0000Eoo`03001oo`0000Aoo`04001oogoo0006Ool01000Oomoo`0027oo
00D007ooOomoo`0001Ioo`03001oo`0000eoo`04001oogoo0005Ool00`00Ool0000>Ool00`00Ool0
0003Ool01@00Oomoogoo00001goo000KOol00`00Oomoo`02Ool20003Ool01000Oomoo`002Goo00<0
07oo000017oo00<007oo00001Woo0P000goo00@007ooOol0009oo`04001oogoo0002Ool00`00Ool0
0005Ool01000Oomoo`002Woo00<007oo00001Goo00<007oo00001Goo00<007oo00002Goo00<007oo
00000goo00<007oo00001Goo00@007ooOol0009oo`03001oo`00009oo`03001oogoo00=oo`03001o
o`0000Eoo`03001oo`0000Aoo`04001oogoo0006Ool01000Oomoo`0027oo00D007ooOomoo`0001Io
o`03001oo`0000eoo`04001oogoo0005Ool00`00Ool0000>Ool00`00Ool00003Ool01@00Oomoogoo
00001goo000KOol00`00Oomoo`02Ool20003Ool01000Oomoo`002Goo00<007oo000017oo00<007oo
00001Goo00<007oo00000goo00@007ooOol0009oo`04001oogoo0002Ool00`00Ool00005Ool01000
Oomoo`002Woo00<007oo000017oo00@007ooOol000Eoo`03001oo`0000Uoo`03001oo`0000=oo`04
001oogoo0004Ool01000Oomoo`000Woo00<007ooOol00Woo00<007ooOol00goo00<007oo00001Goo
00<007oo000017oo00@007ooOol000Ioo`04001oogoo0008Ool01@00Oomoogoo00005Woo00<007oo
00003Goo00@007ooOol000Eoo`04001oogoo000=Ool01000Oomoo`000Woo00D007ooOomoo`0000Mo
o`006goo00<007ooOol00Woo0P000goo00@007ooOol000Uoo`03001oo`0000Aoo`03001oo`00009o
o`@00003Ool00000009oo`04001oogoo0002Ool01000Oomoo`000Woo00<007oo00001Goo00@007oo
Ool000Qoo`<00003Ool0000000=oo`04001oogoo0005Ool01000Oomoo`0027oo00<007oo00000goo
00<007ooOol00P000goo0P0000Eoo`00Oomoo`0000Aoo`03001oogoo00=oo`04001oogoo0004Ool0
0`00Ool00004Ool01000Oomoo`0017oo00<007oo00000Woo00<007ooOol01Woo00D007ooOomoo`00
00]oo`D0009oo`04001oogooOol3000=Ool01000Oomoo`001Goo00<007ooOol01P0000Aoo`000000
00=oo`05001oogooOol00002Ool01@00Oomoogoo00001goo000KOol20002Ool00`00Ool00002Ool0
1@00Oomoogoo00002Goo00<007oo000017oo00<007oo00000Woo00X007ooOol007oo001oo`00Ool0
009oo`04001oogoo0002Ool01P00Oomoo`00Ool000Eoo`05001oogooOol00008Ool2000017oo001o
o`000Woo00@007ooOol000Eoo`04001oogoo0008Ool00`00Ool00003Ool01P00Oomoo`00Ool0009o
o`04001oo`000002Ool00`00Oomoo`02Ool00`00Oomoo`02Ool01@00Oomoogoo000017oo00<007oo
000017oo00<007oo00000P000Woo00@007oo0000009oo`03001oogoo00Ioo`05001oogooOol0000=
Ool01`00Oomoogoo001oo`00009oo`03001oo`0000eoo`04001oogoo0005Ool01000Oomoo`000Woo
00D007ooOomoo`0000Aoo`<0009oo`04001oogoo0003Ool00`00Oomoo`05Ool001]oo`07001oogoo
Ool007oo00000Woo00D007ooOomoo`0000Qoo`04001oogoo0004Ool00`00Ool00003Ool02@00Ool0
07oo001oo`00Ool00002Ool01000Oomoo`000Woo00H007ooOol007oo0005Ool01@00Oomoogoo0000
1Woo100000Aoo`00Ool0009oo`05001oogooOol00004Ool01000Oomoo`0027oo00<007oo00000goo
00H007ooOol007oo0002Ool01000Ool000000Woo00<007ooOol00Woo00<007ooOol00Woo00D007oo
Oomoo`0000Aoo`04001oogoo0003Ool00`00Ool000020002Ool01000Ool000000Woo00<007ooOol0
1Woo00<007ooOol00Woo00<007ooOol02Woo00L007ooOomoo`00Ool00002Ool01000Ool0000037oo
00@007ooOol000Eoo`04001oogoo0002Ool00`00Oomoo`02Ool01000Oomoogoo0`000Woo00@007oo
Ool000=oo`03001oogoo00Eoo`006goo00L007ooOomoo`00Ool00002Ool01@00Oomoogoo000027oo
00@007ooOol000Aoo`04001oogoo0002Ool01000Ool007oo0`0000Eoo`00Oomoo`00009oo`04001o
ogoo0002Ool00`00Ool00005Ool01@00Oomoogoo00001Woo00<007oo00000Woo00<007oo00000Woo
00D007ooOomoo`0000Aoo`04001oogoo0008Ool00`00Ool00003Ool00`00Oomoo`020003Ool01000
Ool000000Woo00<007ooOol00Woo00<007ooOol00Woo00D007ooOomoo`0000Aoo`04001oogoo0003
Ool01000Oomoo`000goo00@007oo0000009oo`03001oogoo00Ioo`03001oogoo009oo`03001oogoo
00Yoo`07001oogooOol007oo00000Woo00@007oo000000aoo`04001oogoo0005Ool01000Oomoo`00
0Woo00<007ooOol00Woo00@007ooOomoo`<0009oo`04001oogoo0003Ool00`00Oomoo`05Ool001]o
o`05001oogooOol00002Ool00`00Ool00003Ool00`00Oomoo`06Ool01000Oomoo`0017oo00L007oo
Ool007oo001oo`0200001Woo00000000Ool000=oo`03001oo`00009oo`06001oogoo001oo`001Goo
00D007ooOomoo`0000Moo`80009oo`03001oo`00009oo`05001oogooOol00004Ool01000Oomoo`00
27oo00<007oo00000goo00@007ooOol000Aoo`04001oo`000002Ool00`00Oomoo`02Ool00`00Oomo
o`02Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oo`00Ool00002Ool01000Ool0
00000Woo00<007ooOol01Woo00<007ooOol00Woo00<007ooOol02Woo00L007ooOomoo`00Ool00002
Ool01000Ool0000037oo00@007ooOol000Eoo`04001oogoo0002Ool01`00Oomoogoo001oo`00009o
o`<0009oo`04001oogoo0003Ool00`00Oomoo`05Ool001]oo`05001oogooOol00002Ool00`00Ool0
0003Ool00`00Oomoo`06Ool01000Oomoo`0017oo00@007ooOol0009oo`03001oo`00009oo`04001o
ogoo0003Ool00`00Ool00002Ool01P00Oomoo`00Ool000Eoo`05001oogooOol00008Ool00`00Oomo
o`020003Ool01@00Oomoogoo000017oo00@007ooOol000Qoo`03001oo`0000=oo`03001oogoo00<0
009oo`800005Ool007ooOol00004Ool00`00Oomoo`02Ool01@00Oomoogoo00000goo00D007ooOomo
o`0000=oo`03001oogoo008000=oo`03001oo`0000=oo`03001oogoo00Eoo`03001oogoo009oo`03
001oogoo00Uoo`8000Aoo`04001oogooOol200000goo001oo`0;Ool01@00Oomoogoo000017oo00D0
07ooOol007oo008000Aoo`03001oogoo009oo`05001oogooOol00002Ool01@00Oomoogoo00001goo
000KOol20002Ool01P00Oomoo`00Ool000=oo`03001oogoo00Ioo`04001oogoo0004Ool01000Oomo
o`0017oo00@007ooOol0009oo`04001oogooOol20003Ool01P00Oomoo`00Ool000Eoo`05001oogoo
Ool00008Ool01@00Oomoogoo00000goo00D007ooOomoo`0000Aoo`04001oogoo0007Ool01000Oomo
o`000goo00@007ooOol000=oo`03001oogoo009oo`03001oo`0000Aoo`03001oogoo009oo`05001o
ogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000Eoo`05001oogooOol00007Ool0
0`00Oomoo`02Ool00`00Oomoo`0COol01000Oomoo`0037oo00D007ooOomoo`0000Aoo`04001oogoo
000<Ool01@00Oomoogoo00000Woo00D007ooOomoo`0000Moo`006goo00D007ooOomoo`00009oo`03
001oo`0000Aoo`03001oogoo00Eoo`04001oogoo0004Ool01000Oomoo`000goo00D007ooOomoo`00
009oo`04001oogooOol20004Ool01@00Ool007oo000017oo00<007ooOol00Woo00<007ooOol01Woo
00D007ooOomoo`0000=oo`05001oogooOol00004Ool01000Oomoo`001goo00@007ooOol000=oo`04
001oogoo0003Ool00`00Oomoo`02Ool00`00Ool00004Ool00`00Oomoo`02Ool01@00Oomoogoo0000
0goo00D007ooOomoo`0000=oo`05001oogooOol00005Ool01@00Oomoogoo00001goo00<007ooOol0
0Woo00<007ooOol04goo00@007ooOol000aoo`05001oogooOol00004Ool01000Oomoo`0037oo00<0
07ooOol00Woo00<007oo00000goo00<007ooOol01Goo000KOol01@00Oomoogoo00000Woo00<007oo
000017oo00<007ooOol01Goo00@007ooOol000Aoo`04001oogoo0003Ool01@00Oomoogoo00000Woo
00@007ooOomoo`8000Aoo`05001oo`00Ool00004Ool00`00Oomoo`02Ool00`00Oomoo`06Ool01@00
Oomoogoo00000goo00D007ooOomoo`0000Aoo`05001oogooOol00006Ool01@00Oomoogoo00000Woo
00D007ooOomoo`00009oo`03001oogoo009oo`03001oo`0000Aoo`03001oogoo009oo`05001oogoo
Ool00003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000Eoo`05001oogooOol00007Ool00`00
Oomoo`03Ool00`00Oomoo`0AOol01@00Oomoogoo000037oo00D007ooOomoo`0000Aoo`04001oogoo
000<Ool00`00Oomoo`02Ool00`00Ool00003Ool00`00Oomoo`05Ool001]oo`05001oogooOol00002
Ool00`00Ool00004Ool00`00Oomoo`05Ool01000Oomoo`0017oo00@007ooOol000=oo`05001oogoo
Ool00002Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Ool00002Ool01@00Oomoogoo000017oo
00<007ooOol01Woo00D007ooOomoo`0000=oo`05001oogooOol00004Ool01@00Oomoogoo00001Woo
00D007ooOomoo`00009oo`05001oogooOol00002Ool00`00Oomoo`02Ool00`00Ool00004Ool00`00
Oomoo`02Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00004Ool00`00
Oomoo`02Ool00`00Oomoo`05Ool00`00Oomoo`03Ool00`00Oomoo`0AOol01@00Oomoogoo000037oo
00<007ooOol00Woo00D007ooOomoo`0000=oo`03001oogoo00Uoo`03001oogoo009oo`03001oo`00
00=oo`03001oogoo00Eoo`006goo00D007ooOomoo`00009oo`03001oo`0000Aoo`03001oogoo00Eo
o`05001oogooOol00003Ool01000Oomoo`000goo00D007ooOomoo`00009oo`03001oogoo009oo`03
001oogoo009oo`03001oo`00009oo`05001oogooOol00004Ool00`00Oomoo`06Ool01@00Oomoogoo
00000goo00D007ooOomoo`0000Aoo`03001oogoo009oo`03001oogoo00=oo`05001oogooOol00002
Ool00`00Oomoo`02Ool00`00Ool00004Ool00`00Ool00004Ool00`00Oomoo`02Ool01@00Oomoogoo
00000goo00D007ooOomoo`0000=oo`05001oogooOol00004Ool00`00Oomoo`02Ool00`00Oomoo`05
Ool00`00Oomoo`03Ool00`00Oomoo`0AOol01@00Oomoogoo000037oo00<007ooOol00Woo00D007oo
Oomoo`0000=oo`03001oogoo00Uoo`03001oogoo009oo`03001oo`0000=oo`03001oogoo00Eoo`00
5Wooo`002`00000KOol01@00Oomoogoo00000Woo00@007oo000000Uoo`<000=oo`05001oogooOol0
0008Ool00`00Ool00002Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Ool00002Ool01@00Oomo
ogoo000017oo0P001Goo0`0000Aoo`00Ool000=oo`07001oogooOol007oo00000Woo00<007ooOol0
0Woo00<007ooOol01goo00@007ooOol000Ioo`03001oogoo009oo`05001oo`00Ool00002Ool01000
Oomoo`000goo00<007oo00000goo00D007ooOomoo`0000=oo`03001oogoo009oo`80009oo`03001o
ogoo00Aoo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Eoo`05001oo`00Ool00003Ool2
0002Ool01@00Oomoogoo000017oo0P000goo00@007ooOomoo`8000Uoo`03001oogoo009oo`03001o
ogoo009oo`03001oogoo00Moo`03001oogoo005oo`006goo00D007ooOomoo`00009oo`03001oo`00
011oo`04001oogoo0009Ool01P00Oomoo`00Ool000Uoo`03001oo`00009oo`05001oogooOol00004
Ool00`00Oomoo`04Ool01`00Oomoogoo001oo`0000=oo`03001oogoo00=oo`04001oogoo000>Ool0
1000Oomoo`001Woo00<007ooOol00Woo00<007oo000017oo00@007ooOol000Eoo`05001oogooOol0
0003Ool01000Oomoo`001Woo00@007ooOol0029oo`05001oo`00Ool0000;Ool00`00Oomoo`02Ool0
0`00Oomoo`02Ool01@00Oomoogoo00002Woo00<007ooOol00Woo00<007ooOol047oo000KOol01@00
Oomoogoo00000Woo00<007oo000047oo00@007ooOol000aoo`03001oo`0000Uoo`03001oo`00009o
o`04001oogoo0005Ool00`00Oomoo`04Ool00`00Oomoo`03Ool01@00Oomoogoo00001Goo00@007oo
Ool000ioo`04001oogoo000;Ool00`00Ool00004Ool01000Oomoo`001Goo00D007ooOomoo`0000=o
o`04001oogoo0006Ool01000Oomoo`008Woo00D007ooOomoo`0000]oo`03001oogoo009oo`03001o
ogoo009oo`05001oogooOol0000:Ool00`00Oomoo`02Ool00`00Oomoo`0@Ool001]oo`05001oogoo
Ool00002Ool00`00Ool0000@Ool01000Oomoo`0037oo00<007oo00002Goo00<007oo00000Woo00@0
07ooOol000Eoo`03001oogoo00Aoo`03001oogoo00=oo`05001oogooOol00005Ool01000Oomoo`00
3Woo00@007ooOol000]oo`03001oo`0000Aoo`04001oogoo0005Ool01@00Oomoogoo00000goo00@0
07ooOol000Ioo`04001oogoo000ROol01@00Oomoogoo00002goo00<007ooOol00Woo00<007ooOol0
0Woo00@007ooOol000aoo`05001oogooOol0000BOol001]oo`800003Ool007oo009oo`03001oo`00
011oo`04001oogoo000<Ool00`00Ool00009Ool00`00Ool00002Ool01000Oomoo`001Goo00<007oo
Ool017oo00<007ooOol00goo00D007ooOomoo`0000Eoo`04001oogoo000>Ool00`00Ool0000<Ool0
0`00Ool00004Ool01000Oomoo`001Goo00D007ooOomoo`0000=oo`04001oogoo0006Ool01000Oomo
o`008Woo00D007ooOomoo`0000aoo`05001oogooOol00004Ool01000Oomoo`0037oo00D007ooOomo
o`00019oo`006goo00@007ooOol000=oo`03001oo`00011oo`04001oogoo000<Ool00`00Ool00009
Ool00`00Ool00002Ool01000Oomoo`001Goo00<007ooOol017oo00<007ooOol00goo00@007ooOol0
00Ioo`04001oogoo000>Ool00`00Ool0000<Ool00`00Ool00004Ool01000Oomoo`001Goo00D007oo
Oomoo`0000=oo`04001oogoo0006Ool01000Oomoo`008Woo00D007ooOomoo`0000aoo`05001oogoo
Ool00005Ool00`00Ool0000<Ool01@00Oomoogoo00004Woo000KOol01000Oomoo`000goo00<007oo
000047oo00@007ooOol000aoo`03001oo`0000Uoo`03001oo`00009oo`04001oogoo0005Ool00`00
Oomoo`04Ool00`00Oomoo`03Ool01000Oomoo`001Woo00@007ooOol000moo`8000aoo`03001oo`00
00Aoo`04001oogoo0005Ool01@00Oomoogoo00000goo00@007ooOol000Ioo`04001oogoo000ROol0
1@00Oomoogoo000037oo00D007ooOomoo`0000Eoo`03001oo`0000aoo`05001oogooOol0000BOol0
01]oo`04001oogoo0003Ool00`00Ool0000@Ool01000Oomoo`0037oo00<007oo00002Goo00<007oo
00000Woo00<007oo00001Woo00<007ooOol017oo00<007ooOol00goo00@007ooOol000Ioo`04001o
ogoo000?Ool2000<Ool00`00Ool00004Ool01000Oomoo`001Woo00@007ooOol000=oo`04001oogoo
0006Ool01000Oomoo`008goo00@007ooOol000aoo`04001oogoo0006Ool00`00Ool0000<Ool01@00
Oomoogoo00004Woo000KOol01000Oomoo`000goo00<007oo000047oo00@007ooOol000aoo`03001o
o`0000Uoo`03001oo`00009oo`03001oo`0000Ioo`03001oogoo00Aoo`03001oogoo00=oo`04001o
ogoo0006Ool01000Oomoo`003goo0P0037oo00<007oo000017oo00@007ooOol000Ioo`04001oogoo
0003Ool01000Oomoo`001Woo00@007ooOol002=oo`04001oogoo000<Ool01000Oomoo`001Woo00<0
07oo000037oo00D007ooOomoo`00019oo`006goo00@007ooOol000=oo`03001oo`00011oo`04001o
ogoo000<Ool2000:Ool00`00Ool00002Ool00`00Ool00006Ool00`00Oomoo`04Ool00`00Oomoo`03
Ool01000Oomoo`001goo00<007oo00003goo0P0037oo00<007oo000017oo00<007oo00001goo00<0
07oo000017oo00@007ooOol000Ioo`04001oogoo000SOol01000Oomoo`0037oo00@007ooOol000Io
o`03001oo`0000eoo`04001oogoo000BOol001]oo`800003Ool007oo009oo`03001oo`00011oo`04
001oogoo000<Ool2000:Ool00`00Ool00002Ool00`00Ool00006Ool00`00Oomoo`04Ool00`00Oomo
o`03Ool01000Oomoo`001goo00<007oo00003goo0P0037oo00<007oo000017oo00<007oo00001goo
00<007oo00001Goo00<007oo00001Woo00@007ooOol002=oo`04001oogoo000<Ool01000Oomoo`00
1Woo00<007oo00003Goo00@007ooOol0019oo`006goo00@007ooOol000=oo`03001oo`00011oo`04
001oogoo000<Ool2000:Ool00`00Ool00002Ool20008Ool00`00Oomoo`03Ool00`00Oomoo`03Ool0
1000Oomoo`001goo00<007oo00003goo0P0037oo00<007oo000017oo00<007oo00001goo00<007oo
00001Goo00<007oo00001goo00<007oo00008goo00@007ooOol000aoo`04001oogoo0006Ool00`00
Ool0000=Ool01000Oomoo`004Woo000KOol01000Oomoo`000goo00<007oo000047oo00@007ooOol0
00aoo`8000Yoo`8000=oo`8000Qoo`03001oogoo00=oo`03001oogoo00Aoo`03001oo`0000Moo`03
001oo`0000moo`8000aoo`03001oo`0000Aoo`03001oo`0000Moo`03001oo`0000Eoo`03001oo`00
00Moo`03001oo`0002=oo`04001oogoo000<Ool01000Oomoo`001Woo00<007oo00003Goo00@007oo
Ool0019oo`006goo00@007ooOol000=oo`03001oo`00011oo`04001oogoo000<Ool2000:Ool20003
Ool20008Ool00`00Oomoo`03Ool00`00Oomoo`04Ool00`00Ool00007Ool00`00Ool0000?Ool2000<
Ool00`00Ool00004Ool00`00Ool00007Ool00`00Ool00005Ool00`00Ool00007Ool00`00Ool0000S
Ool01000Oomoo`0037oo00@007ooOol000Ioo`03001oo`0000eoo`04001oogoo000BOol001]oo`04
001oogoo0003Ool00`00Ool0000@Ool01000Oomoo`0037oo0P002Woo0P000goo0P0027oo00<007oo
Ool00goo00<007ooOol017oo00<007oo00001goo00<007oo000047oo00<007ooOol02Woo00<007oo
000017oo00<007oo00001goo00<007oo00001Goo00<007oo00001goo00<007oo00008goo00<007oo
00003Woo00<007oo00001Woo00<007oo00003Goo00@007ooOol0019oo`006goo0P0000=oo`00Ool0
0Woo00<007oo000047oo00@007ooOol000eoo`03001oogoo00Qoo`8000=oo`03001oogoo00Moo`03
001oogoo00=oo`03001oogoo00Aoo`03001oo`0000Moo`03001oo`00011oo`03001oogoo00Yoo`03
001oo`0000Aoo`03001oo`0000Moo`03001oo`0000Eoo`03001oo`0000Moo`03001oo`0002=oo`03
001oo`0000ioo`03001oo`0000Ioo`03001oo`0000eoo`03001oo`0001=oo`006goo00@007ooOol0
00=oo`03001oo`00015oo`03001oo`0000eoo`03001oogoo00Qoo`8000=oo`03001oogoo00Moo`03
001oogoo00=oo`03001oogoo00Aoo`03001oo`0000Moo`03001oo`00011oo`03001oogoo00Yoo`03
001oo`0000Aoo`03001oo`0000Moo`03001oo`0000Eoo`03001oo`0000Moo`03001oo`0002=oo`03
001oo`0000ioo`03001oo`0000Ioo`03001oo`0000ioo`8001=oo`006goo00@007ooOol000=oo`80
019oo`03001oo`0000eoo`03001oogoo00Qoo`8000=oo`03001oogoo00Moo`03001oogoo009oo`03
001oogoo00Eoo`03001oo`0000Moo`03001oo`00011oo`03001oogoo00Yoo`03001oo`0000Aoo`03
001oo`0000Moo`03001oo`0000Eoo`03001oo`0000Moo`03001oo`0002=oo`03001oo`0000ioo`03
001oo`0000Moo`8000ioo`8001=oo`006goo00@007ooOol000Aoo`03001oogoo011oo`03001oo`00
00eoo`03001oogoo00Qoo`8000eoo`03001oogoo009oo`03001oogoo00Eoo`03001oo`0000Moo`03
001oo`00011oo`03001oogoo00Yoo`03001oo`0000Aoo`03001oo`0000Moo`03001oo`0000Eoo`03
001oo`0000Moo`03001oo`0002=oo`03001oo`0000ioo`03001oo`0000Moo`8000ioo`8001=oo`00
6goo00@007ooOol000Aoo`03001oogoo011oo`8000ioo`03001oogoo00Qoo`8000eoo`03001oogoo
009oo`03001oogoo00Eoo`03001oo`0000Moo`03001oo`0001eoo`03001oo`0000Aoo`03001oo`00
00Moo`03001oo`0000Eoo`03001oo`0000Moo`03001oo`0002=oo`03001oo`0000ioo`03001oo`00
00Moo`8000ioo`8001=oo`006goo0P0000=oo`00Ool00goo00<007ooOol047oo0P003Woo00<007oo
Ool027oo0P003Goo00<007ooOol00Woo00<007ooOol01Goo00<007oo00001goo00<007oo00007Goo
0P001Woo0P001goo00<007oo00001Goo00<007oo00001goo00<007oo00008goo00<007oo00003goo
0P001goo00<007ooOol03Goo0P004goo000KOol01000Oomoo`0017oo00<007ooOol047oo0P003Woo
00<007ooOol027oo0P003Goo00<007ooOol00Woo00<007ooOol01Goo00<007oo00001goo0P007Woo
0P001Woo0P001goo00<007oo00001Goo00<007oo00001goo00<007oo00008goo00<007oo000047oo
00<007ooOol01Goo00<007ooOol03Goo0P004goo000KOol01000Oomoo`0017oo00<007ooOol047oo
0P003Woo00<007ooOol027oo0P003Goo00<007ooOol00Woo00<007ooOol01Goo00<007oo00001goo
0P007goo00<007ooOol017oo0P001goo00<007oo00001Goo00<007oo00001goo00<007oo00008goo
00<007oo000067oo00<007ooOol03Goo0P004goo000;Ool00`00Oomoo`02Ool00`00Oomoo`02Ool0
0`00Oomoo`03Ool01000Oomoo`0017oo00<007ooOol047oo0P006Woo00<007ooOol02goo00<007oo
Ool00Woo00<007ooOol01Goo0P0027oo0P007goo00<007ooOol017oo0P001goo00<007oo00001Goo
00<007oo00001goo00<007oo000097oo0P0067oo00<007ooOol03Goo0P004goo000:Ool00`00Ool0
0007Ool00`00Ool00004Ool01000Oomoo`0017oo00<007ooOol04Goo00<007ooOol067oo00<007oo
Ool02goo00<007ooOol00Woo00<007ooOol01Goo0P0027oo0P007goo00<007ooOol017oo0P001goo
00<007oo00001Goo00<007oo00001goo00<007oo000097oo0P00:Goo00<007ooOol04Goo000:Ool0
0`00Ool00009Ool00`00Oomoo`02Ool200000goo001oo`03Ool00`00Oomoo`0AOol00`00Oomoo`0H
Ool00`00Oomoo`0;Ool00`00Oomoo`02Ool00`00Oomoo`06Ool00`00Oomoo`06Ool2000OOol00`00
Oomoo`04Ool20008Ool00`00Oomoo`04Ool00`00Ool00007Ool2000UOol00`00Oomoo`0XOol00`00
Oomoo`0AOol000Yoo`03001oo`0000Moo`8000Eoo`04001oogoo0004Ool00`00Oomoo`0AOol00`00
Oomoo`0HOol00`00Oomoo`0;Ool00`00Oomoo`02Ool00`00Oomoo`06Ool00`00Oomoo`06Ool2000O
Ool00`00Oomoo`04Ool20008Ool00`00Oomoo`04Ool00`00Ool00007Ool2000UOol00`00Oomoo`0X
Ool00`00Oomoo`0AOol000Yoo`03001oo`0000Moo`03001oogoo00Aoo`03001oo`0000Eoo`03001o
ogoo015oo`03001oogoo01Qoo`03001oogoo00]oo`03001oogoo009oo`03001oogoo00Ioo`03001o
ogoo00Ioo`8001moo`03001oogoo00Aoo`03001oogoo00Moo`03001oogoo00Aoo`8000Qoo`8002Eo
o`03001oogoo02Qoo`03001oogoo015oo`002goo00<007ooOol01Woo0`0017oo00<007oo00001Goo
00<007ooOol04Goo00<007ooOol067oo00<007ooOol02goo00<007ooOol00Woo00<007ooOol01Woo
00<007ooOol01Woo0P007goo00<007ooOol017oo00<007ooOol01goo00<007ooOol017oo0P0027oo
0P009Goo00<007ooOol0:7oo00<007ooOol04Goo000KOol00`00Ool00005Ool00`00Oomoo`0/Ool0
0`00Oomoo`0;Ool00`00Oomoo`02Ool00`00Oomoo`06Ool00`00Oomoo`07Ool00`00Oomoo`0MOol0
0`00Oomoo`04Ool00`00Oomoo`07Ool00`00Oomoo`04Ool20008Ool2000UOol00`00Oomoo`0lOol0
01]oo`03001oo`0000Eoo`03001oogoo02aoo`03001oogoo00]oo`03001oogoo009oo`03001oogoo
00Ioo`03001oogoo00Moo`03001oogoo01eoo`03001oogoo00Aoo`03001oogoo00Moo`03001oogoo
00Eoo`03001oogoo00Moo`03001oogoo02=oo`03001oogoo03aoo`006goo0`00=7oo00<007ooOol0
2goo00<007ooOol00Woo00<007ooOol01Woo00<007ooOol01goo00<007ooOol07Goo00<007ooOol0
17oo00<007ooOol01goo00<007ooOol01Goo00<007ooOol01goo00<007ooOol0HWoo000KOol00`00
Ool0000dOol00`00Oomoo`0;Ool00`00Oomoo`02Ool00`00Oomoo`0@Ool00`00Oomoo`0MOol00`00
Oomoo`04Ool00`00Oomoo`07Ool00`00Oomoo`05Ool00`00Oomoo`07Ool00`00Oomoo`1ROol001]o
o`03001oo`0003Aoo`03001oogoo00]oo`03001oogoo009oo`03001oogoo011oo`03001oogoo01eo
o`03001oogoo00Aoo`03001oogoo00Moo`03001oogoo00Eoo`03001oogoo00Moo`03001oogoo069o
o`006goo00<007oo0000=7oo00<007ooOol02goo00<007ooOol00Woo00<007ooOol047oo00<007oo
Ool07Goo00<007ooOol017oo00<007ooOol03goo00<007ooOol01goo00<007ooOol0HWoo000KOol0
0`00Ool0000dOol00`00Oomoo`0<Ool01@00Oomoogoo00004Woo00<007ooOol07Goo00<007ooOol0
17oo00<007ooOol03goo00<007ooOol01goo00<007ooOol0HWoo000KOol3000dOol00`00Oomoo`0<
Ool01@00Oomoogoo00004Woo00<007ooOol07Goo00<007ooOol017oo00<007ooOol03goo00<007oo
Ool01goo00<007ooOol0HWoo000KOol00`00Ool0000dOol00`00Oomoo`0<Ool01@00Oomoogoo0000
4Woo00<007ooOol0=Woo00<007ooOol01goo00<007ooOol0HWoo000KOol00`00Ool00013Ool01@00
Oomoogoo00004Woo00<007ooOol0=Woo00<007ooOol01goo00<007ooOol0HWoo000KOol00`00Oomo
o`13Ool01@00Oomoogoo00004Woo00<007ooOol0=Woo00<007ooOol01goo00<007ooOol0HWoo000K
Ool00`00Oomoo`13Ool01@00Oomoogoo0000Bgoo00<007ooOol0K7oo000KOol20014Ool01@00Oomo
ogoo0000^Woo000KOol00`00Oomoo`13Ool01@00Oomoogoo0000^Woo000KOol00`00Oomoo`13Ool0
1@00Oomoogoo0000^Woo000KOol00`00Oomoo`13Ool01@00Oomoogoo0000^Woo000KOol00`00Oomo
o`13Ool01@00Oomoogoo0000^Woo000KOol20014Ool01@00Oomoogoo0000^Woo000KOol00`00Oomo
o`13Ool01@00Oomoogoo0000^Woo000KOol00`00Oomoo`13Ool01@00Oomoogoo0000^Woo000KOol0
0`00Oomoo`13Ool01@00Oomoogoo0000^Woo000COol50003Ool00`00Oomoo`13Ool01@00Oomoogoo
0000^Woo000EOol00`00Oomoo`03Ool00`00Oomoo`13Ool01@00Oomoogoo0000^Woo000EOol00`00
Oomoo`03Ool20014Ool01000Oomoo`00^goo000EOol00`00Oomoo`03Ool00`00Oomoo`13Ool01000
Oomoo`00^goo000EOol00`00Oomoo`03Ool00`00Oomoo`13Ool01000Oomoo`00^goo000DOol20005
Ool00`00Oomoo`13Ool01000Oomoo`00^goo000KOol00`00Oomoo`13Ool01000Oomoo`00^goo000K
Ool20014Ool01000Oomoo`00^goo000KOol00`00Oomoo`13Ool01000Oomoo`00^goo000KOol00`00
Oomoo`13Ool01000Oomoo`00^goo000KOol00`00Oomoo`14Ool00`00Ool0002kOol001]oo`03001o
ogoo04Aoo`03001oo`000;]oo`006goo0P00AGoo00<007oo0000^goo000KOol00`00Oomoo`14Ool0
0`00Ool0002kOol001]oo`03001oogoo04Aoo`03001oo`000;]oo`006goo00<007ooOol0A7oo00<0
07oo0000^goo000KOol00`00Oomoo`14Ool00`00Ool0002kOol001]oo`03001oogoo04Aoo`03001o
o`000;]oo`006goo0P00AGoo00<007oo0000^goo000KOol00`00Oomoo`14Ool00`00Ool0002kOol0
01]oo`03001oogoo04Aoo`800;aoo`006goo00<007ooOol0A7oo0P00_7oo000KOol00`00Oomoo`14
Ool00`00Oomoo`2kOol001]oo`800?moo`Aoo`006goo00<007ooOol0ogoo0goo000KOol00`00Oomo
o`3oOol3Ool001]oo`03001oogoo0?moo`=oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo
003oOolQOol00?moob5oo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-13.7902, -1.77528, 
  0.505108, 0.0189822}}]
}, Open  ]],

Cell["\<\
Here is the normalized cumulative curvature function. This function has \
desirable shape invariance properties: size, translation and rotation \
invariance.\
\>", "Text"],

Cell[BoxData[
    \(cc = FoldList[Plus, First[d2y], Rest[d2y]]; \n
    ncc = cc + Table[\(\((i - 1)\)\ 2\ N[\[Pi]]\)\/L, {i, L}]; \)], "Input",
  CellLabel->"In[131]:="],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\n\(ListPlot[ncc, PlotJoined \[Rule] True]; \)\)\)], "Input",
  CellLabel->"In[139]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00744048 0.25153 0.157046 [
[.17262 .23903 -6 -9 ]
[.17262 .23903 6 0 ]
[.32143 .23903 -6 -9 ]
[.32143 .23903 6 0 ]
[.47024 .23903 -6 -9 ]
[.47024 .23903 6 0 ]
[.61905 .23903 -6 -9 ]
[.61905 .23903 6 0 ]
[.76786 .23903 -9 -9 ]
[.76786 .23903 9 0 ]
[.91667 .23903 -9 -9 ]
[.91667 .23903 9 0 ]
[.01131 .01596 -24 -4.5 ]
[.01131 .01596 0 4.5 ]
[.01131 .09448 -12 -4.5 ]
[.01131 .09448 0 4.5 ]
[.01131 .17301 -24 -4.5 ]
[.01131 .17301 0 4.5 ]
[.01131 .33005 -18 -4.5 ]
[.01131 .33005 0 4.5 ]
[.01131 .40858 -6 -4.5 ]
[.01131 .40858 0 4.5 ]
[.01131 .4871 -18 -4.5 ]
[.01131 .4871 0 4.5 ]
[.01131 .56562 -6 -4.5 ]
[.01131 .56562 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.17262 .25153 m
.17262 .25778 L
s
[(20)] .17262 .23903 0 1 Mshowa
.32143 .25153 m
.32143 .25778 L
s
[(40)] .32143 .23903 0 1 Mshowa
.47024 .25153 m
.47024 .25778 L
s
[(60)] .47024 .23903 0 1 Mshowa
.61905 .25153 m
.61905 .25778 L
s
[(80)] .61905 .23903 0 1 Mshowa
.76786 .25153 m
.76786 .25778 L
s
[(100)] .76786 .23903 0 1 Mshowa
.91667 .25153 m
.91667 .25778 L
s
[(120)] .91667 .23903 0 1 Mshowa
.125 Mabswid
.06101 .25153 m
.06101 .25528 L
s
.09821 .25153 m
.09821 .25528 L
s
.13542 .25153 m
.13542 .25528 L
s
.20982 .25153 m
.20982 .25528 L
s
.24702 .25153 m
.24702 .25528 L
s
.28423 .25153 m
.28423 .25528 L
s
.35863 .25153 m
.35863 .25528 L
s
.39583 .25153 m
.39583 .25528 L
s
.43304 .25153 m
.43304 .25528 L
s
.50744 .25153 m
.50744 .25528 L
s
.54464 .25153 m
.54464 .25528 L
s
.58185 .25153 m
.58185 .25528 L
s
.65625 .25153 m
.65625 .25528 L
s
.69345 .25153 m
.69345 .25528 L
s
.73065 .25153 m
.73065 .25528 L
s
.80506 .25153 m
.80506 .25528 L
s
.84226 .25153 m
.84226 .25528 L
s
.87946 .25153 m
.87946 .25528 L
s
.95387 .25153 m
.95387 .25528 L
s
.99107 .25153 m
.99107 .25528 L
s
.25 Mabswid
0 .25153 m
1 .25153 L
s
.02381 .01596 m
.03006 .01596 L
s
[(-1.5)] .01131 .01596 1 0 Mshowa
.02381 .09448 m
.03006 .09448 L
s
[(-1)] .01131 .09448 1 0 Mshowa
.02381 .17301 m
.03006 .17301 L
s
[(-0.5)] .01131 .17301 1 0 Mshowa
.02381 .33005 m
.03006 .33005 L
s
[(0.5)] .01131 .33005 1 0 Mshowa
.02381 .40858 m
.03006 .40858 L
s
[(1)] .01131 .40858 1 0 Mshowa
.02381 .4871 m
.03006 .4871 L
s
[(1.5)] .01131 .4871 1 0 Mshowa
.02381 .56562 m
.03006 .56562 L
s
[(2)] .01131 .56562 1 0 Mshowa
.125 Mabswid
.02381 .03167 m
.02756 .03167 L
s
.02381 .04737 m
.02756 .04737 L
s
.02381 .06307 m
.02756 .06307 L
s
.02381 .07878 m
.02756 .07878 L
s
.02381 .11019 m
.02756 .11019 L
s
.02381 .12589 m
.02756 .12589 L
s
.02381 .1416 m
.02756 .1416 L
s
.02381 .1573 m
.02756 .1573 L
s
.02381 .18871 m
.02756 .18871 L
s
.02381 .20442 m
.02756 .20442 L
s
.02381 .22012 m
.02756 .22012 L
s
.02381 .23583 m
.02756 .23583 L
s
.02381 .26723 m
.02756 .26723 L
s
.02381 .28294 m
.02756 .28294 L
s
.02381 .29864 m
.02756 .29864 L
s
.02381 .31435 m
.02756 .31435 L
s
.02381 .34576 m
.02756 .34576 L
s
.02381 .36146 m
.02756 .36146 L
s
.02381 .37717 m
.02756 .37717 L
s
.02381 .39287 m
.02756 .39287 L
s
.02381 .42428 m
.02756 .42428 L
s
.02381 .43999 m
.02756 .43999 L
s
.02381 .45569 m
.02756 .45569 L
s
.02381 .4714 m
.02756 .4714 L
s
.02381 .5028 m
.02756 .5028 L
s
.02381 .51851 m
.02756 .51851 L
s
.02381 .53421 m
.02756 .53421 L
s
.02381 .54992 m
.02756 .54992 L
s
.02381 .00026 m
.02756 .00026 L
s
.02381 .58133 m
.02756 .58133 L
s
.02381 .59703 m
.02756 .59703 L
s
.02381 .61274 m
.02756 .61274 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.03125 .36868 m
.03869 .35475 L
.04613 .30113 L
.05357 .40035 L
.06101 .33767 L
.06845 .29224 L
.07589 .29995 L
.08333 .30766 L
.09077 .31537 L
.09821 .32308 L
.10565 .3324 L
.1131 .21767 L
.12054 .26101 L
.12798 .35391 L
.13542 .33693 L
.14286 .2453 L
.1503 .25369 L
.15774 .2614 L
.16518 .26911 L
.17262 .22825 L
.18006 .21675 L
.1875 .29264 L
.19494 .20556 L
.20238 .18431 L
.20982 .19202 L
.21726 .13158 L
.2247 .08298 L
.23214 .2024 L
.23958 .01716 L
.24702 .07685 L
.25446 .11493 L
.2619 .12264 L
.26935 .07335 L
.27679 .01472 L
.28423 .09165 L
.29167 .31592 L
.29911 .53167 L
.30655 .53893 L
.31399 .54852 L
.32143 .44167 L
.32887 .4661 L
.33631 .56976 L
.34375 .56865 L
.35119 .46079 L
.35863 .46955 L
.36607 .47634 L
.37351 .60332 L
.38095 .50616 L
.38839 .50038 L
.39583 .50809 L
Mistroke
.40327 .5158 L
.41071 .52351 L
.41815 .53122 L
.4256 .47684 L
.43304 .49279 L
.44048 .55546 L
.44792 .45013 L
.45536 .44642 L
.4628 .45413 L
.47024 .46184 L
.47768 .40275 L
.48512 .35281 L
.49256 .47025 L
.5 .38893 L
.50744 .35823 L
.51488 .27482 L
.52232 .39357 L
.52976 .40016 L
.5372 .40835 L
.54464 .29458 L
.55208 .29995 L
.55952 .40863 L
.56696 .42299 L
.5744 .32219 L
.58185 .32917 L
.58929 .45932 L
.59673 .43139 L
.60417 .35391 L
.61161 .36162 L
.61905 .37568 L
.62649 .5013 L
.63393 .45865 L
.64137 .39246 L
.64881 .40016 L
.65625 .40787 L
.66369 .41558 L
.67113 .42329 L
.67857 .43163 L
.68601 .22925 L
.69345 .19973 L
.70089 .20744 L
.70833 .21515 L
.71577 .22286 L
.72321 .23057 L
.73065 .23828 L
.7381 .24599 L
.74554 .25369 L
.75298 .2614 L
.76042 .26911 L
.76786 .36751 L
Mistroke
.7753 .40165 L
.78274 .29 L
.79018 .29995 L
.79762 .30766 L
.80506 .31537 L
.8125 .32308 L
.81994 .33078 L
.82738 .39834 L
.83482 .4703 L
.84226 .37739 L
.8497 .36162 L
.85714 .36933 L
.86458 .44919 L
.87202 .50912 L
.87946 .40077 L
.8869 .40016 L
.89435 .40787 L
.90179 .41558 L
.90923 .42329 L
.91667 .431 L
.92411 .47628 L
.93155 .56976 L
.93899 .50235 L
.94643 .46184 L
.95387 .46955 L
.96131 .47725 L
.96875 .23828 L
.97619 .24599 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[139]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`006goo0P00ogoo17oo000KOol00`00Oomo
o`3oOol3Ool000Uoo`D0009oo`03001oogoo009oo`03001oogoo00=oo`03001oogoo0?moo`=oo`00
2goo00<007ooOol01Woo00<007oo000017oo00<007ooOol0ogoo0goo0005Ool30003Ool00`00Oomo
o`08Ool00`00Oomoo`02Ool20011Ool00`00Oomoo`2oOol000]oo`03001oogoo00Ioo`8000Eoo`03
001oogoo03Ioo`03001oogoo00Moo`03001oogoo0;moo`002goo00<007ooOol01Woo00<007ooOol0
17oo00<007ooOol0=Woo00<007ooOol01goo00<007ooOol0_goo000:Ool20008Ool30004Ool00`00
Oomoo`0fOol00`00Oomoo`07Ool00`00Oomoo`2oOol001]oo`8003Moo`03001oogoo00Ioo`800<5o
o`006goo00<007ooOol0=Woo0P001goo00<007oo0000`7oo000KOol00`00Oomoo`0fOol20007Ool0
0`00Ool00030Ool001]oo`03001oogoo03Ioo`8000Moo`03001oo`000<1oo`006goo00<007ooOol0
=Woo0P001goo00<007oo0000`7oo000KOol2000gOol20007Ool00`00Ool00030Ool001]oo`03001o
ogoo03Ioo`8000Moo`03001oo`000<1oo`006goo00<007ooOol0=Woo0P001goo00<007oo0000`7oo
000KOol00`00Oomoo`0fOol20006Ool01000Oomoo`00`7oo000KOol2000gOol00`00Ool00005Ool0
1000Oomoo`00`7oo000KOol00`00Oomoo`0eOol01000Oomoo`001Goo00@007ooOol00<1oo`006goo
00<007ooOol0=Goo00@007ooOol000Eoo`05001oogooOol0002oOol001]oo`03001oogoo03Eoo`04
001oogoo0005Ool01@00Oomoogoo0000_goo000KOol2000fOol01000Oomoo`001Goo00D007ooOomo
o`000;moo`006goo00<007ooOol0<Woo00@007ooOol0009oo`03001oogoo00=oo`05001oogooOol0
002oOol001=oo`D000=oo`03001oogoo039oo`04001oogoo0003Ool01@00Oomoogoo000017oo00<0
07ooOol0_Goo000EOol00`00Oomoo`03Ool00`00Oomoo`0bOol01000Oomoo`000goo00D007ooOomo
o`0000Aoo`03001oogoo0;eoo`003goo0`000goo00<007ooOol00goo0P00<goo00@007ooOol000=o
o`05001oogooOol00004Ool00`00Oomoo`2mOol001Eoo`03001oogoo00=oo`03001oogoo035oo`80
009oo`05001oogooOol00003Ool00`00Oomoo`02Ool00`00Oomoo`2mOol001Eoo`03001oogoo00=o
o`03001oogoo035oo`80009oo`05001oogooOol00003Ool00`00Oomoo`02Ool00`00Oomoo`2mOol0
01Aoo`8000Eoo`03001oogoo035oo`80009oo`05001oogooOol00003Ool00`00Oomoo`02Ool00`00
Oomoo`2mOol001]oo`80039oo`80009oo`03001oogoo009oo`04001oogoo0004Ool00`00Oomoo`2m
Ool001]oo`03001oogoo035oo`05001oo`00Ool00004Ool00`00Ool00005Ool00`00Oomoo`2mOol0
01]oo`03001oogoo035oo`05001oo`00Ool00004Ool00`00Ool00005Ool00`00Oomoo`2mOol001]o
o`03001oogoo031oo`06001oogoo001oo`001Goo0P001Goo00<007ooOol0_Goo000KOol2000aOol0
1P00Oomoo`00Ool000Ioo`03001oogoo00=oo`03001oogoo0;eoo`006goo00<007ooOol0<7oo00H0
07ooOol007oo000<Ool00`00Oomoo`2mOol001]oo`03001oogoo031oo`06001oogoo001oo`0037oo
00<007ooOol0_Goo000KOol00`00Oomoo`0`Ool01P00Oomoo`00Ool000aoo`03001oogoo0;eoo`00
6goo00<007ooOol0<7oo00H007ooOol007oo000<Ool00`00Oomoo`2mOol001]oo`80035oo`06001o
ogoo001oo`0037oo00<007ooOol0_Goo000KOol00`00Oomoo`0_Ool01`00Oomoogoo001oo`0000eo
o`03001oogoo0;aoo`006goo00<007ooOol0;goo00L007ooOomoo`00Ool0000=Ool00`00Oomoo`2l
Ool001]oo`03001oogoo02moo`07001oogooOol007oo00003Goo00<007ooOol0_7oo000KOol2000`
Ool01000Oomoogoo0P003Woo00<007ooOol0_7oo000KOol00`00Oomoo`0_Ool01000Oomoogoo0P00
3Woo00<007ooOol0_7oo000;Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00
Oomoo`0_Ool01000Oomoogoo0P003Woo00<007ooOol0_7oo000:Ool00`00Ool00007Ool00`00Ool0
0004Ool00`00Oomoo`0_Ool01000Oomoogoo0P003Woo00<007ooOol0_7oo0005Ool30002Ool00`00
Ool00009Ool00`00Oomoo`02Ool2000`Ool00`00Oomoo`02Ool00`00Oomoo`0<Ool00`00Oomoo`2l
Ool000Yoo`03001oo`0000Moo`8000Eoo`03001oogoo02ioo`03001oogoo00=oo`03001oogoo00ao
o`03001oogoo0;aoo`002Woo00<007oo00001goo00<007ooOol017oo00<007ooOol0;Woo00<007oo
Ool00goo00<007ooOol037oo00<007ooOol0_7oo000;Ool00`00Oomoo`06Ool30004Ool00`00Oomo
o`0/Ool00`00Ool00005Ool00`00Oomoo`0<Ool00`00Oomoo`2lOol001]oo`8002eoo`<000Eoo`03
001oogoo00aoo`03001oogoo0;aoo`006goo00<007ooOol0:goo00@007ooOol000Eoo`03001oogoo
00aoo`03001oogoo0;aoo`006goo00<007ooOol0:goo00<007ooOol01Woo00<007ooOol037oo00<0
07ooOol0_7oo000KOol00`00Oomoo`0[Ool00`00Oomoo`06Ool00`00Oomoo`0<Ool00`00Oomoo`1Y
Ool00`00Oomoo`1@Ool001]oo`8002]oo`03001oogoo00Moo`03001oogoo00aoo`03001oogoo06Uo
o`80055oo`006goo00<007ooOol0:Woo00<007ooOol05Woo00<007ooOol0J7oo00@007ooOol0051o
o`006goo00<007ooOol087oo0`000goo00D007ooOomoo`0001Qoo`03001oogoo00=oo`<0009oo`03
001oogoo01moo`8000Aoo`03001oogoo01moo`03001oogoo009oo`03001oogoo00ioo`05001oogoo
Ool00008Ool50002Ool00`00Oomoo`02Ool00`00Oomoo`0IOol5000017oo000000000goo00<007oo
Ool047oo000KOol00`00Oomoo`0POol00`00Oomoo`02Ool00`00Ool00002Ool00`00Oomoo`0FOol0
0`00Oomoo`04Ool01P00Oomoo`00Ool0021oo`03001oo`00009oo`03001oo`0001moo`03001oo`00
009oo`03001oo`0000moo`03001oogoo009oo`03001oogoo00Moo`07001oogooOol007oo00000Woo
00<007oo000077oo00D007ooOomoo`0000Aoo`03001oo`00015oo`006goo00<007ooOol05Goo00<0
07ooOol02Goo00@007ooOomoo`<0009oo`03001oogoo01Ioo`03001oogoo009oo`@00004Ool007oo
000POol00`00Ool00002Ool00`00Ool0000OOol00`00Ool00002Ool00`00Ool0000?Ool00`00Oomo
o`03Ool00`00Oomoo`06Ool01`00Oomoogoo001oo`00009oo`03001oo`0001aoo`03001oogoo009o
o`07001oogooOol007oo00004Goo000KOol2000FOol00`00Oomoo`09Ool01000Oomoogoo0`000Woo
00<007ooOol05Woo00<007ooOol00Woo00<007oo00000Woo00<007oo000087oo0P000goo00<007oo
000087oo00L007ooOomoo`00Ool0000>Ool00`00Oomoo`05Ool00`00Oomoo`05Ool01`00Oomoogoo
001oo`00009oo`03001oo`0001aoo`03001oogoo009oo`07001oogooOol007oo00004Goo000KOol0
0`00Oomoo`0EOol00`00Oomoo`08Ool00`00Ool00002Ool30002Ool00`00Oomoo`0FOol00`00Oomo
o`03Ool20002Ool00`00Ool0000POol00`00Oomoo`02Ool00`00Ool0000OOol00`00Ool00002Ool0
0`00Ool0000>Ool00`00Oomoo`06Ool00`00Oomoo`04Ool01`00Oomoogoo001oo`00009oo`03001o
o`0001aoo`07001oogooOol007oo00000Woo00<007oo00004Goo000KOol00`00Oomoo`0EOol2000:
Ool01P00Oomoo`00Ool0009oo`03001oogoo01Moo`03001oogoo00Aoo`05001oogooOol0000ROol2
0003Ool00`00Oomoo`0OOol00`00Oomoo`02Ool00`00Oomoo`0=Ool00`00Oomoo`07Ool00`00Oomo
o`02Ool20004Ool00`00Oomoo`02Ool00`00Oomoo`0JOol20004Ool00`00Oomoo`02Ool00`00Oomo
o`0@Ool001]oo`03001oogoo01Eoo`8000eoo`03001oo`00009oo`03001oogoo01Moo`03001oogoo
06Moo`03001oogoo00Qoo`03001oogoo04Moo`006goo0P005Woo0P003Goo00H007ooOol007oo000I
Ool00`00Oomoo`1WOol00`00Oomoo`09Ool00`00Oomoo`0lOol00`00Oomoo`07Ool001]oo`03001o
ogoo01Eoo`8000aoo`07001oogooOol007oo00006Goo00<007ooOol0Igoo00<007ooOol02Woo00<0
07ooOol0>goo0P0027oo000KOol00`00Oomoo`0EOol20005Ool00`00Oomoo`04Ool01`00Oomoogoo
001oo`0001Uoo`03001oogoo06Moo`03001oogoo00]oo`03001oogoo03Yoo`03001oo`0000Moo`00
6goo00<007ooOol057oo00<007oo00001Goo0P001Goo00L007ooOomoo`00Ool0000IOol00`00Oomo
o`1WOol00`00Oomoo`0<Ool00`00Oomoo`0iOol00`00Oomoo`07Ool001Aoool000d000006goo00<0
07ooOol01goo00<007ooOol01goo00@007ooOol0009oo`04001oogooOol20002Ool01000Oomoogoo
0P000Woo00<007oo000017oo00<007ooOol01goo00<007ooOol01goo0P0027oo00<007ooOol01goo
00<007ooOol01goo00<007ooOol01goo00<007ooOol01goo00<007ooOol01Woo00<007ooOol01goo
00<007ooOol01goo00<007ooOol01goo00<007ooOol01goo00<007ooOol01Goo00<007oo00002Goo
00<007ooOol00Woo00<007ooOol00Woo00<007ooOol01goo00<007ooOol01goo00<007ooOol01Woo
00<007ooOol01goo00<007ooOol01goo00D007ooOomoo`0000Eoo`03001oogoo005oo`006goo00<0
07ooOol057oo00@007ooOol000Aoo`05001oogooOol00002Ool20002Ool00`00Ool0000JOol00`00
Oomoo`05Ool00`00Oomoo`0UOol00`00Oomoo`0TOol00`00Oomoo`0?Ool00`00Oomoo`0?Ool01@00
Oomoogoo00009Woo00<007ooOol02goo00<007ooOol01goo000KOol00`00Oomoo`0DOol01000Oomo
o`0017oo00<007ooOol00Woo0P0017oo00<007oo00006Woo00<007ooOol0IWoo00<007ooOol047oo
00<007ooOol0=Goo00<007ooOol01goo000KOol2000EOol01000Oomoo`0017oo00<007ooOol00Woo
0P0017oo00<007oo00006Woo00<007ooOol0IWoo00<007ooOol047oo00<007ooOol0=Goo00<007oo
Ool01goo000KOol00`00Oomoo`0DOol01000Oomoo`0017oo00<007ooOol00goo00<007ooOol00Woo
00<007oo00006Woo00<007ooOol0IWoo00<007ooOol04Goo00<007ooOol0=7oo00<007ooOol01goo
000KOol00`00Oomoo`0DOol01000Oomoo`0017oo00<007ooOol02Goo00<007ooOol06Goo00<007oo
Ool0>7oo00<007ooOol0:goo00<007ooOol04Goo00<007ooOol0=7oo00<007ooOol01goo000KOol0
0`00Oomoo`0DOol01000Oomoo`0017oo00<007ooOol02Goo00<007ooOol06Goo00<007ooOol0>7oo
00<007ooOol0:goo00<007ooOol04Goo00<007ooOol0=7oo00<007ooOol01goo000KOol2000EOol0
1000Oomoo`0017oo00<007ooOol02Goo00<007ooOol06Goo00<007ooOol0>7oo00<007ooOol0:Woo
00<007ooOol04Woo00<007ooOol0=7oo00<007ooOol01goo000KOol00`00Oomoo`0DOol01@00Oomo
ogoo00000goo00<007ooOol02Goo00<007ooOol06Goo00<007ooOol0>7oo00<007ooOol0:Woo00<0
07ooOol04Woo00<007ooOol0=7oo00<007ooOol01goo000KOol00`00Oomoo`0DOol01@00Oomoogoo
00000goo00<007ooOol02Goo00<007ooOol06Goo00<007ooOol0>7oo00<007ooOol0:Woo00<007oo
Ool04Woo00<007ooOol00goo00<007ooOol0;Woo00<007ooOol01goo000KOol00`00Oomoo`09Ool0
0`00Oomoo`08Ool01@00Oomoogoo00000Woo00<007ooOol02Woo00<007ooOol06Goo00<007ooOol0
>7oo00<007ooOol01Goo00<007ooOol08Woo00<007ooOol04Woo00<007ooOol00goo0P00;goo00<0
07ooOol01goo000KOol2000:Ool20009Ool01@00Oomoogoo00000Woo00<007ooOol09Woo00<007oo
Ool0=goo0P001goo0P008goo00<007ooOol04goo00<007ooOol00Woo0P00;Woo00<007ooOol027oo
000KOol00`00Oomoo`03Ool00`00Oomoo`03Ool00`00Ool00008Ool01@00Oomoogoo00000Woo00<0
07ooOol09Woo00<007ooOol0=goo0P001goo00<007oo00008Woo00<007ooOol04goo00<007ooOol0
0Woo00<007oo0000;Goo00<007ooOol027oo000KOol00`00Oomoo`03Ool00`00Oomoo`02Ool01@00
Oomoogoo00001Woo00<007ooOol00Woo00@007ooOol002Qoo`03001oogoo03Moo`03001oo`0000Io
o`03001oo`00029oo`03001oogoo01=oo`03001oogoo009oo`04001oogoo000/Ool00`00Oomoo`08
Ool001]oo`03001oogoo00=oo`03001oogoo009oo`03001oogoo009oo`03001oogoo00=oo`03001o
ogoo009oo`04001oogoo000XOol00`00Oomoo`0gOol00`00Ool00006Ool00`00Ool0000ROol00`00
Oomoo`0COol00`00Oomoo`02Ool01@00Oomoogoo0000:goo00<007ooOol027oo000KOol00`00Oomo
o`03Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`02Ool01000Oomo
o`00:7oo00<007ooOol0=goo00<007oo00001Woo00<007oo00008Woo00<007ooOol04goo00<007oo
Ool00Woo00<007ooOol00Woo00<007ooOol0:7oo00<007ooOol027oo000KOol20003Ool20004Ool0
0`00Oomoo`04Ool01@00Oomoogoo000017oo00@007ooOol002Qoo`03001oogoo03Moo`03001oo`00
00Ioo`03001oo`00029oo`03001oogoo01=oo`03001oogoo009oo`03001oogoo00=oo`03001oogoo
02Moo`03001oogoo00Qoo`006goo00<007ooOol00Woo0P0017oo00<007ooOol01Goo00@007ooOol0
00Aoo`04001oogoo000XOol00`00Oomoo`0gOol00`00Ool00006Ool00`00Ool0000ROol00`00Oomo
o`0COol01@00Oomoogoo00001goo00<007ooOol09Woo00<007ooOol027oo000;Ool00`00Oomoo`02
Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`02Ool20004Ool00`00Oomoo`06Ool00`00
Ool00004Ool01000Oomoo`00:7oo00<007ooOol0=goo00<007oo00001Goo00@007ooOol000Eoo`03
001oogoo01Yoo`03001oogoo01=oo`05001oogooOol00008Ool00`00Oomoo`0UOol00`00Oomoo`08
Ool000Yoo`03001oo`0000Moo`03001oo`0000Aoo`03001oogoo009oo`03001oo`00009oo`03001o
ogoo00Qoo`8000Aoo`04001oogoo000XOol00`00Oomoo`0gOol00`00Ool00005Ool01000Oomoo`00
1Goo0P006goo00<007ooOol04goo00D007ooOomoo`0000Uoo`03001oogoo02Aoo`03001oogoo00Qo
o`002Woo00<007oo00002Goo00<007ooOol00Woo0P000goo00<007oo00000Woo00<007ooOol02Goo
00<007ooOol00goo00<007oo0000:7oo00<007ooOol0=goo00<007oo00001Goo00D007ooOomoo`00
00Aoo`03001oo`0001Yoo`03001oogoo01=oo`05001oogooOol0000:Ool00`00Oomoo`0SOol00`00
Oomoo`08Ool000Yoo`03001oo`0000Moo`8000Eoo`03001oogoo009oo`03001oo`00009oo`03001o
ogoo00moo`03001oo`0002Qoo`03001oogoo03Moo`03001oo`0000Eoo`05001oogooOol00004Ool0
0`00Ool0000JOol00`00Oomoo`0COol01@00Oomoogoo00002Woo00<007ooOol08goo00<007ooOol0
27oo000:Ool00`00Ool00007Ool00`00Oomoo`04Ool00`00Oomoo`02Ool00`00Ool00002Ool00`00
Oomoo`0?Ool00`00Ool0000XOol00`00Oomoo`0fOol01000Oomoo`001Goo00D007ooOomoo`0000Ao
o`03001oo`0001Yoo`03001oogoo01=oo`05001oogooOol0000:Ool00`00Oomoo`0SOol00`00Oomo
o`08Ool000]oo`03001oogoo00Ioo`<000Aoo`05001oogooOol00002Ool01000Oomoo`004Goo0P00
:Goo00<007ooOol0=Woo00@007ooOol000Eoo`05001oogooOol00004Ool00`00Ool0000JOol00`00
Oomoo`0COol01@00Oomoogoo00002Woo00<007ooOol08goo00<007ooOol027oo000KOol20002Ool0
1000Oomoo`000Woo00<007ooOol03goo0P00:Goo00<007ooOol0=Woo00@007ooOol000Eoo`05001o
ogooOol00004Ool00`00Ool0000JOol00`00Oomoo`0DOol01000Oomoo`002Woo00<007ooOol08goo
00<007ooOol027oo000KOol01@00Oomoogoo00000Woo00@007ooOol0015oo`03001oogoo02Qoo`03
001oogoo03Ioo`04001oogoo0005Ool01@00Oomoogoo00000goo00@007ooOol001Yoo`03001oogoo
01Aoo`04001oogoo000;Ool00`00Oomoo`0ROol00`00Oomoo`08Ool001]oo`05001oogooOol00002
Ool00`00Ool0000BOol00`00Oomoo`0XOol00`00Oomoo`0aOol00`00Oomoo`02Ool01000Oomoo`00
1Goo00D007ooOomoo`0000=oo`04001oogoo0005Ool00`00Oomoo`0BOol00`00Oomoo`0DOol01000
Oomoo`002goo00<007ooOol08Woo00<007ooOol027oo000KOol01000Oomoo`000goo00<007oo0000
?Goo00<007ooOol0<Goo00<007ooOol00Woo00@007ooOol000Eoo`05001oogooOol00003Ool01000
Oomoo`001Goo0P004goo00<007ooOol057oo00@007ooOol000]oo`03001oogoo029oo`03001oogoo
00Qoo`006goo0P0000=oo`00Ool00Woo00<007oo0000?Goo00<007ooOol0<Goo00<007ooOol00Woo
00@007ooOol000Eoo`05001oogooOol00003Ool01000Oomoo`001Goo00<007oo00004Woo00<007oo
Ool057oo00@007ooOol000]oo`03001oogoo00Aoo`03001oogoo01]oo`03001oogoo00Qoo`006goo
00<007oo000017oo00<007oo0000?Goo00<007ooOol0<Goo00D007ooOomoo`0000Aoo`03001oogoo
009oo`05001oogooOol00003Ool01@00Oomoogoo000017oo00@007ooOol0015oo`03001oogoo01Ao
o`04001oogoo000;Ool00`00Oomoo`03Ool00`00Ool0000LOol00`00Oomoo`08Ool001]oo`03001o
o`0000Aoo`03001oo`0003eoo`03001oogoo031oo`8000=oo`03001oogoo009oo`03001oogoo009o
o`05001oogooOol00003Ool01@00Oomoogoo000017oo00@007ooOol0015oo`03001oogoo01Aoo`04
001oogoo000;Ool00`00Oomoo`03Ool00`00Ool0000LOol00`00Oomoo`08Ool001]oo`03001oogoo
00Aoo`03001oo`0003ioo`03001oogoo02moo`8000=oo`03001oogoo009oo`03001oogoo009oo`05
001oogooOol00003Ool01@00Oomoogoo000017oo00D007ooOomoo`00011oo`03001oogoo01Aoo`04
001oogoo000;Ool00`00Oomoo`02Ool01000Oomoo`0077oo00<007ooOol027oo000KOol20006Ool2
000nOol00`00Oomoo`0_Ool20003Ool00`00Oomoo`02Ool00`00Oomoo`02Ool01@00Oomoogoo0000
0goo00D007ooOomoo`0000=oo`03001oogoo009oo`03001oogoo00ioo`03001oogoo01Aoo`03001o
o`0000aoo`03001oogoo009oo`04001oogoo000LOol00`00Oomoo`08Ool001]oo`03001oogoo00Eo
o`8003ioo`03001oogoo02moo`80009oo`03001oogoo00=oo`03001oogoo009oo`05001oogooOol0
0003Ool01@00Oomoogoo00000goo00<007ooOol00Woo00<007ooOol03Woo00<007ooOol05Goo0P00
37oo00<007ooOol00Woo00@007ooOol001aoo`03001oogoo00Qoo`006goo00<007ooOol01Goo00<0
07ooOol0?Goo00<007ooOol0;goo00D007oo001oo`0000Eoo`05001oogooOol00005Ool01000Oomo
o`000goo00D007ooOomoo`0000Aoo`03001oogoo00eoo`03001oogoo01Ioo`8000eoo`05001oogoo
Ool00002Ool00`00Oomoo`0JOol00`00Oomoo`08Ool001]oo`03001oogoo00Eoo`03001oogoo03eo
o`03001oogoo02moo`05001oo`00Ool00005Ool01@00Oomoogoo00001Goo00@007ooOol000=oo`05
001oogooOol00004Ool00`00Oomoo`0=Ool00`00Oomoo`0FOol2000=Ool01@00Oomoogoo00000Woo
00<007ooOol06Woo00<007ooOol027oo000KOol20006Ool00`00Oomoo`0mOol00`00Oomoo`0^Ool0
1P00Oomoo`00Ool000Eoo`05001oogooOol00005Ool01000Oomoo`000goo00D007ooOomoo`0000Ao
o`03001oogoo00=oo`03001oogoo00Moo`03001oogoo01Ioo`8000eoo`05001oogooOol00003Ool0
0`00Oomoo`0IOol00`00Oomoo`08Ool001]oo`03001oogoo00Eoo`03001oogoo03eoo`03001oogoo
02ioo`06001oogoo001oo`001Goo00D007ooOomoo`0000Eoo`04001oogoo0003Ool01@00Oomoogoo
000017oo00<007ooOol00goo0P0027oo00<007ooOol05goo00<007ooOol02goo00D007ooOomoo`00
00=oo`03001oogoo01Uoo`03001oogoo00Qoo`006goo00<007ooOol01Goo00<007ooOol0?Goo00<0
07ooOol0;Woo00H007ooOol007oo0006Ool200000goo001oo`04Ool00`00Ool00004Ool01@00Oomo
ogoo000017oo00<007ooOol00goo00<007oo00001goo00<007ooOol05goo00<007ooOol02goo00D0
07ooOomoo`0000=oo`03001oogoo00Aoo`03001oogoo019oo`03001oogoo00Qoo`004goo1@000goo
00<007ooOol0AGoo00<007ooOol0;Woo00H007ooOol007oo0008Ool20005Ool00`00Ool00004Ool0
1@00Oomoogoo000017oo00<007ooOol00goo00@007ooOol000Ioo`03001oogoo01Moo`03001oogoo
00]oo`04001oogoo0004Ool00`00Oomoo`02Ool200000goo001oo`0BOol00`00Oomoo`08Ool001Eo
o`03001oogoo00=oo`03001oogoo04Eoo`03001oogoo02ioo`06001oogoo001oo`0027oo0P001Goo
00<007oo000017oo00D007ooOomoo`0000Aoo`03001oogoo00=oo`05001oogooOol00005Ool00`00
Oomoo`0UOol01000Oomoo`0017oo00<007ooOol00Woo00D007ooOomoo`00019oo`03001oogoo00Qo
o`005Goo00<007ooOol00goo0P00AWoo00<007ooOol0;Woo00H007ooOol007oo0009Ool00`00Oomo
o`03Ool00`00Ool00004Ool01@00Oomoogoo00001Goo00D007ooOomoo`0000Eoo`03001oogoo009o
o`03001oogoo02Eoo`04001oogoo0004Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`0?
Ool00`00Oomoo`08Ool001Eoo`03001oogoo00=oo`03001oogoo04Eoo`03001oogoo02ioo`06001o
ogoo001oo`0047oo0P0017oo00@007ooOol000Ioo`05001oogooOol00005Ool00`00Oomoo`02Ool0
0`00Oomoo`0UOol01000Oomoo`0017oo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol03goo
00<007ooOol027oo000EOol00`00Oomoo`03Ool00`00Oomoo`15Ool00`00Oomoo`0]Ool01`00Oomo
ogoo001oo`00011oo`8000Aoo`04001oogoo0006Ool01@00Oomoogoo00001Woo00D007ooOomoo`00
02Qoo`03001oo`0000Aoo`03001oogoo009oo`03001oogoo00=oo`03001oogoo00eoo`03001oogoo
00Uoo`0057oo0P001Goo00<007ooOol0AGoo00<007ooOol0;Goo00L007ooOomoo`00Ool0000AOol0
0`00Oomoo`02Ool01000Oomoo`001Woo00D007ooOomoo`0000Moo`04001oogoo000XOol00`00Ool0
0004Ool00`00Oomoo`02Ool00`00Oomoo`04Ool00`00Oomoo`0<Ool00`00Oomoo`09Ool001]oo`80
04Ioo`03001oogoo02eoo`07001oogooOol007oo00005Woo00@007ooOol000Ioo`05001oogooOol0
0008Ool00`00Ool0000XOol00`00Ool00004Ool00`00Oomoo`02Ool00`00Oomoo`05Ool00`00Oomo
o`0;Ool00`00Oomoo`09Ool001]oo`03001oogoo04Eoo`03001oogoo02eoo`04001oogooOol2000H
Ool00`00Ool00006Ool01@00Oomoogoo00002Goo0P00:7oo00<007oo00001Goo00@007ooOol000Uo
o`03001oogoo00Yoo`03001oogoo00Uoo`006goo00<007ooOol0AGoo00<007ooOol0;Goo00@007oo
Oomoo`8001Qoo`03001oo`0000Ioo`05001oogooOol0000:Ool00`00Oomoo`0VOol00`00Ool00005
Ool01000Oomoo`002Woo00<007ooOol02Goo00<007ooOol02Goo000KOol00`00Oomoo`15Ool00`00
Oomoo`0]Ool01000Oomoogoo0P0067oo00<007oo00001Woo00D007ooOomoo`0003=oo`03001oo`00
00Eoo`04001oogoo000:Ool00`00Oomoo`09Ool00`00Oomoo`09Ool001]oo`8004Ioo`03001oogoo
00Aoo`03001oogoo02Ioo`04001oogooOol2000HOol20007Ool01@00Oomoogoo0000<goo00<007oo
00001Goo00@007ooOol000Yoo`03001oogoo00Uoo`03001oogoo00Uoo`006goo00<007ooOol0AGoo
00<007ooOol017oo00<007ooOol09Woo00<007ooOol00Woo00<007ooOol05Woo0P001goo00@007oo
Ool003Aoo`03001oo`0000Eoo`04001oogoo000;Ool00`00Oomoo`08Ool00`00Oomoo`09Ool001]o
o`03001oogoo04Eoo`03001oogoo00Aoo`80029oo`05001oogooOol00005Ool00`00Oomoo`0FOol2
0007Ool01000Oomoo`00=7oo0P001Woo00@007ooOol000]oo`03001oogoo00Qoo`03001oogoo00Uo
o`006goo00<007ooOol0AGoo00<007ooOol017oo0P0087oo0P0000Eoo`00Oomoo`0000Eoo`03001o
ogoo01Ioo`8000Moo`04001oogoo000dOol20006Ool01000Oomoo`002goo00<007ooOol027oo00<0
07ooOol02Goo000KOol20016Ool00`00Oomoo`04Ool2000POol01`00Oomoogoo001oo`0000Eoo`03
001oogoo01Ioo`03001oogoo00Ioo`04001oogoo000eOol00`00Oomoo`04Ool01000Oomoo`002goo
00<007ooOol027oo00<007ooOol02Goo000KOol00`00Oomoo`15Ool00`00Oomoo`04Ool2000POol0
0`00Oomoo`02Ool20005Ool00`00Oomoo`0FOol00`00Oomoo`06Ool01000Oomoo`00=Goo00<007oo
Ool017oo00@007ooOol000]oo`03001oogoo00Qoo`03001oogoo00Uoo`006goo00<007ooOol0AGoo
00<007ooOol017oo00<007oo00001Goo00<007ooOol05goo00<007ooOol00goo00<007ooOol00goo
00<007ooOol07goo00@007ooOol003Eoo`03001oogoo00Eoo`03001oo`0000]oo`03001oogoo00Ao
o`05001oogooOol0000;Ool001]oo`03001oogoo04Eoo`03001oogoo00Aoo`03001oo`0000Eoo`80
01Qoo`03001oogoo00Uoo`03001oogoo01moo`04001oogoo000eOol00`00Oomoo`05Ool00`00Ool0
000<Ool00`00Oomoo`03Ool20002Ool00`00Oomoo`09Ool001]oo`8004Ioo`03001oogoo00=oo`04
001oogoo0005Ool00`00Ool0000GOol00`00Oomoo`09Ool00`00Oomoo`0POol2000fOol00`00Oomo
o`05Ool00`00Ool0000<Ool00`00Oomoo`03Ool01@00Ool007oo00002goo000KOol00`00Oomoo`15
Ool00`00Oomoo`03Ool01000Oomoo`001Goo00@007ooOol001Ioo`03001oogoo02aoo`8003ioo`03
001oo`0000aoo`03001oogoo009oo`04001oogooOol2000;Ool001]oo`03001oogoo04Ioo`03001o
ogoo009oo`04001oogoo0005Ool01@00Oomoogoo00003goo00<007ooOol00Woo00<007ooOol0;Goo
0P00?Woo00<007oo000037oo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol02Goo0009Ool5
0002Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`16Ool00`00Oomoo`02Ool01000Oomo
o`001Goo00D007ooOomoo`0000moo`8000=oo`03001oogoo02eoo`8003ioo`8000eoo`03001oogoo
009oo`03001oogoo00ioo`002goo00<007ooOol01Woo00<007oo000017oo00<007ooOol0AWoo00<0
07ooOol00Woo00@007ooOol000Eoo`05001oogooOol0000?Ool20003Ool00`00Oomoo`0]Ool2000n
Ool2000=Ool00`00Oomoo`02Ool00`00Oomoo`0>Ool000]oo`03001oogoo00Qoo`03001oogoo009o
o`8004Moo`03001oogoo009oo`04001oogoo0004Ool00`00Oomoo`02Ool00`00Oomoo`0=Ool00`00
Ool00002Ool00`00Oomoo`0]Ool2000nOol2000=Ool00`00Oomoo`02Ool00`00Oomoo`0>Ool000]o
o`03001oogoo00Ioo`8000Eoo`03001oogoo04Ioo`03001oogoo009oo`05001oogooOol00003Ool0
0`00Oomoo`02Ool00`00Oomoo`0<Ool01000Oomoo`000Woo00<007ooOol0;Goo00<007ooOol0?Woo
00<007ooOol02goo00<007ooOol00Woo00<007ooOol03Woo000;Ool00`00Oomoo`06Ool00`00Oomo
o`04Ool00`00Oomoo`16Ool00`00Oomoo`02Ool01@00Oomoogoo00000goo00<007ooOol00Woo00<0
07ooOol037oo00@007ooOol0009oo`03001oogoo02eoo`03001oogoo03ioo`03001oogoo00]oo`05
001oogooOol0000AOol000Yoo`8000Qoo`<000Aoo`03001oogoo04Ioo`03001oogoo009oo`05001o
ogooOol00003Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`06Ool01000Oomoo`000Woo
00<007ooOol0;Goo00<007ooOol0?Woo00<007ooOol02goo00D007ooOomoo`00015oo`006goo0P00
Agoo00<007ooOol00Woo00D007ooOomoo`0000=oo`03001oogoo009oo`03001oogoo009oo`03001o
o`0000Moo`04001oogoo0002Ool00`00Oomoo`1^Ool00`00Oomoo`0<Ool01000Oomoo`004Goo000K
Ool00`00Oomoo`16Ool00`00Oomoo`02Ool01@00Oomoogoo00000goo00<007ooOol00Woo00D007oo
Oomoo`0000=oo`03001oogoo00Aoo`04001oogoo0002Ool00`00Oomoo`1^Ool00`00Oomoo`0<Ool0
1000Oomoo`004Goo000KOol00`00Oomoo`16Ool00`00Oomoo`02Ool01@00Oomoogoo00000goo00<0
07ooOol00goo00@007ooOol000Aoo`03001oogoo00=oo`07001oogooOol007oo0000Ogoo00@007oo
Ool0015oo`006goo00<007ooOol0AWoo00<007ooOol00Woo00D007ooOomoo`0000=oo`03001oogoo
00=oo`04001oogoo0005Ool00`00Oomoo`02Ool01`00Oomoogoo001oo`0007moo`04001oogoo000A
Ool001]oo`8004Moo`03001oogoo009oo`05001oogooOol00003Ool00`00Oomoo`03Ool01000Oomo
o`001Woo00@007ooOol000Aoo`03001oo`0007moo`04001oogoo000AOol001]oo`03001oogoo04Io
o`05001oogooOol00004Ool01@00Oomoogoo00001Goo00@007ooOol000Moo`03001oo`0000Aoo`03
001oo`0007moo`03001oo`00019oo`006goo00<007ooOol0AWoo00D007ooOomoo`0000Aoo`05001o
ogooOol00005Ool01000Oomoo`0027oo0P0017oo00<007oo0000Ogoo00<007oo00004Woo000KOol0
0`00Oomoo`16Ool01@00Oomoogoo000017oo00D007ooOomoo`0000Eoo`04001oogoo0009Ool00`00
Oomoo`02Ool20020Ool00`00Ool0000BOol001]oo`8004Qoo`04001oogoo0004Ool01@00Oomoogoo
00001Goo00<007oo00003goo0P00P7oo00<007oo00004Woo000KOol00`00Oomoo`18Ool00`00Ool0
0004Ool01@00Oomoogoo00001Goo00<007oo00003goo0P00P7oo00<007oo00004Woo000KOol00`00
Oomoo`19Ool20004Ool01000Oomoo`001Woo00<007oo000047oo00<007ooOol0OWoo00<007oo0000
4Woo000KOol00`00Oomoo`19Ool20005Ool00`00Ool00006Ool00`00Ool0000@Ool00`00Oomoo`1n
Ool00`00Ool0000BOol001]oo`8004]oo`03001oogoo00=oo`03001oo`0000Ioo`03001oo`00011o
o`03001oogoo07moo`80019oo`006goo00<007ooOol0D7oo00<007oo00001Woo00<007oo000047oo
00<007ooOol0Ogoo0P004Woo000DOol30004Ool00`00Oomoo`1@Ool00`00Ool00006Ool00`00Ool0
000@Ool00`00Oomoo`1oOol00`00Oomoo`0AOol001Aoo`03001oogoo00Aoo`03001oogoo051oo`03
001oo`0000Ioo`03001oo`00099oo`03001oogoo015oo`005Goo00<007ooOol00goo0P00DGoo00<0
07oo00001Woo00<007oo0000TWoo00<007ooOol04Goo000EOol00`00Oomoo`03Ool00`00Oomoo`1@
Ool00`00Ool00006Ool00`00Ool0002BOol00`00Oomoo`0AOol001Aoo`03001oo`0000Aoo`03001o
ogoo051oo`8000Qoo`80099oo`03001oogoo015oo`005Goo00<007ooOol00goo00<007ooOol0FWoo
0P00YWoo000KOol00`00Oomoo`1JOol00`00Oomoo`2UOol001]oo`8005]oo`03001oogoo0:Eoo`00
6goo00<007ooOol0FWoo00<007ooOol0YGoo000KOol00`00Oomoo`1JOol00`00Oomoo`2UOol001]o
o`03001oogoo05Yoo`03001oogoo0:Eoo`006goo0P00Fgoo00<007ooOol0YGoo000KOol00`00Oomo
o`1JOol00`00Oomoo`2UOol001]oo`03001oogoo0?moo`=oo`006goo00<007ooOol0ogoo0goo000K
Ool2003oOol4Ool001]oo`03001oogoo0?moo`=oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo
8Goo003oOolQOol00?moob5oo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-13.8066, -1.75474, 
  0.505252, 0.0239377}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Fourier Analysis", "Subsection"],

Cell["\<\
Again, calculate the coefficients of the Fourier series expansion of the \
boundary representation. The sequence ncc, unlike the earlier case of the \
sequence u, is an intrinsic shape function. It exhibits the desired \
invariance to affine transformations.\
\>", "Text"],

Cell["Analysis: Fourier descriptors.", "Subsubsection"],

Cell[BoxData[
    \(\(NCC = InverseFourier[ncc]; \)\)], "Input",
  CellLabel->"In[133]:="],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(DiscretePlot[Abs[Drop[NCC, \(-\(Length[NCC]\/2\)\)]], 
      PlotJoined \[Rule] True, PlotRange \[Rule] All]; \)\)], "Input",
  CellLabel->"In[134]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0151172 0.0147151 0.0786142 [
[.17498 .00222 -6 -9 ]
[.17498 .00222 6 0 ]
[.32615 .00222 -6 -9 ]
[.32615 .00222 6 0 ]
[.47732 .00222 -6 -9 ]
[.47732 .00222 6 0 ]
[.6285 .00222 -6 -9 ]
[.6285 .00222 6 0 ]
[.77967 .00222 -6 -9 ]
[.77967 .00222 6 0 ]
[.93084 .00222 -6 -9 ]
[.93084 .00222 6 0 ]
[.01131 .09333 -6 -4.5 ]
[.01131 .09333 0 4.5 ]
[.01131 .17194 -6 -4.5 ]
[.01131 .17194 0 4.5 ]
[.01131 .25056 -6 -4.5 ]
[.01131 .25056 0 4.5 ]
[.01131 .32917 -6 -4.5 ]
[.01131 .32917 0 4.5 ]
[.01131 .40779 -6 -4.5 ]
[.01131 .40779 0 4.5 ]
[.01131 .4864 -6 -4.5 ]
[.01131 .4864 0 4.5 ]
[.01131 .56501 -6 -4.5 ]
[.01131 .56501 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.17498 .01472 m
.17498 .02097 L
s
[(10)] .17498 .00222 0 1 Mshowa
.32615 .01472 m
.32615 .02097 L
s
[(20)] .32615 .00222 0 1 Mshowa
.47732 .01472 m
.47732 .02097 L
s
[(30)] .47732 .00222 0 1 Mshowa
.6285 .01472 m
.6285 .02097 L
s
[(40)] .6285 .00222 0 1 Mshowa
.77967 .01472 m
.77967 .02097 L
s
[(50)] .77967 .00222 0 1 Mshowa
.93084 .01472 m
.93084 .02097 L
s
[(60)] .93084 .00222 0 1 Mshowa
.125 Mabswid
.05404 .01472 m
.05404 .01847 L
s
.08428 .01472 m
.08428 .01847 L
s
.11451 .01472 m
.11451 .01847 L
s
.14475 .01472 m
.14475 .01847 L
s
.20522 .01472 m
.20522 .01847 L
s
.23545 .01472 m
.23545 .01847 L
s
.26568 .01472 m
.26568 .01847 L
s
.29592 .01472 m
.29592 .01847 L
s
.35639 .01472 m
.35639 .01847 L
s
.38662 .01472 m
.38662 .01847 L
s
.41686 .01472 m
.41686 .01847 L
s
.44709 .01472 m
.44709 .01847 L
s
.50756 .01472 m
.50756 .01847 L
s
.53779 .01472 m
.53779 .01847 L
s
.56803 .01472 m
.56803 .01847 L
s
.59826 .01472 m
.59826 .01847 L
s
.65873 .01472 m
.65873 .01847 L
s
.68896 .01472 m
.68896 .01847 L
s
.7192 .01472 m
.7192 .01847 L
s
.74943 .01472 m
.74943 .01847 L
s
.8099 .01472 m
.8099 .01847 L
s
.84014 .01472 m
.84014 .01847 L
s
.87037 .01472 m
.87037 .01847 L
s
.9006 .01472 m
.9006 .01847 L
s
.96107 .01472 m
.96107 .01847 L
s
.99131 .01472 m
.99131 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02381 .09333 m
.03006 .09333 L
s
[(1)] .01131 .09333 1 0 Mshowa
.02381 .17194 m
.03006 .17194 L
s
[(2)] .01131 .17194 1 0 Mshowa
.02381 .25056 m
.03006 .25056 L
s
[(3)] .01131 .25056 1 0 Mshowa
.02381 .32917 m
.03006 .32917 L
s
[(4)] .01131 .32917 1 0 Mshowa
.02381 .40779 m
.03006 .40779 L
s
[(5)] .01131 .40779 1 0 Mshowa
.02381 .4864 m
.03006 .4864 L
s
[(6)] .01131 .4864 1 0 Mshowa
.02381 .56501 m
.03006 .56501 L
s
[(7)] .01131 .56501 1 0 Mshowa
.125 Mabswid
.02381 .03044 m
.02756 .03044 L
s
.02381 .04616 m
.02756 .04616 L
s
.02381 .06188 m
.02756 .06188 L
s
.02381 .07761 m
.02756 .07761 L
s
.02381 .10905 m
.02756 .10905 L
s
.02381 .12477 m
.02756 .12477 L
s
.02381 .1405 m
.02756 .1405 L
s
.02381 .15622 m
.02756 .15622 L
s
.02381 .18767 m
.02756 .18767 L
s
.02381 .20339 m
.02756 .20339 L
s
.02381 .21911 m
.02756 .21911 L
s
.02381 .23483 m
.02756 .23483 L
s
.02381 .26628 m
.02756 .26628 L
s
.02381 .282 m
.02756 .282 L
s
.02381 .29773 m
.02756 .29773 L
s
.02381 .31345 m
.02756 .31345 L
s
.02381 .34489 m
.02756 .34489 L
s
.02381 .36062 m
.02756 .36062 L
s
.02381 .37634 m
.02756 .37634 L
s
.02381 .39206 m
.02756 .39206 L
s
.02381 .42351 m
.02756 .42351 L
s
.02381 .43923 m
.02756 .43923 L
s
.02381 .45495 m
.02756 .45495 L
s
.02381 .47068 m
.02756 .47068 L
s
.02381 .50212 m
.02756 .50212 L
s
.02381 .51785 m
.02756 .51785 L
s
.02381 .53357 m
.02756 .53357 L
s
.02381 .54929 m
.02756 .54929 L
s
.02381 .58074 m
.02756 .58074 L
s
.02381 .59646 m
.02756 .59646 L
s
.02381 .61218 m
.02756 .61218 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
.5 Mabswid
.02381 .01472 m
.02381 .60332 L
s
.03893 .01472 m
.03893 .15953 L
s
.05404 .01472 m
.05404 .32597 L
s
.06916 .01472 m
.06916 .16301 L
s
.08428 .01472 m
.08428 .2026 L
s
.0994 .01472 m
.0994 .06843 L
s
.11451 .01472 m
.11451 .13279 L
s
.12963 .01472 m
.12963 .05206 L
s
.14475 .01472 m
.14475 .08864 L
s
.15986 .01472 m
.15986 .08372 L
s
.17498 .01472 m
.17498 .0422 L
s
.1901 .01472 m
.1901 .08009 L
s
.20522 .01472 m
.20522 .05667 L
s
.22033 .01472 m
.22033 .02975 L
s
.23545 .01472 m
.23545 .05361 L
s
.25057 .01472 m
.25057 .05751 L
s
.26568 .01472 m
.26568 .04817 L
s
.2808 .01472 m
.2808 .04104 L
s
.29592 .01472 m
.29592 .07185 L
s
.31104 .01472 m
.31104 .02272 L
s
.32615 .01472 m
.32615 .06035 L
s
.34127 .01472 m
.34127 .04445 L
s
.35639 .01472 m
.35639 .04275 L
s
.3715 .01472 m
.3715 .06727 L
s
.38662 .01472 m
.38662 .02871 L
s
.40174 .01472 m
.40174 .05872 L
s
.41686 .01472 m
.41686 .05882 L
s
.43197 .01472 m
.43197 .04355 L
s
.44709 .01472 m
.44709 .06166 L
s
.46221 .01472 m
.46221 .0663 L
s
.47732 .01472 m
.47732 .01958 L
s
.49244 .01472 m
.49244 .08419 L
s
.50756 .01472 m
.50756 .03737 L
s
.52268 .01472 m
.52268 .03126 L
s
.53779 .01472 m
.53779 .0305 L
s
.55291 .01472 m
.55291 .01993 L
s
.56803 .01472 m
.56803 .02979 L
s
.58314 .01472 m
.58314 .06094 L
s
.59826 .01472 m
.59826 .03147 L
s
.61338 .01472 m
.61338 .03351 L
s
.6285 .01472 m
.6285 .044 L
s
.64361 .01472 m
.64361 .04133 L
s
.65873 .01472 m
.65873 .02273 L
s
.67385 .01472 m
.67385 .04221 L
s
.68896 .01472 m
.68896 .02804 L
s
.70408 .01472 m
.70408 .03115 L
s
.7192 .01472 m
.7192 .04244 L
s
.73432 .01472 m
.73432 .0318 L
s
.74943 .01472 m
.74943 .03194 L
s
.76455 .01472 m
.76455 .02603 L
s
.77967 .01472 m
.77967 .03197 L
s
.79478 .01472 m
.79478 .02525 L
s
.8099 .01472 m
.8099 .02149 L
s
.82502 .01472 m
.82502 .02394 L
s
.84014 .01472 m
.84014 .0166 L
s
.85525 .01472 m
.85525 .03648 L
s
.87037 .01472 m
.87037 .03187 L
s
.88549 .01472 m
.88549 .02642 L
s
.9006 .01472 m
.9006 .02581 L
s
.91572 .01472 m
.91572 .03335 L
s
.93084 .01472 m
.93084 .04466 L
s
.94596 .01472 m
.94596 .02393 L
s
.96107 .01472 m
.96107 .02449 L
s
.97619 .01472 m
.97619 .03426 L
s
.02 w
.02381 .60332 Mdot
.03893 .15953 Mdot
.05404 .32597 Mdot
.06916 .16301 Mdot
.08428 .2026 Mdot
.0994 .06843 Mdot
.11451 .13279 Mdot
.12963 .05206 Mdot
.14475 .08864 Mdot
.15986 .08372 Mdot
.17498 .0422 Mdot
.1901 .08009 Mdot
.20522 .05667 Mdot
.22033 .02975 Mdot
.23545 .05361 Mdot
.25057 .05751 Mdot
.26568 .04817 Mdot
.2808 .04104 Mdot
.29592 .07185 Mdot
.31104 .02272 Mdot
.32615 .06035 Mdot
.34127 .04445 Mdot
.35639 .04275 Mdot
.3715 .06727 Mdot
.38662 .02871 Mdot
.40174 .05872 Mdot
.41686 .05882 Mdot
.43197 .04355 Mdot
.44709 .06166 Mdot
.46221 .0663 Mdot
.47732 .01958 Mdot
.49244 .08419 Mdot
.50756 .03737 Mdot
.52268 .03126 Mdot
.53779 .0305 Mdot
.55291 .01993 Mdot
.56803 .02979 Mdot
.58314 .06094 Mdot
.59826 .03147 Mdot
.61338 .03351 Mdot
.6285 .044 Mdot
.64361 .04133 Mdot
.65873 .02273 Mdot
.67385 .04221 Mdot
.68896 .02804 Mdot
.70408 .03115 Mdot
.7192 .04244 Mdot
.73432 .0318 Mdot
.74943 .03194 Mdot
.76455 .02603 Mdot
.77967 .03197 Mdot
.79478 .02525 Mdot
.8099 .02149 Mdot
.82502 .02394 Mdot
.84014 .0166 Mdot
.85525 .03648 Mdot
.87037 .03187 Mdot
.88549 .02642 Mdot
.9006 .02581 Mdot
.91572 .03335 Mdot
.93084 .04466 Mdot
.94596 .02393 Mdot
.96107 .02449 Mdot
.97619 .03426 Mdot
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[134]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo000cOol5
0002Ool00`00Oomoo`0POol30003Ool00`00Oomoo`0POol20004Ool00`00Oomoo`0ROol30002Ool0
0`00Oomoo`0QOol00`00Oomoo`02Ool00`00Oomoo`0POol20004Ool00`00Oomoo`0EOol003Eoo`07
001oogooOol007oo00008Goo00<007ooOol00Woo00<007oo00008goo00H007ooOol007oo000TOol0
1P00Oomoo`00Ool0025oo`03001oo`00009oo`03001oo`00025oo`03001oo`00009oo`03001oo`00
01Ioo`00=Goo00L007ooOomoo`00Ool0000ROol01`00Oomoogoo001oo`00029oo`07001oogooOol0
07oo00008Woo100000Aoo`00Ool002=oo`06001oogoo001oo`008Goo00<007oo00000Woo00<007oo
00005Woo000eOol01`00Oomoogoo001oo`00029oo`07001oogooOol007oo00008goo00H007ooOol0
07oo000ROol00`00Ool00002Ool00`00Ool0000QOol20003Ool00`00Ool0000QOol20003Ool00`00
Ool0000FOol003Eoo`07001oogooOol007oo00008Goo00<007oo00000Woo00<007oo00008Goo00<0
07oo00000Woo00<007oo00008goo0P000Woo00<007oo00008Goo00<007ooOol00Woo00<007oo0000
8Goo00<007ooOol00Woo00<007oo00005Woo000dOol20004Ool00`00Oomoo`0QOol00`00Oomoo`02
Ool00`00Oomoo`0QOol00`00Oomoo`02Ool00`00Oomoo`0SOol01@00Oomoogoo00008Woo0`000goo
00<007ooOol08Goo0P000goo00<007ooOol05Goo003oOolQOol000moo`03001oogoo0?moo`moo`00
3goo00<007ooOol0ogoo3goo000?Ool00`00Oomoo`3oOol?Ool000moo`03001oogoo07Moo`<0061o
o`<0035oo`0027ooo`004`001Woo000?Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05
001oogooOol00003Ool01@00Oomoogoo000017oo00D007ooOomoo`0000=oo`05001oogooOol00003
Ool01@00Oomoogoo00000goo00D007ooOomoo`0000Aoo`05001oogooOol00003Ool00`00Ool00004
00000goo001oo`02Ool01@00Oomoogoo00000goo00<007ooOol00Woo00D007ooOomoo`0000=oo`05
001oogooOol00003Ool01P00Oomoogoo001oo`D00003Ool007oo00=oo`05001oogooOol00003Ool0
0`00Ool0000400000goo001oo`02Ool01@00Oomoogoo00000goo00<007ooOol00Woo00H007ooOomo
o`00Ool500000goo001oo`02Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`03001oogoo
00<000=oo`03001oogoo01000003Ool007oo009oo`03001oogoo00<0009oo`<0009oo`05001oogoo
Ool00002Ool3000017oo000000000Woo00D007ooOomoo`0000Uoo`003goo00D007ooOomoo`0000=o
o`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000Aoo`05001oogooOol0
0003Ool01@00Oomoogoo00000goo00<007ooOol00`000Woo00D007ooOomoo`0000Aoo`05001oogoo
Ool00003Ool00`00Ool0000400000goo001oo`02Ool01@00Oomoogoo00000goo00<007ooOol00`00
0goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool00`00Ool0000400000goo001oo`03Ool0
1@00Oomoogoo00000Woo2`000Woo00D007ooOomoo`0000=oo`03001oogoo009oo`06001oogooOol0
07oo1@0000Aoo`00Oomoo`<0009oo`05001oogooOol00003Ool01P00Oomoogoo001oo`D0009oo`03
001oo`0001000003Ool007oo009oo`03001oo`0000T00003Ool007oo009oo`03001oo`0000P00003
Ool007oo00aoo`003goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo0000
0goo00D007ooOomoo`0000Aoo`05001oogooOol00003Ool01@00Oomoogoo00000goo00<007oo0000
100000=oo`00Ool00Woo00<007ooOol00Woo00D007ooOomoo`0000=oo`03001oo`0000@00003Ool0
07oo009oo`05001oogooOol00003Ool00`00Ool000040002Ool01@00Oomoogoo00000goo00D007oo
Oomoo`0000=oo`03001oogoo00<0009oo`03001oogoo009oo`03001oo`0000800003Ool0000000/0
0004Ool007ooOol3000017oo000000000goo00H007ooOomoo`00Ool500000goo001oo`080002Ool0
0`00Oomoo`0300000goo0000000600000goo0000000A0002Ool00`00Oomoo`0@0002Ool00`00Ool0
000;000<Ool000moo`80009oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomo
o`0000=oo`03001oogoo009oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00<007oo0000
100000=oo`00Ool00Woo00<007ooOol00Woo00D007ooOomoo`0000=oo`03001oogoo00<0009oo`05
001oogooOol00003Ool01P00Oomoogoo001oo`D0009oo`05001oogooOol00003Ool01@00Oomoogoo
00000goo00<007ooOol01Goo00<007ooOol05@0000=oo`00Ool02@000Woo00D007ooOomoo`00009o
o`<0009oo`03001oo`0000P00003Ool007oo01h000AooaD00003Ool007oo00d000]oo`003goo00D0
07ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000Ao
o`05001oogooOol00003Ool01@00Oomoogoo00000goo00<007oo0000100000=oo`00Ool00Woo00<0
07ooOol00Woo00<007oo00000P000goo00<007ooOol01Goo00D007ooOomoo`0000=oo`06001oogoo
Ool007oo1@000Woo00D007ooOomoo`0000=oo`05001oogooOol00003Ool00`00Oomoo`05Ool00`00
Ool0000=0003Ool500000goo001oo`090002Ool00`00Ool000020007Ool00`00Ool0000800000goo
001oo`0<00000goo000000060005Ool30004Ool<0002Ool8000017oo001oogoo0`0000=oo`000000
1P002goo000?Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool0
1@00Oomoogoo000017oo00D007ooOomoo`00009oo`<0009oo`05001oogooOol00002Ool30002Ool0
1@00Oomoogoo000017oo1P000Woo00<007ooOol01Goo00<007ooOol00`0000Aoo`000000009oo`03
001oogoo00<000=oo`05001oogooOol00002Ool30002Ool01@00Oomoogoo00001goo00<007oo0000
200000Aoo`00000000Eoo`<0009oo`03001oo`00010000Eoo`<00003Ool00000018000Aoo`D000mo
o`T000Qoo`P000Qoo`D000]oo`003goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00
Oomoogoo00000goo00D007ooOomoo`0000Aoo`06001oogooOol007oo1@0000=oo`00Ool00Woo00<0
07ooOol01Goo00D007ooOomoo`00009oo`P0009oo`03001oogoo00Eoo`03001oo`0000P00003Ool0
07oo00Moo`06001oogooOol007oo1@0000=oo`00Ool00Woo00<007ooOol01Goo00<007oo00001`00
3goo00<007ooOol00`0000=oo`0000002P0017oo1@0017oo2`0000Aoo`00000000Ioo`<0011oo`P0
00Yoo`P000Qoo`<000aoo`003goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomo
ogoo00000goo00<007ooOol00`000goo00H007ooOomoo`00Ool500000goo001oo`02Ool00`00Oomo
o`05Ool01P00Oomoogoo001oo`T0009oo`03001oogoo00Eoo`03001oo`0000P00003Ool007oo00Mo
o`06001oogooOol007oo1@0000=oo`00Ool00Woo00<007ooOol01Goo00<007ooOol00`004goo00<0
07ooOol01goo2@0017oo1@001goo1@008Goo0`004Goo1@005goo000?Ool20002Ool01@00Oomoogoo
00000goo00D007ooOomoo`0000=oo`06001oogooOol007oo1@000Woo00H007ooOomoo`00Ool50000
0goo001oo`02Ool00`00Oomoo`04Ool30002Ool00`00Ool000070003Ool00`00Oomoo`05Ool00`00
Ool0000800000goo001oo`07Ool01P00Oomoogoo001oo`D00003Ool007oo009oo`03001oogoo00Eo
o`03001oogoo01Ioo`03001oogoo00Moo`P000Eoo`D000Moo`D003Eoo`D001Moo`003goo00D007oo
Oomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00<007oo000010000Woo00D0
07ooOomoo`00009oo`<0009oo`03001oogoo00<000Aoo`d000Ioo`03001oogoo00Eoo`03001oogoo
00<00004Ool000000002Ool00`00Oomoo`04Ool30002Ool3000017oo000000000Woo00D007ooOomo
o`0000Moo`03001oogoo01Ioo`03001oogoo00Qoo`<000Yoo`<000Uoo`<003Moo`<001Qoo`003goo
00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00<007oo00001000
0Woo00D007ooOomoo`0000Moo`03001oo`0000@000=oo``000Moo`03001oogoo00Aoo`<000Yoo`03
001oogoo00=oo`X000Aoo`<0009oo`03001oogoo00Eoo`03001oogoo01Eoo`<007Moo`003goo00D0
07ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00<007ooOol00`000goo
00D007ooOomoo`0000Moo`03001oo`0000@000=oo`T000Yoo`03001oogoo00=oo`D000Qoo`<000Ao
o`X000=oo`P000Ioo`03001oogoo01Aoo`D007Ioo`003goo0P000Woo00D007ooOomoo`0000=oo`05
001oogooOol00002Ool30002Ool00`00Oomoo`06Ool01@00Oomoogoo00001goo00<007oo00001000
17oo20002Woo00<007ooOol00goo1@001goo1@000goo2P000goo2@001Goo00<007ooOol057oo1@00
MWoo000?Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`03001oo`0000@00003Ool007oo
00Moo`05001oogooOol00007Ool00`00Oomoo`030009Ool3000:Ool30004Ool50007Ool50004Ool3
0002Ool30004Ool90005Ool00`00Oomoo`0DOol5001fOol000moo`05001oogooOol00003Ool01@00
Oomoogoo00000goo00<007oo0000100000=oo`00Ool01goo00D007ooOomoo`0000Moo`03001oogoo
01Qoo`D000Aoo`<000Qoo`D0015oo`P000Eoo`03001oogoo01Eoo`<007Moo`003goo00D007ooOomo
o`0000=oo`05001oogooOol00003Ool00`00Ool0000400000goo001oo`07Ool01@00Oomoogoo0000
1Woo0`006Goo1@0047oo0`005Woo0`001Woo00<007ooOol0Sgoo000?Ool20002Ool01@00Oomoogoo
00000goo00D007ooOomoo`00009oo`<0009oo`03001oogoo00Ioo`03001oogoo00<000Aoo`D001Qo
o`D0035oo`<0091oo`003goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool00`00Oomoo`05
Ool00`00Oomoo`04Ool300000goo000000030003Ool5000IOol3000aOol5002?Ool000Ioo`D000Ao
o`05001oogooOol00003Ool01@00Oomoogoo00000goo00<007ooOol01Goo00<007ooOol00goo2P00
0goo1@00CGoo1@00Sgoo0008Ool00`00Oomoo`04Ool01@00Oomoogoo00000goo00D007ooOomoo`00
00=oo`03001oogoo00Eoo`03001oogoo00=oo`X000Aoo`<004ioo`D008moo`0027oo00<007ooOol0
17oo0P000Woo00D007ooOomoo`0000=oo`05001oogooOol00007Ool00`00Oomoo`03Ool5000017oo
00000000Egoo0`00T7oo0008Ool00`00Oomoo`04Ool01@00Oomoogoo00000goo00D007ooOomoo`00
00=oo`03001oogoo00Eoo`03001oogoo00Aoo`<00>moo`0027oo00<007ooOol017oo00D007ooOomo
o`0000=oo`05001oogooOol00003Ool00`00Oomoo`05Ool00`00Oomoo`3fOol000Moo`8000Ioo`05
001oogooOol00003Ool01@00Oomoogoo00000goo00<007ooOol01Goo00<007ooOol0mWoo000?Ool0
1@00Oomoogoo00000goo00D007ooOomoo`0000=oo`03001oogoo00Eoo`03001oogoo0?Ioo`003goo
0P000Woo00D007ooOomoo`0000=oo`05001oogooOol00007Ool00`00Oomoo`3fOol000moo`05001o
ogooOol00003Ool01@00Oomoogoo00000goo00<007ooOol01Goo00<007ooOol0mWoo000?Ool01@00
Oomoogoo00000goo00D007ooOomoo`0000=oo`03001oogoo00Eoo`03001oogoo0?Ioo`003goo00D0
07ooOomoo`0000=oo`05001oogooOol00003Ool00`00Oomoo`05Ool00`00Oomoo`3fOol000moo`80
009oo`05001oogooOol00003Ool01@00Oomoogoo00001Woo0`00mgoo000?Ool01@00Oomoogoo0000
0goo00D007ooOomoo`0000=oo`03001oogoo00=oo`D00?Ioo`003goo00D007ooOomoo`0000=oo`05
001oogooOol00003Ool00`00Oomoo`03Ool5003fOol000moo`05001oogooOol00003Ool01@00Oomo
ogoo00000goo00<007ooOol00goo1@00mWoo000?Ool20002Ool01@00Oomoogoo00000goo00D007oo
Oomoo`0000Ioo`<00?Moo`003goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool00`00Oomo
o`3nOol000moo`05001oogooOol00003Ool01@00Oomoogoo00000goo00<007ooOol0oWoo000?Ool0
1@00Oomoogoo00000goo00D007ooOomoo`0000=oo`03001oogoo0?ioo`003goo00<007ooOol00`00
0Woo00D007ooOomoo`0000=oo`03001oogoo0?ioo`003goo1`0000Aoo`00Oomoo`<0009oo`03001o
ogoo0?ioo`003goo00<007oo0000100000=oo`00Ool01@0000=oo`00Ool0ogoo0007Ool30005Ool0
0`00Ool0000400000goo001oo`0500000goo001oo`3oOol000Moo`03001oogoo00Eoo`03001oogoo
00<0009oo`03001oo`0000@00003Ool007oo0?moo`0027oo00<007ooOol017oo0P001Woo00<007oo
Ool00`000Woo00<007ooOol0oWoo0008Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`05
Ool00`00Oomoo`3nOol000Moo`03001oo`0000Eoo`03001oogoo00Eoo`03001oogoo00Eoo`03001o
ogoo0?ioo`0027oo00<007ooOol017oo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol0oWoo
000?Ool20006Ool00`00Oomoo`05Ool00`00Oomoo`3nOol000moo`03001oogoo00Eoo`03001oogoo
00Eoo`03001oogoo0?ioo`003goo00<007ooOol01Goo00<007ooOol017oo0`00ogoo000?Ool00`00
Oomoo`05Ool00`00Oomoo`03Ool5003nOol000moo`8000Ioo`03001oogoo00=oo`D00?ioo`003goo
00<007ooOol01Goo00<007ooOol00goo1@00oWoo000?Ool00`00Oomoo`05Ool00`00Oomoo`04Ool3
003oOol000moo`03001oogoo00Eoo`03001oogoo0?moo`Moo`003goo00<007ooOol01Goo00<007oo
Ool0ogoo1goo000?Ool20006Ool00`00Oomoo`3oOol7Ool000moo`03001oogoo00Eoo`03001oogoo
0?moo`Moo`003goo00<007ooOol01Goo00<007ooOol0ogoo1goo000?Ool00`00Oomoo`05Ool00`00
Oomoo`3oOol7Ool000moo`8000Ioo`03001oogoo0?moo`Moo`003goo00<007ooOol01Goo00<007oo
Ool0ogoo1goo0007Ool20006Ool00`00Oomoo`05Ool00`00Oomoo`3oOol7Ool000Uoo`03001oogoo
00=oo`03001oogoo00Eoo`03001oogoo0?moo`Moo`0027oo00<007ooOol017oo0P001Woo00<007oo
Ool0ogoo1goo0009Ool00`00Oomoo`03Ool00`00Oomoo`05Ool00`00Oomoo`3oOol7Ool000Moo`03
001oo`0000Eoo`03001oogoo00Eoo`03001oogoo0?moo`Moo`0027oo00<007ooOol017oo00<007oo
Ool01Goo00<007ooOol0ogoo1goo000?Ool00`00Oomoo`05Ool00`00Oomoo`3oOol7Ool000moo`80
00Ioo`03001oogoo0?moo`Moo`003goo00<007ooOol01Goo00<007ooOol0ogoo1goo000?Ool00`00
Oomoo`05Ool00`00Oomoo`3oOol7Ool000moo`03001oogoo00Eoo`03001oogoo0?moo`Moo`003goo
0P001Woo00<007ooOol0ogoo1goo000?Ool00`00Oomoo`05Ool00`00Oomoo`3oOol7Ool000moo`03
001oogoo00Eoo`03001oogoo0?moo`Moo`003goo00<007ooOol01Goo00<007ooOol0ogoo1goo000?
Ool20006Ool00`00Oomoo`3oOol7Ool000moo`03001oogoo00Eoo`03001oogoo0?moo`Moo`003goo
00<007ooOol01Goo00<007ooOol0ogoo1goo000?Ool00`00Oomoo`05Ool00`00Oomoo`3oOol7Ool0
00moo`8000Ioo`03001oogoo0?moo`Moo`003goo00<007ooOol01Goo00<007ooOol0ogoo1goo000?
Ool00`00Oomoo`04Ool3003oOol8Ool000Qoo`<000Aoo`03001oogoo00=oo`D00?moo`Moo`002Goo
00<007ooOol00goo00<007ooOol00goo1@00ogoo1goo0007Ool40004Ool20004Ool5003oOol7Ool0
00Moo`03001oo`0000Eoo`03001oogoo00Aoo`<00?moo`Qoo`0027oo0P001Goo00<007ooOol0ogoo
3goo0009Ool00`00Oomoo`03Ool00`00Oomoo`3oOol?Ool000moo`800?mooa1oo`003goo00<007oo
Ool0ogoo3goo000?Ool00`00Oomoo`3oOol?Ool000moo`03001oogoo0?moo`moo`003goo0P00ogoo
47oo000?Ool00`00Oomoo`3oOol?Ool000moo`03001oogoo0?moo`moo`003goo00<007ooOol0ogoo
3goo000?Ool00`00Oomoo`3oOol?Ool000moo`800?mooa1oo`003goo00<007ooOol0ogoo3goo000?
Ool00`00Oomoo`3oOol?Ool000moo`03001oogoo0?moo`moo`003goo0P00ogoo47oo000?Ool00`00
Oomoo`3oOol?Ool000Qoo`03001oogoo00Aoo`03001oogoo0?moo`moo`001goo00<007oo00001Goo
00<007ooOol0ogoo3goo0009Ool00`00Oomoo`03Ool2003oOol@Ool000Moo`8000Ioo`03001oogoo
0?moo`moo`001goo00<007ooOol01Goo00<007ooOol0ogoo3goo0007Ool30005Ool00`00Oomoo`3o
Ool?Ool000moo`800?mooa1oo`003goo00<007ooOol0ogoo3goo000?Ool00`00Oomoo`3oOol?Ool0
00moo`03001oogoo0?moo`moo`003goo00<007ooOol0ogoo3goo000?Ool2003oOol@Ool000moo`03
001oogoo0?moo`moo`003goo00<007ooOol0ogoo3goo000?Ool00`00Oomoo`3oOol?Ool000moo`80
0?mooa1oo`003goo00<007ooOol0ogoo3goo000?Ool00`00Oomoo`3oOol?Ool000moo`03001oogoo
0?moo`moo`003goo0P00ogoo47oo000?Ool00`00Oomoo`3oOol?Ool000moo`03001oogoo0?moo`mo
o`001goo0P001Woo00<007ooOol0ogoo3goo0007Ool00`00Ool00005Ool00`00Oomoo`3oOol?Ool0
00Moo`03001oo`0000Eoo`800?mooa1oo`001goo0P001Woo00<007ooOol0ogoo3goo0007Ool00`00
Oomoo`05Ool00`00Oomoo`3oOol?Ool000Qoo`8000Eoo`03001oogoo0?moo`moo`003goo0P00ogoo
47oo000?Ool00`00Oomoo`3oOol?Ool000moo`03001oogoo0?moo`moo`003goo00<007ooOol0ogoo
3goo000?Ool2003oOol@Ool000moo`03001oogoo0?moo`moo`003goo00<007ooOol0ogoo3goo000?
Ool00`00Oomoo`3oOol?Ool000moo`800?mooa1oo`003goo00<007ooOol0ogoo3goo000?Ool00`00
Oomoo`3oOol?Ool000moo`03001oogoo0?moo`moo`003goo00<007ooOol0ogoo3goo000?Ool2003o
Ool@Ool000moo`03001oogoo0?moo`moo`0027oo00<007ooOol017oo00<007ooOol0ogoo3goo0008
Ool00`00Oomoo`04Ool00`00Oomoo`3oOol?Ool000Qoo`03001oogoo00Aoo`800?mooa1oo`002Goo
00<007ooOol00goo00<007ooOol0ogoo3goo0007Ool00`00Ool00005Ool00`00Oomoo`3oOol?Ool0
00Moo`<000Eoo`03001oogoo0?moo`moo`003goo0P00ogoo47oo000?Ool00`00Oomoo`3oOol?Ool0
00moo`03001oogoo0?moo`moo`003goo00<007ooOol0ogoo3goo000?Ool00`00Oomoo`3oOol?Ool0
00eoo`@00?mooa1oo`0037oo1@00ogoo47oo000<Ool5003oOol@Ool000aoo`D00?mooa1oo`003Goo
1000ogoo47oo000?Ool00`00Oomoo`3oOol?Ool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-3.6621, -0.578784, 
  0.242567, 0.0466447}}]
}, Open  ]],

Cell["Synthesis: Boundary reconstruction.", "Subsubsection"],

Cell["\<\
Here, the boundary will be reconstructed from a few low-order coefficients. \
Low-pass filtering is performed with a rectangular window, leading to \
significant ringing distortion. However, as can be seen below, the boundary \
is recognizable.\
\>", "Text"],

Cell[BoxData[
    \(low = 8; \n
    NCClow = Join[Take[NCC, low], Table[0, {L - 2  low + 1}], 
        Take[NCC, \(-low\) + 1]]\ ; \n
    datalow = 
      Chop[Fourier[NCClow] - Table[\(\((i - 1)\)\ 2\ N[\[Pi]]\)\/L, {i, L}]]; 
    \)], "Input",
  CellLabel->"In[135]:="],

Cell["\<\
Comparison of original and reconstructed cumulative curvature functions.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[{
        ListPlot[cc, PlotJoined \[Rule] True, 
          DisplayFunction \[Rule] Identity], 
        ListPlot[datalow, PlotJoined \[Rule] True, 
          DisplayFunction \[Rule] Identity]}, 
      DisplayFunction \[Rule] $DisplayFunction]; \)\)], "Input",
  CellLabel->"In[136]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00744048 0.536686 0.0832568 [
[.17262 .52419 -6 -9 ]
[.17262 .52419 6 0 ]
[.32143 .52419 -6 -9 ]
[.32143 .52419 6 0 ]
[.47024 .52419 -6 -9 ]
[.47024 .52419 6 0 ]
[.61905 .52419 -6 -9 ]
[.61905 .52419 6 0 ]
[.76786 .52419 -9 -9 ]
[.76786 .52419 9 0 ]
[.91667 .52419 -9 -9 ]
[.91667 .52419 9 0 ]
[.01131 .03715 -12 -4.5 ]
[.01131 .03715 0 4.5 ]
[.01131 .1204 -12 -4.5 ]
[.01131 .1204 0 4.5 ]
[.01131 .20366 -12 -4.5 ]
[.01131 .20366 0 4.5 ]
[.01131 .28692 -12 -4.5 ]
[.01131 .28692 0 4.5 ]
[.01131 .37017 -12 -4.5 ]
[.01131 .37017 0 4.5 ]
[.01131 .45343 -12 -4.5 ]
[.01131 .45343 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.17262 .53669 m
.17262 .54294 L
s
[(20)] .17262 .52419 0 1 Mshowa
.32143 .53669 m
.32143 .54294 L
s
[(40)] .32143 .52419 0 1 Mshowa
.47024 .53669 m
.47024 .54294 L
s
[(60)] .47024 .52419 0 1 Mshowa
.61905 .53669 m
.61905 .54294 L
s
[(80)] .61905 .52419 0 1 Mshowa
.76786 .53669 m
.76786 .54294 L
s
[(100)] .76786 .52419 0 1 Mshowa
.91667 .53669 m
.91667 .54294 L
s
[(120)] .91667 .52419 0 1 Mshowa
.125 Mabswid
.06101 .53669 m
.06101 .54044 L
s
.09821 .53669 m
.09821 .54044 L
s
.13542 .53669 m
.13542 .54044 L
s
.20982 .53669 m
.20982 .54044 L
s
.24702 .53669 m
.24702 .54044 L
s
.28423 .53669 m
.28423 .54044 L
s
.35863 .53669 m
.35863 .54044 L
s
.39583 .53669 m
.39583 .54044 L
s
.43304 .53669 m
.43304 .54044 L
s
.50744 .53669 m
.50744 .54044 L
s
.54464 .53669 m
.54464 .54044 L
s
.58185 .53669 m
.58185 .54044 L
s
.65625 .53669 m
.65625 .54044 L
s
.69345 .53669 m
.69345 .54044 L
s
.73065 .53669 m
.73065 .54044 L
s
.80506 .53669 m
.80506 .54044 L
s
.84226 .53669 m
.84226 .54044 L
s
.87946 .53669 m
.87946 .54044 L
s
.95387 .53669 m
.95387 .54044 L
s
.99107 .53669 m
.99107 .54044 L
s
.25 Mabswid
0 .53669 m
1 .53669 L
s
.02381 .03715 m
.03006 .03715 L
s
[(-6)] .01131 .03715 1 0 Mshowa
.02381 .1204 m
.03006 .1204 L
s
[(-5)] .01131 .1204 1 0 Mshowa
.02381 .20366 m
.03006 .20366 L
s
[(-4)] .01131 .20366 1 0 Mshowa
.02381 .28692 m
.03006 .28692 L
s
[(-3)] .01131 .28692 1 0 Mshowa
.02381 .37017 m
.03006 .37017 L
s
[(-2)] .01131 .37017 1 0 Mshowa
.02381 .45343 m
.03006 .45343 L
s
[(-1)] .01131 .45343 1 0 Mshowa
.125 Mabswid
.02381 .0538 m
.02756 .0538 L
s
.02381 .07045 m
.02756 .07045 L
s
.02381 .0871 m
.02756 .0871 L
s
.02381 .10375 m
.02756 .10375 L
s
.02381 .13705 m
.02756 .13705 L
s
.02381 .1537 m
.02756 .1537 L
s
.02381 .17036 m
.02756 .17036 L
s
.02381 .18701 m
.02756 .18701 L
s
.02381 .22031 m
.02756 .22031 L
s
.02381 .23696 m
.02756 .23696 L
s
.02381 .25361 m
.02756 .25361 L
s
.02381 .27026 m
.02756 .27026 L
s
.02381 .30357 m
.02756 .30357 L
s
.02381 .32022 m
.02756 .32022 L
s
.02381 .33687 m
.02756 .33687 L
s
.02381 .35352 m
.02756 .35352 L
s
.02381 .38682 m
.02756 .38682 L
s
.02381 .40347 m
.02756 .40347 L
s
.02381 .42013 m
.02756 .42013 L
s
.02381 .43678 m
.02756 .43678 L
s
.02381 .47008 m
.02756 .47008 L
s
.02381 .48673 m
.02756 .48673 L
s
.02381 .50338 m
.02756 .50338 L
s
.02381 .52003 m
.02756 .52003 L
s
.02381 .55334 m
.02756 .55334 L
s
.02381 .56999 m
.02756 .56999 L
s
.02381 .58664 m
.02756 .58664 L
s
.02381 .60329 m
.02756 .60329 L
s
.02381 .02049 m
.02756 .02049 L
s
.02381 .00384 m
.02756 .00384 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.03125 .59879 m
.03869 .58732 L
.04613 .55481 L
.05357 .60332 L
.06101 .56601 L
.06845 .53783 L
.07589 .53783 L
.08333 .53783 L
.09077 .53783 L
.09821 .53783 L
.10565 .53869 L
.1131 .47378 L
.12054 .49267 L
.12798 .53783 L
.13542 .52474 L
.14286 .47208 L
.1503 .47244 L
.15774 .47244 L
.16518 .47244 L
.17262 .44669 L
.18006 .43651 L
.1875 .47266 L
.19494 .42241 L
.20238 .40705 L
.20982 .40705 L
.21726 .37092 L
.2247 .34107 L
.23214 .40029 L
.23958 .29801 L
.24702 .32556 L
.25446 .34166 L
.2619 .34166 L
.26935 .31144 L
.27679 .27627 L
.28423 .31298 L
.29167 .42778 L
.29911 .53807 L
.30655 .53783 L
.31399 .53883 L
.32143 .4781 L
.32887 .48697 L
.33631 .53783 L
.34375 .53316 L
.35119 .47189 L
.35863 .47244 L
.36607 .47196 L
.37351 .53519 L
.38095 .47959 L
.38839 .47244 L
.39583 .47244 L
Mistroke
.40327 .47244 L
.41071 .47244 L
.41815 .47244 L
.4256 .43953 L
.43304 .4439 L
.44048 .47303 L
.44792 .41311 L
.45536 .40705 L
.4628 .40705 L
.47024 .40705 L
.47768 .37164 L
.48512 .34108 L
.49256 .39925 L
.5 .35206 L
.50744 .33169 L
.51488 .28339 L
.52232 .34225 L
.52976 .34166 L
.5372 .34191 L
.54464 .27751 L
.55208 .27627 L
.55952 .3298 L
.56696 .33333 L
.5744 .2758 L
.58185 .27542 L
.58929 .34033 L
.59673 .32144 L
.60417 .27627 L
.61161 .27627 L
.61905 .27964 L
.62649 .34215 L
.63393 .31545 L
.64137 .27627 L
.64881 .27627 L
.65625 .27627 L
.66369 .27627 L
.67113 .27627 L
.67857 .27661 L
.68601 .16523 L
.69345 .14549 L
.70089 .14549 L
.70833 .14549 L
.71577 .14549 L
.72321 .14549 L
.73065 .14549 L
.7381 .14549 L
.74554 .14549 L
.75298 .14549 L
.76042 .14549 L
.76786 .19357 L
Mistroke
.7753 .20758 L
.78274 .14431 L
.79018 .14549 L
.79762 .14549 L
.80506 .14549 L
.8125 .14549 L
.81994 .14549 L
.82738 .17722 L
.83482 .21128 L
.84226 .15794 L
.8497 .14549 L
.85714 .14549 L
.86458 .18375 L
.87202 .21143 L
.87946 .1499 L
.8869 .14549 L
.89435 .14549 L
.90179 .14549 L
.90923 .14549 L
.91667 .14549 L
.92411 .16541 L
.93155 .21088 L
.93899 .17106 L
.94643 .14549 L
.95387 .14549 L
.96131 .14549 L
.96875 .01472 L
.97619 .01472 L
Mfstroke
.03125 .59837 m
.03869 .58586 L
.04613 .57371 L
.05357 .56222 L
.06101 .55168 L
.06845 .54234 L
.07589 .53435 L
.08333 .5278 L
.09077 .52268 L
.09821 .51884 L
.10565 .51604 L
.1131 .51392 L
.12054 .51203 L
.12798 .50988 L
.13542 .50691 L
.14286 .50261 L
.1503 .49651 L
.15774 .48827 L
.16518 .47769 L
.17262 .46475 L
.18006 .44966 L
.1875 .43284 L
.19494 .41489 L
.20238 .3966 L
.20982 .3789 L
.21726 .36277 L
.2247 .34916 L
.23214 .33897 L
.23958 .33293 L
.24702 .33154 L
.25446 .33505 L
.2619 .34339 L
.26935 .35619 L
.27679 .37279 L
.28423 .39229 L
.29167 .41358 L
.29911 .43548 L
.30655 .45677 L
.31399 .47631 L
.32143 .49311 L
.32887 .5064 L
.33631 .51569 L
.34375 .52079 L
.35119 .52179 L
.35863 .51906 L
.36607 .51321 L
.37351 .50496 L
.38095 .49514 L
.38839 .48457 L
.39583 .47398 L
Mistroke
.40327 .46396 L
.41071 .45492 L
.41815 .44702 L
.4256 .44024 L
.43304 .43435 L
.44048 .42897 L
.44792 .42364 L
.45536 .41785 L
.4628 .41116 L
.47024 .40324 L
.47768 .39389 L
.48512 .38312 L
.49256 .37113 L
.5 .3583 L
.50744 .34515 L
.51488 .33233 L
.52232 .32049 L
.52976 .31026 L
.5372 .30215 L
.54464 .29654 L
.55208 .29357 L
.55952 .29318 L
.56696 .29506 L
.5744 .29869 L
.58185 .30341 L
.58929 .30841 L
.59673 .31286 L
.60417 .31595 L
.61161 .31699 L
.61905 .31543 L
.62649 .31092 L
.63393 .30336 L
.64137 .29288 L
.64881 .27983 L
.65625 .26476 L
.66369 .24833 L
.67113 .23132 L
.67857 .2145 L
.68601 .19859 L
.69345 .18422 L
.70089 .17189 L
.70833 .16191 L
.71577 .15442 L
.72321 .14937 L
.73065 .14657 L
.7381 .14571 L
.74554 .14638 L
.75298 .14813 L
.76042 .15055 L
.76786 .15322 L
Mistroke
.7753 .15582 L
.78274 .15812 L
.79018 .15996 L
.79762 .16131 L
.80506 .16219 L
.8125 .16269 L
.81994 .16295 L
.82738 .16309 L
.83482 .16326 L
.84226 .16354 L
.8497 .16398 L
.85714 .16459 L
.86458 .16527 L
.87202 .16594 L
.87946 .16641 L
.8869 .1665 L
.89435 .166 L
.90179 .16471 L
.90923 .16243 L
.91667 .15902 L
.92411 .15435 L
.93155 .14835 L
.93899 .14102 L
.94643 .13239 L
.95387 .12257 L
.96131 .11172 L
.96875 .10003 L
.97619 .08778 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[136]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo003oOolQ
Ool000moo`03001oogoo0?moo`moo`003goo0P00ogoo47oo000?Ool00`00Oomoo`3oOol?Ool000mo
o`03001oogoo0?moo`moo`003goo00<007ooOol0ogoo1Goo0`001goo000?Ool00`00Oomoo`3oOol5
Ool00`00Oomoo`07Ool000moo`800?moo`Ioo`03001oogoo00Moo`003goo00<007ooOol0ogoo1Goo
00<007ooOol01goo0008Ool20005Ool00`00Oomoo`3oOol5Ool00`00Oomoo`07Ool000Qoo`03001o
o`0000Aoo`03001oogoo0?moo`Eoo`03001oogoo00Moo`000goo0`000Woo00<007oo000017oo0`00
ogoo1Goo00<007ooOol01goo0008Ool20005Ool00`00Oomoo`3oOol5Ool00`00Oomoo`07Ool000Qo
o`03001oogoo00Aoo`03001oogoo0?moo`Eoo`03001oogoo00Moo`002Goo0P0017oo00<007ooOol0
ogoo1Goo00<007ooOol01goo000?Ool00`00Oomoo`3oOol4Ool00`00Oomoo`08Ool000moo`800?mo
o`Eoo`03001oogoo00Qoo`003goo00<007ooOol0ogoo17oo00<007ooOol027oo000?Ool00`00Oomo
o`3oOol4Ool00`00Oomoo`08Ool000moo`03001oogoo0?moo`Aoo`03001oogoo00Qoo`003goo00<0
07ooOol0ogoo17oo00<007ooOol027oo000?Ool2003oOol5Ool00`00Oomoo`08Ool000moo`03001o
ogoo0?moo`Aoo`03001oogoo00Qoo`003goo00<007ooOol0ogoo17oo00<007ooOol027oo000?Ool0
0`00Oomoo`3oOol4Ool00`00Oomoo`08Ool000moo`800?moo`Eoo`04001oogoo0007Ool000moo`03
001oogoo0?moo`Aoo`03001oo`0000Qoo`003goo00<007ooOol0ogoo17oo00<007oo000027oo000?
Ool00`00Oomoo`3oOol4Ool20009Ool000moo`03001oogoo0?moo`Aoo`8000Uoo`003goo0P00ogoo
1Goo00<007ooOol027oo000?Ool00`00Oomoo`3oOol4Ool00`00Oomoo`08Ool000moo`03001oogoo
0?moo`=oo`8000Yoo`002Goo00<007ooOol00goo00<007ooOol0ogoo0Woo0P002goo0008Ool00`00
Ool00004Ool00`00Oomoo`3oOol2Ool2000;Ool000=oo`<000Aoo`03001oogoo009oo`<00?moo`5o
o`03001oo`0000]oo`0027oo0P001Goo00<007ooOol0ogoo00@007ooOol000]oo`0027oo00<007oo
Ool017oo00<007ooOol0ogoo00@007ooOol000]oo`0027oo0`0017oo00<007ooOol0oWoo00D007oo
Oomoo`0000]oo`003goo0P00oWoo00<007ooOol00Woo00<007ooOol02Goo000?Ool00`00Oomoo`3l
Ool00`00Oomoo`03Ool00`00Oomoo`09Ool000moo`03001oogoo0=1oo`03001oogoo02Moo`8000Io
o`03001oogoo00Uoo`003goo00<007ooOol0]goo50001Goo2`0027oo0`001goo2@000goo00<007oo
Ool00Woo1@002goo000?Ool00`00Oomoo`2gOol00`00Oomoo`05Ool30007Ool20005Ool00`00Oomo
o`07Ool00`00Oomoo`05Ool01000Oomoo`001Goo0P0027oo00@007ooOol000Eoo`03001oogoo00eo
o`003goo0P00]goo00<007ooOol017oo0P002goo1@0000=oo`00Ool02Goo00<007ooOol017oo00@0
07ooOol000Eoo`03001oogoo00Qoo`8000Eoo`03001oogoo00ioo`003goo00<007ooOol0]Woo00<0
07ooOol00goo00<007ooOol02goo00<007ooOol00Woo0P002Woo00<007ooOol00goo00<007ooOol0
0Woo00<007ooOol00Woo00<007ooOol01goo0P001Woo00<007ooOol03Woo000?Ool00`00Oomoo`2e
Ool00`00Oomoo`03Ool00`00Oomoo`0=Ool01P00Oomoogoo001oo`l00003Ool007oo00=oo`03001o
ogoo009oo`03001oogoo00Eoo`80009oo`03001oogoo00=oo`03001oogoo00ioo`003goo00<007oo
Ool0]Goo00<007ooOol00Woo00<007ooOol03Woo00D007ooOomoo`0000]oo`03001oogoo009ooa<0
00Aoo`03001oogoo00=oo`03001oogoo00ioo`003goo0P00]Woo00<007ooOol00Woo00<007ooOol0
3Woo00D007ooOomoo`0000aoo`03001oogoo009oo`03001oogoo009oo`05001oogooOol0000<Ool0
0`00Oomoo`02Ool00`00Oomoo`0?Ool000moo`03001oogoo0;Eoo`05001oogooOol0000AOol01@00
Oomoogoo000037oo00D007ooOomoo`0000Eoo`05001oogooOol0000<Ool00`00Oomoo`02Ool00`00
Oomoo`0?Ool000moo`03001oogoo0;Eoo`04001oogoo000BOol01@00Oomoogoo000037oo00D007oo
Oomoo`0000Ioo`04001oogoo000<Ool00`00Oomoo`02Ool00`00Oomoo`0?Ool000moo`03001oogoo
0;Eoo`04001oogoo000BOol01@00Oomoogoo000037oo00D007ooOomoo`0000Ioo`04001oogoo000=
Ool01000Oomoo`004Woo000?Ool00`00Oomoo`2eOol00`00Ool0000DOol01000Oomoo`003Goo00@0
07ooOol000Ioo`04001oogoo000=Ool01000Oomoo`004Woo000?Ool2002fOol2000EOol01000Oomo
o`003Goo00@007ooOol000Ioo`04001oogoo000=Ool01000Oomoo`004Woo000?Ool00`00Oomoo`2e
Ool2000EOol01000Oomoo`003Goo00@007ooOol000Moo`03001oo`0000eoo`04001oogoo000BOol0
00moo`03001oogoo0;Aoo`8001Ioo`03001oo`0000moo`03001oo`0000Moo`03001oo`0000eoo`03
001oo`0001=oo`002Goo0`000goo00<007ooOol0]7oo0P005goo0P003goo00<007oo00001goo0P00
3Woo00<007oo00004goo000:Ool00`00Oomoo`02Ool00`00Oomoo`2dOol2000GOol2000?Ool20008
Ool2000?Ool2000COol000=oo`<0009oo`@000=oo`<00;Aoo`03001oogoo01Moo`03001oogoo00eo
o`8000Uoo`03001oogoo00eoo`8001=oo`0027oo00<007oo000017oo00<007ooOol0]7oo00<007oo
Ool05goo00<007ooOol03Woo00<007ooOol01goo00<007ooOol03Goo00<007ooOol04Woo0009Ool2
0004Ool00`00Oomoo`2cOol2000ZOol00`00Oomoo`07Ool00`00Oomoo`0=Ool00`00Oomoo`0BOol0
00Yoo`03001oogoo009oo`03001oogoo0;=oo`8005Uoo`003goo0P00/goo00<007oo0000FGoo000?
Ool00`00Oomoo`2bOol00`00Ool0001IOol000moo`03001oogoo0;5oo`04001oogoo001IOol000mo
o`03001oogoo0;5oo`04001oogoo001IOol000moo`03001oogoo0;5oo`04001oogoo001IOol000mo
o`800;5oo`05001oogooOol0001IOol000moo`03001oogoo0;1oo`05001oogooOol0001IOol000mo
o`03001oogoo0:moo`03001oogoo009oo`03001oogoo05Moo`003goo00<007ooOol0[goo00<007oo
Ool00Woo00<007ooOol0Egoo000?Ool00`00Oomoo`2_Ool01@00Oomoogoo0000FWoo000?Ool2002_
Ool00`00Oomoo`02Ool00`00Oomoo`1HOol000moo`03001oogoo0:ioo`03001oogoo009oo`03001o
ogoo05Qoo`003goo00<007ooOol0[Goo00<007ooOol00goo00<007ooOol0F7oo000?Ool00`00Oomo
o`2]Ool00`00Oomoo`03Ool00`00Oomoo`1HOol000moo`800:eoo`03001oogoo00Aoo`03001oogoo
05Qoo`003goo00<007ooOol0[7oo00<007ooOol017oo00<007ooOol0F7oo000?Ool00`00Oomoo`13
Ool00`00Oomoo`18Ool30005Ool30005Ool40007Ool;001JOol000Qoo`8000Eoo`03001oogoo04=o
o`03001oogoo04Qoo`03001oo`0000Eoo`03001oo`0000Eoo`04001oogooOol20005Ool00`00Ool0
001ROol000Yoo`03001oogoo009oo`03001oogoo04=oo`03001oogoo041oo`03001oogoo00Eoo`03
001oo`0000Eoo`03001oo`0000Eoo`03001oogoo009oo`03001oogoo00=oo`8006=oo`000goo0`00
0goo00<007ooOol00goo0`00@Woo00<007oo0000@Goo00<007ooOol01Goo00<007oo00001Goo00<0
07oo000017oo00<007ooOol00goo00<007ooOol00Woo00<007oo0000Hgoo000:Ool00`00Oomoo`02
Ool00`00Oomoo`12Ool00`00Ool00011Ool00`00Oomoo`05Ool01000Oomoo`000goo00@007ooOol0
00Aoo`03001oogoo00=oo`03001oogoo009oo`8006Aoo`0027oo00<007oo000017oo00<007ooOol0
@Woo00<007oo0000@7oo0P001Woo00<007ooOol01P000goo00D007ooOomoo`0000Eoo`03001oogoo
009oo`8006Aoo`002Goo00<007ooOol00goo00<007ooOol0>Goo00<007ooOol01Woo00<007oo0000
@7oo00<007oo00001Goo0`0000=oo`00Ool00Woo0P000Woo00D007ooOomoo`0000Ioo`05001oogoo
Ool0001UOol000moo`03001oogoo03Uoo`03001oogoo00Ioo`03001oo`00041oo`03001oo`0000Ao
o`8000=oo`06001oogooOol007oo0`000goo00<007ooOol017oo00<007ooOol00P00IGoo000?Ool2
000jOol20006Ool01@00Oomoogoo0000?goo00<007oo00000goo00<007oo00000goo00D007ooOomo
o`0000=oo`05001oogooOol00006Ool01@00Ool007oo0000IGoo000?Ool00`00Oomoo`0iOol20006
Ool01@00Oomoogoo0000?Woo00@007ooOol0009oo`04001oogoo0003Ool01@00Oomoogoo00000goo
0P0000=oo`00Ool01Woo00@007oo000006Ioo`003goo00<007ooOol0>Goo0P001Woo00D007ooOomo
o`0003ioo`06001oogoo001oo`000goo00D007ooOomoo`0000=oo`06001oogooOol007oo0P001goo
0P0000=oo`00Ool0IGoo000?Ool00`00Oomoo`0iOol20006Ool01@00Oomoogoo0000?Woo00H007oo
Ool007oo0003Ool01@00Oomoogoo00000goo00D007ooOomoo`00009oo`T0009oo`03001oogoo06Ao
o`003goo0P00>Woo00<007oo000017oo00<007ooOol00Woo00<007ooOol0?7oo00<007ooOol00P00
17oo00<007ooOol00Woo00<007oo000017oo00@007ooOol000Moo`04001oogoo001VOol000moo`03
001oogoo03Qoo`04001oogoo0004Ool00`00Oomoo`02Ool00`00Oomoo`0kOol01@00Oomoogoo0000
1Goo00<007ooOol00Woo00<007oo000017oo00@007ooOol000Moo`03001oo`0006Moo`003goo00<0
07ooOol0>7oo00@007ooOol000Aoo`03001oogoo009oo`03001oogoo03]oo`04001oogooOol20003
Ool00`00Oomoo`03Ool00`00Ool00005Ool20009Ool2001WOol000moo`03001oogoo03Qoo`03001o
ogoo008000=oo`03001oogoo009oo`03001oogoo03]oo`06001oogoo001oo`000goo00<007ooOol0
0goo00<007oo00001Goo0P002Goo0P00Igoo000?Ool00`00Oomoo`0hOol300001Goo000007oo0000
1Goo00<007ooOol0>goo00H007ooOol007oo0003Ool00`00Oomoo`04Ool20005Ool20009Ool2001W
Ool000moo`8003Qoo`8000Aoo`<000Eoo`03001oogoo03Yoo`04001oogoo0002Ool01@00Oomoogoo
00003Goo00<007ooOol027oo00<007ooOol0IWoo000?Ool00`00Oomoo`0eOol200000goo001oo`03
Ool30006Ool00`00Oomoo`0dOol00`00Oomoo`02Ool00`00Ool00003Ool5000=Ool00`00Oomoo`08
Ool00`00Oomoo`1VOol000moo`03001oogoo03Eoo`800003Ool007oo00Eoo`03001oogoo00Aoo`03
001oogoo03Aoo`03001oogoo009oo`8008Yoo`003goo00<007ooOol0=7oo0P000Woo00<007ooOol0
1Goo00<007ooOol00goo00<007ooOol0<goo0P000goo0P00Rgoo000?Ool2000eOol20002Ool00`00
Oomoo`05Ool00`00Oomoo`03Ool00`00Oomoo`0cOol20003Ool2002;Ool000moo`03001oogoo03Ao
o`05001oo`00Ool00008Ool00`00Oomoo`02Ool00`00Oomoo`0cOol00`00Ool00002Ool00`00Oomo
o`2:Ool000moo`03001oogoo03=oo`800004Ool007oo0008Ool00`00Oomoo`02Ool00`00Oomoo`0c
Ool00`00Ool00002Ool00`00Oomoo`2:Ool000Qoo`<000Aoo`03001oogoo03=oo`06001oogoo001o
o`002Goo00D007ooOomoo`0003Aoo`05001oogoo001oo`02002<Ool000Qoo`03001oogoo00Aoo`03
001oogoo039oo`80009oo`03001oo`0000Uoo`05001oogooOol0000dOol01P00Oomoo`00Ool008eo
o`000goo0`000goo00<007ooOol00goo0`00<Woo0P000Woo00<007oo00002Woo00@007ooOol003Ao
o`03001oogoo00<008eoo`002Goo00<007ooOol00goo00<007ooOol0<Goo00<007oo00000Woo0P00
2goo00@007ooOol003Aoo`06001oogoo001oo`00SGoo0008Ool00`00Ool00004Ool00`00Oomoo`0a
Ool00`00Ool00002Ool2000;Ool01000Oomoo`00=7oo00H007ooOol007oo002=Ool000Uoo`03001o
ogoo00=oo`03001oogoo035oo`8000=oo`8000aoo`03001oo`0003=oo`03001oogoo00800003Ool0
07oo08aoo`003goo00<007ooOol0<7oo00<007oo000017oo00<007ooOol02Woo00<007oo0000<goo
00D007ooOol007oo008008eoo`003goo0P00<Goo00<007oo000017oo00<007ooOol02goo0P00<goo
00<007oo00000Woo00<007ooOol0S7oo000?Ool00`00Oomoo`0_Ool01000Oomoo`0017oo00<007oo
Ool02goo0P00<goo00<007oo00000Woo00<007ooOol0S7oo000?Ool00`00Oomoo`0_Ool01000Oomo
o`0017oo00<007ooOol02goo0P00<goo0P000goo00<007ooOol0S7oo000?Ool00`00Oomoo`0_Ool0
0`00Ool00005Ool00`00Oomoo`0<Ool2000aOol20004Ool00`00Oomoo`2<Ool000moo`8002moo`04
001oogoo000DOol2000aOol00`00Oomoo`2BOol000moo`03001oogoo02ioo`@001Aoo`8002eoo`D0
09Aoo`003goo00<007ooOol0;Goo00<007oo00005goo00<007ooOol0:Woo00@007ooOol009Ioo`00
3goo00<007ooOol0;Goo0P0067oo00<007ooOol0:Goo00@007ooOol009Moo`003goo00<007ooOol0
;Goo0P0067oo0P00:Woo00<007oo0000V7oo000?Ool2000]Ool2000IOol2000ZOol2002IOol000mo
o`03001oogoo02aoo`8001Uoo`03001oo`0002Uoo`03001oogoo09Qoo`003goo00<007ooOol0:goo
00<007oo00006Goo00<007oo00009goo0`00VWoo000?Ool00`00Oomoo`0[Ool00`00Ool0000IOol0
1000Oomoo`009Goo00<007oo0000Vgoo000?Ool00`00Oomoo`0XOol00`00Ool00002Ool00`00Oomo
o`0GOol01000Oomoo`0097oo00@007ooOol009]oo`003goo0P00:7oo0P0000Aoo`00Ool001Yoo`04
001oogoo000ROol20003Ool00`00Oomoo`2IOol000moo`03001oogoo02Moo`03001oo`00009oo`03
001oogoo01Qoo`05001oogooOol0000QOol20003Ool00`00Oomoo`2IOol000Moo`D000=oo`03001o
ogoo02Ioo`04001oogoo0002Ool00`00Oomoo`0HOol01@00Oomoogoo00007goo0`0000Eoo`00Oomo
o`0009]oo`002Goo00<007ooOol00goo00<007ooOol09Woo00@007oo0000009oo`03001oogoo01Uo
o`04001oogoo000NOol00`00Ool00002Ool01000Oomoo`00Vgoo0003Ool30003Ool00`00Oomoo`03
Ool3000UOol01@00Ool007oo00000Woo00<007ooOol06Goo00D007ooOomoo`0001eoo`03001oo`00
00=oo`03001oo`0009]oo`002Goo00<007ooOol00goo00<007ooOol09Goo00<007oo00000Woo00<0
07oo00006goo00D007ooOomoo`0001aoo`04001oogoo0003Ool00`00Ool0002KOol000Uoo`03001o
ogoo00=oo`03001oogoo02Eoo`8000=oo`03001oo`0001]oo`05001oogooOol0000KOol01@00Oomo
ogoo00000goo0P00W7oo0008Ool20005Ool00`00Oomoo`0UOol20003Ool2000LOol00`00Oomoo`02
Ool00`00Oomoo`0GOol01@00Oomoogoo000017oo0P00W7oo000?Ool00`00Oomoo`0TOol20004Ool2
000LOol00`00Oomoo`02Ool00`00Oomoo`0FOol00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomo
o`2JOol000moo`8001moo`P000Eoo`03001oogoo01Yoo`03001oogoo009oo`03001oogoo00Qoo`D0
00Eoo`X000Eoo`03001oogoo09Yoo`003goo00<007ooOol05Woo00<007ooOol01Goo00<007ooOol0
0goo00<007ooOol017oo00<007ooOol06Woo00<007ooOol00goo00<007ooOol01goo00D007ooOomo
o`0000Aoo`04001oogoo000<Ool00`00Oomoo`2JOol000moo`03001oogoo01Ioo`03001oogoo00Eo
o`03001oogoo00=oo`03001oogoo025oo`03001oogoo00=oo`03001oo`0000Moo`05001oogooOol0
0003Ool01000Oomoo`00ZWoo000?Ool00`00Oomoo`0FOol20006Ool00`00Oomoo`02Ool00`00Oomo
o`0ROol00`00Oomoo`04Ool30006Ool01@00Oomoogoo00000goo00@007ooOol00:Yoo`003goo0P00
5goo0P001Goo00<007ooOol00goo00<007ooOol08goo00<007ooOol00goo0`001Woo00D007ooOomo
o`0000=oo`03001oo`000:]oo`003goo00<007ooOol05Woo00<007oo000017oo00<007ooOol00Woo
00<007ooOol097oo00<007ooOol017oo00<007oo000017oo00<007ooOol00goo00<007ooOol00P00
[7oo000?Ool00`00Oomoo`0EOol01000Oomoo`0017oo00D007ooOomoo`0002Moo`03001oogoo00Ao
o`03001oo`0000Aoo`03001oogoo00=oo`05001oo`00Ool0002/Ool000moo`03001oogoo01Eoo`04
001oogoo0004Ool01@00Oomoo`00Ool00`000goo00<007ooOol07Woo00@007ooOomoo`<00003Ool0
000000Aoo`03001oogoo00=oo`04001oo`00000DOol20004Ool00`00Oomoo`0ROol00`00Oomoo`02
Ool00`00Oomoo`0LOol50002Ool00`00Oomoo`02Ool00`00Oomoo`0KOol5000017oo000000000goo
00<007ooOol04Goo000?Ool00`00Oomoo`0EOol01000Oomoo`0017oo00<007oo00000Woo00<007oo
Ool00Woo00<007oo00007goo00<007ooOol00Woo0P0000Aoo`00000000=oo`03001oogoo00=oo`03
001oo`0001Eoo`03001oo`00009oo`03001oo`00029oo`03001oo`00009oo`03001oo`0001moo`07
001oogooOol007oo00000Woo00<007oo00007Woo00D007ooOomoo`0000Aoo`03001oo`00019oo`00
3goo0P005Woo00@007ooOol000Aoo`8000Aoo`07001oogooOol007oo00007goo00<007ooOol01000
00Aoo`00000000=oo`03001oogoo00=oo`03001oo`0001Eoo`03001oo`00009oo`03001oo`00029o
o`03001oo`00009oo`03001oo`0001moo`07001oogooOol007oo00000Woo00<007oo00007Woo00<0
07ooOol00Woo00L007ooOomoo`00Ool0000BOol000moo`03001oogoo01Eoo`05001oogooOol00002
Ool20005Ool01`00Oomoogoo001oo`0001moo`05001oogoo001oo`02000017oo000000000goo00<0
07ooOol00goo0`005Goo0P000goo00<007oo00008goo00L007ooOomoo`00Ool0000OOol01`00Oomo
ogoo001oo`00009oo`03001oo`0001ioo`03001oogoo009oo`07001oogooOol007oo00004Woo000?
Ool00`00Oomoo`0EOol00`00Oomoo`0400000goo001oo`03Ool00`00Ool00002Ool00`00Ool0000O
Ool01000Oomoogoo0`0000Aoo`00Ool000=oo`03001oogoo00=oo`03001oo`0001Eoo`03001oogoo
009oo`03001oo`00029oo`03001oo`00009oo`03001oo`0001moo`07001oogooOol007oo00000Woo
00<007oo00007Woo00L007ooOomoo`00Ool00002Ool00`00Ool0000BOol000moo`03001oogoo01Eo
o`<00005Ool007ooOol00006Ool00`00Oomoo`02Ool00`00Oomoo`0NOol00`00Oomoo`02Ool20002
Ool20003Ool00`00Oomoo`02Ool200000goo001oo`0EOol20003Ool00`00Oomoo`0ROol00`00Oomo
o`02Ool00`00Oomoo`0MOol20004Ool00`00Oomoo`02Ool00`00Oomoo`0LOol20004Ool00`00Oomo
o`02Ool00`00Oomoo`0AOol000moo`03001oogoo019oo`@000=oo`04001oogoo000/Ool00`00Oomo
o`03Ool01000Oomoogoo0P0000=oo`00Ool00Woo0P0000Aoo`00Ool00:ioo`003goo0P004Goo0P00
0goo00D007ooOomoo`00009oo`03001oogoo02]oo`03001oogoo009oo`06001oogooOol007oo1@00
17oo00<007ooOol0[Goo000?Ool00`00Oomoo`0?Ool00`00Oomoo`02Ool00`00Oomoo`02Ool01000
Oomoo`00;Goo00D007ooOomoo`0000Aoo`04001oogoo0007Ool00`00Oomoo`2]Ool000moo`03001o
ogoo00ioo`03001oogoo00=oo`03001oogoo00=oo`8002ioo`05001oogooOol00005Ool00`00Ool0
0007Ool00`00Oomoo`2]Ool000moo`03001oogoo00aoo`8000Ioo`03001oogoo00=oo`8002ioo`05
001oogooOol00005Ool00`00Ool00007Ool00`00Oomoo`2]Ool000Qoool001T000003goo00<007oo
Ool01goo00<007oo00002`001Goo00<007oo00002Goo00<007ooOol027oo00<007ooOol01goo00<0
07ooOol01goo00<007ooOol00Woo1@0000=oo`00Ool00Woo00<007ooOol00goo00<007ooOol01goo
00<007ooOol027oo00<007ooOol01goo00<007ooOol01goo00<007ooOol027oo00<007ooOol01goo
00<007ooOol027oo00<007ooOol01goo00<007ooOol01goo00<007ooOol027oo00<007ooOol01goo
00<007ooOol01goo00<007ooOol027oo00<007ooOol01goo00<007ooOol01goo00<007ooOol027oo
00<007ooOol01goo00<007ooOol00Goo000?Ool00`00Oomoo`09Ool00`00Oomoo`0JOol00`00Oomo
o`0WOol00`00Oomoo`0VOol00`00Oomoo`0WOol00`00Oomoo`0VOol00`00Oomoo`0VOol00`00Oomo
o`0FOol000moo`03001oogoo00Qoo`03001oogoo0?moo`Aoo`003goo00<007ooOol027oo00<007oo
Ool0ogoo17oo000?Ool20004Ool01000Oomoogoo0P00ogoo1Woo000?Ool00`00Oomoo`03Ool01P00
Oomoo`00Ool00?moo`Ioo`003goo00<007ooOol00goo00D007oo001oo`000?moo`Moo`003goo00<0
07ooOol00Woo0`000Woo00<007ooOol0ogoo1Goo000?Ool00`00Oomoo`02Ool00`00Ool00002Ool0
0`00Oomoo`3oOol5Ool000moo`8000=oo`<0009oo`03001oogoo0?moo`Eoo`003goo00<007ooOol0
0Woo0`000Woo00<007ooOol0ogoo1Goo000?Ool01000Oomoogoo0P0000Aoo`00Ool00?moo`Qoo`00
3goo00@007ooOomoo`800004Ool007oo003oOol8Ool000moo`80009oo`06001oogoo001oo`00ogoo
27oo000?Ool01000Oomoo`000goo00<007oo0000ogoo27oo000?Ool01000Oomoo`0017oo0P00ogoo
27oo000?Ool00`00Ool00005Ool00`00Oomoo`3oOol7Ool000moo`03001oo`0000Eoo`03001oogoo
0?moo`Moo`003goo0P001Woo00<007ooOol0ogoo1goo000?Ool00`00Oomoo`3oOol?Ool000moo`03
001oogoo0?moo`moo`003goo00<007ooOol0ogoo3goo000?Ool00`00Oomoo`3oOol?Ool00?moob5o
o`00ogoo8Goo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-7.47905, -6.5549, 0.483204, 
  0.0431829}}]
}, Open  ]],

Cell[BoxData[
    \(x = Drop[FoldList[Plus, 0, Cos[datalow]], 1]; \n
    y = Drop[FoldList[Plus, 0, Sin[datalow]], 1]; \)], "Input",
  CellLabel->"In[137]:="],

Cell["\<\
The reconstruction of the boundary from a set of low-order FS coefficients \
leads to a smoothed boundary. The reconstruction results in an open curve.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(ListPlot[Transpose[{x, y}], AspectRatio -> Automatic, 
      PlotJoined \[Rule] True]; \)\)], "Input",
  CellLabel->"In[138]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.51414 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0947613 0.0319115 1.40754 0.0319115 [
[.25432 1.39504 -3 -9 ]
[.25432 1.39504 3 0 ]
[.41388 1.39504 -6 -9 ]
[.41388 1.39504 6 0 ]
[.57343 1.39504 -6 -9 ]
[.57343 1.39504 6 0 ]
[.73299 1.39504 -6 -9 ]
[.73299 1.39504 6 0 ]
[.89255 1.39504 -6 -9 ]
[.89255 1.39504 6 0 ]
[.08226 .13108 -18 -4.5 ]
[.08226 .13108 0 4.5 ]
[.08226 .45019 -18 -4.5 ]
[.08226 .45019 0 4.5 ]
[.08226 .76931 -18 -4.5 ]
[.08226 .76931 0 4.5 ]
[.08226 1.08842 -18 -4.5 ]
[.08226 1.08842 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1.51414 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.25432 1.40754 m
.25432 1.41379 L
s
[(5)] .25432 1.39504 0 1 Mshowa
.41388 1.40754 m
.41388 1.41379 L
s
[(10)] .41388 1.39504 0 1 Mshowa
.57343 1.40754 m
.57343 1.41379 L
s
[(15)] .57343 1.39504 0 1 Mshowa
.73299 1.40754 m
.73299 1.41379 L
s
[(20)] .73299 1.39504 0 1 Mshowa
.89255 1.40754 m
.89255 1.41379 L
s
[(25)] .89255 1.39504 0 1 Mshowa
.125 Mabswid
.12667 1.40754 m
.12667 1.41129 L
s
.15858 1.40754 m
.15858 1.41129 L
s
.1905 1.40754 m
.1905 1.41129 L
s
.22241 1.40754 m
.22241 1.41129 L
s
.28623 1.40754 m
.28623 1.41129 L
s
.31814 1.40754 m
.31814 1.41129 L
s
.35005 1.40754 m
.35005 1.41129 L
s
.38196 1.40754 m
.38196 1.41129 L
s
.44579 1.40754 m
.44579 1.41129 L
s
.4777 1.40754 m
.4777 1.41129 L
s
.50961 1.40754 m
.50961 1.41129 L
s
.54152 1.40754 m
.54152 1.41129 L
s
.60535 1.40754 m
.60535 1.41129 L
s
.63726 1.40754 m
.63726 1.41129 L
s
.66917 1.40754 m
.66917 1.41129 L
s
.70108 1.40754 m
.70108 1.41129 L
s
.7649 1.40754 m
.7649 1.41129 L
s
.79681 1.40754 m
.79681 1.41129 L
s
.82873 1.40754 m
.82873 1.41129 L
s
.86064 1.40754 m
.86064 1.41129 L
s
.06285 1.40754 m
.06285 1.41129 L
s
.03094 1.40754 m
.03094 1.41129 L
s
.92446 1.40754 m
.92446 1.41129 L
s
.95637 1.40754 m
.95637 1.41129 L
s
.98828 1.40754 m
.98828 1.41129 L
s
.25 Mabswid
0 1.40754 m
1 1.40754 L
s
.09476 .13108 m
.10101 .13108 L
s
[(-40)] .08226 .13108 1 0 Mshowa
.09476 .45019 m
.10101 .45019 L
s
[(-30)] .08226 .45019 1 0 Mshowa
.09476 .76931 m
.10101 .76931 L
s
[(-20)] .08226 .76931 1 0 Mshowa
.09476 1.08842 m
.10101 1.08842 L
s
[(-10)] .08226 1.08842 1 0 Mshowa
.125 Mabswid
.09476 .1949 m
.09851 .1949 L
s
.09476 .25872 m
.09851 .25872 L
s
.09476 .32254 m
.09851 .32254 L
s
.09476 .38637 m
.09851 .38637 L
s
.09476 .51401 m
.09851 .51401 L
s
.09476 .57784 m
.09851 .57784 L
s
.09476 .64166 m
.09851 .64166 L
s
.09476 .70548 m
.09851 .70548 L
s
.09476 .83313 m
.09851 .83313 L
s
.09476 .89695 m
.09851 .89695 L
s
.09476 .96078 m
.09851 .96078 L
s
.09476 1.0246 m
.09851 1.0246 L
s
.09476 1.15224 m
.09851 1.15224 L
s
.09476 1.21607 m
.09851 1.21607 L
s
.09476 1.27989 m
.09851 1.27989 L
s
.09476 1.34371 m
.09851 1.34371 L
s
.09476 .06725 m
.09851 .06725 L
s
.09476 .00343 m
.09851 .00343 L
s
.09476 1.47136 m
.09851 1.47136 L
s
.25 Mabswid
.09476 0 m
.09476 1.51414 L
s
0 0 m
1 0 L
1 1.51414 L
0 1.51414 L
closepath
clip
newpath
.5 Mabswid
.11831 1.42907 m
.14481 1.44684 L
.17362 1.46057 L
.20404 1.47021 L
.23544 1.47592 L
.26728 1.47809 L
.29918 1.47719 L
.33091 1.47379 L
.36237 1.46845 L
.39355 1.46166 L
.42448 1.45383 L
.45521 1.44521 L
.48573 1.4359 L
.516 1.4258 L
.5459 1.41463 L
.57517 1.40193 L
.60344 1.38712 L
.6301 1.36959 L
.65433 1.34882 L
.67506 1.32455 L
.69107 1.29695 L
.70121 1.26669 L
.70464 1.23496 L
.70109 1.20325 L
.69092 1.173 L
.67511 1.14528 L
.65501 1.1205 L
.63202 1.09836 L
.6075 1.07794 L
.58264 1.05794 L
.55864 1.0369 L
.53687 1.01357 L
.51893 .98718 L
.50657 .95776 L
.50137 .92627 L
.50431 .8945 L
.51541 .86458 L
.53371 .83844 L
.55759 .81727 L
.58523 .80132 L
.61505 .78996 L
.64596 .782 L
.67729 .77594 L
.70869 .77027 L
.73989 .76356 L
.77054 .75468 L
.80016 .74281 L
.82818 .72754 L
.85404 .70884 L
.87732 .68702 L
Mistroke
.89781 .66255 L
.91553 .63601 L
.93066 .60791 L
.94345 .57868 L
.95414 .54861 L
.96287 .51792 L
.96962 .48673 L
.97418 .45514 L
.97619 .42329 L
.97517 .3914 L
.97058 .35982 L
.96195 .3291 L
.94901 .29993 L
.93174 .27309 L
.91046 .24931 L
.88579 .22907 L
.8585 .21253 L
.82939 .19946 L
.79914 .18928 L
.76828 .18116 L
.73715 .17415 L
.70599 .16728 L
.67499 .15972 L
.64434 .1508 L
.61426 .14017 L
.58486 .12775 L
.55617 .11378 L
.52802 .09875 L
.50006 .08337 L
.47181 .06852 L
.4428 .05522 L
.41271 .04461 L
.38152 .03785 L
.34966 .03605 L
.318 .04001 L
.28772 .05011 L
.26013 .06613 L
.23631 .08737 L
.21696 .11275 L
.20225 .14107 L
.19189 .17125 L
.1852 .20245 L
.18135 .23413 L
.17943 .26599 L
.17857 .29789 L
.17805 .32979 L
.17728 .3617 L
.17582 .39357 L
.17345 .4254 L
.17006 .45713 L
Mistroke
.16567 .48874 L
.16042 .52021 L
.15447 .55156 L
.14801 .58282 L
.14122 .614 L
.13425 .64514 L
.12718 .67626 L
.12006 .70736 L
.11287 .73845 L
.10558 .76952 L
.09812 .80055 L
.09044 .83152 L
.0825 .86243 L
.07432 .89328 L
.06596 .92407 L
.05757 .95486 L
.04937 .9857 L
.04164 1.01666 L
.03476 1.04782 L
.02917 1.07924 L
.02534 1.11092 L
.02381 1.1428 L
.02508 1.17468 L
.02965 1.20627 L
.0379 1.23709 L
.05009 1.26658 L
.06629 1.29408 L
.08634 1.31891 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[138]:=",
  ImageSize->{190.188, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002g00015Q000`40O003h00O]goo002gOol00;Mo
o`0057oo00<007ooOol0X7oo000DOol00`00Oomoo`2POol001Aoo`03001oogoo0:1oo`0057oo00<0
07ooOol0X7oo000DOol00`00Oomoo`2POol001Aoo`03001oogoo0:1oo`0057oo00<007ooOol0:Goo
1@00LWoo000DOol00`00Oomoo`0TOol50005Ool5001]Ool001Aoo`03001oogoo025oo`<000moo`D0
06Qoo`0057oo00<007ooOol07goo0P005goo0P00IWoo000DOol00`00Oomoo`0MOol2000KOol3001S
Ool001Aoo`03001oogoo01]oo`80021oo`80065oo`0057oo00<007ooOol06Woo00<007ooOol08Woo
0P00Ggoo000DOol00`00Oomoo`0IOol00`00Oomoo`0UOol2001MOol001Aoo`03001oogoo01Moo`80
02Yoo`8005]oo`0057oo00<007ooOol05Woo00<007ooOol0;7oo0P00FGoo000DOol00`00Oomoo`0E
Ool00`00Oomoo`0_Ool2001GOol001Aoo`03001oogoo01Eoo`03001oogoo035oo`8005Eoo`0057oo
00<007ooOol057oo00<007ooOol0=7oo0P00Dgoo000DOol00`00Oomoo`0DOol00`00Oomoo`0fOol2
001AOol001Aoo`03001oogoo01=oo`03001oogoo03Uoo`8004moo`002Woo0`000Woo00<007ooOol0
0Woo00<007ooOol04Woo00<007ooOol0?7oo0P00CGoo000;Ool01P00Oomoo`00Ool000=oo`03001o
ogoo019oo`03001oogoo03ioo`8004]oo`0017oo0`000Woo100000Aoo`00Ool000=oo`80019oo`03
001oogoo045oo`8004Uoo`002Goo00<007oo00000Woo00<007oo00000goo00<007ooOol04Goo00<0
07ooOol0@goo0P00Agoo000:Ool20002Ool00`00Ool00003Ool00`00Oomoo`0@Ool00`00Oomoo`16
Ool30014Ool000]oo`05001oogooOol00004Ool00`00Oomoo`0@Ool00`00Oomoo`19Ool20012Ool0
01Aoo`03001oogoo00moo`03001oogoo04aoo`@003ioo`0057oo00<007ooOol03goo00<007ooOol0
D7oo1@00>Goo000DOol00`00Oomoo`0?Ool00`00Oomoo`1EOol3000fOol001Aoo`03001oogoo00io
o`03001oogoo05Uoo`@0039oo`0057oo00<007ooOol03Woo00<007ooOol0GGoo1@00;Goo000DOol0
0`00Oomoo`0>Ool00`00Oomoo`1ROol5000XOol001Aoo`03001oogoo00ioo`03001oogoo06Moo`80
02Ioo`0057oo00<007ooOol03Goo00<007ooOol0JWoo0`008goo000DOol00`00Oomoo`0=Ool00`00
Oomoo`1]Ool3000POol001Aoo`03001oogoo00eoo`03001oogoo071oo`<001eoo`0057oo00<007oo
Ool03Goo00<007ooOol0Lgoo0P006goo000DOol00`00Oomoo`0=Ool00`00Oomoo`1eOol2000IOol0
01Aoo`03001oogoo00aoo`03001oogoo07Qoo`8001Moo`0057oo00<007ooOol037oo00<007ooOol0
NWoo0P005Goo000DOol00`00Oomoo`0<Ool00`00Oomoo`1lOol00`00Oomoo`0BOol001Aoo`03001o
ogoo00aoo`03001oogoo07eoo`03001oogoo015oo`0057oo00<007ooOol037oo00<007ooOol0OWoo
00<007ooOol047oo000DOol00`00Oomoo`0<Ool00`00Oomoo`1oOol00`00Oomoo`0?Ool001Aoo`03
001oogoo00aoo`03001oogoo081oo`03001oogoo00ioo`0057oo00<007ooOol037oo00<007ooOol0
PGoo00<007ooOol03Goo000DOol00`00Oomoo`0<Ool00`00Oomoo`22Ool00`00Oomoo`0<Ool001Ao
o`03001oogoo00aoo`03001oogoo08=oo`03001oogoo00]oo`0057oo00<007ooOol037oo00<007oo
Ool0Q7oo00<007ooOol02Woo000DOol00`00Oomoo`0<Ool00`00Oomoo`25Ool00`00Oomoo`09Ool0
01Aoo`03001oogoo00aoo`03001oogoo08Eoo`03001oogoo00Uoo`0057oo00<007ooOol037oo00<0
07ooOol0QWoo00<007ooOol027oo000DOol00`00Oomoo`0<Ool00`00Oomoo`26Ool00`00Oomoo`08
Ool001Aoo`03001oogoo00aoo`03001oogoo08Moo`03001oogoo00Moo`0057oo00<007ooOol037oo
00<007ooOol0R7oo00<007ooOol01Woo000DOol00`00Oomoo`0<Ool00`00Oomoo`28Ool00`00Oomo
o`06Ool001Aoo`03001oogoo00aoo`03001oogoo08Uoo`03001oogoo00Eoo`0057oo00<007ooOol0
37oo00<007ooOol0RGoo00<007ooOol01Goo000DOol00`00Oomoo`0<Ool00`00Oomoo`2:Ool00`00
Oomoo`04Ool001Aoo`03001oogoo00aoo`03001oogoo08Yoo`03001oogoo00Aoo`0057oo00<007oo
Ool037oo00<007ooOol0RWoo00<007ooOol017oo000DOol00`00Oomoo`0<Ool00`00Oomoo`2;Ool0
0`00Oomoo`03Ool001Aoo`03001oogoo00aoo`03001oogoo08]oo`03001oogoo00=oo`0057oo00<0
07ooOol037oo00<007ooOol0Rgoo00<007ooOol00goo000DOol00`00Oomoo`0<Ool00`00Oomoo`2;
Ool00`00Oomoo`03Ool001Aoo`03001oogoo00aoo`03001oogoo08]oo`03001oogoo00=oo`0057oo
00<007ooOol037oo00<007ooOol0S7oo00<007ooOol00Woo000DOol00`00Oomoo`0;Ool00`00Oomo
o`2=Ool00`00Oomoo`02Ool001Aoo`03001oogoo00]oo`03001oogoo08eoo`03001oogoo009oo`00
57oo00<007ooOol02goo00<007ooOol0SGoo00<007ooOol00Woo000DOol00`00Oomoo`0;Ool00`00
Oomoo`2=Ool00`00Oomoo`02Ool001Aoo`03001oogoo00]oo`03001oogoo08eoo`03001oogoo009o
o`0057oo00<007ooOol02goo00<007ooOol0SGoo00<007ooOol00Woo000DOol00`00Oomoo`0;Ool0
0`00Oomoo`2=Ool00`00Oomoo`02Ool001Aoo`03001oogoo00]oo`03001oogoo08eoo`03001oogoo
009oo`0057oo00<007ooOol02goo00<007ooOol0SGoo00<007ooOol00Woo000DOol00`00Oomoo`0;
Ool00`00Oomoo`2=Ool00`00Oomoo`02Ool001Aoo`03001oogoo00]oo`03001oogoo08eoo`03001o
ogoo009oo`002Goo0P0017oo00<007ooOol00Woo00<007ooOol02Woo00<007ooOol0SWoo00<007oo
Ool00Woo000;Ool01P00Oomoo`00Ool000=oo`03001oogoo00Yoo`03001oogoo08ioo`03001oogoo
009oo`0017oo0`000goo00L007ooOomoo`00Ool00003Ool2000;Ool00`00Oomoo`2>Ool00`00Oomo
o`02Ool000]oo`06001oogoo001oo`000goo00<007ooOol02Woo00<007ooOol0SWoo00<007ooOol0
0Woo0009Ool00`00Ool00002Ool00`00Ool00003Ool00`00Oomoo`0:Ool00`00Oomoo`2>Ool00`00
Oomoo`02Ool000Yoo`03001oogoo009oo`03001oogoo009oo`03001oogoo00Yoo`03001oogoo08io
o`03001oogoo009oo`0057oo00<007ooOol02Goo00<007ooOol0SWoo00<007ooOol00goo000DOol0
0`00Oomoo`09Ool00`00Oomoo`2>Ool00`00Oomoo`03Ool001Aoo`03001oogoo00Uoo`03001oogoo
08ioo`03001oogoo00=oo`0057oo00<007ooOol02Goo00<007ooOol0SWoo00<007ooOol00goo000D
Ool00`00Oomoo`09Ool00`00Oomoo`2>Ool00`00Oomoo`03Ool001Aoo`03001oogoo00Uoo`03001o
ogoo08eoo`03001oogoo00Aoo`0057oo00<007ooOol02Goo00<007ooOol0SGoo00<007ooOol017oo
000DOol00`00Oomoo`09Ool00`00Oomoo`2=Ool00`00Oomoo`04Ool001Aoo`03001oogoo00Uoo`03
001oogoo08eoo`03001oogoo00Aoo`0057oo00<007ooOol02Goo00<007ooOol0SGoo00<007ooOol0
17oo000DOol00`00Oomoo`08Ool00`00Oomoo`2=Ool00`00Oomoo`05Ool001Aoo`03001oogoo00Qo
o`03001oogoo08eoo`03001oogoo00Eoo`0057oo00<007ooOol027oo00<007ooOol0S7oo00<007oo
Ool01Woo000DOol00`00Oomoo`07Ool00`00Oomoo`2=Ool00`00Oomoo`06Ool001Aoo`03001oogoo
00Moo`03001oogoo08eoo`03001oogoo00Ioo`0057oo00<007ooOol01goo00<007ooOol0S7oo00<0
07ooOol01goo000DOol00`00Oomoo`07Ool00`00Oomoo`2<Ool00`00Oomoo`07Ool001Aoo`03001o
ogoo00Ioo`03001oogoo08eoo`03001oogoo00Moo`0057oo00<007ooOol01Woo00<007ooOol0S7oo
00<007ooOol027oo000DOol00`00Oomoo`06Ool00`00Oomoo`2<Ool00`00Oomoo`08Ool001Aoo`03
001oogoo00Ioo`03001oogoo08aoo`03001oogoo00Qoo`0057oo00<007ooOol01Woo00<007ooOol0
Rgoo00<007ooOol02Goo000DOol00`00Oomoo`06Ool00`00Oomoo`2;Ool00`00Oomoo`09Ool001Ao
o`03001oogoo00Eoo`03001oogoo08]oo`03001oogoo00Yoo`0057oo00<007ooOol01Goo00<007oo
Ool0Rgoo00<007ooOol02Woo000DOol00`00Oomoo`05Ool00`00Oomoo`2:Ool00`00Oomoo`0;Ool0
01Aoo`03001oogoo00Eoo`03001oogoo08Yoo`03001oogoo00]oo`0057oo00<007ooOol01Goo00<0
07ooOol0RGoo00<007ooOol037oo000DOol00`00Oomoo`04Ool00`00Oomoo`2:Ool00`00Oomoo`0<
Ool001Aoo`03001oogoo00Aoo`03001oogoo08Uoo`03001oogoo00eoo`0057oo00<007ooOol017oo
00<007ooOol0R7oo00<007ooOol03Woo000DOol00`00Oomoo`04Ool00`00Oomoo`28Ool00`00Oomo
o`0>Ool001Aoo`03001oogoo00Aoo`03001oogoo08Moo`03001oogoo00moo`0057oo00<007ooOol0
17oo00<007ooOol0Qgoo00<007ooOol03goo000DOol00`00Oomoo`03Ool00`00Oomoo`27Ool00`00
Oomoo`0@Ool001Aoo`03001oogoo00=oo`03001oogoo08Ioo`03001oogoo015oo`0057oo00<007oo
Ool00goo00<007ooOol0QGoo00<007ooOol04Woo000DOol00`00Oomoo`03Ool00`00Oomoo`24Ool0
0`00Oomoo`0COol001Aoo`03001oogoo009oo`03001oogoo08Aoo`03001oogoo01Aoo`0057oo00<0
07ooOol00Woo00<007ooOol0Pgoo00<007ooOol05Goo000DOol00`00Oomoo`02Ool00`00Oomoo`22
Ool00`00Oomoo`0FOol001Aoo`05001oogooOol00024Ool00`00Oomoo`0GOol001Aoo`05001oogoo
Ool00023Ool00`00Oomoo`0HOol001Aoo`05001oogooOol00022Ool00`00Oomoo`0IOol001Aoo`05
001oogooOol00021Ool00`00Oomoo`0JOol001Aoo`04001oogoo0021Ool00`00Oomoo`0KOol001Ao
o`04001oogoo001oOol2000NOol001Aoo`04001oogoo001lOol3000POol001Aoo`04001oogoo001i
Ool3000SOol001Aoo`04001oogoo001gOol2000VOol001Aoo`03001oo`0007Eoo`<002Qoo`002Goo
0`000goo00<007ooOol00Woo00<007oo0000Lgoo0P00:goo0009Ool00`00Oomoo`02Ool00`00Ool0
0003Ool00`00Ool0001_Ool4000]Ool000Aoo`<000=oo`07001oogooOol007oo00000goo0`00JGoo
1P00<Goo000:Ool01`00Oomoogoo001oo`0000=oo`03001oo`0006=oo`H003Moo`002Goo00<007oo
00000Woo00<007oo00000goo0P00H7oo1000?Goo000:Ool00`00Oomoo`02Ool00`00Oomoo`02Ool2
001MOol30011Ool001Aoo`8005Yoo`<004Aoo`0057oo00<007ooOol0Egoo0P00Agoo000DOol00`00
Oomoo`1EOol20019Ool001Aoo`03001oogoo05=oo`8004]oo`0057oo00<007ooOol0DGoo0P00CGoo
000COol2001BOol00`00Oomoo`1=Ool001=oo`80055oo`03001oogoo04ioo`004goo0P00Cgoo0P00
DGoo000COol2001>Ool00`00Oomoo`1AOol001=oo`8004eoo`03001oogoo059oo`004Woo00<007oo
0000C7oo00<007ooOol0Dgoo000BOol00`00Ool0001<Ool00`00Oomoo`1COol0019oo`03001oo`00
04]oo`03001oogoo05Aoo`004Woo00<007oo0000BWoo00<007ooOol0EGoo000BOol00`00Ool0001:
Ool00`00Oomoo`1EOol0015oo`04001oogoo0019Ool00`00Oomoo`1FOol0015oo`04001oogoo0019
Ool00`00Oomoo`1FOol0011oo`05001oogooOol00019Ool00`00Oomoo`1FOol0011oo`05001oogoo
Ool00018Ool00`00Oomoo`1GOol0011oo`05001oogooOol00018Ool00`00Oomoo`1GOol0011oo`05
001oogooOol00018Ool00`00Oomoo`1GOol000moo`03001oogoo009oo`03001oogoo04Ioo`03001o
ogoo05Moo`003goo00<007ooOol00Woo00<007ooOol0AWoo00<007ooOol0Egoo000?Ool00`00Oomo
o`02Ool00`00Oomoo`16Ool00`00Oomoo`1GOol000moo`03001oogoo009oo`03001oogoo04Ioo`03
001oogoo05Moo`003goo00<007ooOol00Woo00<007ooOol0AWoo00<007ooOol0Egoo000>Ool00`00
Oomoo`03Ool00`00Oomoo`16Ool00`00Oomoo`1GOol000ioo`03001oogoo00=oo`03001oogoo04Mo
o`03001oogoo05Ioo`003Goo00<007ooOol017oo00<007ooOol0Agoo00<007ooOol0EWoo000=Ool0
0`00Oomoo`04Ool00`00Oomoo`17Ool00`00Oomoo`1FOol000eoo`03001oogoo00Aoo`03001oogoo
04Moo`03001oogoo05Ioo`003Goo00<007ooOol017oo00<007ooOol0Agoo00<007ooOol0EWoo000<
Ool00`00Oomoo`05Ool00`00Oomoo`18Ool00`00Oomoo`1EOol000aoo`03001oogoo00Eoo`03001o
ogoo04Qoo`03001oogoo05Eoo`0037oo00<007ooOol01Goo00<007ooOol0BGoo00<007ooOol0E7oo
000<Ool00`00Oomoo`05Ool00`00Oomoo`19Ool00`00Oomoo`1DOol000aoo`03001oogoo00Eoo`03
001oogoo04Yoo`03001oogoo05=oo`002goo00<007ooOol01Woo00<007ooOol0BWoo00<007ooOol0
Dgoo000;Ool00`00Oomoo`06Ool00`00Oomoo`1;Ool00`00Oomoo`1BOol000Yoo`03001oogoo00Mo
o`03001oogoo04]oo`03001oogoo059oo`002Woo00<007ooOol01goo00<007ooOol0C7oo00<007oo
Ool0DGoo000:Ool00`00Oomoo`07Ool00`00Oomoo`1=Ool00`00Oomoo`1@Ool000Yoo`03001oogoo
00Moo`03001oogoo04ioo`03001oogoo04moo`002Goo00<007ooOol027oo00<007ooOol0Cgoo00<0
07ooOol0CWoo0009Ool00`00Oomoo`08Ool00`00Oomoo`1@Ool00`00Oomoo`1=Ool000Uoo`03001o
ogoo00Qoo`03001oogoo055oo`03001oogoo04aoo`002Goo00<007ooOol027oo00<007ooOol0DWoo
00<007ooOol0Bgoo0009Ool00`00Oomoo`08Ool00`00Oomoo`1COol00`00Oomoo`1:Ool000Uoo`03
001oogoo00Qoo`03001oogoo05Aoo`03001oogoo04Uoo`0027oo00<007ooOol02Goo00<007ooOol0
EGoo0P00BGoo0008Ool00`00Oomoo`09Ool00`00Oomoo`1GOol20017Ool000Qoo`D0009oo`03001o
ogoo009oo`03001oogoo05Uoo`03001oogoo04Aoo`0027oo00<007oo00000goo00<007oo00000goo
00<007ooOol0FWoo00<007ooOol0@goo0004Ool3000017oo001oo`000goo00<007oo00000goo0P00
G7oo00<007ooOol0@Woo0008Ool00`00Ool00003Ool00`00Ool00003Ool00`00Oomoo`1LOol00`00
Oomoo`11Ool000Moo`04001oogoo0003Ool00`00Ool00003Ool00`00Oomoo`1MOol00`00Oomoo`10
Ool000Moo`04001oo`000004Ool00`00Oomoo`02Ool00`00Oomoo`1NOol00`00Oomoo`0oOol000Mo
o`03001oogoo00Yoo`03001oogoo05moo`03001oogoo03ioo`001goo00<007ooOol02Woo00<007oo
Ool0H7oo00<007ooOol0?Goo0007Ool00`00Oomoo`0:Ool00`00Oomoo`1QOol00`00Oomoo`0lOol0
00Moo`03001oogoo00Yoo`03001oogoo069oo`03001oogoo03]oo`001goo00<007ooOol02Woo00<0
07ooOol0Hgoo00<007ooOol0>Woo0007Ool00`00Oomoo`0:Ool00`00Oomoo`1SOol00`00Oomoo`0j
Ool000Moo`03001oogoo00Yoo`03001oogoo06Aoo`03001oogoo03Uoo`001goo00<007ooOol02Woo
00<007ooOol0IGoo00<007ooOol0>7oo0007Ool00`00Oomoo`0:Ool00`00Oomoo`1VOol00`00Oomo
o`0gOol000Moo`03001oogoo00Yoo`03001oogoo06Ioo`03001oogoo03Moo`001goo00<007ooOol0
2Woo00<007ooOol0Igoo00<007ooOol0=Woo0007Ool00`00Oomoo`0:Ool00`00Oomoo`1WOol00`00
Oomoo`0fOol000Moo`03001oogoo00Yoo`03001oogoo06Qoo`03001oogoo03Eoo`001goo00<007oo
Ool02Woo00<007ooOol0J7oo00<007ooOol0=Goo0007Ool00`00Oomoo`0:Ool00`00Oomoo`1YOol0
0`00Oomoo`0dOol000Qoo`03001oogoo00Uoo`03001oogoo06Uoo`03001oogoo03Aoo`0027oo00<0
07ooOol02Goo00<007ooOol0JWoo00<007ooOol0<goo0008Ool00`00Oomoo`09Ool00`00Oomoo`1Z
Ool00`00Oomoo`0cOol000Qoo`03001oogoo00Uoo`03001oogoo06Yoo`03001oogoo03=oo`0027oo
00<007ooOol02Goo00<007ooOol0JWoo00<007ooOol0<goo0009Ool00`00Oomoo`08Ool00`00Oomo
o`1ZOol00`00Oomoo`0cOol000Uoo`03001oogoo00Qoo`03001oogoo06Yoo`03001oogoo03=oo`00
2Woo00<007ooOol01goo00<007ooOol0JWoo00<007ooOol0<goo000:Ool00`00Oomoo`07Ool00`00
Oomoo`1ZOol00`00Oomoo`0cOol000Yoo`03001oogoo00Moo`03001oogoo06Yoo`03001oogoo03=o
o`002goo00<007ooOol01Woo00<007ooOol0JWoo00<007ooOol0<goo000;Ool00`00Oomoo`06Ool0
0`00Oomoo`1ZOol00`00Oomoo`0cOol000aoo`03001oogoo00Eoo`03001oogoo06Yoo`03001oogoo
03=oo`0037oo00<007ooOol01Goo00<007ooOol0JWoo00<007ooOol0<goo000=Ool00`00Oomoo`04
Ool00`00Oomoo`1ZOol00`00Oomoo`0cOol000eoo`03001oogoo00Aoo`03001oogoo06Uoo`03001o
ogoo03Aoo`003Woo00<007ooOol00goo00<007ooOol0JGoo00<007ooOol0=7oo000>Ool00`00Oomo
o`03Ool00`00Oomoo`1YOol00`00Oomoo`0dOol000moo`03001oogoo009oo`03001oogoo06Qoo`03
001oogoo03Eoo`0047oo00D007ooOomoo`0006Yoo`03001oogoo03Eoo`0047oo00D007ooOomoo`00
06Uoo`03001oogoo03Ioo`004Goo00@007ooOol006Uoo`03001oogoo03Ioo`004Goo00@007ooOol0
06Qoo`03001oogoo03Moo`004Woo00<007oo0000J7oo00<007ooOol0=goo000DOol00`00Oomoo`1U
Ool00`00Oomoo`0hOol001Aoo`03001oogoo06Aoo`03001oogoo03Uoo`0057oo00<007ooOol0Hgoo
00<007ooOol0>Woo000DOol00`00Oomoo`1ROol00`00Oomoo`0kOol001Aoo`03001oogoo01Uoo`03
001oogoo01Eoo`D0009oo`03001oogoo01=oo`D0009oo`03001oogoo00Uoo`03001oogoo00Moo`<0
00=oo`03001oogoo01Aoo`<000=oo`03001oogoo00moo`0057oo00<007ooOol067oo00<007oo0000
67oo00L007ooOomoo`00Ool0000FOol01`00Oomoogoo001oo`0000Uoo`03001oogoo00Qoo`03001o
ogoo009oo`03001oo`0001Eoo`03001oogoo009oo`03001oo`00011oo`0057oo00<007ooOol06Woo
00<007ooOol05Woo00L007ooOomoo`00Ool0000FOol00`00Oomoo`03Ool00`00Oomoo`06Ool00`00
Oomoo`0:Ool01`00Oomoogoo001oo`0001Ioo`03001oogoo00=oo`03001oogoo00ioo`0057oo00<0
07ooOol067oo0P006Goo00L007ooOomoo`00Ool0000FOol01000Oomoogoo0P0027oo00<007ooOol0
2goo00L007ooOomoo`00Ool0000FOol01000Oomoogoo0P004Goo000DOol00`00Oomoo`0HOol00`00
Oomoo`0HOol01`00Oomoogoo001oo`0001Ioo`05001oogooOol00008Ool00`00Oomoo`0;Ool00`00
Ool00002Ool00`00Ool0000EOol00`00Ool00002Ool00`00Oomoo`0@Ool001Aoo`03001oogoo01Qo
o`<001Moo`8000Aoo`03001oogoo01Aoo`8000=oo`<000Aoo`8000moo`03001oogoo009oo`03001o
ogoo01Eoo`04001oogooOol3000@Ool001Aoo`03001oogoo05Uoo`8004Eoo`0057oo00<007ooOol0
F7oo00<007ooOol0AGoo000DOol00`00Oomoo`1FOol20018Ool001Aoo`03001oogoo05Aoo`8004Yo
o`0057oo00<007ooOol0DWoo0P00C7oo0003Oond000001Aoo`03001oogoo01Uoo`03001oogoo01Yo
o`03001oogoo01Aoo`<000=oo`03001oogoo01Uoo`03001oogoo01Yoo`03001oogoo015oo`0057oo
00<007ooOol0BWoo0`00Dgoo000DOol00`00Oomoo`17Ool3001FOol001Aoo`05001oogooOol00013
Ool2001IOol001Aoo`03001oogoo009oo`8003eoo`@005]oo`0057oo00<007ooOol017oo0P00=goo
1000Ggoo000DOol00`00Oomoo`06Ool2000bOol3001SOol001Aoo`03001oogoo00Qoo`8002aoo`@0
06Ioo`0057oo00<007ooOol02Woo0`0097oo1@00JWoo000DOol00`00Oomoo`0=Ool2000POol2001_
Ool001Aoo`03001oogoo00moo`@001Qoo`@0075oo`0057oo00<007ooOol04goo6000MGoo000DOol0
0`00Oomoo`2POol001Aoo`03001oogoo0:1oo`0057oo00<007ooOol0X7oo000DOol00`00Oomoo`2P
Ool001Aoo`03001oogoo0:1oo`0057oo00<007ooOol0X7oo000DOol00`00Oomoo`2POol00;Moo`00
]goo0000\
\>"],
  ImageRangeCache->{{{0, 182.875}, {277.375, 0}} -> {-3.53164, -44.5749, 
  0.17443, 0.17443}}]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"Microsoft Windows 3.0",
ScreenRectangle->{{0, 1280}, {0, 968}},
WindowToolbars->"EditBar",
CellGrouping->Manual,
WindowSize->{581, 602},
WindowMargins->{{134, Automatic}, {Automatic, 54}},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, -1}},
ShowCellLabel->True,
ShowCellTags->False,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False},
StyleDefinitions -> "ArticleClassic.nb"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1709, 49, 36, 0, 72, "Title"],
Cell[1748, 51, 143, 5, 72, "Address"],

Cell[CellGroupData[{
Cell[1916, 60, 29, 0, 56, "Section"],
Cell[1948, 62, 483, 9, 82, "Text"],

Cell[CellGroupData[{
Cell[2456, 75, 125, 3, 31, "Input"],
Cell[2584, 80, 252, 8, 57, "Output"]
}, Open  ]],
Cell[2851, 91, 63, 0, 27, "Text"],
Cell[2917, 93, 11636, 276, 221, 5918, 200, "GraphicsData", 
"PostScript", "Graphics"],
Cell[14556, 371, 158, 3, 44, "Text"],
Cell[14717, 376, 420, 6, 111, "Input"],
Cell[15140, 384, 251, 4, 44, "Text"],
Cell[15394, 390, 71, 2, 31, "Input"],
Cell[15468, 394, 99, 2, 31, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[15604, 401, 352, 8, 71, "Input"],
Cell[15959, 411, 21299, 571, 296, 5540, 371, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],
Cell[37273, 985, 156, 3, 44, "Text"],
Cell[37432, 990, 328, 7, 91, "Input"],

Cell[CellGroupData[{
Cell[37785, 1001, 348, 8, 71, "Input"],
Cell[38136, 1011, 17761, 517, 182, 5167, 356, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],
Cell[55912, 1531, 34, 0, 56, "Section"],
Cell[55949, 1533, 45, 0, 43, "Subsection"],
Cell[55997, 1535, 215, 4, 44, "Text"],

Cell[CellGroupData[{
Cell[56237, 1543, 115, 2, 31, "Input"],
Cell[56355, 1547, 194, 5, 30, "Output"]
}, Open  ]],
Cell[56564, 1555, 38, 0, 43, "Subsection"],
Cell[56605, 1557, 502, 8, 95, "Text"],
Cell[57110, 1567, 59, 0, 33, "Subsubsection"],
Cell[57172, 1569, 85, 2, 31, "Input"],

Cell[CellGroupData[{
Cell[57282, 1575, 127, 3, 43, "Input"],
Cell[57412, 1580, 17996, 705, 186, 7165, 566, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],
Cell[75423, 2288, 258, 5, 44, "Text"],

Cell[CellGroupData[{
Cell[75706, 2297, 170, 3, 51, "Input"],
Cell[75879, 2302, 63, 2, 30, "Output"],
Cell[75945, 2306, 62, 2, 31, "Input"]
}, Open  ]],
Cell[76022, 2311, 60, 0, 33, "Subsubsection"],
Cell[76085, 2313, 268, 5, 61, "Text"],
Cell[76356, 2320, 194, 5, 91, "Input"],
Cell[76553, 2327, 121, 3, 27, "Text"],

Cell[CellGroupData[{
Cell[76699, 2334, 171, 3, 51, "Input"],
Cell[76873, 2339, 20376, 560, 296, 5576, 372, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],
Cell[97264, 2902, 42, 0, 56, "Section"],
Cell[97309, 2904, 303, 5, 61, "Text"],

Cell[CellGroupData[{
Cell[97637, 2913, 83, 1, 43, "Subsection"],
Cell[97723, 2916, 394, 6, 78, "Text"],
Cell[98120, 2924, 255, 5, 62, "Input"],
Cell[98378, 2931, 42, 0, 27, "Text"],
Cell[98423, 2933, 128, 3, 31, "Input"],

Cell[CellGroupData[{
Cell[98576, 2940, 101, 2, 31, "Input"],
Cell[98680, 2944, 36177, 772, 186, 5677, 390, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],
Cell[134872, 3719, 75, 0, 27, "Text"],
Cell[134950, 3721, 214, 5, 51, "Input"],
Cell[135167, 3728, 126, 3, 31, "Input"],

Cell[CellGroupData[{
Cell[135318, 3735, 129, 3, 31, "Input"],
Cell[135450, 3740, 36765, 772, 186, 5527, 381, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],
Cell[172230, 4515, 181, 4, 44, "Text"],
Cell[172414, 4521, 169, 3, 64, "Input"],

Cell[CellGroupData[{
Cell[172608, 4528, 109, 2, 51, "Input"],
Cell[172720, 4532, 29056, 704, 186, 5995, 414, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[201825, 5242, 38, 0, 43, "Subsection"],
Cell[201866, 5244, 282, 5, 61, "Text"],
Cell[202151, 5251, 55, 0, 33, "Subsubsection"],
Cell[202209, 5253, 90, 2, 31, "Input"],

Cell[CellGroupData[{
Cell[202324, 5259, 173, 3, 65, "Input"],
Cell[202500, 5264, 21298, 731, 186, 7455, 555, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],
Cell[223813, 5998, 60, 0, 33, "Subsubsection"],
Cell[223876, 6000, 268, 5, 61, "Text"],
Cell[224147, 6007, 271, 7, 84, "Input"],
Cell[224421, 6016, 96, 2, 27, "Text"],

Cell[CellGroupData[{
Cell[224542, 6022, 311, 7, 71, "Input"],
Cell[224856, 6031, 23710, 734, 186, 7871, 533, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],
Cell[248581, 6768, 158, 3, 51, "Input"],
Cell[248742, 6773, 175, 3, 44, "Text"],

Cell[CellGroupData[{
Cell[248942, 6780, 150, 3, 31, "Input"],
Cell[249095, 6785, 20113, 553, 296, 5414, 366, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

