(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    797717,      19137]*)
(*NotebookOutlinePosition[    798458,      19163]*)
(*  CellTagsIndexPosition[    798414,      19159]*)
(*WindowFrame->Normal*)



Notebook[{
Cell["DIGITAL IMAGE REPRESENTATION AND DISPLAY", "Title"],

Cell["Mariusz Jankowski", "Author"],

Cell["\<\
Department of Electrical Engineering
University of Southern Maine
mjkcc@usm.maine.edu\
\>", "Address"],

Cell[BoxData[
    \(<< ImageProcessing`\)], "Input",
  CellLabel->"In[1]:="],

Cell[BoxData[
    \(<< LinearAlgebra`MatrixManipulation`\)], "Input",
  CellLabel->"In[2]:="],

Cell[CellGroupData[{

Cell["INTRODUCTION", "Section"],

Cell["\<\
This document will introduce the concept of a two-dimensional (2D) discrete \
signal. Mathematically, such signals can be represented as functions of two \
independent variables. For example, an image is a brightness function of two \
spatial variables. Nowadays, such signals are typically processed by digital \
hardware and thus represented by arrays of numbers, each number a sample of \
the original continuous-time function (\"image representation\"). As such, \
they can be manipulated mathematically (\"image processing\"), on a computer, \
to achieve a desired result.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["IMAGE REPRESENTATION", "Section"],

Cell[TextData[{
  "A monochrome digital image ",
  Cell[BoxData[
      \(TraditionalForm\`f(x, y)\)]],
  " is a 2D array of luminance values,\n\n\t",
  Cell[BoxData[
      FormBox[
        RowBox[{\(f(x, y)\), " ", "=", " ", 
          RowBox[{"(", GridBox[{
                {\(f(0, 0)\), \(f(0, 1)\), ".", \(f(0, N - 1)\)},
                {\(f(1, 0)\), \(f(1, 1)\), ".", \(f(1, N - 1)\)},
                {".", ".", ".", "."},
                {\(f(M - 1, 0)\), \(f(M - 1, 1)\), ".", \(f(M - 1, N - 1)\)}
                }], ")"}]}], TraditionalForm]]],
  "\n\t\nwith  ",
  Cell[BoxData[
      \(TraditionalForm\`0 \[LessEqual] \ f(x, y)\  \[LessEqual] \ L\)]],
  ", and typically ",
  Cell[BoxData[
      \(TraditionalForm\`L = 255\)]],
  ". Each element of the array is called a pel (picture element), more \
commonly called pixel. Values in this range can be efficiently represented by \
8 binary digits and therefore each pixel occupies one byte in memory. Total \
storage requirements for an image are therefore of the order of ",
  StyleBox["MxN",
    FontSlant->"Italic"],
  " bytes, where ",
  StyleBox["M,N",
    FontSlant->"Italic"],
  " are the number of rows and columns in the image array. A typical value \
for ",
  StyleBox["M",
    FontSlant->"Italic"],
  " and ",
  StyleBox["N",
    FontSlant->"Italic"],
  " is 512, resulting in 262,144 bytes of memory for a single digital image. \
There are however image acquisition devices on the market today that have far \
higher spatial resolutions. For example, the Kodak MegaPlus Model 4.2i camera \
has a resolution 2029x2044 @ 8 bits/pixel, the Nikon Coolscan (LS-1000) 35mm \
desktop film scanner has a resolution of 2592x3888 pixels @ 12-bits/pixel. "
}], "Text"],

Cell["Consider a small portion of the \"head\" image.", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(A = 
      ReadImage["\<head.tif\>", "\<TIFF\>", ImageOutput -> RawImageData]\  // 
        Reverse; \n
    \((a = TakeMatrix[A, \ {64, 64}, {71, 71}])\) // MatrixForm\)], "Input",
  CellLabel->"In[3]:="],

Cell[BoxData[
    TagBox[
      RowBox[{"(", GridBox[{
            {"12", "46", "55", "30", "137", "130", "152", "139"},
            {"18", "61", "37", "50", "138", "136", "147", "140"},
            {"14", "41", "35", "56", "142", "139", "143", "150"},
            {"40", "53", "29", "90", "161", "143", "147", "145"},
            {"84", "58", "39", "77", "146", "147", "146", "150"},
            {"88", "61", "52", "101", "152", "156", "150", "142"},
            {"85", "57", "62", "82", "150", "146", "151", "153"},
            {"71", "62", "50", "50", "153", "151", "151", "163"}
            }], ")"}],
      (MatrixForm[ #]&)]], "Output",
  CellLabel->"Out[3]//MatrixForm="]
}, Open  ]],

Cell[TextData[{
  "Small values represent dark areas of an image, while large values \
represent bright pixels. Note that the image array ",
  Cell[BoxData[
      \(TraditionalForm\`a\)]],
  " gets progressively brighter (larger values) as we move from left to right \
and top to bottom of the data array shown above."
}], "Text"],

Cell["A color digital image  **** UNDER DEVELOPMENT ****", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["IMAGE DISPLAY", "Section"],

Cell[TextData[{
  "Two-dimensional signals may be visualized in any number of ways, such as \
surface plots, contour plots and  intensity plots. The latter is the most \
natural (see ",
  StyleBox["ListDensityPlot", "Program"],
  ")."
}], "Text"],

Cell["Here is a 32-by-32  fragment of the example image.", "Caption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(tmp = TakeMatrix[A, \ {64, 64}, {95, 95}]; \n
    Show[GraphicsArray[{
          ListDensityPlot[tmp, \ Mesh -> False, \ 
            DisplayFunction -> Identity], \n\t\t\t
          ListPlot3D[tmp, DisplayFunction -> Identity], \n\t\t\t\t
          ListContourPlot[tmp, DisplayFunction -> Identity]}]]; \)], "Input",
  CellLabel->"In[11]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .3125 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.31746 0.00744048 0.31746 [
[ 0 0 0 0 ]
[ 1 .3125 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .3125 L
0 .3125 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.00744048 0.321429 0.30506 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0300481 0.0192308 0.0300481 [
[.01923 -0.0125 -3 -9 ]
[.01923 -0.0125 3 0 ]
[.16947 -0.0125 -3 -9 ]
[.16947 -0.0125 3 0 ]
[.31971 -0.0125 -6 -9 ]
[.31971 -0.0125 6 0 ]
[.46995 -0.0125 -6 -9 ]
[.46995 -0.0125 6 0 ]
[.62019 -0.0125 -6 -9 ]
[.62019 -0.0125 6 0 ]
[.77043 -0.0125 -6 -9 ]
[.77043 -0.0125 6 0 ]
[.92067 -0.0125 -6 -9 ]
[.92067 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01923 -6 -4.5 ]
[-0.0125 .01923 0 4.5 ]
[-0.0125 .16947 -6 -4.5 ]
[-0.0125 .16947 0 4.5 ]
[-0.0125 .31971 -12 -4.5 ]
[-0.0125 .31971 0 4.5 ]
[-0.0125 .46995 -12 -4.5 ]
[-0.0125 .46995 0 4.5 ]
[-0.0125 .62019 -12 -4.5 ]
[-0.0125 .62019 0 4.5 ]
[-0.0125 .77043 -12 -4.5 ]
[-0.0125 .77043 0 4.5 ]
[-0.0125 .92067 -12 -4.5 ]
[-0.0125 .92067 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.01923 0 m
.01923 .00625 L
s
[(0)] .01923 -0.0125 0 1 Mshowa
.16947 0 m
.16947 .00625 L
s
[(5)] .16947 -0.0125 0 1 Mshowa
.31971 0 m
.31971 .00625 L
s
[(10)] .31971 -0.0125 0 1 Mshowa
.46995 0 m
.46995 .00625 L
s
[(15)] .46995 -0.0125 0 1 Mshowa
.62019 0 m
.62019 .00625 L
s
[(20)] .62019 -0.0125 0 1 Mshowa
.77043 0 m
.77043 .00625 L
s
[(25)] .77043 -0.0125 0 1 Mshowa
.92067 0 m
.92067 .00625 L
s
[(30)] .92067 -0.0125 0 1 Mshowa
.125 Mabswid
.04928 0 m
.04928 .00375 L
s
.07933 0 m
.07933 .00375 L
s
.10938 0 m
.10938 .00375 L
s
.13942 0 m
.13942 .00375 L
s
.19952 0 m
.19952 .00375 L
s
.22957 0 m
.22957 .00375 L
s
.25962 0 m
.25962 .00375 L
s
.28966 0 m
.28966 .00375 L
s
.34976 0 m
.34976 .00375 L
s
.37981 0 m
.37981 .00375 L
s
.40986 0 m
.40986 .00375 L
s
.4399 0 m
.4399 .00375 L
s
.5 0 m
.5 .00375 L
s
.53005 0 m
.53005 .00375 L
s
.5601 0 m
.5601 .00375 L
s
.59014 0 m
.59014 .00375 L
s
.65024 0 m
.65024 .00375 L
s
.68029 0 m
.68029 .00375 L
s
.71034 0 m
.71034 .00375 L
s
.74038 0 m
.74038 .00375 L
s
.80048 0 m
.80048 .00375 L
s
.83053 0 m
.83053 .00375 L
s
.86058 0 m
.86058 .00375 L
s
.89063 0 m
.89063 .00375 L
s
.95072 0 m
.95072 .00375 L
s
.98077 0 m
.98077 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01923 m
.00625 .01923 L
s
[(0)] -0.0125 .01923 1 0 Mshowa
0 .16947 m
.00625 .16947 L
s
[(5)] -0.0125 .16947 1 0 Mshowa
0 .31971 m
.00625 .31971 L
s
[(10)] -0.0125 .31971 1 0 Mshowa
0 .46995 m
.00625 .46995 L
s
[(15)] -0.0125 .46995 1 0 Mshowa
0 .62019 m
.00625 .62019 L
s
[(20)] -0.0125 .62019 1 0 Mshowa
0 .77043 m
.00625 .77043 L
s
[(25)] -0.0125 .77043 1 0 Mshowa
0 .92067 m
.00625 .92067 L
s
[(30)] -0.0125 .92067 1 0 Mshowa
.125 Mabswid
0 .04928 m
.00375 .04928 L
s
0 .07933 m
.00375 .07933 L
s
0 .10938 m
.00375 .10938 L
s
0 .13942 m
.00375 .13942 L
s
0 .19952 m
.00375 .19952 L
s
0 .22957 m
.00375 .22957 L
s
0 .25962 m
.00375 .25962 L
s
0 .28966 m
.00375 .28966 L
s
0 .34976 m
.00375 .34976 L
s
0 .37981 m
.00375 .37981 L
s
0 .40986 m
.00375 .40986 L
s
0 .4399 m
.00375 .4399 L
s
0 .5 m
.00375 .5 L
s
0 .53005 m
.00375 .53005 L
s
0 .5601 m
.00375 .5601 L
s
0 .59014 m
.00375 .59014 L
s
0 .65024 m
.00375 .65024 L
s
0 .68029 m
.00375 .68029 L
s
0 .71034 m
.00375 .71034 L
s
0 .74038 m
.00375 .74038 L
s
0 .80048 m
.00375 .80048 L
s
0 .83053 m
.00375 .83053 L
s
0 .86058 m
.00375 .86058 L
s
0 .89063 m
.00375 .89063 L
s
0 .95072 m
.00375 .95072 L
s
0 .98077 m
.00375 .98077 L
s
.25 Mabswid
0 0 m
0 1 L
s
.01923 .99375 m
.01923 1 L
s
.16947 .99375 m
.16947 1 L
s
.31971 .99375 m
.31971 1 L
s
.46995 .99375 m
.46995 1 L
s
.62019 .99375 m
.62019 1 L
s
.77043 .99375 m
.77043 1 L
s
.92067 .99375 m
.92067 1 L
s
.125 Mabswid
.04928 .99625 m
.04928 1 L
s
.07933 .99625 m
.07933 1 L
s
.10938 .99625 m
.10938 1 L
s
.13942 .99625 m
.13942 1 L
s
.19952 .99625 m
.19952 1 L
s
.22957 .99625 m
.22957 1 L
s
.25962 .99625 m
.25962 1 L
s
.28966 .99625 m
.28966 1 L
s
.34976 .99625 m
.34976 1 L
s
.37981 .99625 m
.37981 1 L
s
.40986 .99625 m
.40986 1 L
s
.4399 .99625 m
.4399 1 L
s
.5 .99625 m
.5 1 L
s
.53005 .99625 m
.53005 1 L
s
.5601 .99625 m
.5601 1 L
s
.59014 .99625 m
.59014 1 L
s
.65024 .99625 m
.65024 1 L
s
.68029 .99625 m
.68029 1 L
s
.71034 .99625 m
.71034 1 L
s
.74038 .99625 m
.74038 1 L
s
.80048 .99625 m
.80048 1 L
s
.83053 .99625 m
.83053 1 L
s
.86058 .99625 m
.86058 1 L
s
.89063 .99625 m
.89063 1 L
s
.95072 .99625 m
.95072 1 L
s
.98077 .99625 m
.98077 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .01923 m
1 .01923 L
s
.99375 .16947 m
1 .16947 L
s
.99375 .31971 m
1 .31971 L
s
.99375 .46995 m
1 .46995 L
s
.99375 .62019 m
1 .62019 L
s
.99375 .77043 m
1 .77043 L
s
.99375 .92067 m
1 .92067 L
s
.125 Mabswid
.99625 .04928 m
1 .04928 L
s
.99625 .07933 m
1 .07933 L
s
.99625 .10938 m
1 .10938 L
s
.99625 .13942 m
1 .13942 L
s
.99625 .19952 m
1 .19952 L
s
.99625 .22957 m
1 .22957 L
s
.99625 .25962 m
1 .25962 L
s
.99625 .28966 m
1 .28966 L
s
.99625 .34976 m
1 .34976 L
s
.99625 .37981 m
1 .37981 L
s
.99625 .40986 m
1 .40986 L
s
.99625 .4399 m
1 .4399 L
s
.99625 .5 m
1 .5 L
s
.99625 .53005 m
1 .53005 L
s
.99625 .5601 m
1 .5601 L
s
.99625 .59014 m
1 .59014 L
s
.99625 .65024 m
1 .65024 L
s
.99625 .68029 m
1 .68029 L
s
.99625 .71034 m
1 .71034 L
s
.99625 .74038 m
1 .74038 L
s
.99625 .80048 m
1 .80048 L
s
.99625 .83053 m
1 .83053 L
s
.99625 .86058 m
1 .86058 L
s
.99625 .89063 m
1 .89063 L
s
.99625 .95072 m
1 .95072 L
s
.99625 .98077 m
1 .98077 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
32 string
32 32 8 [32 0 0 32 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
11414E2AC3B9D9C6C3C5CBC5C8BBC3C6613247C699B2BEB8
B9D0A7B2BCBE6B93
19573447C5C2D2C8C6C6D6C6C5B5CBB278464EBEB5B796BF
C1D3D9B8909DB483
143A3250CBC6CCD6CFCDD0DAD6C5D5C693558F79B9A787A8
96B9B9BBB8C8B569
394B2980E6CCD2CFD2D5D9D6EDCCC5C59E66AEAAB1AA7AB2
96BECD94C98AB8C6
7852376ED0D2D0D6D3E1DCD2D7CDBEBFAA766FA7B5B87694
9BA7CB8CAB9BBC86
7D574A90D9DFD6CBD5D9D5DDE4C5BCCCBE7D5E6EA7A37283
BBAEBCB882B9AD6F
79515875D6D0D7DACFD6D6D9B7BEC9BBB986684065A186BB
9985B9B5A59A9A6E
65584747DAD7D7E9D7DDC9C1C1C5C9D6C38564574D4EA387
BE76BEB19D8C8F87
3D374057D0EBE6D7D5CFBFC6C2B7C5D3B2AED35F514A7FC8
B17FBE968D869A80
32464452A16587C6BEBCCCBCC6B9BFC2C5C1CDB1505851B8
BB70A47F65658093
4D5454BCBB65ADC2B1C6D9D5C5BBBEC5ADD3DD5E51655737
37477F769E90A08C
5555484A416C8F9BBED3D7C6D7C8CCAEA0D5DA3D4E613E3D
5E7593B5C1C5D9D2
BC756E579ABFA5C1DAE7E4E6EDD9CC9BCCDDA4433D435429
36858FABA0ADC3D2
DDC6A1C5CCCBD9D5DDE9DDD3CDCDB9B2DABC4B3C3937395C
7A969197938FAAAF
ABBCBECBAACDC6D2D7DDD0D7D5CBCBAB8364344D4B5A4B73
859EA1B1ABB8B2BB
BBB5C2C3C5C9B8DFD7E6DDCBBC949E6B5B6E8962797D68AF
B2B5C9C9A0A8AFAD
D0ADC3C6CDCDAECCCCB7ABA7AB89A868475A4DD6EBDF96B4
BFD0D5D5C1B4AB96
CCBED0C3BEBBB2D6BCC5C8BCB4A4AF4D573EE6CCD6E0C3B8
DDC2CCD5CFBCAEA7
E4D2C9C5C9BCBEC6B4C1BBB4B4AEAB52556CEAD2DCDDD5BC
CFBCA5B5D2D0C9C6
C5C3CBC6C5C3B9C5BCC1BCB9B7BB97694E5ADFDCD5DADFC3
E3B7909B9BCCC6C2
9BB7A4CCD3C8C1C5C9B8BCC1BBBB8F664887C1E1E7DDD6C6
DDCDAB9496A89E94
5770839ECBBBBEC5C5C8BCC3B8948C91C1C6CBE9EEF3B4CC
E0D5D5A87991AA9A
3C476168BCC1AFC5C5BCB9BCB7B2D9A589A1CDF1F5D5B4D3
D7C29EA59DBECBBB
48463E509E9DBEC1C9C1CCB4A4A569646EA0DAFAF7C5CFDD
D9A3829DBEBCB4D9
5C4636465F7DAEC1BBBCA7A49E875E5791E0EBFFD0B7E1E3
DDA49DABCF969ED3
55473A2D4344435CC3CCB276322F419BC8EBF0C2B9D5D7CF
C2AA8AA3C897A1C8
4B41413A2D282F3D3C2A3A47483C8FD2F5EABEB8D7DCD6C9
AB978CADCB9AA3A4
44433E3637302D30363A4B4D68A3CBF1D6A5B5DFDFD2CCC1
9A8689AED6AA8D78
3439342D2D302D3E463E6EAAC2DDEDD2B4D3DCDDDCDFCDCF
AFA193A8D9D2B7A7
4A2F2636363D406690BEE0E0DCD7C2C1E1DCDFD5C9CBC5B2
B59472A394DCDAAF
E4DAC1BCB7C5CCDDE6E6DDCCC2BCCBDFDADCD2E0CCCFB49E
9E99A4838DB8CCC8
FDF7F8FAF4F0F4EEDDD2B4BED5CFDADFDCD7B8BFD2C6C5B2
D0B5BE9D6C8AC6C5
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.35119 0.00744048 0.64881 0.30506 MathSubStart
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.11022e-016 1.04977 -0.0679587 1.04977 [
[.20131 .17781 -11.698 -9 ]
[.20131 .17781 .302 0 ]
[.40909 .09608 -10.8909 -9 ]
[.40909 .09608 1.10907 0 ]
[.63425 .0076 -10.0839 -9 ]
[.63425 .0076 1.91614 0 ]
[.79552 .14001 0 -6.12026 ]
[.79552 .14001 12 2.87974 ]
[.88711 .28027 0 -5.98728 ]
[.88711 .28027 12 3.01272 ]
[.96711 .40279 0 -5.87447 ]
[.96711 .40279 12 3.12553 ]
[.02411 .26511 -6 -2.74232 ]
[.02411 .26511 0 6.25768 ]
[.01467 .32427 -12 -2.79235 ]
[.01467 .32427 0 6.20765 ]
[.00486 .38575 -18 -2.84454 ]
[.00486 .38575 0 6.15546 ]
[-0.00534 .44968 -18 -2.89903 ]
[-0.00534 .44968 0 6.10097 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.03716 .25514 m
.68874 0 L
s
.21035 .18732 m
.21487 .19208 L
s
[(10)] .20131 .17781 .94967 1 Mshowa
.41738 .10625 m
.42153 .11134 L
s
[(20)] .40909 .09608 .81515 1 Mshowa
.64163 .01845 m
.64532 .02387 L
s
[(30)] .63425 .0076 .68064 1 Mshowa
.125 Mabswid
.25047 .17161 m
.25314 .1745 L
s
.29122 .15565 m
.29385 .15859 L
s
.33262 .13945 m
.3352 .14242 L
s
.37466 .12298 m
.3772 .12599 L
s
.46079 .08926 m
.46322 .09235 L
s
.5049 .07199 m
.50728 .07512 L
s
.54973 .05443 m
.55206 .0576 L
s
.5953 .03659 m
.59757 .0398 L
s
.17084 .20279 m
.17359 .20561 L
s
.13192 .21803 m
.13471 .22081 L
s
.09359 .23304 m
.09641 .23578 L
s
.05583 .24783 m
.05869 .25053 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.78318 .14446 m
.777 .14668 L
s
[(10)] .79552 .14001 -1 .36006 Mshowa
.87465 .28439 m
.86842 .28645 L
s
[(20)] .88711 .28027 -1 .33051 Mshowa
.95456 .40662 m
.94829 .40854 L
s
[(30)] .96711 .40279 -1 .30544 Mshowa
.125 Mabswid
.80252 .17404 m
.7988 .17536 L
s
.82131 .20279 m
.81759 .20409 L
s
.83959 .23075 m
.83586 .23202 L
s
.85736 .25793 m
.85363 .25919 L
s
.89149 .31014 m
.88774 .31135 L
s
.90788 .33521 m
.90413 .33641 L
s
.92384 .35963 m
.92009 .36081 L
s
.9394 .38343 m
.93564 .38459 L
s
.76327 .11401 m
.75957 .11536 L
s
.74277 .08265 m
.73908 .08403 L
s
.72165 .05034 m
.71797 .05174 L
s
.69987 .01704 m
.6962 .01846 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03634 .26033 m
.04245 .25795 L
s
[(0)] .02411 .26511 1 -0.3906 Mshowa
.02694 .31961 m
.03308 .31729 L
s
[(50)] .01467 .32427 1 -0.37948 Mshowa
.01718 .38122 m
.02334 .37895 L
s
[(100)] .00486 .38575 1 -0.36788 Mshowa
.00703 .44528 m
.01321 .44308 L
s
[(150)] -0.00534 .44968 1 -0.35577 Mshowa
.125 Mabswid
.03449 .27201 m
.03816 .27058 L
s
.03262 .28377 m
.03629 .28236 L
s
.03074 .29563 m
.03442 .29422 L
s
.02885 .30758 m
.03253 .30617 L
s
.02502 .33174 m
.0287 .33035 L
s
.02308 .34397 m
.02677 .34259 L
s
.02113 .35629 m
.02482 .35491 L
s
.01916 .3687 m
.02285 .36734 L
s
.01518 .39383 m
.01888 .39248 L
s
.01317 .40654 m
.01687 .4052 L
s
.01114 .41935 m
.01484 .41802 L
s
.00909 .43227 m
.0128 .43094 L
s
.00495 .45841 m
.00866 .4571 L
s
.00285 .47163 m
.00657 .47033 L
s
.00074 .48497 m
.00446 .48367 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.5 Mabswid
.691 .574 .718 r
.38843 .77461 .39814 .80339 .41577 .79401 .40616 .76162 Metetra
.744 .591 .686 r
.40616 .76162 .41577 .79401 .43332 .79056 .4243 .73569 Metetra
.625 .475 .659 r
.4243 .73569 .43332 .79056 .45099 .78709 .44193 .72736 Metetra
.627 .471 .652 r
.44193 .72736 .45099 .78709 .46889 .77759 .45966 .71783 Metetra
.541 .412 .653 r
.45966 .71783 .46889 .77759 .48684 .76925 .47724 .72468 Metetra
.574 .458 .684 r
.47724 .72468 .48684 .76925 .50484 .76808 .4951 .72569 Metetra
.501 .416 .691 r
.4951 .72569 .50484 .76808 .52299 .75846 .51311 .73507 Metetra
.544 .525 .785 r
.51311 .73507 .52299 .75846 .54117 .73922 .53138 .73735 Metetra
.509 .882 .974 r
.53138 .73735 .54117 .73922 .55938 .72476 .54979 .7324 Metetra
.54979 .7324 .55938 .72476 .57737 .69493 .56824 .72018 Metetra
.18 0 .186 r
.56824 .72018 .57737 .69493 .5959 .69816 .58661 .70073 Metetra
.692 .981 .841 r
.58661 .70073 .5959 .69816 .61491 .7122 .60509 .68727 Metetra
.679 .589 .748 r
.60509 .68727 .61491 .7122 .63351 .70235 .6237 .67735 Metetra
.48 .479 .778 r
.6237 .67735 .63351 .70235 .65271 .70689 .64296 .68415 Metetra
.364 .429 .794 r
.64296 .68415 .65271 .70689 .67189 .70541 .66267 .6959 Metetra
.719 .779 .9 r
.66267 .6959 .67189 .70541 .69096 .69784 .68178 .68704 Metetra
.626 .726 .919 r
.68178 .68704 .69096 .69784 .71006 .68903 .70122 .68302 Metetra
.803 .871 .898 r
.70122 .68302 .71006 .68903 .72792 .65728 .72026 .66921 Metetra
.586 .15 .18 r
.72026 .66921 .72792 .65728 .7477 .65798 .74062 .6761 Metetra
0 0 .018 r
.74062 .6761 .7477 .65798 .76835 .66839 .75928 .65363 Metetra
.612 .656 .869 r
.75928 .65363 .76835 .66839 .7874 .65333 .77931 .65066 Metetra
.938 .913 .766 r
.77931 .65066 .7874 .65333 .80716 .64672 .79749 .62212 Metetra
.77 .641 .719 r
.79749 .62212 .80716 .64672 .82578 .62556 .81595 .59854 Metetra
.635 .559 .752 r
.81595 .59854 .82578 .62556 .84819 .64559 .83598 .59294 Metetra
.634 .487 .666 r
.83598 .59294 .84819 .64559 .86623 .61695 .85568 .58251 Metetra
.547 .475 .727 r
.85568 .58251 .86623 .61695 .88732 .61867 .87696 .58645 Metetra
.781 .618 .678 r
.87696 .58645 .88732 .61867 .90474 .58523 .89442 .55315 Metetra
.557 .491 .737 r
.89442 .55315 .90474 .58523 .92046 .53913 .91583 .55572 Metetra
.764 .364 .295 r
.91583 .55572 .92046 .53913 .94391 .55822 .94092 .58627 Metetra
.622 .276 .364 r
.94092 .58627 .94391 .55822 .97122 .60343 .96417 .59775 Metetra
.705 .897 .966 r
.96417 .59775 .97122 .60343 .9922 .59645 .98496 .58821 Metetra
.633 .441 .606 r
.38296 .64193 .38843 .77461 .40616 .76162 .40065 .61598 Metetra
.6 .414 .601 r
.40065 .61598 .40616 .76162 .4243 .73569 .41781 .60435 Metetra
.557 .383 .601 r
.41781 .60435 .4243 .73569 .44193 .72736 .43451 .61136 Metetra
.59 .412 .609 r
.43451 .61136 .44193 .72736 .45966 .71783 .4517 .60625 Metetra
.575 .402 .61 r
.4517 .60625 .45966 .71783 .47724 .72468 .46891 .60666 Metetra
.584 .407 .608 r
.46891 .60666 .47724 .72468 .4951 .72569 .48632 .60373 Metetra
.5 .343 .6 r
.48632 .60373 .4951 .72569 .51311 .73507 .5037 .62896 Metetra
.476 .332 .605 r
.5037 .62896 .51311 .73507 .53138 .73735 .5215 .65712 Metetra
.412 .301 .617 r
.5215 .65712 .53138 .73735 .54979 .7324 .53978 .68959 Metetra
.333 .304 .676 r
.53978 .68959 .54979 .7324 .56824 .72018 .55849 .71328 Metetra
.634 .811 .968 r
.55849 .71328 .56824 .72018 .58661 .70073 .57721 .70819 Metetra
.57721 .70819 .58661 .70073 .60509 .68727 .59599 .69943 Metetra
.173 0 0 r
.59599 .69943 .60509 .68727 .6237 .67735 .61485 .69062 Metetra
.61485 .69062 .6237 .67735 .64296 .68415 .63335 .6673 Metetra
.665 .649 .824 r
.63335 .6673 .64296 .68415 .66267 .6959 .6524 .66081 Metetra
.299 .312 .706 r
.6524 .66081 .66267 .6959 .68178 .68704 .67279 .68345 Metetra
.729 .922 .957 r
.67279 .68345 .68178 .68704 .70122 .68302 .69207 .67324 Metetra
.589 .737 .946 r
.69207 .67324 .70122 .68302 .72026 .66921 .71181 .67035 Metetra
.715 .987 .864 r
.71181 .67035 .72026 .66921 .74062 .6761 .73107 .65638 Metetra
.74 .66 .77 r
.73107 .65638 .74062 .6761 .75928 .65363 .75028 .64117 Metetra
.631 .703 .898 r
.75028 .64117 .75928 .65363 .77931 .65066 .7703 .6369 Metetra
.723 .719 .846 r
.7703 .6369 .77931 .65066 .79749 .62212 .79001 .62648 Metetra
.757 .969 .689 r
.79001 .62648 .79749 .62212 .81595 .59854 .80888 .60507 Metetra
.226 0 0 r
.80888 .60507 .81595 .59854 .83598 .59294 .82933 .60186 Metetra
.776 .887 .472 r
.82933 .60186 .83598 .59294 .85568 .58251 .84708 .56837 Metetra
.886 .758 .715 r
.84708 .56837 .85568 .58251 .87696 .58645 .86454 .53402 Metetra
.332 .29 .661 r
.86454 .53402 .87696 .58645 .89442 .55315 .88924 .56888 Metetra
.082 0 .052 r
.88924 .56888 .89442 .55315 .91583 .55572 .90858 .55095 Metetra
.856 .413 .003 r
.90858 .55095 .91583 .55572 .94092 .58627 .93676 .60656 Metetra
.408 .047 .237 r
.93676 .60656 .94092 .58627 .96417 .59775 .95795 .59948 Metetra
.97 .918 .586 r
.95795 .59948 .96417 .59775 .98496 .58821 .97448 .55634 Metetra
.599 .533 .752 r
.37341 .61611 .38296 .64193 .40065 .61598 .39021 .61435 Metetra
.697 .932 .965 r
.39021 .61435 .40065 .61598 .41781 .60435 .40738 .60594 Metetra
.689 .976 .906 r
.40738 .60594 .41781 .60435 .43451 .61136 .42468 .59528 Metetra
.654 .639 .823 r
.42468 .59528 .43451 .61136 .4517 .60625 .44191 .5901 Metetra
.619 .624 .834 r
.44191 .5901 .4517 .60625 .46891 .60666 .4592 .58711 Metetra
.673 .615 .783 r
.4592 .58711 .46891 .60666 .48632 .60373 .47669 .57965 Metetra
.436 .453 .779 r
.47669 .57965 .48632 .60373 .5037 .62896 .49413 .58775 Metetra
.576 .465 .69 r
.49413 .58775 .5037 .62896 .5215 .65712 .51185 .58808 Metetra
.623 .459 .639 r
.51185 .58808 .5215 .65712 .53978 .68959 .52974 .57714 Metetra
.465 .321 .6 r
.52974 .57714 .53978 .68959 .55849 .71328 .54796 .60932 Metetra
.401 .279 .597 r
.54796 .60932 .55849 .71328 .57721 .70819 .56685 .65307 Metetra
.476 .375 .661 r
.56685 .65307 .57721 .70819 .59599 .69943 .58589 .6681 Metetra
.327 .347 .73 r
.58589 .6681 .59599 .69943 .61485 .69062 .60534 .68585 Metetra
0 .345 .709 r
.60534 .68585 .61485 .69062 .63335 .6673 .6249 .69408 Metetra
0 0 .118 r
.6249 .69408 .63335 .6673 .6524 .66081 .64349 .66552 Metetra
.934 .968 .701 r
.64349 .66552 .6524 .66081 .67279 .68345 .66188 .63473 Metetra
.408 .344 .674 r
.66188 .63473 .67279 .68345 .69207 .67324 .68246 .65599 Metetra
.522 .582 .856 r
.68246 .65599 .69207 .67324 .71181 .67035 .7025 .65793 Metetra
.629 .705 .9 r
.7025 .65793 .71181 .67035 .73107 .65638 .72242 .65371 Metetra
.577 .907 .978 r
.72242 .65371 .73107 .65638 .75028 .64117 .74234 .64699 Metetra
.19 0 0 r
.74234 .64699 .75028 .64117 .7703 .6369 .76263 .64394 Metetra
.585 .87 .552 r
.76263 .64394 .7703 .6369 .79001 .62648 .78181 .62353 Metetra
.47 .858 .977 r
.78181 .62353 .79001 .62648 .80888 .60507 .80225 .61914 Metetra
.80225 .61914 .80888 .60507 .82933 .60186 .82039 .58647 Metetra
.788 .725 .794 r
.82039 .58647 .82933 .60186 .84708 .56837 .83973 .56856 Metetra
.808 .999 .838 r
.83973 .56856 .84708 .56837 .86454 .53402 .85906 .55065 Metetra
.639 .233 .257 r
.85906 .55065 .86454 .53402 .88924 .56888 .88157 .56296 Metetra
.748 .258 0 r
.88157 .56296 .88924 .56888 .90858 .55095 .90714 .59913 Metetra
.474 .201 .419 r
.90714 .59913 .90858 .55095 .93676 .60656 .92769 .58701 Metetra
.835 .71 .726 r
.92769 .58701 .93676 .60656 .95795 .59948 .94614 .55746 Metetra
.692 .544 .681 r
.94614 .55746 .95795 .59948 .97448 .55634 .96576 .5379 Metetra
.34 .816 .771 r
.36249 .61892 .37341 .61611 .39021 .61435 .3796 .61269 Metetra
.697 .932 .965 r
.3796 .61269 .39021 .61435 .40738 .60594 .39688 .60421 Metetra
.788 .933 .927 r
.39688 .60421 .40738 .60594 .42468 .59528 .41435 .59235 Metetra
.53 .866 .993 r
.41435 .59235 .42468 .59528 .44191 .5901 .43164 .58823 Metetra
.762 .937 .941 r
.43164 .58823 .44191 .5901 .4592 .58711 .44921 .57741 Metetra
.704 .755 .892 r
.44921 .57741 .4592 .58711 .47669 .57965 .46678 .56988 Metetra
.607 .728 .931 r
.46678 .56988 .47669 .57965 .49413 .58775 .48439 .56677 Metetra
.584 .563 .796 r
.48439 .56677 .49413 .58775 .51185 .58808 .50212 .56588 Metetra
.6 .562 .784 r
.50212 .56588 .51185 .58808 .52974 .57714 .52001 .56385 Metetra
.248 .484 .888 r
.52001 .56385 .52974 .57714 .54796 .60932 .5381 .57199 Metetra
.612 .5 .702 r
.5381 .57199 .54796 .60932 .56685 .65307 .55634 .56769 Metetra
.505 .364 .622 r
.55634 .56769 .56685 .65307 .58589 .6681 .57501 .58401 Metetra
.356 .258 .605 r
.57501 .58401 .58589 .6681 .60534 .68585 .59458 .62663 Metetra
.376 .301 .644 r
.59458 .62663 .60534 .68585 .6249 .69408 .61444 .6549 Metetra
.242 .259 .679 r
.61444 .6549 .6249 .69408 .64349 .66552 .63479 .68269 Metetra
.63479 .68269 .64349 .66552 .66188 .63473 .65356 .65385 Metetra
.747 .807 .329 r
.65356 .65385 .66188 .63473 .68246 .65599 .67143 .6071 Metetra
.524 .42 .679 r
.67143 .6071 .68246 .65599 .7025 .65793 .69161 .61481 Metetra
.271 .268 .672 r
.69161 .61481 .7025 .65793 .72242 .65371 .71329 .64479 Metetra
.644 .785 .949 r
.71329 .64479 .72242 .65371 .74234 .64699 .73338 .63923 Metetra
.827 .848 .863 r
.73338 .63923 .74234 .64699 .76263 .64394 .75289 .62248 Metetra
.693 .63 .781 r
.75289 .62248 .76263 .64394 .78181 .62353 .77285 .61187 Metetra
.791 .777 .84 r
.77285 .61187 .78181 .62353 .80225 .61914 .7925 .5963 Metetra
.844 .685 .686 r
.7925 .5963 .80225 .61914 .82039 .58647 .81024 .55758 Metetra
.748 .614 .71 r
.81024 .55758 .82039 .58647 .83973 .56856 .82916 .53485 Metetra
.607 .516 .726 r
.82916 .53485 .83973 .56856 .85906 .55065 .84988 .53131 Metetra
0 .209 .728 r
.84988 .53131 .85906 .55065 .88157 .56296 .87379 .55695 Metetra
.66 .148 0 r
.87379 .55695 .88157 .56296 .90714 .59913 .89861 .58577 Metetra
.927 .778 .676 r
.89861 .58577 .90714 .59913 .92769 .58701 .91552 .54128 Metetra
.729 .559 .66 r
.91552 .54128 .92769 .58701 .94614 .55746 .9338 .51078 Metetra
.702 .54 .665 r
.9338 .51078 .94614 .55746 .96576 .5379 .95273 .4865 Metetra
.808 .877 .897 r
.35171 .61505 .36249 .61892 .3796 .61269 .36921 .60206 Metetra
.66 .725 .897 r
.36921 .60206 .3796 .61269 .39688 .60421 .38643 .59685 Metetra
.764 .808 .888 r
.38643 .59685 .39688 .60421 .41435 .59235 .40396 .58602 Metetra
.821 .826 .853 r
.40396 .58602 .41435 .59235 .43164 .58823 .42168 .5707 Metetra
.704 .648 .792 r
.42168 .5707 .43164 .58823 .44921 .57741 .43928 .56092 Metetra
.554 .595 .849 r
.43928 .56092 .44921 .57741 .46678 .56988 .45673 .56111 Metetra
.16 .537 .924 r
.45673 .56111 .46678 .56988 .48439 .56677 .47428 .56693 Metetra
.505 .905 .921 r
.47428 .56693 .48439 .56677 .50212 .56588 .49218 .56038 Metetra
.858 .848 .833 r
.49218 .56038 .50212 .56588 .52001 .56385 .51023 .54144 Metetra
.444 .476 .798 r
.51023 .54144 .52001 .56385 .5381 .57199 .52829 .5483 Metetra
.496 .496 .787 r
.52829 .5483 .5381 .57199 .55634 .56769 .54659 .55299 Metetra
.638 .662 .857 r
.54659 .55299 .55634 .56769 .57501 .58401 .56501 .54858 Metetra
.689 .553 .695 r
.56501 .54858 .57501 .58401 .59458 .62663 .58337 .53274 Metetra
.262 .184 .576 r
.58337 .53274 .59458 .62663 .61444 .6549 .60353 .59443 Metetra
.14 .135 .59 r
.60353 .59443 .61444 .6549 .63479 .68269 .62427 .64556 Metetra
.254 .277 .692 r
.62427 .64556 .63479 .68269 .65356 .65385 .6449 .67105 Metetra
.096 0 .018 r
.6449 .67105 .65356 .65385 .67143 .6071 .66439 .65558 Metetra
.119 0 .296 r
.66439 .65558 .67143 .6071 .69161 .61481 .68261 .61178 Metetra
.719 .939 .957 r
.68261 .61178 .69161 .61481 .71329 .64479 .70224 .60125 Metetra
.378 .339 .688 r
.70224 .60125 .71329 .64479 .73338 .63923 .7238 .62265 Metetra
.589 .631 .861 r
.7238 .62265 .73338 .63923 .75289 .62248 .74434 .6207 Metetra
.682 .959 .945 r
.74434 .6207 .75289 .62248 .77285 .61187 .76446 .61 Metetra
.829 .975 .886 r
.76446 .61 .77285 .61187 .7925 .5963 .7842 .59304 Metetra
.948 .905 .746 r
.7842 .59304 .7925 .5963 .81024 .55758 .80274 .56133 Metetra
.798 .98 .701 r
.80274 .56133 .81024 .55758 .82916 .53485 .82188 .53834 Metetra
.588 .922 .703 r
.82188 .53834 .82916 .53485 .84988 .53131 .84165 .52266 Metetra
0 .061 .567 r
.84165 .52266 .84988 .53131 .87379 .55695 .86525 .54467 Metetra
0 .225 .742 r
.86525 .54467 .87379 .55695 .89861 .58577 .88916 .56472 Metetra
.89 .716 .66 r
.88916 .56472 .89861 .58577 .91552 .54128 .90579 .51656 Metetra
.555 .537 .79 r
.90579 .51656 .91552 .54128 .9338 .51078 .92799 .51776 Metetra
.176 0 0 r
.92799 .51776 .9338 .51078 .95273 .4865 .94965 .5128 Metetra
.854 .911 .872 r
.34064 .61338 .35171 .61505 .36921 .60206 .35844 .59691 Metetra
.827 .846 .862 r
.35844 .59691 .36921 .60206 .38643 .59685 .37619 .58155 Metetra
.763 .689 .781 r
.37619 .58155 .38643 .59685 .40396 .58602 .39395 .56619 Metetra
.255 .389 .807 r
.39395 .56619 .40396 .58602 .42168 .5707 .41083 .57764 Metetra
.129 0 0 r
.41083 .57764 .42168 .5707 .43928 .56092 .42843 .5734 Metetra
.229 0 0 r
.42843 .5734 .43928 .56092 .45673 .56111 .44621 .56686 Metetra
.714 .26 .17 r
.44621 .56686 .45673 .56111 .47428 .56693 .46371 .58192 Metetra
.873 .552 .439 r
.46371 .58192 .47428 .56693 .49218 .56038 .48074 .66118 Metetra
.561 .311 .495 r
.48074 .66118 .49218 .56038 .51023 .54144 .49935 .66312 Metetra
.476 .247 .486 r
.49935 .66312 .51023 .54144 .52829 .5483 .51823 .63603 Metetra
.258 .054 .401 r
.51823 .63603 .52829 .5483 .54659 .55299 .5369 .58083 Metetra
.794 .799 .307 r
.5369 .58083 .54659 .55299 .56501 .54858 .5551 .52002 Metetra
.652 .557 .735 r
.5551 .52002 .56501 .54858 .58337 .53274 .57359 .51207 Metetra
.374 .456 .816 r
.57359 .51207 .58337 .53274 .60353 .59443 .59252 .52116 Metetra
.068 .064 .543 r
.59252 .52116 .60353 .59443 .62427 .64556 .61327 .58925 Metetra
.32 .268 .642 r
.61327 .58925 .62427 .64556 .6449 .67105 .63386 .62121 Metetra
.357 .308 .666 r
.63386 .62121 .6449 .67105 .66439 .65558 .65477 .64659 Metetra
.535 .745 .972 r
.65477 .64659 .66439 .65558 .68261 .61178 .67501 .64475 Metetra
0 0 .081 r
.67501 .64475 .68261 .61178 .70224 .60125 .69329 .59929 Metetra
.762 .967 .928 r
.69329 .59929 .70224 .60125 .7238 .62265 .71303 .58616 Metetra
.378 .364 .717 r
.71303 .58616 .7238 .62265 .74434 .6207 .73472 .60387 Metetra
.61 .641 .856 r
.73472 .60387 .74434 .6207 .76446 .61 .75542 .60057 Metetra
.777 .82 .886 r
.75542 .60057 .76446 .61 .7842 .59304 .77557 .58722 Metetra
.838 .902 .883 r
.77557 .58722 .7842 .59304 .80274 .56133 .79548 .57012 Metetra
.652 .861 .478 r
.79548 .57012 .80274 .56133 .82188 .53834 .81455 .54314 Metetra
.897 .958 .622 r
.81455 .54314 .82188 .53834 .84165 .52266 .83296 .51024 Metetra
.026 .362 .834 r
.83296 .51024 .84165 .52266 .86525 .54467 .85588 .52485 Metetra
0 .207 .727 r
.85588 .52485 .86525 .54467 .88916 .56472 .88044 .55102 Metetra
.934 .776 .661 r
.88044 .55102 .88916 .56472 .90579 .51656 .89725 .50269 Metetra
.476 .62 .913 r
.89725 .50269 .90579 .51656 .92799 .51776 .91967 .50506 Metetra
0 .087 .633 r
.91967 .50506 .92799 .51776 .94965 .5128 .94552 .53249 Metetra
.883 .839 .797 r
.32951 .60941 .34064 .61338 .35844 .59691 .3478 .58604 Metetra
.806 .748 .799 r
.3478 .58604 .35844 .59691 .37619 .58155 .36576 .56836 Metetra
.253 .497 .895 r
.36576 .56836 .37619 .58155 .39395 .56619 .38267 .57535 Metetra
.708 .289 .249 r
.38267 .57535 .39395 .56619 .41083 .57764 .39952 .59044 Metetra
.725 .338 .316 r
.39952 .59044 .41083 .57764 .42843 .5734 .41658 .60931 Metetra
.726 .416 .455 r
.41658 .60931 .42843 .5734 .44621 .56686 .43359 .64401 Metetra
.59 .324 .482 r
.43359 .64401 .44621 .56686 .46371 .58192 .45166 .65427 Metetra
.498 .239 .452 r
.45166 .65427 .46371 .58192 .48074 .66118 .47035 .64408 Metetra
.63 .635 .837 r
.47035 .64408 .48074 .66118 .49935 .66312 .48905 .63988 Metetra
.772 .647 .723 r
.48905 .63988 .49935 .66312 .51823 .63603 .50798 .61638 Metetra
.673 .629 .797 r
.50798 .61638 .51823 .63603 .5369 .58083 .52686 .60846 Metetra
.369 .036 .264 r
.52686 .60846 .5369 .58083 .5551 .52002 .54582 .59811 Metetra
.429 .186 .442 r
.54582 .59811 .5551 .52002 .57359 .51207 .5647 .57343 Metetra
.247 .021 .361 r
.5647 .57343 .57359 .51207 .59252 .52116 .58323 .53365 Metetra
.041 0 0 r
.58323 .53365 .59252 .52116 .61327 .58925 .60216 .52205 Metetra
.273 .217 .611 r
.60216 .52205 .61327 .58925 .63386 .62121 .62271 .56465 Metetra
0 .015 .538 r
.62271 .56465 .63386 .62121 .65477 .64659 .64462 .62619 Metetra
.48 .533 .834 r
.64462 .62619 .65477 .64659 .67501 .64475 .66515 .63053 Metetra
.131 .413 .86 r
.66515 .63053 .67501 .64475 .69329 .59929 .68629 .64255 Metetra
0 0 .222 r
.68629 .64255 .69329 .59929 .71303 .58616 .70468 .59522 Metetra
.734 .909 .539 r
.70468 .59522 .71303 .58616 .73472 .60387 .72384 .56706 Metetra
.168 .225 .679 r
.72384 .56706 .73472 .60387 .75542 .60057 .74674 .59856 Metetra
.415 .848 .944 r
.74674 .59856 .75542 .60057 .77557 .58722 .76769 .59392 Metetra
.76769 .59392 .77557 .58722 .79548 .57012 .78832 .58291 Metetra
.902 .864 .421 r
.78832 .58291 .79548 .57012 .81455 .54314 .80529 .52702 Metetra
.731 .707 .827 r
.80529 .52702 .81455 .54314 .83296 .51024 .8257 .51475 Metetra
.463 0 0 r
.8257 .51475 .83296 .51024 .85588 .52485 .84798 .52089 Metetra
.661 .124 0 r
.84798 .52089 .85588 .52485 .88044 .55102 .87253 .54597 Metetra
.987 .838 .608 r
.87253 .54597 .88044 .55102 .89725 .50269 .88874 .48989 Metetra
.492 .652 .93 r
.88874 .48989 .89725 .50269 .91967 .50506 .91111 .49095 Metetra
0 0 .455 r
.91111 .49095 .91967 .50506 .94552 .53249 .93855 .53105 Metetra
.656 .571 .747 r
.31951 .58379 .32951 .60941 .3478 .58604 .33698 .57618 Metetra
.753 .763 .861 r
.33698 .57618 .3478 .58604 .36576 .56836 .35471 .56514 Metetra
.427 0 0 r
.35471 .56514 .36576 .56836 .38267 .57535 .37163 .57331 Metetra
.911 .558 .358 r
.37163 .57331 .38267 .57535 .39952 .59044 .38679 .63176 Metetra
.473 .173 .376 r
.38679 .63176 .39952 .59044 .41658 .60931 .40499 .6252 Metetra
.732 .36 .347 r
.40499 .6252 .41658 .60931 .43359 .64401 .42246 .64732 Metetra
.42246 .64732 .43359 .64401 .45166 .65427 .44095 .64434 Metetra
.408 .662 .963 r
.44095 .64434 .45166 .65427 .47035 .64408 .4595 .6462 Metetra
.694 .982 .878 r
.4595 .6462 .47035 .64408 .48905 .63988 .47846 .63344 Metetra
.12 .581 .919 r
.47846 .63344 .48905 .63988 .50798 .61638 .49734 .6377 Metetra
.49734 .6377 .50798 .61638 .52686 .60846 .51652 .61145 Metetra
.827 .999 .825 r
.51652 .61145 .52686 .60846 .54582 .59811 .53564 .59255 Metetra
.575 .838 .995 r
.53564 .59255 .54582 .59811 .5647 .57343 .55486 .58809 Metetra
.964 .9 .529 r
.55486 .58809 .5647 .57343 .58323 .53365 .57349 .53233 Metetra
.699 .959 .946 r
.57349 .53233 .58323 .53365 .60216 .52205 .5926 .52179 Metetra
.145 0 0 r
.5926 .52179 .60216 .52205 .62271 .56465 .61212 .52416 Metetra
.095 .155 .636 r
.61212 .52416 .62271 .56465 .64462 .62619 .63295 .56017 Metetra
.249 .205 .611 r
.63295 .56017 .64462 .62619 .66515 .63053 .65475 .60486 Metetra
.132 .27 .74 r
.65475 .60486 .66515 .63053 .68629 .64255 .67629 .62685 Metetra
.686 .693 .851 r
.67629 .62685 .68629 .64255 .70468 .59522 .69681 .61848 Metetra
.69681 .61848 .70468 .59522 .72384 .56706 .71512 .56848 Metetra
.242 0 0 r
.71512 .56848 .72384 .56706 .74674 .59856 .73632 .57125 Metetra
.478 .478 .779 r
.73632 .57125 .74674 .59856 .76769 .59392 .75805 .57784 Metetra
.702 .698 .843 r
.75805 .57784 .76769 .59392 .78832 .58291 .77886 .56801 Metetra
.927 .757 .65 r
.77886 .56801 .78832 .58291 .80529 .52702 .79623 .51443 Metetra
.901 .787 .726 r
.79623 .51443 .80529 .52702 .8257 .51475 .81483 .48007 Metetra
.38 .376 .729 r
.81483 .48007 .8257 .51475 .84798 .52089 .83806 .49701 Metetra
.153 .299 .76 r
.83806 .49701 .84798 .52089 .87253 .54597 .8623 .51934 Metetra
.647 .581 .767 r
.8623 .51934 .87253 .54597 .88874 .48989 .88387 .51177 Metetra
.28 0 .186 r
.88387 .51177 .88874 .48989 .91111 .49095 .90486 .49786 Metetra
.751 .263 .075 r
.90486 .49786 .91111 .49095 .93855 .53105 .93083 .52444 Metetra
.48 .522 .823 r
.30913 .56372 .31951 .58379 .33698 .57618 .32596 .56733 Metetra
.543 .009 0 r
.32596 .56733 .33698 .57618 .35471 .56514 .34238 .58244 Metetra
.485 .085 .207 r
.34238 .58244 .35471 .56514 .37163 .57331 .35984 .58275 Metetra
.873 .543 .422 r
.35984 .58275 .37163 .57331 .38679 .63176 .37471 .64694 Metetra
.418 0 .122 r
.37471 .64694 .38679 .63176 .40499 .6252 .39295 .64517 Metetra
.39295 .64517 .40499 .6252 .42246 .64732 .41194 .62526 Metetra
.249 .375 .796 r
.41194 .62526 .42246 .64732 .44095 .64434 .43 .63793 Metetra
.63 .831 .978 r
.43 .63793 .44095 .64434 .4595 .6462 .4488 .63244 Metetra
.75 .723 .827 r
.4488 .63244 .4595 .6462 .47846 .63344 .46784 .61959 Metetra
.691 .706 .859 r
.46784 .61959 .47846 .63344 .49734 .6377 .48688 .61158 Metetra
.605 .551 .768 r
.48688 .61158 .49734 .6377 .51652 .61145 .50601 .60839 Metetra
.731 .93 .956 r
.50601 .60839 .51652 .61145 .53564 .59255 .52529 .59784 Metetra
.52529 .59784 .53564 .59255 .55486 .58809 .54466 .58847 Metetra
.812 .345 .113 r
.54466 .58847 .55486 .58809 .57349 .53233 .56455 .61601 Metetra
.272 .059 .395 r
.56455 .61601 .57349 .53233 .5926 .52179 .58363 .56593 Metetra
.215 0 .293 r
.58363 .56593 .5926 .52179 .61212 .52416 .60279 .53588 Metetra
.672 .236 .205 r
.60279 .53588 .61212 .52416 .63295 .56017 .6231 .55051 Metetra
.752 .273 0 r
.6231 .55051 .63295 .56017 .65475 .60486 .64443 .58281 Metetra
0 .154 .691 r
.64443 .58281 .65475 .60486 .67629 .62685 .66609 .60843 Metetra
.586 .617 .85 r
.66609 .60843 .67629 .62685 .69681 .61848 .68697 .60635 Metetra
.897 .782 .727 r
.68697 .60635 .69681 .61848 .71512 .56848 .70629 .57119 Metetra
.953 .953 .691 r
.70629 .57119 .71512 .56848 .73632 .57125 .72542 .53637 Metetra
.299 .324 .719 r
.72542 .53637 .73632 .57125 .75805 .57784 .74806 .5578 Metetra
.591 .604 .833 r
.74806 .5578 .75805 .57784 .77886 .56801 .76948 .55547 Metetra
.859 .79 .783 r
.76948 .55547 .77886 .56801 .79623 .51443 .78932 .53034 Metetra
.78932 .53034 .79623 .51443 .81483 .48007 .80802 .4929 Metetra
.428 0 .064 r
.80802 .4929 .81483 .48007 .83806 .49701 .8299 .49275 Metetra
.776 .948 .932 r
.8299 .49275 .83806 .49701 .8623 .51934 .85068 .4789 Metetra
.352 .339 .705 r
.85068 .4789 .8623 .51934 .88387 .51177 .87533 .50125 Metetra
.312 .606 .951 r
.87533 .50125 .88387 .51177 .90486 .49786 .8986 .50622 Metetra
.8986 .50622 .90486 .49786 .93083 .52444 .91916 .48577 Metetra
.701 .299 .283 r
.29655 .57525 .30913 .56372 .32596 .56733 .3128 .59053 Metetra
.619 .264 .346 r
.3128 .59053 .32596 .56733 .34238 .58244 .32969 .60024 Metetra
.692 .322 .342 r
.32969 .60024 .34238 .58244 .35984 .58275 .34648 .61721 Metetra
.719 .404 .444 r
.34648 .61721 .35984 .58275 .37471 .64694 .36293 .64909 Metetra
.858 .982 .855 r
.36293 .64909 .37471 .64694 .39295 .64517 .382 .63028 Metetra
.606 .659 .875 r
.382 .63028 .39295 .64517 .41194 .62526 .40048 .6272 Metetra
.165 0 0 r
.40048 .6272 .41194 .62526 .43 .63793 .419 .62776 Metetra
.651 .757 .927 r
.419 .62776 .43 .63793 .4488 .63244 .43788 .6222 Metetra
.588 .737 .946 r
.43788 .6222 .4488 .63244 .46784 .61959 .45684 .61905 Metetra
.815 .969 .901 r
.45684 .61905 .46784 .61959 .48688 .61158 .47613 .6036 Metetra
.411 .716 .986 r
.47613 .6036 .48688 .61158 .50601 .60839 .49532 .60404 Metetra
.824 .902 .895 r
.49532 .60404 .50601 .60839 .52529 .59784 .51475 .58849 Metetra
.903 .787 .723 r
.51475 .58849 .52529 .59784 .54466 .58847 .53416 .5523 Metetra
.67 .545 .703 r
.53416 .5523 .54466 .58847 .56455 .61601 .55355 .53919 Metetra
.57 .414 .631 r
.55355 .53919 .56455 .61601 .58363 .56593 .57317 .53808 Metetra
0 .014 .584 r
.57317 .53808 .58363 .56593 .60279 .53588 .5937 .57252 Metetra
.513 .191 .358 r
.5937 .57252 .60279 .53588 .6231 .55051 .61393 .57156 Metetra
.451 .065 .216 r
.61393 .57156 .6231 .55051 .64443 .58281 .63432 .56933 Metetra
0 .124 .659 r
.63432 .56933 .64443 .58281 .66609 .60843 .65578 .58984 Metetra
.564 .606 .854 r
.65578 .58984 .66609 .60843 .68697 .60635 .67677 .58894 Metetra
.584 .632 .865 r
.67677 .58894 .68697 .60635 .70629 .57119 .69791 .58675 Metetra
.923 .867 .435 r
.69791 .58675 .70629 .57119 .72542 .53637 .71586 .525 Metetra
0 .292 .781 r
.71586 .525 .72542 .53637 .74806 .5578 .73814 .54011 Metetra
.254 .442 .854 r
.73814 .54011 .74806 .5578 .76948 .55547 .7606 .55169 Metetra
.819 .954 .905 r
.7606 .55169 .76948 .55547 .78932 .53034 .78131 .53523 Metetra
.78131 .53523 .78932 .53034 .80802 .4929 .8029 .52892 Metetra
0 0 .18 r
.8029 .52892 .80802 .4929 .8299 .49275 .82114 .4834 Metetra
.958 .818 .664 r
.82114 .4834 .8299 .49275 .85068 .4789 .83886 .43617 Metetra
.444 .39 .703 r
.83886 .43617 .85068 .4789 .87533 .50125 .86254 .45048 Metetra
.464 .384 .681 r
.86254 .45048 .87533 .50125 .8986 .50622 .8867 .46508 Metetra
.697 .553 .686 r
.8867 .46508 .8986 .50622 .91916 .48577 .90723 .44468 Metetra
.637 .337 .445 r
.28125 .62111 .29655 .57525 .3128 .59053 .29764 .63839 Metetra
.306 .025 .312 r
.29764 .63839 .3128 .59053 .32969 .60024 .31671 .61736 Metetra
.759 .402 .379 r
.31671 .61736 .32969 .60024 .34648 .61721 .333 .64571 Metetra
.516 .169 .317 r
.333 .64571 .34648 .61721 .36293 .64909 .35116 .64636 Metetra
.826 .916 .898 r
.35116 .64636 .36293 .64909 .382 .63028 .37023 .63106 Metetra
.709 .975 .922 r
.37023 .63106 .382 .63028 .40048 .6272 .38918 .61939 Metetra
.515 .765 .987 r
.38918 .61939 .40048 .6272 .419 .62776 .40786 .61746 Metetra
.55 .724 .955 r
.40786 .61746 .419 .62776 .43788 .6222 .42672 .61551 Metetra
.855 .839 .829 r
.42672 .61551 .43788 .6222 .45684 .61905 .44617 .59511 Metetra
.589 .56 .79 r
.44617 .59511 .45684 .61905 .47613 .6036 .46527 .59305 Metetra
.554 .723 .952 r
.46527 .59305 .47613 .6036 .49532 .60404 .48455 .59097 Metetra
.728 .736 .857 r
.48455 .59097 .49532 .60404 .51475 .58849 .50406 .58024 Metetra
.642 .805 .961 r
.50406 .58024 .51475 .58849 .53416 .5523 .52366 .57438 Metetra
.696 .799 .332 r
.52366 .57438 .53416 .5523 .55355 .53919 .54319 .53062 Metetra
.919 .796 .709 r
.54319 .53062 .55355 .53919 .57317 .53808 .56246 .49107 Metetra
.727 .554 .657 r
.56246 .49107 .57317 .53808 .5937 .57252 .58162 .4602 Metetra
.379 .256 .584 r
.58162 .4602 .5937 .57252 .61393 .57156 .60243 .5064 Metetra
.236 .196 .608 r
.60243 .5064 .61393 .57156 .63432 .56933 .62391 .54945 Metetra
0 .174 .709 r
.62391 .54945 .63432 .56933 .65578 .58984 .64543 .57235 Metetra
.56 .62 .869 r
.64543 .57235 .65578 .58984 .67677 .58894 .66647 .57136 Metetra
.75 .702 .806 r
.66647 .57136 .67677 .58894 .69791 .58675 .68705 .55629 Metetra
.679 .579 .736 r
.68705 .55629 .69791 .58675 .71586 .525 .70782 .54372 Metetra
.70782 .54372 .71586 .525 .73814 .54011 .7282 .52351 Metetra
.137 .386 .839 r
.7282 .52351 .73814 .54011 .7606 .55169 .75086 .53756 Metetra
.817 .768 .807 r
.75086 .53756 .7606 .55169 .78131 .53523 .77142 .51716 Metetra
.874 .738 .709 r
.77142 .51716 .78131 .53523 .8029 .52892 .79064 .48043 Metetra
.707 .542 .662 r
.79064 .48043 .8029 .52892 .82114 .4834 .81051 .45397 Metetra
.618 .551 .757 r
.81051 .45397 .82114 .4834 .83886 .43617 .83227 .44861 Metetra
.583 .115 .109 r
.83227 .44861 .83886 .43617 .86254 .45048 .85571 .45823 Metetra
.85571 .45823 .86254 .45048 .8867 .46508 .87686 .44277 Metetra
.732 .66 .779 r
.87686 .44277 .8867 .46508 .90723 .44468 .89805 .42728 Metetra
.373 .007 .207 r
.26695 .64589 .28125 .62111 .29764 .63839 .28517 .63924 Metetra
.106 0 0 r
.28517 .63924 .29764 .63839 .31671 .61736 .30303 .63986 Metetra
.29 0 .135 r
.30303 .63986 .31671 .61736 .333 .64571 .32166 .63069 Metetra
.669 .683 .854 r
.32166 .63069 .333 .64571 .35116 .64636 .34025 .62391 Metetra
.651 .601 .785 r
.34025 .62391 .35116 .64636 .37023 .63106 .35895 .6171 Metetra
.761 .724 .818 r
.35895 .6171 .37023 .63106 .38918 .61939 .37809 .6029 Metetra
.42 .554 .884 r
.37809 .6029 .38918 .61939 .40786 .61746 .39658 .60702 Metetra
.769 .78 .862 r
.39658 .60702 .40786 .61746 .42672 .61551 .41585 .59394 Metetra
.587 .58 .812 r
.41585 .59394 .42672 .61551 .44617 .59511 .43489 .59186 Metetra
.701 .922 .967 r
.43489 .59186 .44617 .59511 .46527 .59305 .45427 .58237 Metetra
.7 .769 .906 r
.45427 .58237 .46527 .59305 .48455 .59097 .47371 .57405 Metetra
.683 .673 .834 r
.47371 .57405 .48455 .59097 .50406 .58024 .49327 .56569 Metetra
.579 .664 .897 r
.49327 .56569 .50406 .58024 .52366 .57438 .51293 .56346 Metetra
.897 .777 .721 r
.51293 .56346 .52366 .57438 .54319 .53062 .53268 .52678 Metetra
.953 .833 .688 r
.53268 .52678 .54319 .53062 .56246 .49107 .55215 .48214 Metetra
.89 .811 .764 r
.55215 .48214 .56246 .49107 .58162 .4602 .57153 .45343 Metetra
.205 .632 .95 r
.57153 .45343 .58162 .4602 .60243 .5064 .59143 .45663 Metetra
.723 .464 0 r
.59143 .45663 .60243 .5064 .62391 .54945 .61435 .56465 Metetra
.218 0 0 r
.61435 .56465 .62391 .54945 .64543 .57235 .63502 .55596 Metetra
.732 .709 .83 r
.63502 .55596 .64543 .57235 .66647 .57136 .65567 .54341 Metetra
.573 .534 .773 r
.65567 .54341 .66647 .57136 .68705 .55629 .67692 .54226 Metetra
.574 .683 .914 r
.67692 .54226 .68705 .55629 .70782 .54372 .69832 .53981 Metetra
.936 .907 .768 r
.69832 .53981 .70782 .54372 .7282 .52351 .7183 .50926 Metetra
0 .153 .687 r
.7183 .50926 .7282 .52351 .75086 .53756 .74151 .53098 Metetra
.963 .842 .675 r
.74151 .53098 .75086 .53756 .77142 .51716 .76043 .48498 Metetra
.814 .643 .67 r
.76043 .48498 .77142 .51716 .79064 .48043 .77943 .44467 Metetra
.53 .469 .733 r
.77943 .44467 .79064 .48043 .81051 .45397 .80184 .44798 Metetra
.606 .87 .992 r
.80184 .44798 .81051 .45397 .83227 .44861 .82364 .4413 Metetra
.716 .225 0 r
.82364 .4413 .83227 .44861 .85571 .45823 .84985 .47771 Metetra
.258 0 .112 r
.84985 .47771 .85571 .45823 .87686 .44277 .87174 .46586 Metetra
.33 0 .188 r
.87174 .46586 .87686 .44277 .89805 .42728 .89389 .45524 Metetra
.25286 .66283 .26695 .64589 .28517 .63924 .27237 .64133 Metetra
.732 .984 .903 r
.27237 .64133 .28517 .63924 .30303 .63986 .29126 .62844 Metetra
.717 .75 .879 r
.29126 .62844 .30303 .63986 .32166 .63069 .30997 .61919 Metetra
.558 .704 .938 r
.30997 .61919 .32166 .63069 .34025 .62391 .32836 .61725 Metetra
.825 .84 .859 r
.32836 .61725 .34025 .62391 .35895 .6171 .34767 .60054 Metetra
.628 .652 .855 r
.34767 .60054 .35895 .6171 .37809 .6029 .36643 .59605 Metetra
.284 .682 .972 r
.36643 .59605 .37809 .6029 .39658 .60702 .38509 .59768 Metetra
.845 .797 .804 r
.38509 .59768 .39658 .60702 .41585 .59394 .40479 .57589 Metetra
.402 .526 .867 r
.40479 .57589 .41585 .59394 .43489 .59186 .42364 .58113 Metetra
.738 .777 .884 r
.42364 .58113 .43489 .59186 .45427 .58237 .44314 .5703 Metetra
.749 .759 .861 r
.44314 .5703 .45427 .58237 .47371 .57405 .46275 .5582 Metetra
.65 .676 .861 r
.46275 .5582 .47371 .57405 .49327 .56569 .48235 .55222 Metetra
.728 .736 .857 r
.48235 .55222 .49327 .56569 .51293 .56346 .50212 .54126 Metetra
.668 .619 .791 r
.50212 .54126 .51293 .56346 .53268 .52678 .52198 .53271 Metetra
.992 .822 .571 r
.52198 .53271 .53268 .52678 .55215 .48214 .54158 .45167 Metetra
.603 .53 .745 r
.54158 .45167 .55215 .48214 .57153 .45343 .56129 .44774 Metetra
.417 0 0 r
.56129 .44774 .57153 .45343 .59143 .45663 .58145 .4605 Metetra
.927 .576 .344 r
.58145 .4605 .59143 .45663 .61435 .56465 .6041 .56352 Metetra
.927 .942 .787 r
.6041 .56352 .61435 .56465 .63502 .55596 .62439 .53558 Metetra
.494 .555 .847 r
.62439 .53558 .63502 .55596 .65567 .54341 .64565 .53822 Metetra
.542 .855 .997 r
.64565 .53822 .65567 .54341 .67692 .54226 .66687 .53318 Metetra
.782 .843 .898 r
.66687 .53318 .67692 .54226 .69832 .53981 .68782 .51912 Metetra
.82 .703 .736 r
.68782 .51912 .69832 .53981 .7183 .50926 .70807 .49104 Metetra
.29 .465 .86 r
.70807 .49104 .7183 .50926 .74151 .53098 .73055 .50108 Metetra
.75 .622 .718 r
.73055 .50108 .74151 .53098 .76043 .48498 .75115 .47795 Metetra
.908 .884 .798 r
.75115 .47795 .76043 .48498 .77943 .44467 .77141 .4511 Metetra
.498 0 0 r
.77141 .4511 .77943 .44467 .80184 .44798 .79436 .4583 Metetra
.684 .206 .11 r
.79436 .4583 .80184 .44798 .82364 .4413 .81872 .4772 Metetra
.435 .11 .314 r
.81872 .4772 .82364 .4413 .84985 .47771 .84102 .46917 Metetra
.765 .873 .926 r
.84102 .46917 .84985 .47771 .87174 .46586 .86295 .45591 Metetra
.697 .826 .945 r
.86295 .45591 .87174 .46586 .89389 .45524 .88539 .44647 Metetra
.713 .586 .712 r
.24232 .63175 .25286 .66283 .27237 .64133 .26157 .61394 Metetra
.348 .395 .768 r
.26157 .61394 .27237 .64133 .29126 .62844 .27881 .62427 Metetra
.836 .881 .875 r
.27881 .62427 .29126 .62844 .30997 .61919 .29814 .60754 Metetra
.734 .753 .868 r
.29814 .60754 .30997 .61919 .32836 .61725 .31711 .59693 Metetra
.672 .631 .801 r
.31711 .59693 .32836 .61725 .34767 .60054 .33602 .58872 Metetra
.762 .758 .849 r
.33602 .58872 .34767 .60054 .36643 .59605 .35528 .57556 Metetra
0 0 .539 r
.35528 .57556 .36643 .59605 .38509 .59768 .37289 .60066 Metetra
.929 .951 .78 r
.37289 .60066 .38509 .59768 .40479 .57589 .39306 .57245 Metetra
.102 .632 .87 r
.39306 .57245 .40479 .57589 .42364 .58113 .41212 .57397 Metetra
.547 .802 .992 r
.41212 .57397 .42364 .58113 .44314 .5703 .43154 .57051 Metetra
.805 .981 .896 r
.43154 .57051 .44314 .5703 .46275 .5582 .4514 .55456 Metetra
.787 .925 .927 r
.4514 .55456 .46275 .5582 .48235 .55222 .47126 .54107 Metetra
.824 .786 .816 r
.47126 .54107 .48235 .55222 .50212 .54126 .49123 .52136 Metetra
.462 .539 .85 r
.49123 .52136 .50212 .54126 .52198 .53271 .51108 .52508 Metetra
.957 .757 .591 r
.51108 .52508 .52198 .53271 .54158 .45167 .53103 .43528 Metetra
.482 .592 .887 r
.53103 .43528 .54158 .45167 .56129 .44774 .55083 .43719 Metetra
.873 .798 .774 r
.55083 .43719 .56129 .44774 .58145 .4605 .57048 .41064 Metetra
.861 .573 .043 r
.57048 .41064 .58145 .4605 .6041 .56352 .59336 .54817 Metetra
.854 .752 .749 r
.59336 .54817 .6041 .56352 .62439 .53558 .61376 .51884 Metetra
.466 .59 .893 r
.61376 .51884 .62439 .53558 .64565 .53822 .63507 .52138 Metetra
.466 .59 .893 r
.63507 .52138 .64565 .53822 .66687 .53318 .65667 .52396 Metetra
.91 .832 .756 r
.65667 .52396 .66687 .53318 .68782 .51912 .67695 .49187 Metetra
.72 .62 .745 r
.67695 .49187 .68782 .51912 .70807 .49104 .69786 .47516 Metetra
0 .047 .603 r
.69786 .47516 .70807 .49104 .73055 .50108 .72138 .50186 Metetra
.933 .968 .737 r
.72138 .50186 .73055 .50108 .75115 .47795 .74171 .47079 Metetra
.267 .672 .968 r
.74171 .47079 .75115 .47795 .77141 .4511 .7643 .47307 Metetra
.485 .086 .208 r
.7643 .47307 .77141 .4511 .79436 .4583 .78708 .47409 Metetra
.16 0 0 r
.78708 .47409 .79436 .4583 .81872 .4772 .80903 .46213 Metetra
.838 .777 .793 r
.80903 .46213 .81872 .4772 .84102 .46917 .83 .43853 Metetra
.727 .611 .727 r
.83 .43853 .84102 .46917 .86295 .45591 .8513 .4188 Metetra
.665 .55 .714 r
.8513 .4188 .86295 .45591 .88539 .44647 .87328 .40543 Metetra
.898 .789 .731 r
.22968 .62514 .24232 .63175 .26157 .61394 .25055 .58888 Metetra
.193 .319 .765 r
.25055 .58888 .26157 .61394 .27881 .62427 .26746 .60272 Metetra
.603 .589 .81 r
.26746 .60272 .27881 .62427 .29814 .60754 .2859 .59946 Metetra
.392 .713 .987 r
.2859 .59946 .29814 .60754 .31711 .59693 .30426 .59988 Metetra
.272 .773 .749 r
.30426 .59988 .31711 .59693 .33602 .58872 .32319 .59408 Metetra
.948 .943 .743 r
.32319 .59408 .33602 .58872 .35528 .57556 .34371 .56105 Metetra
0 0 .526 r
.34371 .56105 .35528 .57556 .37289 .60066 .36151 .5811 Metetra
.642 .631 .824 r
.36151 .5811 .37289 .60066 .39306 .57245 .38085 .57518 Metetra
.905 .971 .807 r
.38085 .57518 .39306 .57245 .41212 .57397 .40101 .55053 Metetra
.729 .638 .756 r
.40101 .55053 .41212 .57397 .43154 .57051 .42082 .53459 Metetra
.645 .534 .713 r
.42082 .53459 .43154 .57051 .4514 .55456 .44051 .52477 Metetra
.585 .526 .756 r
.44051 .52477 .4514 .55456 .47126 .54107 .46016 .52232 Metetra
.85 .711 .709 r
.46016 .52232 .47126 .54107 .49123 .52136 .48043 .48663 Metetra
.224 .274 .704 r
.48043 .48663 .49123 .52136 .51108 .52508 .50008 .50739 Metetra
.906 .724 .644 r
.50008 .50739 .51108 .52508 .53103 .43528 .52032 .44611 Metetra
.862 .951 .597 r
.52032 .44611 .53103 .43528 .55083 .43719 .54017 .41223 Metetra
.383 .44 .797 r
.54017 .41223 .55083 .43719 .57048 .41064 .56028 .42118 Metetra
.56028 .42118 .57048 .41064 .59336 .54817 .58029 .40387 Metetra
.121 .056 .503 r
.58029 .40387 .59336 .54817 .61376 .51884 .60335 .51595 Metetra
.493 0 0 r
.60335 .51595 .61376 .51884 .63507 .52138 .62511 .52887 Metetra
.522 .862 .596 r
.62511 .52887 .63507 .52138 .65667 .52396 .64616 .51072 Metetra
.95 .76 .612 r
.64616 .51072 .65667 .52396 .67695 .49187 .66494 .4394 Metetra
.394 .331 .668 r
.66494 .4394 .67695 .49187 .69786 .47516 .68754 .45909 Metetra
.431 .586 .905 r
.68754 .45909 .69786 .47516 .72138 .50186 .70975 .46257 Metetra
.469 .421 .722 r
.70975 .46257 .72138 .50186 .74171 .47079 .73259 .47125 Metetra
.133 .681 .752 r
.73259 .47125 .74171 .47079 .7643 .47307 .75501 .46836 Metetra
.567 .887 .989 r
.75501 .46836 .7643 .47307 .78708 .47409 .77735 .46154 Metetra
.864 .814 .799 r
.77735 .46154 .78708 .47409 .80903 .46213 .79835 .43653 Metetra
.741 .647 .756 r
.79835 .43653 .80903 .46213 .83 .43853 .81986 .418 Metetra
.733 .685 .804 r
.81986 .418 .83 .43853 .8513 .4188 .84177 .40328 Metetra
.855 .78 .778 r
.84177 .40328 .8513 .4188 .87328 .40543 .86253 .3771 Metetra
.67 .573 .738 r
.21883 .59624 .22968 .62514 .25055 .58888 .23764 .5856 Metetra
.234 0 0 r
.23764 .5856 .25055 .58888 .26746 .60272 .25526 .59087 Metetra
.624 .727 .921 r
.25526 .59087 .26746 .60272 .2859 .59946 .27385 .58629 Metetra
.626 .707 .904 r
.27385 .58629 .2859 .59946 .30426 .59988 .2926 .58168 Metetra
.58 .618 .855 r
.2926 .58168 .30426 .59988 .32319 .59408 .31133 .57952 Metetra
.806 .732 .783 r
.31133 .57952 .32319 .59408 .34371 .56105 .33131 .55869 Metetra
.828 .368 .122 r
.33131 .55869 .34371 .56105 .36151 .5811 .34875 .58647 Metetra
.523 .907 .757 r
.34875 .58647 .36151 .5811 .38085 .57518 .36855 .57417 Metetra
.379 0 0 r
.36855 .57417 .38085 .57518 .40101 .55053 .38766 .58082 Metetra
.269 0 .182 r
.38766 .58082 .40101 .55053 .42082 .53459 .40776 .56713 Metetra
.106 0 .124 r
.40776 .56713 .42082 .53459 .44051 .52477 .42817 .54456 Metetra
.42817 .54456 .44051 .52477 .46016 .52232 .44844 .5258 Metetra
.969 .911 .697 r
.44844 .5258 .46016 .52232 .48043 .48663 .4691 .48476 Metetra
0 .533 .743 r
.4691 .48476 .48043 .48663 .50008 .50739 .48901 .48704 Metetra
.88 .709 .666 r
.48901 .48704 .50008 .50739 .52032 .44611 .50942 .4366 Metetra
.839 .821 .832 r
.50942 .4366 .52032 .44611 .54017 .41223 .52948 .41683 Metetra
.553 .01 0 r
.52948 .41683 .54017 .41223 .56028 .42118 .54975 .42593 Metetra
.685 .178 .03 r
.54975 .42593 .56028 .42118 .58029 .40387 .57047 .44256 Metetra
0 0 .119 r
.57047 .44256 .58029 .40387 .60335 .51595 .5905 .40295 Metetra
.505 .344 .596 r
.5905 .40295 .60335 .51595 .62511 .52887 .61165 .41572 Metetra
.56 .384 .599 r
.61165 .41572 .62511 .52887 .64616 .51072 .63269 .41266 Metetra
.634 .443 .607 r
.63269 .41266 .64616 .51072 .66494 .4394 .65306 .38748 Metetra
0 .022 .552 r
.65306 .38748 .66494 .4394 .68754 .45909 .6771 .44284 Metetra
.607 .675 .889 r
.6771 .44284 .68754 .45909 .70975 .46257 .69895 .43856 Metetra
.606 .589 .808 r
.69895 .43856 .70975 .46257 .73259 .47125 .72101 .43425 Metetra
.429 .407 .733 r
.72101 .43425 .73259 .47125 .75501 .46836 .74432 .44534 Metetra
.64 .618 .813 r
.74432 .44534 .75501 .46836 .77735 .46154 .76671 .4384 Metetra
.876 .715 .678 r
.76671 .4384 .77735 .46154 .79835 .43653 .78626 .39418 Metetra
.55 .463 .71 r
.78626 .39418 .79835 .43653 .81986 .418 .80941 .39471 Metetra
.554 .571 .826 r
.80941 .39471 .81986 .418 .84177 .40328 .83273 .39397 Metetra
.696 .847 .955 r
.83273 .39397 .84177 .40328 .86253 .3771 .8554 .38419 Metetra
.328 .416 .8 r
.2075 .57215 .21883 .59624 .23764 .5856 .2246 .58102 Metetra
.553 .855 .998 r
.2246 .58102 .23764 .5856 .25526 .59087 .24311 .5764 Metetra
.299 .538 .913 r
.24311 .5764 .25526 .59087 .27385 .58629 .26099 .58167 Metetra
.912 .823 .746 r
.26099 .58167 .27385 .58629 .2926 .58168 .28198 .5473 Metetra
.019 .134 .644 r
.28198 .5473 .2926 .58168 .31133 .57952 .29884 .5723 Metetra
.768 .846 .91 r
.29884 .5723 .31133 .57952 .33131 .55869 .31845 .56004 Metetra
.33 0 0 r
.31845 .56004 .33131 .55869 .34875 .58647 .33723 .56403 Metetra
.56 .569 .819 r
.33723 .56403 .34875 .58647 .36855 .57417 .35651 .563 Metetra
.505 .707 .962 r
.35651 .563 .36855 .57417 .38766 .58082 .376 .56196 Metetra
.763 .69 .782 r
.376 .56196 .38766 .58082 .40776 .56713 .39632 .54438 Metetra
.539 .557 .822 r
.39632 .54438 .40776 .56713 .42817 .54456 .41608 .54451 Metetra
.566 .931 .928 r
.41608 .54451 .42817 .54456 .44844 .5258 .4363 .53571 Metetra
.4363 .53571 .44844 .5258 .4691 .48476 .45677 .5205 Metetra
.425 .087 .287 r
.45677 .5205 .4691 .48476 .48901 .48704 .47715 .51413 Metetra
.47715 .51413 .48901 .48704 .50942 .4366 .49792 .47993 Metetra
0 0 .126 r
.49792 .47993 .50942 .4366 .52948 .41683 .51851 .43866 Metetra
.51851 .43866 .52948 .41683 .54975 .42593 .53885 .40519 Metetra
.876 .711 .674 r
.53885 .40519 .54975 .42593 .57047 .44256 .55887 .35896 Metetra
.483 .344 .615 r
.55887 .35896 .57047 .44256 .5905 .40295 .57956 .37239 Metetra
.638 .556 .746 r
.57956 .37239 .5905 .40295 .61165 .41572 .60015 .36434 Metetra
.512 .409 .674 r
.60015 .36434 .61165 .41572 .63269 .41266 .62128 .36951 Metetra
.685 .539 .681 r
.62128 .36951 .63269 .41266 .65306 .38748 .64183 .35048 Metetra
.164 .228 .684 r
.64183 .35048 .65306 .38748 .6771 .44284 .6644 .37761 Metetra
.504 .382 .647 r
.6644 .37761 .6771 .44284 .69895 .43856 .68662 .38548 Metetra
.428 .354 .671 r
.68662 .38548 .69895 .43856 .72101 .43425 .70966 .40106 Metetra
.598 .527 .746 r
.70966 .40106 .72101 .43425 .74432 .44534 .73189 .39654 Metetra
.497 .411 .689 r
.73189 .39654 .74432 .44534 .76671 .4384 .75515 .40349 Metetra
.661 .558 .727 r
.75515 .40349 .76671 .4384 .78626 .39418 .77729 .39122 Metetra
0 .511 .774 r
.77729 .39122 .78626 .39418 .80941 .39471 .80096 .39561 Metetra
.542 .926 .825 r
.80096 .39561 .80941 .39471 .83273 .39397 .82342 .3832 Metetra
.43 .697 .976 r
.82342 .3832 .83273 .39397 .8554 .38419 .84729 .38367 Metetra
.19058 .60468 .2075 .57215 .2246 .58102 .21112 .57885 Metetra
.926 .833 .733 r
.21112 .57885 .2246 .58102 .24311 .5764 .23263 .54088 Metetra
.016 .124 .635 r
.23263 .54088 .24311 .5764 .26099 .58167 .24882 .56572 Metetra
.508 .621 .899 r
.24882 .56572 .26099 .58167 .28198 .5473 .26734 .56597 Metetra
.248 0 .019 r
.26734 .56597 .28198 .5473 .29884 .5723 .28659 .55867 Metetra
.21 .508 .91 r
.28659 .55867 .29884 .5723 .31845 .56004 .30508 .5652 Metetra
.409 .848 .732 r
.30508 .5652 .31845 .56004 .33723 .56403 .32481 .55529 Metetra
.334 .681 .979 r
.32481 .55529 .33723 .56403 .35651 .563 .34404 .55676 Metetra
.056 .561 .883 r
.34404 .55676 .35651 .563 .376 .56196 .36338 .56081 Metetra
.819 .961 .902 r
.36338 .56081 .376 .56196 .39632 .54438 .38385 .54433 Metetra
.783 .979 .908 r
.38385 .54433 .39632 .54438 .41608 .54451 .40429 .5291 Metetra
.723 .72 .847 r
.40429 .5291 .41608 .54451 .4363 .53571 .42467 .51766 Metetra
.646 .662 .851 r
.42467 .51766 .4363 .53571 .45677 .5205 .44501 .51125 Metetra
.865 .823 .805 r
.44501 .51125 .45677 .5205 .47715 .51413 .46583 .48701 Metetra
.69 .605 .756 r
.46583 .48701 .47715 .51413 .49792 .47993 .48645 .47415 Metetra
.79 .292 0 r
.48645 .47415 .49792 .47993 .51851 .43866 .50692 .50332 Metetra
.259 .004 .323 r
.50692 .50332 .51851 .43866 .53885 .40519 .52794 .46979 Metetra
.52794 .46979 .53885 .40519 .55887 .35896 .54826 .3654 Metetra
.688 .953 .693 r
.54826 .3654 .55887 .35896 .57956 .37239 .56864 .34534 Metetra
.658 .588 .764 r
.56864 .34534 .57956 .37239 .60015 .36434 .58922 .33598 Metetra
.643 .572 .76 r
.58922 .33598 .60015 .36434 .62128 .36951 .60995 .32777 Metetra
.6 .49 .7 r
.60995 .32777 .62128 .36951 .64183 .35048 .63091 .32189 Metetra
.101 .238 .72 r
.63091 .32189 .64183 .35048 .6644 .37761 .65321 .34498 Metetra
.262 .319 .734 r
.65321 .34498 .6644 .37761 .68662 .38548 .67588 .36373 Metetra
.138 .333 .796 r
.67588 .36373 .68662 .38548 .70966 .40106 .69897 .3804 Metetra
.693 .666 .819 r
.69897 .3804 .70966 .40106 .73189 .39654 .72087 .36944 Metetra
.573 .551 .792 r
.72087 .36944 .73189 .39654 .75515 .40349 .7435 .36728 Metetra
.648 .545 .724 r
.7435 .36728 .75515 .40349 .77729 .39122 .7657 .35619 Metetra
.651 .552 .73 r
.7657 .35619 .77729 .39122 .80096 .39561 .78803 .34504 Metetra
.412 .353 .682 r
.78803 .34504 .80096 .39561 .82342 .3832 .81302 .36193 Metetra
.569 .606 .85 r
.81302 .36193 .82342 .3832 .84729 .38367 .83668 .35967 Metetra
.825 .628 .637 r
.18044 .56516 .19058 .60468 .21112 .57885 .20493 .49829 Metetra
.603 .43 .619 r
.20493 .49829 .21112 .57885 .23263 .54088 .22392 .48619 Metetra
.689 .518 .65 r
.22392 .48619 .23263 .54088 .24882 .56572 .24409 .46099 Metetra
.232 .134 .531 r
.24409 .46099 .24882 .56572 .26734 .56597 .25814 .51134 Metetra
.245 .21 .62 r
.25814 .51134 .26734 .56597 .28659 .55867 .27476 .53736 Metetra
.807 .682 .725 r
.27476 .53736 .28659 .55867 .30508 .5652 .29563 .50876 Metetra
.381 .304 .644 r
.29563 .50876 .30508 .5652 .32481 .55529 .31348 .5262 Metetra
.174 .284 .737 r
.31348 .5262 .32481 .55529 .34404 .55676 .3318 .54274 Metetra
.285 .549 .923 r
.3318 .54274 .34404 .55676 .36338 .56081 .35111 .548 Metetra
.696 .751 .894 r
.35111 .548 .36338 .56081 .38385 .54433 .37135 .53912 Metetra
.549 .855 .998 r
.37135 .53912 .38385 .54433 .40429 .5291 .39155 .53405 Metetra
.226 0 0 r
.39155 .53405 .40429 .5291 .42467 .51766 .41175 .53413 Metetra
.41175 .53413 .42467 .51766 .44501 .51125 .43287 .50956 Metetra
.837 .961 .889 r
.43287 .50956 .44501 .51125 .46583 .48701 .45378 .49147 Metetra
.981 .895 .657 r
.45378 .49147 .46583 .48701 .48645 .47415 .47518 .44182 Metetra
0 0 .546 r
.47518 .44182 .48645 .47415 .50692 .50332 .49543 .47822 Metetra
.362 .444 .811 r
.49543 .47822 .50692 .50332 .52794 .46979 .51646 .48705 Metetra
.934 .9 .502 r
.51646 .48705 .52794 .46979 .54826 .3654 .53759 .42904 Metetra
0 0 .03 r
.53759 .42904 .54826 .3654 .56864 .34534 .55788 .33842 Metetra
.751 .884 .94 r
.55788 .33842 .56864 .34534 .58922 .33598 .57857 .32657 Metetra
.51 .757 .985 r
.57857 .32657 .58922 .33598 .60995 .32777 .59958 .32426 Metetra
.231 0 0 r
.59958 .32426 .60995 .32777 .63091 .32189 .62111 .33163 Metetra
.917 .931 .56 r
.62111 .33163 .63091 .32189 .65321 .34498 .6411 .2883 Metetra
.523 .406 .662 r
.6411 .2883 .65321 .34498 .67588 .36373 .66283 .29177 Metetra
.09 .088 .56 r
.66283 .29177 .67588 .36373 .69897 .3804 .68779 .35199 Metetra
.521 .513 .787 r
.68779 .35199 .69897 .3804 .72087 .36944 .71045 .35352 Metetra
0 .268 .774 r
.71045 .35352 .72087 .36944 .7435 .36728 .73451 .37171 Metetra
.579 .915 .69 r
.73451 .37171 .7435 .36728 .7657 .35619 .75651 .35407 Metetra
0 .488 .728 r
.75651 .35407 .7657 .35619 .78803 .34504 .78029 .35823 Metetra
.604 .121 .081 r
.78029 .35823 .78803 .34504 .81302 .36193 .80525 .3716 Metetra
.462 0 0 r
.80525 .3716 .81302 .36193 .83668 .35967 .82998 .37729 Metetra
.568 .391 .601 r
.17656 .46697 .18044 .56516 .20493 .49829 .19482 .46077 Metetra
.688 .551 .694 r
.19482 .46077 .20493 .49829 .22392 .48619 .21421 .44391 Metetra
.594 .479 .691 r
.21421 .44391 .22392 .48619 .24409 .46099 .23256 .43878 Metetra
.715 .638 .77 r
.23256 .43878 .24409 .46099 .25814 .51134 .25175 .42536 Metetra
.345 .232 .579 r
.25175 .42536 .25814 .51134 .27476 .53736 .26764 .45464 Metetra
.393 .272 .595 r
.26764 .45464 .27476 .53736 .29563 .50876 .28454 .47741 Metetra
.47 .452 .756 r
.28454 .47741 .29563 .50876 .31348 .5262 .30312 .48211 Metetra
.198 .214 .651 r
.30312 .48211 .31348 .5262 .3318 .54274 .32081 .50568 Metetra
.355 .352 .718 r
.32081 .50568 .3318 .54274 .35111 .548 .3396 .51833 Metetra
.577 .531 .766 r
.3396 .51833 .35111 .548 .37135 .53912 .35952 .51575 Metetra
.769 .664 .747 r
.35952 .51575 .37135 .53912 .39155 .53405 .38047 .49392 Metetra
.437 .394 .713 r
.38047 .49392 .39155 .53405 .41175 .53413 .40024 .50275 Metetra
.73 .606 .719 r
.40024 .50275 .41175 .53413 .43287 .50956 .42128 .48205 Metetra
.58 .548 .784 r
.42128 .48205 .43287 .50956 .45378 .49147 .44185 .47925 Metetra
.886 .784 .743 r
.44185 .47925 .45378 .49147 .47518 .44182 .46321 .44574 Metetra
.775 .996 .807 r
.46321 .44574 .47518 .44182 .49543 .47822 .48421 .42631 Metetra
.047 .092 .586 r
.48421 .42631 .49543 .47822 .51646 .48705 .50484 .46679 Metetra
.556 .606 .859 r
.50484 .46679 .51646 .48705 .53759 .42904 .52623 .46517 Metetra
.981 .805 .398 r
.52623 .46517 .53759 .42904 .55788 .33842 .54686 .32055 Metetra
.309 .494 .877 r
.54686 .32055 .55788 .33842 .57857 .32657 .5679 .32787 Metetra
.459 0 0 r
.5679 .32787 .57857 .32657 .59958 .32426 .58932 .33655 Metetra
.803 .913 .52 r
.58932 .33655 .59958 .32426 .62111 .33163 .60989 .30011 Metetra
.637 .556 .746 r
.60989 .30011 .62111 .33163 .6411 .2883 .63118 .29158 Metetra
.702 .178 0 r
.63118 .29158 .6411 .2883 .66283 .29177 .65381 .31224 Metetra
.603 .179 .211 r
.65381 .31224 .66283 .29177 .68779 .35199 .67662 .32469 Metetra
.175 .307 .76 r
.67662 .32469 .68779 .35199 .71045 .35352 .70025 .34373 Metetra
0 .018 .512 r
.70025 .34373 .71045 .35352 .73451 .37171 .72472 .36714 Metetra
.08 .604 .875 r
.72472 .36714 .73451 .37171 .75651 .35407 .74839 .37013 Metetra
.334 0 .013 r
.74839 .37013 .75651 .35407 .78029 .35823 .7719 .36657 Metetra
.549 .016 0 r
.7719 .36657 .78029 .35823 .80525 .3716 .79691 .37757 Metetra
.79691 .37757 .80525 .3716 .82998 .37729 .82005 .36333 Metetra
.531 .593 .862 r
.16447 .44841 .17656 .46697 .19482 .46077 .18214 .44802 Metetra
.658 .728 .901 r
.18214 .44802 .19482 .46077 .21421 .44391 .2006 .44168 Metetra
.919 .591 .404 r
.2006 .44168 .21421 .44391 .23256 .43878 .21082 .52436 Metetra
.474 .196 .41 r
.21082 .52436 .23256 .43878 .25175 .42536 .23014 .51683 Metetra
0 0 .121 r
.23014 .51683 .25175 .42536 .26764 .45464 .25557 .43677 Metetra
.93 .551 .175 r
.25557 .43677 .26764 .45464 .28454 .47741 .26992 .4916 Metetra
.634 .201 .2 r
.26992 .4916 .28454 .47741 .30312 .48211 .28813 .50405 Metetra
.28813 .50405 .30312 .48211 .32081 .50568 .30893 .48245 Metetra
.181 .351 .798 r
.30893 .48245 .32081 .50568 .3396 .51833 .32768 .49492 Metetra
.271 .407 .816 r
.32768 .49492 .3396 .51833 .35952 .51575 .34692 .50505 Metetra
.723 .799 .912 r
.34692 .50505 .35952 .51575 .38047 .49392 .36749 .49462 Metetra
.86 .978 .858 r
.36749 .49462 .38047 .49392 .40024 .50275 .3886 .47386 Metetra
.706 .606 .743 r
.3886 .47386 .40024 .50275 .42128 .48205 .4095 .45822 Metetra
.6 .589 .812 r
.4095 .45822 .42128 .48205 .44185 .47925 .43013 .45401 Metetra
.54 .547 .81 r
.43013 .45401 .44185 .47925 .46321 .44574 .45085 .45362 Metetra
.853 .984 .7 r
.45085 .45362 .46321 .44574 .48421 .42631 .47228 .42501 Metetra
.787 .291 .015 r
.47228 .42501 .48421 .42631 .50484 .46679 .49304 .45283 Metetra
.405 .627 .944 r
.49304 .45283 .50484 .46679 .52623 .46517 .5145 .45504 Metetra
.967 .746 .551 r
.5145 .45504 .52623 .46517 .54686 .32055 .53583 .3352 Metetra
.53583 .3352 .54686 .32055 .5679 .32787 .55685 .31699 Metetra
0 .412 .85 r
.55685 .31699 .5679 .32787 .58932 .33655 .57836 .32686 Metetra
.839 .85 .853 r
.57836 .32686 .58932 .33655 .60989 .30011 .59957 .30724 Metetra
.888 .965 .639 r
.59957 .30724 .60989 .30011 .63118 .29158 .62033 .27308 Metetra
.654 .673 .856 r
.62033 .27308 .63118 .29158 .65381 .31224 .64189 .26558 Metetra
.491 .41 .692 r
.64189 .26558 .65381 .31224 .67662 .32469 .66422 .2714 Metetra
.126 .149 .615 r
.66422 .2714 .67662 .32469 .70025 .34373 .68874 .3122 Metetra
.691 .593 .74 r
.68874 .3122 .70025 .34373 .72472 .36714 .71082 .29707 Metetra
.358 .278 .628 r
.71082 .29707 .72472 .36714 .74839 .37013 .73586 .32505 Metetra
.686 .541 .683 r
.73586 .32505 .74839 .37013 .7719 .36657 .758 .30455 Metetra
.501 .388 .657 r
.758 .30455 .7719 .36657 .79691 .37757 .78235 .31097 Metetra
.667 .489 .635 r
.78235 .31097 .79691 .37757 .82005 .36333 .80422 .28517 Metetra
.36 .362 .726 r
.15402 .41446 .16447 .44841 .18214 .44802 .17047 .42446 Metetra
.651 .601 .786 r
.17047 .42446 .18214 .44802 .2006 .44168 .18906 .41685 Metetra
.411 .464 .805 r
.18906 .41685 .2006 .44168 .21082 .52436 .20649 .42222 Metetra
.087 .024 .482 r
.20649 .42222 .21082 .52436 .23014 .51683 .21909 .48262 Metetra
.832 .643 .647 r
.21909 .48262 .23014 .51683 .25557 .43677 .24285 .42475 Metetra
.705 .206 0 r
.24285 .42475 .25557 .43677 .26992 .4916 .25964 .4474 Metetra
0 0 .355 r
.25964 .4474 .26992 .4916 .28813 .50405 .27495 .49592 Metetra
.785 .844 .896 r
.27495 .49592 .28813 .50405 .30893 .48245 .2954 .48175 Metetra
.55 .918 .946 r
.2954 .48175 .30893 .48245 .32768 .49492 .31551 .47388 Metetra
.317 .465 .85 r
.31551 .47388 .32768 .49492 .34692 .50505 .33488 .4813 Metetra
.762 .661 .751 r
.33488 .4813 .34692 .50505 .36749 .49462 .35602 .46053 Metetra
.509 .469 .748 r
.35602 .46053 .36749 .49462 .3886 .47386 .3761 .46275 Metetra
.813 .807 .845 r
.3761 .46275 .3886 .47386 .4095 .45822 .39725 .44441 Metetra
.529 .688 .94 r
.39725 .44441 .4095 .45822 .43013 .45401 .41787 .44268 Metetra
.585 .757 .96 r
.41787 .44268 .43013 .45401 .45085 .45362 .43878 .43835 Metetra
.599 .696 .911 r
.43878 .43835 .45085 .45362 .47228 .42501 .45989 .43398 Metetra
.45989 .43398 .47228 .42501 .49304 .45283 .48129 .42309 Metetra
.463 .472 .783 r
.48129 .42309 .49304 .45283 .5145 .45504 .5027 .42772 Metetra
.81 .668 .706 r
.5027 .42772 .5145 .45504 .53583 .3352 .52444 .3947 Metetra
.52444 .3947 .53583 .3352 .55685 .31699 .5456 .30226 Metetra
.487 .652 .932 r
.5456 .30226 .55685 .31699 .57836 .32686 .56702 .30221 Metetra
.704 .637 .779 r
.56702 .30221 .57836 .32686 .59957 .30724 .58843 .28863 Metetra
.898 .518 .069 r
.58843 .28863 .59957 .30724 .62033 .27308 .61259 .37202 Metetra
.494 .217 .423 r
.61259 .37202 .62033 .27308 .64189 .26558 .63516 .3672 Metetra
.135 0 .335 r
.63516 .3672 .64189 .26558 .66422 .2714 .65507 .29322 Metetra
.763 .353 .275 r
.65507 .29322 .66422 .2714 .68874 .3122 .67969 .33138 Metetra
.67969 .33138 .68874 .3122 .71082 .29707 .70071 .29047 Metetra
.928 .906 .78 r
.70071 .29047 .71082 .29707 .73586 .32505 .72209 .26007 Metetra
.584 .436 .646 r
.72209 .26007 .73586 .32505 .758 .30455 .74494 .25222 Metetra
.405 .344 .676 r
.74494 .25222 .758 .30455 .78235 .31097 .76986 .2683 Metetra
.454 .407 .716 r
.76986 .2683 .78235 .31097 .80422 .28517 .79472 .27702 Metetra
.746 .929 .95 r
.13983 .41195 .15402 .41446 .17047 .42446 .15873 .40077 Metetra
.517 .535 .813 r
.15873 .40077 .17047 .42446 .18906 .41685 .17645 .40129 Metetra
0 .243 .753 r
.17645 .40129 .18906 .41685 .20649 .42222 .19315 .41375 Metetra
.939 .617 .4 r
.19315 .41375 .20649 .42222 .21909 .48262 .20185 .51232 Metetra
.649 .286 .342 r
.20185 .51232 .21909 .48262 .24285 .42475 .21923 .53035 Metetra
.459 .188 .414 r
.21923 .53035 .24285 .42475 .25964 .4474 .23957 .51869 Metetra
.358 .072 .336 r
.23957 .51869 .25964 .4474 .27495 .49592 .26062 .49922 Metetra
.457 .885 .823 r
.26062 .49922 .27495 .49592 .2954 .48175 .28091 .49004 Metetra
.353 .789 .614 r
.28091 .49004 .2954 .48175 .31551 .47388 .30151 .47823 Metetra
.826 .999 .826 r
.30151 .47823 .31551 .47388 .33488 .4813 .32275 .45738 Metetra
.533 .556 .824 r
.32275 .45738 .33488 .4813 .35602 .46053 .34283 .45701 Metetra
.7 .931 .965 r
.34283 .45701 .35602 .46053 .3761 .46275 .36366 .44631 Metetra
.774 .734 .816 r
.36366 .44631 .3761 .46275 .39725 .44441 .38488 .42914 Metetra
.268 .53 .914 r
.38488 .42914 .39725 .44441 .41787 .44268 .40528 .43505 Metetra
0 .497 .857 r
.40528 .43505 .41787 .44268 .43878 .43835 .426 .44106 Metetra
.955 .939 .728 r
.426 .44106 .43878 .43835 .45989 .43398 .44808 .40423 Metetra
.663 .585 .757 r
.44808 .40423 .45989 .43398 .48129 .42309 .46949 .39323 Metetra
0 .122 .66 r
.46949 .39323 .48129 .42309 .5027 .42772 .49062 .4198 Metetra
.971 .758 .558 r
.49062 .4198 .5027 .42772 .52444 .3947 .51289 .3095 Metetra
.621 .437 .613 r
.51289 .3095 .52444 .3947 .5456 .30226 .53421 .28978 Metetra
.76 .797 .883 r
.53421 .28978 .5456 .30226 .56702 .30221 .55559 .27616 Metetra
0 0 .48 r
.55559 .27616 .56702 .30221 .58843 .28863 .57793 .31452 Metetra
.812 .432 .335 r
.57793 .31452 .58843 .28863 .61259 .37202 .60156 .37266 Metetra
.907 .982 .777 r
.60156 .37266 .61259 .37202 .63516 .3672 .62362 .34421 Metetra
.898 .724 .658 r
.62362 .34421 .63516 .3672 .65507 .29322 .64463 .29166 Metetra
.853 .395 .064 r
.64463 .29166 .65507 .29322 .67969 .33138 .66983 .34071 Metetra
.893 .928 .546 r
.66983 .34071 .67969 .33138 .70071 .29047 .69109 .29656 Metetra
.426 .824 .61 r
.69109 .29656 .70071 .29047 .72209 .26007 .71373 .28101 Metetra
.144 0 .01 r
.71373 .28101 .72209 .26007 .74494 .25222 .73654 .26669 Metetra
.55 .066 .058 r
.73654 .26669 .74494 .25222 .76986 .2683 .7613 .27673 Metetra
.712 .899 .527 r
.7613 .27673 .76986 .2683 .79472 .27702 .78307 .24553 Metetra
.12241 .43328 .13983 .41195 .15873 .40077 .14231 .41595 Metetra
.587 .878 .571 r
.14231 .41595 .15873 .40077 .17645 .40129 .16262 .39505 Metetra
.64 .855 .981 r
.16262 .39505 .17645 .40129 .19315 .41375 .18138 .38839 Metetra
.968 .661 .38 r
.18138 .38839 .19315 .41375 .20185 .51232 .18735 .50935 Metetra
.664 .922 .975 r
.18735 .50935 .20185 .51232 .21923 .53035 .20734 .50023 Metetra
.62 .555 .76 r
.20734 .50023 .21923 .53035 .23957 .51869 .22723 .49364 Metetra
.299 .413 .811 r
.22723 .49364 .23957 .51869 .26062 .49922 .24596 .5026 Metetra
.864 .988 .837 r
.24596 .5026 .26062 .49922 .28091 .49004 .26746 .48031 Metetra
.469 .743 .988 r
.26746 .48031 .28091 .49004 .30151 .47823 .28744 .47877 Metetra
.899 .953 .827 r
.28744 .47877 .30151 .47823 .32275 .45738 .30918 .45381 Metetra
.787 .935 .928 r
.30918 .45381 .32275 .45738 .34283 .45701 .33023 .43919 Metetra
.647 .679 .867 r
.33023 .43919 .34283 .45701 .36366 .44631 .35093 .43225 Metetra
.562 .703 .935 r
.35093 .43225 .36366 .44631 .38488 .42914 .37162 .42914 Metetra
.207 .733 .818 r
.37162 .42914 .38488 .42914 .40528 .43505 .39251 .42599 Metetra
.127 .569 .923 r
.39251 .42599 .40528 .43505 .426 .44106 .41336 .43066 Metetra
.86 .828 .815 r
.41336 .43066 .426 .44106 .44808 .40423 .43532 .40654 Metetra
.986 .852 .623 r
.43532 .40654 .44808 .40423 .46949 .39323 .45806 .343 Metetra
.741 .561 .65 r
.45806 .343 .46949 .39323 .49062 .4198 .47983 .30693 Metetra
.595 .402 .59 r
.47983 .30693 .49062 .4198 .51289 .3095 .50123 .28835 Metetra
.743 .685 .795 r
.50123 .28835 .51289 .3095 .53421 .28978 .52265 .27221 Metetra
.634 .682 .878 r
.52265 .27221 .53421 .28978 .55559 .27616 .54418 .26582 Metetra
.902 .492 .106 r
.54418 .26582 .55559 .27616 .57793 .31452 .56687 .33243 Metetra
.56687 .33243 .57793 .31452 .60156 .37266 .58878 .30046 Metetra
.214 .172 .592 r
.58878 .30046 .60156 .37266 .62362 .34421 .61255 .34189 Metetra
.993 .831 .58 r
.61255 .34189 .62362 .34421 .64463 .29166 .63324 .26972 Metetra
.715 .329 0 r
.63324 .26972 .64463 .29166 .66983 .34071 .65864 .32642 Metetra
.812 .805 .844 r
.65864 .32642 .66983 .34071 .69109 .29656 .68138 .30674 Metetra
.583 .849 .503 r
.68138 .30674 .69109 .29656 .71373 .28101 .70377 .28056 Metetra
.847 .998 .815 r
.70377 .28056 .71373 .28101 .73654 .26669 .72624 .25703 Metetra
.57 .812 .99 r
.72624 .25703 .73654 .26669 .7613 .27673 .74999 .2515 Metetra
.709 .654 .792 r
.74999 .2515 .7613 .27673 .78307 .24553 .77324 .23689 Metetra
.954 .888 .727 r
.10659 .43819 .12241 .43328 .14231 .41595 .12953 .39777 Metetra
.523 .607 .878 r
.12953 .39777 .14231 .41595 .16262 .39505 .14758 .39709 Metetra
.73 .241 .082 r
.14758 .39709 .16262 .39505 .18138 .38839 .16379 .41463 Metetra
.84 .518 .445 r
.16379 .41463 .18138 .38839 .18735 .50935 .17393 .49337 Metetra
.723 .72 .847 r
.17393 .49337 .18735 .50935 .20734 .50023 .19426 .48157 Metetra
.508 .606 .885 r
.19426 .48157 .20734 .50023 .22723 .49364 .21359 .48134 Metetra
.585 .739 .949 r
.21359 .48134 .22723 .49364 .24596 .5026 .23349 .4772 Metetra
.73 .641 .759 r
.23349 .4772 .24596 .5026 .26746 .48031 .25465 .46003 Metetra
.517 .592 .868 r
.25465 .46003 .26746 .48031 .28744 .47877 .27455 .45967 Metetra
.643 .664 .855 r
.27455 .45967 .28744 .47877 .30918 .45381 .29515 .45277 Metetra
.341 .814 .902 r
.29515 .45277 .30918 .45381 .33023 .43919 .31574 .44844 Metetra
.941 .963 .693 r
.31574 .44844 .33023 .43919 .35093 .43225 .33848 .41026 Metetra
.528 .58 .851 r
.33848 .41026 .35093 .43225 .37162 .42914 .35906 .40961 Metetra
.416 .553 .885 r
.35906 .40961 .37162 .42914 .39251 .42599 .37971 .41285 Metetra
.817 .791 .827 r
.37971 .41285 .39251 .42599 .41336 .43066 .40156 .39264 Metetra
.62 .523 .723 r
.40156 .39264 .41336 .43066 .43532 .40654 .42304 .38406 Metetra
.887 .715 .663 r
.42304 .38406 .43532 .40654 .45806 .343 .4458 .33062 Metetra
.894 .798 .746 r
.4458 .33062 .45806 .343 .47983 .30693 .46775 .29682 Metetra
.929 .812 .708 r
.46775 .29682 .47983 .30693 .50123 .28835 .4896 .25477 Metetra
.058 .185 .682 r
.4896 .25477 .50123 .28835 .52265 .27221 .51084 .27912 Metetra
.842 .412 .208 r
.51084 .27912 .52265 .27221 .54418 .26582 .53275 .32469 Metetra
.203 0 .26 r
.53275 .32469 .54418 .26582 .56687 .33243 .55485 .29265 Metetra
0 .02 .575 r
.55485 .29265 .56687 .33243 .58878 .30046 .578 .33275 Metetra
.578 .33275 .58878 .30046 .61255 .34189 .60011 .29372 Metetra
.706 .546 .669 r
.60011 .29372 .61255 .34189 .63324 .26972 .62237 .26786 Metetra
.814 .33 0 r
.62237 .26786 .63324 .26972 .65864 .32642 .64713 .30794 Metetra
.706 .72 .861 r
.64713 .30794 .65864 .32642 .68138 .30674 .67038 .29602 Metetra
.856 .868 .848 r
.67038 .29602 .68138 .30674 .70377 .28056 .6932 .27354 Metetra
.824 .933 .902 r
.6932 .27354 .70377 .28056 .72624 .25703 .71623 .25497 Metetra
.477 .89 .923 r
.71623 .25497 .72624 .25703 .74999 .2515 .74003 .24676 Metetra
.982 .89 .653 r
.74003 .24676 .74999 .2515 .77324 .23689 .76092 .19856 Metetra
.896 .778 .723 r
.09219 .42968 .10659 .43819 .12953 .39777 .11526 .3902 Metetra
.824 .835 .857 r
.11526 .3902 .12953 .39777 .14758 .39709 .13543 .37262 Metetra
.926 .561 .138 r
.13543 .37262 .14758 .39709 .16379 .41463 .1474 .42563 Metetra
.857 .506 .387 r
.1474 .42563 .16379 .41463 .17393 .49337 .15964 .48367 Metetra
.463 .743 .989 r
.15964 .48367 .17393 .49337 .19426 .48157 .17901 .48215 Metetra
.76 .977 .918 r
.17901 .48215 .19426 .48157 .21359 .48134 .19989 .46756 Metetra
.787 .764 .833 r
.19989 .46756 .21359 .48134 .23349 .4772 .22106 .45035 Metetra
.478 .505 .807 r
.22106 .45035 .23349 .4772 .25465 .46003 .24059 .45253 Metetra
.482 .796 .999 r
.24059 .45253 .25465 .46003 .27455 .45967 .26079 .44951 Metetra
.725 .82 .924 r
.26079 .44951 .27455 .45967 .29515 .45277 .2818 .43859 Metetra
.43 .648 .95 r
.2818 .43859 .29515 .45277 .31574 .44844 .30211 .43941 Metetra
.391 .729 .99 r
.30211 .43941 .31574 .44844 .33848 .41026 .32277 .43892 Metetra
.32277 .43892 .33848 .41026 .35906 .40961 .34565 .40285 Metetra
.791 .892 .917 r
.34565 .40285 .35906 .40961 .37971 .41285 .3673 .38778 Metetra
.357 .457 .826 r
.3673 .38778 .37971 .41285 .40156 .39264 .38807 .39484 Metetra
.817 .998 .846 r
.38807 .39484 .40156 .39264 .42304 .38406 .41019 .37438 Metetra
.951 .784 .639 r
.41019 .37438 .42304 .38406 .4458 .33062 .43361 .3092 Metetra
.849 .717 .716 r
.43361 .3092 .4458 .33062 .46775 .29682 .45574 .27409 Metetra
.369 .486 .847 r
.45574 .27409 .46775 .29682 .4896 .25477 .47704 .28011 Metetra
.772 .384 .32 r
.47704 .28011 .4896 .25477 .51084 .27912 .49838 .32338 Metetra
.351 .016 .25 r
.49838 .32338 .51084 .27912 .53275 .32469 .52069 .31177 Metetra
.938 .791 .672 r
.52069 .31177 .53275 .32469 .55485 .29265 .5429 .26049 Metetra
.411 .431 .771 r
.5429 .26049 .55485 .29265 .578 .33275 .56543 .2678 Metetra
.134 .129 .586 r
.56543 .2678 .578 .33275 .60011 .29372 .58909 .31048 Metetra
.58909 .31048 .60011 .29372 .62237 .26786 .61194 .29068 Metetra
.494 .061 .144 r
.61194 .29068 .62237 .26786 .64713 .30794 .63571 .29584 Metetra
.724 .826 .928 r
.63571 .29584 .64713 .30794 .67038 .29602 .65912 .28378 Metetra
.964 .808 .64 r
.65912 .28378 .67038 .29602 .6932 .27354 .68035 .22605 Metetra
.007 .094 .606 r
.68035 .22605 .6932 .27354 .71623 .25497 .70692 .26873 Metetra
.70692 .26873 .71623 .25497 .74003 .24676 .7303 .24851 Metetra
.991 .877 .544 r
.7303 .24851 .74003 .24676 .76092 .19856 .75039 .18427 Metetra
.855 .716 .709 r
.07874 .41242 .09219 .42968 .11526 .3902 .10186 .37405 Metetra
.838 .726 .741 r
.10186 .37405 .11526 .3902 .13543 .37262 .12365 .34443 Metetra
.769 .413 0 r
.12365 .34443 .13543 .37262 .1474 .42563 .13702 .38337 Metetra
.93 .627 .16 r
.13702 .38337 .1474 .42563 .15964 .48367 .14632 .46342 Metetra
.619 .64 .849 r
.14632 .46342 .15964 .48367 .17901 .48215 .16614 .45788 Metetra
.648 .615 .802 r
.16614 .45788 .17901 .48215 .19989 .46756 .1864 .4497 Metetra
.536 .637 .897 r
.1864 .4497 .19989 .46756 .22106 .45035 .20617 .44797 Metetra
.65 .933 .969 r
.20617 .44797 .22106 .45035 .24059 .45253 .22687 .43836 Metetra
.178 .512 .914 r
.22687 .43836 .24059 .45253 .26079 .44951 .24636 .44445 Metetra
.744 .912 .95 r
.24636 .44445 .26079 .44951 .2818 .43859 .26764 .43209 Metetra
.808 .889 .902 r
.26764 .43209 .2818 .43859 .30211 .43941 .2893 .41573 Metetra
.549 .579 .837 r
.2893 .41573 .30211 .43941 .32277 .43892 .31005 .41377 Metetra
.727 .65 .773 r
.31005 .41377 .32277 .43892 .34565 .40285 .33191 .39728 Metetra
.864 .901 .858 r
.33191 .39728 .34565 .40285 .3673 .38778 .35409 .37552 Metetra
.62 .768 .951 r
.35409 .37552 .3673 .38778 .38807 .39484 .37553 .36939 Metetra
.793 .676 .735 r
.37553 .36939 .38807 .39484 .41019 .37438 .39799 .34238 Metetra
.852 .667 .652 r
.39799 .34238 .41019 .37438 .43361 .3092 .42125 .28883 Metetra
.726 .692 .818 r
.42125 .28883 .43361 .3092 .45574 .27409 .443 .27482 Metetra
.849 .401 .143 r
.443 .27482 .45574 .27409 .47704 .28011 .46375 .31685 Metetra
.512 .137 .266 r
.46375 .31685 .47704 .28011 .49838 .32338 .48583 .32213 Metetra
.347 .82 .894 r
.48583 .32213 .49838 .32338 .52069 .31177 .50834 .31694 Metetra
.994 .871 .583 r
.50834 .31694 .52069 .31177 .5429 .26049 .53094 .24962 Metetra
0 .093 .576 r
.53094 .24962 .5429 .26049 .56543 .2678 .55367 .26848 Metetra
.054 .62 .713 r
.55367 .26848 .56543 .2678 .58909 .31048 .57664 .2669 Metetra
.502 .436 .714 r
.57664 .2669 .58909 .31048 .61194 .29068 .59999 .26923 Metetra
0 .123 .673 r
.59999 .26923 .61194 .29068 .63571 .29584 .62443 .29422 Metetra
.994 .855 .588 r
.62443 .29422 .63571 .29584 .65912 .28378 .64595 .22805 Metetra
.339 .293 .66 r
.64595 .22805 .65912 .28378 .68035 .22605 .67089 .24847 Metetra
.67089 .24847 .68035 .22605 .70692 .26873 .69409 .22563 Metetra
.257 .284 .698 r
.69409 .22563 .70692 .26873 .7303 .24851 .72012 .24762 Metetra
.991 .886 .586 r
.72012 .24762 .7303 .24851 .75039 .18427 .74108 .18906 Metetra
.444 .323 .62 r
.07205 .34669 .07874 .41242 .10186 .37405 .08864 .3553 Metetra
.844 .708 .713 r
.08864 .3553 .10186 .37405 .12365 .34443 .11136 .31968 Metetra
.956 .612 .251 r
.11136 .31968 .12365 .34443 .13702 .38337 .12099 .38659 Metetra
.904 .572 .406 r
.12099 .38659 .13702 .38337 .14632 .46342 .12959 .47036 Metetra
.92 .971 .776 r
.12959 .47036 .14632 .46342 .16614 .45788 .15243 .43992 Metetra
.535 .637 .898 r
.15243 .43992 .16614 .45788 .1864 .4497 .17205 .43814 Metetra
.702 .792 .92 r
.17205 .43814 .1864 .4497 .20617 .44797 .1927 .42848 Metetra
.596 .646 .87 r
.1927 .42848 .20617 .44797 .22687 .43836 .21296 .42399 Metetra
.591 .718 .932 r
.21296 .42399 .22687 .43836 .24636 .44445 .23343 .41946 Metetra
.571 .578 .822 r
.23343 .41946 .24636 .44445 .26764 .43209 .25398 .4162 Metetra
.692 .732 .881 r
.25398 .4162 .26764 .43209 .2893 .41573 .27526 .4063 Metetra
.426 0 0 r
.27526 .4063 .2893 .41573 .31005 .41377 .29498 .42027 Metetra
.948 .956 .721 r
.29498 .42027 .31005 .41377 .33191 .39728 .31848 .38235 Metetra
.749 .764 .865 r
.31848 .38235 .33191 .39728 .35409 .37552 .34038 .36831 Metetra
.622 .864 .988 r
.34038 .36831 .35409 .37552 .37553 .36939 .36203 .36077 Metetra
.931 .822 .716 r
.36203 .36077 .37553 .36939 .39799 .34238 .38541 .31799 Metetra
.888 .708 .653 r
.38541 .31799 .39799 .34238 .42125 .28883 .40904 .26071 Metetra
.769 .408 0 r
.40904 .26071 .42125 .28883 .443 .27482 .42868 .31679 Metetra
.322 0 .212 r
.42868 .31679 .443 .27482 .46375 .31685 .451 .30505 Metetra
.46 .72 .981 r
.451 .30505 .46375 .31685 .48583 .32213 .47327 .30371 Metetra
.738 .729 .844 r
.47327 .30371 .48583 .32213 .50834 .31694 .49594 .28921 Metetra
.872 .697 .663 r
.49594 .28921 .50834 .31694 .53094 .24962 .51878 .23855 Metetra
.802 .336 0 r
.51878 .23855 .53094 .24962 .55367 .26848 .54168 .281 Metetra
.754 .915 .543 r
.54168 .281 .55367 .26848 .57664 .2669 .56453 .24666 Metetra
0 .01 .575 r
.56453 .24666 .57664 .2669 .59999 .26923 .58848 .27526 Metetra
.411 0 0 r
.58848 .27526 .59999 .26923 .62443 .29422 .61256 .28174 Metetra
.965 .804 .633 r
.61256 .28174 .62443 .29422 .64595 .22805 .63464 .22039 Metetra
.766 .277 0 r
.63464 .22039 .64595 .22805 .67089 .24847 .66057 .261 Metetra
.94 .878 .464 r
.66057 .261 .67089 .24847 .69409 .22563 .68191 .19427 Metetra
0 .095 .643 r
.68191 .19427 .69409 .22563 .72012 .24762 .70855 .22786 Metetra
.369 .547 .899 r
.70855 .22786 .72012 .24762 .74108 .18906 .73413 .23269 Metetra
0 .062 .578 r
.06239 .30312 .07205 .34669 .08864 .3553 .07648 .32799 Metetra
.701 .61 .752 r
.07648 .32799 .08864 .3553 .11136 .31968 .09641 .31373 Metetra
.726 .196 0 r
.09641 .31373 .11136 .31968 .12099 .38659 .11216 .33184 Metetra
.94 .665 .198 r
.11216 .33184 .12099 .38659 .12959 .47036 .118 .4327 Metetra
.64 .535 .719 r
.118 .4327 .12959 .47036 .15243 .43992 .13857 .42176 Metetra
.535 .637 .898 r
.13857 .42176 .15243 .43992 .17205 .43814 .15823 .41986 Metetra
.416 .58 .907 r
.15823 .41986 .17205 .43814 .1927 .42848 .17768 .42188 Metetra
.772 .885 .927 r
.17768 .42188 .1927 .42848 .21296 .42399 .199 .40811 Metetra
.672 .725 .889 r
.199 .40811 .21296 .42399 .23343 .41946 .2199 .39953 Metetra
.596 .646 .87 r
.2199 .39953 .23343 .41946 .25398 .4162 .24061 .39483 Metetra
.446 .557 .874 r
.24061 .39483 .25398 .4162 .27526 .4063 .26098 .39671 Metetra
.726 .843 .936 r
.26098 .39671 .27526 .4063 .29498 .42027 .28263 .3853 Metetra
.734 .603 .711 r
.28263 .3853 .29498 .42027 .31848 .38235 .30523 .36194 Metetra
.274 .475 .874 r
.30523 .36194 .31848 .38235 .34038 .36831 .3259 .36892 Metetra
.839 .987 .865 r
.3259 .36892 .34038 .36831 .36203 .36077 .34849 .34803 Metetra
.93 .778 .671 r
.34849 .34803 .36203 .36077 .38541 .31799 .37273 .29339 Metetra
.895 .709 .643 r
.37273 .29339 .38541 .31799 .40904 .26071 .39682 .23119 Metetra
0 0 .349 r
.39682 .23119 .40904 .26071 .42868 .31679 .41666 .27377 Metetra
.727 .572 .68 r
.41666 .27377 .42868 .31679 .451 .30505 .43933 .2466 Metetra
0 0 .506 r
.43933 .2466 .451 .30505 .47327 .30371 .4603 .2969 Metetra
.886 .905 .836 r
.4603 .2969 .47327 .30371 .49594 .28921 .48332 .27173 Metetra
.885 .77 .73 r
.48332 .27173 .49594 .28921 .51878 .23855 .50635 .23499 Metetra
.652 .097 0 r
.50635 .23499 .51878 .23855 .54168 .281 .52922 .25668 Metetra
.797 .7 .758 r
.52922 .25668 .54168 .281 .56453 .24666 .55232 .23137 Metetra
0 .028 .561 r
.55232 .23137 .56453 .24666 .58848 .27526 .57619 .25595 Metetra
.648 .698 .882 r
.57619 .25595 .58848 .27526 .61256 .28174 .59996 .24755 Metetra
.603 .546 .763 r
.59996 .24755 .61256 .28174 .63464 .22039 .62398 .24041 Metetra
.145 0 0 r
.62398 .24041 .63464 .22039 .66057 .261 .64807 .22919 Metetra
.418 .454 .791 r
.64807 .22919 .66057 .261 .68191 .19427 .67317 .23537 Metetra
.142 0 .153 r
.67317 .23537 .68191 .19427 .70855 .22786 .6969 .20918 Metetra
.968 .766 .579 r
.6969 .20918 .70855 .22786 .73413 .23269 .71717 .13097 Metetra
.908 .52 .268 r
.04744 .2947 .06239 .30312 .07648 .32799 .05859 .33901 Metetra
.944 .957 .732 r
.05859 .33901 .07648 .32799 .09641 .31373 .08186 .30287 Metetra
0 .336 .77 r
.08186 .30287 .09641 .31373 .11216 .33184 .09888 .31128 Metetra
.96 .642 .374 r
.09888 .31128 .11216 .33184 .118 .4327 .1039 .41444 Metetra
.685 .694 .853 r
.1039 .41444 .118 .4327 .13857 .42176 .12439 .40468 Metetra
.16 .458 .885 r
.12439 .40468 .13857 .42176 .15823 .41986 .143 .41185 Metetra
.804 .859 .89 r
.143 .41185 .15823 .41986 .17768 .42188 .16459 .39541 Metetra
.644 .603 .794 r
.16459 .39541 .17768 .42188 .199 .40811 .1854 .38677 Metetra
.639 .649 .844 r
.1854 .38677 .199 .40811 .2199 .39953 .20623 .37938 Metetra
.246 .464 .873 r
.20623 .37938 .2199 .39953 .24061 .39483 .22587 .38645 Metetra
.851 .856 .845 r
.22587 .38645 .24061 .39483 .26098 .39671 .2484 .36441 Metetra
.63 .561 .758 r
.2484 .36441 .26098 .39671 .28263 .3853 .26984 .35552 Metetra
.747 .634 .735 r
.26984 .35552 .28263 .3853 .30523 .36194 .29242 .33344 Metetra
.217 .347 .782 r
.29242 .33344 .30523 .36194 .3259 .36892 .31268 .34548 Metetra
.819 .702 .736 r
.31268 .34548 .3259 .36892 .34849 .34803 .33593 .3153 Metetra
.864 .672 .641 r
.33593 .3153 .34849 .34803 .37273 .29339 .36069 .25457 Metetra
.827 .637 .646 r
.36069 .25457 .37273 .29339 .39682 .23119 .38447 .20276 Metetra
.521 .526 .801 r
.38447 .20276 .39682 .23119 .41666 .27377 .4058 .20206 Metetra
0 0 .257 r
.4058 .20206 .41666 .27377 .43933 .2466 .42442 .29407 Metetra
.278 0 .207 r
.42442 .29407 .43933 .2466 .4603 .2969 .44736 .27801 Metetra
.625 .688 .889 r
.44736 .27801 .4603 .2969 .48332 .27173 .47022 .27115 Metetra
.956 .932 .73 r
.47022 .27115 .48332 .27173 .50635 .23499 .49362 .23265 Metetra
.757 .24 0 r
.49362 .23265 .50635 .23499 .52922 .25668 .51657 .26257 Metetra
.51657 .26257 .52922 .25668 .55232 .23137 .54012 .25553 Metetra
.529 .089 .147 r
.54012 .25553 .55232 .23137 .57619 .25595 .5641 .26462 Metetra
.146 0 0 r
.5641 .26462 .57619 .25595 .59996 .24755 .58831 .26157 Metetra
.757 .893 .492 r
.58831 .26157 .59996 .24755 .62398 .24041 .61178 .2219 Metetra
.918 .78 .692 r
.61178 .2219 .62398 .24041 .64807 .22919 .63474 .17612 Metetra
.491 .402 .683 r
.63474 .17612 .64807 .22919 .67317 .23537 .65949 .17914 Metetra
.406 .34 .67 r
.65949 .17914 .67317 .23537 .6969 .20918 .68515 .19158 Metetra
.947 .792 .656 r
.68515 .19158 .6969 .20918 .71717 .13097 .70731 .13766 Metetra
.85 .434 0 r
.03411 .27436 .04744 .2947 .05859 .33901 .0467 .30756 Metetra
.437 .442 .766 r
.0467 .30756 .05859 .33901 .08186 .30287 .06424 .31119 Metetra
.952 .936 .738 r
.06424 .31119 .08186 .30287 .09888 .31128 .08785 .2737 Metetra
.978 .68 .363 r
.08785 .2737 .09888 .31128 .1039 .41444 .08911 .39988 Metetra
.775 .761 .84 r
.08911 .39988 .1039 .41444 .12439 .40468 .11054 .3835 Metetra
0 0 .509 r
.11054 .3835 .12439 .40468 .143 .41185 .12734 .40501 Metetra
.87 .859 .827 r
.12734 .40501 .143 .41185 .16459 .39541 .15004 .38052 Metetra
.697 .75 .893 r
.15004 .38052 .16459 .39541 .1854 .38677 .17109 .37045 Metetra
.623 .709 .907 r
.17109 .37045 .1854 .38677 .20623 .37938 .19186 .36426 Metetra
.52 .689 .944 r
.19186 .36426 .20623 .37938 .22587 .38645 .21243 .36197 Metetra
.696 .648 .798 r
.21243 .36197 .22587 .38645 .2484 .36441 .23421 .34907 Metetra
.593 .717 .93 r
.23421 .34907 .2484 .36441 .26984 .35552 .25542 .34402 Metetra
.819 .824 .852 r
.25542 .34402 .26984 .35552 .29242 .33344 .27799 .32438 Metetra
.328 .709 .982 r
.27799 .32438 .29242 .33344 .31268 .34548 .29915 .32448 Metetra
.597 .645 .869 r
.29915 .32448 .31268 .34548 .33593 .3153 .32094 .31925 Metetra
.987 .804 .57 r
.32094 .31925 .33593 .3153 .36069 .25457 .34843 .21954 Metetra
.834 .652 .656 r
.34843 .21954 .36069 .25457 .38447 .20276 .37224 .17048 Metetra
.311 .371 .763 r
.37224 .17048 .38447 .20276 .4058 .20206 .39304 .18069 Metetra
.946 .591 .209 r
.39304 .18069 .4058 .20206 .42442 .29407 .41074 .28706 Metetra
.958 .839 .684 r
.41074 .28706 .42442 .29407 .44736 .27801 .43492 .23654 Metetra
.284 .306 .708 r
.43492 .23654 .44736 .27801 .47022 .27115 .45721 .25187 Metetra
.409 .581 .91 r
.45721 .25187 .47022 .27115 .49362 .23265 .48023 .25414 Metetra
.059 0 0 r
.48023 .25414 .49362 .23265 .51657 .26257 .50373 .24035 Metetra
.622 .655 .861 r
.50373 .24035 .51657 .26257 .54012 .25553 .52736 .23316 Metetra
.129 .369 .827 r
.52736 .23316 .54012 .25553 .5641 .26462 .55138 .24616 Metetra
.919 .777 .688 r
.55138 .24616 .5641 .26462 .58831 .26157 .57496 .19855 Metetra
.499 .384 .654 r
.57496 .19855 .58831 .26157 .61178 .2219 .59934 .20044 Metetra
.468 .59 .892 r
.59934 .20044 .61178 .2219 .63474 .17612 .62406 .20101 Metetra
.271 0 .036 r
.62406 .20101 .63474 .17612 .65949 .17914 .64882 .19346 Metetra
.959 .846 .426 r
.64882 .19346 .65949 .17914 .68515 .19158 .66997 .10798 Metetra
.34 .245 .6 r
.66997 .10798 .68515 .19158 .70731 .13766 .69659 .13531 Metetra
0 g
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.21035 .18732 m
.21487 .19208 L
s
[(10)] .20131 .17781 .94967 1 Mshowa
.41738 .10625 m
.42153 .11134 L
s
[(20)] .40909 .09608 .81515 1 Mshowa
.64163 .01845 m
.64532 .02387 L
s
[(30)] .63425 .0076 .68064 1 Mshowa
.125 Mabswid
.25047 .17161 m
.25314 .1745 L
s
.29122 .15565 m
.29385 .15859 L
s
.33262 .13945 m
.3352 .14242 L
s
.37466 .12298 m
.3772 .12599 L
s
.46079 .08926 m
.46322 .09235 L
s
.5049 .07199 m
.50728 .07512 L
s
.54973 .05443 m
.55206 .0576 L
s
.5953 .03659 m
.59757 .0398 L
s
.17084 .20279 m
.17359 .20561 L
s
.13192 .21803 m
.13471 .22081 L
s
.09359 .23304 m
.09641 .23578 L
s
.05583 .24783 m
.05869 .25053 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.678571 0.00744048 0.97619 0.30506 MathSubStart
%% ContourGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0117866 0.0310174 -0.0117866 0.0310174 [
[.1433 -0.0125 -3 -9 ]
[.1433 -0.0125 3 0 ]
[.29839 -0.0125 -6 -9 ]
[.29839 -0.0125 6 0 ]
[.45347 -0.0125 -6 -9 ]
[.45347 -0.0125 6 0 ]
[.60856 -0.0125 -6 -9 ]
[.60856 -0.0125 6 0 ]
[.76365 -0.0125 -6 -9 ]
[.76365 -0.0125 6 0 ]
[.91873 -0.0125 -6 -9 ]
[.91873 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .1433 -6 -4.5 ]
[-0.0125 .1433 0 4.5 ]
[-0.0125 .29839 -12 -4.5 ]
[-0.0125 .29839 0 4.5 ]
[-0.0125 .45347 -12 -4.5 ]
[-0.0125 .45347 0 4.5 ]
[-0.0125 .60856 -12 -4.5 ]
[-0.0125 .60856 0 4.5 ]
[-0.0125 .76365 -12 -4.5 ]
[-0.0125 .76365 0 4.5 ]
[-0.0125 .91873 -12 -4.5 ]
[-0.0125 .91873 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.1433 0 m
.1433 .00625 L
s
[(5)] .1433 -0.0125 0 1 Mshowa
.29839 0 m
.29839 .00625 L
s
[(10)] .29839 -0.0125 0 1 Mshowa
.45347 0 m
.45347 .00625 L
s
[(15)] .45347 -0.0125 0 1 Mshowa
.60856 0 m
.60856 .00625 L
s
[(20)] .60856 -0.0125 0 1 Mshowa
.76365 0 m
.76365 .00625 L
s
[(25)] .76365 -0.0125 0 1 Mshowa
.91873 0 m
.91873 .00625 L
s
[(30)] .91873 -0.0125 0 1 Mshowa
.125 Mabswid
.17432 0 m
.17432 .00375 L
s
.20533 0 m
.20533 .00375 L
s
.23635 0 m
.23635 .00375 L
s
.26737 0 m
.26737 .00375 L
s
.3294 0 m
.3294 .00375 L
s
.36042 0 m
.36042 .00375 L
s
.39144 0 m
.39144 .00375 L
s
.42246 0 m
.42246 .00375 L
s
.48449 0 m
.48449 .00375 L
s
.51551 0 m
.51551 .00375 L
s
.54653 0 m
.54653 .00375 L
s
.57754 0 m
.57754 .00375 L
s
.63958 0 m
.63958 .00375 L
s
.6706 0 m
.6706 .00375 L
s
.70161 0 m
.70161 .00375 L
s
.73263 0 m
.73263 .00375 L
s
.79467 0 m
.79467 .00375 L
s
.82568 0 m
.82568 .00375 L
s
.8567 0 m
.8567 .00375 L
s
.88772 0 m
.88772 .00375 L
s
.11228 0 m
.11228 .00375 L
s
.08127 0 m
.08127 .00375 L
s
.05025 0 m
.05025 .00375 L
s
.01923 0 m
.01923 .00375 L
s
.94975 0 m
.94975 .00375 L
s
.98077 0 m
.98077 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .1433 m
.00625 .1433 L
s
[(5)] -0.0125 .1433 1 0 Mshowa
0 .29839 m
.00625 .29839 L
s
[(10)] -0.0125 .29839 1 0 Mshowa
0 .45347 m
.00625 .45347 L
s
[(15)] -0.0125 .45347 1 0 Mshowa
0 .60856 m
.00625 .60856 L
s
[(20)] -0.0125 .60856 1 0 Mshowa
0 .76365 m
.00625 .76365 L
s
[(25)] -0.0125 .76365 1 0 Mshowa
0 .91873 m
.00625 .91873 L
s
[(30)] -0.0125 .91873 1 0 Mshowa
.125 Mabswid
0 .17432 m
.00375 .17432 L
s
0 .20533 m
.00375 .20533 L
s
0 .23635 m
.00375 .23635 L
s
0 .26737 m
.00375 .26737 L
s
0 .3294 m
.00375 .3294 L
s
0 .36042 m
.00375 .36042 L
s
0 .39144 m
.00375 .39144 L
s
0 .42246 m
.00375 .42246 L
s
0 .48449 m
.00375 .48449 L
s
0 .51551 m
.00375 .51551 L
s
0 .54653 m
.00375 .54653 L
s
0 .57754 m
.00375 .57754 L
s
0 .63958 m
.00375 .63958 L
s
0 .6706 m
.00375 .6706 L
s
0 .70161 m
.00375 .70161 L
s
0 .73263 m
.00375 .73263 L
s
0 .79467 m
.00375 .79467 L
s
0 .82568 m
.00375 .82568 L
s
0 .8567 m
.00375 .8567 L
s
0 .88772 m
.00375 .88772 L
s
0 .11228 m
.00375 .11228 L
s
0 .08127 m
.00375 .08127 L
s
0 .05025 m
.00375 .05025 L
s
0 .01923 m
.00375 .01923 L
s
0 .94975 m
.00375 .94975 L
s
0 .98077 m
.00375 .98077 L
s
.25 Mabswid
0 0 m
0 1 L
s
.1433 .99375 m
.1433 1 L
s
.29839 .99375 m
.29839 1 L
s
.45347 .99375 m
.45347 1 L
s
.60856 .99375 m
.60856 1 L
s
.76365 .99375 m
.76365 1 L
s
.91873 .99375 m
.91873 1 L
s
.125 Mabswid
.17432 .99625 m
.17432 1 L
s
.20533 .99625 m
.20533 1 L
s
.23635 .99625 m
.23635 1 L
s
.26737 .99625 m
.26737 1 L
s
.3294 .99625 m
.3294 1 L
s
.36042 .99625 m
.36042 1 L
s
.39144 .99625 m
.39144 1 L
s
.42246 .99625 m
.42246 1 L
s
.48449 .99625 m
.48449 1 L
s
.51551 .99625 m
.51551 1 L
s
.54653 .99625 m
.54653 1 L
s
.57754 .99625 m
.57754 1 L
s
.63958 .99625 m
.63958 1 L
s
.6706 .99625 m
.6706 1 L
s
.70161 .99625 m
.70161 1 L
s
.73263 .99625 m
.73263 1 L
s
.79467 .99625 m
.79467 1 L
s
.82568 .99625 m
.82568 1 L
s
.8567 .99625 m
.8567 1 L
s
.88772 .99625 m
.88772 1 L
s
.11228 .99625 m
.11228 1 L
s
.08127 .99625 m
.08127 1 L
s
.05025 .99625 m
.05025 1 L
s
.01923 .99625 m
.01923 1 L
s
.94975 .99625 m
.94975 1 L
s
.98077 .99625 m
.98077 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .1433 m
1 .1433 L
s
.99375 .29839 m
1 .29839 L
s
.99375 .45347 m
1 .45347 L
s
.99375 .60856 m
1 .60856 L
s
.99375 .76365 m
1 .76365 L
s
.99375 .91873 m
1 .91873 L
s
.125 Mabswid
.99625 .17432 m
1 .17432 L
s
.99625 .20533 m
1 .20533 L
s
.99625 .23635 m
1 .23635 L
s
.99625 .26737 m
1 .26737 L
s
.99625 .3294 m
1 .3294 L
s
.99625 .36042 m
1 .36042 L
s
.99625 .39144 m
1 .39144 L
s
.99625 .42246 m
1 .42246 L
s
.99625 .48449 m
1 .48449 L
s
.99625 .51551 m
1 .51551 L
s
.99625 .54653 m
1 .54653 L
s
.99625 .57754 m
1 .57754 L
s
.99625 .63958 m
1 .63958 L
s
.99625 .6706 m
1 .6706 L
s
.99625 .70161 m
1 .70161 L
s
.99625 .73263 m
1 .73263 L
s
.99625 .79467 m
1 .79467 L
s
.99625 .82568 m
1 .82568 L
s
.99625 .8567 m
1 .8567 L
s
.99625 .88772 m
1 .88772 L
s
.99625 .11228 m
1 .11228 L
s
.99625 .08127 m
1 .08127 L
s
.99625 .05025 m
1 .05025 L
s
.99625 .01923 m
1 .01923 L
s
.99625 .94975 m
1 .94975 L
s
.99625 .98077 m
1 .98077 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.6 g
.01923 .98077 m
.98077 .98077 L
.98077 .01923 L
.01923 .01923 L
F
0 g
.5 Mabswid
.7 g
.01923 .93673 m
.05025 .93995 L
.08127 .94414 L
.11228 .94427 L
.1433 .94538 L
.17432 .94221 L
.20533 .94082 L
.23635 .93446 L
.26737 .92512 L
.28053 .91873 L
.29839 .91245 L
.3294 .90196 L
.35555 .88772 L
.36042 .88592 L
.39144 .8727 L
.42246 .8573 L
.42361 .8567 L
.45347 .8346 L
.46102 .82568 L
.48449 .79851 L
.4899 .79467 L
.51551 .7754 L
.52239 .76365 L
.54653 .73521 L
.54854 .73263 L
.54937 .70161 L
.54653 .69942 L
.51551 .69049 L
.49704 .6706 L
.51551 .66203 L
.54653 .6516 L
.55982 .63958 L
.56358 .60856 L
.55979 .57754 L
.56509 .54653 L
.57754 .53376 L
.59742 .51551 L
.60856 .50152 L
.63958 .49544 L
.6706 .49644 L
.69407 .51551 L
.70161 .52082 L
.72105 .51551 L
.72757 .48449 L
.73263 .47789 L
.76365 .47454 L
.79467 .46701 L
.82568 .45639 L
.83157 .45347 L
.8567 .44115 L
.88772 .44404 L
.91873 .43915 L
.94341 .42246 L
.91873 .39794 L
.90365 .39144 L
.88772 .38782 L
.87698 .39144 L
.8567 .40009 L
.84748 .39144 L
.83431 .36042 L
.8567 .3515 L
.88772 .33294 L
.91873 .33943 L
.94975 .33162 L
.98077 .34077 L
.98077 .98077 L
.01923 .98077 L
F
0 g
.01923 .93673 m
.05025 .93995 L
.08127 .94414 L
.11228 .94427 L
.1433 .94538 L
.17432 .94221 L
.20533 .94082 L
.23635 .93446 L
.26737 .92512 L
.28053 .91873 L
.29839 .91245 L
.3294 .90196 L
.35555 .88772 L
.36042 .88592 L
.39144 .8727 L
.42246 .8573 L
.42361 .8567 L
.45347 .8346 L
.46102 .82568 L
.48449 .79851 L
.4899 .79467 L
.51551 .7754 L
.52239 .76365 L
.54653 .73521 L
.54854 .73263 L
.54937 .70161 L
.54653 .69942 L
.51551 .69049 L
.49704 .6706 L
.51551 .66203 L
.54653 .6516 L
.55982 .63958 L
.56358 .60856 L
.55979 .57754 L
.56509 .54653 L
.57754 .53376 L
.59742 .51551 L
.60856 .50152 L
.63958 .49544 L
.6706 .49644 L
.69407 .51551 L
.70161 .52082 L
.72105 .51551 L
.72757 .48449 L
.73263 .47789 L
.76365 .47454 L
.79467 .46701 L
.82568 .45639 L
.83157 .45347 L
.8567 .44115 L
Mistroke
.88772 .44404 L
.91873 .43915 L
.94341 .42246 L
.91873 .39794 L
.90365 .39144 L
.88772 .38782 L
.87698 .39144 L
.8567 .40009 L
.84748 .39144 L
.83431 .36042 L
.8567 .3515 L
.88772 .33294 L
.91873 .33943 L
.94975 .33162 L
.98077 .34077 L
Mfstroke
.8 g
.01923 .9414 m
.05025 .94418 L
.08127 .94893 L
.10461 .94975 L
.11228 .94982 L
.1433 .95125 L
.15817 .94975 L
.17432 .94775 L
.20533 .94614 L
.23635 .94059 L
.26737 .93307 L
.29754 .91873 L
.29839 .91844 L
.3294 .90824 L
.36042 .89561 L
.38279 .88772 L
.39144 .88368 L
.42246 .86731 L
.44221 .8567 L
.45347 .84742 L
.47189 .82568 L
.48449 .81114 L
.50689 .79467 L
.51551 .78868 L
.53137 .76365 L
.54653 .74703 L
.55968 .73263 L
.56723 .70161 L
.54653 .68238 L
.51551 .67713 L
.51258 .6706 L
.51551 .66917 L
.54653 .66356 L
.57465 .63958 L
.569 .60856 L
.56538 .57754 L
.56935 .54653 L
.57754 .53826 L
.60264 .51551 L
.60856 .50784 L
.63958 .50156 L
.6706 .50378 L
.68412 .51551 L
.70161 .53816 L
.71121 .54653 L
.7319 .57754 L
.73263 .5788 L
.7335 .57754 L
.73675 .54653 L
.75555 .51551 L
.76365 .5087 L
.79467 .49156 L
.80625 .48449 L
.82568 .46906 L
.8567 .46477 L
.86622 .48449 L
.88772 .51198 L
.89577 .51551 L
.9185 .54653 L
.91873 .547 L
.94975 .56274 L
.98077 .5665 L
.98077 .98077 L
.01923 .98077 L
F
0 g
.01923 .9414 m
.05025 .94418 L
.08127 .94893 L
.10461 .94975 L
.11228 .94982 L
.1433 .95125 L
.15817 .94975 L
.17432 .94775 L
.20533 .94614 L
.23635 .94059 L
.26737 .93307 L
.29754 .91873 L
.29839 .91844 L
.3294 .90824 L
.36042 .89561 L
.38279 .88772 L
.39144 .88368 L
.42246 .86731 L
.44221 .8567 L
.45347 .84742 L
.47189 .82568 L
.48449 .81114 L
.50689 .79467 L
.51551 .78868 L
.53137 .76365 L
.54653 .74703 L
.55968 .73263 L
.56723 .70161 L
.54653 .68238 L
.51551 .67713 L
.51258 .6706 L
.51551 .66917 L
.54653 .66356 L
.57465 .63958 L
.569 .60856 L
.56538 .57754 L
.56935 .54653 L
.57754 .53826 L
.60264 .51551 L
.60856 .50784 L
.63958 .50156 L
.6706 .50378 L
.68412 .51551 L
.70161 .53816 L
.71121 .54653 L
.7319 .57754 L
.73263 .5788 L
.7335 .57754 L
.73675 .54653 L
.75555 .51551 L
Mistroke
.76365 .5087 L
.79467 .49156 L
.80625 .48449 L
.82568 .46906 L
.8567 .46477 L
.86622 .48449 L
.88772 .51198 L
.89577 .51551 L
.9185 .54653 L
.91873 .547 L
.94975 .56274 L
.98077 .5665 L
Mfstroke
.7 g
.01923 .63388 m
.02279 .63958 L
.05025 .64865 L
.08049 .63958 L
.08127 .63945 L
.08148 .63958 L
.11228 .66736 L
.11599 .6706 L
.13397 .70161 L
.1433 .72917 L
.17432 .72713 L
.1819 .73263 L
.19549 .76365 L
.20533 .76683 L
.23635 .77333 L
.25733 .79467 L
.26737 .80245 L
.29839 .80284 L
.3294 .79876 L
.34064 .79467 L
.35101 .76365 L
.36042 .76343 L
.39078 .73263 L
.39144 .7323 L
.39237 .73263 L
.42246 .73516 L
.42324 .73263 L
.45347 .71775 L
.48449 .70243 L
.48535 .70161 L
.48449 .68919 L
.45347 .67908 L
.42246 .68832 L
.40309 .6706 L
.42246 .65618 L
.43997 .63958 L
.44423 .60856 L
.45347 .60006 L
.45621 .57754 L
.4575 .54653 L
.4565 .51551 L
.45347 .50841 L
.44692 .51551 L
.42273 .54653 L
.42246 .54691 L
.42175 .54653 L
.39752 .51551 L
.40882 .48449 L
.42246 .47528 L
.45347 .47992 L
.48449 .45716 L
.49006 .45347 L
.51551 .44252 L
.54653 .43059 L
.55338 .42246 L
.57747 .39144 L
.57754 .39136 L
.58847 .36042 L
.59188 .3294 L
.60856 .30569 L
.61266 .29839 L
.60856 .29131 L
.59115 .26737 L
.57754 .25408 L
.54653 .26029 L
.53695 .23635 L
.52948 .20533 L
.53951 .17432 L
.51892 .1433 L
.51551 .12878 L
.51182 .11228 L
.50641 .08127 L
.49583 .05025 L
.49605 .01923 L
.01923 .01923 L
F
0 g
.01923 .63388 m
.02279 .63958 L
.05025 .64865 L
.08049 .63958 L
.08127 .63945 L
.08148 .63958 L
.11228 .66736 L
.11599 .6706 L
.13397 .70161 L
.1433 .72917 L
.17432 .72713 L
.1819 .73263 L
.19549 .76365 L
.20533 .76683 L
.23635 .77333 L
.25733 .79467 L
.26737 .80245 L
.29839 .80284 L
.3294 .79876 L
.34064 .79467 L
.35101 .76365 L
.36042 .76343 L
.39078 .73263 L
.39144 .7323 L
.39237 .73263 L
.42246 .73516 L
.42324 .73263 L
.45347 .71775 L
.48449 .70243 L
.48535 .70161 L
.48449 .68919 L
.45347 .67908 L
.42246 .68832 L
.40309 .6706 L
.42246 .65618 L
.43997 .63958 L
.44423 .60856 L
.45347 .60006 L
.45621 .57754 L
.4575 .54653 L
.4565 .51551 L
.45347 .50841 L
.44692 .51551 L
.42273 .54653 L
.42246 .54691 L
.42175 .54653 L
.39752 .51551 L
.40882 .48449 L
.42246 .47528 L
.45347 .47992 L
Mistroke
.48449 .45716 L
.49006 .45347 L
.51551 .44252 L
.54653 .43059 L
.55338 .42246 L
.57747 .39144 L
.57754 .39136 L
.58847 .36042 L
.59188 .3294 L
.60856 .30569 L
.61266 .29839 L
.60856 .29131 L
.59115 .26737 L
.57754 .25408 L
.54653 .26029 L
.53695 .23635 L
.52948 .20533 L
.53951 .17432 L
.51892 .1433 L
.51551 .12878 L
.51182 .11228 L
.50641 .08127 L
.49583 .05025 L
.49605 .01923 L
Mfstroke
.8 g
.01923 .6156 m
.05025 .63224 L
.08127 .6216 L
.10111 .63958 L
.11228 .6526 L
.13149 .6706 L
.1433 .70115 L
.14358 .70161 L
.17432 .70642 L
.20414 .73263 L
.20533 .74991 L
.22438 .76365 L
.23635 .76518 L
.26495 .79467 L
.26737 .79653 L
.29839 .79806 L
.32104 .79467 L
.29839 .7639 L
.26737 .76575 L
.26056 .76365 L
.26737 .7589 L
.29839 .75593 L
.3294 .7461 L
.35058 .73263 L
.3294 .70608 L
.29839 .70711 L
.29722 .70161 L
.29839 .70074 L
.3282 .6706 L
.29839 .64905 L
.28951 .63958 L
.26737 .60923 L
.26615 .60856 L
.25206 .57754 L
.26698 .54653 L
.26737 .54571 L
.27398 .54653 L
.2895 .57754 L
.27163 .60856 L
.29839 .6202 L
.32759 .60856 L
.32345 .57754 L
.3294 .57411 L
.35968 .54653 L
.3294 .53594 L
.29839 .53364 L
.29013 .51551 L
.29839 .51085 L
.3294 .5037 L
.36042 .49533 L
.391 .48449 L
.39144 .48414 L
.42246 .46211 L
.45347 .46403 L
.46971 .45347 L
.45347 .42788 L
.44855 .42246 L
.45347 .41516 L
.46199 .39144 L
.47049 .36042 L
.48449 .34252 L
.49378 .3294 L
.51551 .3116 L
.53019 .3294 L
.533 .36042 L
.51551 .38131 L
.50712 .39144 L
.49235 .42246 L
.51551 .43441 L
.54639 .42246 L
.54653 .42229 L
.56747 .39144 L
.57754 .38017 L
.58385 .36042 L
.58622 .3294 L
.60137 .29839 L
.58474 .26737 L
.57754 .26056 L
.55522 .26737 L
.54653 .29018 L
.51551 .2837 L
.5062 .26737 L
.51551 .24831 L
.52278 .23635 L
.51551 .21408 L
.48449 .20813 L
.48089 .20533 L
.45347 .17523 L
.44263 .17432 L
.45347 .15024 L
.45422 .17432 L
.48449 .20028 L
.51551 .18766 L
.5173 .17432 L
.51551 .17188 L
.49141 .1433 L
.49358 .11228 L
.49174 .08127 L
.48449 .06775 L
.47621 .05025 L
.48449 .0251 L
.48818 .01923 L
.01923 .01923 L
F
0 g
.01923 .6156 m
.05025 .63224 L
.08127 .6216 L
.10111 .63958 L
.11228 .6526 L
.13149 .6706 L
.1433 .70115 L
.14358 .70161 L
.17432 .70642 L
.20414 .73263 L
.20533 .74991 L
.22438 .76365 L
.23635 .76518 L
.26495 .79467 L
.26737 .79653 L
.29839 .79806 L
.32104 .79467 L
.29839 .7639 L
.26737 .76575 L
.26056 .76365 L
.26737 .7589 L
.29839 .75593 L
.3294 .7461 L
.35058 .73263 L
.3294 .70608 L
.29839 .70711 L
.29722 .70161 L
.29839 .70074 L
.3282 .6706 L
.29839 .64905 L
.28951 .63958 L
.26737 .60923 L
.26615 .60856 L
.25206 .57754 L
.26698 .54653 L
.26737 .54571 L
.27398 .54653 L
.2895 .57754 L
.27163 .60856 L
.29839 .6202 L
.32759 .60856 L
.32345 .57754 L
.3294 .57411 L
.35968 .54653 L
.3294 .53594 L
.29839 .53364 L
.29013 .51551 L
.29839 .51085 L
.3294 .5037 L
.36042 .49533 L
Mistroke
.391 .48449 L
.39144 .48414 L
.42246 .46211 L
.45347 .46403 L
.46971 .45347 L
.45347 .42788 L
.44855 .42246 L
.45347 .41516 L
.46199 .39144 L
.47049 .36042 L
.48449 .34252 L
.49378 .3294 L
.51551 .3116 L
.53019 .3294 L
.533 .36042 L
.51551 .38131 L
.50712 .39144 L
.49235 .42246 L
.51551 .43441 L
.54639 .42246 L
.54653 .42229 L
.56747 .39144 L
.57754 .38017 L
.58385 .36042 L
.58622 .3294 L
.60137 .29839 L
.58474 .26737 L
.57754 .26056 L
.55522 .26737 L
.54653 .29018 L
.51551 .2837 L
.5062 .26737 L
.51551 .24831 L
.52278 .23635 L
.51551 .21408 L
.48449 .20813 L
.48089 .20533 L
.45347 .17523 L
.44263 .17432 L
.45347 .15024 L
.45422 .17432 L
.48449 .20028 L
.51551 .18766 L
.5173 .17432 L
.51551 .17188 L
.49141 .1433 L
.49358 .11228 L
.49174 .08127 L
.48449 .06775 L
.47621 .05025 L
Mistroke
.48449 .0251 L
.48818 .01923 L
Mfstroke
.5 g
.01923 .93214 m
.05025 .93585 L
.08127 .93957 L
.11228 .93897 L
.1433 .93983 L
.17432 .93695 L
.20533 .93572 L
.23635 .92846 L
.26433 .91873 L
.26737 .91724 L
.29839 .90683 L
.3294 .8958 L
.34067 .88772 L
.36042 .87828 L
.39144 .86801 L
.41228 .8567 L
.42246 .85008 L
.45255 .82568 L
.45347 .82471 L
.48279 .79467 L
.48449 .78845 L
.51318 .76365 L
.51551 .76023 L
.53575 .73263 L
.52426 .70161 L
.51551 .70042 L
.50848 .70161 L
.48449 .71486 L
.45347 .72374 L
.43609 .73263 L
.42246 .76094 L
.41805 .76365 L
.39144 .76916 L
.36042 .78707 L
.35337 .79467 L
.3294 .80497 L
.29839 .80726 L
.26737 .80778 L
.25037 .79467 L
.23635 .78053 L
.20533 .77395 L
.18138 .76365 L
.17432 .75087 L
.1433 .74251 L
.13521 .73263 L
.12555 .70161 L
.11228 .67844 L
.09272 .6706 L
.08127 .66235 L
.05025 .65909 L
.01923 .64547 L
F
0 g
.01923 .93214 m
.05025 .93585 L
.08127 .93957 L
.11228 .93897 L
.1433 .93983 L
.17432 .93695 L
.20533 .93572 L
.23635 .92846 L
.26433 .91873 L
.26737 .91724 L
.29839 .90683 L
.3294 .8958 L
.34067 .88772 L
.36042 .87828 L
.39144 .86801 L
.41228 .8567 L
.42246 .85008 L
.45255 .82568 L
.45347 .82471 L
.48279 .79467 L
.48449 .78845 L
.51318 .76365 L
.51551 .76023 L
.53575 .73263 L
.52426 .70161 L
.51551 .70042 L
.50848 .70161 L
.48449 .71486 L
.45347 .72374 L
.43609 .73263 L
.42246 .76094 L
.41805 .76365 L
.39144 .76916 L
.36042 .78707 L
.35337 .79467 L
.3294 .80497 L
.29839 .80726 L
.26737 .80778 L
.25037 .79467 L
.23635 .78053 L
.20533 .77395 L
.18138 .76365 L
.17432 .75087 L
.1433 .74251 L
.13521 .73263 L
.12555 .70161 L
.11228 .67844 L
.09272 .6706 L
.08127 .66235 L
.05025 .65909 L
Mistroke
.01923 .64547 L
Mfstroke
.4 g
.01923 .92747 m
.05025 .93175 L
.08127 .93505 L
.11228 .9337 L
.1433 .93433 L
.17432 .93171 L
.20533 .93062 L
.23635 .92224 L
.2462 .91873 L
.26737 .90829 L
.29839 .90127 L
.3294 .88932 L
.33146 .88772 L
.36042 .87065 L
.39144 .86203 L
.39971 .8567 L
.42246 .8432 L
.44453 .82568 L
.45347 .81628 L
.48179 .79467 L
.48449 .77848 L
.50229 .76365 L
.51551 .74141 L
.52011 .73263 L
.51551 .71969 L
.48449 .72541 L
.45347 .72992 L
.448 .73263 L
.43681 .76365 L
.42246 .77048 L
.39144 .77572 L
.3616 .79467 L
.36042 .7963 L
.3294 .81078 L
.29839 .81157 L
.26737 .81294 L
.24341 .79467 L
.23635 .78761 L
.20533 .7806 L
.17432 .76958 L
.16471 .76365 L
.1433 .75247 L
.12604 .73263 L
.11686 .70161 L
.11228 .69214 L
.08127 .68496 L
.05484 .6706 L
.05025 .66937 L
.01923 .65405 L
F
0 g
.01923 .92747 m
.05025 .93175 L
.08127 .93505 L
.11228 .9337 L
.1433 .93433 L
.17432 .93171 L
.20533 .93062 L
.23635 .92224 L
.2462 .91873 L
.26737 .90829 L
.29839 .90127 L
.3294 .88932 L
.33146 .88772 L
.36042 .87065 L
.39144 .86203 L
.39971 .8567 L
.42246 .8432 L
.44453 .82568 L
.45347 .81628 L
.48179 .79467 L
.48449 .77848 L
.50229 .76365 L
.51551 .74141 L
.52011 .73263 L
.51551 .71969 L
.48449 .72541 L
.45347 .72992 L
.448 .73263 L
.43681 .76365 L
.42246 .77048 L
.39144 .77572 L
.3616 .79467 L
.36042 .7963 L
.3294 .81078 L
.29839 .81157 L
.26737 .81294 L
.24341 .79467 L
.23635 .78761 L
.20533 .7806 L
.17432 .76958 L
.16471 .76365 L
.1433 .75247 L
.12604 .73263 L
.11686 .70161 L
.11228 .69214 L
.08127 .68496 L
.05484 .6706 L
.05025 .66937 L
.01923 .65405 L
s
.9 g
.01923 .94636 m
.05025 .9487 L
.0567 .94975 L
.08127 .95423 L
.11228 .95602 L
.1433 .95795 L
.17432 .95399 L
.20533 .95202 L
.22298 .94975 L
.23635 .94727 L
.26737 .942 L
.29839 .93007 L
.31689 .91873 L
.3294 .91514 L
.36042 .90881 L
.39144 .90195 L
.41136 .88772 L
.42246 .88084 L
.45347 .86282 L
.48158 .88772 L
.45347 .9058 L
.42622 .91873 L
.42246 .92138 L
.39144 .92809 L
.36042 .94049 L
.34524 .94975 L
.3294 .95627 L
.29839 .97819 L
.2915 .98077 L
.01923 .98077 L
F
0 g
.01923 .94636 m
.05025 .9487 L
.0567 .94975 L
.08127 .95423 L
.11228 .95602 L
.1433 .95795 L
.17432 .95399 L
.20533 .95202 L
.22298 .94975 L
.23635 .94727 L
.26737 .942 L
.29839 .93007 L
.31689 .91873 L
.3294 .91514 L
.36042 .90881 L
.39144 .90195 L
.41136 .88772 L
.42246 .88084 L
.45347 .86282 L
.48158 .88772 L
.45347 .9058 L
.42622 .91873 L
.42246 .92138 L
.39144 .92809 L
.36042 .94049 L
.34524 .94975 L
.3294 .95627 L
.29839 .97819 L
.2915 .98077 L
s
.3 g
.01923 .92252 m
.05025 .9275 L
.08127 .93041 L
.11228 .92823 L
.1433 .92864 L
.17432 .92625 L
.20533 .9253 L
.2283 .91873 L
.23635 .91307 L
.26737 .89835 L
.29839 .89545 L
.31931 .88772 L
.3294 .87617 L
.36042 .86235 L
.38032 .8567 L
.39144 .84761 L
.42246 .83612 L
.4361 .82568 L
.45347 .80726 L
.47531 .79467 L
.45347 .76595 L
.42246 .77835 L
.39144 .78213 L
.37148 .79467 L
.36042 .81052 L
.3294 .81666 L
.29839 .81593 L
.26737 .8182 L
.23635 .79555 L
.23544 .79467 L
.20533 .78733 L
.17432 .78129 L
.1433 .76775 L
.13891 .76365 L
.1169 .73263 L
.11228 .71202 L
.08127 .70637 L
.06768 .70161 L
.05025 .68367 L
.02215 .6706 L
.01923 .66743 L
F
0 g
.01923 .92252 m
.05025 .9275 L
.08127 .93041 L
.11228 .92823 L
.1433 .92864 L
.17432 .92625 L
.20533 .9253 L
.2283 .91873 L
.23635 .91307 L
.26737 .89835 L
.29839 .89545 L
.31931 .88772 L
.3294 .87617 L
.36042 .86235 L
.38032 .8567 L
.39144 .84761 L
.42246 .83612 L
.4361 .82568 L
.45347 .80726 L
.47531 .79467 L
.45347 .76595 L
.42246 .77835 L
.39144 .78213 L
.37148 .79467 L
.36042 .81052 L
.3294 .81666 L
.29839 .81593 L
.26737 .8182 L
.23635 .79555 L
.23544 .79467 L
.20533 .78733 L
.17432 .78129 L
.1433 .76775 L
.13891 .76365 L
.1169 .73263 L
.11228 .71202 L
.08127 .70637 L
.06768 .70161 L
.05025 .68367 L
.02215 .6706 L
.01923 .66743 L
s
.2 g
.01923 .91515 m
.02623 .91873 L
.05025 .92292 L
.08127 .92544 L
.11228 .92223 L
.1433 .92239 L
.17432 .92022 L
.20533 .91941 L
.20818 .91873 L
.23635 .89357 L
.24762 .88772 L
.26737 .88501 L
.27522 .88772 L
.29839 .88891 L
.30245 .88772 L
.31307 .8567 L
.3294 .85031 L
.34717 .82568 L
.3294 .82316 L
.29839 .82055 L
.26737 .82392 L
.23635 .81609 L
.20533 .79485 L
.17432 .7959 L
.1433 .79499 L
.14284 .79467 L
.11228 .76736 L
.10811 .76365 L
.0982 .73263 L
.08127 .72814 L
.0601 .73263 L
.05456 .76365 L
.06115 .79467 L
.05025 .81898 L
.04121 .82568 L
.05025 .84321 L
.05369 .8567 L
.05025 .85818 L
.01923 .85948 L
F
0 g
.01923 .91515 m
.02623 .91873 L
.05025 .92292 L
.08127 .92544 L
.11228 .92223 L
.1433 .92239 L
.17432 .92022 L
.20533 .91941 L
.20818 .91873 L
.23635 .89357 L
.24762 .88772 L
.26737 .88501 L
.27522 .88772 L
.29839 .88891 L
.30245 .88772 L
.31307 .8567 L
.3294 .85031 L
.34717 .82568 L
.3294 .82316 L
.29839 .82055 L
.26737 .82392 L
.23635 .81609 L
.20533 .79485 L
.17432 .7959 L
.1433 .79499 L
.14284 .79467 L
.11228 .76736 L
.10811 .76365 L
.0982 .73263 L
.08127 .72814 L
.0601 .73263 L
.05456 .76365 L
.06115 .79467 L
.05025 .81898 L
.04121 .82568 L
.05025 .84321 L
.05369 .8567 L
.05025 .85818 L
.01923 .85948 L
s
.7 g
.01923 .39158 m
.05025 .41787 L
.05687 .42246 L
.08127 .45148 L
.10596 .42246 L
.11228 .41978 L
.1433 .40812 L
.16939 .39144 L
.17432 .39035 L
.17878 .39144 L
.20533 .40412 L
.23287 .39144 L
.23635 .38868 L
.2665 .36042 L
.23635 .33343 L
.22051 .3294 L
.23035 .29839 L
.20533 .28067 L
.17432 .2788 L
.1433 .27927 L
.13793 .26737 L
.13651 .23635 L
.13423 .20533 L
.12951 .17432 L
.136 .1433 L
.12853 .11228 L
.13913 .08127 L
.14087 .05025 L
.14172 .01923 L
.01923 .01923 L
F
0 g
.01923 .39158 m
.05025 .41787 L
.05687 .42246 L
.08127 .45148 L
.10596 .42246 L
.11228 .41978 L
.1433 .40812 L
.16939 .39144 L
.17432 .39035 L
.17878 .39144 L
.20533 .40412 L
.23287 .39144 L
.23635 .38868 L
.2665 .36042 L
.23635 .33343 L
.22051 .3294 L
.23035 .29839 L
.20533 .28067 L
.17432 .2788 L
.1433 .27927 L
.13793 .26737 L
.13651 .23635 L
.13423 .20533 L
.12951 .17432 L
.136 .1433 L
.12853 .11228 L
.13913 .08127 L
.14087 .05025 L
.14172 .01923 L
s
.6 g
.01923 .38411 m
.02569 .39144 L
.05025 .40839 L
.07663 .42246 L
.08127 .42485 L
.08574 .42246 L
.11228 .41275 L
.1433 .3957 L
.14908 .39144 L
.17432 .3811 L
.20533 .39049 L
.23635 .37094 L
.24848 .36042 L
.23635 .35101 L
.20533 .33967 L
.20221 .3294 L
.20533 .32322 L
.21839 .29839 L
.20533 .28802 L
.17432 .28401 L
.1433 .29547 L
.13185 .26737 L
.13156 .23635 L
.12679 .20533 L
.11985 .17432 L
.12835 .1433 L
.12173 .11228 L
.13279 .08127 L
.13454 .05025 L
.13661 .01923 L
.01923 .01923 L
F
0 g
.01923 .38411 m
.02569 .39144 L
.05025 .40839 L
.07663 .42246 L
.08127 .42485 L
.08574 .42246 L
.11228 .41275 L
.1433 .3957 L
.14908 .39144 L
.17432 .3811 L
.20533 .39049 L
.23635 .37094 L
.24848 .36042 L
.23635 .35101 L
.20533 .33967 L
.20221 .3294 L
.20533 .32322 L
.21839 .29839 L
.20533 .28802 L
.17432 .28401 L
.1433 .29547 L
.13185 .26737 L
.13156 .23635 L
.12679 .20533 L
.11985 .17432 L
.12835 .1433 L
.12173 .11228 L
.13279 .08127 L
.13454 .05025 L
.13661 .01923 L
s
1 g
.01923 .95196 m
.05025 .95388 L
.08127 .96075 L
.11228 .96395 L
.1433 .96722 L
.17432 .96224 L
.20533 .95936 L
.23635 .95553 L
.23966 .98077 L
.01923 .98077 L
F
0 g
.01923 .95196 m
.05025 .95388 L
.08127 .96075 L
.11228 .96395 L
.1433 .96722 L
.17432 .96224 L
.20533 .95936 L
.23635 .95553 L
.23966 .98077 L
s
.5 g
.01923 .37718 m
.03463 .39144 L
.05025 .3998 L
.08127 .40806 L
.11228 .40629 L
.13736 .39144 L
.1433 .38752 L
.17432 .37254 L
.20044 .36042 L
.19343 .3294 L
.20533 .30576 L
.20737 .29839 L
.20533 .29652 L
.17432 .28923 L
.15615 .29839 L
.1587 .3294 L
.1433 .34095 L
.11228 .34423 L
.09775 .3294 L
.11228 .31324 L
.13274 .29839 L
.12599 .26737 L
.1268 .23635 L
.11954 .20533 L
.11228 .18449 L
.11074 .17432 L
.11228 .16946 L
.12121 .1433 L
.11529 .11228 L
.12697 .08127 L
.12881 .05025 L
.13194 .01923 L
.01923 .01923 L
F
0 g
.01923 .37718 m
.03463 .39144 L
.05025 .3998 L
.08127 .40806 L
.11228 .40629 L
.13736 .39144 L
.1433 .38752 L
.17432 .37254 L
.20044 .36042 L
.19343 .3294 L
.20533 .30576 L
.20737 .29839 L
.20533 .29652 L
.17432 .28923 L
.15615 .29839 L
.1587 .3294 L
.1433 .34095 L
.11228 .34423 L
.09775 .3294 L
.11228 .31324 L
.13274 .29839 L
.12599 .26737 L
.1268 .23635 L
.11954 .20533 L
.11228 .18449 L
.11074 .17432 L
.11228 .16946 L
.12121 .1433 L
.11529 .11228 L
.12697 .08127 L
.12881 .05025 L
.13194 .01923 L
s
.4 g
.01923 .37017 m
.05025 .39056 L
.05217 .39144 L
.08127 .39471 L
.11228 .39981 L
.12723 .39144 L
.1433 .38078 L
.17432 .36343 L
.1771 .36042 L
.18356 .3294 L
.19347 .29839 L
.17432 .29478 L
.16704 .29839 L
.16732 .3294 L
.1433 .34648 L
.11228 .35002 L
.09099 .3294 L
.11228 .30709 L
.1239 .29839 L
.12 .26737 L
.12199 .23635 L
.11228 .20626 L
.11143 .20533 L
.10154 .17432 L
.11228 .14894 L
.11402 .1433 L
.11228 .13376 L
.10868 .11228 L
.11228 .10264 L
.12124 .08127 L
.12322 .05025 L
.12742 .01923 L
.01923 .01923 L
F
0 g
.01923 .37017 m
.05025 .39056 L
.05217 .39144 L
.08127 .39471 L
.11228 .39981 L
.12723 .39144 L
.1433 .38078 L
.17432 .36343 L
.1771 .36042 L
.18356 .3294 L
.19347 .29839 L
.17432 .29478 L
.16704 .29839 L
.16732 .3294 L
.1433 .34648 L
.11228 .35002 L
.09099 .3294 L
.11228 .30709 L
.1239 .29839 L
.12 .26737 L
.12199 .23635 L
.11228 .20626 L
.11143 .20533 L
.10154 .17432 L
.11228 .14894 L
.11402 .1433 L
.11228 .13376 L
.10868 .11228 L
.11228 .10264 L
.12124 .08127 L
.12322 .05025 L
.12742 .01923 L
s
.3 g
.01923 .36242 m
.05025 .36994 L
.08127 .37883 L
.1001 .39144 L
.11228 .39275 L
.11505 .39144 L
.1433 .3733 L
.16331 .36042 L
.1433 .35243 L
.11228 .35591 L
.08364 .3294 L
.11228 .30076 L
.11541 .29839 L
.11348 .26737 L
.11691 .23635 L
.11228 .22107 L
.08783 .20533 L
.09107 .17432 L
.10471 .1433 L
.10151 .11228 L
.11228 .08824 L
.11526 .08127 L
.11744 .05025 L
.12282 .01923 L
.01923 .01923 L
F
0 g
.01923 .36242 m
.05025 .36994 L
.08127 .37883 L
.1001 .39144 L
.11228 .39275 L
.11505 .39144 L
.1433 .3733 L
.16331 .36042 L
.1433 .35243 L
.11228 .35591 L
.08364 .3294 L
.11228 .30076 L
.11541 .29839 L
.11348 .26737 L
.11691 .23635 L
.11228 .22107 L
.08783 .20533 L
.09107 .17432 L
.10471 .1433 L
.10151 .11228 L
.11228 .08824 L
.11526 .08127 L
.11744 .05025 L
.12282 .01923 L
s
.2 g
.01923 .11688 m
.02252 .11228 L
.05025 .09972 L
.05693 .11228 L
.06262 .1433 L
.08127 .16177 L
.09177 .1433 L
.09335 .11228 L
.10514 .08127 L
.10987 .05025 L
.08127 .02846 L
.05133 .01923 L
.01923 .01923 L
F
0 g
.01923 .11688 m
.02252 .11228 L
.05025 .09972 L
.05693 .11228 L
.06262 .1433 L
.08127 .16177 L
.09177 .1433 L
.09335 .11228 L
.10514 .08127 L
.10987 .05025 L
.08127 .02846 L
.05133 .01923 L
s
.2 g
.01923 .31855 m
.03824 .29839 L
.05025 .29392 L
.08127 .29232 L
.09331 .26737 L
.08127 .25054 L
.05025 .25605 L
.01923 .25836 L
F
0 g
.01923 .31855 m
.03824 .29839 L
.05025 .29392 L
.08127 .29232 L
.09331 .26737 L
.08127 .25054 L
.05025 .25605 L
.01923 .25836 L
s
.7 g
.01923 .48674 m
.0275 .51551 L
.05025 .54497 L
.07359 .51551 L
.06896 .48449 L
.05252 .45347 L
.05025 .45308 L
.01923 .44272 L
F
0 g
.01923 .48674 m
.0275 .51551 L
.05025 .54497 L
.07359 .51551 L
.06896 .48449 L
.05252 .45347 L
.05025 .45308 L
.01923 .44272 L
s
.4 g
.01923 .24168 m
.04569 .23635 L
.03701 .20533 L
.04677 .17432 L
.04441 .1433 L
.01923 .12812 L
F
0 g
.01923 .24168 m
.04569 .23635 L
.03701 .20533 L
.04677 .17432 L
.04441 .1433 L
.01923 .12812 L
s
.9 g
.01923 .59631 m
.04512 .57754 L
.01923 .55678 L
F
0 g
.01923 .59631 m
.04512 .57754 L
.01923 .55678 L
s
.2 g
.01923 .72346 m
.04198 .70161 L
.01923 .68809 L
F
0 g
.01923 .72346 m
.04198 .70161 L
.01923 .68809 L
s
.9 g
.01923 .42867 m
.03881 .42246 L
.01923 .40582 L
F
0 g
.01923 .42867 m
.03881 .42246 L
.01923 .40582 L
s
.1 g
.01923 .10291 m
.029 .08127 L
.0228 .05025 L
.03308 .01923 L
.01923 .01923 L
F
0 g
.01923 .10291 m
.029 .08127 L
.0228 .05025 L
.03308 .01923 L
s
.5 g
.01923 .21757 m
.02182 .20533 L
.02789 .17432 L
.02495 .1433 L
.01923 .14063 L
F
0 g
.01923 .21757 m
.02182 .20533 L
.02789 .17432 L
.02495 .1433 L
.01923 .14063 L
s
.4 g
.01923 .77884 m
.02186 .76365 L
.01923 .75999 L
F
0 g
.01923 .77884 m
.02186 .76365 L
.01923 .75999 L
s
.01923 .02003 m
.01967 .01923 L
.01923 .01923 L
F
.01923 .02003 m
.01967 .01923 L
s
.3 g
.05025 .01968 m
.07013 .05025 L
.05025 .07182 L
.02988 .05025 L
F
0 g
.05025 .01968 m
.07013 .05025 L
.05025 .07182 L
.02988 .05025 L
.05025 .01968 L
s
.1 g
.08127 .89591 m
.09031 .91873 L
.08127 .91975 L
.0594 .91873 L
F
0 g
.08127 .89591 m
.09031 .91873 L
.08127 .91975 L
.0594 .91873 L
.08127 .89591 L
s
.1 g
.08127 .10509 m
.08194 .11228 L
.08127 .11644 L
.07783 .11228 L
F
0 g
.08127 .10509 m
.08194 .11228 L
.08127 .11644 L
.07783 .11228 L
.08127 .10509 L
s
.2 g
.1179 .01923 m
.11228 .03949 L
.08796 .01923 L
F
0 g
.1179 .01923 m
.11228 .03949 L
.08796 .01923 L
s
.7 g
.11228 .31996 m
.1433 .3016 L
.15096 .3294 L
.1433 .3353 L
.11228 .3379 L
.10461 .3294 L
F
0 g
.11228 .31996 m
.1433 .3016 L
.15096 .3294 L
.1433 .3353 L
.11228 .3379 L
.10461 .3294 L
.11228 .31996 L
s
.7 g
.1433 .43773 m
.16081 .45347 L
.1433 .47665 L
.12462 .45347 L
F
0 g
.1433 .43773 m
.16081 .45347 L
.1433 .47665 L
.12462 .45347 L
.1433 .43773 L
s
.2 g
.1433 .35997 m
.14453 .36042 L
.1433 .36162 L
.12949 .36042 L
F
0 g
.1433 .35997 m
.14453 .36042 L
.1433 .36162 L
.12949 .36042 L
.1433 .35997 L
s
.9 g
.1433 .09191 m
.16709 .11228 L
.1433 .13669 L
.13634 .11228 L
F
0 g
.1433 .09191 m
.16709 .11228 L
.1433 .13669 L
.13634 .11228 L
.1433 .09191 L
s
.9 g
.3294 .03684 m
.33275 .05025 L
.36042 .07214 L
.39144 .07988 L
.3931 .08127 L
.41469 .11228 L
.403 .1433 L
.40745 .17432 L
.39144 .18523 L
.36429 .20533 L
.36042 .21031 L
.3294 .20866 L
.31249 .23635 L
.29839 .25692 L
.26737 .26616 L
.25947 .26737 L
.23635 .27128 L
.20533 .27321 L
.17432 .27326 L
.14572 .26737 L
.1433 .26031 L
.14199 .23635 L
.14289 .20533 L
.14106 .17432 L
.1433 .16337 L
.17432 .14988 L
.20533 .16898 L
.20752 .17432 L
.23635 .19698 L
.25017 .20533 L
.26737 .22743 L
.29463 .20533 L
.26917 .17432 L
.27181 .1433 L
.29839 .1132 L
.30104 .11228 L
.3294 .0999 L
.34286 .08127 L
.3294 .05771 L
.32613 .05025 L
F
0 g
.3294 .03684 m
.33275 .05025 L
.36042 .07214 L
.39144 .07988 L
.3931 .08127 L
.41469 .11228 L
.403 .1433 L
.40745 .17432 L
.39144 .18523 L
.36429 .20533 L
.36042 .21031 L
.3294 .20866 L
.31249 .23635 L
.29839 .25692 L
.26737 .26616 L
.25947 .26737 L
.23635 .27128 L
.20533 .27321 L
.17432 .27326 L
.14572 .26737 L
.1433 .26031 L
.14199 .23635 L
.14289 .20533 L
.14106 .17432 L
.1433 .16337 L
.17432 .14988 L
.20533 .16898 L
.20752 .17432 L
.23635 .19698 L
.25017 .20533 L
.26737 .22743 L
.29463 .20533 L
.26917 .17432 L
.27181 .1433 L
.29839 .1132 L
.30104 .11228 L
.3294 .0999 L
.34286 .08127 L
.3294 .05771 L
.32613 .05025 L
.3294 .03684 L
s
.1 g
.17432 .82049 m
.19026 .82568 L
.17432 .84097 L
.15494 .82568 L
F
0 g
.17432 .82049 m
.19026 .82568 L
.17432 .84097 L
.15494 .82568 L
.17432 .82049 L
s
.7 g
.20533 .47316 m
.20988 .48449 L
.22226 .51551 L
.2142 .54653 L
.20533 .57339 L
.1989 .57754 L
.20533 .58852 L
.2149 .60856 L
.20533 .62284 L
.19276 .60856 L
.17432 .57918 L
.17346 .57754 L
.15718 .54653 L
.17432 .5433 L
.18917 .51551 L
.19275 .48449 L
F
0 g
.20533 .47316 m
.20988 .48449 L
.22226 .51551 L
.2142 .54653 L
.20533 .57339 L
.1989 .57754 L
.20533 .58852 L
.2149 .60856 L
.20533 .62284 L
.19276 .60856 L
.17432 .57918 L
.17346 .57754 L
.15718 .54653 L
.17432 .5433 L
.18917 .51551 L
.19275 .48449 L
.20533 .47316 L
s
.8 g
.17432 .19512 m
.19621 .20533 L
.17432 .23091 L
.16661 .20533 L
F
0 g
.17432 .19512 m
.19621 .20533 L
.17432 .23091 L
.16661 .20533 L
.17432 .19512 L
s
.7 g
.17781 .01923 m
.17432 .02793 L
.17045 .01923 L
F
0 g
.17781 .01923 m
.17432 .02793 L
.17045 .01923 L
s
.7 g
.17432 .66563 m
.20035 .6706 L
.20533 .67282 L
.22533 .70161 L
.20533 .72933 L
.18106 .70161 L
.17432 .67735 L
.17165 .6706 L
F
0 g
.17432 .66563 m
.20035 .6706 L
.20533 .67282 L
.22533 .70161 L
.20533 .72933 L
.18106 .70161 L
.17432 .67735 L
.17165 .6706 L
.17432 .66563 L
s
.9 g
.20533 .41917 m
.23279 .42246 L
.20533 .43597 L
.19612 .42246 L
F
0 g
.20533 .41917 m
.23279 .42246 L
.20533 .43597 L
.19612 .42246 L
.20533 .41917 L
s
.9 g
.21563 .01923 m
.20533 .03767 L
.20058 .01923 L
F
0 g
.21563 .01923 m
.20533 .03767 L
.20058 .01923 L
s
.9 g
.3294 .31792 m
.35928 .3294 L
.33382 .36042 L
.36042 .37482 L
.3862 .36042 L
.39144 .3571 L
.39814 .36042 L
.42246 .3817 L
.43565 .39144 L
.42246 .40546 L
.39144 .41492 L
.36042 .4196 L
.35296 .42246 L
.36042 .43835 L
.38943 .45347 L
.36042 .46486 L
.35123 .45347 L
.3294 .43899 L
.3174 .45347 L
.3294 .46199 L
.34611 .48449 L
.3294 .48988 L
.29839 .49568 L
.26737 .4934 L
.23635 .50068 L
.22841 .48449 L
.23635 .46063 L
.25229 .45347 L
.23938 .42246 L
.25852 .39144 L
.26737 .38489 L
.29839 .36317 L
.3031 .36042 L
.32053 .3294 L
F
0 g
.3294 .31792 m
.35928 .3294 L
.33382 .36042 L
.36042 .37482 L
.3862 .36042 L
.39144 .3571 L
.39814 .36042 L
.42246 .3817 L
.43565 .39144 L
.42246 .40546 L
.39144 .41492 L
.36042 .4196 L
.35296 .42246 L
.36042 .43835 L
.38943 .45347 L
.36042 .46486 L
.35123 .45347 L
.3294 .43899 L
.3174 .45347 L
.3294 .46199 L
.34611 .48449 L
.3294 .48988 L
.29839 .49568 L
.26737 .4934 L
.23635 .50068 L
.22841 .48449 L
.23635 .46063 L
.25229 .45347 L
.23938 .42246 L
.25852 .39144 L
.26737 .38489 L
.29839 .36317 L
.3031 .36042 L
.32053 .3294 L
.3294 .31792 L
s
.9 g
.23635 .13708 m
.24471 .1433 L
.23635 .14623 L
.22994 .1433 L
F
0 g
.23635 .13708 m
.24471 .1433 L
.23635 .14623 L
.22994 .1433 L
.23635 .13708 L
s
.9 g
.23635 .07826 m
.24371 .08127 L
.23635 .08818 L
.23142 .08127 L
F
0 g
.23635 .07826 m
.24371 .08127 L
.23635 .08818 L
.23142 .08127 L
.23635 .07826 L
s
.9 g
.23635 .54251 m
.2387 .54653 L
.23635 .54942 L
.23506 .54653 L
F
0 g
.23635 .54251 m
.2387 .54653 L
.23635 .54942 L
.23506 .54653 L
.23635 .54251 L
s
.7 g
.26737 .30011 m
.28705 .3294 L
.26737 .35884 L
.24696 .3294 L
F
0 g
.26737 .30011 m
.28705 .3294 L
.26737 .35884 L
.24696 .3294 L
.26737 .30011 L
s
.7 g
.29839 .29745 m
.29901 .29839 L
.29839 .30305 L
.27323 .29839 L
F
0 g
.29839 .29745 m
.29901 .29839 L
.29839 .30305 L
.27323 .29839 L
.29839 .29745 L
s
.7 g
.35873 .98077 m
.3294 .9736 L
.31862 .98077 L
F
0 g
.35873 .98077 m
.3294 .9736 L
.31862 .98077 L
s
.8 g
.3294 .17217 m
.33205 .17432 L
.3294 .18188 L
.32394 .17432 L
F
0 g
.3294 .17217 m
.33205 .17432 L
.3294 .18188 L
.32394 .17432 L
.3294 .17217 L
s
.8 g
.36042 .61814 m
.38258 .63958 L
.38426 .6706 L
.36042 .70058 L
.33147 .6706 L
.33101 .63958 L
F
0 g
.36042 .61814 m
.38258 .63958 L
.38426 .6706 L
.36042 .70058 L
.33147 .6706 L
.33101 .63958 L
.36042 .61814 L
s
.8 g
.36042 .1168 m
.37784 .1433 L
.36042 .15281 L
.34785 .1433 L
F
0 g
.36042 .1168 m
.37784 .1433 L
.36042 .15281 L
.34785 .1433 L
.36042 .1168 L
s
.7 g
.36042 .2951 m
.36205 .29839 L
.36042 .29888 L
.35967 .29839 L
F
0 g
.36042 .2951 m
.36205 .29839 L
.36042 .29888 L
.35967 .29839 L
.36042 .2951 L
s
.2 g
.39144 .78902 m
.42246 .78662 L
.45347 .78861 L
.45488 .79467 L
.45347 .79542 L
.42606 .82568 L
.42246 .82821 L
.399 .82568 L
.39144 .82168 L
.38224 .79467 L
F
0 g
.39144 .78902 m
.42246 .78662 L
.45347 .78861 L
.45488 .79467 L
.45347 .79542 L
.42606 .82568 L
.42246 .82821 L
.399 .82568 L
.39144 .82168 L
.38224 .79467 L
.39144 .78902 L
s
.7 g
.39144 .20074 m
.42018 .20533 L
.39144 .22903 L
.38527 .20533 L
F
0 g
.39144 .20074 m
.42018 .20533 L
.39144 .22903 L
.38527 .20533 L
.39144 .20074 L
s
.7 g
.42246 .25456 m
.43894 .26737 L
.44353 .29839 L
.44766 .3294 L
.42246 .33516 L
.41406 .3294 L
.41454 .29839 L
.40351 .26737 L
F
0 g
.42246 .25456 m
.43894 .26737 L
.44353 .29839 L
.44766 .3294 L
.42246 .33516 L
.41406 .3294 L
.41454 .29839 L
.40351 .26737 L
.42246 .25456 L
s
.7 g
.43249 .01923 m
.43323 .05025 L
.42246 .06648 L
.4052 .05025 L
.41707 .01923 L
F
0 g
.43249 .01923 m
.43323 .05025 L
.42246 .06648 L
.4052 .05025 L
.41707 .01923 L
s
.7 g
.42246 .94915 m
.4238 .94975 L
.42246 .96688 L
.41333 .94975 L
F
0 g
.42246 .94915 m
.4238 .94975 L
.42246 .96688 L
.41333 .94975 L
.42246 .94915 L
s
.5 g
.42246 .49509 m
.42563 .51551 L
.42246 .52008 L
.41848 .51551 L
F
0 g
.42246 .49509 m
.42563 .51551 L
.42246 .52008 L
.41848 .51551 L
.42246 .49509 L
s
.8 g
.45347 .68736 m
.4726 .70161 L
.45347 .71134 L
.42987 .70161 L
F
0 g
.45347 .68736 m
.4726 .70161 L
.45347 .71134 L
.42987 .70161 L
.45347 .68736 L
s
.9 g
.54905 .98077 m
.56455 .94975 L
.57754 .94427 L
.58473 .94975 L
.60856 .96893 L
.62642 .94975 L
.60856 .91981 L
.6075 .91873 L
.60856 .91547 L
.63958 .89872 L
.6706 .90337 L
.6879 .88772 L
.6706 .86454 L
.66292 .8567 L
.6706 .84487 L
.70161 .82895 L
.70572 .82568 L
.7139 .79467 L
.73263 .7856 L
.76365 .77496 L
.76851 .76365 L
.76641 .73263 L
.76951 .70161 L
.79364 .6706 L
.78536 .63958 L
.77652 .60856 L
.76365 .58836 L
.7488 .60856 L
.75208 .63958 L
.74365 .6706 L
.73623 .70161 L
.73263 .70716 L
.71337 .73263 L
.70161 .74028 L
.69301 .76365 L
.67167 .79467 L
.6706 .79544 L
.63958 .82333 L
.63704 .82568 L
.60856 .84878 L
.60044 .8567 L
.57754 .88213 L
.55011 .88772 L
.54653 .8905 L
.51551 .91051 L
.50325 .91873 L
.48449 .94025 L
.46793 .94975 L
.45347 .96652 L
.44056 .98077 L
F
0 g
.54905 .98077 m
.56455 .94975 L
.57754 .94427 L
.58473 .94975 L
.60856 .96893 L
.62642 .94975 L
.60856 .91981 L
.6075 .91873 L
.60856 .91547 L
.63958 .89872 L
.6706 .90337 L
.6879 .88772 L
.6706 .86454 L
.66292 .8567 L
.6706 .84487 L
.70161 .82895 L
.70572 .82568 L
.7139 .79467 L
.73263 .7856 L
.76365 .77496 L
.76851 .76365 L
.76641 .73263 L
.76951 .70161 L
.79364 .6706 L
.78536 .63958 L
.77652 .60856 L
.76365 .58836 L
.7488 .60856 L
.75208 .63958 L
.74365 .6706 L
.73623 .70161 L
.73263 .70716 L
.71337 .73263 L
.70161 .74028 L
.69301 .76365 L
.67167 .79467 L
.6706 .79544 L
.63958 .82333 L
.63704 .82568 L
.60856 .84878 L
.60044 .8567 L
.57754 .88213 L
.55011 .88772 L
.54653 .8905 L
.51551 .91051 L
.50325 .91873 L
.48449 .94025 L
.46793 .94975 L
.45347 .96652 L
.44056 .98077 L
Mistroke
Mfstroke
.9 g
.45347 .69838 m
.45738 .70161 L
.45347 .70331 L
.44821 .70161 L
F
0 g
.45347 .69838 m
.45738 .70161 L
.45347 .70331 L
.44821 .70161 L
.45347 .69838 L
s
.5 g
.45347 .64459 m
.47243 .6706 L
.45347 .67062 L
.44881 .6706 L
F
0 g
.45347 .64459 m
.47243 .6706 L
.45347 .67062 L
.44881 .6706 L
.45347 .64459 L
s
.5 g
.98077 .32944 m
.98074 .3294 L
.94975 .31478 L
.91873 .32716 L
.88772 .32088 L
.873 .3294 L
.8567 .34037 L
.82568 .35121 L
.819 .36042 L
.8066 .39144 L
.79467 .40185 L
.78082 .42246 L
.77179 .45347 L
.76365 .46534 L
.73263 .46569 L
.71775 .48449 L
.70161 .50967 L
.6706 .4891 L
.63958 .48936 L
.60856 .49546 L
.59232 .51551 L
.57754 .52925 L
.56094 .54653 L
.55424 .57754 L
.5583 .60856 L
.54838 .63958 L
.54653 .64139 L
.51551 .65604 L
.48449 .66662 L
.45543 .63958 L
.46062 .60856 L
.46467 .57754 L
.46506 .54653 L
.46915 .51551 L
.46581 .48449 L
.48449 .46852 L
.50864 .45347 L
.51551 .45051 L
.54653 .43847 L
.55977 .42246 L
.57754 .39452 L
.58487 .39144 L
.59291 .36042 L
.59739 .3294 L
.60856 .31483 L
.61999 .29839 L
.60856 .28218 L
.59713 .26737 L
.57754 .24781 L
.54653 .24275 L
.54378 .23635 L
.54319 .20533 L
.54381 .17432 L
.53292 .1433 L
.5235 .11228 L
.51832 .08127 L
.51551 .06931 L
.50826 .05025 L
.50311 .01923 L
.98077 .01923 L
F
0 g
.98077 .32944 m
.98074 .3294 L
.94975 .31478 L
.91873 .32716 L
.88772 .32088 L
.873 .3294 L
.8567 .34037 L
.82568 .35121 L
.819 .36042 L
.8066 .39144 L
.79467 .40185 L
.78082 .42246 L
.77179 .45347 L
.76365 .46534 L
.73263 .46569 L
.71775 .48449 L
.70161 .50967 L
.6706 .4891 L
.63958 .48936 L
.60856 .49546 L
.59232 .51551 L
.57754 .52925 L
.56094 .54653 L
.55424 .57754 L
.5583 .60856 L
.54838 .63958 L
.54653 .64139 L
.51551 .65604 L
.48449 .66662 L
.45543 .63958 L
.46062 .60856 L
.46467 .57754 L
.46506 .54653 L
.46915 .51551 L
.46581 .48449 L
.48449 .46852 L
.50864 .45347 L
.51551 .45051 L
.54653 .43847 L
.55977 .42246 L
.57754 .39452 L
.58487 .39144 L
.59291 .36042 L
.59739 .3294 L
.60856 .31483 L
.61999 .29839 L
.60856 .28218 L
.59713 .26737 L
.57754 .24781 L
.54653 .24275 L
Mistroke
.54378 .23635 L
.54319 .20533 L
.54381 .17432 L
.53292 .1433 L
.5235 .11228 L
.51832 .08127 L
.51551 .06931 L
.50826 .05025 L
.50311 .01923 L
Mfstroke
.3 g
.48449 .73985 m
.48794 .76365 L
.48449 .76634 L
.4569 .76365 L
F
0 g
.48449 .73985 m
.48794 .76365 L
.48449 .76634 L
.4569 .76365 L
.48449 .73985 L
s
.9 g
.60856 .51517 m
.63958 .50816 L
.6706 .51183 L
.67464 .51551 L
.68412 .54653 L
.70073 .57754 L
.70161 .57841 L
.71153 .60856 L
.7032 .63958 L
.70161 .64055 L
.68472 .6706 L
.6706 .70122 L
.67025 .70161 L
.65975 .73263 L
.63958 .76006 L
.63677 .76365 L
.60856 .78509 L
.59597 .79467 L
.57754 .81162 L
.56105 .82568 L
.54653 .83467 L
.5161 .8567 L
.51551 .85736 L
.48449 .88501 L
.46003 .8567 L
.48449 .82778 L
.48641 .82568 L
.51551 .80154 L
.5253 .79467 L
.54126 .76365 L
.54653 .75812 L
.57375 .73263 L
.57754 .72177 L
.58302 .70161 L
.58869 .6706 L
.5938 .63958 L
.57754 .61773 L
.57492 .60856 L
.5714 .57754 L
.57397 .54653 L
.57754 .54299 L
.60274 .54653 L
.60595 .57754 L
.60856 .58827 L
.63639 .60856 L
.63958 .60965 L
.64463 .60856 L
.63958 .60349 L
.62379 .57754 L
.63764 .54653 L
.60856 .5356 L
.60831 .51551 L
F
0 g
.60856 .51517 m
.63958 .50816 L
.6706 .51183 L
.67464 .51551 L
.68412 .54653 L
.70073 .57754 L
.70161 .57841 L
.71153 .60856 L
.7032 .63958 L
.70161 .64055 L
.68472 .6706 L
.6706 .70122 L
.67025 .70161 L
.65975 .73263 L
.63958 .76006 L
.63677 .76365 L
.60856 .78509 L
.59597 .79467 L
.57754 .81162 L
.56105 .82568 L
.54653 .83467 L
.5161 .8567 L
.51551 .85736 L
.48449 .88501 L
.46003 .8567 L
.48449 .82778 L
.48641 .82568 L
.51551 .80154 L
.5253 .79467 L
.54126 .76365 L
.54653 .75812 L
.57375 .73263 L
.57754 .72177 L
.58302 .70161 L
.58869 .6706 L
.5938 .63958 L
.57754 .61773 L
.57492 .60856 L
.5714 .57754 L
.57397 .54653 L
.57754 .54299 L
.60274 .54653 L
.60595 .57754 L
.60856 .58827 L
.63639 .60856 L
.63958 .60965 L
.64463 .60856 L
.63958 .60349 L
.62379 .57754 L
.63764 .54653 L
Mistroke
.60856 .5356 L
.60831 .51551 L
.60856 .51517 L
Mfstroke
.4 g
.58785 .01923 m
.58798 .05025 L
.57754 .06868 L
.56386 .08127 L
.55378 .11228 L
.57754 .14128 L
.58049 .1433 L
.60856 .17153 L
.61172 .17432 L
.63958 .20023 L
.64602 .20533 L
.6706 .22241 L
.68381 .23635 L
.69634 .26737 L
.70161 .27428 L
.71247 .29839 L
.73263 .31457 L
.76365 .31475 L
.79289 .29839 L
.79467 .29501 L
.79757 .29839 L
.81821 .3294 L
.79467 .35951 L
.79268 .36042 L
.7874 .39144 L
.76365 .41926 L
.75585 .42246 L
.73263 .45341 L
.73258 .45347 L
.70751 .48449 L
.70161 .49363 L
.68085 .48449 L
.6706 .47834 L
.63958 .48194 L
.63324 .48449 L
.60856 .48924 L
.5948 .48449 L
.57754 .47522 L
.55145 .48449 L
.57754 .49478 L
.58708 .51551 L
.57754 .52452 L
.55676 .54653 L
.54837 .57754 L
.55286 .60856 L
.54653 .6289 L
.53834 .63958 L
.51551 .65036 L
.48449 .65006 L
.47365 .63958 L
.47654 .60856 L
.4726 .57754 L
.47212 .54653 L
.47958 .51551 L
.47944 .48449 L
.48449 .4799 L
.51551 .46187 L
.53118 .45347 L
.54653 .44693 L
.56609 .42246 L
.57754 .39871 L
.5921 .39144 L
.59737 .36042 L
.60307 .3294 L
.60856 .3226 L
.62726 .29839 L
.60856 .27419 L
.60318 .26737 L
.57754 .24119 L
.55606 .23635 L
.56577 .20533 L
.55323 .17432 L
.54952 .1433 L
.54653 .1346 L
.53545 .11228 L
.52832 .08127 L
.51767 .05025 L
.51551 .04655 L
.51002 .01923 L
F
0 g
.58785 .01923 m
.58798 .05025 L
.57754 .06868 L
.56386 .08127 L
.55378 .11228 L
.57754 .14128 L
.58049 .1433 L
.60856 .17153 L
.61172 .17432 L
.63958 .20023 L
.64602 .20533 L
.6706 .22241 L
.68381 .23635 L
.69634 .26737 L
.70161 .27428 L
.71247 .29839 L
.73263 .31457 L
.76365 .31475 L
.79289 .29839 L
.79467 .29501 L
.79757 .29839 L
.81821 .3294 L
.79467 .35951 L
.79268 .36042 L
.7874 .39144 L
.76365 .41926 L
.75585 .42246 L
.73263 .45341 L
.73258 .45347 L
.70751 .48449 L
.70161 .49363 L
.68085 .48449 L
.6706 .47834 L
.63958 .48194 L
.63324 .48449 L
.60856 .48924 L
.5948 .48449 L
.57754 .47522 L
.55145 .48449 L
.57754 .49478 L
.58708 .51551 L
.57754 .52452 L
.55676 .54653 L
.54837 .57754 L
.55286 .60856 L
.54653 .6289 L
.53834 .63958 L
.51551 .65036 L
.48449 .65006 L
.47365 .63958 L
Mistroke
.47654 .60856 L
.4726 .57754 L
.47212 .54653 L
.47958 .51551 L
.47944 .48449 L
.48449 .4799 L
.51551 .46187 L
.53118 .45347 L
.54653 .44693 L
.56609 .42246 L
.57754 .39871 L
.5921 .39144 L
.59737 .36042 L
.60307 .3294 L
.60856 .3226 L
.62726 .29839 L
.60856 .27419 L
.60318 .26737 L
.57754 .24119 L
.55606 .23635 L
.56577 .20533 L
.55323 .17432 L
.54952 .1433 L
.54653 .1346 L
.53545 .11228 L
.52832 .08127 L
.51767 .05025 L
.51551 .04655 L
.51002 .01923 L
Mfstroke
.6 g
.48449 .37254 m
.49276 .39144 L
.48449 .40457 L
.47635 .39144 L
F
0 g
.48449 .37254 m
.49276 .39144 L
.48449 .40457 L
.47635 .39144 L
.48449 .37254 L
s
1 g
.48449 .84865 m
.49453 .8567 L
.48449 .86291 L
.47917 .8567 L
F
0 g
.48449 .84865 m
.49453 .8567 L
.48449 .86291 L
.47917 .8567 L
.48449 .84865 L
s
.9 g
.48449 .23512 m
.49153 .23635 L
.48449 .2623 L
.47948 .23635 L
F
0 g
.48449 .23512 m
.49153 .23635 L
.48449 .2623 L
.47948 .23635 L
.48449 .23512 L
s
.3 g
.51551 .48467 m
.54653 .51409 L
.57754 .50511 L
.58135 .51551 L
.57754 .5192 L
.55235 .54653 L
.54653 .5657 L
.53353 .57754 L
.54653 .60511 L
.54686 .60856 L
.54653 .61023 L
.52734 .63958 L
.51551 .64449 L
.4922 .63958 L
.49717 .60856 L
.48449 .58858 L
.48111 .57754 L
.47955 .54653 L
.48449 .5299 L
.49304 .51551 L
F
0 g
.51551 .48467 m
.54653 .51409 L
.57754 .50511 L
.58135 .51551 L
.57754 .5192 L
.55235 .54653 L
.54653 .5657 L
.53353 .57754 L
.54653 .60511 L
.54686 .60856 L
.54653 .61023 L
.52734 .63958 L
.51551 .64449 L
.4922 .63958 L
.49717 .60856 L
.48449 .58858 L
.48111 .57754 L
.47955 .54653 L
.48449 .5299 L
.49304 .51551 L
.51551 .48467 L
s
.6 g
.51551 .34066 m
.51883 .36042 L
.51551 .36453 L
.49591 .36042 L
F
0 g
.51551 .34066 m
.51883 .36042 L
.51551 .36453 L
.49591 .36042 L
.51551 .34066 L
s
.7 g
.51551 .87519 m
.52691 .88772 L
.51551 .8953 L
.50242 .88772 L
F
0 g
.51551 .87519 m
.52691 .88772 L
.51551 .8953 L
.50242 .88772 L
.51551 .87519 L
s
1 g
.51551 .81696 m
.54277 .82568 L
.51551 .83864 L
.50458 .82568 L
F
0 g
.51551 .81696 m
.54277 .82568 L
.51551 .83864 L
.50458 .82568 L
.51551 .81696 L
s
.9 g
.51551 .39903 m
.53084 .42246 L
.51551 .42497 L
.51006 .42246 L
F
0 g
.51551 .39903 m
.53084 .42246 L
.51551 .42497 L
.51006 .42246 L
.51551 .39903 L
s
.3 g
.58235 .01923 m
.58136 .05025 L
.57754 .05722 L
.55098 .08127 L
.54653 .09131 L
.54132 .08127 L
.53076 .05025 L
.51796 .01923 L
F
0 g
.58235 .01923 m
.58136 .05025 L
.57754 .05722 L
.55098 .08127 L
.54653 .09131 L
.54132 .08127 L
.53076 .05025 L
.51796 .01923 L
s
.9 g
.54653 .36144 m
.5539 .39144 L
.54653 .40469 L
.52336 .39144 L
F
0 g
.54653 .36144 m
.5539 .39144 L
.54653 .40469 L
.52336 .39144 L
.54653 .36144 L
s
.2 g
.54653 .53744 m
.54742 .54653 L
.54653 .54996 L
.52957 .54653 L
F
0 g
.54653 .53744 m
.54742 .54653 L
.54653 .54996 L
.52957 .54653 L
.54653 .53744 L
s
.7 g
.54653 .8446 m
.57754 .82686 L
.58309 .8567 L
.57754 .86362 L
.54653 .87517 L
.5301 .8567 L
F
0 g
.54653 .8446 m
.57754 .82686 L
.58309 .8567 L
.57754 .86362 L
.54653 .87517 L
.5301 .8567 L
.54653 .8446 L
s
.2 g
.57533 .01923 m
.54653 .04439 L
.53041 .01923 L
F
0 g
.57533 .01923 m
.54653 .04439 L
.53041 .01923 L
s
.9 g
.57754 .31371 m
.57994 .3294 L
.57876 .36042 L
.57754 .36507 L
.5468 .36042 L
.54791 .3294 L
F
0 g
.57754 .31371 m
.57994 .3294 L
.57876 .36042 L
.57754 .36507 L
.5468 .36042 L
.54791 .3294 L
.57754 .31371 L
s
1 g
.57754 .76732 m
.57949 .79467 L
.57754 .79644 L
.54937 .79467 L
F
0 g
.57754 .76732 m
.57949 .79467 L
.57754 .79644 L
.54937 .79467 L
.57754 .76732 L
s
.3 g
.60856 .18433 m
.63386 .20533 L
.63958 .21379 L
.6706 .23118 L
.67545 .23635 L
.68348 .26737 L
.70161 .29003 L
.70505 .29839 L
.73263 .32014 L
.76365 .32015 L
.79467 .31202 L
.80528 .3294 L
.79467 .34524 L
.76365 .35824 L
.761 .36042 L
.76365 .36311 L
.77823 .39144 L
.76365 .4093 L
.73263 .42153 L
.73137 .42246 L
.7153 .45347 L
.70161 .47233 L
.6706 .45501 L
.63958 .46802 L
.60856 .47961 L
.57754 .467 L
.55149 .45347 L
.57278 .42246 L
.57754 .40955 L
.59972 .39144 L
.60205 .36042 L
.60856 .33113 L
.61033 .3294 L
.63523 .29839 L
.61169 .26737 L
.60856 .26165 L
.59543 .23635 L
.58566 .20533 L
F
0 g
.60856 .18433 m
.63386 .20533 L
.63958 .21379 L
.6706 .23118 L
.67545 .23635 L
.68348 .26737 L
.70161 .29003 L
.70505 .29839 L
.73263 .32014 L
.76365 .32015 L
.79467 .31202 L
.80528 .3294 L
.79467 .34524 L
.76365 .35824 L
.761 .36042 L
.76365 .36311 L
.77823 .39144 L
.76365 .4093 L
.73263 .42153 L
.73137 .42246 L
.7153 .45347 L
.70161 .47233 L
.6706 .45501 L
.63958 .46802 L
.60856 .47961 L
.57754 .467 L
.55149 .45347 L
.57278 .42246 L
.57754 .40955 L
.59972 .39144 L
.60205 .36042 L
.60856 .33113 L
.61033 .3294 L
.63523 .29839 L
.61169 .26737 L
.60856 .26165 L
.59543 .23635 L
.58566 .20533 L
.60856 .18433 L
s
.6 g
.98077 .31472 m
.96362 .29839 L
.94975 .283 L
.92712 .26737 L
.92725 .23635 L
.91873 .23613 L
.91854 .23635 L
.89125 .26737 L
.88772 .26825 L
.8567 .2748 L
.84843 .29839 L
.82568 .31611 L
.81212 .29839 L
.80211 .26737 L
.80599 .23635 L
.7998 .20533 L
.79467 .20007 L
.77582 .20533 L
.78421 .23635 L
.78311 .26737 L
.78178 .29839 L
.76365 .30951 L
.73263 .30911 L
.7193 .29839 L
.70643 .26737 L
.70161 .25898 L
.69217 .23635 L
.6706 .21384 L
.65735 .20533 L
.63958 .19679 L
.62419 .17432 L
.60856 .15942 L
.59414 .1433 L
.57754 .13039 L
.56385 .11228 L
.5759 .08127 L
.57754 .0799 L
.58308 .08127 L
.60856 .0959 L
.61818 .08127 L
.60856 .07091 L
.59426 .05025 L
.59325 .01923 L
.98077 .01923 L
F
0 g
.98077 .31472 m
.96362 .29839 L
.94975 .283 L
.92712 .26737 L
.92725 .23635 L
.91873 .23613 L
.91854 .23635 L
.89125 .26737 L
.88772 .26825 L
.8567 .2748 L
.84843 .29839 L
.82568 .31611 L
.81212 .29839 L
.80211 .26737 L
.80599 .23635 L
.7998 .20533 L
.79467 .20007 L
.77582 .20533 L
.78421 .23635 L
.78311 .26737 L
.78178 .29839 L
.76365 .30951 L
.73263 .30911 L
.7193 .29839 L
.70643 .26737 L
.70161 .25898 L
.69217 .23635 L
.6706 .21384 L
.65735 .20533 L
.63958 .19679 L
.62419 .17432 L
.60856 .15942 L
.59414 .1433 L
.57754 .13039 L
.56385 .11228 L
.5759 .08127 L
.57754 .0799 L
.58308 .08127 L
.60856 .0959 L
.61818 .08127 L
.60856 .07091 L
.59426 .05025 L
.59325 .01923 L
s
.2 g
.57754 .42726 m
.59795 .45347 L
.57754 .45885 L
.56592 .45347 L
F
0 g
.57754 .42726 m
.59795 .45347 L
.57754 .45885 L
.56592 .45347 L
.57754 .42726 L
s
.7 g
.60374 .98077 m
.57754 .97609 L
.57209 .98077 L
F
0 g
.60374 .98077 m
.57754 .97609 L
.57209 .98077 L
s
.7 g
.98077 .13156 m
.97266 .1433 L
.95555 .17432 L
.94975 .18712 L
.91873 .19687 L
.90768 .17432 L
.88772 .14753 L
.88158 .1433 L
.8667 .11228 L
.8567 .09982 L
.84634 .11228 L
.84436 .1433 L
.8567 .16053 L
.86673 .17432 L
.88772 .20422 L
.89036 .20533 L
.88772 .22136 L
.87721 .23635 L
.8567 .25215 L
.8476 .26737 L
.82568 .29822 L
.81299 .26737 L
.81539 .23635 L
.81345 .20533 L
.79467 .18289 L
.76365 .1939 L
.74986 .17432 L
.76365 .15084 L
.78913 .1433 L
.77717 .11228 L
.77739 .08127 L
.76365 .07068 L
.74062 .08127 L
.74884 .11228 L
.73263 .12856 L
.72448 .11228 L
.72834 .08127 L
.71431 .05025 L
.70161 .03538 L
.68566 .05025 L
.67276 .08127 L
.67384 .11228 L
.67983 .1433 L
.6706 .17198 L
.66881 .17432 L
.63958 .17833 L
.63775 .17432 L
.60856 .14525 L
.60701 .1433 L
.57754 .11866 L
.57331 .11228 L
.57754 .095 L
.60856 .10907 L
.62893 .08127 L
.60856 .06082 L
.60075 .05025 L
.59891 .01923 L
.98077 .01923 L
F
0 g
.98077 .13156 m
.97266 .1433 L
.95555 .17432 L
.94975 .18712 L
.91873 .19687 L
.90768 .17432 L
.88772 .14753 L
.88158 .1433 L
.8667 .11228 L
.8567 .09982 L
.84634 .11228 L
.84436 .1433 L
.8567 .16053 L
.86673 .17432 L
.88772 .20422 L
.89036 .20533 L
.88772 .22136 L
.87721 .23635 L
.8567 .25215 L
.8476 .26737 L
.82568 .29822 L
.81299 .26737 L
.81539 .23635 L
.81345 .20533 L
.79467 .18289 L
.76365 .1939 L
.74986 .17432 L
.76365 .15084 L
.78913 .1433 L
.77717 .11228 L
.77739 .08127 L
.76365 .07068 L
.74062 .08127 L
.74884 .11228 L
.73263 .12856 L
.72448 .11228 L
.72834 .08127 L
.71431 .05025 L
.70161 .03538 L
.68566 .05025 L
.67276 .08127 L
.67384 .11228 L
.67983 .1433 L
.6706 .17198 L
.66881 .17432 L
.63958 .17833 L
.63775 .17432 L
.60856 .14525 L
.60701 .1433 L
.57754 .11866 L
Mistroke
.57331 .11228 L
.57754 .095 L
.60856 .10907 L
.62893 .08127 L
.60856 .06082 L
.60075 .05025 L
.59891 .01923 L
Mfstroke
.7 g
.60856 .80012 m
.61394 .82568 L
.60856 .83011 L
.579 .82568 L
F
0 g
.60856 .80012 m
.61394 .82568 L
.60856 .83011 L
.579 .82568 L
.60856 .80012 L
s
1 g
.63958 .66547 m
.6706 .65985 L
.67336 .6706 L
.6706 .67825 L
.64926 .70161 L
.64565 .73263 L
.63958 .74155 L
.6224 .76365 L
.60856 .77357 L
.5797 .76365 L
.59264 .73263 L
.60411 .70161 L
.60856 .68853 L
.62684 .6706 L
F
0 g
.63958 .66547 m
.6706 .65985 L
.67336 .6706 L
.6706 .67825 L
.64926 .70161 L
.64565 .73263 L
.63958 .74155 L
.6224 .76365 L
.60856 .77357 L
.5797 .76365 L
.59264 .73263 L
.60411 .70161 L
.60856 .68853 L
.62684 .6706 L
.63958 .66547 L
s
.2 g
.60856 .35096 m
.63139 .36042 L
.63958 .38148 L
.66975 .39144 L
.6706 .39182 L
.70161 .41102 L
.71161 .42246 L
.70161 .44337 L
.6706 .43524 L
.63958 .44329 L
.60856 .43805 L
.5844 .42246 L
.60856 .39277 L
.60881 .39144 L
.60856 .39026 L
.60727 .36042 L
F
0 g
.60856 .35096 m
.63139 .36042 L
.63958 .38148 L
.66975 .39144 L
.6706 .39182 L
.70161 .41102 L
.71161 .42246 L
.70161 .44337 L
.6706 .43524 L
.63958 .44329 L
.60856 .43805 L
.5844 .42246 L
.60856 .39277 L
.60881 .39144 L
.60856 .39026 L
.60727 .36042 L
.60856 .35096 L
s
.2 g
.60856 .2021 m
.61411 .20533 L
.60856 .21314 L
.60471 .20533 L
F
0 g
.60856 .2021 m
.61411 .20533 L
.60856 .21314 L
.60471 .20533 L
.60856 .2021 L
s
.8 g
.61999 .01923 m
.63025 .05025 L
.60856 .05075 L
.60817 .05025 L
.60541 .01923 L
F
0 g
.61999 .01923 m
.63025 .05025 L
.60856 .05075 L
.60817 .05025 L
.60541 .01923 L
s
.7 g
.63958 .78505 m
.64411 .79467 L
.63958 .79956 L
.61603 .79467 L
F
0 g
.63958 .78505 m
.64411 .79467 L
.63958 .79956 L
.61603 .79467 L
.63958 .78505 L
s
.6 g
.65747 .01923 m
.63958 .02837 L
.63319 .01923 L
F
0 g
.65747 .01923 m
.63958 .02837 L
.63319 .01923 L
s
.4 g
.6706 .30357 m
.69635 .3294 L
.67732 .36042 L
.6706 .3672 L
.65534 .36042 L
.65471 .3294 L
F
0 g
.6706 .30357 m
.69635 .3294 L
.67732 .36042 L
.6706 .3672 L
.65534 .36042 L
.65471 .3294 L
.6706 .30357 L
s
.7 g
.6706 .745 m
.67632 .76365 L
.6706 .77146 L
.65649 .76365 L
F
0 g
.6706 .745 m
.67632 .76365 L
.6706 .77146 L
.65649 .76365 L
.6706 .745 L
s
.5 g
.70161 .06844 m
.70701 .08127 L
.71238 .11228 L
.72601 .1433 L
.73263 .1518 L
.73734 .17432 L
.73263 .17925 L
.70556 .20533 L
.73263 .23271 L
.73526 .23635 L
.73263 .23939 L
.72718 .23635 L
.70161 .2102 L
.6939 .20533 L
.68446 .17432 L
.69032 .1433 L
.68755 .11228 L
.69447 .08127 L
F
0 g
.70161 .06844 m
.70701 .08127 L
.71238 .11228 L
.72601 .1433 L
.73263 .1518 L
.73734 .17432 L
.73263 .17925 L
.70556 .20533 L
.73263 .23271 L
.73526 .23635 L
.73263 .23939 L
.72718 .23635 L
.70161 .2102 L
.6939 .20533 L
.68446 .17432 L
.69032 .1433 L
.68755 .11228 L
.69447 .08127 L
.70161 .06844 L
s
.7 g
.70161 .66177 m
.71914 .6706 L
.71297 .70161 L
.70161 .7132 L
.68935 .70161 L
.69629 .6706 L
F
0 g
.70161 .66177 m
.71914 .6706 L
.71297 .70161 L
.70161 .7132 L
.68935 .70161 L
.69629 .6706 L
.70161 .66177 L
s
.7 g
.98077 .61247 m
.94975 .61611 L
.91873 .623 L
.90829 .60856 L
.88772 .59013 L
.86429 .57754 L
.8567 .57096 L
.82568 .57143 L
.79467 .57531 L
.7943 .57754 L
.79128 .60856 L
.79467 .61807 L
.81233 .63958 L
.82568 .64979 L
.84434 .6706 L
.82568 .68673 L
.79897 .70161 L
.79467 .70662 L
.78072 .73263 L
.78121 .76365 L
.77298 .79467 L
.76365 .80128 L
.74889 .82568 L
.73954 .8567 L
.75138 .88772 L
.73263 .90915 L
.71472 .91873 L
.70161 .93119 L
.6926 .94975 L
.70161 .97453 L
.71294 .98077 L
.98077 .98077 L
F
0 g
.98077 .61247 m
.94975 .61611 L
.91873 .623 L
.90829 .60856 L
.88772 .59013 L
.86429 .57754 L
.8567 .57096 L
.82568 .57143 L
.79467 .57531 L
.7943 .57754 L
.79128 .60856 L
.79467 .61807 L
.81233 .63958 L
.82568 .64979 L
.84434 .6706 L
.82568 .68673 L
.79897 .70161 L
.79467 .70662 L
.78072 .73263 L
.78121 .76365 L
.77298 .79467 L
.76365 .80128 L
.74889 .82568 L
.73954 .8567 L
.75138 .88772 L
.73263 .90915 L
.71472 .91873 L
.70161 .93119 L
.6926 .94975 L
.70161 .97453 L
.71294 .98077 L
s
.8 g
.80997 .01923 m
.82568 .02506 L
.85324 .05025 L
.82568 .07803 L
.79467 .07688 L
.76365 .05368 L
.73263 .05419 L
.73073 .05025 L
.70161 .01981 L
.69489 .01923 L
F
0 g
.80997 .01923 m
.82568 .02506 L
.85324 .05025 L
.82568 .07803 L
.79467 .07688 L
.76365 .05368 L
.73263 .05419 L
.73073 .05025 L
.70161 .01981 L
.69489 .01923 L
s
.2 g
.73263 .32624 m
.76365 .32617 L
.78967 .3294 L
.76365 .34332 L
.739 .36042 L
.76365 .37965 L
.76897 .39144 L
.76365 .39873 L
.73263 .40826 L
.7147 .39144 L
.70161 .3671 L
.69797 .36042 L
.70161 .35372 L
.72061 .3294 L
F
0 g
.73263 .32624 m
.76365 .32617 L
.78967 .3294 L
.76365 .34332 L
.739 .36042 L
.76365 .37965 L
.76897 .39144 L
.76365 .39873 L
.73263 .40826 L
.7147 .39144 L
.70161 .3671 L
.69797 .36042 L
.70161 .35372 L
.72061 .3294 L
.73263 .32624 L
s
.4 g
.70161 .15497 m
.71589 .17432 L
.70161 .1779 L
.70041 .17432 L
F
0 g
.70161 .15497 m
.71589 .17432 L
.70161 .1779 L
.70041 .17432 L
.70161 .15497 L
s
.7 g
.76722 .01923 m
.76365 .02089 L
.73263 .02302 L
.7115 .01923 L
F
0 g
.76722 .01923 m
.76365 .02089 L
.73263 .02302 L
.7115 .01923 L
s
.7 g
.73263 .19133 m
.7556 .20533 L
.76365 .2166 L
.77492 .23635 L
.77003 .26737 L
.77268 .29839 L
.76365 .30407 L
.73263 .30345 L
.72627 .29839 L
.71561 .26737 L
.73263 .25137 L
.74757 .23635 L
.73263 .21902 L
.71884 .20533 L
F
0 g
.73263 .19133 m
.7556 .20533 L
.76365 .2166 L
.77492 .23635 L
.77003 .26737 L
.77268 .29839 L
.76365 .30407 L
.73263 .30345 L
.72627 .29839 L
.71561 .26737 L
.73263 .25137 L
.74757 .23635 L
.73263 .21902 L
.71884 .20533 L
.73263 .19133 L
s
.6 g
.93132 .98077 m
.91873 .96263 L
.91289 .94975 L
.89542 .91873 L
.88772 .91127 L
.8567 .9148 L
.85305 .88772 L
.84966 .8567 L
.85007 .82568 L
.8567 .8017 L
.85776 .79467 L
.8567 .78826 L
.84668 .76365 L
.8567 .74849 L
.86285 .73263 L
.8567 .7052 L
.8528 .70161 L
.82568 .69869 L
.81913 .70161 L
.79467 .73052 L
.79377 .73263 L
.79455 .76365 L
.79467 .76433 L
.7991 .79467 L
.79467 .80635 L
.77204 .82568 L
.76365 .8346 L
.75812 .8567 L
.76365 .87338 L
.78655 .88772 L
.78168 .91873 L
.76365 .93758 L
.73263 .93584 L
.72172 .94975 L
.73263 .96924 L
.76365 .96245 L
.79467 .96614 L
.82568 .94985 L
.85148 .98077 L
F
0 g
.93132 .98077 m
.91873 .96263 L
.91289 .94975 L
.89542 .91873 L
.88772 .91127 L
.8567 .9148 L
.85305 .88772 L
.84966 .8567 L
.85007 .82568 L
.8567 .8017 L
.85776 .79467 L
.8567 .78826 L
.84668 .76365 L
.8567 .74849 L
.86285 .73263 L
.8567 .7052 L
.8528 .70161 L
.82568 .69869 L
.81913 .70161 L
.79467 .73052 L
.79377 .73263 L
.79455 .76365 L
.79467 .76433 L
.7991 .79467 L
.79467 .80635 L
.77204 .82568 L
.76365 .8346 L
.75812 .8567 L
.76365 .87338 L
.78655 .88772 L
.78168 .91873 L
.76365 .93758 L
.73263 .93584 L
.72172 .94975 L
.73263 .96924 L
.76365 .96245 L
.79467 .96614 L
.82568 .94985 L
.85148 .98077 L
s
.8 g
.73263 .26189 m
.75525 .26737 L
.73263 .29611 L
.72617 .26737 L
F
0 g
.73263 .26189 m
.75525 .26737 L
.73263 .29611 L
.72617 .26737 L
.73263 .26189 L
s
.1 g
.73263 .38627 m
.75221 .39144 L
.73263 .39236 L
.73175 .39144 L
F
0 g
.73263 .38627 m
.75221 .39144 L
.73263 .39236 L
.73175 .39144 L
.73263 .38627 L
s
.8 g
.78652 .98077 m
.76365 .97492 L
.74342 .98077 L
F
0 g
.78652 .98077 m
.76365 .97492 L
.74342 .98077 L
s
.9 g
.76365 .53616 m
.77533 .54653 L
.76365 .56488 L
.75549 .54653 L
F
0 g
.76365 .53616 m
.77533 .54653 L
.76365 .56488 L
.75549 .54653 L
.76365 .53616 L
s
.8 g
.76365 .23531 m
.76428 .23635 L
.76365 .24331 L
.76242 .23635 L
F
0 g
.76365 .23531 m
.76428 .23635 L
.76365 .24331 L
.76242 .23635 L
.76365 .23531 L
s
.5 g
.82568 .79238 m
.83123 .79467 L
.82579 .82568 L
.82903 .8567 L
.82568 .86326 L
.79467 .86428 L
.78178 .8567 L
.79467 .84109 L
.81817 .82568 L
.82288 .79467 L
F
0 g
.82568 .79238 m
.83123 .79467 L
.82579 .82568 L
.82903 .8567 L
.82568 .86326 L
.79467 .86428 L
.78178 .8567 L
.79467 .84109 L
.81817 .82568 L
.82288 .79467 L
.82568 .79238 L
s
.8 g
.79467 .10253 m
.82568 .08917 L
.83452 .11228 L
.83342 .1433 L
.82568 .17355 L
.8096 .1433 L
.79467 .11406 L
.79387 .11228 L
F
0 g
.79467 .10253 m
.82568 .08917 L
.83452 .11228 L
.83342 .1433 L
.82568 .17355 L
.8096 .1433 L
.79467 .11406 L
.79387 .11228 L
.79467 .10253 L
s
.9 g
.82568 .03683 m
.83111 .05025 L
.82568 .05625 L
.79836 .05025 L
F
0 g
.82568 .03683 m
.83111 .05025 L
.82568 .05625 L
.79836 .05025 L
.82568 .03683 L
s
.5 g
.9195 .98077 m
.91873 .97959 L
.88772 .955 L
.88616 .94975 L
.8567 .939 L
.84274 .91873 L
.82568 .89385 L
.80025 .91873 L
.82568 .93672 L
.84801 .94975 L
.8567 .97253 L
.86593 .98077 L
F
0 g
.9195 .98077 m
.91873 .97959 L
.88772 .955 L
.88616 .94975 L
.8567 .939 L
.84274 .91873 L
.82568 .89385 L
.80025 .91873 L
.82568 .93672 L
.84801 .94975 L
.8567 .97253 L
.86593 .98077 L
s
.6 g
.82568 .57865 m
.8567 .59618 L
.88772 .60326 L
.89369 .60856 L
.91037 .63958 L
.91873 .64297 L
.93955 .6706 L
.91873 .6848 L
.89607 .70161 L
.88772 .7068 L
.8602 .70161 L
.85889 .6706 L
.8567 .6639 L
.83306 .63958 L
.82568 .63398 L
.80692 .60856 L
F
0 g
.82568 .57865 m
.8567 .59618 L
.88772 .60326 L
.89369 .60856 L
.91037 .63958 L
.91873 .64297 L
.93955 .6706 L
.91873 .6848 L
.89607 .70161 L
.88772 .7068 L
.8602 .70161 L
.85889 .6706 L
.8567 .6639 L
.83306 .63958 L
.82568 .63398 L
.80692 .60856 L
.82568 .57865 L
s
.5 g
.82568 .71624 m
.84181 .73263 L
.82568 .74525 L
.81135 .73263 L
F
0 g
.82568 .71624 m
.84181 .73263 L
.82568 .74525 L
.81135 .73263 L
.82568 .71624 L
s
.8 g
.82764 .98077 m
.82568 .96755 L
.81849 .98077 L
F
0 g
.82764 .98077 m
.82568 .96755 L
.81849 .98077 L
s
.4 g
.82568 .91605 m
.82696 .91873 L
.82568 .92023 L
.82203 .91873 L
F
0 g
.82568 .91605 m
.82696 .91873 L
.82568 .92023 L
.82203 .91873 L
.82568 .91605 L
s
.8 g
.82568 .22857 m
.84195 .23635 L
.82804 .26737 L
.82568 .26953 L
.82497 .26737 L
.82517 .23635 L
F
0 g
.82568 .22857 m
.84195 .23635 L
.82804 .26737 L
.82568 .26953 L
.82497 .26737 L
.82517 .23635 L
.82568 .22857 L
s
.5 g
.8567 .12516 m
.85693 .1433 L
.88772 .16362 L
.89516 .17432 L
.88772 .18528 L
.87961 .17432 L
.8567 .14336 L
.85666 .1433 L
F
0 g
.8567 .12516 m
.85693 .1433 L
.88772 .16362 L
.89516 .17432 L
.88772 .18528 L
.87961 .17432 L
.8567 .14336 L
.85666 .1433 L
.8567 .12516 L
s
.8 g
.98077 .93461 m
.97284 .91873 L
.94975 .89183 L
.94664 .88772 L
.91873 .86564 L
.90785 .8567 L
.89794 .82568 L
.89637 .79467 L
.89894 .76365 L
.91772 .73263 L
.88772 .73108 L
.88622 .73263 L
.86864 .76365 L
.87446 .79467 L
.86864 .82568 L
.86534 .8567 L
.86881 .88772 L
.88772 .90096 L
.90537 .91873 L
.91873 .94666 L
.9235 .94975 L
.94373 .98077 L
.98077 .98077 L
F
0 g
.98077 .93461 m
.97284 .91873 L
.94975 .89183 L
.94664 .88772 L
.91873 .86564 L
.90785 .8567 L
.89794 .82568 L
.89637 .79467 L
.89894 .76365 L
.91772 .73263 L
.88772 .73108 L
.88622 .73263 L
.86864 .76365 L
.87446 .79467 L
.86864 .82568 L
.86534 .8567 L
.86881 .88772 L
.88772 .90096 L
.90537 .91873 L
.91873 .94666 L
.9235 .94975 L
.94373 .98077 L
s
.4 g
.88772 .28373 m
.91873 .28219 L
.93619 .29839 L
.91873 .31261 L
.88772 .30875 L
.86805 .29839 L
F
0 g
.88772 .28373 m
.91873 .28219 L
.93619 .29839 L
.91873 .31261 L
.88772 .30875 L
.86805 .29839 L
.88772 .28373 L
s
.6 g
.88772 .0267 m
.91873 .02715 L
.92587 .05025 L
.91873 .05582 L
.88772 .06849 L
.87003 .05025 L
F
0 g
.88772 .0267 m
.91873 .02715 L
.92587 .05025 L
.91873 .05582 L
.88772 .06849 L
.87003 .05025 L
.88772 .0267 L
s
.8 g
.98077 .40966 m
.94975 .39847 L
.94046 .39144 L
.91873 .37736 L
.88772 .36661 L
.87181 .36042 L
.88772 .35271 L
.91873 .35345 L
.94975 .34342 L
.98077 .35079 L
F
0 g
.98077 .40966 m
.94975 .39847 L
.94046 .39144 L
.91873 .37736 L
.88772 .36661 L
.87181 .36042 L
.88772 .35271 L
.91873 .35345 L
.94975 .34342 L
.98077 .35079 L
s
.5 g
.88772 .64871 m
.91385 .6706 L
.88772 .68967 L
.87261 .6706 L
F
0 g
.88772 .64871 m
.91385 .6706 L
.88772 .68967 L
.87261 .6706 L
.88772 .64871 L
s
.8 g
.88772 .08589 m
.89495 .11228 L
.88772 .12896 L
.8792 .11228 L
F
0 g
.88772 .08589 m
.89495 .11228 L
.88772 .12896 L
.8792 .11228 L
.88772 .08589 L
s
.4 g
.90209 .98077 m
.88772 .97759 L
.88101 .98077 L
F
0 g
.90209 .98077 m
.88772 .97759 L
.88101 .98077 L
s
.6 g
.88772 .47048 m
.91081 .48449 L
.88772 .49007 L
.88371 .48449 L
F
0 g
.88772 .47048 m
.91081 .48449 L
.88772 .49007 L
.88371 .48449 L
.88772 .47048 L
s
.9 g
.88772 .85073 m
.8892 .8567 L
.91397 .88772 L
.91873 .89169 L
.94975 .91172 L
.95507 .91873 L
.94975 .93556 L
.91873 .9272 L
.91553 .91873 L
.88772 .8898 L
.88451 .88772 L
.88567 .8567 L
F
0 g
.88772 .85073 m
.8892 .8567 L
.91397 .88772 L
.91873 .89169 L
.94975 .91172 L
.95507 .91873 L
.94975 .93556 L
.91873 .9272 L
.91553 .91873 L
.88772 .8898 L
.88451 .88772 L
.88567 .8567 L
.88772 .85073 L
s
.8 g
.91919 .01923 m
.91873 .0195 L
.88824 .01923 L
F
0 g
.91919 .01923 m
.91873 .0195 L
.88824 .01923 L
s
.8 g
.91873 .07125 m
.94365 .08127 L
.91873 .08818 L
.89605 .08127 L
F
0 g
.91873 .07125 m
.94365 .08127 L
.91873 .08818 L
.89605 .08127 L
.91873 .07125 L
s
.6 g
.91873 .09965 m
.93877 .11228 L
.92633 .1433 L
.91873 .15068 L
.90167 .1433 L
.9058 .11228 L
F
0 g
.91873 .09965 m
.93877 .11228 L
.92633 .1433 L
.91873 .15068 L
.90167 .1433 L
.9058 .11228 L
.91873 .09965 L
s
.6 g
.98077 .88608 m
.94975 .87619 L
.92393 .8567 L
.91873 .8493 L
.91211 .82568 L
.91054 .79467 L
.9109 .76365 L
.91873 .7516 L
.94975 .7528 L
.95461 .76365 L
.95283 .79467 L
.98077 .82565 L
F
0 g
.98077 .88608 m
.94975 .87619 L
.92393 .8567 L
.91873 .8493 L
.91211 .82568 L
.91054 .79467 L
.9109 .76365 L
.91873 .7516 L
.94975 .7528 L
.95461 .76365 L
.95283 .79467 L
.98077 .82565 L
s
.8 g
.98077 .81253 m
.97269 .79467 L
.96973 .76365 L
.96465 .73263 L
.94975 .72377 L
.91873 .73218 L
.91769 .70161 L
.91873 .70076 L
.94975 .68637 L
.97908 .70161 L
.98077 .70308 L
F
0 g
.98077 .81253 m
.97269 .79467 L
.96973 .76365 L
.96465 .73263 L
.94975 .72377 L
.91873 .73218 L
.91769 .70161 L
.91873 .70076 L
.94975 .68637 L
.97908 .70161 L
.98077 .70308 L
s
.5 g
.91873 .11142 m
.92118 .11228 L
.91873 .12545 L
.91776 .11228 L
F
0 g
.91873 .11142 m
.92118 .11228 L
.91873 .12545 L
.91776 .11228 L
.91873 .11142 L
s
.6 g
.98077 .09976 m
.9597 .08127 L
.96845 .05025 L
.94975 .03835 L
.92807 .01923 L
.98077 .01923 L
F
0 g
.98077 .09976 m
.9597 .08127 L
.96845 .05025 L
.94975 .03835 L
.92807 .01923 L
s
.5 g
.98077 .09249 m
.96994 .08127 L
.97823 .05025 L
.94975 .02828 L
.93633 .01923 L
.98077 .01923 L
F
0 g
.98077 .09249 m
.96994 .08127 L
.97823 .05025 L
.94975 .02828 L
.93633 .01923 L
s
.6 g
.98077 .68168 m
.97268 .6706 L
.94975 .66359 L
.93659 .63958 L
.94975 .63406 L
.98077 .62808 L
F
0 g
.98077 .68168 m
.97268 .6706 L
.94975 .66359 L
.93659 .63958 L
.94975 .63406 L
.98077 .62808 L
s
.9 g
.94975 .35735 m
.97752 .36042 L
.94975 .37366 L
.94245 .36042 L
F
0 g
.94975 .35735 m
.97752 .36042 L
.94975 .37366 L
.94245 .36042 L
.94975 .35735 L
s
.4 g
.97345 .01923 m
.94975 .02129 L
.9456 .01923 L
F
0 g
.97345 .01923 m
.94975 .02129 L
.9456 .01923 L
s
.5 g
.98077 .87209 m
.95151 .8567 L
.98077 .83926 L
F
0 g
.98077 .87209 m
.95151 .8567 L
.98077 .83926 L
s
.8 g
.98077 .12039 m
.95251 .11228 L
.98077 .108 L
F
0 g
.98077 .12039 m
.95251 .11228 L
.98077 .108 L
s
.6 g
.98077 .54355 m
.9636 .51551 L
.98077 .49405 L
F
0 g
.98077 .54355 m
.9636 .51551 L
.98077 .49405 L
s
.5 g
.98077 .2862 m
.97505 .26737 L
.97305 .23635 L
.96606 .20533 L
.96859 .17432 L
.97948 .1433 L
.98077 .141 L
F
0 g
.98077 .2862 m
.97505 .26737 L
.97305 .23635 L
.96606 .20533 L
.96859 .17432 L
.97948 .1433 L
.98077 .141 L
s
.4 g
.98077 .08486 m
.97792 .08127 L
.98077 .06222 L
F
0 g
.98077 .08486 m
.97792 .08127 L
.98077 .06222 L
s
.4 g
.98077 .21243 m
.97862 .20533 L
.9791 .17432 L
.98077 .16403 L
F
0 g
.98077 .21243 m
.97862 .20533 L
.9791 .17432 L
.98077 .16403 L
s
.9 g
.98077 .75923 m
.97918 .73263 L
.98077 .72687 L
F
0 g
.98077 .75923 m
.97918 .73263 L
.98077 .72687 L
s
.6 g
.98077 .04357 m
.97942 .01923 L
.98077 .01923 L
F
0 g
.98077 .04357 m
.97942 .01923 L
s
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[11]:=",
  ImageSize->{443.75, 138.625},
  ImageMargins->{{42, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006k0000RQ000`40O003h00Oogoo_7oo003oOonl
Ool00?mookaoo`00ogoo_7oo003oOonlOol00?mookaoo`006Woo00<007ooOol03goo00<007ooOol0
2Woo1@000Woo00<007ooOol027oo1@000Woo00<007ooOol027oo0`000goo00<007ooOol02Goo0`00
0goo00<007ooOol02Goo0P0017oo00<007ooOol0_goo00<007ooOol02goo1@000Woo00<007ooOol0
27oo1@000Woo00<007ooOol02Goo0`000goo00<007ooOol02Woo0`000goo00<007ooOol02Goo0P00
17oo00<007ooOol04Goo000IOol00`00Ool0000?Ool00`00Ool0000=Ool01`00Oomoogoo001oo`00
00]oo`07001oogooOol007oo00002Goo00<007ooOol00Woo00<007oo00002Woo00<007ooOol00Woo
00<007oo000037oo00H007ooOol007oo002oOol00`00Ool0000>Ool01`00Oomoogoo001oo`0000]o
o`07001oogooOol007oo00002Woo00<007ooOol00Woo00<007oo00002goo00<007ooOol00Woo00<0
07oo000037oo00H007ooOol007oo000BOol001Uoo`03001oo`00015oo`03001oogoo00]oo`07001o
ogooOol007oo00002goo00<007ooOol00goo00<007ooOol027oo00L007ooOomoo`00Ool0000;Ool0
0`00Oomoo`03Ool00`00Oomoo`09Ool01`00Oomoogoo001oo`000<5oo`03001oogoo00aoo`07001o
ogooOol007oo00002goo00<007ooOol00goo00<007ooOol02Goo00L007ooOomoo`00Ool0000<Ool0
0`00Oomoo`03Ool00`00Oomoo`09Ool01`00Oomoogoo001oo`00019oo`006Goo00<007oo00003goo
0P003Woo00L007ooOomoo`00Ool0000;Ool01000Oomoogoo0P002goo00L007ooOomoo`00Ool0000;
Ool01000Oomoogoo0P003Goo00H007ooOol007oo002oOol2000?Ool01`00Oomoogoo001oo`0000]o
o`04001oogooOol2000<Ool01`00Oomoogoo001oo`0000aoo`04001oogooOol2000=Ool01P00Oomo
o`00Ool0019oo`006Goo00<007oo00003goo00<007ooOol03Goo00L007ooOomoo`00Ool0000;Ool0
1@00Oomoogoo00002goo00<007oo00000Woo00<007oo00002Woo00<007oo00000Woo00<007ooOol0
2Woo00<007oo00000Woo00<007oo0000_goo00<007ooOol03Woo00L007ooOomoo`00Ool0000;Ool0
1@00Oomoogoo000037oo00<007oo00000Woo00<007oo00002goo00<007oo00000Woo00<007ooOol0
2Woo00<007oo00000Woo00<007oo00004Woo000JOol00`00Oomoo`0>Ool3000<Ool20004Ool00`00
Oomoo`09Ool20003Ool3000:Ool00`00Oomoo`02Ool00`00Oomoo`0:Ool01000Oomoogoo0`002goo
00<007ooOol00Woo00<007ooOol0_Woo0`003Goo0P0017oo00<007ooOol02Goo0P000goo0`002goo
00<007ooOol00Woo00<007ooOol02goo00@007ooOomoo`<000]oo`03001oogoo009oo`03001oogoo
015oo`00ogoo_7oo003oOonlOol00?mookaoo`0057oo00<007ooOol00WooMP00ZWooMP0037oo000C
Ool00`00Ool00003Ool00`00Ool00002Ool01@00Oomoogoo00000Woo00D007ooOomoo`0000=oo`04
001oogoo0003Ool01000Oomoo`000goo00@007ooOol000=oo`04001oogoo0003Ool01000Oomoo`00
0goo00@007ooOol000=oo`04001oogoo0003Ool01000Oomoo`000goo00D007ooOomoo`00009oo`05
001oogooOol00002Ool01@00Oomoogoo00000Woo00D007ooOomoo`00009oo`05001oogooOol00002
Ool01`00Oomoogoo001oo`000:Yoo`03001oo`0000=oo`05001oogooOol00002Ool01@00Oomoogoo
00000Woo00D007ooOomoo`0000=oo`04001oogoo0003Ool01@00Oomoogoo00000Woo00D007ooOomo
o`0000=oo`04001oogoo0003Ool01@00Oomoogoo00000Woo00D007ooOomoo`00009oo`05001oogoo
Ool00003Ool01000Oomoo`000goo00D007ooOomoo`00009oo`05001oogooOol00003Ool01000Oomo
o`000goo00D007ooOomoo`00009oo`03001oo`0000aoo`004goo00<007oo00000goo00<007ooOol0
LGoo0P00ZWoo00L007oo001oo`00Ool00003Ool01000Oomoogoo10000Woo0P000Woo0P005goo00<0
07oo00001Goo1P001Goo100000=oo`0000000Woo00<007ooOol00Woo00<007oo00001Goo00<007oo
Ool00Woo00<007ooOol01Woo0P000Woo10000Woo0P0000=oo`00Ool02goo000COol00`00Ool00003
Ool00`00Ool8@P0324838@P49BT35:D4HaP3G_L4Kg/:HaP4IcT3HaP4IcT3G_L7HaP4<H`46<H38@P4
HaP3CW<4F]H:G_L4JeX3DY@4F]H7G_L3=Jd4BU82Ool00`00Oomoo`2XOol01P00Ool000aS000HaP<0
008U:@03000HaQS600@0009W>@04001W>FLiIcT2000GIcT00`00F]H00005IcT500000bDY000HaP02
6<H500001FLi000004ic00001E[F00<006LiIcT01P001FLi0P001U[F1@0000=JeP0000000P0000@m
k`00Ool000aoo`004goo00<007oo00000goo00<007oo24800`Q20b4812DY0aBU16<H0ekg16mk2V<H
16Li0f<H16Li0ekg1f<H136<11S60b4816<H0dic15[F2Ukg16]J0e:D15[F1ekg0cF]14YB0Woo00<0
07ooOol0Z7oo00T007oo36<001S6000U:@006<H00P0000<U:@00000010001VLi00<006LiIcT05FLi
00@005[FF]H000EW>@D000039BT001S6008000039BT0000000800004IcT005[F0006F]H2000>IcT0
0`00F]IJeP02F]H00`00CW=>L`02CW<00`00F]IJeP020002?Nl00`00Ool0000<Ool001Aoo`03001o
ogoo009oo`03001oo`Q200<8@P<Q20@U:@<DY@AS60=Nm`A_N`YS60AW>@=S60AW>@=Nm`MS60@aS0@H
aP<Q20AS60=>L`AJePYNm`A[FP=BU0AJePMNm`<e[@A:DP9oo`03001oogoo0:Qoo`03001oo`aS0080
008U:@04000HaQS66<H70006IcT00`00IcUW>@0<IcT00`00IcUW>@06IcT01000F]IJeP0016Li00@0
05[F001>L`<000039BT002DY008U:@@0009W>@03001JeU[F00AJeP03001>L`00008000YW>@800003
IcT005[F009JeP03001>Ldic00=>L`03001JeU[F00@00003Ool007oo00]oo`006Goo00<007oo2480
0`Q20b4812DY0aBU16<H0ekg16mk2V<H16Li0f<H16Li0ekg1f<H136<11S60b4816<H0dic15[F2Ukg
16]J0e:D15[F1ekg0cF]14YB0Woo00<007ooOol0Z7oo00@007oo36<000@U:@03000HaQS6008HaPD0
01AW>@8000QW>@04001JeU[F0004IcT01000F]H004ic0`001BDY1`001U[F00H004icCW<005[F0007
IcT20002Li`01@00IcT005[F00001Tic00@005[FF]IJeP<00003Ool007oo00]oo`006Goo00<007oo
36<00`aS0bU:11S60b481f<H16]J0fLi1f<H16]J1f<H0e[F16Li0e[F13g_12480bDY15kg1e[F0dYB
15kg0f<H16]J0fmk15kg0dYB14ic0e[F148@0Woo00<007ooOol0Z7oo00<007oo36<00P000RDY00<0
01S66<H00aS61@005FLi0P0026Li0P001FLi00@005[F001>L`<000DU:@04000mk`000008F]H01P00
CW=>Ldic001JePD000EW>@800003IcT005[F009JeP04001>LdicCW<20005F]H200000goo001oo`0;
Ool001Uoo`03001oo`aS00<<H`<YBP@HaP<Q20MS60A[FP=W>@MS60A[FPMS60=JePAW>@=JeP@mk`@Q
20<U:@ANm`MJeP=:DPANm`=S60A[FP=_N`ANm`=:DPA>L`=JePA2409oo`03001oogoo05Moo`8000Ao
o`03001oogoo04Qoo`08001oo`aS000HaP009BT000@HaP03000U:@00008001IW>@03001cW00000QW
>@03001W>FLi00AW>@80009>L`03000aS00000<U:@80008mk`8000MJeP03001>L`00009>L`03001J
eU[F00=JeP8000EW>@03001JeU[F00=JeP<000IJeP<00003Ool007oo00]oo`006Goo00<007oo36<0
0`aS0bU:11S60b481f<H16]J0fLi1f<H16]J1f<H0e[F16Li0e[F13g_12480bDY15kg1e[F0dYB15kg
0f<H16]J0fmk15kg0dYB14ic0e[F148@0Woo00<007ooOol0FGoo00H007ooOol007oo0019Ool01000
Ool<H`000QS600<001S66<H00aS600<002DY00000P002fLi00<006LiIcT02FLi00@007>L000000eW
>@04001JeP00CW<300029BT20003?Nl00`00CW<00005F]H01000CW=>L`000Tic00@005[FF]IJeP80
009JePD000UJeP<000=JeP<00003Ool007oo00]oo`006Goo00<007oo24800`Q20acW11S60bU:16Li
0f<H16Li0f]J1fLi16]J0fmk16]J0f<H16]J0f<H14YB12U:0dHa13g_0ekg15:D0d8@15Je0dYB3Ukg
16Li0e[F13F]0Woo00<007ooOol0F7oo00L007ooOomoo`00Ool00019Ool01000Ool<H`0021S600<0
02DY00000P002VLi00<007>L00002VLi00@007>LLiacW0<000]W>@800004CW<00000<H`300000cg_
00000002?Nl30004F]H00`00CW=>L`020002CW<30002CW<00`00F]IJeP0:F]H30003IcT200001U[F
00000000Ool000aoo`006Goo00<007oo24800`Q20acW11S60bU:16Li0f<H16Li0f]J1fLi16]J0fmk
16]J0f<H16]J0f<H14YB12U:0dHa13g_0ekg15:D0d8@15Je0dYB3Ukg16Li0e[F13F]0Woo00<007oo
Ool0FGoo00H007ooOol007oo0019Ool00`00Ool000096<H2000013g_000000002VLi00<006LiIcT0
26Li00<007>LLi`01G>L00<006LiIcT026Li0P0000I>L`00000aS000<H`300000dic000000020005
F]H00`00CW=>L`020002CW<20003CW<00`00F]IJeP02F]H20006F]H00`00F]IJeP030004F]H20000
0goo001oo`0;Ool001Uoo`03001oo`Q200<8@P<Li`@HaP<YBPAW>@=S60AW>@=[FPMW>@A[FP=_N`A[
FP=S60A[FP=S60A:DP@YBP=6<@@mk`=Nm`ABU0=240AF]@=:DPiNm`AW>@=JeP@e[@9oo`03001oogoo
05Moo`03001oo`00009oo`03001oo`0004Uoo`03001oo`00008HaP8000@HaPH00003Li`00000019W
>@8000QcW003001W>FLi00MW>@0;001JeP00000mk`00<H`003g_001JeP0200000dic001JeP05F]H0
0`00CW<00002?Nl20002F]H01@00CW=>L`00F]H00`0000=W>@00F]H00U[F00D005[F001W>@00009J
eP03001JeU[F00AJeP03001oo`0000aoo`006Goo00<007oo24800`Q20acW11S60bU:16Li0f<H16Li
0f]J1fLi16]J0fmk16]J0f<H16]J0f<H14YB12U:0dHa13g_0ekg15:D0d8@15Je0dYB3Ukg16Li0e[F
13F]0Woo00<007ooOol0F7oo00<007ooOol00Woo00<007ooOol0B7oo00<007oo6<H00P000RDY00<0
01S600001`000g>L00<006LiIcT036Li0`002g>L00<006LiIcT01VLi00L005[F000003g_000aS003
0003F]H00`00F]IJeP05F]H00`00CW<00002?Nl20002F]H01P00CW=>L`00F]H000AW>@<00004CW<0
0000IcT600000e[F0000000200000goo001oo`0;Ool001Uoo`03001ooacW00<Li`<U:@@DY@=240Ac
W0=W>@A[FP=W>@M[FPA_N`=[FPAg_@=W>@MS60A>L`@aS0MF]@=JePAF]@<mk`AJeP=:DPANm`=W>@A:
DP=W>@A6<@=Nm`AS609oo`03001oogoo0:Qoo`03001oo`0000@U:@03000HaQS600L0009cW003001W
>FLi00eW>@03001cW7>L00AcW003001cW7>L00=cW003001W>FLi00MW>@06001JeP00000mk`000S6<
0`002U[F00<004ic00000Sg_0P0000=JeP00CW<00Tic00<005[F000016Li0P000Tic0`0000IJeP00
CW<004ic0003F]H200000goo001oo`0;Ool001Uoo`03001ooacW00<Li`<U:@@DY@=240AcW0=W>@A[
FP=W>@M[FPA_N`=[FPAg_@=W>@MS60A>L`@aS0MF]@=JePAF]@<mk`AJeP=:DPANm`=W>@A:DP=W>@A6
<@=Nm`AS609oo`03001oogoo0:Aoo`07001oogooOol007oo000012DY00@001S66<HHaPD00003IcT0
000000mW>@03001cW7>L00EcW08000AcW003001W>FLi00MW>@03001JeU[F00800003?Nl0036<0080
0003CW<005[F00QJeP03001>L`00008mk`03001>L`0000E>L`03001JeP0000=W>@800003CW<004ic
00800003F]H004ic008000EJeP9oo`03001oogoo00Yoo`006Goo00<007oo7>L00acW0bDY11BU0d8@
17>L0fLi16]J0fLi1f]J16mk0f]J17Nm0fLi1f<H14ic136<1eJe0e[F15Je0cg_15[F0dYB15kg0fLi
14YB0fLi14Ha0ekg16<H0Woo00<007ooOol0Hgoo0P00?Woo00<007oo00000Woo00<007oo<H`00P00
0RDY00@001S66<HHaPL000YW>@03001W>FLi009W>@03001cW7>L00EcW003001W>@0000=cW003001W
>FLi00QW>@03001JeU[F00800004?Nl0036<<H`200000dic001JeP08F]H20003?Nl00`00CW=>L`04
CW<00`00F]H00003IcT2000014ic001>L`000U[F00@004icCW<000EJeP03001oo`0000aoo`006Goo
00<007oo?Nl00cg_0bU:11S60cF]4V]J0g>L16mk1f]J0fLi1ekg15Je13W>0cF]15:D0e[F15kg0cW>
14YB0dic15:D0fLi14Ha0eJe14ic0ekg148@0Woo00<007ooOol0HGoo0P0000Aoo`00000003ioo`03
001oogoo00@00004<H`002DY00036<H6000:IcT30002IcT00`00LiacW006Li`01000IcUW>@000W>L
00<006LiIcT026Li00P005[FF]H004ic000mk`000S6<100025[F0P000cg_00<004icCW<014ic0P00
00AJeP00IcUW>@800007CW<004icCW<005[F00000Tic00<005[FF]H00U[F0P0000=oo`00Ool02goo
000DOol00`00Oomoo`02Ool00`00Oolmk`03?Nl3:DX46<H3=JdBJeX3Li`4Kg/7JeX3IcT7G_L4E[D4
>Lh3=Jd4DY@3F]H4G_L3>Lh4BU83CW<4DY@3IcT4AS43E[D4CW<3G_L4@Q02Ool00`00Oomoo`0oOol3
0003Ool00`00Oomoo`0FOol30003Ool2000mOol20003Ool01P00Oolmk`00<H`0008U:@<000039BT0
000000<0009W>@8000]W>@03001cW7>L00McW08000=cW003001W>FLi00=W>@03001W>FLi00=W>@07
001JeP00CW<003g_00000c6<0P0000=>L`00F]H01U[F0`000cg_00@004icCW=>L`8000=JeP05001W
>FLi001JeP050002F]H20004F]H01@00CW<007oo000037oo000COol00`00Ool00003Ool00`00Oolm
k`03?Nl3:DX46<H3=JdBJeX3Li`4Kg/7JeX3IcT7G_L4E[D4>Lh3=Jd4DY@3F]H4G_L3>Lh4BU83CW<4
DY@3IcT4AS43E[D4CW<3G_L4@Q02Ool00`00Oomoo`0oOol00`00Oomoo`02Ool00`00Ool0000DOol3
0006Ool00`00Ool0000lOol00`00Oomoo`02Ool01P00Oolmk`00<H`000@U:@800005<H`00000001W
>@020002Li`20009IcT00`00LiacW00<Li`00`00IcUW>@03IcT00`00IcUW>@04IcT01P00F]H00000
?Nl000@aS0800003CW<005[F00AJeP800003?Nl00000008mk`04001>Ldic0006F]H20003F]H20000
0cg_00000007F]H300000goo001oo`0;Ool001Eoo`06001oogooOol007oo13g_0bU:11S60cF]4V]J
0g>L16mk1f]J0fLi1ekg15Je13W>0cF]15:D0e[F15kg0cW>14YB0dic15:D0fLi14Ha0eJe14ic0ekg
148@00=oo`000000@Woo00L007ooOomoo`00Ool0000BOol30008Ool01000Oomoo`00>goo0`000Woo
00H007oo?Nl0036<00059BT500000fLi001cW004Li`20007IcT00`00LiacW004Li`00`00LiacW006
Li`01000IcUW>FLi0P001fLi0P0000=>L`0000001C6<0P0000=>L`00F]H00e[F0P0000<mk`000000
0cg_00<004ic00001U[F0P000e[F0P0000@mk`00CW<000EJeP06001>L`00001oo`0037oo000COol2
0004Ool00`00Oolmk`03?Nl3:DX49BT3BU87Kg/4JeX3IcT4JeX3Kg/4JeX3Kg/4Li`3HaP4G_L3IcT4
G_L4?Nl3;F/4=Jd7DY@3>Lh4@Q03G_L4E[D7G_L3@Q04G_L3E[D4=Jd2Ool00`00Oomoo`10Ool01`00
Oomoogoo001oo`0000moo`<000]oo`03001oogoo008003moo`06001oocg_000aS0001BDY1@0000=W
>@00Li`01G>L00<006LiIcT01FLi00<007>LLi`00g>L0P0027>L00@006LiIcUW>@8000MW>@03001J
eP00008000HaS0800003CW<0000000@00005?Nl00000000mk`030008F]H00`00F]IJeP02F]H20000
13g_001>L`0015[F00H004ic000007oo000<Ool001=oo`03001oogoo00=oo`03001oocg_00<mk`<Y
BP@U:@=:DPM_N`A[FP=W>@A[FP=_N`A[FP=_N`AcW0=S60ANm`=W>@ANm`@mk`<]J`@e[@MBU0<icPA2
40=Nm`AF]@MNm`=240ANm`=F]@@e[@9oo`03001oogoo03moo`03001oo`00009oo`03001oo`0000eo
o`<000eoo`05001oogooOol0000oOol01P00Oolmk`00<H`000DU:@D00003IcT007>L00IcW08000IW
>@03001cW7>L00=cW003001cW7>L00AcW08000IW>@03001W>FLi00AW>@03001JeP00008000DaS004
000aS0000005CW<00`00?Nlmk`02?Nl01@00CW=>Ldic00000U[F0P002E[F0P000Tic00@005[FF]IJ
eP800005CW<00000Ool0000<Ool001=oo`<000=oo`03001oocg_00<mk`<YBP@U:@=:DPM_N`A[FP=W
>@A[FP=_N`A[FP=_N`AcW0=S60ANm`=W>@ANm`@mk`<]J`@e[@MBU0<icPA240=Nm`AF]@MNm`=240AN
m`=F]@@e[@9oo`03001oogoo041oo`03001oogoo009oo`03001oogoo00Uoo`<0015oo`05001oogoo
Ool0000nOol00`00Oolmk`0200059BT01@00<H`aS000CW<00`000W>L0P001G>L0P001FLi00<007>L
Li`01g>L0P002FLi0P000VLi0P0000IJeP00CW<003g_0003<H`00`009BT000030005CW<01@00?Nlm
k`00CW<00P000Tic0P000Tic0P001e[F00<004icCW<00Tic0`000Tic00D003g_001oo`0000aoo`00
6Goo00<007oo?Nl00cg_0bU:12e[0cW>2f]J0fmk16Li1f]J0fmk15[F0ekg16Li1ekg148@0cF]1248
0c6<15:D0d8@15kg0dic148@0ekg15[F0e:D1dic13F]0Woo00<007ooOol0Cgoo0P0057oo00@007oo
Oomoo`8003eoo`03001oocg_008000DU:@03000aS36<00D0009cW004001W>@000005Li`00`00IcUW
>@03IcT00`00LiacW005Li`00`00IcT000040006IcT30003F]H01@00CW<003g_00000S6<00D002DY
000002DY00@000=>L`03000mk`000080009JeP800003CW<0000000800003CW<005[F00IJeP8000M>
L`05000mk`00Ool0000<Ool001Uoo`03001oocg_00<mk`<YBP@]J`<icP][FP=_N`AW>@M[FP=_N`AJ
eP=Nm`AW>@MNm`A240<e[@@Q20<aS0ABU0=240ANm`=>L`A240=Nm`AJeP=BU0M>L`@e[@9oo`03001o
ogoo04aoo`<001Ioo`03001oogoo009oo`03001oogoo03]oo`05001oo`00<H`000069BT70002Li`0
0`00IcT00007Li`01@00IcUW>FLi000017>L10000VLi00@005[FF]H000QW>@H00004CW<003g_0002
<H`00`009BT000039BT00`00<H`000020002CW<01000?Nl000000e[F00<004ic00000Sg_00<004ic
00001e[F00<004icCW<01Tic00D003g_001oo`0000aoo`006Goo00<007oo?Nl00cg_0bU:12e[0cW>
2f]J0fmk16Li1f]J0fmk15[F0ekg16Li1ekg148@0cF]12480c6<15:D0d8@15kg0dic148@0ekg15[F
0e:D1dic13F]0Woo00<007ooOol0:7oo1@000Woo00<007ooOol05goo0`006Goo00<007ooOol00goo
00<007ooOol00Woo1@000Woo00<007ooOol0;Woo00D007oo000aS00000PU:@D0009cW08000QcW004
001W>@000004Li`00`00IcUW>@05IcT2000=IcT200000dic00000003<H`00`009BTU:@049BT20000
0c6<00000002CW<200000dic001JeP02F]H20002?Nl00`00CW<00007F]H00`00CW=>L`06CW<01@00
?Nmoogoo000037oo000IOol00`00Oolmk`03?Nl3:DX4;F/3>Lh;JeX3Kg/4IcT7JeX3Kg/4F]H3G_L4
IcT7G_L4@Q03=Jd48@P3<H`4DY@3@Q04G_L3CW<4@Q03G_L4F]H3DY@7CW<4=Jd2Ool00`00Oomoo`0Z
Ool01`00Oomoogoo001oo`0001Ioo`<001Qoo`04001oogoo0005Ool00`00Oomoo`04Ool01`00Oomo
ogoo001oo`0002moo`03001ooc6<008aS003000U:BDY00DU:@D0009cW003001cW7>L00QcW003001c
W7>L00AcW003001W>FLi00EW>@03001W>FLi00aW>@03001JeP00008000@aS003000U:BDY00DU:@<0
00=>L`800007CW<005[FF]H004ic00000Sg_0`001E[F00<004icCW<024ic00@007ooOol000aoo`00
6Goo00<007oo<H`00c6<0be[1b4816mk1f]J0gNm16]J0fmk16Li2V<H16Li0f]J16<H148@0c6<12U:
1bDY0e:D148@0ekg13W>0ekg15[F0dic1dHa148@0Woo00<007ooOol0:Woo00L007ooOomoo`00Ool0
000COol3000KOol200000goo001oo`05Ool00`00Oomoo`03Ool01`00Oomoogoo001oo`0002moo`04
001ooc6<<H`200089BT4000CLi`00`00IcUW>@0@IcT30002IcT00`00F]H000030003<H`00`009BTU
:@069BT30003CW<200000dic001JeP030002?Nl50003F]H00`00CW=>L`02CW<20004CW<01000Oomo
o`0037oo000IOol00`00OolaS003<H`3;F/78@P4Kg/7JeX3Mkd4JeX3Kg/4IcT:HaP4IcT3JeX4HaP4
@Q03<H`4:DX79BT3DY@4@Q03G_L4>Lh3G_L4F]H3CW<7AS44@Q02Ool00`00Oomoo`0ZOol01`00Oomo
ogoo001oo`00015oo`<001eoo`06000Xl`00001oo`001Goo00<007ooOol00Woo00L007ooOomoo`00
Ool0000_Ool01000Ool000002RDY10004W>L00<006LiIcT04FLi00<007>L00000VLi00<005[F0000
1@0000<aS0009BT01bDY0`001Dic00<005[FF]H00`000Sg_10000e[F00<004icCW<00Tic00<003g_
000014ic00@007ooOol000aoo`006Goo00<007oo<H`00c6<0be[1b4816mk1f]J0gNm16]J0fmk16Li
2V<H16Li0f]J16<H148@0c6<12U:1bDY0e:D148@0ekg13W>0ekg15[F0dic1dHa148@0Woo00<007oo
Ool0:Woo00L007ooOomoo`00Ool0000>Ool3000OOol01000Nfd002Sc0`001Woo00D007ooOomoo`00
00=oo`03001oo`0002moo`03001oobDY008U:@H0008U:@D0011cW08000iW>@03001W>FLi00AW>@04
001W>FLi0003F]H00`00CW=>L`0300000c6<000U:@069BT01000<H`000000dic00P005[FF]IJeP00
CW<003g_0P0000=JeP0000000U[F00<004icCW<00Tic00@003g_?Nl000A>L`04001oogoo000<Ool0
01Uoo`03001ooacW00<Li`<HaP@Q20<YBPA[FP=g_@AcW0M[FP=W>@ANm`MS60=JePAS60=[FPAJePAF
]@=[FP@]J`<YBP@U:@<mk`AW>@=JeP@mk`=Nm`A:DP=6<@A240=>L`A2409oo`03001oogoo02Uoo`80
00Aoo`03001oogoo00]oo`80029oo`04001kK@00:?<30006Ool00`00Oomoo`020004Ool00`00Oomo
o`0^Ool00`00Ool0000200056<H00`009BTU:@05000=Li`3000>IcT200000e[F001W>@04IcT01000
IcUW>@000e[F200022DY0`000Tic0`000U[F00@004ic000mk`800005F]H005[FF]H00005CW<01000
?Nlmk`001Dic00<007oo000037oo000IOol00`00OolLi`037>L36<H48@P3:DX4JeX3Mkd4Li`7JeX3
IcT4G_L7HaP3F]H4HaP3JeX4F]H4E[D3JeX4;F/3:DX49BT3?Nl4IcT3F]H4?Nl3G_L4BU83AS44@Q03
CW<4@Q02Ool00`00Oomoo`0jOol3000TOol01000Nfd002Sc0P0000=k4P00Ool01Goo00<007ooOol0
=Woo00<007oo6<H021S600<002DY00004@0046Li00<005[FF]H00U[F00<006LiIcT016Li00<005[F
F]H00e[F0P000VLi10001bDY00<0036<00000`000VLi0`0000=>L`00?Nl00P0000AJeP00F]IJePH0
00<mk`8000A>L`03001oo`0000aoo`006Goo00<007oo7>L00acW0aS612480bU:16]J0gNm17>L1f]J
0fLi15kg1f<H0e[F16<H0f]J15[F15Je0f]J12e[0bU:12DY0cg_16Li0e[F13g_0ekg14YB0dHa148@
0dic148@0Woo00<007ooOol0=goo0`002Woo00<007ooOol06Woo00@007]]000Xl`800003Na8007oo
00Ioo`03001oogoo02Yoo`D0009oo`06001oogooOol007oo2AS600<002DY00002`005fLi00D005[F
F]IJeP0000MW>@05001JeU[FF]H00005IcT400079BT00`00<H`000020002IcT02@00F]H004ic000m
k`00CW<00002F]H00`00CW<00005?Nl20002?Nl20002CW<00`00Ool0000<Ool001Uoo`03001ooacW
00<Li`<HaP@Q20<YBPA[FP=g_@AcW0M[FP=W>@ANm`MS60=JePAS60=[FPAJePAF]@=[FP@]J`<YBP@U
:@<mk`AW>@=JeP@mk`=Nm`A:DP=6<@A240=>L`A2409oo`03001oogoo03Eoo`<000]oo`@001Qoo`<0
009kK@<00003Na8007oo00Ioo`03001oogoo02aoo`07001oogooOol007oo00000Woo00<007oo6<H0
1aS600@002DY9BTU:@<0009JePP001EW>@05001JeU[FF]H00008IcT40005IcT500079BT60003F]H2
0002?Nl2000015[F001>L`000cg_0`000S6<00@003g_?Nl0009>L`03001oo`0000aoo`006Goo00<0
07oo6<H00aS61b480bU:15:D0c6<148@0f<H1ekg16Li0ekg16<H1ekg2f<H0fLi15[F0bU:12e[0bU:
1ekg13W>0e:D13g_1c6<0d8@14YB0Woo00<007ooOol0<Woo0`003Woo0P0000<UN000Ool05Woo2@00
00=k4P00Ool00P001Goo00<007ooOol0:goo00L007ooOomoo`00Ool00002Ool200026<H700039BT>
0003IcT50006IcT20005IcT01000F]IJeP004VLi1@001bDY100015[F1@0000I>L`00CW=>L`00?Nl2
0006<H`01@00?Nlmk`00CW<00Woo00<007ooOol02Woo000=Ool50002Ool00`00Oomoo`02Ool00`00
OolHaP036<H78@P3:DX4DY@3<H`4@Q03HaP7G_L4IcT3G_L4HaP7G_L;HaP3IcT4F]H3:DX4;F/3:DX7
G_L4>Lh3DY@4?Nl7<H`3@Q04BU82Ool00`00Oomoo`0`Ool200000goo001oo`0=Ool00`00JYAZU003
000AOol00`00Oomoo`02Ool01P00804003fE000aE@<00003Na8007oo00<000Eoo`03001oogoo02Yo
o`07001oogooOol007oo00000Woo00@007oo6<H000TU:@<00005CW<00000?Nl00002<H`3000025[F
001W>FLi001JeP00IcT2000=IcT01000F]IJeP004FLi1@0012DY00<002DY9BT00RDY2@0000DaS000
?Nl004ic008000<mk`<000<aS003000mkcg_008mk`04001oogoo000<Ool000moo`07001oogooOol0
07oo00000goo00<007oo6<H00aS61b480bU:15:D0c6<148@0f<H1ekg16Li0ekg16<H1ekg2f<H0fLi
15[F0bU:12e[0bU:1ekg13W>0e:D13g_1c6<0d8@14YB0Woo00<007ooOol0;Goo0`004Woo00<006ZD
JY@00`0047oo2@0000@mU@00<EDaE@800006Na800000001oT@001Goo00<007ooOol0:Woo00L007oo
Oomoo`00Ool00002Ool01000OolHaP0022DY0P0000=>L`0000000P0000Dmk`00<H`003g_00<000=W
>@03001JeP00011W>@04001JeU[F0008IcT00`00IcUW>@04IcT00`00IcT0000300049BT00`00<H`0
00049BT600001c6<0000036<000mk`0000Pmk`<000<mk`06000mkcg_001oo`0037oo000?Ool01`00
Oomoogoo001oo`0000=oo`03001oobDY00<U:@LYBPMNm`<aS0AF]@=S60AJeP=S60A_N`=[FPAS60MN
m`=S60AF]@A[FP=_N`@]J`<YBP@aS0<YBPLHaP@Q20<mk`@icP=>L`A:DP=BU0A6<@03Ool0000002eo
o`8001Aoo`03001ZU6ZD00800003@QT007oo00moo`800004?I@003YL0002MaH01000?ID0035E0`00
0W/B10001Woo00<007ooOol0:7oo0P0017oo00L007ooOomoo`00Ool000089BT40003F]H300001S6<
00000000F]H0009W>@05001JeU[FF]H00005IcT20008IcT01@00F]IJeU[F00001FLi0`0016Li1P00
00<aS0009BT00bDY00@0036<<H`000@U:@H0008U:@8000Pmk`8000@mk`800003CW<00000009oo`03
001oogoo00Yoo`003goo00L007ooOomoo`00Ool00003Ool00`00OolU:@039BT7:DX7G_L3<H`4E[D3
HaP4F]H3HaP4Kg/3JeX4HaP7G_L3HaP4E[D4JeX3Kg/4;F/3:DX4<H`3:DX76<H48@P3?Nl4>Lh3CW<4
BU83DY@4AS42Ool00`00Oomoo`0XOol4000EOol01@00JYAZU000JY@00P003goo00<007LF00000SfD
00@007LFMaIg5P800003?ID0000000<00006Na800000001oU0001Woo00<007ooOol0<Goo00<007oo
9BT01bDY0`001E[F0`0000DaS000000005[F00@000AJeP05001W>FLiIcT00002Li`20006IcT00`00
F]IJeP020004IcT01P00F]IJeU[F001W>@80009cW0D000@U:@03000aS36<008aS003000U:BDY00T0
00039BT0000000Hmk`L00008CW<00000001>L`00Ool000aoo`003goo00L007ooOomoo`00Ool00003
Ool00`00OolU:@039BT7:DX7G_L3<H`4E[D3HaP4F]H3HaP4Kg/3JeX4HaP7G_L3HaP4E[D4JeX3Kg/4
;F/3:DX4<H`3:DX76<H48@P3?Nl4>Lh3CW<4BU83DY@4AS42Ool00`00Oomoo`0UOol3000HOol20000
16ZD001ZU6ZD0`0000=oo`00Ool017oo1@0000=oo`0000000WLF0P0000=SS`00MaH00P0000<ef@00
00001`000WnD00<007ooOol017oo00<007ooOol0<Goo00<007oo9BT022DY2@000S6<10000e[F0P00
0U[F00D006LiIcUW>@0000=cW003001W>FLi00IW>@8000EW>@04001JeU[FF]H200000fLi001cW002
Li`400059BT01@00<H`aS36<00000RDY00<001S66<H011S60P0000<U:@00000013g_10000U[F1@00
0e[F0P0000=oo`00Ool02goo000>Ool20004Ool00`00Oomoo`02Ool00`00OolU:@039BT7:DX7G_L3
<H`4E[D3HaP4F]H3HaP4Kg/3JeX4HaP7G_L3HaP4E[D4JeX3Kg/4;F/3:DX4<H`3:DX76<H48@P3?Nl4
>Lh3CW<4BU83DY@4AS42Ool00`00Oomoo`0SOol2000KOol01000Oc8000000VZD0`0000=oo`000000
0goo00D000@0000004jK00<000=g5PP00003=MT00000008000088CH00000001oU000FYT000Ioo`03
001oogoo009oo`<000=oo`03001oogoo02Eoo`03001oobDY00TU:@H000<aS003000mk`00009>L`D0
0003F]H006Li00=W>@04001cW7>L000?IcT01000F]IJeU[F0`0000=W>@00Li`00W>L10001BDY00L0
036<<H`aS0009BT000066<H00`009BT000020002?Nl30002CW<00`00F]IJeP06F]H500000goo001o
o`0;Ool001Uoo`03001oobU:00HYBPLU:@@Q20<e[@A6<@=>L`ANm`M[FP=S60A[FPMW>@=F]@ABU0A[
FP=_N`@Li`<U:@@aS0LLi`<]J`@icP=:DPAJePMS60=_N`A[FP9oo`03001oogoo025oo`<001aoo`03
001o<P00009ZU003001be00000<000039CH0000000<00004LaL004jKCY/20003MaH20002CSP>0000
0eZI00000007Ool01@00Oomoogoo000017oo00<007oo00009Woo00<007oo9BT02RDY1@000c6<00@0
03g_?Nl000=>L`04001JeP000004IcT01@00LiacW7>L00001FLi00<006LiIcT01fLi00L005[FF]H0
04ic001JeP020003Li`600039BT01P00<H`aS0009BT000DHaP@00005<H`003g_?Nl00003CW<20002
F]H7000016Li000006Li0Woo00<007ooOol02Woo000IOol00`00OolYBP06:DX79BT48@P3=Jd4AS43
CW<4G_L7JeX3HaP4JeX7IcT3E[D4DY@4JeX3Kg/47>L39BT4<H`77>L3;F/4>Lh3BU84F]H7HaP3Kg/4
JeX2Ool00`00Oomoo`0QOol2000MOol00`00Oc800002JY@00`00L]@0000200000g]E000U=P030000
0g<G001^e@0200000fKH0000000300000e;L001>>0050002Nc@3000026oj00000000FYT005^@0006
Ool00`00Oomoo`02Ool01`00Oomoogoo001oo`0002Ioo`04001oo`00000;9BT700000cg_00000004
CW<00`00F]H00003IcT20002Li`20003IcT200000g>L001W>@06IcT00`00F]IJeP0400000e[F0000
000700026<H00`009BTU:@0400000bDY000HaP036<H010009BT000000S6<00D003g_?Nl004ic0080
009JeP<000IW>@03001cW7>L00800003Ool007oo00]oo`006Goo00<007oo:DX01RU:1bDY12480cF]
14Ha0dic15kg1f]J0f<H16]J1fLi0eJe15:D16]J0fmk11cW0bDY136<1acW0be[13W>0dYB15[F1f<H
0fmk16]J0Woo00<007ooOol077oo00@007ooOomoo`800005Ool007ooOol0000HOol02000Oc8006jd
001ZU000L]@300000g]E000U=P0300001G<G001^e@00Og802`0000=oLP00Nc@00W/d10000TVd1@00
1goo00D007ooOomoo`0000=oo`03001oo`0002Ioo`04001oo`00<H`400099BT60005CW<00`00F]H0
0002IcT20006Li`30004Li`20005IcT00`00F]H00004F]H30003IcT400026<H00`009BTU:@069BT0
0`006<HHaP026<H30002<H`01000?Nlmk`000Tic00<005[FF]H00e[F0P001FLi0P0000AW>GooOol0
00aoo`006Goo00<007ooG_L00ekg0cW>13F]0bU:14ic0ekg15:D0f<H16mk2W>L17Nm0fmk16Li0dic
16Li16mk0e:D12480acW12480bU:11BU0aS6148@0dHa15Je0e:D15Je0f<H16]J0Woo00<007ooOol0
6goo00<007oo00000Woo0P000Woo0`0067oo00@007lb001^]0800004L]@007;D0002NeD2000014kL
000000000VkE100000<e^00000001@000Wmb00D007/dNc@006mk00@00004BK@0035e0002>KH00`00
Oomoo`04Ool2000017oo001oo`000Woo00<007oo00009Woo00<007oo00000P000c6<0`0012DY1`00
14ic0P0000=JeP00IcT00P004G>L00H006LiIcUW>@00F]H20003F]H20002Li`00`00IcUW>@040003
6<H200069BT00`006<HHaP046<H30002?Nl01@00CW=>Ldic00001e[F0P001VLi0Woo00<007ooOol0
2Woo000IOol00`00OomNm`03G_L3>Lh4=Jd3:DX4CW<3G_L4DY@3HaP4Kg/:Li`4Mkd3Kg/4IcT3CW<4
IcT4Kg/3DY@48@P37>L48@P3:DX45:D36<H4@Q03AS44E[D3DY@4E[D3HaP4JeX2Ool00`00Oomoo`0K
Ool00`00Ool00002Ool30002Ool2000HOol00`00Oc800002K[@01000L]@007;D0`0000INE@00C]`0
07>J0002K]D20002NcD400000d6f00000003000015mM000006mk0P0000EgV000BK@004Vd00800003
>KH0000000Moo`04001oogoo0004Ool00`00Oomoo`0UOol00`00Ool000050003<H`800000e[F0000
000400001E[F000006Li000057>L00T006LiIcT005[F001>L`00F]H00P000g>L00<006Li00001000
1AS60`0012DY00<001S600000P0000@HaP000000008mk`03001>Ldic009>L`03001JeU[F00@0009J
eP8000AW>@9oo`03001oogoo00Yoo`006Goo00<007ooG_L00ekg0cW>13F]0bU:14ic0ekg15:D0f<H
16mk2W>L17Nm0fmk16Li0dic16Li16mk0e:D12480acW12480bU:11BU0aS6148@0dHa15Je0e:D15Je
0f<H16]J0Woo00<007ooOol06goo00<007oo00000Woo20005goo0P000Vjd0P0000=be000L]@00P00
0UiE100000=Nn`00K]D02@000UXe0P0000EOG@00000006mk00<00006MiP00000BK@0035e0`0027oo
00<007ooOol0;7oo00<007ooIcT03@0000A>L`000000009W>@800003F]H00000009W>@03001cW7>L
019cW006001W>FLiIcT005[F0P0000=JeP00IcT0100000=W>@0000000`002AS60P000bDY00@001S6
6<HHaP<00003?Nl0000000I>L`8000A>L`80009JeP<00004IcUoogoo000<Ool001Uoo`03001ooekg
00=Nm`<icP@e[@<YBPA>L`=Nm`ABU0=S60A_N`YcW0Ag_@=_N`AW>@=>L`AW>@A_N`=BU0@Q20<Li`@Q
20<YBP@DY@<HaPA240=6<@AF]@=BU0AF]@=S60A[FP9oo`03001oogoo01]oo`03001oo`00009oo`03
001oo`0000800003NmL0000001Ioo`03001o<P00009^]003001g5@00009be0D00004>_l005kkG_/3
00000g/e00000006000015Xe000000000e[k0P0000=JE`0000001P000UGd00<007ooOol01Goo0P00
;Goo00@007oo001W>@<00003CW<0000000@00004CW<000000006IcT00`00IcUW>@02IcT00`00Liac
W00ALi`20002IcT02@00F]IJeU[F001JeP00IcT00002IcT500000bDY000HaP0:6<H010009BTU:BDY
0`0000DU:@00000mk`0000m>L`03001JeU[F009JeP800003Ool007oo00]oo`006Goo00<007ooKg/0
0fmk0f<H15:D0f<H1fLi16mk0f]J16mk0gNm16mk0f]J1fLi15kg0e[F16mk15kg0bDY1acW11S60acW
12e[0cg_3TYB14Ha1eJe0Woo00<007ooOol077oo00X007ooOomoo`00Ool003GH001ke`<0015oo`L0
0008K[@007LEMaD007;D001^]0800003K]H0000000D00003CK<0000000L00005FSD00000001Jn`04
000015YG000]50000UHe00<0046E00000UGd00<007ooOol01Woo00<007ooOol0:goo00<007ooLi`0
0P0000AW>@00000000=>L`D000MW>@80009W>@03001cW7>L00icW0@000AW>@03001JeU[F009JeP05
001W>@00Li`00002IcT300000bDY000HaP0<6<H00`009BTU:@029BT300000cg_001>L`0@CW<00`00
F]IJeP02F]H2Ool00`00Oomoo`0:Ool001Uoo`03001oofmk00=_N`=S60ABU0=S60MW>@A_N`=[FPA_
N`=g_@A_N`=[FPMW>@ANm`=JePA_N`ANm`<U:@LLi`@HaP<Li`@]J`<mk`i:DPA6<@MF]@9oo`03001o
ogoo01Ioo`03001oogoo009oo`04001oogooOol20002Ool00`00NmL0000200000gZ;001oo`0=Ool2
00002V]K000004jK001Ze`00K[@007LE0P0000Ebe000K[@007/d00D0009=TP03001=/dfc00H00005
6;800000001bm@02000026Lk00000000FUL002dD0002ESD01P00@IE1U@00EO@000Uoo`03001oogoo
02Yoo`04001oog>LLi`200000fLi001JeP060008IcT00`00LiacW003000<Li`40008IcT00`00F]IJ
eP02F]H<000>6<H01P009BT00000<H`0008mk`03001>Ldic011>L`04001JeU[FF]H2Ool00`00Oomo
o`0:Ool001Uoo`03001oofmk00=_N`=S60ABU0=S60MW>@A_N`=[FPA_N`=g_@A_N`=[FPMW>@ANm`=J
ePA_N`ANm`<U:@LLi`@HaP<Li`@]J`<mk`i:DPA6<@MF]@9oo`03001oogoo01Eoo`03001oo`00009o
o`03001oo`00009oo`80009oo`D00004NX/00000000;Ool01@00Je][F`00GYL00`000V[G00<007LE
00000WMF00<006jdK[@010000Uhd00@004fB0000009=/`L000046;800000L_D500001QDh001JE`00
;A@0009F=@050011U@00EO@00009Ool2000POol50002Ool01P00Oomoogoo001oo`8000AW>@04001J
eU[F000<IcT20003IcT00`00LiacW009Li`00`00IcUW>@0:IcT00`00F]IJeP03F]H800000aS60000
00076<H300026<H00`009BT00002<H`01@00?Nlmkcg_000044ic0P0015[F0Woo00<007ooOol02Woo
000IOol00`00OomF]@03E[D7G_L3IcT4E[D3IcT4HaP7JeX3Kg/;JeX7IcT3E[D4@Q04<H`36<H79BT4
;F/39BT4>Lh3@Q04CW<3DY@4F]H3E[D4G_L3F]H4G_L2Ool00`00Oomoo`0GOol01P00Oomoo`00Ool0
009oo`03001oogoo009oo`050000<P00001jR`0200000goo001oo`07Ool200001D[M001[F`00GYL0
0P000f[G00@007LE001gEP@00004Nc@007;E0002GS@01@00CI800000CK<0200000<H/P0000000`00
00=1U@000000100000@]5000ESEF=@<0009Em003001oogoo00Qoo`03001oogoo01moo`07001oogoo
Ool007oo00000Woo00@007oo000000EW>@03001JeP0000EW>@03001W>FLi00UW>@03001cW7>L00Mc
W003001cW7>L008000YW>@03001JeU[F00=JePP000036<H002DY00L000<U:@80008U:@03000aS000
00<mk`03001>Ldic00I>L`T000IJeP9oo`03001oogoo00Yoo`003Goo1@000Woo00<007ooOol00Woo
00<007ooE[D00eJe1ekg0fLi15Je0fLi16<H1f]J0fmk2f]J1fLi0eJe148@136<0aS61bDY12e[0bDY
13W>0d8@14ic0e:D15[F0eJe15kg0e[F15kg0Woo00<007ooOol05Goo0P000goo00<007oo00000Woo
00<007ooOol00Woo100000IjR`00000007oo0005Ool200001EZI001:gD[M00000ejG0P0000=Ze`00
Jo/01@0000=^]000Nc@00P0000MoL`00GS@004fB001o4@0300000gl/00000002EUP20002MoP50000
0`QA00126@020002;A@01@00ESD0046E00000UGd0`001goo0P008Goo00<007ooOol00goo00<007oo
Ool00P000U[F0`000fLi00<006LiIcT00VLi0P0000=JeP0000002VLi00<007>LLi`017>L0P0000=W
>@0000000W>L0`0026Li00<005[FF]H02@000aS600<002DY9BT02bDY00<0036<000013g_00<004ic
CW<014ic0P003e[F0Woo00<007ooOol02Woo000?Ool01`00Oomoogoo001oo`0000=oo`03001ooeJe
00=F]@MNm`=W>@AF]@=W>@AS60M[FP=_N`][FPMW>@=F]@A240@aS0<HaPLU:@@]J`<U:@@icP=240A>
L`=BU0AJeP=F]@ANm`=JePANm`9oo`03001oogoo01Eoo`03001oogoo009oo`03001oo`00009oo`03
001oogoo009oo`04000iD`00OZ/2000017YX001oogoo1P000eZI0`000UjG2@000VJg00<007/dNc@0
0P0000AoL`00GSAN=0800003Oa400000014000926@d000Uoo`04001oogooOol20004Ool00`00Oomo
o`0DOol01000Oomoogoo0P000goo00<007ooF]H00e[F00<006LiIcT01fLi00<005[F00002FLi0P00
27>L0P0000AW>@00LiacW08000QW>@03001JeU[F00<00003?Nl0036<00<aS0@000PU:@8000<U:@03
000aS00000@mk`03001>Ldic00=>L`80015JeP9oo`03001oogoo00Yoo`003goo00<007ooOol00goo
00H007ooOomoo`00Ool4E[D7G_L3IcT4E[D3IcT4HaP7JeX3Kg/;JeX7IcT3E[D4@Q04<H`36<H79BT4
;F/39BT4>Lh3@Q04CW<3DY@4F]H3E[D4G_L3F]H4G_L00goo0000000GOol30003Ool01@00Oomoogoo
000017oo00@003UC001nZ`800006NVP00000001Jo0000TkM00<004;N00000`000U8h0P000Uif1`00
0VJg00L007/d001be@00Og<00002GS@200000glA0000000300001Sec001B=`00@KD000=F=@800003
8EL0015I00<00006BST0058gDSL0058g0P0000LeM@00001:N`00Ool00007Ool00`00Oomoo`02Ool0
1P00Oomoo`00Ool001Eoo`05001oogooOol00004Ool00`00OomJeP04F]H00`00IcUW>@06IcT00`00
F]H00009IcT00`00LiacW009Li`01000IcT000001VLi10000U[F0P000Sg_00<0036<<H`01C6<00<0
02DY9BT012DY0`000S6<0P0000@U:@00000mk`D00003CW<0000000800003F]H0000000<0009JeP03
001JeU[F00QJeP9oo`03001oogoo00Yoo`003goo00@007ooOomoo`8000Aoo`03001ooekg00=Nm`=J
eP]S60=W>@ANm`=_N`A[FP=cW0A_N`=W>@ANm`=:DPA>L`<e[@@]J`@e[@=6<@@aS0Lmk`<e[@AF]@MJ
ePMW>@=BU0]F]@9oo`03001oogoo00ioo`D0009oo`03001oogoo009oo`03001oogoo009oo`03001o
ogoo00=oo`800003OZ/0000000800004KgX005[lF_`200000e:K00000003Kg/00`00DSP000040000
1UlK000006nK001?7PD00006L]D007mcOg<005hd0P0000=o4@0000000`0000@mL`00DSL00091]@03
001F=EHe00H0009J^P8000=B=`03001B=`0000800003=]l00000008000Ioo`8000=oo`07001oogoo
Ool007oo000057oo0P000goo0`000Woo00<007ooF]H015[F00<006LiIcT01fLi00<006LiIcT016Li
00@006LiIcT000acW003001W>FLi00EW>@@0009JeP<00003?Nl0000000LaS0@0008U:@8000<aS080
008aS003000aS00000L000AJeP03001W>FLi009W>@03001JeU[F00<000QJeP9oo`03001oogoo00Yo
o`003goo00D007ooOomoo`0000Eoo`03001ooekg00=Nm`=JeP]S60=W>@ANm`=_N`A[FP=cW0A_N`=W
>@ANm`=:DPA>L`<e[@@]J`@e[@=6<@@aS0Lmk`<e[@AF]@MJePMW>@=BU0]F]@9oo`03001oogoo011o
o`07001oogooOol007oo00000Woo00<007oo00000Woo0P001Goo0`0000AS6P00LT`0009_NP800004
DWT005:KDY/8000015if001ke`000VnK1P0000=>5`0000000Wmc0P0000IN=000Oa5o4@00N_430002
?G<01P00DSL0046e001F=@<00003@I@003Ee00@00005BST00000001F=`070002KaP00`00Oomoo`05
Ool01@00Oomoogoo00000Woo00<007oo00007Woo00<007oo00001E[F00<006LiIcT036Li00D005[F
001W>@0000ecW004001W>FLiIcT50002CW<2000014ic000000000c6<00@0036<<H`aS080008mk`T0
008mk`03000aS36<00<000UJeP03001W>FLi00AW>@04001JeP00CW<20007F]H2Ool00`00Oomoo`0:
Ool000ioo`8000=oo`<000=oo`03001ooekg00=Nm`=JeP]S60=W>@ANm`=_N`A[FP=cW0A_N`=W>@AN
m`=:DPA>L`<e[@@]J`@e[@=6<@@aS0Lmk`<e[@AF]@MJePMW>@=BU0]F]@9oo`03001oogoo011oo`07
001oogooOol007oo00000Woo00<007oo00000Woo0P001Goo00<006kF00000V<J1@000e9i1P0000<j
>`0000000P0000=ke`00GYP00`0000EWW@00001[>P00009>5`<00005EUP00000001o4@0200002G[a
001beG;E000mL`00DSL00002@KD40002@I@01000=GD004hG0`000UHg0P0000E5eP000016FP00009_
608000Ioo`@00007Ool007ooOol007oo00007Woo00<007oo00001E[F00<006LiIcT036Li00D005[F
001W>@00009cW0l000=JeP03001>L`0000A>L`8000<aS003000U:@0000@aS080008mk`T00006?Nl0
0000001>L`001e[F0P0026Li0`002E[F00<007oo000037oo000IOol00`00OomNm`03G_L3F]H;HaP3
IcT4G_L3Kg/4JeX3Li`4Kg/3IcT4G_L3BU84CW<3=Jd4;F/4=Jd3AS44<H`7?Nl3=Jd4E[D7F]H7IcT3
DY@;E[D2Ool00`00Oomoo`0@Ool01`00Oomoogoo001oo`00009oo`03001oo`00009oo`03001oogoo
00Aoo`03001^eP0000<0008Eg003001WO00000T00003F_`000000080009NV0030012F`00008000=[
>P<00004NmL005IHEUP200001GlA000007[a00000W;E20000U7C0P0000I1U000=GD004hG0002?KH0
1000ESL000000TGF0P0000EN^@00001F=P0000Qoo`03001oo`0000Aoo`03001oogoo01eoo`03001o
o`0000EJeP03001W>FLi00]W>@04001JeU[F0002IcT20008IcT30006F]H01000CW=>L`0014ic0P00
0S6<00@002DY9BT000DaS003000mkcg_00/00004?Nl004ic0005F]H2000:IcT00`00F]IJeP08F]H0
1000Oomoo`0037oo000IOol00`00Oom[FP03JeX3E[D7HaP7IcT4E[D7IcT3F]H4E[D3DY@4E[D3AS44
E[D3=Jd48@P4;F/39BT4JeX3Mkd4Kg/3BU84F]H3G_L;JeX3HaP4F]H3E[D4BU82Ool00`00Oomoo`0@
Ool01`00Oomoogoo001oo`00009oo`03001oo`00009oo`03001oogoo00Eoo`03001c5`00009Ff`80
0003AY`0000000H0009:FP0;001Jo0000016FP00GYP007_F0012F`06000016mJ001ke`000UIH0`00
00=V]P00N_400P0000Ibe@000000045c0002AI<00`00DM=Ad`020002@I@01P00=GD004hG000m]P80
009be@<00003G[T00000009F=P03001oo`0000Ioo`8002Eoo`04001oofLi0005F]H00`00IcUW>@0:
IcT01@00F]IJeU[F000026Li0`002E[F00@004ic0000009>L`04001>L`000002<H`01@009BTU:BDY
00000c6<40000Tic00<005[FF]H00U[F00<006LiIcT02fLi00<005[FF]H01e[F00@007ooOol000ao
o`006Goo00<007ooJeX00f]J0eJe1f<H1fLi15Je1fLi0e[F15Je0e:D15Je0dHa15Je0cF]124812e[
0bDY16]J0gNm16mk0dYB15[F0ekg2f]J0f<H15[F0eJe14YB0Woo00<007ooOol03goo0P0017oo00<0
07ooOol00Woo00D007ooOomoo`0000Qoo`@00003DSL0000000@0009>V`04001:g@00BUX;00000dKM
0000000:000013Wi000007[a2@000TFC00<0057CDM<00P0000=1U00000000P0000=>5`00?KH00P00
0W;E00<005jHGYP00P0000ANM`00ESIF=P8000=oo`<00003Ool007oo02Aoo`04001oofLi0005F]H0
0`00IcUW>@0:IcT01@00F]IJeU[F00001fLi00<005[FF]H02U[F00L004ic000004ic001JeP030000
0c6<000U:@049BT300000bDY000000040005Li`200000e[F000000020003F]H00`00IcUW>@0=IcT0
0`00F]IJeP05F]H01@00CW=oogoo000037oo000IOol00`00Oom[FP03JeX3E[D7HaP7IcT4E[D7IcT3
F]H4E[D3DY@4E[D3AS44E[D3=Jd48@P4;F/39BT4JeX3Mkd4Kg/3BU84F]H3G_L;JeX3HaP4F]H3E[D4
BU82Ool00`00Oomoo`0NOol00`00Oomoo`08Ool50002AY`:00000emM000fWP030002D[/20002H_X4
00000d/N001>g@04000013Wi001jl@000SiL1P000TFC00<0057CDM<00`0000=>_000CUT0100000=B
NP00L]D00P0000ANV000001NM`80009F=PD000Aoo`03001oogoo02=oo`05001oofLiIcT00003F]H0
0`00IcUW>@0:IcT00`00F]IJeP02F]H00`00IcUW>@05IcT00`00F]IJeP0;F]H01000CW=>L`000U[F
10002BDY1@001g>L00<006Li00001U[F00<006LiIcT03fLi00<005[FF]H01E[F00@007ooOol000ao
o`006Goo00<007ooIcT00fLi0ekg16]J0f<H1ekg15[F0f]J15kg0f<H16Li0ekg15[F0e:D15Je0bDY
12U:11cW0g>L16Li0f]J17>L0f<H15kg0fmk16<H0fLi16]J0fLi15kg0eJe15:D0Woo00<007ooOol0
3Goo1@000Woo00<007ooOol00Woo00@007ooOomoo`8000Qoo`<00004DSL007OhMoP200000e9i0016
W00?00001E^n001RnP00Jc/01P0000=c=`0000000`0000Ejl@00000004hG00@00005@G<004FC001A
d`020000135E000004jl0P0000<e]`00DWX00U9j0P0000I_F@00001[6@00GWL60006Ool00`00Oomo
o`0SOol00`00OomW>@02IcT00`00F]H0000=IcT01@00F]IJeU[F00002FLi1P0025[F00<004ic0000
0U[F0`001bDY00<002DY00000P000VLi0P001g>L00<006Li00001E[F00<006Li000046Li00<005[F
F]H015[F00@007ooOol000aoo`006Goo00<007ooIcT00fLi0ekg16]J0f<H1ekg15[F0f]J15kg0f<H
16Li0ekg15[F0e:D15Je0bDY12U:11cW0g>L16Li0f]J17>L0f<H15kg0fmk16<H0fLi16]J0fLi15kg
0eJe15:D0Woo00<007ooOol03goo00L007ooOomoo`00Ool00002Ool00`00Ool00002Ool00`00Oomo
o`05Ool20003Ool50003DWT00`00IaYW6P0200001EjH0012F`00D[/00P0000=[nP00ASX0100000M[
>`00FWL004iI0016>@0200000gnE0000000500000dhG0000000300001D5c0015T`00DM<00P0000<a
E@00=U`00P0000=>F@00=KL010000VmI00<006/IJaT00P0000ISO@00000005Xe0006Ool00`00Oomo
o`0SOol00`00OomW>@03IcT00`00IcUW>@09IcT30004F]H01000IcUW>@000VLi0P0026Li0P001e[F
00@005[FF]IJeP<000DU:@X00004IcT000000004Li`00`00IcUW>@020002F]H01@00IcT007>L0000
46Li00<005[FF]H015[F00<007oo000037oo000IOol00`00OomW>@03IcT3G_L4JeX3HaP7G_L4F]H3
JeX4G_L3HaP4IcT3G_L4F]H3DY@4E[D39BT4:DX47>L3Li`4IcT3JeX4Li`3HaP4G_L3Kg/4HaP3IcT4
JeX3IcT4G_L3E[D4DY@2Ool00`00Oomoo`0?Ool00`00Oomoo`03Ool01P00Oomoo`00Ool0009oo`80
00=oo`<000Eoo`<0009>V`@0009W6P04001NV5jH0002@U/500000dHj00000002@OL01000FWMJM`00
0TiI00@007<g001oU@H00003Oe80000000@00004@G<004FCAI<200001G/C000aE@00=U`02P0000AJ
=@00001kE@<00005>ID005XeFSD00006Ool00`00Oomoo`0ROol00`00OomW>@0?IcT00`00F]IJeP04
F]H01000IcUW>@000VLi0P0026Li00<005[FF]H02U[F0`001RDY1@000g>L00@006LiIcT000EcW005
001W>FLiIcT00002F]H01@00IcT007>L00004FLi0P0015[F0Woo00<007ooOol02Woo000IOol00`00
OomW>@03IcT3G_L4JeX3HaP7G_L4F]H3JeX4G_L3HaP4IcT3G_L4F]H3DY@4E[D39BT4:DX47>L3Li`4
IcT3JeX4Li`3HaP4G_L3Kg/4HaP3IcT4JeX3IcT4G_L3E[D4DY@2Ool00`00Oomoo`0?Ool01000Oomo
ogoo0P000goo00<007oo00000Woo00<007oo00000P002goo2@000ejH20000V:h0`000eYg1P0000=J
N00000000`0000AoDP00001N=@<00004@G<004FCAI<200000g/C0000000300001Cfg000005if0000
0VZE00D005XeFSD007]E00<00003>IH00000009J=@05001oogooOol00002Ool00`00Oomoo`0ROol0
0`00Ool0000@IcT00`00F]IJeP02F]H00`00IcUW>@03IcT01000F]IJeP001VLi00<005[FF]H02e[F
0`001bDY10000g>L00@006LiIcT000IcW004001W>FLiIcT20003IcT00`00IcUW>@0BIcT3000015[F
Oomoo`0037oo000IOol00`00OomcW003Li`3JeX4IcT3HaP4IcT7G_L3HaP4F]H3HaP4G_L7F]H7E[D7
:DX4=Jd3Mkd4JeX7Kg/3JeX4G_L3IcT4G_L3DY@4F]H7JeX3IcT4HaP2Ool00`00Oomoo`0?Ool01@00
Oomoogoo000017oo00<007oo00000Woo0P003goo10000T9l00<004[n00000P0000=_nP0000001@00
0V:h0P0000=_n`0000000P000TXi0P000UYh1P0000AkEP00GSEN=@@00095T`04001k4g/C0002GWL5
00000eif001ZU@020002FSD400000beF000000040002Ool20002Ool00`00Oomoo`0ROol00`00Oomc
W002000>IcT00`00F]IJeP02F]H00`00IcUW>@03IcT01000F]IJeP001VLi00<005[FF]H02e[F0`00
1bDY10000g>L00<006Li00001g>L00@006LiIcUW>@8000=W>@03001W>FLi00=W>@H000aW>@800003
Ool007oo00]oo`006Goo00<007ooLi`00g>L0f]J16Li0f<H16Li1ekg0f<H15[F0f<H15kg1e[F1eJe
1bU:13F]0gNm16]J1fmk0f]J15kg0fLi15kg0e:D15[F1f]J0fLi16<H0Woo00<007ooOol03Woo0P00
0goo0`000goo00<007ooOol00Woo00<007ooOol03Woo00<005kkG_/00P0000=>>00000001P0000<H
e00000001`000eig0`0000A_F@00000M5P800003Na8000000080009N=@04000<<0000002AI<01`00
Na<00000GWL006[G00<00003GWH007]E00<00003FSD007<g00@00003;EH0000000@00003Ool00000
009oo`03001oogoo029oo`03001oog>L009cW003001W>FLi00aW>@03001JeU[F008000EW>@05001J
eU[FF]H00003IcT2000>F]H300069BT50003Li`00`00IcT00008Li`01@00IcUW>FLi00001VLi0`00
00=JeP00F]H00U[F00<006LiIcT02fLi0Woo00<007ooOol02Woo000IOol00`00OomcW003Li`3JeX4
IcT3HaP4IcT7G_L3HaP4F]H3HaP4G_L7F]H7E[D7:DX4=Jd3Mkd4JeX7Kg/3JeX4G_L3IcT4G_L3DY@4
F]H7JeX3IcT4HaP2Ool00`00Oomoo`0OOol2000>Ool500000dhh000U^@030002<A<500001b6j001R
]f:g000eUP00009NM`80009_F@03001^eP0000@00003NeH00000009N=@0:000<<000@G<004FC001k
4`00MeP20002J]L2000015if001kE@000Vkf0P0000=c=`00<IL00P0000<]EP0000001`000Woo00<0
07ooOol08Woo00<007ooLi`00P0046Li00@005[FF]H000EW>@04001JeU[F0004IcT00`00F]IJeP0=
F]H200000c6<000U:@049BT50003Li`01000IcUW>@001g>L00<006LiIcT01FLi00@006LiIcT0009J
eP04001>L`000002F]H2000;IcT2Ool00`00Oomoo`0:Ool001Uoo`03001oof<H00IS60AW>@YS60AN
m`=S60ANm`=S60MNm`AJeP=Nm`A:DP<e[@@U:@@]J`M_N`=[FPM_N`AS60=cW0AJeP=:DPM>L`AW>@MS
609oo`03001oogoo025oo`03001oogoo00aoo`@0009>>0@00003<A<0000000800004;GH000000002
H[L01@00=IH005ig00000U:k0P000VkF1P000WLf00D005he000000``00D0009gF005001Zef[G001g
^00200000g]E00000002K_H:00000gLE0016>@03000015Xe001oo`006Woo0`000goo00L007ooOomo
o`00Ool0000BIcT01000F]IJeP001FLi00@005[FF]H000AW>@03001JeU[F00aJeP<00003<H`002DY
00DU:@@000AcW003001W>@0000QcW003001W>FLi00=W>@80009W>@04001JeU[F0003CW<300000e[F
001W>@09IcT2Ool00`00Oomoo`0:Ool000ioo`<000=oo`03001oogoo009oo`03001oof<H00IS60AW
>@YS60ANm`=S60ANm`=S60MNm`AJeP=Nm`A:DP<e[@@U:@@]J`M_N`=[FPM_N`AS60=cW0AJeP=:DPM>
L`AW>@MS609oo`03001oogoo029oo`03001oogoo00]oo`<00004CK<00000FQ@400000fJg000a=003
0002BQP00`00H[L0000300001Ukk000004XH001^eP80008j>`03001c5`00009g=P03001N=@000080
0003KaL00000008jG0<00003J]L0000000<00003NeD006/I00d00003L]D0000000800004FSD007oo
000JOol00`00Oomoo`02Ool00`00Ool00002Ool00`00OomW>@0CIcT01000F]IJeP001FLi0P001FLi
00<005[FF]H035[F0P0000@mk`00<H`000DU:@D000AcW0<000McW003001W>FLi00=W>@07001cW000
IcT005[F00001dic100026Li0Woo00<007ooOol02Woo000>Ool00`00Oomoo`02Ool00`00Ool00003
Ool00`00OomS6006HaP4IcT:HaP4G_L3HaP4G_L3HaP7G_L4F]H3G_L4BU83=Jd49BT4;F/7Kg/3JeX7
Kg/4HaP3Li`4F]H3BU87CW<4IcT7HaP2Ool00`00Oomoo`0SOol00`00Oomoo`0:Ool2000026ZD001=
/`00FQ@001b@0003I[L300000bef001:60070002DSH00`00BQP00002JcX400001E/Z00000000GSD0
4P0000=[6@0000000P0000AcK@00001>5`@00004MaD007;E0002GSD01@00FSD007oo00006goo00L0
07ooOomoo`00Ool00002Ool2000EIcT00`00F]H00005IcT30003IcT2000=F]H01`00CW<003g_000a
S00000DU:@D000IcW08000McW005001W>FLiIcT00002Li`01@00IcT005[F00002Dic00<005[F0000
1VLi0P0000=oo`00Ool02goo000?Ool01`00Oomoogoo001oo`0000=oo`03001oof<H00IS60AW>@YS
60ANm`=S60ANm`=S60MNm`AJeP=Nm`A:DP<e[@@U:@@]J`M_N`=[FPM_N`AS60=cW0AJeP=:DPM>L`AW
>@MS6003Ool0000002Ioo`8000Yoo`03001ZU6ZD00D0000379000000009V]`03000a=00000<00005
Fa`000000016>P020002DSH200000fNm00000002000017<G000000000TVd00H005he001_5`00MmT3
0002BSP500000bEG0000000200000fli000000030002CQL40002L]D200001ehe000005Xe001oo`00
01Yoo`07001oogooOol007oo00000Woo00@007oo000000EW>@8000eW>@03001W>FLi00EW>@03001J
eP00008000EJeP03001JeU[F00MJeP07001>L`00?Nl0036<000012DY1P003g>L00D006LiIcUW>@00
009cW003001W>@00009JeP03001>Ldic00M>L`03001JeP0000D00004F]Ioogoo000<Ool000moo`07
001oogooOol007oo00000goo00<007ooCW<00dic0e[F15:D0fLi16]J0fLi1f<H16Li1ekg0f<H1ekg
14Ha0c6<12DY148@0f<H1g>L16mk0f]J16<H0fmk16Li0eJe1dYB15Je0dic14YB0Woo00<007ooOol0
9Woo00<007ooOol01goo00<006ZDJY@00`0000<0M000000030000V;I0P0000ANV000001Wo0800003
D[/0000000<00003ESH004Vd0099]0H0009NfP<00006EUL007_FNmH002EG100000=g500000000Uif
0P0000Ec5P00000007;E00800003GSD00000009J=@03001oo`0001Uoo`03001oo`00009oo`03001o
o`00009oo`04001ooe[FF]H50002F]H00`00IcUW>@0CIcT00`00F]IJeP04F]H200000fLi00000007
F]H20002?Nl00`00<H`000049BT500000fLi001cW00<Li`00`00IcUW>@02IcT02@00LiacW7>L001W
>@00F]H00009CW<00`00F]IJeP05F]H200000goo001oo`0;Ool000ioo`03001oo`00009oo`03001o
o`0000=oo`03001oodic00=>L`=JePABU0=W>@A[FP=W>@MS60AW>@MNm`=S60MNm`A6<@<aS0@U:@A2
40=S60McW0A_N`=[FPAS60=_N`AW>@=F]@M:DPAF]@=>L`A:DP9oo`03001oogoo02Moo`03001oogoo
00Ioo`04001ZU6ZD0002MeL200000d9l001gE`04000016Ki0016FTIJ0P000V;I1P0000AO6`000000
009:_080009F=P030019]4Vd00T00003G]T005IG00H0009:NP@0009NMP80009c5P800003L]D007LE
00<00005FSD00000Ool0000JOol00`00Oomoo`02Ool01P00Oomoogoo001oo`<000=JeP<00003F]H0
06Li01AW>@03001JeU[F009JeP03001W>FLi00=W>@03001JeU[F00AJeP80008mk`04000aS0000002
9BT300000dic00000002IcT00`00LiacW009Li`20004IcT01@00LiacW7>L00000VLi00@005[F0000
00Q>L`03001JeU[F00@00004CW=oogoo000<Ool000moo`03001oogoo009oo`03001oogoo009oo`03
001oodic00=>L`=JePABU0=W>@A[FP=W>@MS60AW>@MNm`=S60MNm`A6<@<aS0@U:@A240=S60McW0A_
N`=[FPAS60=_N`AW>@=F]@M:DPAF]@=>L`A:DP9oo`03001oogoo02Qoo`03001oogoo00Eoo`03001Z
U6ZD00H0009gE`<00003I_T0000000X00004Ga`000000002E[X20002LcL01000ESH004Vd200000I6
N`00G]UNf@00LcL300001Cgh00000000F]X00P0000M^]@00000006>?001c5P030002MaD300000eXe
001o/P02000SOol00`00Ool00002CW<30003CW<2000FIcT01@00F]IJeU[F00001FLi00<005[FF]H0
0e[F00H004ic000003g_0003<H`70003IcT00`00LiacW008Li`00`00IcUW>@04IcT01@00LiacW7>L
00000fLi00@005[FF]H000A>L`05001>LdicCW<00002F]H01000CW=>Ldic0Woo00<007ooOol02Woo
000IOol00`00OolYBP03:DX3>Lh4@Q03CW<4IcT7G_L7HaP3IcT4G_L3HaP4G_L3BU84AS43BU88HaP3
IcT7Mkd4Nmh3F]H4IcT3Li`7JeX4E[D3?Nl4BU83E[D4CW<2Ool00`00Oomoo`0YOol20006Ool30000
0bVi000000050002BW/400000f<K001BVP0200000fli0000000200000e^n00000002000025kk001c
=g<g001F=P00BK@200000b2b0000000:000015na000003gh10000Vje00<006Ki0000100000ERM@00
MaEg5@00009Ze`03001o/Wnb008002=oo`03001oo`00008000I>L`03001JeP0001IW>@04001JeU[F
0005IcT00`00F]IJeP02F]H00`00CW=>L`0300000cg_000000070003IcT00`00LiacW009Li`00`00
IcUW>@03IcT00`00LiacW002Li`00`00IcUW>@02IcT01000F]IJeP000Tic00<003g_00000dic00<0
05[F00000dic0Woo00<007ooOol02Woo000IOol00`00OolYBP03:DX3>Lh4@Q03CW<4IcT7G_L7HaP3
IcT4G_L3HaP4G_L3BU84AS43BU88HaP3IcT7Mkd4Nmh3F]H4IcT3Li`7JeX4E[D3?Nl4BU83E[D4CW<2
Ool00`00Oomoo`0[Ool00`00Oomoo`03Ool200000goo0000000:00000eJI0000000300000fli0000
0002BUT200000dXi00000002000016^L000006_j0P0000A9]000000P/PH00004BW/00000LcL80000
0f_l001^]@0400001E7e0015m`00HWD010000V[G1@008goo00<007oo<H`0200000A>L`00F]H000EW
>@8000mW>@<000EW>@03001JeU[F008000=>L`800004CW<003g_?Nl60004IcT00`00LiacW003Li`6
00000fLi001W>@03IcT00`00LiacW003Li`00`00IcUW>@02IcT01P00F]IJeP00CW<0008mk`04001>
Ldic0002F]H00`00CW=>L`02Ool00`00Oomoo`0:Ool001Uoo`03001oobU:00<YBP<icPA240=>L`AW
>@MNm`MS60=W>@ANm`=S60ANm`=:DPA6<@=:DPQS60=W>@Mg_@AkgP=JePAW>@=cW0M[FPAF]@<mk`A:
DP=F]@A>L`9oo`03001oogoo02aoo`03001oogoo009oo`07001oogoo001FE`00LcL00P000TiI0`00
00AFV@00001BV`@0009S6`<00003BST006_l01/0009>V`@00005K[D00000DSP00002DOD00`00AOL0
0004Ool200001Goo001oogoo00008goo00D007oo0000036<008000@mk`03001>L`00008000AW>@03
001JeP00008000iW>@03001W>FLi00=W>@03001JeP0000E>L`<00003CW<0000000@000IW>@03001c
W7>L009cW003001oogoo009oo`800004IcT000000002IcT00`00LiacW003Li`00`00IcUW>@03IcT0
1000F]H0000013g_00@004icCW<0009JeP80009oo`03001oogoo00Yoo`006Goo00<007oo:DX00bU:
0cW>148@0dic16Li1ekg1f<H0fLi15kg0f<H15kg0dYB14Ha0dYB26<H0fLi1gNm17_N0e[F16Li0g>L
1f]J15Je0cg_14YB0eJe14ic0Woo00<007ooOol0;Goo00<007ooOol01Goo00<007<g0000100000A[
V`000000009[F`03001RnV;j00X00003F]/004hh00<00003>E<004gf00800005;A<00000000Y5004
0002BW/200000c5F00000003000015ZH000000000V:G0P000U7e0`0027oo00<007oo00008goo00@0
07oo9BTU:@800003<H`0000000<mk`@000AW>@05001JeU[FF]H0000=IcT00`00F]H00003IcT01000
F]IJeU[F0P000Tic0`0014ic1P0016Li00<007>LLi`00P001Goo0P0000AW>@00F]H0009W>@03001c
W7>L009cW003001W>FLi00=W>@07001JeU[F001>L`00?Nl00P000Tic00<005[FF]H00e[F00<007oo
000037oo000IOol00`00OolLi`037>L38@P4<H`3=Jd4G_L3HaP4E[D7HaP:G_L7F]H4Kg/3DY@4AS44
DY@3IcT7Nmh4JeX3F]H7JeX4HaP3CW<4DY@3CW<4G_L3IcT4G_L2Ool00`00Oomoo`0^Ool20005Ool2
0002FUH400000e[l0000000200000e9i00000005000025<M000005kj001Jf`00CSP300001CUC0000
0000@G<00P0000<P/P0000002P0000I:V`00001JV000Bg420002HYL01000DSP0000037oo00<007oo
00008Woo00<007oo00000bDY00<0036<<H`00`000Sg_0`000fLi00<005[FF]H00U[F00<006LiIcT0
2FLi00@005[FF]H0009W>@03001JeU[F00AJeP800003F]H005[F00<000=>L`80009JeP04001W>FLi
0002Li`00`00Oomoo`04Ool200001fLi001JeU[F001W>@0000AcW003001W>FLi00=W>@05001JeU[F
F]H00002CW<01@00CW=>Ldic00000e[F00<005[FF]H00Woo00<007ooOol02Woo000IOol00`00OolL
i`037>L38@P4<H`3=Jd4G_L3HaP4E[D7HaP:G_L7F]H4Kg/3DY@4AS44DY@3IcT7Nmh4JeX3F]H7JeX4
HaP3CW<4DY@3CW<4G_L3IcT4G_L2Ool00`00Oomoo`0`Ool00`00Oomoo`03Ool00`00FUIJEP060000
1EJk001BN@00Jk`00P0000=>^`00000010000Ukj0`0000=RU`00CM@0100000=1L`0000001@0000<n
>P000000100000@aEP00Jg][N`@00004NkP00000Ool3000=Ool2000ROol00`00OolHaP0200029BT0
0`00<H`aS002<H`50004IcT01@00F]IJeU[F00002VLi00<005[FF]H00U[F00<006Li00001e[F1000
0U[F00H004icCW=>L`00CW<2000015[F001W>@000W>L00<007ooOol00goo00D007>L001W>@00009J
eP03001W>@0000AcW004001W>FLiIcT40002F]H00`00CW=>L`02CW<20002F]H200000fLi00000002
Ool00`00Oomoo`0:Ool001Uoo`03001ooacW00<Li`<Q20@aS0<e[@ANm`=S60AF]@MS60YNm`MJePA_
N`=BU0A6<@ABU0=W>@MkgPA[FP=JePM[FPAS60=>L`ABU0=>L`ANm`=W>@ANm`9oo`03001oogoo035o
o`03001oogoo009oo`03001JEP00008000Aooa800004HYL00000CM@200000c4C0011L`0500000bTD
0000000300001D6e00000000Dch00`0000EBg000NkQk^00000=oo`03001oogoo00aoo`80029oo`03
001ooaS6008HaP03000U:BDY00@0008aS0P000AJeP03001W>FLi00IW>@D0009JeP03001JeU[F00EJ
eP800007IcT00000001JeP00CW<00P0000Hmk`00CW=>L`00F]H20002Li`00`00Oomoo`02Ool01P00
LiacW000IcT0009JeP03001W>@0000=cW003001W>FLi00800004F]H004icCW<70002F]H20005IcT0
0`00Ool0000<Ool001Uoo`03001oobDY00<U:@<Q20@Li`<YBPM>L`ANm`=S60AW>@=S60AW>@=JePMB
U0@e[@<aS0@e[@ABU0=_N`Aoo`=kgPAS60=W>@M_N`ABU0=240A>L`MNm`=JePA_N`9oo`03001oogoo
039oo`03001oogoo009oo`8000aoo`05001Ad`000015T`0600001E:J00000000CM@00P0000<a4`00
@G<00P0000<a=00000000P0000<]=@00=GD01P000Ujh0P0000=>V`0000004goo0P008Woo00<007oo
6<H00P001bDY1@0015[F0P000U[F00<006LiIcT036Li00<005[FF]H02E[F1`000cg_00D004icCW<0
05[F0080009cW003001oogoo009oo`03001cW00000=W>@800003IcT007>L00=cW008001W>FLi001J
eP00CW<000=>L`03001JeU[F00AJeP03001W>FLi00AW>@9oo`03001oogoo00Yoo`006Goo00<007oo
9BT00bDY0b4811cW0bU:1dic15kg0f<H16Li0f<H16Li0e[F1e:D13F]0c6<13F]15:D0fmk17oo0g_N
16<H0fLi1fmk15:D0d8@14ic1ekg0e[F16mk0Woo00<007ooOol0<goo00D007ooOomoo`0000eoo`06
001Ad`000015T`000TVc0P0000A9/`00000mD`<00003>E<0000000800005;A<00000000Q5P050002
@U/300000ejh00000002000AOol4000TOol00`00Ool0000:9BT00`00<H`000020004F]H200000e[F
001W>@0=IcT00`00F]IJeP09F]H:00002Cg_000005[F001W>@00Li`00005Ool00`00Li`00006IcT0
0`00LiacW002Li`02@00IcT005[F001>L`00?Nl00002CW<00`00F]IJeP04F]H00`00IcUW>@020002
IcT2Ool00`00Oomoo`0:Ool001Uoo`03001oobDY00<U:@<Q20@Li`<YBPM>L`ANm`=S60AW>@=S60AW
>@=JePMBU0@e[@<aS0@e[@ABU0=_N`Aoo`=kgPAS60=W>@M_N`ABU0=240A>L`MNm`=JePA_N`9oo`03
001oogoo03Aoo`8000moo`08001Ad`00CK<004FC0019/`800004BK<00000?E<3000013UC000003ee
2P0000<eM@00000010004Goo1000:7oo00<007oo9BT012DY1P0000<U:@0000001P000U[F00<006Li
IcT03VLi00<005[FF]H00U[F0P000U[F1P001C6<00D003g_000005[F0080009cW003001oogoo00=o
o`8000IW>@03001cW7>L00=cW006001W>@00001>L`000cg_00<004ic00000U[F1`000U[F00D006Li
001oo`0000aoo`006Goo00<007oo9BT00bDY0b4811cW0bU:1dic15kg0f<H16Li0f<H16Li0e[F1e:D
13F]0c6<13F]15:D0fmk17oo0g_N16<H0fLi1fmk15:D0d8@14ic1ekg0e[F16mk0Woo00<007ooOol0
=Woo00<007ooOol037oo00P0057C001=/`00AI<004Vc0P0000=9/`00?E<00P0000Le<`00>E<0034C
000mM@0200001C4d00000000EYX01P0047oo1000;7oo00<007oo9BT012DY00<001S66<H00QS600@0
02DY000aS0<0009>L`04001JeU[F000?IcT00`00F]IJeP02F]H00`00CW=>L`050004<H`01000<H`a
S36<0P0000A>L`000000009cW003001oogoo00=oo`8000EW>@8000IcW004001W>@000002CW<00`00
?Nl00002CW<00`00F]H00003IcT00`00F]IJeP03F]H01@00IcT007oo000037oo000IOol00`00Ool]
J`03;F/38@P46<H38@P4;F/3?Nl4E[D3HaP7G_L7DY@4CW<3@Q04;F/3:DX4BU84Li`3Mkd4Ool3JeX4
F]H7Li`3Kg/4DY@3CW<4E[D3IcT4BU83CW<4JeX2Ool00`00Oomoo`0gOol00`00Oomoo`0;Ool02000
DM<004fc0015T`00BK<200000dVc000mD`0200001cDc00000000<A<003ee00T00003Ga`0000000eo
o`@002Ioo`<000=oo`06001oogooOol007oo12DY00<001S66<H00aS600<002DY9BT00P000Sg_0P00
00A>L`00F]H000eW>@8000AJeP03001>Ldic00=>L`03000mk`0000<aS080008aS003000mk`0000<0
00=cW003001oogoo009oo`03001cW000009W>@04001W>FLi0007Li`01000IcT000000dic00L004ic
CW=>L`00F]H00003IcT00`00F]IJeP03F]H01@00IcT007oo000037oo000>Ool30003Ool00`00Oomo
o`02Ool00`00Ool]J`03;F/38@P46<H38@P4;F/3?Nl4E[D3HaP7G_L7DY@4CW<3@Q04;F/3:DX4BU84
Li`3Mkd4Ool3JeX4F]H7Li`3Kg/4DY@3CW<4E[D3IcT4BU83CW<4JeX2Ool00`00Oomoo`0hOol00`00
Oomoo`0:Ool02000DM<004fc0015T`00BK<200001DVc000mD`00?E<0100000@a4`00001oo`800003
EUL0000000@000]oo`@002Yoo`03001oogoo009oo`03001oo`00009oo`03001oo`0000<U:@03000H
aQS600@HaP05000U:@00<H`00002?Nl00`00CW<00002F]H00`00IcUW>@03IcT70005F]H00`00CW=>
L`04CW<20003<H`00`009BT00002<H`50003Li`00`00Oomoo`03Ool20002IcT200000fLi001cW007
Li`01000IcT000001Tic00<005[F00000fLi00<005[F0000100000EJeP00001oo`0000aoo`003Woo
00<007ooOol00Woo00<007oo00000goo00<007oo;F/00be[0b4811S60b4812e[0cg_15Je0f<H1ekg
1e:D14ic0d8@12e[0bU:14YB17>L0gNm17oo0f]J15[F1g>L0fmk15:D0dic15Je0fLi14YB0dic16]J
0Woo00<007ooOol0>Goo0P002Woo00P0057C001=/`00AI<004Vc0P0000M9/`00?E<003eC000e<`04
0003Ool2000=Ool4000_Ool00`00Oomoo`03Ool00`00Oomoo`0200001C6<000U:BDY00001QS600<0
02DY9BT0100000<mk`0000001P000VLi1@001E[F0P001Dic100000<aS00000000`0000<aS0000000
0P0000=W>@00Li`00W>L0P000goo00T007>L001W>@00F]H006Li000027>L00@006Li000000E>L`04
001JeU[F0003IcT20004CW<00`00F]H00002Ool00`00Oomoo`0:Ool000moo`03001oogoo00=oo`06
001oogooOol007oo12U:0b4811cW0aBU2b480be[16<H0fLi15[F0cW>11S60aBU12480dic16Li17Nm
0g_N16<H0ekg1f]J16Li0f<H15Je0dHa15:D0fLi14YB0e:D16Li00=oo`000000?Goo00<007ooOol0
1goo00H0057C001=/`00AI<6000023eC000mD`00=C<002Te000?Ool4000cOol01000Oomoogoo0P00
0goo00<007oo00000bDY00<001S66<H01AS600@002DY9BTU:@@00003?Nl0000000D000IW>@03001J
eU[F009JeP03001>Ldic009>L`L000039BT0036<008aS0800004CW<000000003Li`200000g>L0000
00030003IcT30008Li`200000fLi00000006CW<00`00F]H00003IcT20004CW<00`00F]H00002Ool0
0`00Oomoo`0:Ool000moo`04001oogooOol20004Ool00`00OolYBP03:DX38@P47>L35:D;8@P3;F/4
HaP3IcT4F]H3>Lh46<H35:D48@P3CW<4IcT4Mkd3Nmh4HaP3G_L7JeX4IcT3HaP4E[D3AS44DY@3IcT4
BU83DY@4IcT2Ool00`00Oomoo`0lOol00`00Oomoo`06Ool01000DM<004fc0`0000AAm0000019e@P0
00aoo`@003Ioo`03001oo`00009oo`03001oogoo009oo`03001oo`0000<U:@03000HaQS600HHaP03
000U:BDY008U:@X000IW>@05001JeU[FF]H00003CW<700039BT00`00<H`aS00200001Dic000006Li
00000W>L00<007oo00000W>L0P000VLi00<006LiIcT00VLi00<007>LLi`00g>L0`000VLi00<005[F
00001Tic00<005[F00000VLi00<005[F000014ic00<005[F00000Woo00<007ooOol02Woo000>Ool0
0`00Ool00002Ool00`00Oomoo`03Ool00`00OolYBP03:DX38@P47>L35:D;8@P3;F/4HaP3IcT4F]H3
>Lh46<H35:D48@P3CW<4IcT4Mkd3Nmh4HaP3G_L7JeX4IcT3HaP4E[D3AS44DY@3IcT4BU83DY@4IcT2
Ool00`00Oomoo`0mOol00`00Oomoo`05Ool00`00DM<0000200000dge001Am00200001TWE0011]P00
AQT000]oo`@003]oo`04001oogooOol30002Ool00`00OolU:@049BT00`006<HHaP066<H200049BT9
0006IcT01@00F]IJeP00CW<0300000LU:@00<H`004ic001JeP020003Li`01@00Ool007>L00000VLi
0`000fLi00<007>LLi`00g>L00<006LiIcT00fLi00@005[FF]H0009>L`0;001>LdicCW<005[F001W
>@00F]H00004CW<00`00F]H00002Ool00`00Oomoo`0:Ool000moo`04001oogooOol30003Ool00`00
OolYBP03:DX38@P47>L35:D;8@P3;F/4HaP3IcT4F]H3>Lh46<H35:D48@P3CW<4IcT4Mkd3Nmh4HaP3
G_L7JeX4IcT3HaP4E[D3AS44DY@3IcT4BU83DY@4IcT2Ool00`00Oomoo`0nOol20005Ool00`00DM<0
0002000014ge001Am57d0P0000A9e@00@KH000Qoo`@004Qoo`03001oobDY00@U:@03000HaQS600LH
aPP000039BT0000000l00003<H`0000000LHaP03000U:@0000L0009cW0@00003Li`0000000D0009W
>@03001cW7>L009cW003001W>FLi00=W>@80009JeP03001>Ldic0080009>L`07001JeP00IcT005[F
000014ic00<005[F00000Woo00<007ooOol02Woo000IOol00`00OolU:@039BT78@P37>L;5:D77>L3
5:D47>L38@P49BT37>L4AS43JeX4Nmh4Mkd7G_L3JeX4Kg/3JeX4IcT3E[D4BU83AS44E[D3IcT4CW<7
DY@2Ool00`00Oomoo`10Ool00`00Oomoo`02Ool01@00DM<005iE00000Tge00D0057d000004WE0080
00Eoo`@004aoo`03001oobDY00<U:@03000HaQS6010HaP80008U:@l000039BT001S600DHaPL00003
IcT007>L00McW0<000IW>@03001cW7>L00=cW003001W>FLi009W>@05001JeU[FF]H00003CW<20002
CW<01`00F]H006Li001JeP0000E>L`80009oo`03001oogoo00Yoo`006Goo00<007oo9BT00bDY1b48
0acW2aBU1acW0aBU11cW0b4812DY0acW14Ha0f]J17_N17Nm1ekg0f]J16mk0f]J16Li0eJe14YB0dHa
15Je0fLi14ic1e:D0Woo00<007ooOol0@Goo00@007ooOomoo`<0009NE@04001=m@00DO@30003Ool4
001@Ool00`00OolU:@039BT00`006<HHaP0B6<H300000bDY0000000800059BT00`006<HHaP026<H6
000016Li000007>L0P001G>L0P000U[F00@006LiIcUW>@8000EcW003001W>FLi00=W>@04001JeU[F
0003CW<20002CW<00`00F]H00002IcT00`00F]H00006CW<200000goo001oo`0;Ool001Uoo`03001o
obDY00<U:@LQ20<Li`/DY@LLi`<DY@@Li`<Q20@U:@<Li`A6<@=[FPAkgPAg_@MNm`=[FPA_N`=[FPAW
>@=F]@A:DP=6<@AF]@=W>@A>L`MBU09oo`03001oogoo049oo`04001oogoo0002FUH01000GUD004ge
0P000Woo1000E7oo00<007oo9BT00RDY00<001S66<H02QS61@001aS6300012DY0`0000<HaP000000
100000=W>@00Li`00P000Woo0P0000=cW00000000P000U[F00@006LiIcT000McW003001W>FLi009W
>@04001JeU[F0004CW<20002CW<00`00F]H00002IcT00`00F]H00007CW<00`00Ool0000<Ool001Uo
o`03001oob4800HQ20@Li`XHaP@DY@LHaP<Li`LU:@@e[@=BU0AW>@=kgPA[FPABU0=JePM_N`A[FP=W
>@AS60=>L`A240=6<@AF]@=[FPAF]@=6<@@mk`9oo`03001oogoo04=oo`800003Ool005YF00P005Qo
o`03001oobDY008U:@03000HaQS600/HaP03000<H`00018HaP03000U:BDY00HU:@H00003IcT007>L
009cW003001oo`0000H00003IcT00000009W>@03001cW7>L00AcW08000EW>@03001JeP0000=>L`80
0007?Nl004icCW<005[F00000VLi00<005[F00001dic0Woo00<007ooOol02Woo000IOol00`00OolQ
20068@P47>L:6<H45:D76<H37>L79BT4=Jd3DY@4IcT3Nmh4JeX4DY@3F]H7Kg/4JeX3IcT4HaP3CW<4
@Q03AS44E[D3JeX4E[D3AS44?Nl2Ool00`00Oomoo`15Ool7001LOol00`00OolU:@039BT00`006<HH
aP0;6<H00`006<HHaP0A6<H00`009BTU:@059BT500000e[F00000005Li`00`00Li`000020002F]H0
1000IcUW>FLi0P001G>L0P001VLi00@005[FF]H0009>L`05000mkcg_?Nl00002CW<00`00F]H00003
IcT00`00F]H00006CW<00`00Ool0000<Ool001Uoo`03001oob4800HQ20@Li`XHaP@DY@LHaP<Li`LU
:@@e[@=BU0AW>@=kgPA[FPABU0=JePM_N`A[FP=W>@AS60=>L`A240=6<@AF]@=[FPAF]@=6<@@mk`9o
o`03001oogoo04Ioo`80061oo`03001oobDY00<U:@03000HaQS601hHaP03000U:BDY00@U:@H00006
F]H006Li001cW00017>L0P0015[F00@006LiIcT000IcW003001W>FLi00IW>@03001JeP00009>L`03
000mkcg_008mk`0<001>Ldic001JeP00IcT006Li001JeP0014ic0P000Woo00<007ooOol02Woo000I
Ool00`00OolQ20068@P47>L:6<H45:D76<H37>L79BT4=Jd3DY@4IcT3Nmh4JeX4DY@3F]H7Kg/4JeX3
IcT4HaP3CW<4@Q03AS44E[D3JeX4E[D3AS44?Nl2Ool00`00Oomoo`2XOol00`00Ool00004000N6<H2
00059BT7000025[F001W>@00Li`007oo0002Li`20005F]H01000IcUW>@001W>L00<006LiIcT01VLi
00<005[F00000Tic00<003g_?Nl00Sg_00P004icCW<005[F001W>@000VLi00<005[F00000Tic00<0
03g_?Nl00Woo00<007ooOol02Woo000IOol00`00OolHaP036<H37>L46<H75:D36<H45:D37>L48@P3
7>L4=Jd3E[D4HaP3Kg/4Mkd3JeX4F]H4JeX>Kg/7IcT3E[D4DY@3BU84E[D3Kg/4JeX3F]H4DY@2Ool0
0`00Oomoo`2XOol00`00OolHaP0Q6<H00`009BTU:@029BT;00001VLi001W>@00Li`0009cW004001W
>FLi0003F]H200000fLi001cW007Li`00`00IcUW>@05IcT00`00F]H00003CW<50002CW<01000F]H0
06Li0P000VLi00D005[F000004ic0080009oo`03001oogoo00Yoo`006Goo00<007oo6<H00aS60acW
11S61aBU0aS611BU0acW12480acW13F]0eJe16<H0fmk17Nm0f]J15[F16]J3Vmk1fLi0eJe15:D0dYB
15Je0fmk16]J0e[F15:D0Woo00<007ooOol0Z7oo00<007oo6<H08AS600<002DY9BT02`0000AW>@00
001cW0<00005Li`00000IcT00002IcT30002IcT00`00LiacW008Li`00`00IcUW>@05IcT00`00F]H0
0009CW<01`00F]H006Li001cW000009W>@800007F]H00000CW<007oo000037oo000IOol00`00OolH
aP036<H37>L46<H75:D36<H45:D37>L48@P37>L4=Jd3E[D4HaP3Kg/4Mkd3JeX4F]H4JeX>Kg/7IcT3
E[D4DY@3BU84E[D3Kg/4JeX3F]H4DY@2Ool00`00Oomoo`2XOol00`00OolHaP0J6<H500000aS6000U
:@0>0005Li`200001FLi000005[F00000VLi100037>L00<006LiIcT016Li00<005[FF]H00P001dic
00D005[F001W>@00009cW005001W>FLiIcT00002F]H200000goo001oo`0;Ool001Uoo`03001oobDY
00<U:@<DY@@@Q0LHaP<Li`@Q20<aS0A:DP=Nm`McW0A_N`=[FPMS60AcW0M_N`A[FPMW>@=S60MJePA:
DP<icPABU0=:DPM_N`AF]@9oo`03001oogoo0:Qoo`03001ooaS600LHaP03000HaQS600lHaP03000U
:BDY00<U:@<00003<H`0000000@000=W>@03001cW7>L00IcW004001W>FLiIcT20002IcT00`00Liac
W00=Li`00`00IcUW>@04IcT00`00F]IJeP02F]H00`00CW=>L`02CW<01000CW=>L`000U[F0P000g>L
00D006LiIcUW>@00009JeP9oo`03001oogoo00Yoo`003Woo0P0017oo00<007ooOol00Woo00<007oo
9BT00bDY0aBU11241aS60acW12480c6<14YB0ekg1g>L16mk0f]J1f<H17>L1fmk16]J1fLi0f<H1e[F
14YB0cW>15:D0dYB1fmk15Je0Woo00<007ooOol0WWoo0P0017oo00H007ooOomoo`00Ool76<H2000@
6<H00`009BTU:@0<0003IcT20007Li`20006IcT2000;Li`50007IcT00`00F]IJeP02F]H02@00CW=>
Ldic000mk`00CW<00003F]H20003Li`20002IcT01@00F]Ioogoo000037oo000@Ool01P00Oomoo`00
Ool000=oo`03001oobDY00<U:@<DY@@@Q0LHaP<Li`@Q20<aS0A:DP=Nm`McW0A_N`=[FPMS60AcW0M_
N`A[FPMW>@=S60MJePA:DP<icPABU0=:DPM_N`AF]@9oo`03001oogoo0:1oo`06001oogoo001oo`00
0Woo00<007oo6<H01AS600@000aS36<000dHaP8000049BT00000<H`900000fLi000000020007Li`2
0007IcT00`00LiacW009Li`2000;IcT00`00F]IJeP03F]H01000CW=>L`000Sg_00D004icCW<005[F
00D000=cW0<00004F]Ioogoo000<Ool000moo`07001oogooOol007oo00000goo00<007oo9BT00bDY
0aBU11241aS60acW12480c6<14YB0ekg1g>L16mk0f]J1f<H17>L1fmk16]J1fLi0f<H1e[F14YB0cW>
15:D0dYB1fmk15Je00=oo`000000XGoo00L007ooOomoo`00Ool00002Ool500026<H500076<H60000
12DY0000036<300027>L0`001fLi0P002W>L0P002fLi0P001U[F00<004ic00000Sg_00@003g_001>
L`80009>L`800003IcT007>L009cW003001W>@00009oo`03001oogoo00Yoo`0047oo00H007ooOol0
07oo0003Ool00`00OomcW003Li`3Kg/4HaP3G_L4F]H3HaP4IcT3Kg/7Li`4Kg/3IcT4HaP3G_L4IcT;
Kg/3JeX4Li`7IcT3F]H;CW<3DY@4@Q03AS44G_L7IcT2Ool00`00Oomoo`2POol01P00Oomoo`00Ool0
009oo`03001oo`0001L00003<H`0000000P000UcW0<000UW>@03001cW7>L00]cW003001W>FLi00QW
>@03001JeU[F00EJeP04001>LdicCW<20003?Nl00`00CW=>L`02CW<00`00F]H000020002Li`00`00
IcT00002Ool00`00Oomoo`0:Ool000ioo`03001oo`00009oo`03001oo`0000=oo`03001oog>L00=c
W0=_N`AS60=Nm`AJeP=S60AW>@=_N`McW0A_N`=W>@AS60=Nm`AW>@]_N`=[FPAcW0MW>@=JeP]>L`=B
U0A240=6<@ANm`MW>@9oo`03001oogoo09ioo`03001oo`00009oo`03001oo`00009oo`03001oo`00
020000UcW08000aW>@03001cW7>L00]cW003001W>FLi00MW>@04001JeU[FF]H50006CW<01000?Nlm
k`001Dic0P000VLi0`000VLi00<007oo000037oo000?Ool00`00Oomoo`02Ool00`00Oomoo`02Ool0
0`00OomcW003Li`3Kg/4HaP3G_L4F]H3HaP4IcT3Kg/7Li`4Kg/3IcT4HaP3G_L4IcT;Kg/3JeX4Li`7
IcT3F]H;CW<3DY@4@Q03AS44G_L7IcT2Ool00`00Oomoo`2OOol00`00Oomoo`02Ool01P00Oomoogoo
001ooal000UcW08000eW>@03001cW7>L00QcW003001cW7>L009cW003001W>FLi00EW>@05001JeU[F
F]H0000<CW<200000cg_00000003CW<00`00F]H00006IcT2Ool00`00Oomoo`0:Ool001Uoo`03001o
ogoo00=oo`=kgPMoo`]kgP=g_@A_N`=[FPAJeP=Nm`A[FP=W>@]_N`A[FPMNm`=[FPMS60AJeP=[FPAJ
eP=Nm`A>L`<e[@A6<@MS609oo`03001oogoo0:Qoo`03001oo`0001X000acW003001W>FLi00EW>@80
00AW>@8000UcW0800003IcT007>L00=cW003001W>FLi00AW>@05001JeU[FF]H0000;CW<01000CW=>
L`000Sg_0P000Tic0P001VLi0Woo00<007ooOol02Woo000IOol00`00Oomoo`03Ool3Nmh7Ool;Nmh3
Mkd4Kg/3JeX4F]H3G_L4JeX3IcT;Kg/4JeX7G_L3JeX7HaP4F]H3JeX4F]H3G_L4CW<3=Jd4AS47HaP2
Ool00`00Oomoo`2XOol00`00Oomoo`05OolC00000goo001cW009Li`20008IcT20003IcT00`00Liac
W008Li`00`00IcUW>@02IcT01000Li`000001fLi00D005[FF]IJeP0000=>L`<000=>L`800004F]H0
04ic0004?Nl00`00CW=>L`020005IcT2Ool00`00Oomoo`0:Ool001Uoo`03001oogoo00=oo`=kgPMo
o`]kgP=g_@A_N`=[FPAJeP=Nm`A[FP=W>@]_N`A[FPMNm`=[FPMS60AJeP=[FPAJeP=Nm`A>L`<e[@A6
<@MS609oo`03001oogoo0:Qoo`03001oogoo00aoo`@000Uoo`03001cW7>L00IcW08000]W>@04001W
>FLi000;Li`00`00IcUW>@03IcT00`00IcUW>@08IcT01000F]IJeU[F0`000e[F0`000U[F00D005[F
001>L`0000@mk`<00003F]H006Li00=W>@9oo`03001oogoo00Yoo`006Goo00<007ooOol00goo0g_N
1goo2g_N0gNm16mk0f]J15[F0ekg16]J0fLi2fmk16]J1ekg0f]J1f<H15[F0f]J15[F0ekg14ic0cF]
14Ha1f<H0Woo00<007ooOol0Z7oo00<007ooOol06Goo00<007>LLi`00g>L2@002FLi00<007>LLi`0
2G>L00<006LiIcT01@002VLi0`000U[F1P000e[F0P000U[F00<004ic0000100000Dmk`00001JeP00
00=W>@9oo`03001oogoo00Yoo`006Goo00<007ooOol0LWoo00<007ooOol0Z7oo00<007ooOol0LWoo
00<007ooOol02Woo000IOol00`00Ool00002Ool01@00Oomoogoo00000Woo00D007ooOomoo`0000=o
o`04001oogoo0003Ool01000Oomoo`000goo00@007ooOol000=oo`04001oogoo0003Ool01000Oomo
o`000goo00@007ooOol000=oo`04001oogoo0003Ool01000Oomoo`000goo00D007ooOomoo`00009o
o`05001oogooOol00002Ool01@00Oomoogoo00000Woo00D007ooOomoo`00009oo`05001oogooOol0
0002Ool01`00Oomoogoo001oo`000:Yoo`03001oo`0000=oo`05001oogooOol00002Ool01@00Oomo
ogoo00000Woo00D007ooOomoo`0000=oo`04001oogoo0003Ool01@00Oomoogoo00000Woo00D007oo
Oomoo`0000=oo`04001oogoo0003Ool01@00Oomoogoo00000Woo00D007ooOomoo`00009oo`05001o
ogooOol00003Ool01000Oomoo`000goo00D007ooOomoo`00009oo`05001oogooOol00003Ool01000
Oomoo`000goo00D007ooOomoo`00009oo`03001oo`0000aoo`006GooMP00ZWooMP0037oo003oOonl
Ool00?mookaoo`00ogoo_7oo003oOonlOol00001\
\>"],
  ImageRangeCache->{{{0, 442.75}, {137.625, 0}} -> {-0.0834201, -0.0234425, 
  0.00715267, 0.00715267}, {{11.625, 142.688}, {134.313, 
  3.25}} -> {-7.74939, -4.98711, 0.283311, 0.283311}, {{155.813, 286.875}, {
  134.313, 3.25}} -> {-1.59828, -0.217582, 0.00916616, 0.00916616}, {{300, 
  431.063}, {134.313, 3.25}} -> {-85.6539, -3.83126, 0.274458, 0.274458}}]
}, Open  ]],

Cell[TextData[{
  "When using ",
  StyleBox["ListDensityPlot", "Program"],
  ", it is convenient to avoid having to type the desired options every time. \
This can be accomplished by setting the desired options once with the ",
  StyleBox["SetOptions", "Program"],
  " command."
}], "Text"],

Cell[BoxData[
    \(opts = Options[ListDensityPlot]; \n
    SetOptions[ListDensityPlot, Mesh -> False, \ FrameTicks -> None]; \)], 
  "Input",
  CellLabel->"In[12]:="],

Cell[TextData[{
  "With such a simple representation, it is easy to manipulate individual \
pixels or groups of pixels to achieve a desired effect. For example, by \
adding (subtracting) a constant value to (from) the image array we can modify \
the average brigthness of the image. Multiplicative operations can change the \
contrast of the image.  A negative image may be obtained by subtracting pixel \
values from the maximum luminace value ",
  Cell[BoxData[
      \(TraditionalForm\`L = 255\)]],
  " (for an 8-bit image).  Note however that ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "'s ",
  StyleBox["ListDensityPlot,", "Program"],
  "  automatically adjusts image contrast for best viewing conditions. Use \
the ",
  StyleBox["PlotRange", "Program"],
  " parameter to turn off luminance autoscaling, when not desired. Consider \
the following example:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[
      GraphicsArray[\n
        \t\t{ListDensityPlot[A/2, DisplayFunction \[Rule] Identity, 
            PlotLabel \[Rule] "\<Autoscaling On\>"], \n\t\t\t
          ListDensityPlot[A/2, PlotRange -> {0, 255}, \n\t\t\t\t
            DisplayFunction \[Rule] Identity, 
            PlotLabel \[Rule] "\<Autoscaling Off\>"]}\n\t]]; \)\)], "Input",
  CellLabel->"In[13]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .47619 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0113379 0.47619 [
[ 0 0 0 0 ]
[ 1 .47619 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .47619 L
0 .47619 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0113379 0.477324 0.464853 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00751202 0.0192308 0.00751202 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[.5 1.0125 -44.0938 0 ]
[.5 1.0125 44.0938 12.875 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
gsave
.5 1.0125 -105.094 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.875 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.875000 moveto
 460.000000 16.875000 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.875000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.187500 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Autoscaling) show
135.187500 13.000000 moveto
(On) show
147.187500 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
128 string
128 128 8 [128 0 0 128 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
020201000501010300040302040201050503020101030500
000000020002040005020304040103040401010401030200
000300020200040003040000040004010202020000040004
020000010403020402010301000100040106020200000201
040100000204010200020201040100030200010002040201
0003020004020101
010101040400000203020203030201040004020003020104
000300010004000204040101010202030300030202020202
040103000404010200020401020502030402040103030402
020100010201070201010100000202010201030002030001
020303010200060802050204010300020201000402060302
0202020400020202
020000000004020000020200010103010002060000030202
010304030102030201000302010004020001000202020200
020204020402030803000402000102040403010000000101
000001010002020000040100020003020102000000040001
010101050201020403040101040000040001040102000404
0103020303000200
020202000601000001030204010201000004000304040400
010200020203010004000201010304040201020101000400
010202000001050202030000020003000301030100040001
040001020000030200000601070300030200010400000000
010002000004010002010000040003020000020003020605
0900050202020000
040302000104010000040000030204020401040201040403
000002050304010404000003040502000102000207030203
000202030001040002020004040101000101000402030204
000003040500020102000002040007040003030100010202
010002000300020103010300010300000200000404010006
0400000203020000
030408030300010403030200040003020101020102030400
000502010002010004020405000001020400000100010404
000401010000000002040002000100020000010200000204
020102030204000202020400020202040100000200010300
040200020202000000000002000400010301040404000301
0402000200000200
020201040004040304010103010004000203000001000303
000100010104000201030400010304000102010102000000
020301000001040400010300040104000402030300000402
040000030200020101000300000200040404040001040202
030000040204000100020100000100020102010201000002
0304050700000204
000002000002070101030002030200000105000302000000
000003040300050406000300030501000003000301050305
000004000301000000040003020101010301000000020201
030001020304010202040203030000010404030000020401
020002020302020401010300030400050101020401040304
0100030202000001
020201030402050000010204020000000300020102020204
010001020103020401000001040103020104010003050402
020201020202020605010200020002010402040000020303
030000020301030404000403020201020302020204000305
040000010000000000020004030003000101000504010100
0303010300020104
020001020402010400020201020400040401000102040401
020101030201040004010402040102000300000200000300
000301030001010002030003020301030404020001020000
000206000104020400000202030000020001000304020201
030104030101010003020401040104020200010000040201
0104030100040204
040300030001000005020004000002020101000400030101
040202040303020100000202010206000004010103000302
030201040302030304000001010400010200010101020403
040304000003010004020002010203060104010402010302
020006020602020301020403030100030203020102020003
0200000004000102
010303040400020204020002000202020400030703030102
000302000104020000040400000308000202040301020001
020000000200000502000304010400070001010002000302
000A03000303000100000102020104020402000100010001
000109010101040304020401000001000001000200020402
0204000200020300
020402060004010204020102000302000300000103000400
020201010200020001040100040102020103020102010100
010502030001010002030300050204010200000104040002
020400010104000400010004020000020004040006000102
080000040004000000000203000200010000020301010101
0203020003000101
010402000300040202010100040202020300040303000003
030103040400000103000302050100000002010403010201
030005040404000201000302020001020000030303000102
000101020002000203000000040402040202010201010300
020200040000020000030603000400040405010000000201
0004020001060000
000100020404010002000002040200020204010402010201
010200030400000002020101010003020404000200010002
020201040102060001040004000402040003000000010303
010102040000010403030001000400010401020100020002
020200040003020400020102010101030102040204000300
0301020100000603
000103010405000200010101000404000401000003010003
000001040301000402030202010001030404000102010301
000200000100040302000200000201000002040400050002
000400000202000303000100020000010000010200030100
040105040202030403030202010002030301020104020004
0104020000020200
000005020504000100000203000104000202030203030002
020002000403010102010404020001040003050100030502
020203000004040104000302020600000000020000000001
040202020202040207070300030200000204010300010000
000504020404020100000407060402000400020002010002
0400020002000304
020200010200020204010000040000020002000002000508
040303030304030202000102020102040300000102000401
020303030002020203000201030002040200000101000200
020000050503020003020001000400000200020100000403
020001030000040208000102000203000004020000030303
0000020004020404
040003020300010103040004030402000203020401000401
010100000200000200060000050402010203000205000001
010204030103030100020405000200040400020204020502
040002000000010402040100020200010004010101000102
000400030102020302040302020400020200040200000205
0000000106020104
050303010B05040904041105060600040513146958363748
1C192B0E18304253565E535E55504E3D47433A353624483F
4859441E10046C364C73697279311B292F596056625A270F
191C2B292D49454234513229352531371E24242C2B162D04
0B03070804040D02040404080400020406000B0401031303
0402020909080502
000A05070B00040C0506030A030A0C090604326F4B3D3C1B
0D0610113C3F554E68525D535252483D5345323D37253252
2A667F5E260C3C42291B1F1B1B161238375161525C523713
112B2E37444F42423C3C46151C1D2D3F2E35172533232714
01030700090300040204070507020000050A050502060A0A
0203060405040802
00060C04010E0F0A02010808080F0E0B0B13596242503109
12281801041F474D635B59594F442F2A374C3C3D322F1132
4F4A6931210624581B21101D1016232235426966594C480B
1C38453A3944544D2E3D4C1E2D0B36383D21312E27402830
0B04090003040A0604020403020205090D0B0402000E0504
0B06040606070404
030905010517050C0D08070202030A040A125F38515C4411
1F271900050B195B6955545B4D41373D4048403C20292028
5E5A5A7F1F0B1054281916141E172823312A696C5C605825
2B2A23323F533C3736424C232C102C3241261B302F451735
070A0E04000712040304040308020B080104020C0B06010A
0600040103050207
0002040603100D0A0F030A0004090B0209136653645E4F1C
11310606111215446563605D544D4E41363D39370F162438
4067672B2525051C4F1019221921281B3231646C5B646459
413F423D292524262C22224222151E3B4244281D4141422D
3210110404050B0D0404040204020404080A06050F04010C
07000A0302010108
0203020D04040D040A060B0A040E0F060D105063576B5843
2A21210608130B646B6F4E5F584C4E39212F383F17222A2A
4D64412006111B146611141D1B1C131B3727487363585F44
6141524E372420120A021D301525202E484823263D334519
311005090102060A02040A06030A060903010A070B040606
09040501050C0206
0A02080A07040304040A0202080E070D0D0454715F646557
1B2D29040A03044C36394148524D5446292E4130382D2D12
42644D1B0904210D481D110A0A0F18091626367C7C667142
595F0D211B221E2019131C471C3D362936473926313C5E37
2C23050302020A0A0806030B040206020C0A040D04050407
0404010309020608
0806080D0E040906010A090C0C1104010A05366F56616E4E
2139282C170C3F3330313B4547575348383130523B21231B
566F67161B120A126F210A0D1F130C0A202D3C696F6B7253
470E1B1C18152529202B1F42303A32194A5355393A495A45
123C1411000106110B0B08050D0707020606060505020509
0E10000109020301
04030A070E0909020A08050F03080A0204061086676F6C56
143B3C383A2175424F504A4E666D6C68543A2D4038273334
675E595B1106190A5E475F83828A6D64712E2C3E6F7A6F64
3A120B0C1828312C1C252F422C1B41254646443320475066
4937220B000506000910050A0B08080C10040A0C04020800
0B0F0A0808040806
0601030F0C0B0F0A0B040A080B070B0D0A0A054D61596363
1931133D0E5B61536F534D607373797953402B3B53373746
6669764E1D060B14551E48877B6C6D0D23252A267C7B6868
4256121312261E2D341C4E43453D3848294641432F3C4662
5621430E0A090D04020207070203050A0503120F04070201
0F03080A00040706
07000A0A0A0D0C0805040C08100A040F0B0704265E39765B
101E1321168D72616058525466726F6949341B42603C4444
71719390210E040C22301112200B1B1D1C331D207777686F
6F38462B190F2B363A41421B4C53264E4337473C36365566
584936330200070605040A0909020007050C0F0600060F15
06030F0404040104
080A0D010D0E060004110A010A0C000508051429594A7771
1F1D0C0E5DAC745B585663586F72755D38312653523F3238
6763857610100B15182B201B0E1021140545252B5A7B6F73
7C2547421E251F2A312E412F3F4A363C4F132040563A5B51
5B5F19360D0206090E080606020F05010808090A050E0411
090B0D0308000504
04040F0400050906020E04040511060A0F091C2368316E68
0317060C9E9F5E66635D6E66686D5D5D583F3C524A454044
615F68450A0C0B052536191B151F202C29302027327B7A7D
7841546B20112137262D202E413C4D4A50282B564B44365A
5C6E4D3F340A0806000907040900080009080A050A12010A
03050C0207010401
08090A0510080E040B0E0B0A101212224C376848918B786F
080F0567B0856E575C7961745C6A59514E5652524F59424D
5A6C634C11090F1D2263481915060A28241F2B22257D7F6E
817330486041512920191B3D3E2F525440472D39513E4847
6B6E691B650D04080B0D0E0A070E0A15050A06011606010C
0E0C0B0606000A0F
01101106040A06080A000602001805254E4C53364DAF702E
11041B909A8768657B6567676B6761604D46735341524940
5D714C1901160A13103C2305381E2638222138202A4A8874
7D822C307C312837443B434D583C4C3D4E4B2B37594B604C
6958595244200F03060A0D0A010E04030710090508010400
050C090A0602080A
01040F010A08080C060C020A050314586C6A665C7FB29027
051B3E88837D55686A66676E6E60725D4C59635E544F566A
565F3D71222423180A0F28452C36313434362C2E2D3D788D
7A8843425464727E7368646A6B444559475B3F3F56595054
625A6279285B04060702030609090404000C0606010A0101
080F040A08050B02
040301060C030A02070A0D0A0A0A0B5C7579908C8A7C7436
0C177962495C6460756F76636B78586F63767180726C4D4D
6C514D8E3C31330A2652631C192107072A14344238207B73
6D7F6C2F3450683D5D765E3649465A585E67211E42445153
57543E7A5D4219020A03050204121406100403040C0E1504
06070C0407050E06
0F02050B050805070B0F0C050B0E084241756C6F9C625919
365082535C7289907C736A4D676450715E71856E6844496F
706E5378617552271D246C321E3116242B241D2423344E83
777A852A2E41091909232335363D567A4043523D413D5A4D
4B1E53AC892E51040700030A0A040A0208070409060B0D11
0E0D0E0A0B020305
0709060910060409060F0606020707190F748AA3220E4520
3A56744587827C756D6877697B72785F69717A6352416A8E
6D60537A7F857A392226413B2B2112191915123C28353385
84766D4339671B3332234F6F3B416D6251596F5E3C484F61
50426EB097524727160B040A10130404040A090C0C09090F
061001020A070F06
1708060C03130C080B050E140B0C061F0A42754730330F6F
6E6C7466849B8D948C70787A7A5E5D686E727F7A5A467984
6D65718C7F96AA69221C32253C2A251C3F1B062E34282984
8E686B79383F6F103D1D2D37293655556C545A602B283241
5254438088802C560F110E0C0B040E040A0708050F110F06
020A0A030F150901
0E0A10090F011308080709170C0F123066227B7D43173057
86725C9084A7A48179796A6D795D72746A6C736B655D876B
6D5C808D808B967D1521860D5D46101C220F092E3830225E
838779842437427F32496B352C5748412B65617384372B45
4D58504872904F30470504080901060800040A070E07120A
040E06090E080204
0C06030D06070A0A02040B0E080510694F688F6745293305
5CA5747F8C8589736C7565778D796D67695B6B5A736D6E5D
65566C7E8B779B902612700C4C401F101F2B0829132A2429
8B8F82804A3E3162822758435F6A36472C6E797974843B44
3F5557425388962D532C1309090309090305130510070E09
0315030A0D040F01
0C090300000107060A04000A020C66A56E796D816C152C0F
25596A8274767B69647E877478777663625E60636C80727A
587C766F907A904E14132B0B5E3D1618191929130E3F2720
958A8B986830333B4D5F392F5B6746754C584C4671645F3B
54485C4C4D5383702645220C0E040C08040B0A0F09110C02
110702090B0A0B06
0B0A0B0A04030F07040C080D0A1B636F755F5985573D2D27
0A184D6B7E6A7C857172807A66837F828265585E72787469
69778B84A6968A3A1E297B192E0B831619200223131C2221
9885878E8B293D3E2D3D6E33412E555652493B4948915258
404D425A58494E995927522B0505060A0903030C0B110A07
0A00030A09130A10
0D0F090604050710090804031206594E5E68698D64692420
0E09163E81937E6E898E6F8177707A7873705D6B7F6C6E55
7896699B8A9590171B17753C160F596821202E33191C2E32
7F8A8A9383323231391B5D6D3752643C203E53382C673B6E
6E3D484C5350486B9553285C161609060E0A0406040A090A
0F100F0700000F0A
08060A00050E0E0B0A0B03091003455D62616A77736F3719
08162A062779A58094A19A7A776C7B716E666979877A606D
96678E9E8592501C0F0C531D260B2C7A13443130051C2F26
778A898D864D3E37323142557F46080A0B15113940293A52
546755585451483B8D8A4E3A55190C050501000403050F02
0F150C060C090B04
0A0C06050E050C06120D0504080B237C6A665F718B585720
0A0A5019164271917A8E888D83727D73756563716E5D6672
707F9D88814E1B010A0C05520E16063E570A0F091F183532
7D99879386833A2F2535402E256F1820181F2F191C0B1808
355D745852694D4A79B0923B4A360706000B0402070A0B08
121B02060D0A0001
0E0B0F08090C150212150A010A0C1C987266687A8D6C704B
11214E2B19034B7194857470846E7980857D6D755A64766A
7A969B9CAB260F0F0616396E2026162F2E1519293F222B31
7096868C829F322E2222262D302836321B2A1E2925161123
0F1D193D6661697462583D69385102080502070406030E0A
1915050607040206
1105090F040B100F140F00030E03259C6962645D90897B59
192F5817172405404F5C768B686869906F7455515F8B726A
9489A1C05A0E0E1329132F704136453966104A2A2225222F
5689988A86954135303520201D2E3B2852410A133A1C3B29
342F1B080E3D6859533D2172444F2702050004060B0D0C0B
130A0F040A080A10
1B04060416050D0A100C070B0B0C30866B53676E918D8068
263C5F200B4139122831545C69748770666F617C9F6E5A98
8CB6D064210D10041B122E756F2626233A603B592C2B2D3D
4C918588828983372A21272B2A23373736584B5828251B05
17081F1F130C0B08181C0F727F4350080606010301060D0C
05060E050B0D0305
070D0906100D060C0A050C0A04052A485244526195858A6E
422C51210B5841061F1E242C36698D83755064536F4E8494
AAB74207130F010F050F206E714730294D7F3265162E2A10
5A8C85868680952E2D2C3C3A3D3130383B3D374227271623
362B22101D1621152F0B066185516411060A070505030B11
0A04100804120407
070A0F02101004040A0115000D041F2F162C40194E865D7A
7A0F30341D2B0B17371B0B09141C3D51B69D7E74928AA3B1
481B1C1B021B0D0A0B0E078C695A2102327F263932332C43
968E8F978D82713225384A44382F1B3366675D543B2D320F
2D463D15302F331603110D12885D6621140B040F040C0E0A
1408100B190D040A
0A070207040A0C01090305050C2E325E582C1B498870402E
6832642E2C09292D0C0F171B1916031C2E181B3C39203B15
0512080B0005171E050D176A5B5B3A5C787E22143C2E5D3D
92838B8D87804E222738473C3C81757F8C6F75716934322B
3D2142414F2613211C1803197C64523F06060C040200040A
0F03020102040202
040B030203080A0C060E0404110F251B170E1033401E451F
431E2C5E3A303A1F32233E1F242105151918373220130931
1719120C0F0C09050E0C122F6F444239822D161D2A56594D
99858388817B352522455B5974787B768A7D7B64876B4348
475930484E64490B231411197A873F580C030A0904040B04
0D050C0C08070802
0B0309060A0E0E435E55180F041E290416212B2821170B25
2B342516443E6968685558656F6A59533D3C14314D5B2D24
320A052302120B0609081D4F6356484F221B00223D302D58
A8858B887F853D282C5058776E739181747E82697A715C46
375552543D755E2415300500769336564011010A010A0A0A
060C060009050504
020A100310062F5B403F2A0E291301070F0A131D0B0F192B
2A190C467432485B554B4950503134463B4521204F3F3C28
372F141F0008051116140A4F595448341643183C302C3D63
8E93808B837A4D36154A64717F718F8A798482826F746E47
3C36596F7957414B242A1F0737A6565D6B1709040608090B
0A0B0F0A0A020C0C
0A050D0B0A05394616090E10090F1353381B231F18052234
4DFFA5453C7B4E481D3745414A2C47444356513E40384830
32100E0907080C080C0A05216E3B390B281928352D31375D
93877A82877E5C293C3B6E807D888B7F6A7D86776C76676F
6B3557644E46625E36293411088E963E5243090104060707
03070F0504060103
0A01040B03093853595A1F08081B2119214619180C2D7B8A
90656548152208330B444037444C3055515459603E3B4D42
291B130E0F0E051E0D1024437251091932432E1436353058
8B8084888E89772A3D54747E7986858071867F8D70737A83
6F53355E5354793D181533260C08A08540592609060E1406
0405000610030605
030F07040A040E54534E49192D180E2419424E412A759088
A1957A603E648164170F265043787C80695E454B29202623
2B1724152B4236414B3A442D4E161C325A3126362D38526A
89858E8B868D902721457A646E7B857979857C72846D6F83
765E2E41404C56511D182C301C070CB2682B540D01080503
0400030A06020A04
090F060309040828415D454531342F415E674A34219EA890
B2A0B1A9B6715E3F12001B2C2B594A6E672542544249461C
2D1F25264F805A443456542829202C2C243635313D778F8B
7B6F94958C80902A303F6D7A7A747E7584798A7A73897E7F
887E634D445D554C1035350D32160505A15E436F12040207
0704060606000500
01050A091607071118375A3F1D3F201B253D494F296AAC9C
B7AC9D8A835E2419210D161D2F37571631533053745E6965
350F03172E3216112739052E22152B4B201E313144A67F82
848D878189898E293231575A7D76908E886B7F856A7C7F76
6E825A2C453F4C5F616C471B2419220B1D8F4B5A2D090804
0208040404000A09
060C08030F0F0C0B0B142A33271F092143614D4042408B79
74747A62592C1D2B2D1924814F513741371647284F5A521E
173915293C2005040D1307350B402C344E231921AC96848D
8A8592868E94902B1C333027397F9A82728A877987687E5E
747E644C533C428083747B7E75483114077465435C080503
0409090B0A010406
0F000A0404080E080208212F28262B52594C48424F696457
4B475672646E4D343F648070346F1E0A434E776F4B3D7161
5D231715110009090B0F1F12282C302F422E2E4E8E898993
8E8A908B878E89321D20162B7F838C7C877B5E6E738F7F74
63843C3E264B838C8769799896822B2B0F0CA05463310D0D
0B15060909020011
05090602050B04040B00112B373E4D435A6446535E606D59
524F5E687A5A395B6E5D2D3D4B5B3244163D64421908293C
210F1B08040D04050E1712180D21260438332990818F928E
8D93929090878D4726252D8B9677819E7F648B7E42897284
824319484D708592A18F748F9E68633A1919298153580C09
0B13080D02090307
06020002010D05050A0606152E574F645B3D325B4C1C652D
2B0A233B5569622F48677C73762D4D1F42461124223A3F4E
210D0F190F0B0507070E13051329190C2E371E8982988B89
8A8E8A8C83898B4423328B6B7D85818292757D84854B6785
8458684C7A7D878B9D938694855E8D681B0E19A6595C0F07
0305030200050804
050105020A0007050F0D08051B41462A484C0F4A5C1F3547
38425F33132148482D13266474695058321132120B306114
1B0A170A070306100D09020B071210123D25328A88938C8B
8B968B8A7F8E7D543137857F80698687949881656E7E5C8A
785F4A677A7D8194A290949B81618B86421B16647256280C
08110A0808020E03
05060B0E100504080C100C0F1520495B405E25211C393237
2B3339592C376026232A50597C7F867938452D3229471016
052B0F000606030B020403101E110E0E2923388E8B8F9691
909299968A958B673C645582755F7669828283818C7F4A85
5E5152708281889191768B905A74968D5E1F09137561450E
0C080B040D0F0508
070B0906040E0A0C030D15090614174452434D1F26313838
29331C31655D4B104D4D6E4347391B230D2C312B0C470B29
1E19040F0607040402150C1B19140728351D5AA18F939193
959896A68F8A8A6F487A777C77567D698590688D61818B38
3D4975677E8D9080717A95857D858A8E731B1609875E3707
070403030F080A08
050500040706090B0B061604070912494F576B4C4C3C3C2E
5038312F547798522321045E0E0C2C203831346042364825
09040009060410061405102A211116543A274D9293929694
9E9A939790858677534E757F8153686D758E62786D845E3E
38686F76798A8F846983965A83907E7E6220240A51515904
0F0D000B02050303
080806080A060D050A110B160D0C0C1B3D545E685E4D3622
2F39457E8053732A0B4312291B2C2E142947232B3B352124
0F040A040506082D415921151C3413583D3465989C968E95
98959BA08A848F8558424D7572505C837A84815B82794E42
7A797B808B8988807A7F90567F8C9485791C29035B536A0A
0D0406050E0B0A02
0414020C0B0404090413160D0F0E170E22493F4F6E81482B
23444F777A2659642B112C1247263B0C2B3D45371B213209
070A0B0815031E2854385E629B267B55393E529692979991
96969880858D83825E492D47715E836B5D827F746C6C4D68
74726E7D8F8C8986598996608B947F9B971C21254D665F26
0604070402030604
000402081B030807100D000609111E0A040E42464D6C5C4A
37321F323A4E182C4B584E363153190922426A231224302E
040F0511250B1258AA655747550B5A473E3232999797A397
9B8D87878A8D96895D463D3637725F8553857C6E62645F79
76767A9285726F63789083507E89838D8A54242227665B2B
030107000E130F04
00050A0A10140A09150F0C0A14110F0D0A101B4243324667
2E38402C2A092C30175E2C3522211E0629290A08161B0B28
0B0A1B080F13616146455972322D5D2B272D3D92A5A19795
91868B88808A947D7A94433934598C7C598569635E6C5A71
6D74838B7464667B908D7B4C6884917D905F1B15285A5A32
0A0D02081004140B
081306100A050A16110F0B0E0F1019070808031B29263330
38192C4A211F0F13243631170B1D2D0F1612120B1B121816
000A0402043E4128373643614773312331303A71475F8B85
848F848B8286888A87907C383E3981834F735947475A6778
7D888D908A7B7A8A7F687A597B958683A15D1E10108F6329
060A09020A040A0A
090C040D0204070F0701030C03070208020A050F260E0721
142E1739441E0B1313421C262119030421353216200E3709
070B1104050A082A2B34343B454031363B3B84834779887C
8B98958A83858A79949B4239473D27273259536F6570627E
7F8C86898770787A7A797C809A888C79906A2A160C7F5627
0D060D0C05030804
04000607060A04040604010705080A040D03020A19071515
0B211C2C4543352F2612192C01181E252C19111B0C29190D
1905050512344A59A6A99A755D56323C3C33342E4C646D85
94978B978C8F7A7095992B37442C2B4252677F878A98938B
8E7F7569656885787E9992959C9F8C99A89912200A7B6324
0B0E0A080A090102
0602020A090C050D0C0C0D0A080B041102060407150F1303
202E3B2D3B3C3F06200F03103928110C10150F151B0D102E
53639A44354C527369676D718793BC84524D3D6C86748799
A2A0A1A6988F6D8F9B732F2B2F3B1D265D6478707989938F
855960475087885C6B868A79938D98959D8D0E0F09686819
0B07060A01070702
0407040404070C1203090F09150C040E060A0B0107111920
23534315290E19200F271E0F121F151F27263D2419237A8D
6374B2A889847C88877E8444264B499B8B718A8F8E98959B
A39B949090827D9984352A282728415669666A6764777B6F
7C878883808D8D53696C889585808A899476220B016B6311
0E0404050C070808
00070A02080803040604040003040406050A0A01082B5179
712C1E2D2318474709050D1C2F283110165DA09D55686A8F
8F90A6AB9D87847E908F743D464A457884858E77908B9397
9B9297958E8E785C462536353F35515D6F717C78817D839D
A38E7990A08F7F8A7E7D8E8F7D918D857E2915140F80630F
0507070604080902
0C080C02080A030703060206040304010411050A06532F9E
5B271E161E101B2E353D39150C1B3C60918B728479695C69
7D7B74838A8C7B76838E7D6727497F837F88898A8D819C97
A19B8E84686F4B404D60455558497B7D7F8D8D70767B797B
7E616381A191989A9D868178767B83745912150E27857718
0C050C010A0A0206
04040100040A06080704040002020205060A0A061640796F
2E2407231E14160F0B141C186D8895C39B958B715D797D7C
7B83808F9186808775837F636F7F919279898B90907A8F8F
80787578607649323F3696A59C697E86929595877E786971
707B68849A9595999E888273737A836251030E073F796E19
090D070504080204
0203040305060304040002060102010404080A082E428471
0704030E15130411041943928E8DACAC9E90798C8C8C8F8F
857F7E8283878895827C727E8787888F85928985837D9684
8A8C847E737B363D2CA18F969D89819B888F9591847A757D
81826C73878F829897756F736D776F4A3D0F1B103C74780A
0702080304030503
020304040002010100040103030202060202030657659333
040E190F0F040F172369AF90837884A0AD828A9F9D8F8284
7B767E828D9493958E7D777A7E7B86A0938D8A8D84858B7E
87837E7E7A783A3C4CA4939A9B95849184747F93928D8B9F
A18F7F64908B7A8790786269707170591C1C0C0A506A6F0F
080B090504010003
0200040806040403040204040802020502080406746F7C19
0909040C00041037929EA08D958F9D958A82989D917A7275
7A888A8B8C90979B9A8A84867983828A898E8B8A89828A84
87848280836A4A373F9C9A95999C899F80656D6D8F8B8896
A0A67F6C7C69647988795A6E758274770212011C5359540A
060D0A0708040502
0000030403000003030501040006070306070107736A6906
00020403040D164785BBC2B0AC9A959EA7A2967E7377758B
93898683959DA49B8B8A7F644F4A4C6D80738F948C878A8D
81848783836448335F879EA29B968B9B90786869766F6877
85A6937353766C767474706F74867B6D0E100A315B68340A
0406080704060700
0102040301010105020307020106040203000A0967536C14
1405020806085D8593AEB7B6B6B59A90897F7270747B8E91
817B8BA4A2A6A096857F70554D3B383D4F5C6F8E83858A8A
8C848981686266878B8EA3A7AA7E8F9D9595765566776C6D
6A8F88666E7C7568775B646773786F390F180B3B5C6A1D09
090C0A0700030201
03040006000406010202060101090002040009042A675A37
080604040A09A38C9592A0A1A5897E606E6F69687B938F81
7B989B9AA9AEA38A6E565E5A5645382A32444984877B8A8A
848284807D9874607190A9AC957E9497886F746E858E837A
6D8C8F797D79755066664254696A5A0F170D0F3E6F620C0E
0807060503020002
00070001000402020004060000040200000401000D74484B
0C0706050C0C72868895999A876B606A6A787E899A8D8076
859AA2B7BBAF855A3B53645C574B3D33312C386F6E85878D
878F7E73744A464D7099AFAD8A919B98725B6E85847E988F
8B9195978E7B6856747A807C3D606D031B13193C72630A05
090C010A08030104
00040204000205030200040304050206000603040D4A7F77
2805040109063C67696A92968449667E8A95A5AB90817276
9C9EA6B3B3A15B2136494C5354463D4131263143587A8783
8475736F5F423D669DA5B392809E9F9B736E7891696F9490
847F7574685D727B919D8F8A7144460F010A2A596D3D0D01
0804070800010303
03030402060104000002000300050502050303040A1B8343
6E160D080B034F7A8C9BAA976C59778C8A736FA389747593
9A9AA2AAB19457252C393C464741383C3229202F302F4189
8F7D5323212E6D8CA5A88882959791887761728C6A718C8F
7974756E6E7B889A8A848B8472592908110B545671180404
0205070600030000
040404010203000108010603040404000102070104074BA1
552C100202026387999F9687696D8BA0775F73837E717F9A
9AA5AAA9B1A56E37282E2F373D3F3C352E2E29201C212B2A
1E2932332A6493ACA48581979A968D786A62798E6C72737A
6F6C738F8BA1867354525D66483F1F04292B3D816C0A0603
0105020404030002
04030003020101000406010004020204040401080A0B1974
566E0B0B0718878B95959C985B70AC8A63687A8477849E96
A09DA1A8A5B4A88B622C2528303737302F2C262722202226
29353649728EA996747F9C9C938F876C5E607A9677635455
544B6F798CA0906C65613C42350F0D02175847674D0D0904
020604040A000201
040104020303020600030402040202030500020001040962
9C2F17070C12848CABA9A3996B85A17D306C84888798A199
999B95A2A4A0A8B2AE8B6B37232528252825202022202C31
2C4D77889BA6937E949A9B9A9C90917B7167769893807562
6F6E63596A7E958A8984714F32070907193B957F0F030203
0105000404020204
000106000202030002040201010604060001040406060813
8C6072160614AA907E8698A58494956D3C73887D7375869C
A39E9B9EA1A9A0A5B0B7AB9D90644D34211B26262B2D4865
859D9D9A9788879E9A9C958D8E8A7D7F685072689A997B76
72707B817D667F838A7A6F56100108095E2F696E0A060504
0405070707000605
080104010200020303030203000404010104020700020100
84614B11110D3276704C8DB0A8A69B7A2C5D61676969769D
A6A69DA99E978F9B9FA6ACAFBABBB0A0998784808A8F9BA1
A19B8F88848E9C999A939D8F917E6F6F6B735C63818F8C8F
5E5E5D74908476717A5D405805060C0C3B8C812D09020202
0009040304020400
05010300020400020001000201020404020000000304040D
3D8575311F280D3B5D8588AFB2A0A77C6371708069687E95
7C7996A19D9B9596A08F91939A9BA4B1ADAEAFABA8ABA79B
937E859591999C9A978186938B8A7D927F856E4C618B8A8B
84693D5C6C8C745D50686E230B06071E3B695F0A02040006
0206040101040104
040404020103020300030203010000010303020705050404
0D967A43091916378D9EB69995989A6F708E9882646E8873
666C7681919298A1A2939D999B98929497949B97928A8A8F
9196929995958A8A71647584859681828DA17C5B6672829E
9C86784B517E7F79827C3C09050C16468B61350704030003
0202050400030506
020005020203020501040104020602040202030200040604
0C547E58190A0B2A7F8A917E9AA39F857A91997B4964735F
6E696F766E798CA0A09B939AA0A09E9D9A9B9E9D9696969A
9A989A9C9590727171595F65727C9784799685727B748AA8
9A8F766457768E847D70280D14111F4F716E100700010204
0704040001020204
000002000702040401020300030100040304000006010506
0A1B96693742230B52786B6B93A8AB9F899697867E56576A
7E735D675A63769895796E6E777E9098989A95A09D9F999C
959D998C807A6A4C616E74693C6A867F7A8B86868B806E85
868B786E686B8982784A0E0D07094874664A030201030008
0604020001050004
030104010002000004010302000400020302020302020402
0C0C7995603B420C4B4E5A52909FAAA19D9D9AA08A756F81
8B73656E616F7278796C616D685E6C6F8891959A94908B80
7D83947A6C6E50787B80858174616D6F77667584936B5971
7B846E676C64847F5F150C09041B3684822D030407030607
0600020105040406
040104030100040006000402020202040305000001030400
010918925235261501624132849497A796A2A49997A09995
8D79847F6652646D6E546E7E756B635E6B6B6D68828B6966
6B6280826C62626E88828591775E5965646050686D4B4B72
74766E6D6B69807E4A0F0A1E135B35777916020404020207
0201030100000100
000403000802030203020004060002010104000204040001
0A060A75906125260532413D748B7E84948D97A59A979592
9A949781626E7A75636D81898B81745B525A53556D7C6369
7A5E728B6C3B769085747D8F907564373C46503B323D6184
8B787472685C62442A0A1D1314339D6D420A030400040304
0300010401040604
080300020402000001030500020202060200040702000402
020007169A636C240E1E4E35555E6F84A590929598958A88
9EA39C7F61788A8E7E79949890917F6B61684E5664716071
8A735A6D5966798A827962758A8F7977696C737733497489
8C958B8B6F514169180C150D2944866F1106040002010006
0204010205030203
020404000100020002010100030100000204000304020200
0004020132AF29461C071E4B4D5274A08E929189828A8C8D
A29D8A88718B8D9A9D9F989E9C9A99877D7776614E4F5871
8B81702F6D7990898C836F6E8784858C8A848069355B7590
8B827F766C35554202160F143F5F63460305020503080204
0104020101020105
040206050103090403010400000301000403010402040000
030005060951B01623160905745E707F8588947D818B9AA2
9E9691968C9B9E9B96929596998B929695937F7E6F3D7183
90867058748B8C878A8B727182838A9389817A5D46548486
818F796248555F1B1C12194C2C7C74100300030106040400
0402010006060703
020203020402000302020104010000030304000103000305
03080804041089B31F210C08113B8A7C7C908B738596A89C
96939594959AA1999098938E948B867F7F968F8D7A5E7284
919285727D8E8F86746F547E87878990918B7C5E41578587
74757754426A1F0D0B061B327D5E3F050403070404050A07
0201040004030201
050301040104010002010003040000020706020301010004
0104050202051972D0271E11190C1D488479837492A0838F
92888287A191A198949E9D9AA08783826E7E8C8F7F667082
92938E8C8C8F8879757A65758686836F7D8487713E497D8B
6472734D583912211E055C4475710E020201000003030304
0500010400030003
060000040002000305030503020000000000030202020104
010001020201081D77C63719051015164B5D5E6585897083
7D6E7278969F9B9793929A8B898F9D8D7E7E959086796485
908884868585736E7386806A7A8A855F6474887C4D3B7986
675A484D59080D1B192E349A742202040800040202000405
0207000203030202
020000010002040104020707020300000001040300030401
01000402040602071789BD1D09201C000A4B216C79826775
7B666772948C808DA097786F72868F887F7D89999287808A
8F90908E8A776E71798F887A829486764A5C778759486373
6C3C5A69130F180C2042907F59070B020201030702010304
0403020101020204
050104000002040400010902030302060305030403000000
0200010103020402021790D0142C270C1213404C7E84575F
55494E718C8167808B906E6D6B809385807F898F907D8685
848B8486846E6A6972858A7F7E878878424B7584654A4357
3E4B4A19071B1B0C6B50887E060102000003000403040302
0100010402000203
050706020009010200050203000102000104000002060301
020404020000020000041B5EDD1E4A15131E00154C42583D
373B3B6F7F817E7E957B6B3574748F8B7F83878C8480796E
767E8085755C5D667383868F7D86867B5E3D74817B452D23
3C642610161B1078317A6E16050405030500000207010103
0403040101040000
000501000504040001020404010004040402000300040500
02040306010204020402041172BB28630922151013533B48
37372D6E7A8B8686867F6E397371858682897F88807E7570
6E75828571646173797E7E807983847A69376F8277292F37
6C190F17110A4E1B9C85210804030404060B040502020102
0000060400040102
010201040000000402040104010400020503030201060400
0200020402020003020309060F64A6592C2B1C0C423D3F69
3A3442526C73746B707B77376A738A8478867E7878766453
59697C836E605B68676F767A8073776E5A38636726433065
02071C1910661D868F260306000202010002020405010002
0203020203010200
0A0000090702020000030302000104020002030203060603
01040803000200020102000401063F8E901B4816150E374D
534B41342F535E657278722C696D818483807E6D69645741
5B65768B6F62595F5466767D7F717A703B3327324A56160B
121B20197118857F55000105020304000304040204000104
0309000200040403
000404050004020404050700020201000000050301020204
020102020104010108010401030407268CB84A49180E0F0D
1308090E0F15192045562A275C64717C887B7F6A5D504732
57657E7C7266544D26747A7D7461512A32474C5516161342
777F186F138887620A040305020104040000070100040805
0305030006010404
040402060200030502000302000404020100040600000202
0403040104000302000504000300030514778779255F1617
0C260B0B05180F0E070E0B0A1B5A747E766F7A553C3F3225
51687C85756B403D262C797273485352375E1B1515110775
1E354D2E8B934D0700040502090402000000000204000004
0101000A02030002
050201000002020602010404070202010401020400000702
02040301020005030401000405040205030D457B974D1931
281914261E1F161C1F1914140F0A113A3735372B3236482F
29637D787E533C3D3A32304933284B481B180F0319231726
69074863872E080000040205030403070003010303040102
0102040501090404
030205020402060401060500030203000400000300050802
06010300020304010403010000040001060604165E878566
0F372E190F0C1626191910142812070D043C553A06120E2E
2F3542452E5236533549474C3D22150E04132B0312206012
1C8794730F00030102000401040201010302020300010904
0304040000050102
020104000002030100040203020005000004010104000301
01040202000303010404020004030203000108030516738E
997525282F363518111D051F24250A040B1D131211060402
090C050D1208334B274A21010300142219091C3441190E89
8A8334100004030400020205000102020203020304030401
0201010904000200
050402000101020302020100010005000100060102000301
030100030400030002030402010203020200020300060A14
5B80967A685C210C19273E32180F08030D140B130D061311
191B21131B12110817170D0F141B080B1B3C2508307C7E7C
4B0D07020204000504020201000303000101020004020002
0404000300020204
020102020203010304000000000008000003010202010002
010004010002020401020203040500020103000400040504
020E114D7F8077896D602A0D0E212D21303D3B322C18191C
101B170B1412090611111921191D183B182A6A8B717F4C0B
010005060101000202020103020300000105030402000400
0104020203010203
040000010201020003020002040308030202010000020000
000102010002010407030004020002020302040203030002
0002020B0F05364C7C807E91866F5E5F2F30180F1E1B0F24
2C32323837362D2A202C282B352413187A6C8A7F3E0C0700
070201010404040006040200000205030405020201020000
0401010002000100
000201040002010000050000020202060201020001020002
040204040402000001040000020000040402000007000404
0B000500040307000C0B2B537A7489747C6872817B73735E
694E443149181B211416253040576E7E7A732A13030B0403
050002050404030200000202000001000304000004000200
0403030100040202
020201000100030002060201000103040005030002000004
070404060002030200020400020000010305030201000008
02060202010504060102050A10070403132D3050546A606D
6F85817E64807C796D6976847C7E74592A09040407040102
000106040000020402050004000001020401000302020503
0401000400010000
020401030403000204000500000202020401020002030400
000100000102020304030203000001000202010402020104
03030303030201040401030002020400040002040105070C
0504080F2633323A4E483229150603050203040202000206
020104020201020401030403040200030200000002020300
0202000001000200
010002010000050200020203000200030000040303040206
020002020204030102040103020000040004020004040100
030207000000020301000002000000040000040302030401
020304050400040405070404020401000302030409000203
040404010404000202010501040304020400040000020102
0000000100040002
040101020202020004000300000002020204000200010400
000004040000040000020000000003020201010405000402
040102040003020106000101000403000400000202040003
040001040100040307030202020103020200010103040301
020203000003000404010200030304020005010503010004
0100020400020000
000302010100060000010305020501020006010303040000
020302000402000104000304020003040500000303000104
000403020200030102010800020100040200040200040005
050200000600020001040200020200010207030002010800
020202040305040001010100000200000202000001000303
0100020204010001
040002000000010404060101000003010001020402000403
010004020104040203000202000202000300000200050301
010002030102020102000001020401020403080200050204
000000010002010003020004040401030204040203000002
040301040001030105020002020404040100000604000000
0202020300000200
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0113379 0.97619 0.464853 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00751202 0.0192308 0.00751202 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[.5 1.0125 -47.0938 0 ]
[.5 1.0125 47.0938 12.875 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
gsave
.5 1.0125 -108.094 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.875 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.875000 moveto
 460.000000 16.875000 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.875000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.187500 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Autoscaling) show
135.187500 13.000000 moveto
(Off) show
153.187500 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
128 string
128 128 8 [128 0 0 128 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
010100000200000100020101020100020201010000010200
000000010001020002010102020001020200000200010100
000100010100020001020000020002000101010000020002
010000000201010201000100000000020003010100000100
020000000102000100010100020000010100000001020100
0001010002010000
000000020200000101010101010100020002010001010002
000100000002000102020000000101010100010101010101
020001000202000100010200010201010201020001010201
010000000100030100000000000101000100010001010000
010101000100030401020102000100010100000201030101
0101010200010101
010000000002010000010100000001000001030000010101
000102010001010100000101000002010000000101010100
010102010201010401000201000001020201000000000000
000000000001010000020000010001010001000000020000
000000020100010201020000020000020000020001000202
0001010101000100
010101000300000000010102000100000002000102020200
000100010101000002000100000102020100010000000200
000101000000020101010000010001000100010000020000
020000010000010100000300030100010100000200000000
000001000002000001000000020001010000010001010302
0400020101010000
020101000002000000020000010102010200020100020201
000001020102000202000001020201000001000103010101
000101010000020001010002020000000000000201010102
000001020200010001000001020003020001010000000101
000001000100010001000100000100000100000202000003
0200000101010000
010204010100000201010100020001010000010001010200
000201000001000002010202000000010200000000000202
000200000000000001020001000000010000000100000102
010001010102000101010200010101020000000100000100
020100010101000000000001000200000100020202000100
0201000100000100
010100020002020102000001000002000101000000000101
000000000002000100010200000102000001000001000000
010100000000020200000100020002000201010100000201
020000010100010000000100000100020202020000020101
010000020102000000010000000000010001000100000001
0102020300000102
000001000001030000010001010100000002000101000000
000001020100020203000100010200000001000100020102
000002000100000000020001010000000100000000010100
010000010102000101020101010000000202010000010200
010001010101010200000100010200020000010200020102
0000010101000000
010100010201020000000102010000000100010001010102
000000010001010200000000020001010002000001020201
010100010101010302000100010001000201020000010101
010000010100010202000201010100010101010102000102
020000000000000000010002010001000000000202000000
0101000100010002
010000010201000200010100010200020200000001020200
010000010100020002000201020001000100000100000100
000100010000000001010001010100010202010000010000
000103000002010200000101010000010000000102010100
010002010000000001010200020002010100000000020100
0002010000020102
020100010000000002010002000001010000000200010000
020101020101010000000101000103000002000001000101
010100020101010102000000000200000100000000010201
020102000001000002010001000101030002000201000101
010003010301010100010201010000010101010001010001
0100000002000001
000101020200010102010001000101010200010301010001
000101000002010000020200000104000101020100010000
010000000100000201000102000200030000000001000101
000501000101000000000001010002010201000000000000
000004000000020102010200000000000000000100010201
0102000100010100
010201030002000102010001000101000100000001000200
010100000100010000020000020001010001010001000000
000201010000000001010100020102000100000002020001
010200000002000200000002010000010002020003000001
040000020002000000000101000100000000010100000000
0101010001000000
000201000100020101000000020101010100020101000001
010001020200000001000101020000000001000201000100
010002020202000100000101010000010000010101000001
000000010001000101000000020201020101000100000100
010100020000010000010301000200020202000000000100
0002010000030000
000000010202000001000001020100010102000201000100
000100010200000001010000000001010202000100000001
010100020001030000020002000201020001000000000101
000001020000000201010000000200000200010000010001
010100020001010200010001000000010001020102000100
0100010000000301
000001000202000100000000000202000200000001000001
000000020100000201010101000000010202000001000100
000100000000020101000100000100000001020200020001
000200000101000101000000010000000000000100010000
020002020101010201010101000001010100010002010002
0002010000010100
000002010202000000000101000002000101010101010001
010001000201000001000202010000020001020000010201
010101000002020002000101010300000000010000000000
020101010101020103030100010100000102000100000000
000202010202010000000203030201000200010001000001
0200010001000102
010100000100010102000000020000010001000001000204
020101010102010101000001010001020100000001000200
010101010001010101000100010001020100000000000100
010000020201010001010000000200000100010000000201
010000010000020104000001000101000002010000010101
0000010002010202
020001010100000001020002010201000101010200000200
000000000100000100030000020201000101000102000000
000102010001010000010202000100020200010102010201
020001000000000201020000010100000002000000000001
000200010001010101020101010200010100020100000102
0000000003010002
0201010005020204020208020303000202090A342C1B1B24
0E0C15070C1821292B2F292F2A28271E23211D1A1B12241F
242C220F0802361B263934393C180D14172C302B312D1307
0C0E1514162422211A2819141A12181B0F121216150B1602
050103040202060102020204020001020300050200010901
0201010404040201
0005020305000206020301050105060403021937251E1E0D
060308081E1F2A2734292E292929241E2922191E1B121929
15333F2F13061E21140D0F0D0D0B091C1B2830292E291B09
0815171B222721211E1E230A0E0E161F171A0B121911130A
000103000401000201020302030100000205020201030505
0101030202020401
0003060200070705010004040407070505092C3121281804
09140C00020F2326312D2C2C272217151B261E1E19170819
272534181003122C0D10080E080B11111A2134332C262405
0E1C221D1C222A26171E260F16051B1C1E10181713201418
050204000102050302010201010102040605020100070202
0503020303030202
01040200020B0206060403010101050205092F1C282E2208
0F130C0002050C2D342A2A2D26201B1E2024201E10141014
2F2D2D3F0F05082A140C0B0A0F0B1411181534362E302C12
151511191F291E1B1B2126111608161920130D1817220B1A
030507020003090201020201040105040002010605030005
0300020001020103
0001020301080605070105000204050104093329322F270E
0818030308090A223231302E2A2627201B1E1C1B070B121C
203333151212020E27080C110C10140D191832362D32322C
201F211E1412121316111121110A0F1D2122140E20202116
190808020202050602020201020102020405030207020006
0300050101000004
01010106020206020503050502070703060828312B352C21
15101003040905323537272F2C26271C10171C1F0B111515
2632201003080D0A33080A0E0D0E090D1B132439312C2F22
302029271B12100905010E180A121017242411131E19220C
180802040001030501020503010503040100050305020303
0402020002060103
0501040503020102020501010407030606022A382F32322B
0D161402050102261B1C202429262A23141720181C161609
2132260D04021006240E080505070C040B131B3E3E333821
2C2F06100D110F100C090E230E1E1B141B231C13181E2F1B
161102010101050504030105020103010605020602020203
0202000104010304
0403040607020403000504060608020005021B372B303727
101C14160B061F1918181D22232B29241C1818291D10110D
2B37330B0D090509371005060F09060510161E3437353929
23070D0E0C0A121410150F21181D190C25292A1C1D242D22
091E0A080000030805050402060303010303030202010204
0708000004010100
02010503070404010504020701040501020308433337362B
0A1D1E1C1D103A2127282527333636342A1D16201C13191A
332F2C2D08030C052F232F41414536323817161F373D3732
1D0905060C1418160E121721160D20122323221910232833
241B11050002030004080205050404060802050602010400
0507050404020403
0300010706050705050205040503050605050226302C3131
0C18091E072D30293729263039393C3C2920151D291B1B23
33343B270E03050A2A0F24433D363606111215133E3D3434
212B090909130F161A0E2721221E1C2414232021171E2331
2B1021070504060201010303010102050201090702030100
0701040500020303
03000505050606040202060408050207050302132F1C3B2D
080F09100B463930302C292A33393734241A0D21301E2222
38384948100702061118080910050D0E0E190E103B3B3437
371C23150C07151B1D20210D26291327211B231E1B1B2A33
2C241B19010003030202050404010003020607030003070A
0301070202020002
0405060006070300020805000506000204020A142C253B38
0F0E06072E563A2D2C2B312C37393A2E1C181329291F191C
3331423B0808050A0C15100D0708100A022212152D3D3739
3E1223210F120F15181720171F251B1E270910202B1D2D28
2D2F0C1B0601030407040303010702000404040502070208
0405060104000202
0202070200020403010702020208030507040E1134183734
010B03064F4F2F33312E373334362E2E2C1F1E2925222022
302F342205060502121B0C0D0A0F101614181013193D3D3E
3C202A351008101B13161017201E26252814152B25221B2D
2E37261F1A05040300040302040004000404050205090005
0102060103000200
04040502080407020507050508090911261B342448453C37
040702335842372B2E3C303A2E352C28272B2929272C2126
2D3631260804070E1131240C0A030514120F1511123E3F37
4039182430202814100C0D1E1F17292A2023161C281F2423
3537340D32060204050607050307050A020503000B030006
0706050303000507
000808030205030405000301000C02122726291B26573817
08020D484D4334323D323333353330302623392920292420
2E38260C000B0509081E11021C0F131C11101C101525443A
3E4116183E18141B221D21262C1E261E2725151B2C253026
342C2C292210070103050605000702010308040204000200
0206040503010405
00020700050404060306010502010A2C3635332E3F594813
020D1F44413E2A34353333373730392E262C312F2A272B35
2B2F1E381112110C05071422161B181A1A1B1617161E3C46
3D4421212A32393F393432353522222C232D1F1F2B2C282A
312D313C142D020303010103040402020006030300050000
0407020504020501
0201000306010501030506050505052E3A3C4846453E3A1B
060B3C31242E32303A373B31353C2C37313B384039362626
362826471E1819051329310E0C100303150A1A211C103D39
363F36171A28341E2E3B2F1B24232D2C2F33100F21222829
2B2A1F3D2E210C010501020102090A030802010206070A02
0303060203020703
07010205020402030507060205070421203A36374E312C0C
1B2841292E3944483E393526333228382F38423734222437
3837293C303A29130E1236190F180B1215120E12111A2741
3B3D42151720040C0411111A1B1E2B3D2021291E201E2D26
250F29564417280203000105050205010403020403050608
0706070505010102
0304030408030204030703030103030C073A455111072210
1D2B3A2243413E3A36343B343D393C2F34383D3129203547
3630293D3F423D1C1113201D1510090C0C0A091E141A1942
423B36211C330D19191127371D203631282C372F1E242730
282137584B2923130B050205080902020205040606040407
0308000105030703
0B040306010906040502070A0506030F05213A2318190737
37363A33424D464A46383C3D3D2F2E3437393F3D2D233C42
363238463F4B5534110E19121E15120E1F0D03171A141442
4734353C1C1F37081E0E161B141B2A2A362A2D3015141920
292A21404440162B07080706050207020503040207080703
01050501070A0400
07050804070009040403040B0607091833113D3E210B182B
43392E48425352403C3C35363C2E393A35363935322E4335
362E404640454B3E0A1043062E23080E110704171C18112F
41433C42121B213F1924351A162B242015323039421B1522
262C28243948271823020204040003040002050307030905
0207030407040102
060301060303050501020507040208342734473322141902
2E523A3F46424439363A323B463C3633342D352D3936372E
322B363F453B4D481309380626200F080F15041409151214
45474140251F183141132C212F351B2316373C3C3A421D22
1F2A2B2129444B1629160904040104040102090208030704
010A010506020700
06040100000003030502000501063352373C3640360A1607
122C35413A3B3D34323F433A3C3B3B31312F30313640393D
2C3E3B37483D48270A0915052F1E0B0C0C0C1409071F1310
4A45454C3418191D262F1C172D33233A262C262338322F1D
2A242E262629413813221106070206040205050704080601
0803010405050503
050505050201070302060406050D31373A2F2C422B1E1613
050C26353F353E423839403D33413F4141322C2F393C3A34
343B4542534B451D0F143D0C1705410B0C100111090E1110
4C42434745141E1F161E371920172A2B29241D242448292C
2026212D2C24274C2C132915020203050401010605080503
0500010504090508
06070403020203080404020109032C272F34344632341210
07040B1F40493F37444737403B383D3C39382E353F36372A
3C4B344D454A480B0D0B3A1E0B072C34101017190C0E1719
3F454549411919181C0D2E361B29321E101F291C16331D37
371E2426292824354A29142E0B0B04030705020302050405
0708070300000705
0403050002070705050501040801222E3130353B39371B0C
040B1503133C52404A504D3D3B363D383733343C433D3036
4B33474F4249280E0706290E1305163D09221818020E1713
3B45444643261F1B1918212A3F230405050A081C20141D29
2A332A2C2A28241D4645271D2A0C06020200000201020701
070A060306040502
0506030207020603090602020405113E35332F38452C2B10
0505280C0B2138483D47444641393E393A323138372E3339
383F4E4440270D0005060229070B031F2B0507040F0C1A19
3E4C434943411D17121A201712370C100C0F170C0E050C04
1A2E3A2C293426253C58491D251B03030005020103050504
090D010306050000
0705070404060A01090A050005060E4C3933343D46363825
081027150C0125384A423A3842373C40423E363A2D323B35
3D4B4D4E55130707030B1C3710130B17170A0C141F111518
384B4346414F19171111131618141B190D150F14120B0811
070E0C1E3330343A312C1E341C2801040201030203010705
0C0A020303020103
08020407020508070A0700010701124E3431322E48443D2C
0C172C0B0B120220272E3B4534343448373A2A282F453935
4A4450602D07070914091738201B221C3308251511121117
2B444C45434A201A181A10100E171D14292005091D0E1D14
1A170D04071E342C291E1039222713010200020305060605
0905070205040508
0D0203020B02060508060305050618433529333748464034
131E2F1005201C0914182A2E343A43383337303E4F372D4C
465B6832100608020D09173A371313111D301D2C1615161E
264842444144411B1510131515111B1B1B2C252C14120D02
0B040F0F090605040C0E07393F2128040303000100030606
0203070205060102
03060403080603060502060502021524292229304A424537
21162810052C20030F0F12161B3446413A2832293727424A
555B2103090700070207103738231814263F19320B171508
2D46424343404A1716161E1D1E18181C1D1E1B2113130B11
1B1511080E0B100A17050330422832080305030202010508
0502080402090203
030507010808020205000A0006020F170B16200C27432E3D
3D07181A0E15050B1B0D05040A0E1E285B4E3F3A49455158
240D0E0D010D060505070346342D1001193F131C19191621
4B47474B46413819121C25221C170D1933332E2A1D161907
16231E0A1817190B01080609442E33100A05020702060705
0A0408050C060205
0503010302050600040102020617192F2C160D2444382017
341932171604141606070B0D0C0B010E170C0D1E1C101D0A
0209040500020B0F02060B352D2D1D2E3C3F110A1E172E1E
4941454643402711131C231E1E403A3F46373A38341A1915
1E102120271309100E0C010C3E32291F0303060201000205
0701010001020101
0205010101040506030702020807120D0B070819200F220F
210F162F1D181D0F19111F0F1210020A0C0C1B1910090418
0B0C090607060402070609173722211C41160B0E152B2C26
4C424144403D1A1211222D2C3A3C3D3B453E3D3243352124
232C182427322405110A080C3D431F2C0601050402020502
0602060604030401
05010403050707212F2A0C07020F14020B101514100B0512
151A120B221F3434342A2C3237352C291E1E0A18262D1612
190502110109050304040E27312B2427110D00111E18162C
544245443F421E1416282C3B373948403A3F41343D382E23
1B2A292A1E3A2F120A1802003B491B2B2008000500050505
0306030004020202
010508010803172D201F1507140900030705090E05070C15
150C06233A19242D2A25242828181A231D221010271F1E14
1B170A0F000402080B0A05272C2A241A0B210C1E18161E31
47494045413D261B0A2532383F3847453C424141373A3723
1E1B2C373C2B202512150F031B532B2E350B040203040405
0505070505010606
0502060505021C230B040708040709291C0D110F0C02111A
268052221E3D27240E1B222025162322212B281F201C2418
190807040304060406050210371D1C05140C141A16181B2E
49433D41433F2E141E1D37403E44453F353E433B363B3337
351A2B322723312F1B141A0804474B1F2921040002030303
0103070202030001
0500020501041C292C2D0F04040D100C10230C0C06163D45
483232240A1104190522201B2226182A282A2C301F1D2621
140D09070707020F060812213928040C1921170A1B1A182C
4540424447443B151E2A3A3F3C43424038433F4638393D41
37291A2F292A3C1E0C0A191306045042202C130403070A03
0202000308010302
010703020502072A2927240C160C07120C212720153A4844
504A3D301F3240320B071328213C3E40342F222514101311
150B120A15211B20251D2216270B0E192D18131B161C2935
444247454346481310223D32373D423C3C423E3942363741
3B2F172020262B280E0C16180E03065934152A0600040201
0200010503010502
0407030104020414202E2222181A17202F33251A104F5448
595058545B382F1F09000D16152C25373312212A2124230E
160F121327402D221A2B2A1414101616121B1A181E3B4745
3D374A4A46404815181F363D3D3A3F3A423C453D39443F3F
443F3126222E2A26081A1A06190B0202502F213709020103
0302030303000200
000205040B0303080C1B2D1F0E1F100D121E24271435564E
5B564E45412F120C10060B0E171B2B0B182918293A2F3432
1A07010B17190B08131C0217110A1525100F181822533F41
424643404444471419182B2D3E3B484744353F42353E3F3B
37412D16221F262F3036230D120C11050E47252D16040402
0104020202000504
0306040107070605050A1519130F0410213026202120453C
3A3A3D312C160E15160C124027281B201B0B2314272D290F
0B1C0A141E1002020609031A0520161A27110C10564B4246
45424943474A48150E1918131C3F4D413945433C43343F2F
3A3F3226291E2140413A3D3F3A24180A033A32212E040201
0204040505000203
070005020204070401041017141315292C2624212734322B
25232B393237261A1F3240381A370F0521273B37251E3830
2E110B0A0800040405070F09141618172117172747444449
47454845434744190E100B153F41463E433D2F3739473F3A
31421E1F1325414643343C4C4B4115150706502A31180606
050A030404010008
0204030102050202050008151B1F26212D3223292F30362C
29272F343D2D1C2D372E161E252D19220B1E32210C04141E
10070D0402060202070B090C061013021C19144840474947
4649494848434623131216454B3B404F3F32453F21443942
41210C242638424950473A474F34311D0C0C1440292C0604
0509040601040103
03010001000602020503030A172B27322D1E192D260E3216
1505111D2A34311724333E393B16260F21230812111D1F27
1006070C070502030307090209140C06171B0F44414C4544
4547454641444522111945353E424041493A3E4242253342
422C34263D3E43454E49434A422F46340D070C532C2E0703
0102010100020402
0200020105000302070604020D202315242607252E0F1A23
1C212F1909102424160913323A34282C190819090518300A
0D050B050301030806040105030908091E12194544494645
454B45453F473E2A181B423F403443434A4C4032373F2E45
3C2F25333D3E404A51484A4D40304543210D0B32392B1406
0408050404010701
0203050708020204060806070A10242D202F12100E1C191B
15191C2C161B30131115282C3E3F433C1C2216191423080B
0215070003030105010201080F08070714111C4745474B48
48494C4B454A45331E322A413A2F3B3441414140463F2542
2F28293841404448483B45482D3A4B462F0F04093A302207
0604050206070204
030504030207050601060A04030A0B222921260F13181C1C
14190E18322E250826263721231C0D110616181506230514
0F0C020703030202010A060D0C0A03141A0E2D5047494849
4A4C4B5347454537243D3B3E3B2B3E34424834463040451C
1E243A333F464840383D4A423E424547390D0B04432F1B03
0302010107040504
020200020303040505030B0203040924272B3526261E1E17
281C18172A3B4C291110022F070616101C181A30211B2412
04020004030208030A02081510080B2A1D13264949494B4A
4F4D494B4842433B29273A3F402934363A47313C36422F1F
1C34373B3C45474234414B2D41483F3F3110120528282C02
0706000501020101
04040304050306020508050B0606060D1E2A2F342F261B11
171C223F40293915052109140D16170A142311151D1A1012
0702050202030416202C100A0E1A092C1E1A324C4E4B474A
4C4A4D50454247422C21263A39282E413D42402D413C2721
3D3C3D40454444403D3F482B3F464A423C0E14012D293505
0602030207050501
020A01060502020402090B0607070B0711241F2737402415
1122273B3D132C321508160923131D06151E221B0D101904
030505040A010F142A1C2F314D133D2A1C1F294B494B4C48
4B4B4C40424641412F241623382F41352E413F3A36362634
3A39373E474644432C444B30454A3F4D4B0E101226332F13
0302030201010302
000201040D0104030806000304080F050207212326362E25
1B190F191D270C16252C271B18290C041121351109121817
020702081205092C55322B232A052D231F19194C4B4B514B
4D46434345464B442E231E1B1B392F4229423E3731322F3C
3B3B3D49423937313C4841283F444146452A121113332D15
0100030007090702
00020505080A05040A0706050A08070605080D2121192333
171C2016150416180B2F161A11100F03141405040B0D0514
05050D040709303023222C3919162E1513161E4952504B4A
4843454440454A3E3D4A211C1A2C463E2C4234312F362D38
363A41453A32333D48463D263442483E482F0D0A142D2D19
0506010408020A05
040903080502050B0807050707080C030404010D14131918
1C0C1625100F0709121B180B050E16070B0909050D090C0B
00050201021F20141B1B21302339181118181D38232F4542
424742454143444543483E1C1F1C404127392C23232D333C
3E444648453D3D453F343D2C3D4A4341502E0F0808473114
0305040105020505
040602060102030703000106010301040105020713070310
0A170B1C220F050909210E13100C0102101A190B10071B04
0305080202050415151A1A1D2220181B1D1D4241233C443E
454C4A454142453C4A4D211C231E1313192C29373238313F
3F46434443383C3D3D3C3E404D44463C4835150B063F2B13
0603060602010402
02000303030502020302000302040502060101050C030A0A
05100E1622211A1713090C16000C0F12160C080D06140C06
0C020202091A252C53544D3A2E2B191E1E191A1726323642
4A4B454B46473D384A4C151B2216152129333F43454C4945
473F3A343234423C3F4C494A4E4F464C544C0910053D3112
0507050405040001
03010105040602060606060504050208010302030A070901
10171D161D1E1F03100701081C140806080A070A0D060817
29314D221A2629393433363843495E4229261E36433A434C
515050534C4736474D391715171D0E132E323C383C444947
422C30232843442E3543453C49464C4A4E4607070434340C
0503030500030301
0203020202030609010407040A0602070305050003080C10
1129210A14070C1007130F07090F0A0F13131E120C113D46
313A595444423E44433F42221325244D45384547474C4A4D
514D4A4848413E4C421A15141314202B34333533323B3D37
3E434441404646293436444A424045444A3B110500353108
0702020206030404
00030501040401020302020001020203020505000415283C
38160F16110C23230402060E171418080B2E504E2A343547
474853554E43423F48473A1E2325223C4242473B4845494B
4D494B4A47473C2E23121B1A1F1A282E37383E3C403E414E
51473C4850473F453F3E47473E4846423F140A0A07403107
0203030302040401
06040601040501030103010302010200020802050329174F
2D130F0B0F080D171A1E1C0A060D1E30484539423C342E34
3E3D3A4145463D3B41473E3313243F413F44444546404E4B
504D4742343725202630222A2C243D3E3F4646383B3D3C3D
3F30314050484C4D4E43403C3B3D413A2C090A0713423B0C
0602060005050103
02020000020503040302020001010102030505030B203C37
171203110F0A0B07050A0E0C36444A614D4A45382E3C3E3E
3D414047484340433A413F31373F48493C444548483D4747
403C3A3C303B24191F1B4B524E343F43494A4A433F3C3438
383D34424D4A4A4C4F444139393D4131280107031F3C370C
0406030202040102
010102010203010202000103000100020204050417214238
030201070A090208020C2149474656564F483C4646464747
423F3F414143444A413E393F4343444742494442413E4B42
4546423F393D1B1E1650474B4E44404D44474A48423D3A3E
404136394347414C4B3A3739363B37251E070D081E3A3C05
0301040102010201
01010202000100000002000101010103010101032B324919
02070C070702070B11345748413C42505641454F4E474142
3D3B3F41464A494A473E3B3D3F3D4350494645464242453F
43413F3F3D3C1D1E2652494D4D4A4248423A3F494946454F
50473F3248453D43483C31343838382C0E0E060528353707
0405040202000001
01000204030202010201020204010102010402033A373E0C
040402060002081B494F50464A474E4A45414C4E483D393A
3D44454546484B4D4D4542433C4141454447454544414542
434241404135251B1F4E4D4A4C4E444F403236364745444B
50533F363E34323C443C2D373A413A3B0109000E292C2A05
0306050304020201
000001020100000101020002000303010303000339353403
0001020102060B23425D6158564D4A4F53514B3F393B3A45
494443414A4E524D45453F32272526364039474A46434546
40424341413224192F434F514D4B454D483C34343B37343B
42534939293B363B3A3A38373A433D36070805182D341A05
0203040302030300
00010201000000020101030100030201010005043329360A
0A02010403042E4249575B5B5B5A4D48443F39383A3D4748
403D45525153504B423F382A261D1C1E272E374741424545
464244403431334345475153553F474E4A4A3B2A333B3636
35474433373E3A343B2D3233393C371C070C051D2E350E04
0406050300010100
010200030002030001010300000400010200040215332D1B
04030202050451464A49505052443F30373734343D494740
3D4C4D4D54575145372B2F2D2B221C1519222442433D4545
424142403E4C3A30384854564A3F4A4B44373A374247413D
3646473C3E3C3A283333212A34352D070B06071F37310607
0403030201010001
0003000000020101000203000002010000020000063A2425
0603030206063943444A4C4D43353035353C3F444D46403B
424D515B5D57422D1D29322E2B251E1918161C3737424346
43473F393A252326384C575645484D4C392D3742423F4C47
45484A4B473D342B3A3D403E1E3036010D090C1E39310502
0406000504010002
000201020001020101000201020201030003010206253F3B
1402020004031E333435494B4224333F454A52554840393B
4E4F535959502D101B2426292A231E20181318212C3D4341
423A39372F211E334E525949404F4F4D39373C4834374A48
423F3A3A342E393D484E4745382223070005152C361E0600
0402030400000101
0101020103000200000100010002020102010102050D4121
370B06040501273D464D554B362C3B4645393751443A3A49
4D4D5155584A2B12161C1E2323201C1E1914101718172044
473E291110173646525444414A4B48443B30394635384647
3C3A3A37373D444D45424542392C140408052A2B380C0202
0102030300010000
020202000101000004000301020202000001030002032550
2A160801010131434C4F4B43343645503B2F39413F383F4D
4D5255545852371B1417171B1E1F1E1A171714100E101515
0F141919153249565242404B4D4B463C35313C473639393D
37363947455043392A292E33241F0F0214151E4036050301
0002010202010001
020100010100000002030000020101020202000405050C3A
2B370505030C43454A4A4E4C2D38564531343D423B424F4B
504E5054525A544531161214181B1B181716131311101113
141A1B243947544B3A3F4E4E494743362F303D4B3B312A2A
2A25373C4650483632301E211A0706010B2C233326060402
0103020205000100
020002010101010300010201020101010200010000020431
4E170B03060942465554514C3542503E18364244434C504C
4C4D4A51525054595745351B111214121412101011101618
16263B444D53493F4A4D4D4D4E48483D38333B4C49403A31
3737312C353F4A4544423827190304030C1D4A3F07010101
0002000202010102
000003000101010001020100000302030000020203030409
4630390B030A55483F434C52424A4A361E39443E393A434E
514F4D4F50545052585B554E4832261A100D131315162432
424E4E4D4B44434F4D4E4A4647453E3F342839344D4C3D3B
39383D403E333F41453D372B080004042F17343705030202
0202030303000302
040002000100010101010101000202000002010300010000
423025080806193B3826465854534D3D162E303334343B4E
53534E544F4B474D4F5356575D5D58504C43424045474D50
504D474442474E4C4D494E47483F373735392E3140474647
2F2F2E3A48423B383D2E202C020306061D46401604010101
0004020102010200
020001000102000100000001000102020100000001020206
1E423A180F14061D2E4244575950533E3138384034343F4A
3E3C4B504E4D4A4B504748494D4D5258565757555455534D
493F424A484C4E4D4B40434945453E493F42372630454545
42341E2E36463A2E283437110503030F1D342F0501020003
0103020000020002
020202010001010100010101000000000101010302020202
064B3D21040C0B1B464F5B4C4A4C4D3738474C4132374439
33363B4048494C5051494E4C4D4C494A4B4A4D4B49454547
484B494C4A4A454538323A42424B404146503E2D3339414F
4E433C25283F3F3C413E1E0402060B2345301A0302010001
0101020200010203
010002010101010200020002010301020101010100020302
062A3F2C0C0505153F45483F4D514F423D484C3D2432392F
3734373B373C4650504D494D50504F4E4D4D4F4E4B4B4B4D
4D4C4D4E4A483938382C2F32393E4B423C4B42393D3A4554
4D473B322B3B47423E3814060A080F273837080300000102
0302020000010102
000001000301020200010100010000020102000003000203
050D4B341B211105293C35354954554F444B4B433F2B2B35
3F392E332D313B4C4A3C37373B3F484C4C4D4A504E4F4C4E
4A4E4C46403D352630373A341E35433F3D45434345403742
43453C37343544413C2507060304243A3325010100010004
0302010000020002
010002000001000002000101000200010101010101010201
06063C4A301D210625272D29484F55504E4E4D50453A3740
453932373037393C3C363036342F363744484A4D4A484540
3E414A3D3637283C3D4042403A3036373B333A4249352C38
3D4237333632423F2F0A0604020D1B424116010203010303
0300010002020203
020002010000020003000201010101020102000000010200
00040C49291A130A00312019424A4B534B51524C4B504C4A
463C423F33293236372A373F3A35312F3535363441453433
3531404136313137444142483B2F2C323230283436252539
3A3B37363534403F2507050F092D1A3B3C0B010202010103
0100010000000000
000201000401010101010002030001000002000102020000
0503053A483012130219201E3A453F424A464B524D4B4A49
4D4A4B4031373D3A3136404445403A2D292D292A363E3134
3D2F3945361D3B48423A3E47483A321B1E23281D191E3042
453C3A39342E312215050E090A194E362105010200020102
0100000200020302
040100010201000000010200010101030100020301000201
0100030B4D313612070F271A2A2F37425248494A4C4A4544
4F514E3F303C45473F3C4A4C48483F353034272B32383038
45392D362C333C45413C313A45473C3B3436393B19243A44
464A4545372820340C060A06142243370803020001000003
0102000102010101
010202000000010001000000010000000102000102010100
00020100195714230E030F2526293A504749484441454646
514E45443845464D4E4F4C4F4E4D4C433E3B3B3027272C38
45403817363C48444641373743424246454240341A2D3A48
45413F3B361A2A21010B070A1F2F31230102010201040102
0002010000010002
020103020001040201000200000100000201000201020000
010002030428580B110B04023A2F383F42444A3E40454D51
4F4B484B464D4F4D4B494A4B4C45494B4A493F3F371E3841
4843382C3A454643454539384141454944403D2E232A4243
40473C31242A2F0D0E090C26163E3A080100010003020200
0201000003030301
010101010201000101010002000000010102000001000102
01040402020844590F100604081D453E3E484539424B544E
4B494A4A4A4D504C484C49474A45433F3F4B47463D2F3942
484942393E4747433A372A3F4343444848453E2F202B4243
3A3A3B2A21350F0605030D193E2F1F020201030202020503
0100020002010100
020100020002000001000001020000010303010100000002
0002020101020C3968130F080C060E24423C413A49504147
494441435048504C4A4F4E4D50434141373F46473F333841
494947464647443C3A3D323A434341373E4243381F243E45
323939262C1C09100F022E223A3807010100000001010102
0200000200010001
030000020001000102010201010000000000010101010002
000000010100040E3B631B0C02080A0B252E2F3242443841
3E37393C4B4F4D4B49494D4544474E463F3F4A48433C3242
4844424342423937394340353D45422F323A443E261D3C43
332D24262C04060D0C171A4D3A1101020400020101000202
0103000101010101
010000000001020002010303010100000000020100010200
00000201020301030B445E0E04100E00052510363C41333A
3D3333394A464046504B3C37394347443F3E444C49434045
47484847453B37383C47443D414A433B252E3B432C243139
361E2D3409070C061021483F2C0305010100010301000102
0201010000010102
020002000001020200000401010101030102010201000000
0100000001010201010B48680A161306090920263F422B2F
2A242738464033404548373635404942403F4447483E4342
42454243423735343942453F3F43443C21253A423225212B
1F25250C030D0D063528443F030001000001000201020101
0000000201000101
020303010004000100020101000001000002000001030100
010202010000010000020D2F6E0F250A090F000A26212C1E
1B1D1D373F403F3F4A3D351A3A3A47453F41434642403C37
3B3F40423A2E2E33394143473E43433D2F1E3A403D221611
1E3213080B0D083C183D370B020202010200000103000001
0201020000020000
000200000202020000010202000002020201000100020200
010201030001020102010208395D143104110A0809291D24
1B1B16373D454343433F371C3938424341443F44403F3A38
373A4142383230393C3F3F403C41423D341B37413B14171B
360C070B0805270D4E421004020102020305020201010001
0000030200020001
000100020000000201020002000200010201010100030200
0100010201010001010104030732532C16150E06211E1F34
1D1A212936393A35383D3B1B353945423C433F3C3C3B3229
2C343E4137302D3433373B3D40393B372D1C313313211832
01030E0C08330E4347130103000101000001010202000001
0101010101000100
050000040301010000010101000002010001010101030301
00020401000100010001000200031F47480D240B0A071B26
2925201A17292F32393C39163436404241403F3634322B20
2D323B4537312C2F2A333B3E3F383D381D191319252B0B05
090D100C380C423F2A000002010102000102020102000002
0104000100020201
000202020002010202020300010100000000020100010102
01000101000200000400020001020313465C25240C070706
09040407070A0C10222B15132E32383E443D3F352E282319
2B323F3E39332A26133A3D3E3A3028151923262A0B0B0921
3B3F0C370944433105020102010002020000030000020402
0102010003000202
020201030100010201000101000202010000020300000101
020102000200010100020200010001020A3B433C122F0B0B
06130505020C0707030705050D2D3A3F3B373D2A1E1F1912
28343E423A35201E13163C39392429291B2F0D0A0A08033A
0F1A26174549260300020201040201000000000102000002
0000000501010001
020100000001010301000202030101000200010200000301
010201000100020102000002020201020106223D4B260C18
140C0A130F0F0B0E0F0C0A0A0705081D1B1A1B15191B2417
14313E3C3F291E1E1D191824191425240D0C07010C110B13
340324314317040000020102010201030001000101020001
0001020200040202
010102010201030200030200010101000200000100020401
030001000101020002010000000200000303020B2F434233
071B170C07060B130C0C080A14090306021E2A1D03090717
171A212217291B291A2423261E110A070209150109103009
0E434A390700010001000200020100000101010100000402
0102020000020001
010002000001010000020101010002000002000002000100
0002010100010100020201000201010100000401020B3947
4C3A1214171B1A0C080E020F12120502050E090908030201
04060206090419251325100001000A110C040E1A200C0744
45411A080002010200010102000001010101010102010200
0100000402000100
020201000000010101010000000002000000030001000100
01000001020001000101020100010101010001010003050A
2D404B3D342E10060C131F190C070401060A050906030908
0C0D10090D0908040B0B06070A0D04050D1E1204183E3F3E
250603010102000202010100000101000000010002010001
0202000100010102
010001010101000102000000000004000001000101000001
000002000001010200010101020200010001000200020202
010708263F403B443630150607101610181E1D19160C0C0E
080D0B050A09040308080C100C0E0C1D0C153545383F2605
000002030000000101010001010100000002010201000200
0002010101000101
020000000100010001010001020104010101000000010000
000001000001000203010002010001010101020101010001
0001010507021B263E403F4843372F2F17180C070F0D0712
1619191C1B1B1615101614151A12090C3D36453F1F060300
030100000202020003020100000102010202010100010000
0200000001000000
000100020001000000020000010101030100010000010001
020102020201000000020000010000020201000003000202
0500020002010300060515293D3A443A3E3439403D39392F
34272218240C0D100A0B1218202B373F3D39150901050201
020001020202010100000101000000000102000002000100
0201010000020101
010100000000010001030100000001020002010001000002
030202030001010100010200010000000102010100000004
01030101000202030001020508030201091618282A353036
3742403F32403E3C36343B423E3F3A2C1504020203020001
000003020000010201020002000000010200000101010201
0200000200000000
010200010201000102000200000101010200010001010200
000000000001010102010101000000000101000201010002
010101010101000202000100010102000200010200020306
020204071319191D272419140A0301020101020101000103
010002010100010200010201020100010100000001010100
0101000000000100
000001000000020100010101000100010000020101020103
010001010102010001020001010000020002010002020000
010103000000010100000001000000020000020101010200
010102020200020202030202010200000101010204000101
020202000202000101000200020102010200020000010001
0000000000020001
020000010101010002000100000001010102000100000200
000002020000020000010000000001010100000202000201
020001020001010003000000000201000200000101020001
020000020000020103010101010001010100000001020100
010101000001000202000100010102010002000201000002
0000010200010000
000101000000030000000102010200010003000101020000
010101000201000002000102010001020200000101000002
000201010100010001000400010000020100020100020002
020100000300010000020100010100000103010001000400
010101020102020000000000000100000101000000000101
0000010102000000
020001000000000202030000000001000000010201000201
000002010002020101000101000101000100000100020100
000001010001010001000000010200010201040100020102
000000000001000001010002020200010102020101000001
020100020000010002010001010202020000000302000000
0101010100000100
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[13]:=",
  ImageSize->{328, 156},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000580000W1000`40O003h00OogooBGoo003oOom9
Ool00?moodUoo`00ogooBGoo000?Oon6000MOon6000@Ool000moo`03001oogoo089oo`03001oogoo
01]oo`03001oogoo089oo`03001oogoo00ioo`003goo00<007ooOol0PWoo00<007ooOol06goo00<0
07ooOol0PWoo00<007ooOol03Woo000?Ool00`00Oomoo`22Ool00`00Oomoo`0KOol00`00Oomoo`22
Ool00`00Oomoo`0>Ool000moo`03001oogoo0800009oo`03001oogoo01]oo`03001oo`0007l000=o
o`03001oogoo00ioo`003goo00<007ooOol0I`0000<48@0000005P000Woo00<007ooOol06goo00<0
07oo0000O`000goo00<007ooOol03Woo000?Ool00`00Oomoo`0g00000`@Q000000160002Ool00`00
Oomoo`0KOol00`00Ool0001o0003Ool00`00Oomoo`0>Ool000moo`03001oogoo07P0000312400000
00D0009oo`03001oogoo01]oo`03001oo`0007l000=oo`03001oogoo00ioo`003goo00<007ooOol0
P0000Woo00<007ooOol06goo00<007oo0000O`000goo00<007ooOol03Woo000?Ool00`00Oomoo`02
00000`@Q0000001k0002Ool00`00Oomoo`0KOol00`00Ool0001o0003Ool00`00Oomoo`0>Ool000mo
o`03001oogoo0800009oo`03001oogoo01]oo`03001oo`0007l000=oo`03001oogoo00ioo`003goo
00<007ooOol0P0000Woo00<007ooOol06goo00<007oo0000O`000goo00<007ooOol03Woo000?Ool0
0`00Oomoo`200002Ool00`00Oomoo`0KOol00`00Ool0001o0003Ool00`00Oomoo`0>Ool000moo`03
001oogoo0800009oo`03001oogoo01]oo`03001oo`0007l000=oo`03001oogoo00ioo`003goo00<0
07ooOol0P0000Woo00<007ooOol06goo00<007oo0000O`000goo00<007ooOol03Woo000?Ool00`00
Oomoo`0V00000`@Q0000000P00000`@Q0000000F00000`@Q0000000K0002Ool00`00Oomoo`0KOol0
0`00Ool0001o0003Ool00`00Oomoo`0>Ool000moo`03001oogoo060000031240000001d0009oo`03
001oogoo01]oo`03001oo`0007l000=oo`03001oogoo00ioo`003goo00<007ooOol0P0000Woo00<0
07ooOol06goo00<007oo0000O`000goo00<007ooOol03Woo000?Ool00`00Oomoo`200002Ool00`00
Oomoo`0KOol00`00Ool0001o0003Ool00`00Oomoo`0>Ool000moo`03001oogoo0800009oo`03001o
ogoo01]oo`03001oo`0007l000=oo`03001oogoo00ioo`003goo00<007ooOol0P0000Woo00<007oo
Ool06goo00<007oo0000O`000goo00<007ooOol03Woo000?Ool00`00Oomoo`0G00000`@Q0000001>
00000`@Q0000000E0002Ool00`00Oomoo`0KOol00`00Ool0001o0003Ool00`00Oomoo`0>Ool000mo
o`03001oogoo0800009oo`03001oogoo01]oo`03001oo`0007l000=oo`03001oogoo00ioo`003goo
00<007ooOol0100000@48@0000048@8000032480000000@00088@P05=Jd]JaS66<HU:@0236<01ABU
124<HaS68@P00RU:00<]JbU:;F/00RU:00DU:AcW8@PQ21cW008HaP0B48@U:AcW9BT]Jb4836<8@P00
=JdHaRDY>Lhe[CW>?NlHaPaS0QBU00L]Jc6<:DXaS2e[48@48@0236<35:D02BDY8@PQ21S6:DXHaQBU
6<H@Q0026<H00`aS48@@Q0025:D010Q25:D000@Q0P0000@48@0000048@@000031240000000@00005
124000000008@P04000312420002Ool00`00Oomoo`0KOol00`00Ool0000900000`@Q000000040002
12401AS65:D<H`aS48@00P@Q00D8@P00124<Ha2400LDY@0448@<Ha2448@336<01PQ248@<Ha245:D@
Q0848@06000HaPaS48@LiaS60QcW00/<H`@Q2488@QBU6<HDYAS65:D8@P0000848@<8@P<@Q00636<D
Y@aS248<H`Q20PaS00<48@Q224800PQ200<48@Q200005P0000<48@0000001`000goo00<007ooOol0
3Woo000?Ool01@00Oomoo`0012400P0000@48@0000048@<00003124000@Q00848@8000036<He[BDY
008Li`0336<48@000088@P8Li`05:DXU:CF]:DX]J`03:DX04bDY7>LYBR486<HLiaS648@HaRU:5:Da
S3g_;F/@Q0@Q7>LQ21BU00@<H`88@P087>LHaRU:<H`YBRe[:DXHaP88@P8DY@036<HQ22DY008Q208L
i`0;8@P8@PaS36<DYAcW5:DHaPQ248@HaP0248@00`Q20000000200000`@Q0000000:00000`@Q0000
00020002124600001@@Q001oogoo00007Goo00<007oo00004@0000<<HaS648@00PaS00<48@000000
0P@Q0PaS00<DYA246<H01ABU00@@Q0aS5:D@Q0<<H`0<248<HaBU248HaQcW5:D8@P0036<@Q0Q21P@Q
0PaS00<DYAS65:D00QBU00<<H`@Q12400PQ200<<Ha2448@00Q240PaS00/@Q0@Q12448@Q236<8@PaS
1248@PaS0088@P031240000001h000=oo`03001oogoo00ioo`003goo00<007ooOol00P0000<48@00
00000`@Q0P001`@Q00X8@Re[<H`Q22U:6<H48@Q25:D<H`80000436<Q22DY<H`3;F/01RDY8@PDYABU
6<HU:@8Li`046<HDY@Q26<H29BT02SF]6<H@Q00048@]J`aS48@8@PaS0PQ20Q2400DHaR48=JdaS2e[
008U:@04124<HacW8@P27>L02R48:DXU:ABU7>LU:@aS5:D48AS60QcW00X@Q1S65:D@Q2485:DHaP@Q
00048@<000031240000000H000<48@<000041240000012470002Ool00`00Oomoo`0KOol00`00Ool0
000@00002P@Q5:DHaQ245:D<H`001248@P@Q0P0000@48A2448@HaP<DY@8@Q088@P0336<@Q0aS008<
H`0324848@aS008@Q0086<H<H`Q20008@QBU1248@P@48@88@P0536<@Q1S66<HDY@0248@01000124<
Ha240PaS00T@Q1BU48@8@PaS48@48@Q200000`aS00L8@PaS2488@Q24248<H`0P0003Ool00`00Oomo
o`0>Ool000moo`05001oogoo00048@0300000`Q200048@02124400003@@Q00048@Q2;F/LibU:;F/Q
20Q236<@Q0aS00800004124<Hbe[=Jd2:DX03Be[9BTQ21S67>LQ22DY8@PLia245:D@Q1BU00<]J`07
?Nl<H`@Q248YBQBU36<00PQ200H<H`Q25:D@Q1S65:D2=Jd012e[<H`]Ja240QBU00D@Q1S67>LYBQcW
008HaP0@8@PU:A245:D8@QBU6<HQ212436<HaQBU8@P8@QS60002124300000`Q200000003000010@Q
00048@@Q0`000P@Q0P0000<48@0000001P000Woo00<007ooOol06goo00<007oo0000100000<48@00
00002@0000<48ABU36<00QBU00D@Q0@Q1248@P@Q00<00003124DYAS600<DY@8@Q08<H`<@Q00336<8
@PQ20088@P<DY@067>L48@00124DY@Q21@@Q0PQ200L<H`Q26<HHaQBU6<HDY@04248236<011BU36<<
H`aS0Q240PQ200/48@Q236<@Q0Q2124<H`Q248@48@aS00H000031240000001L000=oo`03001oogoo
00ioo`003goo00<007ooOol01@0000H8@P@Q12448@001242000212402`001248@S6<:DXaS2e[9BT<
H`Q26<H00P000`Q200HQ236<<H`aS2e[:DX29BT02R486<HLiacW6<H48@Q248@Lib480S6<00dDYA24
48@000aS9BT8@PaS48@<Ha245:D<H`026<H00c6<=Jd]J`02<H`01Re[8@PLib487>LDY@<@Q0085:D@
Q1248@P@Q0Q236<Li`8Q20035:D<Hb48008Q20045:DHaPQ224830002124800021242000010@Q0000
00@Q0P0000<48@0000000P0000@48GooOol001eoo`03001oo`0000@000031240000000T00006124H
aQBU6<HDYA240P@Q00<<H`0000000`@Q00@@Q1S66<HHaP8DY@<@Q0@<H`0500048@Q236<@Q0026<H3
24800`00124@Q00212401@Q21248@PQ212400PaS0QS600PDYAS66<HDYA2436<@Q0aS1`Q200D@Q0Q2
12448@aS008@Q00324848A24008@Q004248<H`@Q124M0003Ool00`00Oomoo`0>Ool000moo`03001o
ogoo00<0000712400000124000@Q00000P@Q00d000@Q124000@Q248YBS6<:DXe[Be[8@PDY@0248@0
1@001248@P@Q<H`00SF]00<U:Be[;F/00RDY00<Lia245:D00QcW00d8@Q245:DDYBDY<H`Q21240008
@PaS248aS002248336<01`Q236<HaQ249BTicS6<008]J`068@PaS248:DXU:AS60Q2400H8@P@Q000<
HaS6248248@00aBU9BTU:@0248@021cW6<HQ20aS6<H8@P001243000010@Q000000@Q0P0000<48@00
12400P0000<48@0012400`0000<48@0000000P0000<48@0000000Woo00<007ooOol06goo00<007oo
0000400000L48ABU6<HDYAS65:D@Q003248200000`@Q000HaP026<H00a245:DDY@0248@00`aS2488
@P0236<02@@Q2488@PQ248@HaQ242480000312400aS612448@0512401@aS248@Q1cW6<H00QBU00H@
Q1S648@DYA2436<224801P@Q000000@Q36<48@<8@P8@Q088@P8<H`0448@48@aS124N0003Ool00`00
Oomoo`0>Ool000moo`05001oogoo12400002124500000`@Q0000000212401`0012448@00:DXicRe[
008aS006:DX<HaBU5:D000@Q0P0000TU:AS67>LQ22DY:DXU:BU:8@P00QBU00<Q21S67>L00QBU00`8
@R48<H`U:@aS12400124124U:@aS248312401@aS1248@Q246<H00Sg_00<aS3W>8@P00Re[01P48A24
36<@Q0aS48@<H`Q236<Q20aS7>LHaQBU6<HQ21cW48@HaQcW;F/HaQBU48@40003124200000`@Q0000
0002000212400`0012400007000010@Q000000@Q0Woo00<007ooOol06goo00<007oo00004@0000<D
YAcW5:D00QS600@DY@@Q2488@P@0000348@<H`aS008@Q0045:D@Q1BU48@224800a2436<<H`022480
1@@Q48@HaQ2412400P0000<8@P0048@00P@Q0`0000D48@001248@PaS008Li`036<HLia24008DY@06
0008@P@Q24848@Q20`@Q00T@Q0@Q36<<H`Q236<@Q0aS24800PaS00@DY@aS2488@Qh000=oo`03001o
ogoo00ioo`003goo00D007ooOol48@0000<48@0400048@00000412403@Q2000000@Q000HaSF]:DXa
S3F]9BT@Q1cW008DY@0324848AcW00<HaP037>LQ2248008YBP069BTLiaS66<HYBQcW0Q2400/<HbU:
=JdaS0Q236<8@P@Q248e[A2400848@0736<8@P@Q124@Q1BU7>L00cF]00@icRU:8@P48@<<H`0<248@
Q1BU48@DY@aS8@PHaQcW6<H<HbDY0RU:0QcW00DU:Be[8@P8@QcW0088@P<0000624848@@Q124000@Q
2P000P@Q00@8@P0000048@<0009oo`03001oogoo01]oo`03001oo`0000`000031240000000800003
36<HaQBU008HaP0348@8@PaS0088@P03124000aS00@<H`8@Q08DY@0648@<H`aS36<DY@aS0PQ200@4
8ABU6<HHaP<48@0400048AS62482000212420002248020aS6<HHaQS67>LDYA240004124424800`@Q
48@<H`0236<010@Q48@DYABU0PaS00D@Q1BU48@48@aS00848@<000031240000000l0000312400000
00@000=oo`03001oogoo00ioo`003goo00<007ooOol00P0000<48@0012400P@Q00H000@Q124000@Q
0002124300000`Q2@Q0aS002=Jd00bU:248Li`037>L01A24>LhQ22DY:DX00RDY00XaS3F]=Jde[BU:
7>LDYB487>L@Q08HaP0;<H`]Jbe[;F/8@P0036<48Be[8@P]J`02@Q0014Ha=JdaS3W>0QBU00LLicF]
?Nle[C6<7>L8@P02124030aS5:DHaQBU36<@Q1BU8@PDY@aS8@P@Q0<Q20096<H@Q248:DXaS2DY6<H@
Q0@Q00@000031248@P0000D48@04248000@Q124200000`@Q00048@0412400`0012400002Ool00`00
Oomoo`0KOol00`00Ool0000A00000`@Q8@PHaP026<H00aBU124<H`0336<01@Q27>L@Q1245:D00Q24
11S600HDY@aS248@Q0aS248236<02aS65:DDYABU124000@Q000DYA245:D00b480QS600HLi`Q2248<
HaS67>L26<H02@aS124000001248@PaS24848@0224801A2424848A2424800a2400P<H`Q248@DYAS6
48@<H`Q21P0000<48@000000100000<48@0000003@000goo00<007ooOol03Woo000?Ool00`00Oomo
o`03000612401@0012448@@Q000010@Q00@002DY<H`]J`8aS00<36<HaPQ27>L48Be[<H`YBSF]:DXU
:C6<0SW>0Sg_00DYBR485:DLibU:008HaP0>8@PaS3F]>LhU:@aS00048@Q2:DX<HbDY@Q0mk`8e[@05
124@Q1245:D@Q002?Nl2=Jd00b48:DX8@P0224801Q2436<DYAS636<U:@8Q208Li`039BTDYB48008Q
20075:DLib48<H`YBQ248@P010@Q200000D48@000008@P@Q00@00004124000@Q12440002Ool00`00
Oomoo`0KOol00`00Ool0000B00000a246<HDY@026<H030@Q36<48@aS000DYAS65:DHaQBU48@HaP@L
i`055:D@Q0Q236<DY@0236<01Q246<HHaQcW48@48@800006124DY@@Q48@Q21cW0QS600<000Q22480
0PQ20QcW0QS600<@Q1BU12400P@Q00D8@P@Q248<H`@Q00<@Q08<H`0348@8@Q24008@Q007248<Ha24
6<HDY@Q248@03`0000<48@0000002`000goo00<007ooOol03Woo000?Ool00`00Oomoo`0200061242
000212400`Q212400002124200003124;F/LicW>;F/8@PaS248@Q0Q2AS4icP8aS005;F/YBRU:<H`i
cP02=Jd01RDY6<H<Hb48<H`Li`8Q208icP9:DP0648@48@00124@Q1S60PQ200<@Q0@Q36<00PaS00<H
aPaS48@00SW>0cF]00PLib485:D<H`@Q5:DHaQcW0R4800T<HbDY:DX@Q2DY8@PHaR487>L00QS600@Y
BS6<;F/U:@8HaPH000<48@@000848@<000051248@P0000048@050002Ool00`00Oomoo`0KOol00`00
Ool0000;00000`@Q0000000400001@Q25:D<HacW5:D00`@Q00@8@P@Q8@PLi`8HaP<DY@0:6<HLiaS6
6<H@Q0aS124@Q1S636<248@27>L29BT01PQ200000000248<H`848@03248000@Q00848@0336<48@Q2
008Li`<HaP0636<@Q0Q2124000Q20PaS0Q2400@48A245:D8@P8@Q00336<@Q0aS008<H`045:DHaQBU
48@236<C00000`@Q000000060003Ool00`00Oomoo`0>Ool000moo`03001oogoo00<48@0300048@@Q
00<0000324848@0000848@800006124000Q25:D]JbDY0SW>0PaS0P@Q00<]JeJe>Lh00Re[00@YBS6<
;F/e[@8icP04;F/LiaS648@2:DX00acW6<HLi`02<H`0648@>Lh8@PQ21248@PaS5:D@Q0aS1248@Q24
2480024848@DYBe[?Nle[CW>?Nl@Q08Q200D36<@Q0aS5:DHaQBU8@PDYAcW9BTHaQcW9BT8@Q248@PY
BQcW;F/YBP8]J`0336<HaP@Q008000<48@<000031240000000@48@0400048@00248312400`001240
00020002Ool00`00Oomoo`0KOol00`00Ool0000800000`@Q00000006000010@Q248DYA240QcW0P@Q
0P0000<DYBU:7>L00aBU00<HaQBU6<H00QcW00@DY@aS36<8@P8DY@<<H`8HaP058@PLi`@Q12400002
124224801`@Q00048@Q2124001240088@P035:DLiaS6008Li`0=248@Q1241248@P@Q248<H`Q248@8
@PaS48@00PaS00H@Q0@Q248@Q1BU36<45:D00`@Q36<0000B00000`@Q000000060003Ool00`00Oomo
o`0>Ool000moo`03001oogoo008000051240000000048@0200001P@Q00000000248000<48@0436<@
Q3F]6<H2=Jd01000248000@Q0Tic00H]Jc6<<H`]JcF]<H`2=Jd3;F/27>L00bU:9BTQ20028@P0136<
;F/e[B480`@Q00<001246<H00PaS00<8@PaS48@00QBU00@HaQ2448@HaP@mk`0=8@PYBSF]48@8@Q24
6<H@Q1BU48@DYB487>L00RDY00LYBQBU5:DYBRDY8@PHaP02;F/013F]9BTLiaS60P@Q0P0000L48@00
00048@001240000312401@001248@P0012400P0000<48@0000000`000Woo00<007ooOol06goo00<0
07oo0000300000<48@0000000P0000@48@Q26<H<H`8HaP0400048@0000029BT011BU6<HHaQBU11S6
0aBU0PaS00<DYA2448@00Q2400@HaQBU6<H@Q0@00003248<H`@Q00<48@<8@P0436<8@PQ236<47>L0
1a245:DHaPQ21248@PaS00@8@P0548@<Ha2448@DY@02248011BU48@@Q0aS0QBU00@HaQ2436<<Ha00
00031240000000P000=oo`03001oogoo00ioo`003goo00<007ooOol00`@Q00D000Q212448@0000@4
8@<8@P0948@U:AS6=JdU:DYBAS4mkcF]00848@0?000aS5[F@Q0e[BU:;F/mkc6<>Lh]JcF];F/YBRDY
00<YBP099BT]Jb489BT]JcF]<H`U:@Q200848@0<36<@Q36<9BT<H`Q200048ABU48@<HaBU0Q240Sg_
00Xe[D8@>LhHaRDY<H`Q22U:5:D@Q08<H`8Li`035:DYBRU:008Q20065:DLibU:7>LU:B480cF]00@<
Hc6<124000D48@0600048@@Q248000@Q0P0000<8@P00000010@Q0`000P@Q0Woo00<007ooOol06goo
00<007oo00000`0000<48@0000001@000`@Q00T8@Q2436<HaQ249BTQ21cW6<H00`0000@HaRe[8@PH
aP8DY@057>LHaQcW5:DHaP025:D01Q245:DDYABU48@DY@8@Q0055:DHaQS648@48@02000010@Q248H
aQ240P@Q0P000PQ200@48@Q22488@P8Li`086<HQ21cW36<@Q1S648@DY@88@P848@8<H`03248DYABU
008@Q004248<HaBU36<248@36<H00`@Q6<H0000900000`@Q0000000200000`@Q000000090003Ool0
0`00Oomoo`0>Ool000moo`04001oogoo00022482000010@Q00048@@Q100000<<H`0048@00RDY00lY
BQS69BUF]CW>5:D8@P0036=:DTic@Q0e[C6<?Nl00c6<01<e[C6<<H`aS2DY8@PicRU:8@PYBRDY8@P]
JcW>9BT<H`0024848@0224801acW48@001cW36<@Q1cW008@Q00F7>L@Q1BU9BU6<CW>?Nm241BU6<Hm
kaS65:DHaR487>LQ22DY;F/LibDY7>L29BT01aBU6<H]JbDY<H`U:CF]008]J`04:DXQ212412420003
12400`0012400002000010Q2124000@Q10000`@Q0P000P@Q0Woo00<007ooOol06goo00<007oo0000
0P@Q2P0000<48@0024800Q2400TDY@aS48@YBQcW24848@0012400RDY00@Q21S66<HLi`LHaP8@Q004
7>LDYA245:D248@01aBU7>L@Q0@Q00048@0000848@0736<8@P0036<48@Q236<00PQ200D<H`Q2248@
Q248008Li`098@P8@PaS7>L<H`Q236<@Q0aS008@Q0045:D<Ha2436<248@01`Q236<DYA246<H@Q1S6
00<DY@0348@8@P0000X000031240000000`000=oo`03001oogoo00ioo`003goo00<007ooOol00P00
00<48@0012400`@Q00@000@Q00048@80000A248]JcF]=JdaS2e[?NmJeTYB48@000aS7>M6<D8@?NlY
BP02=Jd2<H`2=Jd03c6<>Lh]JbDY;F/aS2e[:DXU:BU:=JdYBRe[7>LicP0348@01PaS12448ABU8@PD
Y@DHaP<DY@057>LmkdHa?Nm6<@028@P01bU:<H`icSg_>Lhe[C6<008e[@8Q2003;F/Q22e[008Li`0:
:DX]JbU::DXaS2e[<H`mkaBU;F/60002124300001@@Q0000000012400P000P@Q00H000@Q124000@Q
0002Ool00`00Oomoo`0KOol00`00Ool0000=00000`@Q5:DHaP026<H021BU7>L]JbDY248000@Q36<2
8@P00acW5:DHaP066<H01AcW5:D@Q1BU6<H00QBU00<@Q1BU6<H00QBU00<<HacW24800PQ200H48@00
0008@Q24248536<324801@aS7>LQ21cW8@P00Q2400<DYAS67>L00QcW11S60Q2400<DYA245:D00PaS
11BU00HHaQBU6<HLi`Q25:DJ0003Ool00`00Oomoo`0>Ool000moo`03001oogoo00@00003124000@Q
008000H48@04;F/icSg_BU82AS402Cg_>LhHaP@Q248mkc6<9BT]J`02<H`02CW>=JdicS6<=Jdmkbe[
=JdaS002>Lh00d8@>Lhe[@029BT01CF]:DXU:DHa7>L00QS600@48A24:DXaS08<H`0I48@000005:D8
@QS68@PLia24?NlicSF]?Nle[ABU6<HYBSF]7>L]JcW>;F/HaRDY8@P00be[00<aS12436<00R4812U:
00LLicg_;F/Q20aS00048@04000224800`0024800002000212401@Q20000000012400`0000D48@00
Oomoo`0001eoo`03001oo`0000h000045:DLiacW9BT28@P27>L01`aS00048AcW6<H@Q1BU008HaP03
7>LHaQcW008HaP047>LDYAS66<H27>L00b487>LHaP0248@011S65:D@Q2480`aS00@000Q25:DHaP84
8@092480000024848@aS48@<H`Q2008Li`0<6<HLiaS6248<HaBU6<H<HaBU7>LDY@aS0Q240aBU00<H
aPQ212400Q2411BU00D<HacW5:D@Q0@Q00H000848@0300048@0000@000031240000000L000=oo`03
001oogoo00ioo`003goo00@007ooOol48@800003124000@Q008000<48@0400048@@Q12428@P04cW>
=Jde[Dic<H`]J`aS6<HYBT8@:DX]JcW>AS5:DSg_>Lhe[BDY008aS005:DXicRe[>Li24002=Jd05R48
9BTe[CW>=JdYBSg_<H`icRU:48@<Ha24=JdHaPaS6<H8@Q245:D@Q0aS0Q2400HHaRDY@Q0icSg_@Q02
5:D01248124<H`@Q0Q240QS600<LibU:?Nl00R4800DYBQcW8@PLibe[008U:@0636<YBUJeAS4DYBU:
10000P@Q00@000@Q00048@800005124000@Q1248@P0512430002Ool00`00Oomoo`0KOol00`00Ool0
000>000248@02QcW6<HHaRDY6<HDY@@Q36<DYB480QBU00<Lib489BT00QcW00THaQ246<HHaQBU7>LD
YAcW8@P00QS60Q24010HaQcW6<HDYAcW6<HLiaBU24848@Q26<H<H`@Q36<48@<8@P061248@PQ236<@
Q2480QcW00LQ20Q2248@Q00012400002248336<02ABU7>L@Q1245:D<Ha2436<DY@0248@01P@Q5:DY
BR48248DYA0000031240000000H000=oo`03001oogoo00ioo`003goo00P007ooOol000@Q00048@Q2
0P0000<48@0012401@0000d<H`@Q>Li6<E:D48@48B4848@LibU:>LhQ2002@Q005Cg_>Lhe[CF]>Lhe
[Cg_>Lhmkbe[=JdicSg_<H`YBR48=Je6<CF]<H`YBP02?Nl00d8@?NlLi`0248@01B487>LDYA242480
0PaS0PQ200@LiaBU6<HHaP924006>Lhe[B487>LaS0aS0QS600`@Q2DY=JdLib48=JdaS2U:;F/e[Be[
7>L29BT03C6<:DXQ23F]F]I:DRU:8@P@Q0Q2124000@Q0088@P<000L48@080008@P0000048@001240
009oo`03001oogoo01]oo`03001oo`0000<000031240000000P0000=124001cW8@PYBPQ2000@Q0Q2
36<DYAcW48@00R480QcW0QS600<LiaS67>L00QcW00TDYAS67>LLiaS65:D@Q1S68@P00QS600HDYAcW
7>LQ21cW36<22480112436<8@PQ21@@Q00@<H`Q236<<H`8Q20067>LHaQ2436<HaP@Q0PaS00D8@Q24
6<H<Ha24008HaP8DY@036<HDY@aS008@Q00:6<HDYA246<H]JbDY5:D@Q0Q212430002124;00000`@Q
000000040003Ool00`00Oomoo`0>Ool000moo`09001oogoo24848@00124000Q200<48@0300048@Q2
00848@06000<H`@Q8@PicR480QS600`48CF]=Jde[CW><Ha244icAS5:DTHa>Lh3?Nl2;F/2=Jd073W>
?Nlmkbe[8@Pmkd8@=JdaS3W>AS4mkdYBE[De[A2436<HaQ247>LDYA2436<Li`aS000DYAS60QBU00E2
44Ha=Jde[Cg_008Li`08=Jd8@QcW36<DYAS65:DHaP8YBP04=JdYBRe[<H`25:D031S68@PYBRU:8@Q2
44Ha@Q0DYBU:1248@P<48@0:00048@00124000@Q00048@Q21242000212401@001248@P@Q00000Woo
00<007ooOol06goo00<007oo1240100000<48@0000000`0000T48@00000000@Q000@Q1cW48@00PaS
00/001S66<HHaQcW6<HQ22DY8@PU:B4800@Li`8DY@8HaP<Li`045:D@Q1cW8@P26<H02acW8@PLibDY
:DXHaPQ2124<H`Q236<00PQ200H48@aS124000Q236<224828@P26<H02acW36<<HaS6124<H`@Q248<
H`Q236<00QBU00@HaQBU5:DHaP88@P0536<@Q1BU5:D@Q0038@P010Q25:D000@Q2`0000<48@000000
1@0000<48@0000000goo00<007ooOol03Woo000?Ool00`00Oomoo`0212401@Q212448@0024800P@Q
00<000@Q24800P@Q00@8@QS6<H`@Q08mk`098@P8@QS6:DY243W>;F]:DT8@009BU003@Q0mkcg_008e
[@04?Nl]JcW>>Lh2=Jd01CW>=JdaS2e[@Q000SF]010]Jd8@AS5244HaBU8mk`Q248A240@Q;F/Q20Q2
36<@Q0848@055:DLiaS648@]J`02@Q003cg_@Q0@Q1S68@PmkaS69BTe[AS65:DYBRDY8@PDY@02<H`0
3SW>@Q0HaQBU8@PU:Be[:DXU:CW>BU8U:AS68@P200021242000030@Q000000@Q00048@0024848@00
124000<48@80009oo`03001oogoo01]oo`05001oo`0000048@0300000`@Q0000000200001`@Q0000
00@Q36<HaPQ2008Li`0948@48@aS5:DQ21cW5:DU:B48008YBP038@PLiacW008HaP047>LDYAcW7>L2
6<H01AcW6<HHaQBU8@P00QS600<DYB488@P00R4800PU:AcW1248@R48000DYA240P@Q00@8@P000008
@P8<H`0@248DYB488@PLib48248<Ha247>L<Ha246<H<H`Q25:D248@01`Q26<HHaQcW8@P<H`Q2008@
Q08DY@0648@LibDY48@<Ha243@0000<48@0000001`000goo00<007ooOol03Woo000?Ool01000Oomo
o`@Q0P0000<48@0000000P@Q0P000`@Q020000Q2=JdU:CF]AS4aS2485:DHaP00;F]BU3W>?Nm6<D8@
AS4icSF]>LhaS3W>AS4mkcF]<H`e[Be[=Jd]JcW>0SF]01T]Jc6<:DXe[Cg_AS4icTicBU8@Q0Q2>Lh4
8BDY8@P<H`Q236<DY@@Q5:D8@QBU48@DY@02AS42@Q003RDY7>LHaS6<@Q0@Q2e[8@P]JcF]6<HQ21BU
=Jd2?Nl01CW>@Q0Lib487>L00RU:00PQ22U:AS5:DQBU:DXDY@Q20P@Q00<000@Q12400P0000@8@P00
248000848@030008@P0000848@0300048@00009oo`03001oogoo01]oo`03001oo`0000d0000<124H
aQ246<HQ21S648@8@PaS000DYBU:0QcW0b4800LLiaS67>LHaQcW8@PLi`036<H011BU6<HDYAcW0QS6
00LDYAS65:DHaQcW8@PLi`029BT010Q2124Li`000Q240`@Q00@8@P0024848@<8@P@Q200>48@<H`aS
6<HQ20Q25:D@Q1BU6<H<Ha24248HaP<Li`048@P<Ha2436<25:D021245:DQ22DY248DY@Q212470000
0`@Q00048@0400000`@Q000000040003Ool00`00Oomoo`0>Ool000moo`03001oogoo00848@H0000D
12400000124000@Q<HaBU3F]?Nle[D8@=Jd8@QBU124@Q2e[=Je2408icP07?Nle[C6<?Nm243W>?Nl0
0SW>0S6<00l]Jc6<<H`e[D8@>Lhmkbe[?NlicSF]BU8mkdYB9BT00PQ200DDY@@Q;F/Li`Q200<<H`04
5:D8@P@Q7>L248@01DYBAS56<Dic=Jd00QS601@LibDY;F/LiaBU;F/aS248>LhU:Be[9BTQ23W><H`]
JacW:DXU:Be[0RDY00HYBT8@>Lh@Q24848@21240100012448@0010@Q00@8@P@Q0008@P8000@48@04
001oogoo000MOol00`00Ool0000=00003QS6:DXHaQcW6<HQ21S61248@P00248DYAS68@P37>L26<H0
0acW8@PLi`037>L26<H01ABU6<HHaQS68@P00QcW00PDYAcW7>LHaRDY7>LU:A240P@Q00@8@P005:D<
H`@48@0424848@0036<224801BDY8@PQ22DY6<H00`aS00X@Q1BU36<8@QBU6<H@Q1cW48@DY@8@Q007
7>LHaQBU36<DYA245:D00Q2400HDYB487>L8@Q24248:000010@Q000000@Q1`000goo00<007ooOol0
3Woo000?Ool00`00Oomoo`04124200000`@Q00000004124010aS<H`e[CW>0Re[00e242U:7>LDYA24
124<HbDY=JdmkcF]?Nm24002>Lh01D8@?NlaS48@?Nl00T8@00HaS2e[;F/icSg_>Lh2=Jd05CW>AS52
45:DBU96<AcW36<DYCg_36<DY@@Q@Q08@PaS48@00124248<H`0248@00dic@Q124002AS402ABU7>LL
iaBU7>Le[AS68@PDY@03:DX02RDY7>LU:BDYBU8YBRe[8@PU:B480Re[0RDY00E>Lbe[48@YBQBU00<0
00848@8000848@0424848@001242000212400`Q21248@P02Ool00`00Oomoo`0KOol00`00Ool0000<
000010@Q6<HHaQcW0QBU00<Q21BU36<00PQ200P000@Q48@HaQcW6<HLib480QcW00DQ21cW6<HQ21cW
008Q20036<HDYABU00<Li`8HaP0>7>LQ2248:DXU:B4836<48@Q27>L48@Q2000Q20848@03248000Q2
00848@88@P039BTQ2248008Q2009248<H`aS248<HaS636<@Q0Q200<DY@0548@<Ha2448@U:@025:D3
48@25:D248@01BDY5:D8@QBU24802@0000<48@0000001@0000<48@0012400goo00<007ooOol03Woo
000?Ool00`00Oomoo`03124400000`Q212448@0200001@Q2000]JbDY;F/00SF]00=6<C6<=Jd00Q24
0P@Q00H8@QcW@Q1:DSg_=Jd2AS4013F]@Q0icSW>0Sg_0SW>00<]JcF]?Nl00SF]00HYBSg_BU8e[Dic
AS42BU802@Q236<8@SW>7>L8@P@Q;F/e[@0248@01aBU6<H<H`aS5:DHaSg_0096<@03BU9241S6008H
aP0?7>L<Hbe[=JdHaRU:<H`Lia247>LYBQcW5:DaS1cW008e[@037>LU:BDY008YBP069BTe[DYB:DXD
YBe[0PQ200@48@0012448@<000@48@0324848@00008000848@9oo`03001oogoo01]oo`03001oo`00
00H000031240000000800005124001BU48@DY@026<H00b486<HHaP02248200001P@Q36<Q22DY7>LH
aP8Q20036<HQ21cW00DLi`035:DHaQcW008HaP065:DLibDY6<HU:B480RDY0`@Q00HLi`aS124001BU
6<H324801PaS12448@Q236<Li`8Q20039BTQ20aS00<<H`0>124DYAS636<DYAS636<8@PaS5:D<H`Q2
6<H<H`8HaP0336<@Q124008DY@0648@HaRDY5:D8@QBU0P@Q2`0000<48@00000010000goo00<007oo
Ool03Woo000?Ool01P00Oomoo`@Q00048@8000D48@0600048@Q2000Q22e[0S6<02He[CW>>Lhe[AS6
36<48@Q25:D00124?NmBU48@BU9BU4ic?NlicSF]?NlicSF]<H`e[Cg_@Q0mkc6<=Je:DS6<AS5>Ld8@
BU8YBPaS0P@Q00PYBPaS48@48ABU?Nl8@R480QS600D000aS5:D@Q3W>00=6<@03@Q0U:AcW00<HaP04
8@PYBSg_8@P31242248011cW8@PDYAcW0RU:00<aS2U:;F/00RU:00TU:AcWAS56<BDY7>LYBPaS1240
1`0000H48@001248@P@Q000312401000Oomoo`007Goo00<007oo00002`0000@48@0048@DY@<HaP8L
i`0>6<H<H`@Q00048@Q20008@QcW:DXQ22DY:DXU:@8Li`036<HLiacW00<HaP037>LQ21cW008HaP08
9BTHaR489BTQ22DY5:D48@8000085:D48@Q20008@QcW124@Q08<H`0500048@Q2248Li`048@P00a24
36<<H`0236<011245:DLia240`000P@Q00@<Ha24248<H`8DY@036<HDYABU008DY@0848@<Hb488@P@
Q0aS5:D48@/000031240000000@000=oo`03001oogoo00ioo`003goo00<007ooOol00P@Q0P0000H4
8@00124000Q21242000212402Q24?Nle[C6<;F/icTHa;F/YBQ240P@Q00LYBPaS248Q23W>BU8mk`03
AS400d8@>Lhmk`02>Lh2<H`013W>=Jd]Jc6<0SW>00LmkdicAS5242DY36<0000212401`00:DX48@Q2
000LibU:00<48@8<H`8HaP04?Nm>Ld8@BU82@Q002QcW5:D@Q1S68@PDYA24=Jd<Ha240PaS00`DY@aS
36<48@aS124HaRe[>Lh]JbU:=Jd29BT01Sg_F]I:DQcW9BTHaP<00004124000000003124010Q236<0
00000P@Q0P000Woo00<007ooOol06goo00<007oo00001`0000<48@0000000`0000L8@QcW6<HHaQBU
7>LQ20025:D010Q2000001BU0P@Q00@@Q1cW9BTLi`@Q20@Li`8HaP047>LHaQBU6<H37>L01BDY8@PQ
21241240100000HDY@00124000aS5:D30002124236<011cW9BTQ22DY0R4800D<H`Q2248<Ha240088
@P036<H48@Q200848@0924848@@Q00048@0036<DYAcW008DY@096<H@Q1247>L]JbDY36<@Q0aS00X0
00848@H000=oo`03001oogoo00ioo`003goo00<007ooOol01P@Q00H8@P002488@P@Q0002124050aS
CW<icS6<=JdmkdHa=JdicRDY248@Q2DY5:D<H`009BTicTYB@Q02>Lh00d8@=Jdmk`02@Q002Cg_=Jdi
cRe[<H`icSF]?Nm:DP02CW<025Je48@48@@Q0008@QcW=Jd248@04PQ25:DDY@Q236<DYAcW48@DYAS6
>Li:DT8@AS5244ic6<HDY@<@Q0035:DHaQBU008HaP0536<DY@aS5:D@Q00224801A24124<H`aS7>L0
0S6<00Xe[CW><H`]JacW=JdLibU:00048@H000848@0336<8@P0000D0009oo`03001oogoo01]oo`03
001oo`0000D00004124000@Q124400000`@Q9BTLi`026<H03acW8@PHaQcW48@48@Q248@8@P@Q000@
Q1cW9BTQ20027>L00b486<HLi`028@P021cW6<HLiaBU6<HLiaS67>L39BT00bU:2480000200000`@Q
36<HaP0224800`@Q2488@P0212401`Q236<8@PQ236<LibDY00<Q20039BT<H`Q200@8@P0736<8@PaS
36<48@Q212400PQ20P@Q00D8@P0012448@aS00<HaP077>LHaQBU36<HaPaS5:D02P000P@Q1P000goo
00<007ooOol03Woo000?Ool01@00Oomoo`Q200000P@Q00H000@Q24848@Q2124200001@@Q000@Q4ic
=Jd00S6<00P]JdYBAS4mkbe[36<DYBe[0PQ200L@Q0008@PU:Be[>Li6<@03=Jd00dYB=JdicP02:DX0
2Be[AS4icSF]BU96<E:DHaP]J`0212403@Q25:D8@QBU>LhQ21S68@PLic6<248U:ABU00<@Q0085:DY
BTHaCW=6<D8@BU8Q20<HaP8@Q00?36<DYAcW5:DYBR481248@QcW36<LiaBU6<HDY@aS00848@0:7>Le
[Be[:DXLia24>LhQ22DY48@50004124010Q212448@000`@Q00@8@WooOol001eoo`03001oo`@Q00D0
0003124000@Q00D00003248U:AS6008HaP085:DU:B487>LDY@@Q248DY@848@072480012448@DYAcW
8@P00aS600<U:AS67>L00aBU00PQ21cW6<HU:B48:DXaS1BU0P0000`48@Q21248@QcW48@<Ha2436<H
aP@Q48@524800aBU8@PU:@028@P00bDY48@<H`0236<224803`@Q248<H`Q25:D@Q000124<H`@Q36<8
@PaS24848@0200001`aS6<HDYABU36<8@QcW008@Q0032480000000L000031240000000@00005125o
ogooOol0000@Ool000moo`04001oogoo36<300001`Q200048@@Q24848@0000<48@0_6<I243F]:DXa
S3F]BU96<D8@=Jd@Q1cW;F/@Q0@Q8@PLi`Q25:DHaRU:;F/e[CW>@Q0icS6<=JdaS3g_CW<e[Be[CW=6
<E[FJeXaS1241248@P0036<8@QBU>Lhe[@0348@011cW<H`Libe[0aBU00XLibDYBU9244Ha@Q16<D8@
6<HDY@8@Q08DY@0=48@HaQS66<H]JbDY;F/DYA2436<000Q212400PaS00@8@P@Q12448@8<H`06124i
cSg_8@PYBP@Q1P000P@Q0P0000@48@0012448@80009oo`03001oogoo01]oo`03001oo`@Q00<00005
1240000000048@05000010aS8@PHaQBU0QS600hU:B488@PHaPQ236<DY@Q2000@Q0aS1248@PaS0QBU
00@HaQcW8@PLi`<HaP0=7>LU:AS65:DU:B48;F/e[AS6248000@Q00000P@Q00<8@QcW6<H00`Q200@<
HaS636<DY@<8@P0336<@Q2DY00DQ200336<8@PQ200@8@P<<H`035:D@Q1BU0088@P04124000@Q0003
1243000212401@007>LLia245:D04@000goo00<007ooOol03Woo000?Ool01000Oomoo`000P@Q00@0
00Q2124000848@0300048@@Q0080000B5:DU:BU:8@PYBS6<BU9244Ha=JdQ21BU:DX@Q0@Q;F/Q2000
0PaS02<@Q1BU6<He[DHa@Q0icRU:<H`YBSF]9BU244YBE[EJeR480008@P@Q00048@00124@Q3F]>LhQ
21S65:DU:Cg_6<HaS0Q2008DY@03248]JdHa00A24004BU8DYABU5:D37>L26<H37>L061S68@P@Q124
248@Q1S65:D@Q0Q236<8@Q24248DY@@Q000aS48@:DXaS0Q200048@@000081248@P@Q0008@P@Q0008
@P80009oo`03001oogoo01]oo`03001oo`0000<000031240000000L00007248@Q1BU48@DYAS69BT0
0R4800THaQ24248DY@Q2000DYA2400000P@Q0PQ2014<HaS68@PQ21cW5:DHaQBU6<H@Q2489BTYBRe[
48@000@Q00D0000;248HaQcW48@<H`Q248@Li`aS6<H48@0224800`@Q5:DQ20048@P012DY2488@PQ2
2@aS00H@Q0Q224848@Q236<2248312400`Q21248@P0200001AS68@PDYAS612401`0000@48@000004
8@8000031240000000=oo`03001oogoo00ioo`003goo00@007ooOol000848@030008@PQ20080000?
124000Q200048@0036<DY@Q25:DQ20aS9BU242e[008mk`09124HaQS636<DY@@Q248HaPaS00848@0=
248<HacW:DYJeTic?NlicTYBAS5BU5[F9BT00`aS00<000aS12400`@Q00X004Ha=Jd]Ja24000HaSg_
48@Li`8HaP035:DQ24YB0096<@0=BU96<D8@>LhHaQ247>LU:B487>LDY@aS6<H00S6<01/]JbU:7>LD
YAS6124DYB487>L8@QS65:DHaPQ20008@P@Q2496<Be[<H`@Q0Q2124000@Q00000`@Q00P8@P@Q2484
8@aS124000@Q0Woo00<007ooOol06goo00<007oo00000`000P@Q100000d48@00000000@Q24848@Q2
48@48A248@PDY@027>L02@0036<<H`@Q248000@Q36<48@020002124010aS5:D]JbDY0QcW00DU:B48
:DX]Ja2400<48@0300048@0000@000088@PHaQBU248000aS7>L8@P<<H`03248@Q2DY008Q20079BTQ
22487>L<H`Q236<00Q2400@<H`Q2124<H`8HaP8DY@0E36<8@PaS0008@Q2436<48@aS248<H`@Q0004
8@00124Q21BU6<H8@P@Q00L00005124000@Q00048@030003Ool00`00Oomoo`0>Ool000moo`04001o
ogoo1244000212400`001240000200000`@Q5:DHaP02;F/02QBU36<U:DHa>LhQ21BU=JdHaS6<0QBU
00<48ABU5:D00P@Q00L8@PaS36<8@P0036<DY@0236<27>L01A247>L8@P0024800P@Q0P0000H8@PaS
00048@Q2=Jd2;F/031cW;F/mkcg_48@8@QcW5:D]JacWBU924096<@9240059BT@Q1247>LQ20027>L0
1D8@>LhmkdHa=Jd00SW>00He[AS66<HDYAcW48@28@P012DY48@8@Q240PaS00H000aS?NlaS2U:7>L2
00000`@Q00000002000212470002Ool00`00Oomoo`0KOol00`00Ool0000<00003PQ236<DYABU2484
8A248@PLia24248HaPaS6<H224800`002488@P02000412400`001248@P02124236<01@Q236<48@00
124010000P@Q0P0000H48AS65:DDY@aS5:D27>L01`Q2124<H`Q25:D<HbDY00DQ200548@8@PQ236<@
Q00236<01B487>LLib486<H00QcW00HHaPaS36<8@PaS248348@00`Q21248@P0212401P00124LiaS6
5:D<Ha0000=oo`03001oogoo00ioo`003goo00D007ooOol000@Q00<000<48@0L00048@000008@P@Q
48@<H`Q21248@QS68@P<Hb4836<Q20aS5:D]JacW6<HLi`aS6<H@Q1cW36<248@01000248<H`aS0QS6
00L@Q0Q2124HaPQ236<8@P0412401P0012448@Q25:De[@8Q200:7>M241BU248<HaBU:DX]JbDYCW<2
@Q0014Ha@Q0mkaS60Q2400@Q22e[;F/icP8mk`0<>Li6<Cg_?NlaS48@=JdQ22DY8@P]JaS60RDY00@a
S2DY124@Q088@P0736<mkd8@7>L]J`@Q00000P@Q0P0000@48@00124000<48@0300048@00009oo`03
001oogoo01]oo`03001oo`0000/00003124000Q200848@0;00048@aS48@48A24124@Q0@Q248DY@03
36<01@@Q36<8@PaS12400PQ200@000@Q12448@8<H`0424848@0036<3124700000`@Q248HaP0248@0
0`aS8@P8@P0212401@Q25:DDYA249BT0124800DLi`aS2488@Q24008DY@@Li`068@PLiacW6<HQ21S6
0a2400PDY@aS48@@Q1S648@000Q20`@Q00@Lib4836<DYA0000=oo`03001oogoo00ioo`003goo00L0
07ooOol48@001240000312402b48;F/YBPaS124000aS5:D000Q248@00QBU00X@Q0Q2124@Q1BU6<H@
Q0Q28@PLi`<e[@03:DX]Jc6<008e[@0B;F/YBQcW7>L8@QS69BT]JaBU48@HaP@Q000@Q00024848@00
0P@Q00@<HbDY<H`YBP8U:@0:48@<H`0048@LiaS65:D]JeJe@Q02AS400cg_@Q0Li`025:D042U:;F/i
cSF]>Li:DT8@>Lhmkd8@=JdmkcW>;F/Q21S60bU:00HLicW>;F/@Q0Q26<H200002CW>BU8HaRU:8@P8
@P001240000312401@001240000012400`000Woo00<007ooOol06goo00<007oo00001P0000@@Q1BU
5:D48@8000041248@P00124424802@@Q0008@PQ236<8@P@Q48@<H`036<H25:D36<H25:D236<010@Q
36<@Q1BU0PQ200H<H`000008@P001244000010@Q48@HaQBU0Q2400@8@P@Q0008@P8<H`03248DYBU:
00<Q20037>LQ20aS0088@P8DY@057>LHaQcW9BTQ20027>L01b486<HLiacW5:D@Q0aS00<DY@0636<L
iaBU24848@aS0P0000HLibDY36<DYA24124>0003Ool00`00Oomoo`0>Ool000moo`0A001oogoo0004
8@Q20008@P005:D]Jb487>LDY@@Q5:D8@P02000212401@Q236<48@@Q36<00QBU00P<H`@Q8@PicQS6
9BT]JbU:0RDY0RU:0QS600<Q21cW8@P00Q2400/U:AcW7>LDYAS65:D8@PaS00048@0000<8@P0L124U
:Be[:DXU:AS6248Q20aS7>LHaQBU7>LaS4HaBU9244Ha@Q0mkbDY6<H8@RDY<H`icSg_>Lh2AS406cg_
@Q12448@=JdicSF]8@PLiaS6;F/e[Cg_:DXQ22DY48@DY@aS000HaU:D:DX]JcF]24848@0200081240
0`0012448@02Ool00`00Oomoo`0KOol04000Ool00000124000@Q0008@QBU48@<H`Q20008@P@Q1000
0P@Q0P0000T48@Q224848@0048@Li`aS48@00QBU0Q240QBU0PaS00<@Q0aS48@00PQ200H@Q0aS36<8
@PaS24821243000312402@0048@DYABU48@<H`@Q48@48@0236<01@Q236<HaR489BT00b4800HLia24
36<48A246<H37>L28@P021cW8@PQ22486<HLiaS648@236<011BU6<HLiaBU0Q240PQ200@48@0036<Y
BP8DY@036<H48@0000d000=oo`03001oogoo00ioo`003goo00D007ooOol48@0000<48@04000Lib48
2482124020Q212448@Q2:DXLi`aS48@236<02@0048@HaRDYOomBU2487>Lmk`029BT01PaS6<HQ2248
9BTDY@<Q208YBP047>LQ21cW9BT26<H010Q212448@001@@Q00<00124=Jd00QcW00H48ABU36<DYAS6
5:D26<H012e[BU9243g_0T8@00<mkbe[5:D00QcW00<e[D8@?Nl00THa00PmkcF]?Nm243W>=JdicS6<
0SF]018HaRU:<H`U:B48<H`]JaS65:DHaPQ21256<DYB7>LYBR48124700000`@Q000000030002Ool0
0`00Oomoo`0KOol00`00Ool0000500000`aS48@48@02000020@Q000000@Q5:D<H`@Q248212402@00
248<Ha24@Q0YBQ2436<Li`0248@00`@Q36<@Q00248@010Q248@@Q1240QBU00@<Ha2436<@Q08<H`03
1240000000L0000:248HaPaS36<000Q21248@PaS248236<011BU9BTQ21cW0R4800<LiaBU24800PaS
00<HaR487>L00R4800LLiaS67>LQ21cW6<HLi`036<H00`aS5:DHaP0248@031S65:D<H`Q236<48@00
8@PU:@aS5:D@Q0h000=oo`03001oogoo00ioo`003goo00@007ooOol48@800005124000@Q7>LYBP02
;F/020aS12448@aS48@<Ha248@P236<01@@Q5:DmkdHaBU800S6<00HU:@Q248@48AS612428@P011S6
8@PU:AS60bU:00T]Jc6<7>LLibDY8@PDY@aS24800`@Q00h000aS1248@Q248@PicRU:124<HaS68@PD
Y@Q20aS600@]JdHa@Q1240=6<@05>LhDYAcW:DXicP02?Nl3@Q0013W>@Q0mkdHa0SW>00Hmkd8@=JdY
BQS6;F/2:DX01Sg_7>L<H`Q26<H@Q0848@09DYA24248;F/@Q0@Q00048@Q200D00004248000000002
Ool00`00Oomoo`0KOol00`00Ool0000500001@aS5:DDYABU12400P0000D48@Q21248@Q2400848@05
0008@QcW8@PU:@026<H01Q241248@P0036<0008@Q00436<@Q12436<45:D00aS636<<H`0248@00`Q2
12448@0400003@@Q00048@Q248@LiaBU00048@aS48@8@P@Q00<<H`035:DQ224800@Q20047>L8@PaS
5:D37>L38@P011cW8@PLib480acW00@Q21S65:D<H`<DY@067>L<H`@Q124<H`Q20P0000DYBR4848@D
Y@Q200<000031240000000<00004124000000003Ool00`00Oomoo`0>Ool000moo`05001oogoo0004
8@0200000`@Q00048@02:DX29BT06PaS5:D<H`@Q48@<Hb489BTQ21BU>Li:DTHaDYA:DSg_<H`Lic6<
@Q0aS0Q2124@Q2U:8@P2?Nl01T8@=Jd]Jb489BTDY@<@Q00J5:D8@Q24248DYB486<HQ22DY7>LQ21BU
9BT8@PaS6<H]JaS648@HaQBU7>LYBSF]AS524096<@03@Q16<DYB008@Q0068@Pmkc6<=Jdmkd8@0Sg_
00A243g_>Li2408e[@04@Q0icRe[5:D28@P00bDY:DXYBP0236<031BU6<H<H`00125JeSF]5:DYBP@Q
00048@D000051240000012400002Ool00`00Oomoo`0KOol00`00Ool0000600025:D248@01P@Q2484
8@0024848@<@Q00A248LibDY8@PYBRDY7>LHaPaS6<HQ21S6124000Q25:D@Q0027>L00b486<HDY@02
48@524801P@Q24848@Q248@<H`8@Q00436<@Q0Q248@212402@aS5:D<H`Q236<8@PaS5:DHaP068@P0
1BDY2488@Q247>L00QS600DLib487>LLib48008Li`078@PHaQS68@PLiaBU24800a240QBU0P@Q00<8
@PaS12400P0000@]JaS6248DY@d000=oo`03001oogoo00ioo`003goo00<007ooOol00P@Q0P0000H4
8@00124DYB48;F/28@P26<H05ABU8@P]Jc6<9BTHaQ24CW=F]DYBF]IBU5[FE[EJeSW>;F/Li`Q2000<
H`025:D03Be[9BTe[C6<48@Q22U:8@PU:B4836<DY@aS008@Q0059BU242e[8@PHaP02:DX25:D01124
5:DDYA240aS600HLicW>AS56<Cg_=Jd2BU801dHa@Q1:DQBU6<HLicF]008mk`09>LhmkcW>@Q0mkdHa
?NlicTHa008mk`09AS4mkc6<9BTQ22e[:DXU:@Q2008HaP03124HaPQ200800005DY@]Jb48=Jd8@P0;
0002Ool00`00Oomoo`0KOol00`00Ool0000600000`Q248@DY@0248@236<05@Q248@DYAS648@<H`Q2
9BTYBRDY;F/YBRe[:DX]JacW5:D<H`@Q00048@0224801aBU48@HaQS6248@Q1BU00<@Q0031248@P@Q
0088@P0548@Q21BU48@<H`025:D6248436<01AcW8@PQ21cW6<H00RDY0R4800DU:@Q236<<HaS600DL
i`038@PLib48008Li`068@PLiacW8@PLiaS60Q240QBU00L@Q0@Q36<<H`0036<48@0200001BU:5:D@
Q1S612402`000goo00<007ooOol03Woo000?Ool00`00Oomoo`02000212403PQ2000000Q236<HaRe[
7>L<HacW48@<Ha247>L29BT08QBU=JeF]DicF]IF]DicAS5242e[48@<Ha241248@PaS5:DHaRU:248H
aRU:6<HYBSW>;F/e[C6<6<H48@00248DYAS60PQ200X@Q1cW000DYA24248DYBDY48@<H`8HaP038@QB
U3g_00924003AS52448@00=6<@085:DHaQS6:DX]Jcg_>Li:DP96<@04=Jdmkd8@=Jd2?Nl05SW>=Je2
42e[5:DQ21cW9BT]Jc6<=JdQ20aS48@<Ha24124<HdHa9BT]JaBU0P@Q0P0000<48@0000000P000P@Q
0Woo00<007ooOol06goo00<007oo00000`0000<48@0000000P@Q00T<HaBU36<48@aS24848@Q236<0
0Q2400L8@QS6:DXU:Be[:DXU:@028@P01ABU24848@Q200000P@Q00X8@PaS5:D48@aS5:D<HaBU7>LD
Y@8HaP0636<000001248@PaS0P@Q00<8@PaS00000PQ200D48@Q248@8@P@Q008<H`0348@YBQcW00PQ
2003248<H`aS008DY@8Li`079BTQ22486<HLib486<H00acW00PHaR485:D8@Q2436<@Q1BU0QS600/@
Q0@Q24848@Q200048B4848@DY@Q200/000=oo`03001oogoo00ioo`003goo00@007ooOol000848@03
00048@@Q00<48@0:248DYAS648@<H`@Q48@Q236<9BT38@P02DHa?NlicSW>?NlaS2e[5:D<H`025:D0
5@aS48A242DY:DXHaR486<H8@R485:DU:Be[:DX<H`Q27>L8@QBU7>L@Q00200003`@Q248001S6124Q
21BU6<HU:A2436<@Q5JeBU924002AS40148@BU9244Ha0TYB01PDY@aS6<HHaQ247>Lmkdic@Q0icTHa
@Q0mkd8@=Jdmkbe[>Lhmkc6<9BTYBQcW8@P2@Q003CW>?NlmkcW>9BTHaPQ2000icS6<8@P]J`@Q00<0
00@48@<0009oo`03001oogoo01]oo`03001oo`0000P000091248@PaS24848@00248@Q1S600@@Q003
8@PLiacW008Li`046<HDY@Q21242248030@Q248Q21245:D<Ha2436<48A24248@Q08DY@848@0536<4
8@Q236<8@P0300003@@Q000<H`0048@8@PaS48@8@P@Q248YBRDY00@Q20039BTQ2248008U:@0:2484
8@aS36<8@PaS7>LU:B487>L28@P01AcW8@PHaQcW5:D00QcW00DHaQ245:D<Ha24008Q20@Li`0848@<
H`@Q000LiaS648@DY@/000=oo`03001oogoo00ioo`003goo00H007ooOol48@001242000312400`00
124@Q0025:D011245:DYBRe[0RDY01lQ22DY=JdaS2U:9BTQ22U:>LhaS3F]9BTHaQcW<Ha243W>6<He
[@aS124Q22DY>Lhe[BDY7>LicS6<;F/@Q00324800`0012448@0212401`aS248DYABU6<HDYB48008D
Y@059BU6<DHaAS5:DP02AS400dYBAS524002AS404aS636<@Q0Q25:Dmkd8@AS4mkd8@?Nl]JcF]>Li6
<Cg_>LhaS48@008Li`0:48@U:D8@AS5243F]?Nm>LdYB@Q025:D2124015:D:DXaS1S60`@Q00@8@P00
12448@800004249oogoo000MOol00`00Ool00009000524825:D448@26<H01ABU48@@Q1BU7>L00QS6
00X@Q0aS36<HaR487>L<HaS61240008@Q0087>LHaQ2436<LiaS65:D8@P<48@D000848@88@P0336<8
@Q240088@P0548@Q22488@PU:@028@P00bDY8@PQ20028@P01PaS1248@P@Q248Li`8Q20077>LQ21cW
5:DHaQcW8@P00QcW00HHaR4836<<H`Q248@38@P01AS67>LU:BDY8@P00PQ20P0000@YBQBU6<H<H`<0
00031240000000<00005125oogooOol0000@Ool000moo`05001oogoo00048@030000<@@Q000000@Q
0008@QBU6<HLibDY8@P]Jc6<8@PYBRe[<H`e[Be[:DXU:Be[=Jdmkbe[7>L]JcF];F/DYAcW9BT]JaS6
8@P8@QcW<H`Q20aS124DYAcW48@48@aS124000@Q008000051248@PQ236<48@0248@020007>LHaQBU
BU9244HaBU82AS44BU800d8@AS4Q200248@03ABUAS5:DSW>@Q1>Lcg_<Ha6<Cg_8@Q6<CW>0092400?
8@P<HbDY9BTicT8@BU9BU4Ha>Li6<Dic=JdaS1cW008<H`045:E242U:;F/312401@Q212448@001240
0P000Woo00<007ooOol06goo00<007oo00002@0000@48@Q236<<H`8@Q0035:DHaQ24008DY@8HaP8D
Y@0J48@DYAS67>LDY@aS5:DHaQBU248<Ha245:D<Ha24124<HaS648@48@00248<H`Q200048@H000<4
8@040008@PQ2000236<01@Q29BTQ22489BT00R4812DY0R48010@Q0Q22488@R489BTLib489BTLiaS6
8@PLia248@PLi`8Q200<48@48A2448@Lib489BTYBR487>LQ22DY0QS600D<H`@Q1248@R48008DY@<0
00031240000000@000=oo`03001oogoo00ioo`003goo00<007ooOol01@0000@48@0000048@80000<
248DYBU:9BTaS2e[7>LHaRe[9BT<Hc6<0QBU00X48A247>LYBSF]<H`DYBDY<H`mk`8icP035:DU:@aS
008Q2003248@Q124008Li`059BT@Q0@Q124<H`02124300003@@Q248000Q25:D<H`@Q5:DHaPaSAS52
44ic00I6<@09@Q16<DHa8@P@Q1S6AS4e[Cg_00=24003BU8icSg_009240079BTaS48@@Q0]JcF]9BT0
0Sg_00i244HaCW=:DT8@BU9242e[AS4e[@aS124<He:D0Re[00<48@0000001@0000D48@00Oomoo`00
01eoo`03001oo`0000X000061248@QBU48@HaQBU0PaS00@DYA24124HaP88@P040008@PaS5:D26<H0
0`Q248@HaP037>L00`Q248@48@0248@00`@Q2488@P0236<01A242480000012401P0000T48@001248
@P@Q0008@PaS12400R4800<U:B488@P01b4800H@Q0Q236<Q21S67>L38@P00bDY7>LLi`028@P01a24
6<HQ22485:DHaQ24008Li`8Q208U:@0:8@PU:B485:DQ21S6124000@Q:DX25:D:0003Ool00`00Oomo
o`0>Ool000moo`03001oogoo00@0000412400000000312401@0036<Q22485:D00RDY00`48BDY;F/<
HaS68@PLib48;F/HaPQ248@29BT051BU248@Q36<>Lhe[BU:;F/HaPQ26<H8@P@Q6<HaS0Q236<48@Q2
124300001PQ212448@00124000<8@P037>L@Q1S60096<@05BU96<DHaAS5:DP02AS4013g_AS4mkbU:
0QS600A243g_@Q0e[@92400<BU9>Ld8@<H`e[Cg_;F]6<Cg_;F/U:C6<0Sg_00=244YBDY@00TYB00a>
Ld8@<Ha6<D8@8@P<H`Q2<H`icRU:5:D212401`Q212448@@Q00048@00009oo`03001oogoo01]oo`03
001oo`0000/00004124@Q124248248@0300048@DY@@Q36<@Q0aS48@DY@aS1248@P8@Q00624848@Q2
6<HLiaS60QBU00L<H`@Q36<48@0036<HaP0212400`001240000300000`@Q00000003000312400`aS
248<H`028@P01BDY8@PQ22489BT00R4800@Lib487>LDY@8<H`048@PLib486<H28@P29BT02R486<HH
aQcW5:DQ21cW5:D@Q1S60QcW00<Q22DY:DX00bDY00DQ21S68@PQ212400848@046<HLiaBU24820000
0`@Q000000040003Ool00`00Oomoo`0>Ool000moo`03001oogoo008000848@032480000000848@09
24848@@Q248@Q2DY;F/Q22e[008@Q00;36<LiaS66<HDYAS67>L]JaBU6<HaS00248@00aBU:DX]J`02
?Nl0248@?NlLib485:DHaQBU8@P224800`005:D48@0400001`@Q00000000248<H`Q200848@035:D@
Q1cW00=6<@A:DP0>CW=:DTHaBU96<C6<7>LaS2U:@Q0icRe[>Lhe[@A24005AS4mkbDY@Q0]J`02:DX0
13W>@Q1244Ha0TYB00hicTHaBU8]JcW>BU96<Be[36<48@Q2>LhaS24810@Q00D000@Q124000@Q009o
o`03001oogoo01]oo`03001oo`0000<000031240000000800009124000001248@Q245:D@Q1BU0088
@P05124<H`aS36<8@P0236<011BU248<HaS60`Q20QBU0QcW00PQ21cW36<@Q0Q236<8@Q240P@Q00<0
00Q2000020000`@Q0P000PQ200@<Hb488@PQ20HU:@0<8@PU:B486<H<HaS65:DQ21cW5:DLiaS61B48
00<Lia248@P00aBU00@Lib488@PQ208U:@0>7>LQ22DY5:DLibDY8@PDY@@Q00048AcW6<H@Q0T000=o
o`03001oogoo00ioo`003goo00@007ooOol000848@8000<48@0500048@Q21240000224801b48:DXQ
22DY36<@Q1S6008Li`085:DHaPaS6<HaS2e[9BT8@P8U:@0>=JdQ22487>L<Ha24124DYAS65:D48B48
124DY@8<H`0300048@0000@0000<24848@aS36<8@P005:DHaPaS;F]BU4Ha14YB00=>LdYBDY@00dHa
010e[BDY?NlicSg_>LhYBSg_=Je244YB=Je6<C6<@Q16<@8Li`0=9BTicS6<?Nm6<DYB@Q0icSg_BU92
43g_@Q000THa00LicPaS24848D8@;F/HaP0500041242Ool00`00Oomoo`0KOol00`00Ool000090000
0`@Q0000000212401Q245:D@Q1241248@P<<H`08248<H`@Q36<HaQBU48@48@8@Q00>6<H@Q12436<4
8@Q20008@PaS248001240008@P848@L00003124000@Q00848@070008@PaS124DYBU:8@P01RDY00HY
BR488@PQ21S648@47>L021BU7>LHaR489BTHaR486<H28@P236<01a247>LHaQcW8@PU:B48008Li`03
9BTQ21cW00<Q20077>L48@@Q000Q21BU36<02@000goo00<007ooOol03Woo000?Ool00`00Oomoo`06
000312401P00248000001248@P8U:@04:DXe[BDY9BT27>L02ABU:DXLiaS65:DYBSW>CW<YBP0248@0
1`00;F/48@@Q5:D@Q1cW008HaP06<H`Q21S69BT@Q0@Q0P0000X48@000008@P00248000Q25:D@Q088
@P04:DXLia249BT5BU82CW<3BU82@Q001cW>:DXU:CW>?Nm242U:008e[@07>Li6<C6<?Nle[D8@;F/0
0QcW0SF]00/icSg_AS56<D8@=Je244YB;F]244YB008mk`04<H`@Q1241242:DX01Re[00048@@Q0004
8@@0009oo`03001oogoo01]oo`03001oo`0000T000051240000000048@0248@011BU6<H@Q1240PaS
00T8@QBU36<<H`Q25:DLibDY5:D00PQ200@001BU00000088@P<<H`056<H@Q0aS48@8@P0600001@@Q
00048@0012400PQ20P@Q00@DY@aS248@Q0XU:@8Q20037>LDYA24008Li`0;8@PDYAS66<HLib486<HL
iaS68@PDY@0236<26<H27>L38@P01QS68@PU:ABU8@PU:@8Li`046<H8@PQ200035:D90003Ool00`00
Oomoo`0>Ool000moo`03001oogoo00848@0:00048@@Q00048@001248@P@Q248312405PaS7>LYBRe[
=Jd]JbDY6<H@Q1BU7>LQ23g_@Q0YBSW>5:D48B48248DY@aS0QBU00L8@QBU8@P@Q1BU7>LHaP0248@0
0`@Q00048@0300003@@Q5:DQ22e[48@8@PaS6<H8@Re[7>LHaS6<009>L`0>BU96<DYBCW=:DTicDYA6
<D8@AS5242e[8@PU:@8icP04:DX]Jd8@?Nl2@Q001Be[@Q0mkbDY8@P00cg_00E244HaAS56<D8@008m
k`0=BU8YBSg_AS5:DT8@?Nl<HaBU000]JbU:=Jd00P@Q0`000`@Q00@007ooOol001eoo`03001oo`00
00P00003124000@Q00<00008124<HaBU5:DHaQBU48@<H`88@P0<36<@Q1cW8@PDYAcW248001241248
@P@Q0PQ200<48@Q248@00PQ20PaS0PQ21`0000@8@Q245:D8@P848@0336<48ABU008<H`056<HU:BDY
9BTQ20049BT00bU:8@PQ20028@P00aBU48@@Q0027>L25:D01b487>LQ22485:DQ21cW008@Q0<Li`DQ
208Li`0:9BTDYAcW8@PU:B487>L48@Q200025:D00aS6000000070003Ool00`00Oomoo`0>Ool000mo
o`06001oogoo0008@P000P@Q0P0000@48@002488@P<48@0S24848A249BTLibDY=Je242DY5:D@Q248
9BTicSg_48@]Jc6<5:D8@QBU248Q21247>L48ABU7>LQ21S636<@Q1S612400003124030Q2000<HaBU
:DXLibe[<Ha>La24?NlYBP8Li`05:DY:DTYBBU9>L`03BU8014ic@Q1244Ha0T8@00`]JbDY5:DQ23W>
;F]243F];F]243g_>Lh2=Jd01RDY=JdicSW>=Jdmk`=6<@0;@Q0]JdHaBU8aS4HaBU8mkdicBU8<H`02
48@012DY<H`]Ja2420000Woo00<007ooOol06goo00@007oo00048@L000848@<00009124000Q248@<
Ha246<HQ21240088@P8@Q08Li`0B248DYAS624848@Q2124@Q0Q236<000Q236<@Q0aS1248@PaS1@00
00`48@001248@QBU36<DYAS69BT8@QcW5:D236<00aBU9BTU:@069BT58@P02QBU48@8@Q247>LDYB48
6<HDYB480QcW0QS600H@Q1S67>LLiaS67>L48@P01aBU8@PU:AS68@PU:AcW008U:@071248@PQ248@H
aQBU248020000goo00<007ooOol03Woo000?Ool00`00Oomoo`0300001`@Q36<000@Q0008@P@Q0080
00061248@PaS124000@Q0R4800@U:CF];F/U:@8HaP0936<HaQcW9BT<HaBU9BT]JbDY008HaP0L:DX<
H`@Q48@Q23F]48@8@Q246<HDY@00124000Q248@48@Q2;F]F]C6<:DXQ22U:124]Jb487>L26<H01dic
BU9:DU:DBU9>LdHa00924096<@05BU96<Be[8@PLi`026<H01cW>;F]242U:@Q0mkcF]008aS00A;F/m
kcW>>LhmkdYB@Q0icSF]<H`mkdYB@Q0YBSg_AS524002AS401bU:48@@Q124<H`]JaBU00@000041248
@P@Q0002Ool00`00Oomoo`0KOol00`00Ool0000300001@@Q00000000124010000P@Q0`000a2400<H
aQBU48@00PaS00T48@aS36<@Q0@Q248@Q1BU48@00PaS00/DY@@Q0008@Q246<H8@P@Q248<H`Q200<0
000=1248@P00124DYBU:6<HDYA245:D001BU48@00`aS0bDY00<YBRDY9BT01B4800@U:B485:D@Q0<<
H`067>LDYB485:DQ21cW0aS600<DYAcW7>L00QcW00<U:B487>L00QS600DLibDY8@PDYAcW00@Q2007
5:D8@PQ2248HaQBU24801@0000<48@0000000goo00<007ooOol03Woo000?Ool00`00Oomoo`020002
12422482124010Q212448@@Q0PQ20`@Q00X8@PaS8@PQ21S68@PaS1BU7>LQ208DY@07124DYAS6248]
JaBU6<H00Q2400@<H`005:DDY@848@04248<H`@Q5:D2124010aS12448@Q20S6<0R4800X]JcW>6<HD
YBe[5:D@Q1BU7>M:DP9BU0=:DP06@Q16<DHa@Q16<DYB0Sg_01A:DR487>LHaRe[AS4mkbe[@Q0e[C6<
;F/e[Be[>Lhe[CW>@Q16<CW>0S6<00hmkdYBAS4mkbDY=Je244YB?Nm:DRe[36<8@QBU0Re[00THaP@Q
124000@Q248000Q212400Woo00<007ooOol06goo00<007oo00000`000P@Q0P0000@48@0000000084
8@<000848@8@Q00636<@Q1S6248<Ha240PQ200L000Q236<48ABU248<H`02248010@Q0008@PQ20P00
0P@Q00D000Q2000000@Q00800003124HaQS6008@Q0055:DLi`aS248DY@03248010aS9BTYBRU:0bDY
1B4800DU:AcW7>LU:A24008<H`055:DQ21cW5:DQ20026<H01QBU6<HDYAcW6<HLi`8Q200>7>LHaQS6
7>LU:B487>L@Q1S68@PU:AcW9BTDY@848@04248DYABU36<4000010@Q00048@000goo00<007ooOol0
3Woo000?Ool02P00Oomoo`@Q248000Q2124000@Q0PQ210@Q00<8@PaS00000P@Q00@000aS5:D@Q08H
aP097>L<HaBU9BT@Q0aS1248@Q24008HaP0524848@aS5:D48@0324801`@Q36<8@PaS248000@Q00<0
00037>LQ21BU008HaP068@PaS248>LhHaQ240QS600DLicW>8@P]JdHa00924003AS5244Ha00924096
<@03@Q1:DSg_00<Li`9240039BTicRe[008Q2004;F/aS3g_?Nl2AS402dYBAS4mkcg_AS4mkcF]?Nl]
Jcg_BU800T8@00=BU2e[36<00PQ200A6<C6<5:D000848@0300048@0000848@9oo`03001oogoo01]o
o`06001oo`00124000@Q0`000P@Q10000P@Q100000<48@Q224800`aS00P48@Q248@8@P@Q00048@Q2
0PaS00D48@001248@P0000<48@0300048@@Q00848@D0000336<@Q0Q2008<H`0648@HaQ247>L<H`Q2
0`aS00<Lia245:D02b4800<U:AcW36<00PaS0R4800<@Q1cW5:D00Q2400@DYAS67>LLi`8Q200;9BTQ
21cW7>LQ21cW6<HLiaBU7>LU:@028@P00bU:5:D48@0212400b486<H8@P080003Ool00`00Oomoo`0>
Ool000moo`03001oogoo00848@0300048@00008000051240000000048@03000040@Q00048@00124@
Q0@Q000@Q0Q25:D8@QcW8@P<H`@Q0PQ200DQ20aS48@@Q0aS0080000;48@HaQS6248@Q0@Q6<H48@00
1248@P02000212425:D26<H00acW8@PQ20026<H27>L2@Q002248?Nm6<Cg_AS5>LdYBAS42@Q0024Ha
?Nm:DTic8@PLib487>L248@01aS6;F/YBSF]<H`icS6<008mk`05AS5244Ha@Q0icP05?Nl03d8@CW=6
<DHa?Nm:DSF]5:D8@P@Q?NlYBQ2412400002124200001@@Q001oogoo00007Goo00<007oo00004`00
00/8@P000008@P@Q24848@aS48@48@0000848@0548@48@Q224848@0200001`Q236<<H`@Q248000aS
00<000031240000000800088@P<<H`8@Q0@<H`8Q200548@Lib487>LQ20029BT48@P01acW9BTU:A24
36<@Q0aS0088@P0336<DYABU008HaP047>LHaQcW7>L48@P67>L03B489BTQ22487>LU:AS624848@00
7>LDY@Q200P000=oo`03001oogoo00ioo`003goo00<007ooOol01@0000<48@0000001@000P@Q00L0
00@Q000000@Q36<00002248010@Q48@<HaBU0R4800LHaQBU48@8@PaS5:D0000236<02Q245:D<H`Q2
36<48ABU36<48@aS0`0000/8@QS69BT]Je:DE[E>LcW>;F/YBQS6008Li`8HaP055:DU:C6<=Je24002
BU802dHaBU96<DHa?NlicTYBCW<DYAS68@P00QBU00PQ22U:<H`mkd8@AS5>LdYB0THa00HmkcW>=Jda
S3F]@Q02?Nl00dicBU9:DP02CW<02THaCW=F]Dic248@Q0@Q?NlaS1241P@Q0P000Woo00<007ooOol0
6goo00<007oo00004`0000P48@0012448@0024848@Q20Q2400<<H`Q224800P@Q00@8@P0012448@88
@P<48@050008@P@Q00048@03000010@Q36<@Q1BU0RU:00@U:AcW5:DDY@D<H`05248@Q1S66<HQ2002
9BT012489BTQ22480QcW0RDY00<8@PaS48@00PQ200@@Q1BU6<HLi`8Q208U:@8Q208Li`<HaP038@PL
iacW00DU:@0:8@PU:BU:9BT48@Q2000LiaS624880003Ool00`00Oomoo`0>Ool000moo`03001oogoo
00<000<48@0300048@@Q00D48@030008@P0000<0000824848@Q2000@Q1BU7>LDY@<Li`09000@Q0@Q
0008@QcW5:D8@P@Q0088@P0N1248@PaS1248@QBU:DXaS4ic8@PHaRDY:DXicSF]<H`e[CW>@Q1:DUkg
@Q0YBRDY7>Le[D8@>Li244ic15:D00I>LdHa=Je6<Dic>Lh35:D07AcW36<@Q2e[<H`mkcW>?Nm6<DYB
AS5242e[<H`Q22U:@Q16<Be[=Je244Ha?Nm:DTHaCW=:DTicAS400`@Q0SF]00D<H`@Q000000@Q00@0
009oo`03001oogoo01]oo`03001oo`0000h000031240000000800004124000@Q000224800`aS248<
H`0236<02@0024800000124<H`Q21240000212403P0012448@001248@QBU6<HU:A2436<@Q1BU7>L3
6<H03AcW8@PU:Be[8@PDYA2436<HaR487>LQ22DY00@YBP069BTQ21S68@PU:AcW0`Q200D<H`@Q248D
YAS600<Li`088@PU:B488@PDYAS648@DY@8Q20075:DHaR488@PLibDY8@P00bDY00@Q20000000008H
aP031240000000H000=oo`03001oogoo00ioo`003goo00<007ooOol01P0000<48@Q200000`@Q00D8
@P@Q00048@0000848@80000C248<Ha2448@YBR48248DY@@Q36<@Q0@Q48@<H`@Q248<H`Q236<00Q24
01<Lia2436<@Q3g_AS4aS3W>F]IF]DHa@Q0mkdHa@Q0mkd8@8@P@Q0029BT00dicAS4icP03AS401Dic
BU9>Le:DCW<00dYB00E243g_CW=241S6008DY@0748@DYB48:DXe[C6<=Jd00S6<00HicSg_=Jdmkd8@
AS42@Q02AS401BU:=Jde[DHaBU800T8@0THa00U:DSW>48@48@00=JdaS0Q212400`0000@48@001244
8@9oo`03001oogoo01]oo`03001oo`0000H0000312400000008000031240000000H000848@88@P0;
5:D@Q0@Q248000@Q248000Q212400004124224802PaS24848@Q27>LQ21S67>L]JbU:0R4800LLib48
8@PLib4848@8@P0248@00bDY8@PLi`038@P39BT00bU:9BTU:@029BT01B487>LU:B4836<010Q200<@
Q1BU6<H011S60QcW00<HaQcW8@P01B4800DDYAS66<HQ22DY00@Q20039BTLi`Q20080008HaP031240
000000H000=oo`03001oogoo00ioo`003goo00<007ooOol00P0000@48@0012448@/000848@0;0004
8ABU:DXmkcW>5:D<HaBU48@<H`028@P010@Q00048@aS0QBU00LHaPQ2248]Je:DCW<YBP02=Jd2AS40
14YBDYAF]Dic0T8@00TmkdYBAS4icQcW8@PU:B48?Nl00T8@00A6<CW>BU96<@9:DP04CW=:DTYBBU82
AS4013g_;F/Q21240QS600HLiaS6:DX]JcF]>Lh2?Nl0348@?Nm244icDYA6<Cg_BU9BU4Ha?Nm6<@8m
k`96<@06?Nm:DTHa@Q0mkaBU0PQ200@48D8@<H`48@D000848@04001oogoo000MOol00`00Ool0000D
00001PQ25:DLiacW24848@88@P03124@Q12400<000041248@PQ236<2124011BU:DXU:ABU0QS60R48
00@U:BU::DXU:@8Q20057>LU:B487>L<H`0348@01acW8@PQ22487>LU:B4800HU:@8Q20047>LDYA24
248436<25:D041S67>LLiacW8@PLib489BTYBR487>LU:BU:8@PLib480QcW0R4800HLibDY8@PQ21cW
248212400`008@PHaP090003Ool00`00Oomoo`0>Ool000moo`03001oogoo00<48@0300048@@Q00/0
000@248000@Q000YBQBUCW<]Ja2436<8@PaS248<HaBU6<H27>L03@Q2124<HacW<Ha:DTHa>Li243g_
=Jd]JcF]008mk`0?>Li244HaAS4mkcW>@Q16<Cg_<H`@Q2DY?Nm243g_00A6<@07@Q1>LdYBDYA>LdHa
@Q000SF]00PU:B489BTaS248:DX]JbDY0cg_0THa0SW>13g_0S6<00=245:DBU800dic0T8@00HmkcW>
?Nm243W>;F/224802@@Q48A243W>36<48@001240000212420002Ool00`00Oomoo`0KOol00`00Ool0
000@00002@@Q000000005:D8@RDY5:D8@P0512404@Q236<<H`aS124000@Q36<HaRDY8@PLib487>LH
aQBU6<H00acW0b480QcW0R4800LLiaS6248@Q1cW8@PLi`058@P29BT012U:9BTQ22480QS60a2400DH
aQ245:DDYA2400<Li`8Q20HLi`8HaP038@PYBRDY00<U:@8Q20<Li`038@PLiaBU00848@050008@R48
7>L48@080003Ool00`00Oomoo`0>Ool000moo`03001oogoo00D00003124000@Q00T000848@0:0008
@R48?Nle[ABU48@0012436<22482124030Q236<<HcF]AS5:DV<HCW=:DTHa>Lh]J`@mk`924003AS5:
DT8@00924006>Li243g_<H`e[Cg_0TYB00<mkdHaAS400TYB01<mkdHaAS5243g_>Lhmkc6<>LhU:AS6
7>LHaTYBDYA>LcF]?Nm24003BU80148@?NlmkcF]0SW>00@mkcF]@Q1>L`9:DP9>L`0?AS5243W>>Lhm
kd8@<H`YBP00124001cW?Nle[@aS00848@<0000312400000009oo`03001oogoo01]oo`03001oo`00
01<00004124@Q1cW6<H224800`0024848@0212420003124011S68@PU:C6<0RDY00<Q21cW5:D011cW
0b4800LU:B488@PQ21cW8@PLi`026<H011cW9BTU:AcW0R480RDY00@Lib488@PQ20<Li`036<HLia24
00<<H`069BTYBRDY6<HLib480bDY00@Q21cW7>LHaP<Li`036<HQ22DY00@U:@8Q20<Li`038@PHaQBU
00<0000436<LiaS612480003Ool00`00Oomoo`0>Ool000moo`03001oogoo014000<48@045:DQ248@
>Lh300002@@Q2488@P00248000aS8@Q:DP02AS42E[D00dicBU8mk`05AS400d8@?Nlmk`03@Q001THa
BU9243g_>Lhmk`924096<@03@Q1:DTHa00924003?Nm:DT8@0096<@0>@Q0mkcW>?NlHaQcW5:EBU4Ha
BU9>LdHa@Q1>L`96<@9:DP04@Q0mkcW>?Nl2@Q005SF]>Li244Ha@Q1>LdYB>Lhe[CW>=JdicSF]9BTL
i`@Q36<8@QcW>Lhmk`@Q0P0000<48@0000000`000Woo00<007ooOol06goo00<007oo00004`0000@8
@Q248@PLi`@000848@0600048@00124@Q2DY0R480RU:0RDY00<Lib488@P012480QcW124800<U:B48
7>L00QcW1B4800HU:B488@PQ21cW9BT48@P37>L236<00`Q2:DXQ20029BT28@P00bDY8@PQ20029BT0
12487>LLiacW0R4800<HaQcW8@P00R480RDY00TLiaS67>LHaQcW6<H@Q0aS00000P@Q00<<HacW7>L0
2@000goo00<007ooOol03Woo000?Ool00`00Oomoo`0D00001bU:<Ha:DQS600048@aS00848@0>0004
8@Q248@e[EJeBU9243g_@Q1BU5Je@Q16<@9>L`08AS52448@?NlicSg_@Q16<@=:DP03AS4mkcW>00<m
k`03@Q1BU4YB00=6<@924004AS4mkd8@@Q04?Nl27>L00bDYDYA:DP02CW<01TYB@Q1:DT8@>Lhmk`9:
DP96<@0=CW=BU4Ha?NlaS4YBAS4mkd8@BU8mkc6<=Jd00cW>00<]J`aS36<00P@Q00<YBSF]=Jd010@Q
1@000Woo00<007ooOol06goo00<007oo00004`0000@DYAS69BT<H`80000312400000008000081248
@QS6:DXU:B487>LQ208YBP8Q208U:@<Q20<Li`8Q20<U:@038@PLiacW00<Li`038@PYBRDY00HQ2003
7>LQ224800@Li`8<H`0348@YBRDY00<U:@038@PU:B48008Li`8U:@8Q200;9BTYBR487>LHaRDY8@PL
ib489BTLi`026<H37>L00aBU12448@0200000aBU6<HHaP090003Ool00`00Oomoo`0>Ool000moo`03
001oogoo00<000031240000000H00003124000000080000712400000>Lhe[Cg_36<00P@Q010000@Q
000000Q26<I:DTicDYA6<DYBAS5>LdYBAS52409>L`05BU8mkcW>>Lhmk`04AS42BU82CW<014Ha@Q12
43g_0T8@1THa00=244Ha@Q001D8@00@e[BDY6<HLi`9>L`07BU9>LdicAS5>Ld8@<H`00SF]0dHa00m:
DU:DDY@mkcF]?Nle[C6<?Nm6<Cg_;F/e[CW>@Q000SW>00T000Q2000<HbU:;F/YBP@Q00000P@Q00<0
00@Q00000P000Woo00<007ooOol06goo00<007oo00004`0000@LiaS67>L48@H00008124<HbDY9BTY
BR489BTQ208U:@8Q20<U:@@Li`@Q20@U:@<Q20037>LQ224800hQ20046<H@Q0aS36<59BT00b489BTQ
20036<H38@P01RDY:DXYBQcW6<HLi`8HaP077>LQ21cW5:DHaQcW8@P00QcW00@000@Q00048@<DY@T0
00=oo`03001oogoo00ioo`003goo00<007ooOol0500000<icSF]=Jd01P0000/48@Q28@Q245kgHaQJ
eUJeCW=:DTic009BU003BU8mkcW>008icP03AS5:DTHa00924004BU9>Le:DCW<2AS400cg_<H`U:@02
9BT01cF]@Q0icTHaBU96<D8@0096<@E2400=<H`U:AS6;F]244icDYA>LdYBAS5>LdYB?Nl00SF]00/i
cSF]=JdicT8@DYA:DSW>:DXicSF]00@icP0==JdicT8@?Nle[@@Q24848AS6;F/e[AS612400P0000<4
8@0000000`000Woo00<007ooOol06goo00<007oo00004`0000<LiaS66<H01`0000L48A248@P]Jc6<
;F/YBP039BT2:DX00bDY7>LLi`027>L00b489BTQ20028@P29BT01RU:9BTQ22487>LHaP<@Q0056<HQ
21cW8@PU:@098@P01aS648@<HaBU8@PU:BU:008U:@048@PU:BDY7>L26<H02acW6<HHaQcW8@PYBRDY
7>LDYAcW6<H011cW00`HaQcW8@PLiaS600048@0036<DYAS636<90003Ool00`00Oomoo`0>Ool000mo
o`03001oogoo018000848@03<H`YBSF]0088@P800007124000@Q;F]244YBE[D015[F00A>LdYBAS4m
k`<icP06?Nm6<DYB@Q0mkdHa15:D00I:DT8@?NlicRU:9BT37>L012DY;F/e[DHa0T8@0dHa00A244Ha
@Q0e[@8aS003@Q16<DHa009BU004E[DmkdHaCW<2BU8013W>:DXaS3W>0cF]0THa00LaS3F]?NlicSF]
>Lh]J`02<H`02cW>?Nle[AcW124<H`@Q7>L]JcF]36<010@Q1@000Woo00<007ooOol06goo00<007oo
00004`0000<HaQBU6<H00P@Q1@0000@DYB489BTYBP@]J`8U:@038@PLiacW00<Li`058@PU:B487>LQ
2004:DX01RDY8@PLiacW5:D@Q0<<H`0348@DYAS600TQ20<HaP<Q20<YBP037>LQ22DY008U:@047>LD
YAS67>L36<H28@P26<H27>L00aS67>LDY@026<H27>L02AS636<000@Q000<HaBU6<H48@090003Ool0
0`00Oomoo`0>Ool000moo`03001oogoo00d000031240000000800007124001BU<H`]JaS612400`00
0P@Q00ABU4HaBU9:DP=BU003AS4mkc6<00@e[@05?Nm:DTHa@Q0mk`03CW<2E[D015:DAS4e[BU:0Re[
00LYBR487>LDYAS68@PU:@02@Q000cg_AS56<@04@Q001Sg_CW<icS6<>Li:DP9F]@0=BU8mkdYBBU96
<CF]>Lhe[D8@AS5243g_=Jd00THa0cg_00HicRU:<H`aS248:DX2=Jd00be[1248@P0212400acW=Jda
S00312470002Ool00`00Oomoo`0KOol00`00Ool0000C000010Q26<HDY@aS1P0000@YBR489BTU:@<Y
BP038@PLiaS600@HaP057>LU:B488@PLi`039BT3:DX00b486<HDY@035:D0112436<8@PaS0Q240R48
00<Lib488@P0124800HLibDY7>LHaQcW9BT2:DX022DY7>LU:BDY8@PHaQcW6<H38@P011cW6<HQ2248
11cW00DDYAS66<H@Q1BU008HaP035:D000@Q0080000336<HaQS600X000=oo`03001oogoo00ioo`00
3goo00<007ooOol0500000D48CW>9BTU:@@Q00<000848@04>Li244HaBU82CW<00d8@=JdaS002=Jd2
?Nl054HaCW=6<D8@>Li244icDYAJeUkgE[E242e[7>LYBS6<;F/YBRDY7>L26<H011BU7>Le[CF]0T8@
00A6<D8@AS4mk`8icP059BTQ22DY>Li>L`02E[D01dHaBU9>Ldic>Lh]JcF]00924004?Nm>LdHaAS43
BU8054Ha?Nle[BU:>Lhmkd8@?NlLic6<=Jd000aS248<HacW>LhaS0@Q000212400`0012448@030002
Ool00`00Oomoo`0KOol00`00Ool0000D00000acW48@@Q00600000acW8@PQ20039BT00b486<HHaP02
6<H27>L022489BTQ22487>LQ22DY:DX2;F/01RU:8@PDY@aS5:DHaP8DY@0648@<H`aS36<8@PaS0QS6
1B480acW0a2400DLibDY:DXYBR4800<U:@037>LDYAS6008Q20047>LU:B488@P39BT012487>LHaQBU
0QcW00<Q21cW36<00QS600L000@Q12448@aS7>LHaP0:0003Ool00`00Oomoo`0>Ool000moo`03001o
ogoo01@00005124U:Cg_>LhDY@03000010@Q000Lic6<0SF]0TYB00Y242DY<H`mkdHaBU9BU5JeBU92
408icP9>L`07DYAJeU[FDY@]Ja246<H00RDY0RU:00TQ21cW8@PHaQ246<HQ22e[?Nl00d8@0SW>00Xe
[Be[8@PLic6<CW=BU5[FBU9240=>L`04>Lhe[Cg_BU82=Jd2BU802T8@?NlicSW>=Jd]JcW>?Nm:DTic
0THa00dicR488@P48@00124DYBe[=JdLi`@Q00048@0200000`@Q000000020002Ool00`00Oomoo`0K
Ool00`00Ool0000D000011247>LLi`Q21@0000@<HaS66<HHaP8U:@068@P@Q1S67>LQ22DY0RU:00@U
:B487>LLi`8U:@07:DX]Jbe[:DXDY@Q236<00Q240QBU00T@Q0aS48@<H`Q236<@Q1BU7>L00b480QcW
00XHaQBU48@<HaS69BTYBRe[9BTQ20<U:@047>LHaQcW9BT26<H29BT01R487>LLiacW6<HDY@8Li`8U
:@8Q20037>L@Q12400<00004248DYAS636<:0003Ool00`00Oomoo`0>Ool000moo`03001oogoo01@0
0006124<Hd8@8@Pe[@Q20`@Q00X002DY?Nm6<DicE[E:DSF];F/icP96<@04>Lhe[E:DAS42>Lh02TYB
CW=>Le:DE[EJeTYB:DX@Q1BU0QcW0b480QcW00LHaQBU48@DYAS65:DQ2002AS402cg_:DX@Q1245:De
[DHaDYAF]DHa@Q000dYB00M6<CW><H`icTHa=JdicP02AS400cg_>LhicP02=Jd03Cg_AS5>LdHa@Q16
<D8@>Lh]JaBU1248@P@Q008YBP03>Lh<H`0000T0009oo`03001oogoo01]oo`03001oo`0001@00005
124Q21246<H48@0400002A247>LQ22DY:DXU:AS65:DLi`028@P011cW6<HYBR480QcW0bDY0RU:00<]
JbDY5:D00PQ20PaS0a240`aS0`Q200<<H`Q248@00R4800<LiaBU24800PQ200@HaR48:DXYBP8Q20<U
:@078@PLiaS67>LQ21S67>L00R480acW0QS600<Lib489BT0124800HLiaBU248000@Q00025:D00acW
124000090003Ool00`00Oomoo`0>Ool000moo`03001oogoo00P000031240000000/000059BUBU2U:
5:D8@P0300001S6<@Q1>LdicBU92408e[@09AS5BU3W>;F/icT8@?NlicSg_009>L`07DYAF]EJeF]IB
U3F]6<H00aBU00DHaQcW7>LLiaS600<DY@0348@<Ha24008DY@0936<DYAS66<HDYC6<BU9F]E:D0092
400:BU9>LdYBAS4mkcF]<H`mkdHa=Jd2>Lh013g_=Jde[CW>0THa00=BU48@>Lh00RU:00H]Jc6<9BTL
i`aS00025:D011cW@Q0e[@@Q2P000Woo00<007ooOol06goo00<007oo00005@0000D@Q2U:5:D8@P@Q
00<000036<HQ22DY008U:@098@PHaQS68@PYBQcW5:DLib4800<Li`8U:@<YBP04;F/YBQS636<32485
36<424801P@Q2488@PQ21248@P8<H`03248HaRDY008YBP8Q20<U:@078@PLiaS66<HLib486<H00acW
0QS600HLib488@PYBR487>L35:D01AS648@<H`@Q00000PQ200<<Hb486<H02`000goo00<007ooOol0
3Woo000?Ool00`00Oomoo`0C0003124010aS>LhYBSF]0P@Q00@000aS@Q16<@9:DP9>L`0H;F/icUJe
AS4aS3F]?Nm243W>@Q1>LdYBDYA>Le:DE[EBU5[FE[E6<C6<5:D@Q1BU11S60QBU1Q2400XDYAS66<HU
:CW>AS5F]DYB>Lhmk`9>L`0:BU96<D8@=Jd]Jc6<?Nm:DSW><H`3:DX01bDY=JdmkdHaDYA:DSF]008a
S0037>LQ21S600848@060008@Re[8@PaS2DY0P@Q1@0000@48@000000009oo`03001oogoo01]oo`03
001oo`0001D00004124LiaBU6<H300000`@Q8@PQ20049BT011BU7>LYBR480QS600@Lib487>LQ208U
:@03:DXU:BU:008YBP04;F/YBR486<H3248436<9248236<01A247>LQ22U:9BT00QcW0bDY0R4800LH
aQBU6<HLibDY7>LHaP035:D01Q246<HLib48:DXU:@<HaP0336<@Q0aS00<00005124DYA246<H@Q00;
0003Ool00`00Oomoo`0>Ool000moo`03001oogoo01H0000:124aS4ic5:D8@P001248@T8@AS42E[D0
3E:DCW<e[D8@DY@mkaS6=Je244Ha@Q1>Le:D00=>L`0:BU9BU5:DDYAF]E[FE[E6<CF]6<H248@00aBU
48@DY@0548@02aBU6<HDYBDY>Li6<DicDYA:DSg_BU8014ic0TYB00TmkcW><H`icTicBU9243W><H`0
0SF]00DaS2e[=JdmkdYB0096<@0<@Q0icRDY6<H000@Q000<HacWBU8mk`@Q2`000Woo00<007ooOol0
6goo00<007oo00005P0000@HaRDY24848@800003124Q224800<YBP079BTHaR48:DXLi`aS6<H00b48
00<U:BU:9BT00bDY12U:00D]JbU:8@PHaPaS00/8@P0936<8@Q247>LQ22DY:DXU:AcW00LU:@8Li`06
6<HLibDY9BTQ21cW11S600@DYAS67>LU:@<Q20037>L@Q0aS00<00004124<HbDY7>L<0003Ool00`00
Oomoo`0>Ool000moo`03001oogoo01H0000?1248@THa<H`icPQ20008@UJeBU8mkd8@CW=BU48@009:
DP05=JdLicW>AS4mk`02>Lh00d8@CW=BU003CW<015:DE[EBU5:D0U[F00QF]DicBU8aS2DY6<H@Q0aS
0Q240QBU00<U:C6<@Q000dic00=:DTHa@Q000dic00A:DTHaAS56<@8mk`04=JdYBSW>=Jd2CW<043g_
>LhicSW>?Nm243g_<H`mkd8@AS4mkcF]:DX8@P000P@Q00D]JaBU=Jde[@@Q00/0009oo`03001oogoo
01]oo`03001oo`0001H0000>124Q21S67>L48@00124YBRDY7>LQ22DY:DXQ208U:@046<H<HacW8@P3
7>L00b489BTYBP039BT4:DX2;F/022U:9BTU:AS648@<H`Q2124424800a246<HQ20049BT28@P49BT3
8@P27>L011S65:DLiaS60RDY1AcW00@Q21cW6<HLi`8Q20047>LHaQBU1243000011BU248HaQS63000
0goo00<007ooOol03Woo000?Ool01000Oomoo`@Q5`0000=2436<9BT00PQ200d48AS6>LhicRDYAS5J
eUJeDYA>Lcg_5:D]J`02<H`2=Jd02CW>CW=BU5:DCW=F]DicBU96<@02CW<00e:DE[EF]@02G_L00e[F
DYA>L`03@Q02AS4014icDYABU4ic0THa00=244HaCW<00Tic00E:DTicAS5:DSg_00<e[@04>Lh]Jc6<
@Q03AS43;F/00cW>BU924002>Lh013g_;F/Q22e[0P000P@Q00DLidHa@Q0DY@@Q00@0000312400000
00@0009oo`03001oogoo01]oo`03001oo`0001L000038@PHaQ2400848@07000<HacW7>L@Q248;F/0
0RU:00@U:AcW248DY@@HaP067>LU:BU::DXU:BU:0RDY00<Q22DY9BT00bU:0be[00<YBRDY8@P01248
00@U:BU::DXU:@@Q20DU:@038@PU:AcW00<HaP037>LDYAS600@Q20<DY@037>LU:B4800<Li`035:D@
Q1BU00@0000436<Q2248248<0003Ool00`00Oomoo`0>Ool000moo`03001oogoo01L0000>124Lid8@
>LhHaPaS5:D48AcW;F]244HaE[EJeP9BU005?NlaS3W>>Li24002=Jd01Sg_BU8mkcg_BU9BU09>L`9:
DP04DYA6<DYBBU82CW<00e:DF]IF]@05E[D01E:DCW=:DSg_@Q000TYB0dic00A:DT8@@Q1:DP96<@07
?Nm:DSg_@Q0e[BDY<H`00dHa00U243F]7>L]JcF]AS4icRe[:DX00SF]00T@Q0@Q000000aS7>Le[Be[
124030000Woo00<007ooOol06goo00<007oo00005`0000T<Hb487>L<H`@Q248000aS5:D00R4800HY
BRe[:DXYBQcW6<H27>L01B486<HHaQcW9BT00QcW00<U:BU:9BT00bDY00<YBR489BT00bDY00<YBRe[
:DX01RU:0RDY00<Lib489BT01BDY0R4800XU:B488@PLibDY7>LQ21S648@HaP@Q20066<H<HaBU6<HQ
21cW0QBU0QS600P8@P00000000@Q36<HaQBU3@000goo00<007ooOol03Woo000?Ool00`00Oomoo`0H
00003@@QBU8mkb48124<H`Q26<I6<DicF]I>LdYB009>L`0==JdicTHaCW=2436<=Je6<CW><H`e[CW>
@Q000TYB00A>Le:DDYA:DPA>L`A:DP03CW=:DTYB00=6<@=:DP03CW=:DTYB0096<@03>LhaS3W>0092
400:BU92448@AS5BU3g_;F/aS3W>@Q02CW<0148@?NlU:BU:0cg_00]243g_7>L48@001248@R48AS4a
S1S600d0009oo`03001oogoo01]oo`03001oo`0001P000049BTLia240002124010aS8@PU:Be[12DY
00DHaQcW8@PU:B48008HaP068@PLiaS66<HLib480bDY0RU:32DY0b481RDY0R4800<LiaS67>L00R48
00XU:B488@PQ22U:7>LDYAS67>LQ208U:@048@PLia245:D37>L00b487>L<H`0300001@@Q48@Q21S6
36<03@000goo00<007ooOol03Woo000?Ool00`00Oomoo`0H00001@@Q:DXmkbe[36<00P@Q014DYCg_
AS5:DSg_CW=BU4ic@Q0mkdYBCW<mkbDY<H`icRe[00<e[@04>Lhe[Cg_AS42DY@00dicBU9>L`02DY@6
CW<3BU85CW<2BU83>Lh2;F/06C6<>LhmkdYB@Q0mkdYB@Q0icSg_>Li6<EJeCW=6<CW><H`YBSW>AS52
43g_>LhDY@@Q0088@P0536<U:CW>=Jd8@P0=0002Ool00`00Oomoo`0KOol00`00Ool0000H000011BU
7>LDY@@Q0P0000X8@QcW8@PU:AcW9BTYBRDY8@PLi`8U:@057>L@Q1S67>LDY@036<H011cW6<HLib48
0RU:0bDY0RU:42DY0acW0QBU00PHaQcW7>LU:B487>LU:B480acW00PQ22U:9BTQ21cW6<HDYAcW0R48
0QcW00<8@P0012400P@Q00@@Q1cW6<H48@d000=oo`03001oogoo00ioo`003goo00<007ooOol06000
00X48@aSBU8e[AS68@P@Q0@Q:DXmk`8e[@05BU9F]EJeCW=6<@02BU803d8@?NlYBRU:=JdmkcW>;F/a
S2e[<H`icTicBU8mk`02=Jd00cW>?Nm:DP03CW<00dYBDYA>L`03CW<03dYBCW=>LdHa@Q0mkcF]9BTa
S3F]>Lhe[AcW=Je24002?Nl01THa@Q1244Ha@Q0e[@924003AS4mkcF]008e[@04AS5243g_9BT21240
1P00124U:CW><H`U:@D000031240000000H0009oo`03001oogoo01]oo`03001oo`0001P00009124U
:AS636<@Q0Q2000DYAcW008HaP059BTYBRU:9BTQ20029BT01B487>LDYABU6<H00QcW00DDYAS65:DH
aQcW008U:@037>LHaQS6008Li`DU:@03:DXU:BDY00DU:@8Q20037>LHaQ24008HaP057>LHaPaS6<HQ
20027>L58@P01AS68@PQ22487>L00aS60R4800<Lia2400000`0000@@Q1cW6<H@Q0h000=oo`03001o
ogoo00ioo`003goo00<007ooOol060000P@Q00HmkdYB<H`Lib4812429BT01Re[:DY:DTicE[EBU0=>
L`0<DYA6<CW>=Je244Ha>LhaS3F]<H`e[CW>0Sg_00De[C6<=Jde[Be[008e[@04AS5:DTYBCW<2BU80
1THa@Q0mkd8@BU8mk`8e[@03:DXmkcg_00=2400F>LhaS3F]=JdicS6<>Li244YB=Jd]JcW>?Nm243F]
<H`e[C6<@Q0mkbe[248212400`0036<HaP02@Q000aBU0000000<0002Ool00`00Oomoo`0KOol00`00
Ool0000I00001QcW9BTHaPaS48@0008@Q08DY@8U:@8YBP<U:@04:DXQ21cW6<H28@P00acW6<HHaP02
6<H37>L46<H011BU6<HHaR481BDY0R4800@Lib489BTLi`8HaP035:DLiacW00<Q200;7>LHaQS66<HL
iaS67>LQ22DY6<HDY@027>L00b486<HHaP026<H012487>LDY@@Q0`0000D48@aS8@PQ20Q200h000=o
o`03001oogoo00ioo`003goo00<007ooOol06@0000`48@aSBU8YBQS648@8@P00<H`Q21S6@Q02BU80
45:DBU9BU5:DCW=:DU:DCW=:DTHa?Nm243g_<H`YBS6<0SF]00LYBSF]?NlicSF]<H`]J`04=Jd01T8@
AS4e[C6<=JdaS0924005=JdaS36<=Je6<@02@Q0014YB>Lh]Jbe[0c6<00<YBSF]=Jd00RDY0cW>13F]
00=243g_9BT00P@Q00L<H`Q2;F/HaSW>?Nl8@P0>0002Ool00`00Oomoo`0KOol00`00Ool0000I0000
2`@Q9BTDY@aS24848@006<H@Q0aS8@P00RDY00@YBRDY:DXYBP8U:@09:DXU:BDY8@PLib487>LHaQBU
00<HaP045:DHaQcW7>L26<H00aBU6<HHaP026<H28@P46<H28@P46<H38@P012DY7>LDYABU0aS600<D
YAS66<H00Q240acW11S600<Q21cW48@00P000P@Q00DDY@aS7>LLi`@Q00h000=oo`03001oogoo00io
o`003goo00<007ooOol0100000<48@0000004@0000H48@00124icTYB<H`248@03@006<HQ21cW>Li6
<Cg_@Q1:DTHaBU9BU4ic00=:DP0;CW=:DTYB@Q0aS3F]?NlicS6<=Je24002AS401D8@>Lh]JbU:;F/0
0RU:01he[Cg_<H`e[Cg_;F/icTHa=JdLicW>BU9243W>?Nm6<DYB>LhaS1S67>LQ22U:7>LHaQcW<Ha2
44Ha?Nl2>Lh01cF];F/aS2485:D48@aS0088@P056<I>LcF]8@P48@0>0002Ool00`00Oomoo`0KOol0
0`00Ool0000J00000acW9BTHaP022480300036<@Q0aS7>LQ21cW8@PU:B489BTYBPLU:@038@PHaQS6
008Li`8HaP@Q20037>LDYABU00<DY@0=6<HLiaS66<HLiaBU7>LQ21S636<LibDY8@P00QcW00@Q22DY
7>LHaP8<H`0348@DY@aS008<H`036<HQ224800<Li`066<HDYAS648@8@P000`@Q00@<HbDY6<H@Q0l0
00=oo`03001oogoo00ioo`003goo00@007ooOol48AX0000>249>Lc6<=Jd@Q0@Q36<U:AS6:DX]JcF]
@Q1BU0=:DP0:CW=:DTHaAS5>Le:DCW<mkc6<?Nl2AS42?Nl06TYBCW=:DTYB?Nle[C6<=JdU:BU:<H`i
cS6<>Li6<CW>;F/e[Be[<H`mkdHa@Q0mkc6<>Lh2AS4013g_>Lhe[CF]0SW>00<HaRDY>Lh00THa011:
DTHaAS4e[BU:8@Pe[@aS1248@P@Q5:DQ248@=Jd8@Pl0009oo`03001oogoo01]oo`03001oo`0001X0
0009124U:AS66<H8@P00124@Q0aS008DY@036<HQ22U:00DU:@8Q20069BTYBRDY7>LHaQcW0R480QcW
12DY014LiaS66<HHaQ245:DHaQcW6<HLib487>LDYAS65:DHaQcW008Q20037>LHaQcW008Q208Li`8H
aP8Li`0336<@Q1cW008Q200@9BTQ22486<HDYA246<H48@00124000Q248@Q21S6124?0003Ool00`00
Oomoo`0>Ool000moo`03001oogoo01`000076<IF]ABU8@P<H`0036<00RDY00@YBSW>DYA6<@9:DP03
AS5244Ha0096<@05DYA>LdHaAS4icP02AS48CW<01D8@?NlicSW><H`00RDY00T]JcW>AS5243W>5:De
[Cg_BU800THa00=243F]=Jd00d8@0THa0T8@01De[AS6;F/icTYBAS5243g_>Lhe[AS6:DXQ20002484
8@Q27>L]Jc6<8@P01@0000<48@00000020000Woo00<007ooOol06goo00<007oo00006`0000L<HbU:
248@Q0@Q00048@0248@011BU7>LYBR480RDY1B4800DYBRDY8@PQ21cW008Q20PU:@058@PLiacW7>LH
aP0248@02ABU7>LQ22487>L8@QS67>LU:@038@P26<H78@P01AS636<DYAcW9BT00R480QcW00`HaPaS
5:D@Q000124000@Q36<DYAS648@@0003Ool00`00Oomoo`0>Ool000moo`03001oogoo00H000031240
000001<0000E124YBU[F248@Q0Q2124003W>;F/icSg_@Q16<DYB?Nm244HaCW=BU4ic00=:DP04AS5>
LdicCW<4BU800dicAS5:DP03BU82?Nl02CF]7>LicT8@BU9243W>;F/icP02AS400d8@AS56<@02>Lh2
@Q0024HaBU96<D8@?Nl]Jb48:DX3@Q001THa?NlaS2DY:DX]J`8<H`07248<HbDY5:DmkcW>24804000
0Woo00<007ooOol06goo00<007oo0000700000DDYBe[1248@P@Q008000047>LDYAcW7>L28@P01RDY
7>LQ22489BTYBP@U:@038@PU:BDY00HU:@038@PU:BDY008U:@8Li`096<H<HacW8@PU:B487>LDYAcW
00DQ208Li`<Q20079BTQ22487>LDYA245:D0124800<LiaS648@00QBU10@Q00D@Q0Q27>LLi`@Q0100
00=oo`03001oogoo00ioo`003goo00<007ooOol06@000P@Q0P0000D8@THaF]H<Ha2400848@03248L
idHa008mk`07BU96<CW>@Q1:DUJeCW<01DYB00Y>Le:DCW=:DTicBU96<DYBAS52408mk`07BU96<DHa
?Nl]JcW>@Q000TYB00=243W>?Nl00THa00E243W>=JdYBSg_00924008AS5:DTYBAS4mkbe[8@PYBP92
40<icP04:DXQ23F]36<212401P0036<HaSg_;F/Li`L000031240000000L0009oo`03001oogoo01]o
o`03001oo`0001`00005124Q22e[1248@P0200000`@Q36<Q20027>L01RDY8@PLib489BTYBPLU:@03
:DXU:BDY008U:@048@PU:B488@P27>L01bDY8@PQ21cW5:DLib48008U:@038@PLiacW00<Q20047>LH
aQBU7>L38@P29BT01B487>LDYA245:D00R480acW00@DYA246<H48@<00005124<HacW5:D<H`0A0003
Ool00`00Oomoo`0>Ool000moo`03001oogoo01h0000D36<icV]J48@<H`Q236<48@aS9BU243g_@Q0i
cTYBDYA244HaBU96<@924005DYA:DU:DCW=:DP03CW<01U:D@Q12448@=Jdmk`96<@04?NlaS3W>@Q02
BU85AS401Cg_>Lhmkc6<>Lh00d8@00Xe[Cg_@Q1243W>7>LU:Cg_AS4aS08icP099BT]JacW248@Q0aS
000]Jb48008icP031240000000l0009oo`03001oogoo01]oo`03001oo`0001d00004124LicF]2483
12402@00124@Q2487>LQ21cW9BTYBP028@P01bDY8@PQ2248:DXU:BU:00DU:@06:DXQ22488@PHaQcW
0R4800@LiaS67>LQ208U:@DQ20<Li`036<HLib48008Q200:6<HLib488@PLi`aS48@Lib486<H27>L0
2A245:D<H`@Q24848@005:D@Q0027>LB0003Ool00`00Oomoo`0>Ool000moo`03001oogoo01h00007
124<HcW>HaPHaPaS00000`Q200dU:Be[;F/aS48@AS4icT8@?Nle[CW>?Nm:DP02CW<3BU801TicAS56
<DHaCW=6<@8mk`9:DP06@Q0mkc6<@Q1:DTHa148@00<icSF]>Lh00T8@00le[Cg_AS5242e[<H`icTHa
?NlU:AcW?Nm2436<;F/00RDY00<]J`@Q12400PaS00DDYAS6CW<icQ24008000031240000000d0009o
o`03001oogoo01]oo`03001oo`0001h00006124Lic6<36<48@000`@Q00@@Q1BU5:DHaP8Q20047>LQ
21cW6<H27>L79BT38@P012DY8@PLiacW0RDY00DQ21cW6<HQ22DY00DQ20037>LHaQcW008Q200?6<HL
ib488@PDYAS67>LQ21cW48@<HacW8@PHaQBU008@Q0035:D0000000848@05248<HbDY7>L8@P0B0003
Ool00`00Oomoo`0>Ool000moo`03001oogoo0200000A2496<Ekg36<48A2436<000@Q9BT@Q3F]?Nm2
436<>Lhmk`02<H`02cW>BU96<D8@AS5BU4YB?Nle[CW>@Q000THa0Sg_00=6<DicBU800T8@0THa0TYB
0THa00@icSF]>Lhmk`96<@0L?Nm244YB@Q0icRDY;F/icT8@;F/U:C6<>Lhe[AcW;F/e[@Q2124<H`@Q
48@Q24YB?Nl]J`00124A0002Ool00`00Oomoo`0KOol00`00Ool0000O00001`@Q8@P]J`@Q0008@P@Q
0080000648@8@QS67>LQ21S60QcW0QS600<LibDY8@P00R4800DYBRDY7>LHaQcW00<Q208Li`038@PU
:BDY00@Q208U:@8Q20047>LHaQcW7>L28@P06QcW8@PU:B487>L@Q1BU7>LQ21BU48@HaQcW6<H<HaBU
6<H48@00124000Q248@U:AcW5:DC0003Ool00`00Oomoo`0>Ool000moo`03001oogoo00X000031240
000001@00007249:DV]J248DYA2412400PQ200LQ22DY?Nm242U:;F/YBP029BT01cW>AS52436<@Q16
<DYB00<e[@05@Q1:DT8@@Q0mk`02AS400dYB?Nm24002@Q0014Ha@Q12448@0cF]00<icT8@AS400Sg_
00a244Ha?NlQ22DY>Li2436<9BTQ22U:7>L29BT02@aS000<H`aS124e[BU:AS4mk`0D0002Ool00`00
Oomoo`0KOol00`00Ool0000P000010@Q9BTe[@@Q0PQ200<000@Q12400Q2400<Lib485:D00QBU0Q24
00@Lib488@PHaP8Q20069BTHaQS66<HQ22DY0R4800DLib488@PU:AcW00LQ20<HaP037>LQ2248008L
i`8Q20067>L@Q1247>LQ21S60Q2400HDY@aS48@@Q0@Q000212401@006<HDYB487>L050000goo00<0
07ooOol03Woo000?Ool00`00Oomoo`0500000`@Q0000000J00001@aS;F]_N`aS9BT00PQ200P<H`00
248U:B48;F/LiaS60QcW00<e[Cg_@Q000Sg_00A:DSg_=JdHaP8icP96<@04?Nm2448@AS42@Q0013g_
=JdicSg_0T8@00DicRe[;F/aS3W>0092400@AS4mkd8@@Q0mkbe[7>LicT8@?NlQ21BU48@Lic6<48@2
24801`aS248mkaS6?Nle[@Q201@0009oo`03001oogoo01]oo`03001oo`0002400005124DYCF]124@
Q00312401@00124@Q1245:D010aS00<HaQcW8@P00QcW00@U:AcW6<H<H`8Li`8Q20037>LQ224800<Q
20047>LHaQcW7>L28@P01AcW5:DDYAS67>L00b4800XLib488@PLiaBU36<Lib487>L@Q088@P0336<H
aPQ200@48@057>L<HacW6<H48@0D0003Ool00`00Oomoo`0>Ool000moo`03001oogoo02<00007248i
cUkg5:DaS0@Q48@00`Q200<YBQcW9BT00QS600@DYCF]?Nm6<@=24003?Nle[AcW008icP=24005AS4m
kdHa@Q0mk`02>Lh01CF]>Li2448@>Lh00S6<00HicSg_?Nlmkd8@?Nl2@Q001Sg_=JdHaSF]@Q0icP8D
Y@046<He[@aS124224801`@Q9BT<Hdic@Q0@Q0@Q00D000031240000000`0009oo`03001oogoo01]o
o`03001oo`0002800007124Libe[248HaP0024800`@Q00<DY@aS48@00PaS00<8@QS67>L0124800<L
iaS636<00QcW124800<Lib488@P00acW00DHaQcW8@PQ21cW008HaP@Li`0:8@PLib488@PLiaS636<H
aR487>L2248010aS6<H48@000P@Q00H00124124U:B48248E0003Ool00`00Oomoo`0>Ool000moo`03
001oogoo02800006124000@Q<HaBU2e[0QBU00<<H`@Q8@P00QcW00He[AcW6<HQ22U:=Jd2>Lh02cF]
>LhmkcW>6<He[CW>AS5243g_@Q000cg_010icS6<:DX]JcF]?Nm243F]<H`]JcF]<H`e[CW>?Nm2408i
cP03=Jd]JacW008aS00448@Q21S6<H`2000236<01PQ2<H`<Hd8@AS4@Q1H0009oo`03001oogoo01]o
o`03001oo`0002@000036<HYBQBU0088@P0312400124008<H`066<H<H`aS48@DYAS60QcW00LHaQcW
7>LLi`aS6<HLi`028@P00acW8@PLi`037>L01QS65:DDYAS67>LQ208HaP045:DHaQS66<H27>L01R48
7>LLiaS65:D<H`8HaP04248@Q0aS6<H2000312401AS6124Q224824805P000goo00<007ooOol03Woo
000?Ool01000Oomoo`@Q0P0000<48@000000500000<48@0000002@0000DLidHaBU8<HbDY0088@P0?
124HaRDY:DXU:B486<HDYBU:;F/aS3W>?NlicQBU008e[@A2400<?Nle[CF]<H`YBR48;F/aS3W>AS4e
[C6<0Re[00<YBS6<>Lh00Sg_01@icSg_>LhLiaS648@HaRDY:DX8@P@Q248<Ha2436<icPaS@Q0mkbU:
400000<48@00000010000Woo00<007ooOol06goo00<007oo00009@0000D<Hb489BT48A2400848@04
000<Ha245:D248@01@aS248DYABU6<H00acW00<8@QS66<H0124800XLiaS66<HHaQBU48@DYAS67>LQ
208HaP<DY@036<HLiacW00@Li`8<H`06248<Ha245:D48@000P@Q00L8@P@Q7>L48B487>LDY@0G0003
Ool00`00Oomoo`0>Ool000moo`03001oogoo020000031240000000@0000348A6<Ekg008U:@0536<4
8@@Q1248@P04124030Q236<@Q248:DXDYA24;F/aS3W>?Nm6<@8mk`07=Jd]JbU:8@PHaRU:<H`00Sg_
00HicS6<:DXU:A24>Lh2?Nl023W><H`YBQBU6<HQ22DY:DX324802R48>Lhmk`aS=Jd8@THa@Q0aS0@Q
3@0000<48@0000001`000Woo00<007ooOol06goo00<007oo00009P0000<8@R48;F/00Q2400D48@00
000000@Q00@000848@03248@Q1BU0088@P055:DHaQcW7>LQ20027>L01aS65:DDYA2436<DYAS600<L
i`046<HDYA2424847>L011S65:D8@PaS0Q2400DDY@@Q12448A24008Li`03124HaP@Q008Q20036<H0
000001H000=oo`03001oogoo00ioo`003goo00<007ooOol0:00000H8@SW>@Q0mka24;F/224801P@Q
48@48@@Q000<H`848@0<00048@@Q124<Hbe[>LhmkcW>=JdmkbU:0QcW00dHaQ24:DXe[Cg_@Q0icSF]
8@PLia245:Dmk`02>Lh01RDY:DXYBQS6;F/<H`<8@P09000icPaS6<HU:ABUAS5:DRDY00D000031240
000000`00003124000000080009oo`03001oogoo01]oo`03001oo`0002L00006124Lib487>L8@QBU
0P@Q00<000Q200000P0000<48@000000100000<48ABU7>L00QcW00<HaQcW5:D00`aS00T8@QBU6<HL
ib487>LHaQ2436<00PQ20acW00D@Q1BU5:D<HaBU00@48@09000Li`@Q36<@Q0Q28@PU:A2401T000=o
o`03001oogoo00ioo`003goo00<007ooOol0:@0000/48B48?Nm:DRDY36<HaQBU36<8@Q24008<H`04
248<H`aS36<2248212400`Q27>LHaP026<H011BU6<HHaRDY0QBU00DaS3g_?NlmkbU:00<Li`8HaP03
9BTHaQBU008U:@8<H`0=124000aS48@8@Q24=Jd002DY<Ha241BU12405P0000<48@0000000Woo00<0
07ooOol06goo00<007oo0000:@0000L@Q1cW9BT@Q0@Q36<8@P0212400`Q212448@06124200000`@Q
36<<H`0236<010Q236<<Ha240PQ200DHaQcW7>LLiaBU00D<H`0348@<H`Q2008@Q0848@80000:1248
@P@Q248HaP0048@HaR48248J0003Ool00`00Oomoo`0>Ool000moo`03001oogoo01H0000312400000
01800009248]Jd8@@Q0aS0@Q6<HDY@aS00848@04248@Q0aS36<224802aBU248000@Q000LibU:7>L0
00Q212400QBU01`HaR488@PDYBU:6<HYBQS69BTQ22DY7>L@Q0Q2124000Q25:D000Q248@aS0Q236=2
44YB>Lh48A4000031240000000L0009oo`03001oogoo01]oo`03001oo`0002X00009124DYB488@PH
aP0036<8@P@Q008000031248@P@Q00<48@0324848@000080000636<DY@aS00048@000PQ200P<Ha24
48@8@QBU36<DY@aS0a2400<<H`Q212400P0000H48@Q200048@Q26<H212400b489BTLi`0L0003Ool0
0`00Oomoo`0>Ool000moo`03001oogoo02X0000912400000248icTHaCW<icQ24008DY@8HaP0536<8
@PaS000<H`0248@010@Q00048@aS0`Q20`000P@Q00T000@Q24848AS69BT@Q2DY48@00`0000T8@Q24
36<48@aS6<HQ20aS12400THa00=241S624805`0000<48@0000000P000Woo00<007ooOol06goo00<0
07oo0000;00000D48AcW8@PU:AcW00<8@P8<H`<48@0400048@Q224830004124700001`@Q000<Ha24
248@Q0Q200<000091248@P@Q00048@aS48@48@0000<Q200336<48@0001/000=oo`03001oogoo00io
o`003goo00<007ooOol0;P0000l48@Q2;F]244YB?Nle[Be[48@48@aS48@LiaS636<00P@Q00L000@Q
24848@Q212400002248236<00a24248<H`0224800`@Q2488@P0212402@Q236<48@@Q36<Lia24124H
aP03?Nl00bDY1240000M0002Ool00`00Oomoo`0KOol00`00Ool0000^00002`@Q5:DQ22DY7>LHaQBU
248000@Q24800PaS00<48@0000000P0000<48@0012400P0010@Q00<8@P@Q12400P@Q00<000@Q1240
0P000P@Q0P0000D48@aS248000aS00<Li`0348@0000001d000=oo`03001oogoo00ioo`003goo00<0
07ooOol03P0000<48@000000800000X48@Q29BTmkd8@>Li6<CF]<H`DY@848@0448@DYA246<H27>L0
0aS65:D<H`0236<010Q236<8@P@Q0PQ200H48@002488@PaS48@336<02AcW36<DYCF]AS4icSg_9BT4
8@0P0002Ool00`00Oomoo`0KOol00`00Ool0000a00001P@Q48@Lib487>LQ208HaP032480000000<8
@P@<H`0324848@@Q00@48@0300048@@Q008000<48@0924848@@Q124<H`@Q248HaR48008Li`0348@0
000001l000=oo`03001oogoo00ioo`003goo00<007ooOol03P0000<48@0000008P000P@Q00T001S6
9BTmkd8@?Nm:DT8@=Jd00Re[00@DYAS636<48@8<H`03124@Q1BU008HaP037>LHaQS6008DY@0>48@D
YABU5:DHaQ24248<Hcg_=Je6<Cg_7>L48B80009oo`03001oogoo01]oo`03001oo`0003D0000836<@
Q1cW8@PLibDY8@PHaP8DY@04248<H`@Q000212400`002488@P0536<624802@aS24848@@Q7>LHaR48
7>L<H`0S0003Ool00`00Oomoo`0>Ool000moo`03001oogoo030000031240000000D000848@0;5:DY
BSg_>Li6<CW>?Nle[CW>@Q0mk`02>Lh01Re[=JdU:B486<HU:@8<H`0848@8@PQ248@HaR48:DXe[@8m
k`05>LhDY@Q200048@0R0002Ool00`00Oomoo`0KOol00`00Ool0000i00001@Q25:DLiacW8@P00QcW
00<HaQcW8@P00acW00HDYAS648@@Q0aS48@2124020Q212448@Q236<@Q1BU6<H37>L00`Q21240000S
0003Ool00`00Oomoo`0>Ool000moo`03001oogoo02l000031240000000T000031248@P0000800003
248DYAS6008YBP04=JdaS3F]=Jd2@Q000cg_<Ha24002?Nl2=Jd023W>@Q0mkcg_>Lh]JaBU124V0002
Ool00`00Oomoo`0KOol00`00Ool0000k00001`@Q000000001248@PaS008DY@@HaP8Q20037>LHaR48
008Li`8HaP037>LQ21cW008Li`035:D8@P0002H000=oo`03001oogoo00ioo`003goo00<007ooOol0
A`0000<48@0000000P@Q00@@Q1S66<HLi`8U:@036<HDY@Q202/0009oo`03001oogoo01]oo`03001o
o`0004/00004248<H`aS36<248@00`aS24848@0[0003Ool00`00Oomoo`0>Ool000moo`03001oogoo
05`00003124000000240009oo`03001oogoo01]oo`03001oo`0007l000=oo`03001oogoo00ioo`00
3goo00<007ooOol0P0000Woo00<007ooOol06goo00<007oo0000O`000goo00<007ooOol03Woo000?
Ool00`00Oomoo`0j00000`@Q0000000Q00000`@Q0000000O0002Ool00`00Oomoo`0KOol00`00Ool0
001o0003Ool00`00Oomoo`0>Ool000moo`03001oogoo048000031240000003/0009oo`03001oogoo
01]oo`03001oo`0007l000=oo`03001oogoo00ioo`003goo00<007ooOol0PWoo00<007ooOol06goo
00<007ooOol0PWoo00<007ooOol03Woo000?Oon6000MOon6000@Ool00?moodUoo`00ogooBGoo003o
Oom9Ool00?moodUoo`00G7oo0P00WGoo0P00Bgoo001NOol00`00Oomoo`2LOol00`00Oomoo`18Ool0
02Qoo`800003Ool00000009oo`<0009oo`8000=oo`80009oo`8000=oo`<0009oo`@00004Ool00000
0002Ool300000goo00000002Ool00`00Oomoo`03000COol200000goo00000002Ool00`00Oomoo`1;
Ool200000goo00000002Ool30002Ool20003Ool20002Ool20003Ool30002Ool4000017oo00000000
0Woo0`0000=oo`0000000Woo00<007ooOol00`004goo0P000Woo0`000Woo0`00:goo000XOol01`00
Oomoogoo001oo`00009oo`03001oo`00009oo`03001oo`00009oo`05001oogooOol00002Ool00`00
Oomoo`02Ool30003Ool00`00Oomoo`02Ool01@00Oomoogoo00000Woo00<007oo00000Woo00<007oo
Ool047oo00H007ooOol007oo0002Ool00`00Oomoo`1;Ool01`00Oomoogoo001oo`00009oo`03001o
o`00009oo`03001oo`00009oo`05001oogooOol00002Ool00`00Oomoo`02Ool30003Ool00`00Oomo
o`02Ool01@00Oomoogoo00000Woo00<007oo00000Woo00<007ooOol047oo00@007ooOol0009oo`03
001oogoo009oo`03001oogoo02Yoo`00:Goo0`000Woo00H007ooOol007oo0004Ool01000Oomoo`00
0Woo00D007ooOomoo`0000Ioo`05001oogooOol00004Ool01@00Oomoogoo00000Woo00<007oo0000
0Woo00<007ooOol047oo00H007ooOol007oo0002Ool00`00Oomoo`1<Ool30002Ool01P00Oomoo`00
Ool000Aoo`04001oogoo0002Ool01@00Oomoogoo00001Woo00D007ooOomoo`0000Aoo`05001oogoo
Ool00002Ool00`00Ool00002Ool00`00Oomoo`0@Ool01000Oomoo`000Woo00<007ooOol00Woo00<0
07ooOol0:Woo000YOol01000Ool007oo0P0000=oo`00000010000goo0P000goo0P000Woo0`000goo
0P000goo00@007ooOomoo`80009oo`@000=oo`<0019oo`03001oogoo00D004moo`04001oo`00Ool2
00000goo000000040003Ool20003Ool20002Ool30003Ool20003Ool01000Oomoogoo0P000Woo1000
0goo0`004Woo00D007ooOol007oo00<0009oo`<002]oo`00:Woo00<007ooOol01Woo00<007ooOol0
5goo00<007ooOol08Goo00@007ooOol005Aoo`03001oogoo00Ioo`03001oogoo01Moo`03001oogoo
025oo`04001oogoo0002Ool00`00Oomoo`02Ool00`00Oomoo`0ZOol002Uoo`80025oo`8000Aoo`03
001oogoo01eoo`8005Aoo`80025oo`8000Aoo`03001oogoo01eoo`8000Aoo`03001oogoo009oo`03
001oogoo02Uoo`00ogooBGoo003oOom9Ool00?moodUoo`00ogooBGoo003oOom9Ool00?moodUoo`00
\
\>"],
  ImageRangeCache->{{{0, 327}, {155, 0}} -> {-0.0548482, -0.0238146, 
  0.00645168, 0.00645168}, {{8.5, 156.063}, {151.25, 
  3.6875}} -> {-18.341, -6.3134, 1.00073, 1.00073}, {{170.875, 318.5}, {
  151.25, 3.6875}} -> {-180.865, -6.3134, 1.00073, 1.00073}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["IMAGE HISTOGRAM", "Section"],

Cell[TextData[{
  "An important concept in the representation, statistical characterization \
and processing of digital images is the so-called ",
  StyleBox["histogram. ",
    FontSlant->"Italic"],
  "The histogram is an estimate of the probability distribution of amplitude \
values.  It is simply a count (or relative frequency, if normalized) of the \
various gray levels in the image (see also the ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " functions ",
  StyleBox["Count", "Program"],
  ", ",
  StyleBox["Frequencies", "Program"],
  ", ",
  StyleBox["BinCount", "Program"],
  ").  Histograms play an important role in many image processing tasks such \
as enhancement, compression, thresholding and more."
}], "Text"],

Cell["Here we calculate  the histogram of the example image.", "Caption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(ListPlot[h = Histogram[A], PlotJoined \[Rule] True, 
      PlotRange \[Rule] All]; \)\)], "Input",
  CellLabel->"In[12]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0200747 0.00373483 0.0147151 0.000423761 [
[.20682 .00222 -6 -9 ]
[.20682 .00222 6 0 ]
[.39356 .00222 -9 -9 ]
[.39356 .00222 9 0 ]
[.5803 .00222 -9 -9 ]
[.5803 .00222 9 0 ]
[.76704 .00222 -9 -9 ]
[.76704 .00222 9 0 ]
[.95378 .00222 -9 -9 ]
[.95378 .00222 9 0 ]
[.00757 .09947 -18 -4.5 ]
[.00757 .09947 0 4.5 ]
[.00757 .18422 -18 -4.5 ]
[.00757 .18422 0 4.5 ]
[.00757 .26897 -18 -4.5 ]
[.00757 .26897 0 4.5 ]
[.00757 .35372 -18 -4.5 ]
[.00757 .35372 0 4.5 ]
[.00757 .43848 -24 -4.5 ]
[.00757 .43848 0 4.5 ]
[.00757 .52323 -24 -4.5 ]
[.00757 .52323 0 4.5 ]
[.00757 .60798 -24 -4.5 ]
[.00757 .60798 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.20682 .01472 m
.20682 .02097 L
s
[(50)] .20682 .00222 0 1 Mshowa
.39356 .01472 m
.39356 .02097 L
s
[(100)] .39356 .00222 0 1 Mshowa
.5803 .01472 m
.5803 .02097 L
s
[(150)] .5803 .00222 0 1 Mshowa
.76704 .01472 m
.76704 .02097 L
s
[(200)] .76704 .00222 0 1 Mshowa
.95378 .01472 m
.95378 .02097 L
s
[(250)] .95378 .00222 0 1 Mshowa
.125 Mabswid
.05742 .01472 m
.05742 .01847 L
s
.09477 .01472 m
.09477 .01847 L
s
.13212 .01472 m
.13212 .01847 L
s
.16947 .01472 m
.16947 .01847 L
s
.24416 .01472 m
.24416 .01847 L
s
.28151 .01472 m
.28151 .01847 L
s
.31886 .01472 m
.31886 .01847 L
s
.35621 .01472 m
.35621 .01847 L
s
.43091 .01472 m
.43091 .01847 L
s
.46825 .01472 m
.46825 .01847 L
s
.5056 .01472 m
.5056 .01847 L
s
.54295 .01472 m
.54295 .01847 L
s
.61765 .01472 m
.61765 .01847 L
s
.655 .01472 m
.655 .01847 L
s
.69234 .01472 m
.69234 .01847 L
s
.72969 .01472 m
.72969 .01847 L
s
.80439 .01472 m
.80439 .01847 L
s
.84174 .01472 m
.84174 .01847 L
s
.87908 .01472 m
.87908 .01847 L
s
.91643 .01472 m
.91643 .01847 L
s
.99113 .01472 m
.99113 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02007 .09947 m
.02632 .09947 L
s
[(200)] .00757 .09947 1 0 Mshowa
.02007 .18422 m
.02632 .18422 L
s
[(400)] .00757 .18422 1 0 Mshowa
.02007 .26897 m
.02632 .26897 L
s
[(600)] .00757 .26897 1 0 Mshowa
.02007 .35372 m
.02632 .35372 L
s
[(800)] .00757 .35372 1 0 Mshowa
.02007 .43848 m
.02632 .43848 L
s
[(1000)] .00757 .43848 1 0 Mshowa
.02007 .52323 m
.02632 .52323 L
s
[(1200)] .00757 .52323 1 0 Mshowa
.02007 .60798 m
.02632 .60798 L
s
[(1400)] .00757 .60798 1 0 Mshowa
.125 Mabswid
.02007 .0359 m
.02382 .0359 L
s
.02007 .05709 m
.02382 .05709 L
s
.02007 .07828 m
.02382 .07828 L
s
.02007 .12066 m
.02382 .12066 L
s
.02007 .14184 m
.02382 .14184 L
s
.02007 .16303 m
.02382 .16303 L
s
.02007 .20541 m
.02382 .20541 L
s
.02007 .2266 m
.02382 .2266 L
s
.02007 .24778 m
.02382 .24778 L
s
.02007 .29016 m
.02382 .29016 L
s
.02007 .31135 m
.02382 .31135 L
s
.02007 .33254 m
.02382 .33254 L
s
.02007 .37491 m
.02382 .37491 L
s
.02007 .3961 m
.02382 .3961 L
s
.02007 .41729 m
.02382 .41729 L
s
.02007 .45966 m
.02382 .45966 L
s
.02007 .48085 m
.02382 .48085 L
s
.02007 .50204 m
.02382 .50204 L
s
.02007 .54442 m
.02382 .54442 L
s
.02007 .5656 m
.02382 .5656 L
s
.02007 .58679 m
.02382 .58679 L
s
.25 Mabswid
.02007 0 m
.02007 .61803 L
s
.5 Mabswid
.02381 .60332 m
.02754 .38466 L
.03128 .54908 L
.03501 .33677 L
.03875 .49272 L
.04248 .16896 L
.04622 .15371 L
.04995 .10625 L
.05369 .10286 L
.05742 .09099 L
.06116 .1304 L
.06489 .08675 L
.06863 .08082 L
.07236 .06302 L
.0761 .06302 L
.07983 .08125 L
.08357 .05624 L
.0873 .04989 L
.09104 .0448 L
.09477 .04565 L
.09851 .03972 L
.10224 .04395 L
.10598 .05116 L
.10971 .03506 L
.11345 .03675 L
.11718 .0626 L
.12092 .01472 L
.12465 .05836 L
.12838 .03887 L
.13212 .03209 L
.13585 .03633 L
.13959 .03378 L
.14332 .04184 L
.14706 .04862 L
.15079 .03633 L
.15453 .03633 L
.15826 .03251 L
.162 .03802 L
.16573 .04395 L
.16947 .03294 L
.1732 .03802 L
.17694 .04353 L
.18067 .03633 L
.18441 .04353 L
.18814 .04523 L
.19188 .03845 L
.19561 .04014 L
.19935 .03633 L
.20308 .03802 L
.20682 .04099 L
Mistroke
.21055 .05116 L
.21429 .03124 L
.21802 .03167 L
.22176 .0359 L
.22549 .04014 L
.22923 .04819 L
.23296 .0359 L
.23669 .03209 L
.24043 .02828 L
.24416 .03675 L
.2479 .04311 L
.25163 .05116 L
.25537 .027 L
.2591 .03251 L
.26284 .03039 L
.26657 .03802 L
.27031 .04777 L
.27404 .03336 L
.27778 .03421 L
.28151 .03336 L
.28525 .03209 L
.28898 .0359 L
.29272 .04099 L
.29645 .03167 L
.30019 .03124 L
.30392 .03209 L
.30766 .03506 L
.31139 .04226 L
.31513 .03421 L
.31886 .03039 L
.3226 .03039 L
.32633 .0287 L
.33007 .03887 L
.3338 .04395 L
.33754 .03675 L
.34127 .03209 L
.345 .03336 L
.34874 .02743 L
.35247 .03717 L
.35621 .04607 L
.35994 .0359 L
.36368 .03209 L
.36741 .03167 L
.37115 .03802 L
.37488 .04607 L
.37862 .03167 L
.38235 .03124 L
.38609 .03378 L
.38982 .03124 L
.39356 .0376 L
Mistroke
.39729 .04692 L
.40103 .03124 L
.40476 .0376 L
.4085 .03633 L
.41223 .04523 L
.41597 .05201 L
.4197 .03548 L
.42344 .03378 L
.42717 .03972 L
.43091 .03887 L
.43464 .05497 L
.43838 .05582 L
.44211 .03336 L
.44585 .0448 L
.44958 .04565 L
.45331 .04523 L
.45705 .05412 L
.46078 .04353 L
.46452 .03929 L
.46825 .03929 L
.47199 .0376 L
.47572 .05158 L
.47946 .05412 L
.48319 .04184 L
.48693 .03802 L
.49066 .03972 L
.4944 .05243 L
.49813 .05455 L
.50187 .04395 L
.5056 .04014 L
.50934 .04395 L
.51307 .04607 L
.51681 .05751 L
.52054 .05836 L
.52428 .0448 L
.52801 .04819 L
.53175 .04311 L
.53548 .04141 L
.53922 .05709 L
.54295 .05709 L
.54669 .03929 L
.55042 .04014 L
.55415 .03845 L
.55789 .04777 L
.56162 .05073 L
.56536 .03336 L
.56909 .03294 L
.57283 .0359 L
.57656 .03251 L
.5803 .0465 L
Mistroke
.58403 .04056 L
.58777 .02997 L
.5915 .03251 L
.59524 .03039 L
.59897 .03717 L
.60271 .03378 L
.60644 .02616 L
.61018 .03039 L
.61391 .02658 L
.61765 .0215 L
.62138 .02828 L
.62512 .02743 L
.62885 .0198 L
.63259 .02022 L
.63632 .01811 L
.64006 .02192 L
.64379 .02234 L
.64753 .01726 L
.65126 .02022 L
.655 .01853 L
.65873 .01853 L
.66246 .01811 L
.6662 .0198 L
.66993 .01599 L
.67367 .01641 L
.6774 .01811 L
.68114 .01811 L
.68487 .01683 L
.68861 .01726 L
.69234 .01641 L
.69608 .01514 L
.69981 .01514 L
.70355 .01726 L
.70728 .01683 L
.71102 .01514 L
.71475 .01472 L
.71849 .01514 L
.72222 .01641 L
.72596 .01514 L
.72969 .01514 L
.73343 .01472 L
.73716 .01472 L
.7409 .01514 L
.74463 .01472 L
.74837 .01514 L
.7521 .01514 L
.75584 .01472 L
.75957 .01472 L
.76331 .01514 L
.76704 .01472 L
Mistroke
.77077 .01472 L
.77451 .01472 L
.77824 .01472 L
.78198 .01472 L
.78571 .01472 L
.78945 .01472 L
.79318 .01472 L
.79692 .01472 L
.80065 .01599 L
.80439 .01472 L
.80812 .01472 L
.81186 .01472 L
.81559 .01472 L
.81933 .01472 L
.82306 .01472 L
.8268 .01472 L
.83053 .01472 L
.83427 .01472 L
.838 .01472 L
.84174 .01472 L
.84547 .01472 L
.84921 .01514 L
.85294 .01472 L
.85668 .01472 L
.86041 .01472 L
.86415 .01472 L
.86788 .01472 L
.87162 .01472 L
.87535 .01472 L
.87908 .01472 L
.88282 .01472 L
.88655 .01472 L
.89029 .01472 L
.89402 .01472 L
.89776 .01472 L
.90149 .01472 L
.90523 .01472 L
.90896 .01472 L
.9127 .01472 L
.91643 .01472 L
.92017 .01472 L
.9239 .01472 L
.92764 .01472 L
.93137 .01472 L
.93511 .01472 L
.93884 .01472 L
.94258 .01472 L
.94631 .01472 L
.95005 .01472 L
.95378 .01472 L
Mistroke
.95752 .01472 L
.96125 .01472 L
.96499 .01472 L
.96872 .01472 L
.97246 .01472 L
.97619 .01514 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[12]:=",
  ImageSize->{216, 133.438},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003H0000QA000`40O003h00Of7oo003HOol003]o
o`03001oogoo009oo`03001oogoo01Moo`D0009oo`03001oogoo009oo`03001oogoo01Eoo`D0009o
o`03001oogoo009oo`03001oogoo01Ioo`<000=oo`03001oogoo009oo`03001oogoo01Ioo`<000=o
o`03001oogoo009oo`03001oogoo00=oo`00>Woo00<007oo00000Woo00<007oo00006Woo00L007oo
Oomoo`00Ool00002Ool00`00Ool0000HOol01`00Oomoogoo001oo`00009oo`03001oo`0001Moo`03
001oogoo009oo`03001oo`00009oo`03001oo`0001Moo`03001oogoo009oo`03001oo`00009oo`03
001oo`0000Aoo`00?7oo00H007ooOol007oo000JOol01`00Oomoogoo001oo`00009oo`03001oo`00
01Qoo`03001oogoo00=oo`06001oogoo001oo`0067oo00L007ooOomoo`00Ool00002Ool00`00Ool0
000HOol00`00Oomoo`03Ool01P00Oomoo`00Ool000Aoo`00>Woo0P000goo00<007oo00006Woo00L0
07ooOomoo`00Ool00002Ool00`00Ool0000HOol01000Oomoogoo0P000goo00<007oo000067oo00L0
07ooOomoo`00Ool00002Ool00`00Ool0000HOol01000Oomoogoo0P000goo00<007oo000017oo000j
Ool00`00Oomoo`02Ool00`00Ool0000JOol01`00Oomoogoo001oo`00009oo`03001oo`0001Qoo`05
001oogooOol00004Ool00`00Ool0000GOol00`00Ool00002Ool00`00Ool00002Ool00`00Ool0000G
Ool00`00Ool00002Ool00`00Oomoo`02Ool00`00Ool00004Ool003Yoo`<000=oo`03001oogoo01Qo
o`8000Aoo`03001oogoo009oo`03001oogoo01Ioo`8000=oo`<000=oo`03001oogoo01Moo`03001o
ogoo009oo`03001oogoo009oo`03001oogoo01Moo`04001oogooOol30003Ool00`00Oomoo`03Ool0
0=Qoo`00f7oo000JOol00`00Oomoo`2kOol001Yoo`03001oogoo0;]oo`006Woo00<007ooOol0^goo
000FOoo10001Ool001Yoo`03001oogoo011oo`03001oogoo00ioo`03001oogoo025oo`03001oogoo
025oo`03001oogoo00Aoo`03001oo`0000@0009oo`03001oogoo015oo`03001oogoo025oo`03001o
ogoo00Moo`006Woo00<007ooOol047oo00<007ooOol057oo00@007ooOol000eoo`05001oogooOol0
000aOol200000goo001oo`18Ool001Yoo`03001oogoo011oo`05001oo`00Ool00002Ool01000Oomo
o`001goo0P000goo00<007ooOol00`0000Eoo`00000007oo00<00004Ool000000002Ool20002Ool2
00001Woo00000000Ool000=oo`05001oogooOol0000GOol300000goo00000003001<Ool001Yoo`80
00eoo`03001oo`0000800005Ool00000001oo`0500000goo001oo`0300003Woo001oo`00Ool007oo
001oo`00Ool007oo0002Ool00`00Oomoo`020003Ool20002Ool2000017oo001oo`000Woo100000Io
o`00000007oo0003Ool30002Ool00`00Oomoo`08Ool01000Ool007oo10000Woo00<007ooOol0C7oo
000JOol00`00Oomoo`0;Ool00`00Ool000050002Ool03000Oomoogoo001oo`00Ool007oo001oo`80
0003Ool0000000=oo`03001oogoo008000=oo`05001oogooOol00003Ool01000Oomoogoo0P0000=o
o`0000000goo00T007ooOol007oo001oo`00Ool00P000Woo00@007oo001oo`80009oo`80009oo`<0
0003Ool00000008000=oo`03001oogoo04moo`006Woo00<007ooOol02Woo0P0000=oo`00Ool00`00
0goo00<007ooOol01Goo00@007ooOomoo`80009oo`05001oogooOol00003Ool00`00Oomoo`0>Ool0
1000Oomoo`000goo00<007ooOol00P000goo00<007ooOol00P000goo00<007ooOol00P000Woo00<0
07oo00000`000Woo0P000goo00<007ooOol0Cgoo000JOol00`00Oomoo`09Ool01@00Oomoogoo0000
0Woo0P0047oo00<007ooOol017oo00<007ooOol07Goo00D007ooOomoo`0000=oo`05001oogooOol0
0002Ool20002Ool20003Ool01@00Oomoogoo0000EGoo000JOol2000:Ool00`00Oomoo`04Ool2000k
Ool00`00Oomoo`0<Ool20003Ool00`00Oomoo`1GOol001Yoo`03001oogoo00Moo`<000Ioo`03001o
ogoo0:Qoo`006Woo00<007ooOol01goo0P00/Woo000JOol00`00Oomoo`06Ool00`00Ool0002bOol0
01Yoo`8000Moo`03001oo`000;9oo`006Woo00<007ooOol01Woo00<007ooOol0/Woo000:Ool30003
Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`04Ool00`00Ool0002dOol000Yoo`03001o
ogoo009oo`03001oo`00009oo`03001oo`0000=oo`03001oogoo00Aoo`03001oo`000;Aoo`002goo
00L007ooOomoo`00Ool00002Ool00`00Ool00003Ool20004Ool200000goo001oo`2cOol000]oo`07
001oogooOol007oo00000Woo00<007oo00000goo00<007ooOol00goo0P0000=oo`00Ool0/goo000:
Ool00`00Ool00002Ool00`00Ool00002Ool00`00Ool00003Ool00`00Oomoo`03Ool3002eOol000]o
o`03001oogoo009oo`03001oogoo009oo`03001oogoo009oo`03001oogoo00=oo`03001oo`000;Eo
o`006Woo0P0017oo00<007oo0000]Goo000JOol00`00Oomoo`03Ool00`00Ool0002eOol001Yoo`03
001oogoo009oo`04001oogoo002eOol001Yoo`03001oogoo009oo`03001oogoo0;Ioo`006Woo0P00
0goo00<007ooOol0]Woo000JOol00`00Oomoo`02Ool00`00Oomoo`2fOol001Yoo`03001oogoo009o
o`03001oogoo0;Ioo`006Woo00<007ooOol00Woo00<007ooOol0]Woo000JOol20002Ool00`00Oomo
o`2gOol001Yoo`05001oogooOol0002iOol000]oo`<0009oo`03001oogoo009oo`03001oogoo009o
o`05001oogooOol0002iOol000aoo`06001oogoo001oo`000Woo00<007oo00000goo00D007ooOomo
o`000;Uoo`002Woo100000Aoo`00Ool0009oo`03001oo`0000=oo`80009oo`03001oogoo0;Moo`00
2Woo00<007oo00000Woo00<007oo00000Woo00<007oo00000goo00D007ooOomoo`000;Uoo`002goo
0P000Woo00<007oo00000Woo00<007oo00000goo00D007ooOomoo`000;Uoo`0037oo00D007ooOomo
o`0000Aoo`03001oogoo009oo`05001oogooOol0002iOol001Yoo`80009oo`03001oogoo0;Moo`00
6Woo00D007ooOomoo`000;Uoo`006Woo00D007ooOomoo`000;Uoo`006Woo00D007ooOomoo`000;Uo
o`006Woo0P000Woo00<007ooOol0]goo000JOol01@00Oomoogoo0000^Goo000JOol01@00Oomoogoo
0000^Goo000JOol01@00Oomoogoo0000^Goo000JOol01@00Oomoogoo0000^Goo000JOol20002Ool0
0`00Oomoo`2gOol001Yoo`05001oogooOol0002iOol000Yoo`8000Aoo`03001oogoo009oo`03001o
ogoo009oo`05001oogooOol0002iOol000Yoo`03001oo`00009oo`03001oo`00009oo`03001oo`00
00=oo`05001oogooOol0002iOol000Yoo`03001oo`00009oo`03001oo`00009oo`03001oo`0000=o
o`80009oo`03001oogoo0;Moo`002Woo0P000goo00<007oo00000Woo00<007oo00000goo00D007oo
Oomoo`000;Uoo`002Woo00<007ooOol00Woo00<007oo00000Woo00<007oo00000goo00D007ooOomo
o`000;Uoo`002goo0P000goo00<007ooOol00Woo00<007ooOol00Woo00D007ooOomoo`000;Uoo`00
6Woo0P000Woo00<007ooOol0]goo000JOol01@00Oomoogoo0000^Goo000JOol01@00Oomoogoo0000
^Goo000JOol01@00Oomoogoo0000^Goo000JOol20002Ool00`00Oomoo`2gOol001Yoo`05001oogoo
Ool0002iOol001Yoo`05001oogooOol0002iOol001Yoo`05001oogooOol0002iOol001Yoo`80009o
o`03001oogoo0;Moo`006Woo00<007ooOol00P00^Goo000;Ool00`00Oomoo`02Ool00`00Oomoo`02
Ool00`00Oomoo`02Ool00`00Oomoo`02002iOol000Yoo`03001oo`00009oo`03001oo`00009oo`03
001oo`0000=oo`03001oogoo00800;Uoo`002Woo00<007oo00000Woo00<007oo00000Woo00<007oo
00000goo0P0000=oo`000000^Goo000;Ool01`00Oomoogoo001oo`00009oo`03001oo`0000=oo`03
001oogoo00800;Uoo`002Woo00<007oo00000Woo00<007oo00000Woo00<007oo00000goo00<007oo
Ool00P00^Goo000;Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`02
002iOol001Yoo`800003Ool000000;Uoo`006Woo00<007ooOol00P00^Goo000JOol200000goo0000
002iOol001Yoo`800003Ool000000;Uoo`006Woo0P0000=oo`000000^Goo000JOol200000goo0000
002iOol001Yoo`800003Ool000000;Uoo`006Woo0P0000=oo`000000^Goo000JOol200000goo0000
002iOol001Yoo`800003Ool000000;Uoo`0017oo1@000Woo00<007ooOol00Woo00<007ooOol00Woo
00<007ooOol00Woo0P0000=oo`000000^Goo0006Ool01`00Oomoogoo001oo`00009oo`03001oo`00
009oo`03001oo`0000=oo`800003Ool000000;Uoo`001Woo00L007ooOomoo`00Ool00002Ool00`00
Ool00002Ool00`00Ool00003Ool200000goo0000002iOol000Ioo`07001oogooOol007oo00000Woo
00<007oo00000Woo00<007oo00000goo0`0000=oo`00Ool0^7oo0006Ool01`00Oomoogoo001oo`00
009oo`03001oo`00009oo`03001oo`0000=oo`<00003Ool007oo0;Qoo`001Goo0P0017oo00<007oo
Ool00Woo00<007ooOol00Woo00<007ooOol00Woo0`0000=oo`00Ool0^7oo000JOol300000goo001o
o`2hOol001Yoo`<00003Ool007oo0;Qoo`006Woo0`0000=oo`00Ool0^7oo000JOol300000goo001o
o`2hOol001Yoo`<00003Ool007oo0;Qoo`006Woo0`0000=oo`00Ool0^7oo000JOol300000goo001o
o`2hOol001Yoo`<00003Ool007oo0;Qoo`006Woo0`00^goo000JOol3002kOol000Aoo`D00004Ool0
00000003Ool00`00Oomoo`02Ool00`00Oomoo`02Ool3002kOol000Ioo`05001oogooOol00004Ool0
0`00Ool00002Ool00`00Ool00003Ool3002kOol000Ioo`03001oogoo009oo`07001oogooOol007oo
00000Woo00<007oo00000goo0`00^goo0006Ool00`00Oomoo`02Ool01`00Oomoogoo001oo`00009o
o`03001oo`0000=oo`<00;]oo`001Woo00L007ooOomoo`00Ool00002Ool00`00Ool00002Ool00`00
Ool00003Ool3002kOol000Eoo`8000Aoo`03001oogoo009oo`03001oogoo009oo`03001oogoo009o
o`<00;]oo`006Woo0`00^goo000JOol3002kOol001Yoo`800;aoo`006Woo0P00_7oo000JOol2002l
Ool001Yoo`800;aoo`006Woo0P00_7oo000JOol2002lOol001Yoo`800;aoo`006Woo0P00_7oo000J
Ool2002lOol000Aoo`D0009oo`<0009oo`03001oogoo009oo`03001oogoo009oo`800;aoo`001Woo
00<007ooOol00goo00H007ooOol007oo0002Ool00`00Ool00003Ool2002lOol000Ioo`04001oogoo
Ool4000017oo001oo`000Woo00<007oo00000goo0P00_7oo0006Ool01`00Oomoogoo001oo`00009o
o`03001oo`00009oo`03001oo`0000=oo`03001oogoo0;]oo`001Woo00<007ooOol00Woo0P000Woo
00<007oo00000Woo00<007oo00000goo00<007ooOol0^goo0005Ool20005Ool01@00Oomoogoo0000
17oo00<007ooOol0`7oo003HOol00=Qoo`00\
\>"],
  ImageRangeCache->{{{0, 215}, {132.438, 0}} -> {-36.7582, -154.768, 1.39203, 
  12.2687}}]
}, Open  ]]
}, Open  ]],

Cell["\<\
As a second example consider the histograms of an RGB color image. We compute \
a histogram for each of the channels.\
\>", "Text"],

Cell[BoxData[
    \(\(B = 
      ReadImage["\<beads.tif\>", "\<TIFF\>", 
        ImageOutput -> IntegerPlanarImageData]; \)\)], "Input",
  CellLabel->"In[30]:="],

Cell["\<\
Here we display the three color channels of the example image.\
\>", "Caption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[GraphicsArray[IntegerImageData[B]]]; \)\)], "Input",
  CellLabel->"In[33]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .3125 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.31746 0.00744048 0.31746 [
[ 0 0 0 0 ]
[ 1 .3125 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .3125 L
0 .3125 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.00744048 0.321429 0.30506 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00744048 0.0238095 0.00744048 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
384 string
128 128 8 [128 0 0 128 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
BE0000BF0000C00000BF0000BE0000BE0000C00000C10000C00000C00000BF0000C00000C10000\
C10000C00000C00000C10000C20000C30000C30000C20000C20000C20000C30000
C20000C20000C00000BF0000C00000C00000C10000C20000C30000C40000C10000B700009C0000\
6D00004C00004D00005100005200004D00005100005400005300005800005F0000
6500006400006800005600004B00004500004000003C00003E0000400000430000450000470000\
4E00005700006200006E0000820000A40000BE0000C20000C20000C20000C20000
C30000C30000C20000C10000C10000C20000C20000C20000C20000C20000C20000C20000C30000\
C20000C00000BD0000B90000B40000AD0000A500009F00009E0000A40000A80000
B00000B70000BB0000BF0000C20000C30000C20000C20000C20000C30000C30000C30000C10000\
C10000C00000C00000BF0000BE0000BE0000BF0000C10000C20000C20000C10000
C20000C20000C30000C30000C20000C10000C20000C30000
BE0000C00000C00000BF0000C00000BF0000C00000C10000C00000C00000C00000C00000C20000\
C20000C10000C10000C10000C20000C30000C30000C30000C30000C20000C20000
C10000BE0000B70000B10000AD0000AA0000AA0000AE0000B60000BC0000BD0000B10000900000\
5E00004800004C00004800004300004000004600004900004900004F0000520000
5700005400004C00004900004300003B00003500003700003C00004100004500004800004B0000\
5000005500005900006100007300008F0000B60000C20000C30000C20000C20000
C30000C40000C30000C10000C10000C00000C00000BF0000BF0000C10000C20000C40000C40000\
C20000BC0000B40000A400009000007C00006B00006700006B00007A0000870000
8F00009C0000A90000B50000BD0000C10000C20000C20000C20000C30000C30000C20000C00000\
BE0000BB0000B60000B10000AE0000B10000B60000BC0000BF0000C10000C00000
C20000C20000C30000C30000C20000C20000C20000C30000
BE0000C00000C00000C00000BF0000C00000C00000C20000C10000C10000C10000C10000C20000\
C30000C30000C20000C20000C40000C50000C40000C40000C40000C40000C10000
BA0000AC00009900008300007500006D00006F00007600008700009A0000A70000A10000810000\
5100004600004A00004000003D00003E00004100004200004600004A00004A0000
4E00004A00004400004100004000003600003200003500003D00004200004800004C0000500000\
5700005A00005700005A0000690000810000AA0000C10000C30000C30000C30000
C40000C40000C30000C00000BA0000B30000AC0000A60000A90000B30000BC0000C20000C20000\
BD0000AF00009700007900005D00005200005400005F00006700006D0000750000
7900008000008D00009E0000AF0000BC0000C10000C20000C30000C40000C40000C20000BD0000\
B40000A400009100008100008000008C00009B0000A80000B40000BC0000BF0000
C10000C10000C20000C30000C20000C20000C10000C30000
BE0000C00000C10000C00000BF0000C00000C10000C10000C20000C10000C20000C20000C30000\
C40000C40000C40000C40000C60000C70000C70000C50000C50000C20000B90000
A700008700006A00005500005100005500005D0000600000670000700000770000760000650000\
4900003E00003F00003900003A00003C00003E00004200004500004A00004D0000
4B00004800004300003D00003E00003500003100003700003C00004300004B0000510000590000\
6300006500005D00005900006200007800009D0000BF0000C40000C50000C50000
C70000C50000C00000B400009F00008700007600007200007B00008E0000A40000B20000B60000\
AB00008E00006B00005600004F00005500005D00005C00005900005900005A0000
5C00006200006A00007C0000900000A60000BA0000C20000C40000C50000C30000BE0000B00000\
9500007400005F00006300006C00007400007F00008C00009C0000AB0000B80000
BE0000C00000C20000C20000C20000C20000C10000C20000
BE0000C00000C10000C00000BF0000C00000C10000C30000C30000C20000C20000C30000C40000\
C40000C40000C40000C60000C70000C70000C80000C60000C40000BD0000AE0000
8D00006500005300004E00005300005500005300005300005500005700005800004E0000450000\
3C00003700003600003400003800003C00003F00004500004D00005A00005C0000
5000004800004400003F00004000003900003600003600003D00004200004B0000550000600000\
7A00008500007200006100006000007100008D0000BA0000C50000C60000C70000
C70000C10000B100009300006F00005C00005F00006600006A00007000008100008E0000910000\
8500006700005100004C00005200005A00005700004F00004900004A00004D0000
500000520000580000630000720000850000A20000BB0000C30000C40000C00000B40000950000\
6D00005600005B00006000005E00005C00006100006B00007A00008A0000A00000
B30000BE0000C20000C20000C10000C10000C10000C20000
BF0000C10000C00000C00000BF0000C00000C10000C30000C30000C20000C30000C30000C40000\
C50000C60000C50000C60000C70000C70000C90000C60000C20000B80000A00000
7300005500004D00004E00004A00004600004700004700004900004C00004E00004700003D0000\
3500003400002F00003200003700003B00004300004C00005B0000800000830000
5D00004D00004800004200004600004400003800003700003C00004400004D0000550000660000\
8A0000A600009500006C0000600000650000760000AC0000C10000C50000C60000
C30000B600009600006B00005600005800005C00005800005500005600005E00006700006C0000\
6000004C00004A00004E00005700005300004A0000440000410000410000430000
4700004800004E0000570000630000700000840000A30000BE0000C20000BA0000A20000750000\
5700005700005A00005400004E00004B00004E0000570000610000710000820000
9B0000B40000BF0000C20000C10000C10000C10000C20000
BF0000C00000C10000C00000C00000C10000C10000C30000C30000C20000C30000C20000C40000\
C50000C60000C50000C50000C70000C80000C80000C60000C10000B30000970000
6800005000004F00004600003F00003E00003F00004000004300004500004900004500003D0000\
3500003000003000003300003800003F00004A0000510000650000980000A10000
7300005200004D00004900005200006400004100003A00003E00004300004A0000540000630000\
800000A400009F00007200006200006300006700008B0000A60000B50000BD0000
BA0000A600007700005700005300005600005000004800004600004600004A0000500000560000\
5500004400004400004800004F00004800004100003E00003C00003D00003F0000
4100004200004400004C0000590000650000710000820000AC0000BE0000B40000900000620000\
5500005600005100004700004400004400004700004D00005300006000006E0000
8100009B0000B70000C10000C10000BF0000BE0000BE0000
BF0000C00000C00000C10000C00000C00000C20000C20000C30000C30000C20000C30000C40000\
C50000C50000C60000C60000C70000C80000C80000C60000C00000B30000940000
6400005100004C00003D00003800003C00003E00004000004300004600004800004400003F0000\
3A00003200003000003500003D00004D00005600005500006100008B00009C0000
7600005100005100005300006A00008F00006600004000003F00004300004900005100005C0000\
6B00008200008400006D00006100005F00005C00006A00007C00008E00009E0000
A100008800005B00004A00004F00004600004300004000004000004000004200004700004B0000\
4B00004000003B00004000004300003F00003C00003D00003C00003E0000420000
4300004200004200004600004B00005600006400006800008D0000B70000AD0000830000570000\
5000004600004200004100004000004400004800004C00005100005500005E0000
6F0000840000A50000BB0000BA0000B40000AC0000A70000
BF0000C00000C10000C00000BF0000C00000C10000C30000C30000C30000C30000C30000C40000\
C50000C50000C50000C50000C60000C70000C80000C60000C10000B600009A0000
6800004F00004900003A00003700003D00003F00004300004900004E00005000004A0000440000\
3C0000350000320000370000460000530000590000580000580000690000730000
5B00004E00005200005A0000880000AC00009500005900004300004400004900004E0000580000\
6100006700006900006400005D00005900005100005000005B00006400006E0000
6F00005E00004800004100004100003A00003E00003F00003E0000400000420000430000450000\
4300003D00003700003800003C00003C00003E00003F0000400000450000480000
4D00004F00004A00004700004700004D00005700005A0000770000B10000A900007D0000540000\
4B00003C00003A00003E00004100004500004A0000520000580000570000580000
6100007200008E0000A70000A200008C00007A0000760000
BF0000C00000C10000C10000C00000C10000C20000C30000C30000C30000C30000C30000C50000\
C50000C50000C50000C50000C60000C70000C70000C60000C10000B80000A20000
7400005400004700003700003800003C00004100004900005C00006700006E00006100004C0000\
4100003A00003500003800004300005500005B00005D0000560000550000570000
5000004E0000550000600000940000B40000AE00009200005B00004800004800004C0000550000\
5B00005C00005E00005D00005A00005600004700004000004600004C0000540000
5600004900004100003C00003800003600003A00003C00003D0000400000440000460000430000\
4000003B00003400003600003A00003C00003E00003E00004200004C0000550000
6A00007500006400005100004A00004C00005E00005900006E0000AE0000AA00007F0000550000\
4A00003800003A00004000004300004800005100005C00006900006A0000600000
5C00006400007500007E00007200006000006200006E0000
BE0000C00000C10000C10000C00000C10000C20000C30000C20000C20000C20000C30000C40000\
C50000C40000C50000C40000C50000C60000C60000C40000C20000BB0000AB0000
8900005C00004800003700003600003A00004100004F00006B0000760000850000770000560000\
4800004100003C00003C00004000004D00005900005800005100004F0000500000
4E00005100005800006200008400009C0000A50000A700009300006300004F00004F0000530000\
5600005900005B00005900005600004A00003D00003C00003E0000420000480000
4A00004300003B00003800003500003400003600003A00003D0000420000470000480000450000\
4000003B00003300003400003A00003B00003C00003E0000430000520000680000
940000A500008C00005E00004F00004D00005F0000610000710000B00000AF0000890000580000\
4900003900003B00003F00004400004C00005900006D00008F0000980000780000
6100005D00006100005E0000550000590000620000650000
BE0000C00000C00000C10000C00000C10000C10000C30000C30000C20000C20000C30000C40000\
C50000C40000C30000C40000C40000C50000C40000C20000BE0000B60000A80000
8900005E00004500003800003600003900004000004E00006A0000780000930000900000670000\
4E00004700004600004D00006600004D00004C00004B00004C00004E00004F0000
5100005800006200006800007C00008A0000950000A10000A900009F00007B00005F0000590000\
5A00005F00006000005600004900003E00003C00003C00003F00003F0000440000
4500004200003B00003600003500003400003700003A00003F00004600005400005D00004B0000\
4400003E00003B00003400003900003D00003D00003E00004300004F0000650000
940000A300008A00006100005200004B0000540000580000770000AE0000AC00008F00005C0000\
3F00003500003800003E00004400004B0000580000700000990000A900008B0000
6600005D00005B00005300004B00004A00004D0000500000
BF0000C00000C10000C00000C00000C10000C20000C30000C30000C20000C30000C40000C40000\
C60000C50000C40000C50000C40000C30000BF0000B60000A80000960000800000
6500004900003C00003800003500003700003E00004700005C00006800007C0000800000630000\
4F00004D00005200006B00009D00007D00004F00004C00004E0000500000520000
5800006000006E00008300009C0000A40000A80000AA0000AD0000B40000B300009F0000860000\
7400006D00006600004E00004000004500004000003E00003F00004600004D0000
4A00004400003C00003400003500003400003700003A00004100004B0000690000830000610000\
4C00004400003E00003900003E00004100004100004100004500004D0000570000
6C00007600006600005900005000004B00004D00005000006C00009200008F0000770000520000\
3A00003500003B00003E00004400004B00005600006700008000008E00007C0000
6600005C00005900004B00003A00003700003B0000440000
BF0000C10000C20000C20000C10000C20000C30000C40000C40000C40000C40000C50000C60000\
C70000C60000C60000C40000C20000BA0000AA00008E00007000005B0000520000
4800003D00003400003500003600003700003C00004200004A00005200005800005B0000540000\
4F00005000005600007E0000B40000AE00008D0000680000590000540000560000
5A0000640000810000A60000B50000BB0000BE0000BD0000BC0000BB0000BC0000C00000B70000\
A400008700007000004E00004A0000550000520000420000450000560000730000
6000004900003D00003400003500003200003700003A00004100004E0000730000980000800000\
5400004700004200004300006000005800004600004300004600004B00004F0000
5400005500005200004D00004D00004D00004C00004E00006200006E00006000004E00003F0000\
3600003400003A00004100004700004D00005500006100006A00006D0000670000
6200005700005300004200003000003100003A0000420000
BF0000C10000C20000C20000C20000C20000C30000C40000C40000C40000C50000C60000C70000\
C80000C70000C60000C20000B80000A50000810000610000510000500000530000
4800003B00003300003100003400003700003900003F00004500004900004900004C00004A0000\
4C00004E0000550000890000B80000BD0000B80000AA00009500007E0000650000
5F00006E0000990000B60000C10000C40000C60000C70000C50000C40000BF0000C20000C40000\
B800009C00007B00005100004800004F00004E00004400004C00007100009B0000
7700004E00003E00003300003200003200003500003900004000004D0000700000A600009E0000\
6100004700004700004D00008D00009700006100004A00004900004B00004D0000
4F00004D00004C00004C00004C00004C00004D00004800005200005A00005100004600003D0000\
3600003100003900004100004600004D00005400005B00005E00005F00005E0000
5900005400004E00003A00003000003800003E0000430000
C00000C20000C20000C20000C10000C20000C50000C50000C60000C50000C60000C70000C80000\
C90000C70000C40000BB0000A800008300005F0000510000520000500000490000
4100003A00003400003100003100003700003900003D0000420000410000440000450000470000\
4900004B00005100007300009D0000B40000BE0000BE0000B70000A200007D0000
680000770000A20000BB0000C50000CA0000CC0000CC0000C90000C90000C40000C00000C60000\
C10000AD00008C00005800004000003E00003E00004300004C00007000008C0000
6600004A00003E00003800003300003100003400003800003D00004800006A0000A200009C0000\
6200004800004A0000550000980000AF00009500006F00005E00005A0000550000
5400005000005200004E00004B00004800004300004000004700005100005300004B0000450000\
3D00003500003A00004100004700004F0000530000580000590000590000590000
5800005300004B0000390000380000460000450000440000
C00000C20000C20000C20000C20000C20000C40000C60000C60000C60000C60000C80000C90000\
C80000C70000C00000B100009200006A00005600005400005000004300003D0000
3B00003900003400003400003400003600003900003A0000400000410000420000440000460000\
4800004400004400005800006D00008C0000AA0000BB0000BB0000AE00008C0000
6D00007A0000A60000BC0000C70000CC0000CC0000CD0000CC0000CA0000C90000C20000C60000\
C50000B800009E00006700004400003C00003C00004100004800005500005C0000
5000004700004500004900003400003300003400003700003A00004500005A0000850000810000\
5900004600004700005200007F00009A00009B00009100008600007D0000720000
6900005E00005200004700004100004000004100004500004800004D00005300005100004C0000\
4900004100003C00004300004900005000005500005900005B00005C0000600000
5D00005500005200004100004600005000004C0000440000
C00000C10000C20000C30000C20000C30000C40000C60000C60000C50000C60000C80000C90000\
C90000C40000BA0000A400007B00005D00005500005300004400003A00003A0000
3800003800003700003800003800003800003800003600003C0000410000430000410000400000\
3D00003700003700003E00004600005500007200009D0000B80000B500009C0000
7B00007C0000A70000BE0000C70000CB0000CA0000CB0000CD0000CC0000CB0000C50000C00000\
BE0000B100009900006F00004A00003E00004000004400004500004800004A0000
4E00004F00006400006800004300003600003600003900003C00004200004C00005F0000600000\
4E00004400004800005400007000008600008F0000940000930000910000810000
6D00005B00004700003E00003F00004300004600004C00004C00004F0000560000540000520000\
5000004C00004800004700004E00005C00006100006400006A00006F0000780000
7400006100005A00004400004B00005400005700004A0000
C00000C20000C20000C20000C30000C30000C50000C60000C70000C60000C70000C90000CA0000\
C90000C30000B500009700006F00005A00005600004F00003E00003800003B0000
3A00003A00003C00003F00004000003D00003900003900004200004400004000003A0000350000\
3300003300003600003A00003C00004300004C0000620000990000B70000AC0000
910000800000A30000BD0000C80000CB0000CA0000CB0000CE0000CE0000CC0000C40000B10000\
A600009A00008A00007400005900004A00004800004600004500004700004D0000
5700007B00009900008B00005E00003E00003700003800003D00003F00004600004C00004D0000\
4600004500004E00005900007400008D0000980000A30000A90000AA0000A00000
8300005900004300003E00004200004700004B00004E00005200005500005B00005D00005D0000\
5800005300005000005400006000008E00009900009600009A0000A20000A50000
9700007300005B00004300004B00005400005400004D0000
C00000C20000C30000C30000C30000C30000C40000C70000C70000C70000C70000C80000CB0000\
C90000C20000B100009100006900005D00005600004300003800003800003A0000
3C00003F00004700005400004A00004000003C00003B0000400000440000410000380000340000\
3200003400003800003B00003C00004000004500004B0000690000AB0000B60000
A700008F00009B0000B90000C60000CC0000CC0000CA0000CD0000CE0000CB0000C20000A10000\
9600009800009300008800007E00007000006400005C00005700005B00006B0000
900000B00000B500009F00007400004B00003B00003800003A00003E0000410000450000460000\
440000480000560000620000880000A20000B00000BA0000BD0000BF0000B90000
A900007C00004F00004200004400004800004D00005300005500005E00006B0000760000750000\
650000590000560000590000620000990000B40000B20000B00000AD0000A40000
8F00007000005600003E00004300004800004800004D0000
C00000C20000C20000C20000C20000C20000C50000C60000C60000C60000C70000C90000CA0000\
C80000C20000B100009100006800005C00005100003C00003500003700003A0000
3F00004800006000008800006500004400003D00003A00003D00004200003B0000340000330000\
3400003600003800003C00004000004100004300004600005000008F0000B20000
A700008F00008C0000B20000C40000CB0000CD0000CD0000CF0000CE0000C90000BE00009E0000\
9F0000A40000A50000A50000A50000A400009E0000960000920000940000AA0000
BB0000BE0000B400009C00007300005400004200003B00003A00003B00003E0000410000420000\
4600005000005E00007A0000A10000B40000BD0000C20000C50000C60000C30000
BA0000A000006700004C00004800004C00004E00005200005900006600007900009700009E0000\
8100006900006000005D00005E00007B00009F00009C0000970000920000880000
7600006200005500004000003E00003F00004500004C0000
C00000C10000C20000C20000C10000C20000C40000C60000C70000C60000C70000C80000CA0000\
C80000C20000B400009600006F00005E00004E00003900003500003700003B0000
4100004B00006E00008F00006300004400003E00003A00003D0000400000360000320000340000\
3500003700003B00003E00004600004A00004400004400004A0000670000920000
870000730000740000A10000BF0000C90000CC0000CD0000CF0000CD0000C70000BA0000A60000\
AA0000AE0000B40000B60000B90000BC0000BD0000BC0000BA0000B80000BA0000
BD0000B50000A000008000006400005100004800003F00003B00003B00003C0000400000450000\
4D0000560000690000950000B20000BE0000C30000C60000C70000C90000C80000
C20000B200008600005900004C00004C00004D0000510000580000630000740000930000A30000\
9000007400006600006100005D00006600007D00008700009000009300008D0000
8100007200006700005100004900004500004800004D0000
C00000C20000C20000C30000C20000C20000C40000C50000C60000C70000C60000C80000CA0000\
C90000C40000BA0000A400007F00006700004F00003A00003800003D0000470000
4100004800005800006400004D00004000003C00003800004000003C0000340000340000360000\
3700003900004100004900006000006800004D00004500004400004A0000600000
5D00005F00006800008D0000B50000C20000CA0000CC0000CD0000C90000C20000B50000B00000\
B40000B90000BD0000C00000C20000C40000C60000C70000C50000C30000BF0000
B600009D00007F00006600005600004600003F00004000004000003E00003E00004400004B0000\
530000580000750000A40000BA0000C20000C50000C80000C90000CB0000CA0000
C70000BC0000A200007000005300004F00004F00005000005700005F00006500007500007F0000\
7B00006E00006500006300006300006400007900008800008F00009300009B0000
A10000A000009800008100006500005600004F0000510000
C00000C20000C30000C30000C20000C20000C40000C50000C60000C60000C60000C70000C90000\
CA0000C70000C10000B500009A00007B00005100003B00003D00004A0000530000
4D00004300004700004700004200003D00003C00003C0000400000360000330000330000340000\
3600003A00004500005700008C00008F00005A00004800004400004400004C0000
5600006A00007C0000900000AC0000BD0000C40000C60000C30000BB0000B40000B20000B60000\
BB0000BF0000C30000C50000C60000C70000CA0000CA0000CA0000C80000C30000
B800008F00006C00005E00004F00003A00003400003800003B00003D00003F0000430000490000\
4F0000580000840000AC0000BD0000C40000C70000C80000C90000CB0000CB0000
C90000C20000B200008F00006100005100005100005400005800005D0000600000650000650000\
650000630000620000640000640000620000740000820000950000A40000B10000
B80000BC0000BA0000B100009A00007800006200005C0000
C00000C10000C30000C20000C20000C20000C30000C50000C60000C50000C60000C60000C80000\
C90000C90000C70000C00000B300009B00006300003E00004500004F0000570000
5900004700004200004000003F00003E00003E0000410000410000340000320000330000350000\
3800003F00004700005B00009300008F00005800004600004500004200004A0000
5B00007E00009C0000AD0000B60000BF0000C20000BE0000AE0000960000A50000B10000B80000\
BF0000C30000C60000C70000C80000CA0000CC0000CC0000CC0000CB0000C60000
BC00009800006500005500004200003500003200003500003500003800003800003A00003D0000\
4A00005A0000900000B20000C00000C50000C70000C80000C90000CB0000CC0000
C90000C30000B700009800006E00005800005300005700006500006000005D00005D00005C0000\
5F00005E00005F0000620000600000620000790000950000AB0000B80000C00000
C60000C80000C90000C70000BC0000A800008800006F0000
BF0000C20000C10000C20000C20000C20000C30000C40000C50000C40000C50000C60000C80000\
C80000C80000C80000C50000C10000B300008B00004900004200004C0000550000
4F00004100004000003F0000400000420000470000490000420000360000340000350000370000\
3900003C00004300004F00006C00006A00004C00004300004500004300004C0000
6C0000960000AE0000BB0000C30000C60000C60000C00000AA00008E0000A70000B40000BC0000\
C20000C60000C80000C80000CA0000CC0000CD0000CE0000CE0000CD0000C80000
BF00009E00005B0000430000370000350000340000340000360000340000340000350000380000\
4100006000009B0000B60000C20000C60000C80000C90000CA0000CC0000CC0000
CA0000C20000B300008900006F00006300005C00005C00006E00006400005B00005900005A0000\
5F00005E00005E0000620000610000730000920000AD0000BB0000C30000C90000
CB0000CE0000D00000D00000CB0000C10000AD0000860000
BF0000C20000C10000C10000C10000C10000C30000C50000C50000C30000C40000C50000C70000\
C80000C80000C80000C80000C60000BF0000AA00006F00004800004300004B0000
4400004200004200004500004800004D00004E00004A0000410000360000370000360000360000\
3900003C00004000004800004F00004C0000440000420000430000440000590000
850000A50000B90000C20000C80000CA0000C90000C50000B600009A0000A90000B60000BE0000\
C40000C60000C80000C80000CA0000CB0000CE0000CF0000CE0000CD0000C90000
BF00009B00005600004200003900003600003800003B00003B00003A0000380000390000380000\
3E0000620000A10000B90000C20000C70000C80000C90000CA0000CD0000CC0000
CA0000C30000B100008F00008500008300007B00007100006E00006400006000005F0000600000\
6400006500006100006C00007100008A0000A60000B90000C40000CA0000CD0000
CF0000D10000D30000D40000D00000CA0000C000009D0000
BF0000C10000C20000C10000C00000C10000C20000C40000C50000C30000C50000C50000C60000\
C70000C80000C70000C70000C60000C00000B200008C00005F00004D0000490000
4600004900004E00005900006500006A00006100005000004500003D00003A0000350000380000\
3800003C00004100004600004700004300004100003F00004300004800006B0000
980000B10000BF0000C70000CB0000CD0000CB0000C90000BE0000A50000AE0000B80000C00000\
C50000C60000C80000C90000CA0000CB0000CE0000CE0000CE0000CD0000C70000
BD00008E00005400004400003A00003800003C00004200004600004600003E00003E00003B0000\
420000620000A20000BA0000C30000C70000C80000C90000CA0000CC0000CC0000
CA0000C40000B30000A90000AD0000B00000AA00009C00008B00007E0000760000720000720000\
7600007900007800008300008800009B0000B10000C00000C80000CC0000CE0000
D10000D20000D40000D40000D20000CD0000C60000AD0000
BF0000C10000C10000C10000C10000C10000C20000C40000C40000C30000C40000C50000C70000\
C70000C80000C70000C70000C30000B90000A400008000006500005A00005A0000
5C00006700007600008700009100009600009200007F00005C00004900003E0000360000350000\
3800003C00003F00004300004200004000004000004300004800005A0000780000
A10000B60000C00000C70000C80000C80000CC0000CA0000C30000AE0000AF0000B80000BF0000\
C50000C70000C90000C90000CA0000CB0000CD0000CE0000CE0000CC0000C60000
B700008100005400003F00003600003900004000004D0000670000780000540000410000400000\
4400006A0000A00000B80000C20000C60000C80000C80000C90000CB0000CB0000
CA0000C30000BC0000BF0000C20000C50000C20000BE0000B70000AE0000A30000A30000AA0000\
AC0000A900009C0000910000960000A60000B60000C20000CA0000CE0000CF0000
D00000CF0000CE0000D30000D20000CD0000C80000B50000
BF0000C10000C20000C10000C10000C10000C30000C40000C40000C40000C40000C50000C60000\
C70000C80000C60000C50000BE0000AC00008B00006D00006600006F0000760000
8200009000009E0000AA0000B00000B50000B40000AC00009300006700004C00003B0000380000\
3800003800003D00003F00004000004000003E00003E00004A00005A0000750000
A20000B80000C10000C80000C90000C80000CB0000CA0000C50000B10000AD0000B60000C00000\
C40000C70000C80000C80000C90000CB0000CD0000CE0000CC0000C90000C20000
AD00007A00004F00003B00003400003800004300005600007E0000950000640000430000420000\
4600007400009F0000B10000C00000C50000C60000C70000C90000CA0000CA0000
C80000C10000C40000C70000CB0000CC0000CB0000C90000C80000C70000C30000BC0000BF0000\
C10000BD0000B10000A100009F0000AE0000BA0000C40000CB0000CE0000CF0000
D00000CD0000CB0000D00000D10000CC0000C30000B00000
C00000C00000C10000C10000C00000C10000C30000C40000C30000C40000C40000C50000C60000\
C70000C70000C60000C20000BB0000A300007B00006A00007200008200008F0000
9C0000A70000B20000BA0000C10000C50000C50000C20000B600009700006A00004600003B0000\
3B00003D00003F00004000004100003E00003C0000380000420000460000640000
990000B30000C00000C80000CB0000CB0000C90000C80000C10000A400009B0000B00000BD0000\
C30000C70000C80000C90000C90000CB0000CC0000CE0000CC0000C80000BF0000
A100007A00005000003900003500003900004100004D0000620000740000550000410000430000\
4900006400008600009B0000B90000C40000C70000C70000C70000C80000C60000
C20000C30000C60000C90000CE0000CE0000CD0000CC0000CC0000CC0000CA0000C60000C00000\
C50000C30000BF0000B50000AA0000B00000BB0000C40000CA0000CE0000D00000
D20000D00000CE0000D10000CF0000C90000B40000A30000
BF0000C00000C10000C10000C00000C10000C20000C30000C40000C30000C30000C40000C70000\
C70000C70000C60000C30000B80000A000007900006B00008100008E00009E0000
AA0000B30000BB0000C20000C90000CD0000CE0000CB0000C50000B500009300006300003E0000\
3D00003E00004000004000003D0000380000350000320000350000390000480000
770000A30000BA0000C40000C90000C90000C60000BF0000AF0000870000850000A40000B90000\
C20000C60000C80000C80000C90000CA0000CC0000CD0000CB0000C80000BD0000
A500008300005400003B00003700003900003D00004400004900004A0000460000400000450000\
4B0000570000700000840000A90000C00000C50000C60000C50000BF0000B30000
B80000C20000C70000CA0000CE0000D00000CF0000CE0000CD0000CE0000CD0000CA0000C20000\
C40000C50000C40000C00000B50000AF0000B90000C30000C80000CD0000D00000
D20000D30000D20000D10000CC0000C20000A10000980000
BF0000C00000C00000C10000C00000C00000C20000C30000C30000C30000C30000C40000C60000\
C70000C60000C50000C30000BB0000A900008600007500008A0000970000A60000
B20000BA0000C00000C70000CC0000CC0000CE0000CF0000C90000BE0000A10000770000460000\
3C00003B00003900003800003600003400002F00002E00003000003300003A0000
4C00007B0000A20000B40000BE0000BD0000B60000A50000890000820000970000AC0000B80000\
C00000C60000C70000C70000C80000C90000CB0000CB0000CA0000C90000C20000
B400009800006100003E00003800003A00003E00003E00004200004100003F00004000004A0000\
4F00005B0000760000900000AB0000BE0000C40000C20000BC0000A900009B0000
B30000C10000C70000CB0000D00000D10000D00000CF0000CF0000D00000CF0000CD0000C60000\
BF0000BE0000BA0000B80000B60000AF0000B50000BF0000C60000CB0000CE0000
D00000D10000D20000D00000CB0000C10000B00000A20000
BE0000C00000C00000C10000C00000C00000C10000C20000C30000C20000C20000C30000C60000\
C60000C60000C60000C40000C00000B600009E00008900009000009D0000AD0000
B80000BF0000C40000C90000CD0000CC0000CD0000CF0000C90000BC00009D00007000004A0000\
4100003900003600003200003100003100003000002F00003200003300003A0000
4100005000006400007D00008F00009300008800007500007B0000990000B00000BA0000BF0000\
C20000C50000C60000C60000C70000C90000CA0000C90000C60000C90000C60000
BE0000AB00007800004800003A00003900003B00003C00003D00003E00003D0000470000500000\
540000690000920000AE0000BE0000C50000C80000C50000BF0000B100009D0000
B40000C10000C80000CD0000D00000D20000D10000D10000D10000D20000D20000CE0000C60000\
B200009B00009000008E00009300009F0000AA0000B70000BE0000C50000C90000
CD0000CE0000CF0000CE0000CA0000C80000C40000BE0000
BE0000BF0000C00000C00000C00000C00000C10000C30000C30000C20000C20000C30000C50000\
C60000C60000C50000C50000C50000C00000B50000A20000990000A10000B20000
BC0000C20000C60000CB0000CE0000CF0000D00000CE0000C50000B40000950000670000480000\
4200003800003400003400003200003200003000003000003300003400003B0000
4400004E00004700004600004D00005400005E0000680000890000AB0000BA0000BF0000C20000\
C50000C70000C80000C70000C80000C90000CB0000C90000C70000C60000C50000
BE0000AF00008700005300004100003900003B00003C00003C00003F00003F0000490000500000\
5E0000860000A90000BB0000C40000C70000C90000C80000C50000C00000AD0000
B70000C10000C80000CC0000D00000D20000D20000D00000CE0000D30000D30000CF0000C60000\
A800007800006D00006300005D0000680000800000970000A10000AD0000B80000
BF0000C60000CC0000CE0000CC0000CD0000CD0000CB0000
BE0000C00000C00000C00000BF0000C00000C00000C20000C30000C20000C20000C30000C50000\
C60000C50000C40000C50000C60000C50000C00000B80000AA0000A30000B30000
BD0000C30000C70000CB0000CE0000CF0000CF0000C90000BC00009A00007B0000590000450000\
3F00003A00003600003400003300003100003200003200003300003300003E0000
4600005100004B00003D00003E00004200005100006E00009C0000B40000BD0000C00000C30000\
C60000C80000C90000C90000C90000CA0000CC0000CB0000C80000C30000BB0000
AF00009D00008200006000004A00004300004100004000004300004500004400004B0000570000\
7400009E0000B70000C00000C60000C90000CA0000C90000C80000C60000BD0000
BA0000C10000C80000CD0000D00000D20000D10000CC0000CB0000D10000D50000CF0000C30000\
9D00006100005200004700004300004500004E00005D00006A00007800008F0000
A80000BF0000CB0000CE0000CE0000CE0000CF0000CF0000
BE0000BF0000C00000C00000BF0000C00000C10000C20000C20000C20000C20000C30000C50000\
C50000C50000C50000C60000C70000C70000C40000C00000B70000A90000B10000
BB0000C20000C60000CB0000CD0000CD0000CA0000BD00009E00006800005200004500003D0000\
3A00003900003600003500003400003300003000003300003300003400003A0000
3C00004100003F00003C00003E00004200004F00007C0000A90000B90000BE0000C00000C20000\
C60000C80000CA0000CA0000CB0000CC0000CD0000CC0000C80000BF0000A70000
9500008C00008200007500006900006300005E00005E00005D00005D0000550000570000690000\
900000AE0000BD0000C40000C80000CA0000CA0000CB0000CB0000C90000C50000
BF0000C20000C80000CC0000D10000D30000D30000D00000CE0000D30000D30000CD0000BC0000\
8700004800004100004000004300004600004900004C00004E0000620000800000
A80000C00000CA0000CE0000CD0000CE0000CF0000D00000
BE0000BF0000C00000C00000BF0000C00000C10000C10000C20000C20000C20000C30000C40000\
C50000C50000C60000C60000C70000C70000C40000BE0000B200009F0000A10000
AF0000B80000BE0000C20000C40000C00000B400009500006900005000004200003B0000390000\
350000370000340000360000350000340000340000340000360000370000370000
3800003B00003C00003E00004300004A0000510000810000AE0000BA0000BD0000BF0000C20000\
C40000C70000C90000CA0000CB0000CC0000CD0000CB0000C70000BD00009C0000
8E00009400009400009100009700009C00009D00009D00009B00009800008100006300007D0000\
A40000B80000C00000C60000C90000CA0000CB0000CB0000CB0000CB0000C90000
C30000C30000C80000CC0000D10000D30000D30000D40000D40000D50000D10000C80000B10000\
6C00004600004600004400004A00005400005200004D00004C00005C0000860000
AF0000C30000CD0000D00000CF0000D10000D20000D30000
BD0000C00000C00000C00000C00000C10000C20000C20000C30000C20000C30000C30000C60000\
C60000C60000C60000C70000C80000C60000C10000B300009A00007B0000710000
7F00008E00009700009B00009900008C00007300005300004300004000003E0000380000360000\
3300003300003400003500003700003600003600003700003E00003D00003F0000
4100004100004000004000004A00005200005B00008B0000AE0000B90000BD0000BE0000C00000\
C40000C70000C90000C90000C90000CA0000CC0000CA0000C60000BB0000980000
9D0000A30000A50000AC0000B50000B90000BE0000BF0000BD0000B80000A80000750000910000\
AF0000BC0000C20000C60000C90000CB0000CB0000CB0000CB0000CB0000CA0000
C40000BF0000C70000CC0000D00000D20000D30000D30000D40000D30000CE0000C10000990000\
5400004900004A00004E00005900006C00005F00005400005000005A00008E0000
B40000C50000CE0000D10000D10000D30000D40000D50000
BE0000C00000C00000C00000C00000C10000C20000C30000C30000C30000C40000C50000C70000\
C80000C80000C80000C90000C80000C40000BA0000A200007D0000610000580000
5700005100004D00004E00004E00004B00004A00004800003F00003F0000410000390000360000\
3300003300003500003600003700003800003900003B0000400000480000530000
6100006F0000560000450000500000580000700000A00000AD0000B80000BD0000BD0000C00000\
C40000C80000C90000C80000CA0000CA0000CB0000CA0000C50000B80000A60000
AB0000AE0000B60000BE0000C10000C40000C80000C90000C80000C40000BB00009200009F0000\
B40000BE0000C30000C60000CA0000CB0000CB0000CC0000CB0000CB0000C80000
BF0000AE0000C00000CA0000CE0000D00000D10000D20000D10000CE0000C50000AD00006C0000\
4800004800004C00005700007800009900007E00005C00005200005C0000920000
B70000C60000CE0000D10000D00000CF0000CF0000D50000
BE0000C00000C10000C10000C00000C10000C30000C30000C30000C30000C40000C50000C70000\
C80000C90000C90000C90000C80000C10000B100008E00006B00005B0000560000
5100004500003D00003C00003E00004200004700005100004900004800004800003C0000390000\
3300003300003400003500003800003800003900003C00003E00004C00005D0000
7F00009200006C00004700005000005900008A0000B20000B00000B40000BA0000BC0000C00000\
C40000C70000C80000C80000C90000CA0000CA0000C80000C20000B50000B10000
B30000B90000C10000C40000C60000C90000CD0000CC0000CB0000C90000C50000A80000A50000\
B70000BF0000C30000C70000CA0000CB0000CB0000CB0000CB0000CA0000C80000
BE0000AB0000B80000C80000CD0000CE0000CF0000D00000CF0000C90000B500008400004E0000\
450000460000510000630000930000AA00008400005D0000510000610000940000
B80000C60000CD0000D00000CF0000CB0000CB0000D40000
BE0000BF0000C10000C10000C00000C20000C30000C30000C30000C40000C40000C50000C70000\
C80000C90000C80000C80000C60000BE0000AA00008300006600005C0000570000
4B00004000003C00003A00003D00003F00004300005200005300004D00004700004300003F0000\
3900003500003700003800003B00003800003A00003B00003F0000450000500000
6100006C00005700004800004F00005C00009A0000B50000AF0000A70000B00000B90000BF0000\
C40000C70000C80000C80000C80000C80000C70000C30000B70000B40000B60000
BA0000BE0000C40000C80000CA0000CD0000CF0000CF0000CE0000CC0000C80000B80000AA0000\
B80000BF0000C40000C60000C90000CA0000CA0000CA0000C90000C90000C80000
C10000BD0000C10000C70000CC0000CE0000CE0000CD0000CA0000BF0000A000007400004F0000\
4500004600005200006400008900009200006C0000590000570000690000980000
B80000C60000CD0000D00000D10000CF0000CE0000D40000
BE0000C00000C00000C10000C00000C10000C20000C40000C40000C40000C40000C50000C70000\
C80000C90000C90000C80000C60000BF0000AA00008300006400005D0000530000
4200003C00003A00003A00003C00004100004300004B00004C00004E00005500005700004C0000\
4100003B00003800003A00003E00003A00003A00003E00003E0000420000450000
4700004800004800004B0000560000700000A30000A60000950000870000930000AB0000B90000\
C10000C50000C70000C70000C60000C40000BC0000A90000AC0000B40000B70000
BC0000C20000C70000CA0000CC0000CE0000CE0000CF0000D00000CD0000C90000C10000A80000\
B50000BE0000C30000C60000C70000C90000C90000C80000C80000C80000C70000
C50000C40000C50000C70000CB0000CB0000CB0000CA0000C70000C00000AD00008A00005F0000\
4D00004600004D00005900006500006400005800005700005D00006F00009C0000
B90000C70000CE0000D20000D20000D30000D30000D50000
BE0000C00000C00000C00000C00000C10000C30000C30000C40000C30000C40000C50000C70000\
C80000C80000C80000C90000C70000C10000AF00008D00006A00006000004A0000
3C00003A00003800003A00003C00004100004400004900005200006800008A00008D0000610000\
4700004000003E00003F00004300004000003F00003D0000400000420000460000
4500004400004800005100005E00008A00009800008700007500006F00007A00008C0000A80000\
BC0000C30000C60000C60000C40000BE0000A90000900000A80000B30000BB0000
C00000C50000C80000CC0000CC0000CA0000C90000CA0000CF0000CE0000C80000BD0000990000\
A90000BB0000C20000C50000C70000C80000C80000C60000C50000C40000C40000
C40000C50000C60000C80000CB0000CB0000CB0000CA0000C80000C60000BD0000A700007F0000\
6100004E00004E00005600005800005D00006200006700006700007200009F0000
BD0000C80000CE0000D10000D20000D30000D30000D40000
BE0000C00000C10000C10000C00000C00000C30000C20000C40000C30000C40000C50000C70000\
C80000C80000C80000C80000C80000C30000B900009F00007D0000650000470000
3A00003900003900003A00003D00004100004500004900005400007300009600008E00005F0000\
4700004300004600004500004C0000460000480000420000410000440000480000
4800004900004F00005200006400008400007A00006A00006B0000780000800000900000AC0000\
BC0000C40000C70000C70000C60000C10000B20000980000AB0000B40000BD0000
C30000C80000CB0000CD0000CC0000C90000C90000CE0000CF0000CB0000C10000A80000840000\
990000B40000C00000C40000C70000C80000C70000C40000BE0000B80000C10000
C40000C60000C60000C80000CA0000CB0000CB0000CA0000CA0000C90000C60000BC0000A70000\
7F00006300005800005E0000650000770000890000960000910000800000A30000
BE0000C90000CF0000D10000D30000D30000D30000D40000
BE0000C00000C00000C10000C00000C10000C20000C30000C40000C30000C40000C50000C60000\
C80000C70000C80000C90000C90000C80000C10000B400009B0000760000480000
3B00003A00003A00003B00003E00004100004300004500004900005800006600006100004E0000\
4300004300004300004600004B00003C00003E00003F00003F0000420000450000
4900004D00004F0000510000510000600000600000620000730000800000880000A50000B80000\
C00000C60000C80000C80000C70000C50000BF0000A80000AF0000B70000C00000
C60000CA0000CE0000CF0000CF0000CF0000D10000D10000CC0000C50000B300008800008B0000\
A60000B70000C00000C40000C60000C70000C50000C10000B10000AE0000C00000
C40000C50000C70000C90000CA0000CB0000CA0000CA0000CA0000CB0000C90000C40000B90000\
9F00007C00007600007E00008E0000A30000B00000B70000B60000A80000A70000
BE0000CA0000CE0000D10000D30000D40000D40000D50000
BF0000C00000C10000C10000C10000C00000C30000C30000C30000C30000C40000C50000C60000\
C70000C80000C70000C80000C90000C90000C60000BD0000AD00008B0000500000
3F00003B00003C00003C00004000003F0000410000410000420000460000480000490000470000\
4200004300004100004900004600003700003600003800003B00003F0000430000
4800004F00005200005100004D00005100005700006200007500007E00009A0000B30000BE0000\
C30000C70000C90000C80000C90000C80000C50000B60000B30000B90000C00000
C80000CC0000CE0000CE0000CF0000CE0000CF0000C90000C20000B500009100007D0000A00000\
B70000C00000C30000C60000C80000C80000C60000C30000BC0000B30000BF0000
C30000C50000C70000C80000CA0000CB0000CA0000CA0000CA0000CB0000CA0000C80000C10000\
B40000980000A00000A70000B20000BA0000BE0000C20000C30000C00000BA0000
C00000C80000CE0000D10000D20000D40000D40000D50000
BE0000BF0000C00000C00000C00000C10000C20000C30000C30000C30000C30000C40000C70000\
C70000C80000C70000C80000C90000C80000C40000B90000A400008000005B0000
4300003D00003F00004000003E0000410000400000400000410000410000440000440000470000\
4500004700004A00005000004400003800003700003800003E0000430000490000
5200005E00005B00005500005000004C00005400005D00006D00008F0000AE0000BB0000C00000\
C50000C70000C90000C90000C90000C90000C80000C10000B80000BB0000C10000
C80000CC0000CE0000CE0000CE0000CE0000CC0000C20000B000008D00006E0000850000AE0000\
BE0000C20000C50000C60000C80000C80000C70000C50000C30000C00000C10000
C30000C40000C60000C70000C90000CA0000C90000CA0000CA0000CB0000CB0000C90000C50000\
BE0000AF0000B50000BA0000BE0000C20000C40000C60000C70000C80000C60000
C50000C90000CD0000CF0000D10000D20000D40000D00000
BE0000C00000C00000C00000BF0000C10000C20000C30000C40000C40000C40000C40000C70000\
C80000C80000C80000C80000C80000C40000BA0000A300008400006B0000640000
5500004600004400004200004000004100004100003F00003F00004100004700004B0000510000\
5700006400006000004F00004100003900003600003900003E0000480000540000
6500008900007100005A00005000004500004D00005D0000800000A70000B90000BF0000C20000\
C70000C90000CA0000C80000C90000CA0000CB0000C70000BF0000BE0000C30000
C70000CB0000CD0000CC0000CB0000C60000BA0000A500007F00005E0000600000860000B10000\
BF0000C20000C50000C70000C80000C80000C70000C60000C50000C40000C20000
C30000C30000C40000C60000C80000CA0000C90000C80000C90000CA0000CA0000CA0000C70000\
C20000BC0000BE0000C20000C30000C50000C60000C80000C90000CB0000CA0000
C90000C90000CC0000CD0000CE0000CE0000CC0000C60000
BE0000C00000C00000C10000C00000C00000C20000C30000C40000C40000C40000C50000C70000\
C80000C80000C80000C80000C50000BB0000A500008500007200007500007E0000
7B00006B00005900004E00004A00004700004500004300004300004600004D00005C0000710000\
8900009800009100007200004600004000003700003B00004000004C00005B0000
7300009C00008000005B00004E00004000004900006B0000990000B50000BF0000C20000C50000\
C80000C90000CB0000CA0000CA0000CB0000CB0000C90000C30000BA0000BE0000
C10000C20000C30000BE0000B40000A300008500006400005100004A0000560000850000B20000\
BF0000C30000C50000C60000C80000C90000C70000C70000C60000C60000C40000
C10000C20000C40000C60000C80000C90000C90000C80000C90000CA0000CA0000C90000C60000\
C20000BF0000C10000C40000C50000C60000C70000C80000CB0000CB0000CB0000
CA0000C90000C50000BE0000BC0000B80000AE00009C0000
BE0000C00000C10000C00000C00000C00000C20000C30000C40000C40000C40000C50000C70000\
C70000C80000C60000C50000BF0000AD00008D00007600007900008E0000990000
A50000A400009A00008B00007B00006B00005F00005500004C00005400006B0000890000A50000\
B20000B50000B000009E00006800004800003B00003E00004400004D0000590000
6B00008000006F00005900004D00003D0000500000810000AA0000BC0000C10000C40000C60000\
CA0000CB0000CC0000CC0000CB0000CC0000CB0000C80000BF0000A600009B0000
9B00009600008B00007E00006E00005E00005000004800004900004800004C00007E0000B10000\
BF0000C20000C50000C60000C80000C80000C70000C70000C70000C70000C30000
BA0000BF0000C20000C50000C70000C90000C80000C90000C80000CA0000CA0000C80000C50000\
BA0000BD0000C20000C50000C60000C60000C70000CA0000CC0000CC0000CB0000
CB0000C90000C10000A900008E00007700006800005D0000
BE0000C00000C10000C00000C00000C10000C20000C30000C40000C40000C40000C50000C80000\
C70000C70000C50000C10000B700009D00007D0000730000880000990000A80000
B50000BB0000BE0000BE0000B80000AB0000A000009100006900007A00009A0000AF0000BC0000\
C00000C20000C00000B600009800005E00004300003F00004400004C0000530000
5C00006200005E00005300004D00004000005D0000930000B20000BE0000C30000C50000C70000\
CA0000CC0000CD0000CC0000CC0000CC0000CB0000C60000B600009500007C0000
7000005D00005000004A00004A00004D00004C00004800004600004800004A0000700000AC0000\
BE0000C30000C50000C60000C90000C90000C80000C80000C70000C50000C10000
AB0000B50000BF0000C30000C70000C80000C80000C80000C80000C90000C80000C50000BE0000\
AA0000B80000C00000C40000C50000C60000C60000C90000CB0000CC0000CC0000
CB0000C90000C00000A700007C00005E0000560000540000
BE0000BF0000C00000C00000C00000C10000C20000C40000C40000C40000C40000C50000C70000\
C80000C70000C40000BF0000B100009300007700007900009000009F0000B00000
BC0000C10000C40000C60000C70000C00000BE0000B10000830000970000AD0000BB0000C20000\
C50000C90000C90000C30000B300008800005800004000004500004B0000510000
5600005900005700005400004E00004800006900009D0000B80000C10000C50000C70000C90000\
CB0000CC0000CD0000CE0000CD0000CD0000CA0000C10000A70000870000710000
6700005200004F00004800004600004C00005100004C00004900004500004800005C0000A00000\
BB0000C10000C40000C60000C80000C90000CA0000C90000C80000C60000C00000
A60000A70000BA0000C10000C50000C70000C70000C80000C80000C80000C50000C00000B40000\
9F0000AE0000BD0000C20000C40000C60000C60000C90000CB0000CC0000CC0000
CC0000C90000C10000AB00008000005E0000590000520000
BE0000C00000C00000C00000C00000C10000C20000C30000C40000C40000C40000C50000C70000\
C70000C70000C30000BC0000AC00008B0000770000830000940000A40000B40000
BD0000C40000C60000C80000CB0000C80000C70000BE00009C0000A20000B50000C10000C70000\
CA0000CC0000CD0000CB0000C20000AC00007B00004F00004700004B00004D0000
520000540000550000580000560000660000770000A40000BB0000C30000C60000C70000C90000\
CC0000CD0000CE0000CD0000CD0000CC0000C80000BD0000A100007E0000680000
5900004F00004E00004500004500004800005100004E00004B00004A0000490000520000900000\
B70000C10000C40000C60000C90000CA0000C90000C90000C80000C70000C10000
B20000B60000BF0000C10000C40000C60000C60000C60000C50000C30000BD0000AF0000990000\
840000960000B70000C10000C40000C60000C50000CA0000CC0000CB0000CC0000
CB0000C90000C10000AC0000810000620000580000530000
BF0000BF0000C00000C00000C00000C00000C20000C30000C30000C30000C40000C50000C60000\
C80000C60000C30000BB0000AA0000880000760000880000960000A50000B50000
BE0000C60000C90000CB0000CE0000CD0000CA0000C30000AD0000A90000B60000C10000C60000\
C90000CB0000CC0000CE0000CB0000C00000A600007200004D00004A00004D0000
4E00005400005A0000610000640000830000860000A60000BB0000C30000C70000C80000CA0000\
CC0000CD0000CE0000CD0000CC0000CC0000C90000C00000B30000960000670000
5500004D00004A00004700004A00004C00005C00006700005500004E00004B0000500000760000\
AB0000BE0000C40000C70000C90000CB0000CB0000CA0000CA0000CA0000C40000
C40000C70000CB0000CC0000CE0000CD0000C90000C60000C00000B90000A600008D0000750000\
670000700000A50000BD0000C30000C50000C50000CA0000CC0000CC0000CB0000
CB0000C80000C30000AA00008100006C00005D0000560000
BE0000BF0000C00000C00000BF0000C00000C10000C20000C30000C20000C30000C40000C60000\
C70000C60000C30000BC0000AD00008D00007900008D0000960000A80000B90000
C20000C70000C90000CA0000CE0000CE0000CA0000C20000B00000A20000B10000BD0000C20000\
C80000CB0000C80000CB0000CE0000C80000B900009600006000004C0000500000
5800006200007100007B00008400008B0000910000A60000B90000C30000C60000C70000C90000\
CB0000CC0000CD0000CC0000CB0000CA0000CA0000C60000BF0000AE00007C0000
5D00004E00004400004800004C00005200007300009100006800004D00004C0000520000670000\
960000B80000C20000C70000C90000CA0000CB0000CA0000CA0000C80000C60000
CB0000CF0000CF0000D10000D40000D50000D20000CD0000C30000A700008B0000740000610000\
5000005000007D0000B10000BF0000C20000C50000C90000CB0000CB0000CA0000
CA0000C90000C60000B400009D00008B0000770000670000
BD0000BF0000C00000BF0000BF0000C00000C10000C20000C20000C20000C30000C50000C60000\
C70000C60000C40000BF0000B300009B0000820000900000980000AC0000BC0000
C40000C80000CB0000C90000CD0000CF0000CA0000BD0000A100007B0000960000B60000C30000\
C80000CB0000CD0000CF0000CF0000C80000BB00009100006B00005900005B0000
6E0000850000980000A80000B00000AD0000A80000AD0000B80000C20000C50000C70000C80000\
CA0000CB0000CC0000CB0000CA0000CA0000CC0000CB0000C60000BD00009D0000
7000005300004100004100004700005100006D00008C00006E00005000004F00005B00006A0000\
870000AE0000BF0000C50000C90000CA0000CA0000C80000C60000BF0000C50000
CC0000D00000D30000D40000D60000D70000D40000D00000C50000A300007800006300004E0000\
4400004700005800008C0000B30000BE0000C30000C70000C80000C90000C80000
CA0000C90000C80000C30000BC0000B40000A50000930000
BD0000BE0000BF0000BF0000BF0000C00000C10000C30000C30000C20000C20000C40000C50000\
C60000C60000C50000C30000BC0000AD0000950000940000990000AD0000BC0000
C50000CA0000CD0000CE0000D00000CF0000C80000B900008B00005C0000630000930000B60000\
C20000C80000CC0000CE0000CD0000C40000B000008000006B00006B00007A0000
9B0000B10000BD0000C20000C20000BF0000BD0000B70000B70000BC0000C10000C40000C60000\
C80000C90000CA0000CA0000CA0000CB0000CD0000CC0000CA0000C40000B40000
8A00006400004600004100004500004A00005700006300005C00004F00005400006900007C0000\
9C0000B50000C10000C50000C80000CA0000C80000C20000B70000B90000C30000
CB0000CF0000D30000D50000D80000D80000D60000D00000C60000A500006400004D0000430000\
4400004600004C00005B00008A0000AE0000BD0000C10000C50000C60000C70000
C80000C90000C90000C90000C70000C40000C00000B90000
BE0000BF0000BF0000BF0000BF0000C00000C10000C20000C20000C20000C20000C40000C50000\
C60000C60000C50000C40000C20000BC0000AF0000A100009C0000AD0000BB0000
C40000CB0000CD0000CE0000D10000CE0000C50000B200006F00004800004A00005B0000860000\
AA0000BA0000C10000C20000BD0000B200009800007400006E00007C00009C0000
B50000C10000C80000CB0000CB0000C80000C60000C20000B70000A20000A90000B50000BB0000\
C10000C50000C90000CA0000CB0000CC0000CD0000CE0000CC0000C80000BF0000
A200007800004D00004100004400004900005100005300005300005100005E00007A0000960000\
B10000BF0000C50000C80000CB0000CB0000C80000BF0000AA0000B70000C10000
CC0000D00000D30000D60000D40000D80000D60000D10000C50000A30000570000490000460000\
4500004D00005000005300005900007700009B0000B10000BD0000C10000C10000
C40000C80000CA0000CB0000CA0000C90000C80000C60000
BD0000BF0000BF0000BE0000BE0000BF0000C00000C20000C20000C10000C20000C30000C40000\
C50000C60000C50000C50000C50000C30000BD0000B30000A40000AC0000BA0000
C50000C90000CC0000CC0000CF0000CB0000BF00009F0000530000430000450000470000510000\
6400007C00008700008800007D00008400008D0000730000730000870000AD0000
C00000C70000CC0000CF0000CF0000CE0000CB0000C60000BC0000900000890000A30000B30000\
BE0000C50000C80000C90000CB0000CB0000CD0000CE0000CD0000CA0000C30000
AF00007F00005B00004300004200004800004D00004C00005000005800006E0000890000AC0000\
BD0000C40000C80000CA0000CC0000CC0000CA0000C40000B00000B80000BF0000
CB0000D00000D30000D30000CF0000D50000D70000D10000C50000A000005300004A0000460000\
4700004C00004B00004C00004B00004C00005B0000700000880000970000A70000
BF0000C70000CA0000CB0000CB0000CA0000CB0000C90000
BD0000BF0000BF0000BE0000BF0000BE0000C10000C10000C10000C00000C20000C20000C30000\
C50000C50000C50000C50000C60000C60000C40000BF0000B30000AC0000B80000
C10000C80000CA0000CB0000CA0000C30000B00000750000450000470000460000450000470000\
4F00005500005700005800005800005E0000810000750000720000900000B60000
C30000C90000CD0000D00000D00000CF0000CE0000CB0000C20000980000950000A90000B60000\
C00000C50000C90000CA0000CA0000CB0000CE0000CE0000CD0000CA0000C10000
AE00006C00005A00004F00004700004800004B00004C00005200005F0000720000960000B70000\
C20000C70000C90000CB0000CD0000CE0000CC0000C80000BA0000BB0000C20000
CC0000D20000D40000D50000D20000D80000D80000D10000C30000950000550000500000470000\
4B00004800004B00004F00004F00004800004700004B00005500006F0000990000
BC0000C60000CA0000CB0000CB0000CB0000CB0000CB0000
BC0000BF0000BE0000BF0000BE0000BE0000C00000C10000C10000C10000C10000C20000C30000\
C40000C40000C40000C40000C60000C70000C60000C40000C00000B80000B80000
BE0000C50000C70000C70000C30000B400008D00004D00004200004400004400004600004A0000\
5100005A00005900005400005600005500007E00007E0000760000930000B90000
C60000C90000CD0000D00000D00000CF0000CE0000CC0000C600009F0000A10000B00000BA0000\
C20000C60000C90000CA0000CA0000CC0000CE0000CF0000CD0000C80000BE0000
9F00005100004400004800004900004C00004D00004F00005400005A00006D00009F0000BB0000\
C40000C70000C90000CC0000CE0000CE0000CC0000CB0000C20000BE0000C30000
CD0000D20000D50000D70000D80000DA0000D60000CE0000BF0000880000530000560000510000\
4800004B00005500005C00005800004A00004600004A00004B0000670000980000
BA0000C50000C90000CB0000CB0000CB0000CC0000CC0000
BC0000BE0000BE0000BE0000BE0000BE0000BF0000C00000C00000C00000C10000C00000C20000\
C30000C30000C30000C30000C40000C60000C50000C40000C40000C20000C00000
C00000C10000C10000BE0000B900009F00007300004700003D00003F0000440000480000500000\
6100008100006900005800005700005C00008F00008A00007B0000930000B80000
C50000C90000CC0000CD0000CC0000CC0000CE0000CD0000C90000A90000AB0000B60000BE0000\
C40000C70000C90000CA0000CB0000CC0000CD0000CF0000CC0000C50000B70000
8500004600003E00003B00003E0000440000480000480000470000480000720000A80000BF0000\
C50000C80000C90000CB0000CE0000CD0000CD0000CB0000C70000C30000C40000
CC0000D20000D40000D60000D80000D80000D40000CA0000B40000830000550000510000430000\
4500004F00005E00008000007700005300004900004D00004C0000650000950000
B90000C50000C80000CA0000CB0000CA0000CB0000CC0000
BD0000BE0000BD0000BE0000BD0000BE0000BE0000C00000BF0000BF0000C00000C00000C10000\
C10000C10000C10000C10000C30000C30000C30000C20000C20000C20000C30000
C20000C00000BD0000BB0000B60000A400007F00004700003700003B00004300004A0000550000\
7000008F00006B00005500005B00006E0000A400009D0000880000900000B40000
C40000C80000CB0000C80000C90000C90000CE0000CF0000CA0000AF0000B10000BA0000C10000\
C60000C80000CA0000CA0000CB0000CC0000CE0000CE0000C90000BF0000A40000
6300004600004000003D00003D00003E00004100004000004000004400007B0000AE0000C00000\
C70000C80000C90000CB0000CD0000CE0000CC0000CC0000CA0000C80000C60000
CB0000D10000D40000D60000D70000D70000D00000C50000A600007F0000580000460000400000\
4500004F00006300009300009700006300004B0000520000510000660000910000
B60000C40000C80000CA0000CA0000CA0000CA0000CB0000
BC0000BD0000BE0000BE0000BD0000BD0000BE0000BF0000BF0000BF0000BF0000BF0000C10000\
C10000C10000C10000C10000C20000C30000C30000C30000C20000C20000C30000
C30000C00000BB0000B30000A500008E00006C00004800003800003A00004500004A0000640000\
700000700000590000580000600000940000B20000AA0000960000880000AE0000
C20000C70000CB0000CC0000CA0000CD0000D00000CF0000CB0000B30000B00000BB0000C10000\
C60000C90000CB0000CB0000CC0000CC0000CD0000CA0000C30000AE0000780000
4E00004800004300004200004300004500004700004400004400004400007A0000AF0000C10000\
C60000C70000C90000CA0000CC0000CD0000CC0000CC0000CB0000CA0000C90000
CA0000CE0000D20000D50000D50000D20000C90000B400009800008200005F00004800003E0000\
4300004B00005700007400008000006200004D00004C00005500006700008B0000
B20000C20000C70000C80000C90000CA0000CA0000CB0000
BC0000BE0000BE0000BE0000BC0000BD0000BE0000C00000BF0000BF0000C00000C00000C20000\
C20000C10000C20000C20000C30000C50000C40000C40000C40000C40000C30000
C00000B60000A400008900006E00005800004600003A00003500003900004200004E0000600000\
6900005B00005600005C00007A0000A60000AA00009F00008D00007B0000A00000
BC0000C50000CB0000CD0000D00000D10000CE0000D00000CC0000B70000B00000BC0000C20000\
C70000CA0000CB0000CA0000CC0000CC0000CA0000C30000B00000810000510000
4800004500004400004900005B0000600000510000490000470000490000700000AC0000C00000\
C50000C70000C80000C90000CB0000CC0000CB0000CB0000CB0000CB0000CB0000
C90000CB0000CC0000CF0000CD0000C60000B80000A30000920000820000690000520000410000\
4100004600004E00005700005D00005500004C00004B00005700006E0000890000
B00000C00000C60000C90000C90000C90000C90000CA0000
BC0000BE0000BF0000BF0000BE0000BD0000BF0000C00000C00000C00000C00000C00000C20000\
C30000C30000C30000C40000C50000C60000C60000C60000C60000C40000C10000
B400009A00007700005F00005100004E00004000003400003200003300003D0000470000530000\
5C00005500005800006C00008A00008B00007E00007100006800006900008F0000
B30000C10000C80000CB0000CB0000CE0000CC0000CE0000CA0000B30000AD0000BB0000C10000\
C70000C90000CB0000CA0000CB0000CA0000C40000B200008800005C0000490000
4100004200004600005500008700008F00006500004B00004B00004B0000720000A80000BE0000\
C40000C60000C80000C90000CA0000CB0000CA0000CA0000CA0000CA0000C90000
C50000C00000BA0000BB0000BB0000B80000B30000AD0000A500009B00008000006500004B0000\
4200004300004800004C00004F00004D00004900004F0000680000980000A90000
B50000C00000C50000C80000C90000C90000C90000C90000
BC0000BE0000BF0000BF0000BD0000BD0000BF0000C10000C10000C00000C00000C00000C20000\
C30000C30000C40000C50000C60000C70000C70000C70000C60000C20000B70000
9B00007500005F00005900005100004300003A00003300003200003000003300003B0000440000\
4A00005200006800007600006D00006100005B00005B00006000006400007C0000
A50000BB0000C40000C90000CA0000CB0000C90000CB0000C70000BB0000BC0000BF0000C30000\
C70000C90000CA0000CA0000CA0000C80000C30000B300008A00006200004D0000
3F00004000004200005100007500007900005B00004A00004E00005200008E0000AB0000B60000\
C10000C30000C70000C90000C90000C90000C90000C80000C70000C80000C50000
BE0000B30000AE0000B00000B50000B60000BA0000BD0000BE0000BB0000AD00008F0000660000\
4B00004300004600004700004700004900004E00005900008B0000B60000C00000
C20000C40000C60000C70000C80000C80000C70000C40000
BC0000BE0000BE0000BF0000BE0000BE0000BF0000C00000C00000C00000C00000C10000C30000\
C40000C40000C40000C40000C60000C70000C80000C70000C60000BF0000AD0000
8500006700006000005800004900003E00003900003600003600003400003500003800003A0000\
3E00004D00005E00005B00005600005600005D00007000007600007E0000890000
9F0000B50000C00000C50000C70000C60000C40000C20000BE0000C00000C30000C30000C60000\
C80000CB0000CB0000CB0000CB0000CB0000C80000C00000AC00007F00005C0000
4200004000004400004600005100005300004D00004900005400006D00009D00009C00009C0000\
B40000C00000C50000C70000C80000C90000C70000C50000C40000C40000C00000
B50000A90000A90000B30000B60000BD0000C20000C40000C60000C70000C30000B60000990000\
7000005000004800004700004900004D0000570000750000AC0000C20000C60000
C80000C90000C80000C70000C40000C20000BD0000B10000
BC0000BD0000BE0000BF0000BE0000BE0000BF0000C10000C10000C00000C10000C00000C30000\
C40000C40000C40000C50000C70000C80000C90000C80000C50000BC0000A50000
7900006500005C00004900004100003C00003A00003A00004100004000003800003B00003A0000\
3900003C00004400004600005100005900006A0000840000990000A70000AD0000
B40000BA0000C00000C30000C20000BB0000A80000A80000B80000C10000C30000C50000C60000\
C90000CA0000CC0000CB0000CC0000CC0000CC0000C80000BF0000A50000760000
5200004100004400004100004600004700004900004B00005D00008200009100007600006F0000\
8E0000AF0000C00000C60000C80000C90000C70000C60000C40000C20000B90000
AA0000A30000AB0000B50000BB0000C20000C50000C70000C80000CA0000CA0000C60000BB0000\
A400007E00005E0000520000560000600000750000A00000BE0000C80000C90000
CB0000CC0000CB0000C50000B000009F0000910000740000
BC0000BE0000BF0000BE0000BE0000BE0000C00000C00000C10000C00000C00000C10000C30000\
C40000C40000C40000C60000C70000C80000C80000C70000C40000BC0000A50000
7C00006600005200004000003800003A00003C00004400004700004900004100003E00003D0000\
3A00003B00003C00003F00004C00005C0000830000A40000B40000BD0000C20000
C50000C80000C90000C50000BE0000B10000870000A10000B80000C00000C30000C60000C70000\
C90000CA0000CC0000CB0000CB0000CC0000CD0000CC0000C60000BA0000990000
6900004900004200004100004100004200004700004900005900006C0000660000560000590000\
740000990000B80000C40000C90000C90000C80000C80000C60000C40000BD0000
AA00009F0000AF0000B70000BF0000C40000C60000C70000C90000CA0000CB0000C90000C50000\
BF0000AF00009500007900007B00008C0000A10000BB0000C60000CA0000CC0000
CD0000CE0000CB0000C100009D00006F00005A0000490000
BC0000BE0000BE0000BF0000BE0000BE0000C00000C10000C00000C00000C00000C10000C30000\
C40000C30000C40000C60000C70000C70000C80000C70000C50000BE0000AC0000
8900006D00004E00003A00003900003A00003C0000430000460000450000480000410000400000\
3D00003B00003A00003D00004600006800009D0000B40000C00000C60000CA0000
CB0000CE0000CE0000CC0000C90000C00000A40000A80000B90000C00000C30000C50000C70000\
C90000CB0000CC0000CB0000CC0000CC0000CD0000CD0000CA0000C30000B10000
830000520000450000420000410000410000430000410000440000470000450000470000570000\
780000A30000BB0000C40000C80000C90000C90000C80000C70000C60000C30000
B90000A40000B40000BA0000C10000C50000C60000C80000C90000CB0000CB0000CA0000C80000\
C40000BD0000A800009900009E0000AA0000B60000C30000C90000CC0000CD0000
CE0000CE0000CB0000C000009300005F0000520000460000
BC0000BD0000BD0000BE0000BE0000BE0000C00000C00000C00000BF0000BF0000C10000C20000\
C30000C30000C30000C50000C60000C70000C80000C80000C70000C20000B80000
9F00007C00005000003800003700003700003800003900003C00004000004600004E00004D0000\
4300003D00003E0000400000460000800000AD0000BD0000C50000CB0000CD0000
CE0000CF0000D00000CF0000CD0000C80000BC0000AF0000B70000BE0000C20000C40000C60000\
C90000CA0000CB0000CB0000CC0000CD0000CF0000CE0000CC0000C50000B70000
8500004A00003E00003A00003B00003900003A00003900003900003900003E0000410000550000\
880000B00000C00000C60000C80000CA0000C80000C80000C80000C80000C60000
C10000B10000B80000BD0000C20000C50000C70000C80000C90000CB0000CC0000CB0000C90000\
C60000C20000B00000A40000AC0000B50000BF0000C80000CB0000CD0000CE0000
CF0000CF0000CA0000BE0000880000600000520000490000
BB0000BD0000BE0000BE0000BD0000BE0000C00000C00000C00000BE0000BF0000C00000C20000\
C30000C30000C30000C40000C50000C60000C70000C70000C70000C50000C00000
B200009700006100003A00003600003600003700003700003A00003D00004B00005D00007A0000\
680000450000420000420000480000880000B20000C00000C60000CB0000CB0000
C70000CD0000D00000CF0000CF0000CC0000C50000B30000B60000BB0000C00000C40000C60000\
C80000CA0000CB0000CB0000CC0000CC0000CE0000CE0000CB0000C50000B70000
8100004600003D00003700003600003800003E00003E00003D00003C00003D00003F0000530000\
940000B70000C20000C60000C90000C90000C90000C80000C80000C80000C70000
C50000BC0000BA0000BE0000C30000C60000C70000C80000C90000CB0000CC0000CB0000CA0000\
C80000C50000B70000B10000B70000BD0000C50000CA0000CD0000CE0000CE0000
D00000CE0000C90000BA00008100006200004F0000480000
BC0000BD0000BE0000BE0000BE0000BD0000BF0000C00000C10000BE0000BE0000C00000C10000\
C20000C30000C30000C30000C40000C60000C60000C70000C70000C60000C50000
BF0000AE00008700004700003700003600003700003700003900003C00004700005800007B0000\
7800004D00004300004400005000008C0000B30000C10000C70000CC0000CD0000
CC0000CD0000D00000D00000D00000CD0000C80000B90000AF0000B80000BF0000C20000C40000\
C80000CA0000CB0000CB0000CC0000CC0000CE0000CE0000CA0000C20000B20000
7000004800004200003B00003A00003B0000450000480000480000430000410000430000580000\
9C0000B90000C20000C60000C80000C90000C90000C90000C80000C90000C70000
C70000C20000BD0000BF0000C30000C60000C70000C80000C90000CA0000CB0000CC0000CA0000\
C90000C70000BF0000BD0000C00000C40000C70000CB0000CD0000CE0000CE0000
CF0000CD0000C80000B200007600005D00004A0000460000
BB0000BD0000BD0000BE0000BD0000BD0000BE0000BF0000C00000BF0000BE0000BF0000C10000\
C10000C20000C20000C20000C50000C50000C60000C60000C70000C70000C80000
C50000BC0000A600006A00003D00003900003900003800003900003D0000420000490000500000\
5300004600004400004C00006600008A0000AD0000BE0000C50000CA0000CC0000
CE0000CE0000D00000D10000CF0000CC0000C70000B90000970000AC0000BA0000BF0000C30000\
C70000C90000CA0000CA0000CB0000CB0000CD0000CC0000C70000BB00009D0000
5A00004C00004600003C00003E00004500005A0000760000710000500000460000480000570000\
9D0000BA0000C20000C50000C80000C80000C80000C70000C80000C90000C90000
C80000C30000BE0000BE0000C30000C60000C70000C80000C80000CA0000CB0000CB0000CA0000\
C80000C80000C50000C30000C50000C60000C90000CB0000CC0000CE0000CE0000
CF0000CD0000C60000AB0000730000580000460000450000
BB0000BC0000BC0000BD0000BC0000BD0000BE0000BF0000C00000BE0000BF0000C00000C10000\
C20000C20000C30000C30000C40000C50000C50000C50000C60000C70000C80000
C70000C00000B100008A00005500003D00003A00003800003900003C0000400000410000430000\
4200004300004900005500006F00007900009C0000B80000C10000C70000CC0000
CC0000CE0000D00000D10000CF0000C90000C10000A900007100007B0000A80000B80000C00000\
C50000C80000C80000C90000CA0000CB0000CC0000C80000C00000AC0000730000
4900004500003E00003A00004000004F00006C0000920000830000530000450000460000520000\
940000B70000C00000C50000C70000C80000C70000C70000C70000C80000C90000
C80000C40000BE0000BE0000C20000C50000C70000C80000C80000C90000CA0000CA0000C90000\
C70000C70000C60000C70000C70000C80000CA0000CC0000CC0000CE0000CE0000
CE0000CD0000C60000AD00007A0000570000450000430000
BC0000BD0000BD0000BD0000BD0000BD0000BE0000BF0000C00000BF0000BF0000C00000C10000\
C20000C20000C20000C30000C40000C60000C60000C50000C60000C70000C80000
C50000BB0000A500007D00006100005200004000003B00003B00003B00003F0000400000400000\
4200004600004F00005800005F00006400007B0000AA0000BE0000C40000C80000
CB0000CE0000D00000D00000CF0000C60000B700008700004E00004B00006E00009A0000B30000\
C00000C50000C60000C80000C90000C90000C70000BF0000AC00008000004E0000
4100003E00003B00003D00004400004D00005F00007000005E00004700004100004300004E0000\
7F0000AF0000BE0000C30000C60000C70000C70000C70000C70000C80000C90000
C70000C40000C00000BC0000BF0000C40000C60000C70000C80000CA0000CA0000C90000C80000\
C60000BF0000C20000C70000C80000C80000CA0000CC0000CD0000CD0000CE0000
CE0000CC0000C70000B700008B00005B0000460000450000
BC0000BD0000BD0000BE0000BD0000BD0000BF0000BF0000BF0000BF0000BF0000C00000C20000\
C20000C20000C20000C30000C50000C60000C60000C60000C70000C70000C70000
C10000B200008F00006C00005E00005400004A00004200004000003F0000420000450000470000\
4900004500004800005700005E00006900007F0000A20000B90000C20000C70000
CA0000CD0000CF0000CE0000C90000BB00009B00005700004100004300004900005B00007E0000\
A00000B20000BC0000BF0000C10000C20000BA0000A20000790000530000410000
3C00003900003A00003C00004100004800004F00005100004600004000003F00003F0000440000\
5A00009A0000B90000C10000C40000C60000C60000C60000C60000C70000C70000
C50000C20000C00000BE0000BA0000C10000C40000C60000C70000C90000CA0000C80000C50000\
C00000AA0000BA0000C50000C70000C90000CA0000CC0000CD0000CD0000CD0000
CC0000C90000C60000C00000A700006E00005100004A0000
BC0000BE0000BE0000BE0000BE0000BD0000BF0000C00000C00000BF0000C00000C00000C20000\
C20000C30000C20000C30000C50000C60000C70000C60000C70000C80000C70000
C00000AB00008200006800005D00004A00004100003E00003E00004100004200004A0000460000\
4200003D00003E00005200006100007D0000A00000B40000BE0000C40000C60000
C90000CA0000CC0000C70000BB00009D00006F00004600004200004300004300004500004E0000\
5D00006F0000800000880000910000A900009700007100005600004200003A0000
3900003900003E00003C00003F00004500004600004500004300003E00003E00003800003A0000\
430000710000A90000BC0000C20000C40000C50000C50000C50000C50000C30000
BD0000B20000B80000BB0000B60000B60000BF0000C30000C60000C80000C80000C70000C30000\
BB0000AB0000B40000C20000C60000C80000CA0000CC0000CD0000CC0000CA0000
C80000BE0000BA0000BF0000BA00009900006B0000530000
BD0000BE0000BE0000BE0000BD0000BE0000BF0000C00000C00000BF0000BF0000C00000C20000\
C30000C20000C10000C30000C50000C60000C70000C60000C70000C80000C80000
C10000AE00008600006A00005500004100003C00003B00003C00003D0000400000450000430000\
3F00003E00003E0000490000680000990000B60000C20000C90000CD0000CC0000
CA0000C90000C50000B800009D00007C00005800004300004100004300004400004600004F0000\
5400005100005200005000005500007200007000005900004B00003A0000350000
3A00003A00003E00003D00003F00004300004500004500004300003B0000360000320000370000\
3D00004C0000770000A50000BA0000C00000C20000C20000C10000BD0000B20000
9500007C00008C0000A30000A30000960000A60000B60000BE0000C40000C60000C50000C50000\
C70000C30000BE0000C10000C50000C80000C90000CC0000CC0000CB0000C90000
C30000BB0000B60000B20000B80000B700009A0000700000
BC0000BE0000BE0000BE0000BD0000BF0000BF0000C00000C00000BF0000C00000C00000C20000\
C30000C20000C20000C20000C40000C60000C60000C60000C70000C80000C80000
C40000B700009C00007900005200004300004800004900004A00004200004A0000640000600000\
4900004300004100004A00007E0000AD0000C00000C90000CD0000D00000D20000
D10000CE0000C80000BA00009A00007900005800004300003E0000410000480000520000670000\
7400005900004F00004800004600005000005A00004C00003D0000380000360000
3900003F00004200004200004400004500004B00004700004000003600003200003400003A0000\
3C00004200004E00006A0000950000A90000B20000AF0000A50000950000780000
5C00005400005600006900007800007600007F0000960000A60000B90000C40000CB0000CE0000\
CE0000CE0000CE0000C60000C40000C50000C60000C80000CA0000C90000C80000
CA0000CA0000C70000C20000BA0000B60000A60000860000
BC0000BE0000BE0000BD0000BD0000BE0000BF0000BF0000C00000C00000BF0000C00000C10000\
C20000C10000C10000C20000C40000C40000C50000C50000C60000C70000C80000
C70000BF0000B000009400005A00004A00005300005300004F00004A00005D00008F00007F0000\
4F0000460000460000560000960000B80000C50000CC0000D00000D30000D20000
D30000D00000CC0000C20000A900008300005E00004800003E00004100004B0000580000850000\
9D00006E00005200004C00004600004600004F00003D00003700003B00003D0000
3E00003F00004700004500004500004D00005300004300003400003200003500003800003C0000\
3F00004300004900004C00005F00006B0000750000660000570000540000520000
5400005400005200005400005A00006B00007A0000910000AD0000C30000CC0000D00000D10000\
D20000D30000D30000D00000C60000B70000B60000BD0000C50000CC0000CF0000
D10000D10000D10000CE0000C80000BB00009C00007F0000
BC0000BE0000BE0000BD0000BD0000BD0000BF0000BF0000C00000BF0000C00000C00000C10000\
C10000C10000C10000C20000C30000C40000C50000C50000C50000C60000C80000
C80000C60000BD0000AD00007A00005200005800005700005300004A00005300006D0000610000\
4D00004600004D00006400009E0000BC0000C70000CD0000D10000D40000D40000
D40000D20000CF0000C80000BA00009700006F00004F0000400000400000460000520000740000\
9400007600005400004E00004B00004400004200003900003900003D0000410000
4300004600004700004200003E00004200004D00004000003300003300003500003A0000400000\
4700004E00005500004C00004700004400004900003A00003D00004500004F0000
5800005C00005A00005600005600005F0000750000970000BA0000C90000D00000D40000D40000\
D50000D60000D60000D30000CD0000AF0000A90000BC0000C90000CE0000D00000
D20000D50000D70000D50000D00000C50000AB00007D0000
BD0000BF0000BE0000BE0000BE0000BD0000BF0000C00000C00000BE0000BF0000C00000C10000\
C10000C20000C10000C10000C30000C40000C50000C50000C50000C60000C80000
C80000C80000C40000BB0000A500006900005300004F00004800004300004700004D00004D0000\
4B00005400007000007C0000A20000BD0000C70000CB0000CF0000CF0000D20000
D40000D30000D20000CD0000C40000A900008C00005900004400004100004400004A0000580000\
6700006000004F00004900004900003F00003A00003900003A00003E0000430000
4B00005500005000004700004100003E00004400003F00003200003300003600003C0000470000\
5500007800007400005000004700003F00003A00003500003B00004300004E0000
5C00007300007100006000005A0000550000730000A10000BF0000CB0000D20000D40000D40000\
D40000D60000D60000D50000CF0000B80000B20000C20000CB0000CF0000D20000
D50000D60000D80000D80000D40000CB0000BA0000800000
BC0000BE0000BE0000BD0000BD0000BD0000BF0000BF0000C00000BE0000BE0000C00000C10000\
C10000C10000C10000C20000C30000C30000C40000C40000C40000C50000C60000
C80000C80000C60000C30000BB0000A100007000005100004600004400004800004D0000540000\
6400008C00009F0000990000A60000BC0000C60000CA0000CE0000CD0000CE0000
D30000D40000D30000D10000CB0000B90000A800007500004B00004300004400004500004C0000\
5000004F00004E00004B00004700004600003800003800003B00004100004A0000
5D00008300007400005300004700004000004200003C00003200003300003700003F0000490000\
6000008C00007D00005100004600004000003500003300003800004000004C0000
6100008B00008F00006B00005E0000530000740000A80000C00000CB0000D10000D30000CE0000\
CE0000D50000D60000D50000D00000C00000BC0000C50000CB0000D00000D20000
D40000D60000D60000D70000D50000CE0000BD0000810000
BC0000BD0000BE0000BD0000BC0000BC0000BE0000BE0000BF0000BD0000BE0000BF0000C00000\
C00000C00000C00000C00000C10000C10000C20000C20000C10000C30000C40000
C40000C50000C50000C40000C30000BE0000AE0000920000760000670000670000720000870000\
A30000B50000B70000B00000AB0000BC0000C50000CA0000CF0000D20000D10000
D30000D30000D30000D10000CD0000C10000BA00009E0000630000490000460000430000470000\
4900004A00004E00004E00004C00005600004600003C00003F00004200004C0000
6300009500009700006A00004E00004500004600004400003700003800003900003F0000480000\
5300006800005E00004C00004800004100003F00003400003800003D0000480000
5600007200007F00006600005E00005A0000790000AC0000C30000CD0000D20000D30000D00000\
D10000D50000D60000D50000D00000C10000BE0000C60000CC0000D00000D20000
D40000D40000D00000D40000D50000CE0000BD0000790000
BC0000BD0000BD0000BD0000BC0000BC0000BD0000BE0000BE0000BD0000BD0000BE0000C00000\
BF0000BF0000BF0000BF0000BF0000C00000C00000BF0000C00000C10000C20000
C20000C10000C10000C10000C20000C20000BF0000B90000B20000AD0000AD0000B10000B80000\
BE0000C10000C00000BD0000B30000B70000C20000C90000CE0000D00000D00000
D00000D10000D30000D10000CF0000C60000C30000B900009600005D0000490000450000470000\
4A00004E00005600006300007600008700006B00004700004400004300004A0000
5800007900007800006400005200004D00006000006600003E00003A00003B0000410000450000\
4D00005000004C00004900004B00004F00006900004100003B00003F0000490000
4F00005800005F00005E00006200007700009A0000B10000C40000CF0000D40000D50000D40000\
D40000D60000D50000D30000CE0000BB0000BD0000C60000CC0000D10000D30000
D40000D60000D50000D50000D40000CD0000B900006F0000
BC0000BD0000BD0000BD0000BC0000BC0000BC0000BD0000BE0000BD0000BC0000BD0000BF0000\
BF0000BF0000BE0000BE0000C00000C00000C00000BF0000C00000C00000C10000
C10000C10000C10000C10000C10000C10000C20000C00000BF0000BF0000C00000C10000C10000\
C20000C40000C40000C30000BF0000B70000BD0000C50000CB0000CD0000CE0000
CF0000D00000D00000D00000CD0000C60000C60000C20000B80000970000670000550000540000\
5700006000007000008A0000A80000AE0000960000590000470000420000440000
4C00006000005800005900005E00006500009200009A00005F00004300003C00003E0000430000\
4700004B00004A00005000005C00008000009D0000740000470000430000480000
4A00005200005900005E00006E0000990000B90000B90000C20000CC0000D10000D30000D30000\
D30000D30000D20000CE0000C70000BD0000BD0000C40000CC0000D00000D20000
D40000D50000D70000D70000D40000CC0000B70000720000
BB0000BC0000BD0000BD0000BB0000BC0000BD0000BD0000BE0000BC0000BC0000BD0000BE0000\
BE0000BE0000BE0000BE0000BF0000C00000C00000BF0000C00000C00000C10000
C00000C00000C00000C00000C10000C20000C20000C10000C00000C10000C30000C20000C30000\
C20000C30000C40000C50000C30000BD0000BA0000C10000C70000CA0000CD0000
CC0000CC0000CC0000CB0000C80000C30000C50000C50000C30000BA0000A70000900000850000\
860000940000A50000B60000BF0000BD0000AF00007900004B0000430000420000
4700004D00005200005F00006C00008A0000B20000B400008F00005700004300003F0000400000\
4400004700004E00005E0000840000AE0000B60000A000006B00004E00004A0000
4B00004E0000590000670000870000B40000C30000C20000C10000C80000CD0000CF0000CF0000\
D00000D00000CD0000CA0000C70000C30000BF0000C20000CA0000CF0000D10000
D30000D50000D70000D70000D40000CB0000B60000840000
BB0000BC0000BD0000BD0000BB0000BB0000BC0000BD0000BD0000BC0000BC0000BD0000BD0000\
BE0000BE0000BE0000BD0000BE0000BF0000BF0000BE0000BE0000BF0000C00000
C00000C00000C00000C00000C00000C10000C10000C00000C00000C00000C10000C20000C20000\
C20000C20000C30000C40000C30000C10000BE0000BE0000C10000C40000C70000
C80000C90000C70000C60000C30000C20000C20000C30000C30000C20000BF0000BA0000B70000\
B80000BC0000C10000C30000C50000C40000BD0000A300006800004B0000450000
4A00004C00005200006100007D0000A60000BF0000BF0000B00000850000580000480000460000\
4A0000500000600000830000AD0000BF0000BF0000B80000A100007A00005D0000
5800005D0000690000840000AC0000C10000C40000C50000C30000C50000C90000CB0000CB0000\
CA0000C80000C90000C80000C80000C60000C40000C10000C70000CD0000CE0000
D00000D20000D40000D50000D10000C90000BA00009C0000
BB0000BC0000BD0000BC0000BB0000BC0000BC0000BD0000BD0000BC0000BD0000BD0000BE0000\
BE0000BE0000BD0000BD0000BE0000BF0000BF0000BE0000BE0000BE0000C00000
C00000C00000BF0000BF0000C00000C00000C10000C00000C00000BF0000C10000C10000C10000\
C10000C10000C20000C20000C20000C10000C00000BF0000BF0000C00000C20000
C20000C30000C20000C20000C20000C10000C20000C20000C30000C30000C20000C10000C00000\
C20000C30000C40000C50000C50000C50000C20000B900009F0000700000590000
5C00006000006E0000820000A10000BA0000C30000C20000BD0000AF0000900000700000650000\
6A0000780000950000B00000BE0000C20000C10000BE0000B70000AE0000980000
8900008C00009B0000B00000BE0000C30000C40000C30000C30000C40000C50000C50000C50000\
C60000C60000C80000C80000C70000C60000C60000C50000C60000C90000CA0000
CD0000CF0000D10000D10000CD0000C70000C00000B20000
BA0000BC0000BD0000BC0000BB0000BC0000BC0000BD0000BD0000BB0000BC0000BC0000BE0000\
BE0000BE0000BC0000BD0000BE0000BF0000BE0000BE0000BD0000BE0000BF0000
BF0000BF0000BF0000BF0000C00000C00000C00000BF0000BF0000BF0000C00000C10000C00000\
BF0000C00000C00000C00000C00000BF0000BF0000BF0000BF0000BF0000BE0000
BF0000BF0000C00000C10000C20000C10000C10000C10000C20000C20000C10000C00000C10000\
C20000C30000C30000C20000C20000C20000C20000C00000B90000AA0000990000
920000960000A20000AE0000B90000BF0000C20000C20000C00000BC0000B60000AD0000A50000\
A50000AB0000B60000BD0000C10000C20000C10000C00000BF0000BE0000BC0000
B80000B70000BA0000BF0000C20000C30000C30000C30000C30000C40000C40000C50000C40000\
C40000C50000C60000C70000C60000C50000C50000C60000C50000C60000C60000
C90000CB0000CB0000C90000C70000C70000C50000BE0000
BB0000BC0000BC0000BC0000BB0000BB0000BC0000BD0000BD0000BC0000BC0000BC0000BD0000\
BE0000BD0000BC0000BD0000BE0000BF0000BF0000BD0000BD0000BD0000BF0000
BF0000BF0000BE0000BE0000C00000C00000C00000BF0000BF0000BF0000C00000C00000BF0000\
BF0000BF0000C00000C00000C00000BF0000BF0000BF0000C00000C00000BF0000
BF0000BF0000C00000C10000C10000C10000C10000C10000C10000C20000C10000C10000C00000\
C10000C20000C20000C10000C10000C00000C10000C10000BE0000BC0000B90000
B90000BA0000BC0000BD0000BF0000C10000C20000C20000C10000BF0000BE0000BE0000BD0000\
BC0000BC0000BE0000C00000C20000C20000C10000C10000C10000C10000C00000
C00000BF0000C00000C10000C20000C30000C20000C20000C20000C30000C40000C40000C30000\
C30000C30000C40000C40000C30000C30000C30000C40000C30000C30000C20000
C30000C40000C50000C50000C50000C50000C40000C30000
BB0000BC0000BC0000BC0000BC0000BC0000BC0000BD0000BD0000BC0000BC0000BC0000BD0000\
BE0000BD0000BC0000BD0000BE0000BF0000BF0000BD0000BD0000BD0000BF0000
BF0000BF0000BE0000BE0000BF0000C00000C10000C00000BF0000BF0000C00000C00000C00000\
BF0000BF0000C00000C00000C00000BF0000BF0000C00000C00000C00000C00000
BF0000C00000C00000C10000C10000C00000C00000C10000C20000C20000C10000C10000C10000\
C10000C20000C20000C10000C10000C00000C10000C10000C00000BF0000BE0000
C00000C00000C00000C00000C00000C10000C20000C20000C10000C00000C00000C00000C00000\
C00000C00000C00000C10000C20000C20000C10000C10000C20000C20000C20000
C20000C10000C10000C20000C30000C30000C20000C20000C20000C30000C30000C30000C20000\
C20000C30000C30000C30000C20000C20000C20000C30000C30000C20000C20000
C10000C20000C30000C30000C20000C20000C20000C20000
BB0000BC0000BD0000BC0000BB0000BC0000BD0000BD0000BD0000BC0000BC0000BC0000BD0000\
BD0000BD0000BD0000BD0000BE0000BF0000BE0000BD0000BD0000BE0000BE0000
BF0000BF0000BE0000BE0000C00000C00000C00000BF0000C00000C00000C00000C00000C00000\
BF0000BF0000C00000C00000C10000BF0000BF0000BF0000C00000C00000BF0000
C00000C00000C00000C00000C10000C00000C00000C10000C20000C10000C10000C10000C10000\
C20000C10000C10000C10000C00000C10000C10000C20000C10000C00000C00000
C10000C10000C10000C00000C10000C20000C30000C20000C10000C10000C10000C20000C20000\
C20000C10000C10000C10000C30000C20000C20000C10000C10000C20000C30000
C20000C10000C20000C30000C30000C30000C20000C20000C20000C30000C30000C30000C20000\
C20000C20000C30000C30000C20000C20000C20000C30000C30000C20000C10000
C10000C20000C30000C30000C20000C10000C10000C30000
BB0000BC0000BC0000BC0000BB0000BC0000BD0000BD0000BD0000BC0000BC0000BD0000BD0000\
BD0000BD0000BD0000BD0000BE0000BF0000BE0000BD0000BD0000BD0000BF0000
BF0000BF0000BE0000BE0000C00000C00000C00000BF0000BF0000BF0000C00000C00000C00000\
BF0000BE0000C00000C10000C00000BF0000C00000C00000C00000C00000C00000
C00000BF0000C10000C10000C10000C00000C00000C10000C20000C20000C10000C00000C10000\
C20000C20000C20000C00000C10000C10000C20000C20000C10000C10000C10000
C20000C20000C20000C10000C10000C20000C30000C30000C20000C10000C20000C20000C20000\
C30000C20000C20000C20000C30000C30000C20000C10000C20000C30000C30000
C30000C20000C20000C30000C40000C40000C20000C30000C20000C30000C40000C30000C20000\
C20000C30000C30000C30000C20000C20000C20000C30000C30000C20000C20000
C10000C20000C30000C30000C20000C20000C10000C30000
BC0000BD0000BD0000BD0000BC0000BC0000BD0000BD0000BD0000BC0000BC0000BD0000BE0000\
BE0000BE0000BD0000BD0000BE0000BF0000BF0000BD0000BD0000BE0000BE0000
BF0000BF0000BE0000BF0000C00000C00000C00000BF0000C00000BF0000C00000C00000C00000\
BF0000BE0000C00000C00000C10000BF0000BF0000C00000C10000C00000C00000
BF0000C00000C10000C10000C10000C00000C00000C00000C10000C20000C10000C00000C10000\
C20000C20000C20000C10000C10000C10000C20000C20000C10000C10000C10000
C20000C20000C20000C10000C10000C20000C30000C30000C20000C20000C20000C30000C30000\
C30000C20000C20000C20000C30000C30000C30000C20000C10000C30000C40000
C30000C20000C20000C20000C30000C30000C30000C20000C30000C30000C30000C30000C30000\
C30000C30000C30000C30000C30000C20000C20000C30000C30000C30000C20000
C20000C20000C30000C30000C20000C10000C20000C30000
BC0000BD0000BD0000BD0000BC0000BC0000BD0000BD0000BD0000BC0000BC0000BD0000BD0000\
BE0000BE0000BD0000BD0000BE0000BE0000BE0000BD0000BD0000BD0000BE0000
BF0000BF0000BE0000BF0000C00000C00000C00000BF0000BF0000C00000C00000C00000C00000\
BF0000BF0000C00000C00000C00000BF0000BF0000BF0000C00000C00000C00000
C00000BF0000C00000C10000C10000C00000C00000C00000C20000C20000C10000C00000C00000\
C20000C20000C20000C00000C10000C10000C20000C20000C10000C10000C00000
C20000C20000C20000C10000C10000C20000C30000C30000C20000C10000C20000C30000C30000\
C30000C20000C20000C20000C30000C30000C20000C10000C10000C30000C30000
C30000C20000C20000C20000C30000C30000C30000C20000C20000C30000C30000C30000C30000\
C20000C30000C30000C40000C30000C20000C20000C40000C30000C30000C20000
C20000C20000C30000C30000C20000C20000C20000C30000
BB0000BC0000BC0000BC0000BC0000BB0000BD0000BD0000BD0000BB0000BC0000BD0000BD0000\
BD0000BE0000BD0000BD0000BE0000BF0000BE0000BD0000BD0000BE0000BE0000
BF0000BE0000BF0000BE0000C00000C00000C00000BF0000BF0000BF0000C00000C00000C00000\
BF0000BE0000C00000C00000C00000BF0000BF0000C00000C00000C00000C00000
BF0000BF0000C00000C10000C10000BF0000C00000C10000C20000C20000C10000C00000C10000\
C20000C20000C20000C10000C10000C20000C20000C20000C10000C10000C10000
C20000C20000C20000C10000C10000C20000C20000C30000C20000C10000C20000C30000C30000\
C30000C20000C20000C20000C30000C30000C20000C20000C20000C30000C30000
C30000C20000C20000C30000C40000C40000C30000C20000C20000C30000C40000C40000C20000\
C20000C30000C30000C40000C30000C20000C20000C30000C40000C30000C20000
C20000C20000C30000C30000C20000C20000C20000C30000
BC0000BC0000BD0000BC0000BC0000BB0000BD0000BD0000BD0000BC0000BC0000BD0000BD0000\
BD0000BD0000BD0000BD0000BE0000BE0000BE0000BE0000BD0000BD0000BF0000
BF0000BF0000BE0000BE0000C00000C00000C00000BF0000BF0000BF0000C00000C00000BF0000\
BF0000BF0000C00000C00000C00000BF0000BF0000BF0000C00000C00000C00000
C00000BF0000C00000C10000C10000C00000C00000C00000C10000C20000C10000C00000C00000\
C20000C20000C20000C10000C10000C20000C30000C20000C10000C10000C10000
C30000C20000C20000C20000C10000C20000C30000C20000C20000C10000C10000C30000C30000\
C20000C10000C20000C20000C30000C30000C20000C20000C20000C30000C30000
C20000C20000C20000C30000C40000C30000C20000C20000C20000C40000C30000C30000C20000\
C20000C30000C40000C40000C20000C20000C20000C30000C30000C30000C20000
C20000C30000C30000C30000C20000C20000C20000C30000
BB0000BC0000BD0000BD0000BC0000BC0000BD0000BD0000BD0000BC0000BC0000BC0000BD0000\
BD0000BD0000BC0000BD0000BE0000BE0000BE0000BD0000BD0000BE0000BF0000
BE0000BF0000BE0000BE0000BF0000C00000C00000BF0000BF0000BF0000C00000C10000BF0000\
BF0000BF0000C00000C00000C00000BF0000BF0000BF0000C10000C00000C00000
C00000BF0000C00000C10000C10000C00000C00000C10000C20000C10000C10000C00000C10000\
C20000C30000C20000C10000C10000C20000C20000C20000C10000C10000C10000
C30000C30000C20000C10000C10000C20000C30000C20000C20000C10000C10000C30000C30000\
C20000C20000C20000C20000C30000C30000C20000C20000C20000C30000C30000
C20000C20000C20000C30000C30000C30000C20000C30000C20000C40000C40000C30000C20000\
C20000C30000C30000C40000C30000C20000C20000C30000C30000C30000C20000
C20000C30000C40000C30000C30000C20000C10000C30000
BA0000BC0000BC0000BC0000BB0000BC0000BD0000BD0000BD0000BC0000BB0000BC0000BE0000\
BD0000BD0000BD0000BD0000BE0000BF0000BE0000BD0000BE0000BE0000BF0000
BF0000BF0000BF0000BF0000C00000C00000C00000BF0000BF0000BF0000C00000C00000C00000\
BF0000BF0000C00000C00000C00000BF0000BF0000BF0000C00000C00000BF0000
C00000BF0000C10000C10000C00000C00000C00000C10000C20000C10000C10000C10000C10000\
C20000C20000C20000C10000C10000C10000C20000C20000C10000C10000C10000
C20000C30000C20000C10000C10000C20000C30000C20000C20000C10000C20000C30000C30000\
C30000C10000C20000C20000C30000C30000C20000C20000C20000C30000C30000
C30000C20000C20000C30000C30000C40000C30000C30000C20000C30000C40000C30000C20000\
C20000C30000C40000C30000C20000C20000C20000C30000C30000C30000C30000
C30000C30000C30000C30000C20000C20000C20000C30000
BB0000BC0000BC0000BC0000BC0000BC0000BD0000BE0000BD0000BC0000BB0000BC0000BE0000\
BD0000BD0000BD0000BD0000BF0000BE0000BE0000BD0000BE0000BE0000BF0000
BF0000BF0000BE0000BF0000BF0000BF0000C00000BF0000BE0000BF0000C00000C00000C00000\
BF0000BF0000C00000C00000C00000BF0000BF0000BF0000C10000C00000BF0000
C00000BF0000C10000C10000C00000C00000C00000C00000C20000C10000C10000C00000C10000\
C20000C20000C20000C10000C10000C10000C20000C20000C20000C10000C10000
C20000C20000C30000C10000C10000C20000C20000C30000C10000C10000C20000C20000C30000\
C20000C10000C10000C20000C30000C30000C30000C20000C20000C30000C30000
C30000C20000C20000C20000C30000C40000C30000C20000C20000C40000C40000C30000C20000\
C30000C30000C40000C40000C30000C30000C20000C30000C30000C30000C20000
C20000C20000C30000C40000C20000C20000C20000C40000
BA0000BC0000BC0000BD0000BC0000BC0000BD0000BD0000BD0000BC0000BC0000BD0000BE0000\
BD0000BD0000BC0000BD0000BE0000BE0000BF0000BD0000BE0000BE0000BF0000
BF0000BF0000BF0000BE0000BF0000C00000C00000BF0000BF0000BF0000C00000C00000BF0000\
BF0000BF0000C00000C00000C00000BF0000BF0000C00000C00000C00000BF0000
BF0000BF0000C10000C10000C10000C00000C00000C10000C10000C10000C10000C10000C10000\
C20000C20000C20000C10000C10000C10000C20000C30000C10000C10000C20000
C20000C20000C30000C20000C10000C10000C30000C30000C20000C20000C10000C30000C30000\
C20000C10000C20000C30000C30000C30000C20000C20000C20000C30000C30000
C30000C20000C20000C20000C30000C30000C20000C20000C30000C40000C40000C40000C30000\
C20000C20000C20000C30000C30000C30000C20000C40000C40000C40000C20000
C20000C30000C30000C30000C30000C20000C20000C40000
BB0000BB0000BC0000BC0000BB0000BC0000BD0000BD0000BD0000BC0000BC0000BC0000BD0000\
BD0000BD0000BC0000BD0000BE0000BE0000BE0000BD0000BE0000BE0000BF0000
C00000C00000BF0000BF0000BF0000BF0000C00000BF0000BE0000BF0000C00000C00000BF0000\
BE0000BF0000C00000C00000C00000BF0000BF0000BF0000C00000C00000BF0000
BF0000BF0000C00000C10000C10000C00000C00000C00000C10000C10000C10000C00000C00000\
C20000C20000C20000C10000C10000C10000C20000C20000C20000C10000C20000
C20000C30000C30000C20000C10000C20000C20000C30000C20000C10000C10000C20000C30000\
C20000C10000C20000C20000C30000C30000C20000C20000C20000C30000C40000
C30000C20000C20000C20000C30000C40000C20000C20000C30000C40000C30000C30000C30000\
C30000C30000C30000C40000C30000C30000C30000C30000C40000C30000C20000
C20000C30000C30000C30000C20000C30000C20000C30000
BB0000BC0000BC0000BC0000BC0000BB0000BD0000BD0000BC0000BC0000BC0000BC0000BD0000\
BD0000BD0000BC0000BC0000BE0000BE0000BE0000BD0000BD0000BD0000BF0000
BF0000BF0000BE0000BF0000BF0000BF0000BF0000BF0000BE0000BF0000C00000C00000BF0000\
BE0000BF0000C00000C10000C00000BF0000BF0000BF0000C00000C10000C00000
BF0000C00000C00000C10000C10000C00000C00000C10000C10000C10000C10000C00000C10000\
C20000C20000C10000C10000C10000C10000C20000C20000C10000C10000C20000
C30000C20000C20000C20000C10000C20000C20000C30000C20000C10000C20000C20000C20000\
C20000C10000C10000C20000C30000C30000C20000C20000C20000C30000C30000
C30000C20000C20000C30000C40000C30000C20000C20000C30000C40000C30000C30000C30000\
C30000C30000C40000C30000C30000C30000C30000C40000C40000C30000C30000
C20000C30000C30000C30000C20000C20000C20000C30000
BA0000BC0000BC0000BC0000BB0000BC0000BD0000BD0000BD0000BC0000BB0000BC0000BD0000\
BD0000BD0000BC0000BD0000BE0000BF0000BF0000BE0000BD0000BD0000BF0000
C00000BF0000BF0000BF0000C00000C00000C00000BF0000BE0000BE0000BF0000C10000BF0000\
BE0000BE0000C00000C10000C00000BF0000BE0000C00000C00000C00000C00000
BF0000C00000C00000C10000C10000C00000C00000C10000C10000C20000C10000C10000C10000\
C20000C20000C20000C10000C10000C10000C20000C20000C10000C10000C10000
C30000C20000C20000C10000C10000C20000C30000C30000C20000C10000C10000C20000C30000\
C20000C20000C10000C20000C30000C30000C30000C20000C20000C30000C30000
C30000C20000C20000C30000C30000C30000C30000C20000C20000C40000C40000C30000C30000\
C30000C30000C40000C40000C30000C30000C30000C40000C40000C40000C30000
C20000C20000C30000C30000C20000C20000C20000C30000
BA0000BC0000BC0000BC0000BC0000BC0000BD0000BD0000BD0000BC0000BC0000BC0000BD0000\
BD0000BC0000BC0000BD0000BE0000BE0000BE0000BD0000BE0000BE0000BF0000
BF0000BF0000BF0000BF0000C00000C00000BF0000BF0000BE0000BF0000BF0000C00000BF0000\
BE0000BE0000BF0000C00000C00000BF0000BF0000C00000C10000C00000C00000
C00000C00000C00000C10000C00000C00000C00000C10000C20000C10000C10000C00000C00000\
C20000C20000C20000C10000C10000C10000C20000C20000C10000C10000C10000
C20000C20000C20000C10000C10000C20000C30000C30000C20000C10000C10000C30000C30000\
C20000C20000C20000C20000C30000C30000C30000C20000C20000C30000C30000
C30000C20000C20000C20000C30000C30000C30000C20000C30000C40000C40000C30000C20000\
C30000C30000C40000C40000C30000C20000C20000C40000C30000C40000C20000
C20000C20000C30000C30000C30000C20000C30000C30000
BB0000BC0000BC0000BD0000BC0000BC0000BE0000BD0000BC0000BB0000BC0000BD0000BD0000\
BD0000BC0000BC0000BC0000BD0000BE0000BE0000BD0000BE0000BE0000BF0000
C00000BF0000BE0000BF0000C00000C00000C00000BE0000BE0000BF0000BF0000C00000C00000\
BF0000BF0000C00000C00000C00000BF0000BF0000C00000C10000C00000C00000
C00000C00000C00000C00000C00000C00000C00000C10000C10000C20000C10000C10000C00000\
C20000C20000C10000C10000C00000C10000C20000C20000C10000C10000C10000
C20000C20000C20000C20000C20000C20000C20000C30000C10000C10000C10000C20000C20000\
C30000C10000C10000C20000C30000C40000C30000C20000C20000C30000C30000
C30000C20000C20000C30000C30000C40000C30000C20000C30000C40000C40000C30000C30000\
C20000C30000C40000C40000C30000C30000C30000C40000C40000C30000C30000
C20000C20000C30000C30000C20000C20000C20000C30000
BB0000BC0000BC0000BD0000BC0000BD0000BE0000BD0000BC0000BC0000BC0000BC0000BD0000\
BD0000BD0000BC0000BD0000BE0000BE0000BF0000BE0000BE0000BF0000C00000
C00000BF0000BE0000BF0000C00000C00000C00000BF0000BF0000BF0000C00000C00000C00000\
BF0000BF0000C00000C00000C00000BF0000BF0000C00000C10000C10000C00000
C00000BF0000C00000C00000C10000BF0000C00000C10000C20000C10000C10000C10000C00000\
C20000C30000C20000C10000C10000C10000C30000C20000C20000C10000C20000
C20000C30000C30000C10000C20000C20000C30000C30000C20000C10000C10000C30000C30000\
C20000C10000C20000C30000C30000C30000C20000C20000C20000C30000C30000
C30000C20000C20000C30000C40000C40000C30000C20000C30000C40000C40000C40000C20000\
C20000C30000C40000C40000C30000C30000C30000C40000C40000C30000C30000
C20000C30000C30000C30000C20000C20000C20000C30000
BB0000BC0000BC0000BC0000BB0000BC0000BD0000BD0000BD0000BC0000BC0000BC0000BD0000\
BD0000BD0000BD0000BD0000BD0000BE0000BF0000BE0000BE0000BE0000BF0000
C00000BF0000BF0000BE0000BF0000C00000C00000BE0000BE0000BF0000C00000C00000BF0000\
BF0000BF0000C00000C00000C00000BF0000BF0000BF0000C10000C10000C00000
C00000C00000C10000C00000C10000C00000C00000C10000C10000C10000C10000C00000C00000\
C20000C20000C20000C10000C10000C10000C20000C20000C10000C10000C10000
C20000C30000C30000C20000C20000C20000C30000C20000C20000C10000C10000C20000C30000\
C30000C20000C20000C20000C30000C30000C20000C20000C20000C30000C40000
C30000C20000C30000C30000C40000C40000C30000C30000C30000C30000C40000C30000C30000\
C30000C30000C40000C40000C30000C30000C20000C40000C40000C30000C20000
C20000C30000C30000C30000C20000C20000C20000C30000
BB0000BC0000BC0000BC0000BB0000BC0000BD0000BD0000BC0000BC0000BC0000BC0000BD0000\
BE0000BD0000BC0000BD0000BE0000BE0000BF0000BE0000BE0000BE0000BF0000
C00000BF0000BF0000BF0000C00000C00000C00000BE0000BF0000BF0000C00000C00000C00000\
BF0000BF0000C10000C00000C00000C00000BF0000BF0000C10000C10000C00000
BF0000BF0000C00000C10000C10000C00000C00000C00000C10000C10000C10000C00000C00000\
C20000C20000C20000C10000C10000C10000C20000C20000C10000C20000C10000
C20000C30000C30000C20000C10000C20000C30000C30000C10000C10000C20000C30000C30000\
C30000C20000C20000C30000C30000C30000C20000C20000C20000C30000C30000
C30000C20000C20000C30000C30000C40000C30000C20000C30000C40000C40000C30000C20000\
C20000C30000C30000C40000C20000C20000C20000C40000C40000C30000C20000
C30000C30000C30000C30000C30000C20000C20000C30000
BA0000BC0000BC0000BB0000BC0000BB0000BD0000BC0000BC0000BC0000BC0000BC0000BD0000\
BD0000BC0000BC0000BD0000BE0000BE0000BF0000BE0000BD0000BE0000BF0000
C00000BF0000BF0000BE0000C00000C00000C00000BF0000BE0000BF0000C00000C00000BF0000\
BF0000BF0000C00000C00000C00000C00000BF0000BF0000C00000C00000BF0000
BF0000BF0000C10000C10000C10000C00000C00000C10000C10000C10000C00000C10000C00000\
C20000C20000C20000C00000C10000C20000C20000C20000C10000C10000C10000
C20000C30000C20000C20000C20000C20000C30000C30000C20000C10000C10000C30000C30000\
C30000C10000C20000C20000C40000C40000C30000C20000C20000C30000C40000
C30000C20000C20000C30000C30000C30000C20000C30000C30000C40000C40000C30000C30000\
C20000C30000C40000C30000C30000C20000C20000C40000C40000C30000C30000
C20000C30000C30000C30000C20000C20000C20000C30000
BA0000BB0000BC0000BB0000BB0000BA0000BC0000BC0000BC0000BC0000BB0000BB0000BD0000\
BD0000BC0000BC0000BD0000BD0000BE0000BF0000BE0000BD0000BE0000BF0000
C00000BF0000BF0000BF0000C00000C00000C00000BF0000BE0000BE0000BF0000C00000C00000\
BF0000BF0000C00000C00000C00000BF0000BF0000BF0000C00000C00000BF0000
BF0000BF0000C00000C00000C00000C00000C00000C00000C10000C10000C10000C00000C00000\
C20000C20000C20000C10000C10000C10000C20000C20000C10000C10000C10000
C30000C30000C20000C10000C20000C20000C20000C30000C10000C20000C10000C30000C30000\
C30000C20000C20000C20000C40000C40000C30000C20000C20000C30000C30000
C30000C20000C20000C20000C40000C40000C30000C20000C30000C40000C40000C30000C20000\
C30000C30000C30000C30000C30000C20000C20000C40000C30000C30000C20000
C20000C30000C30000C30000C20000C20000C20000C30000
B90000BA0000BC0000BB0000BB0000BB0000BC0000BB0000BB0000BC0000BC0000BC0000BC0000\
BC0000BC0000BC0000BC0000BD0000BE0000BE0000BE0000BD0000BD0000BF0000
BF0000BF0000BF0000BE0000BF0000BF0000C00000BF0000BE0000BF0000C00000C00000BF0000\
BF0000BF0000C00000C00000C00000C00000BF0000BF0000C00000C00000C00000
BF0000BF0000C00000C00000C00000C00000C00000C00000C10000C10000C10000C00000C10000\
C20000C20000C30000C00000C10000C10000C20000C20000C20000C10000C10000
C30000C20000C30000C10000C20000C20000C30000C30000C10000C10000C10000C30000C30000\
C30000C20000C20000C30000C30000C40000C30000C30000C20000C30000C40000
C30000C20000C20000C30000C40000C40000C30000C30000C30000C40000C40000C40000C30000\
C20000C20000C30000C30000C30000C20000C20000C30000C30000C30000C20000
C20000C30000C30000C30000C20000C20000C30000C30000
B90000BA0000BB0000BB0000BB0000BB0000BB0000BC0000BC0000BB0000BB0000BC0000BD0000\
BD0000BC0000BC0000BC0000BD0000BE0000BE0000BD0000BD0000BD0000BF0000
BF0000BE0000BE0000BE0000BF0000C00000C00000BE0000BF0000BE0000BF0000C00000C00000\
BF0000BF0000C00000C00000C00000BF0000BE0000BF0000C00000C00000C00000
BF0000BF0000C00000C00000C00000C00000C00000C00000C10000C10000C10000C00000C10000\
C20000C20000C20000C10000C10000C10000C20000C20000C10000C10000C10000
C20000C30000C20000C10000C10000C20000C30000C30000C20000C10000C10000C20000C30000\
C30000C20000C20000C20000C30000C30000C20000C20000C30000C30000C40000
C30000C30000C20000C30000C40000C30000C30000C20000C20000C40000C40000C30000C30000\
C20000C30000C40000C40000C30000C30000C20000C30000C30000C30000C20000
C20000C20000C30000C30000C20000C20000C30000C40000
B90000BA0000BB0000BC0000BA0000BB0000BB0000BC0000BC0000BB0000BB0000BB0000BD0000\
BD0000BC0000BC0000BD0000BD0000BE0000BE0000BD0000BD0000BE0000BE0000
BF0000BF0000BE0000BE0000BF0000C00000C00000BE0000BE0000BF0000C00000C00000BF0000\
BE0000BE0000C00000C00000BF0000BE0000BE0000BF0000C00000C00000BF0000
BF0000BF0000C00000C00000C10000BF0000C00000C00000C10000C10000C10000C10000C10000\
C20000C20000C20000C10000C10000C10000C20000C20000C10000C10000C10000
C20000C20000C20000C20000C10000C20000C30000C30000C20000C20000C10000C20000C30000\
C30000C20000C20000C20000C30000C30000C30000C20000C20000C30000C40000
C30000C20000C20000C20000C30000C30000C30000C30000C30000C40000C40000C40000C30000\
C30000C30000C40000C30000C30000C20000C20000C30000C40000C30000C20000
C20000C20000C30000C30000C20000C20000C20000C30000
B90000BA0000BA0000BB0000BA0000BA0000BB0000BC0000BC0000BB0000BB0000BB0000BD0000\
BD0000BB0000BB0000BD0000BE0000BD0000BE0000BD0000BD0000BD0000BE0000
BF0000BE0000BE0000BE0000BF0000C00000BF0000BE0000BE0000BE0000C00000BF0000BF0000\
BE0000BE0000C00000C00000BF0000BE0000BE0000BE0000C00000C00000BF0000
BF0000BF0000C00000C00000C10000BF0000BF0000BF0000C10000C10000C00000C00000C10000\
C10000C20000C20000C10000C00000C10000C20000C20000C20000C10000C10000
C20000C20000C20000C10000C10000C10000C30000C30000C20000C10000C10000C20000C30000\
C20000C20000C20000C20000C30000C30000C20000C20000C20000C30000C40000
C30000C20000C20000C20000C40000C30000C20000C20000C20000C30000C40000C30000C20000\
C20000C30000C30000C30000C20000C20000C20000C30000C30000C30000C20000
C20000C30000C30000C30000C20000C20000C20000C30000
B90000BA0000BA0000BA0000BA0000BA0000BC0000BC0000BC0000BB0000BB0000BC0000BD0000\
BC0000BB0000BB0000BC0000BD0000BD0000BE0000BD0000BD0000BD0000BE0000
BE0000BE0000BE0000BE0000BF0000BF0000BF0000BE0000BD0000BE0000BF0000BF0000BF0000\
BE0000BE0000BF0000BF0000BF0000BE0000BE0000BF0000C00000C10000BF0000
BF0000BF0000C00000C00000C00000BF0000BF0000C00000C10000C10000C00000C00000C00000\
C20000C20000C20000C10000C10000C20000C20000C20000C10000C10000C10000
C20000C20000C20000C10000C10000C20000C30000C30000C20000C10000C10000C20000C20000\
C20000C20000C10000C20000C30000C30000C20000C20000C20000C40000C30000
C30000C20000C20000C30000C30000C30000C20000C20000C20000C30000C40000C30000C20000\
C20000C30000C40000C30000C20000C20000C20000C30000C30000C30000C20000
C20000C20000C30000C30000C20000C20000C20000C30000
B90000BB0000BB0000BA0000BA0000BA0000BB0000BD0000BC0000BB0000BA0000BC0000BC0000\
BC0000BB0000BB0000BC0000BD0000BD0000BE0000BD0000BE0000BD0000BF0000
BF0000BE0000BE0000BE0000BE0000BF0000BF0000BD0000BD0000BE0000BF0000BF0000BF0000\
BE0000BE0000BF0000BF0000BF0000BE0000BE0000BE0000C00000C00000BF0000
BF0000BF0000C00000C10000C00000BF0000BF0000C00000C00000C10000C00000C00000C00000\
C10000C20000C20000C10000C10000C10000C20000C10000C10000C10000C10000
C20000C20000C20000C10000C10000C10000C20000C20000C10000C10000C10000C20000C30000\
C20000C10000C10000C20000C30000C30000C20000C20000C20000C30000C30000
C30000C20000C20000C20000C30000C30000C20000C20000C20000C40000C40000C30000C20000\
C20000C30000C30000C30000C20000C20000C20000C30000C30000C30000C20000
C20000C20000C30000C30000C20000C20000C20000C30000
B90000BB0000BB0000BB0000BA0000B90000BB0000BC0000BC0000BB0000BA0000BC0000BD0000\
BD0000BB0000BB0000BC0000BD0000BD0000BD0000BC0000BD0000BD0000BE0000
BE0000BE0000BD0000BD0000BE0000BF0000BF0000BE0000BE0000BE0000BF0000BF0000BF0000\
BE0000BE0000BF0000BF0000BF0000BE0000BE0000BE0000BF0000BF0000BF0000
BF0000BF0000C00000C10000C00000BF0000BF0000C00000C10000C00000C00000C00000BF0000\
C10000C10000C10000C10000C00000C10000C10000C20000C10000C10000C10000
C20000C20000C20000C10000C10000C10000C30000C30000C10000C10000C10000C20000C20000\
C20000C10000C10000C20000C30000C30000C20000C20000C20000C30000C40000
C30000C20000C20000C20000C30000C30000C30000C20000C30000C40000C30000C30000C20000\
C20000C20000C30000C40000C30000C20000C20000C30000C30000C30000C20000
C20000C20000C30000C30000C20000C10000C10000C30000
B90000BB0000BA0000BA0000B90000B90000BB0000BC0000BC0000BA0000BB0000BB0000BC0000\
BC0000BC0000BB0000BC0000BD0000BD0000BD0000BD0000BC0000BD0000BE0000
BE0000BE0000BD0000BD0000BF0000BF0000BF0000BE0000BE0000BE0000BF0000C00000BE0000\
BE0000BE0000BF0000BE0000BF0000BE0000BE0000BE0000BF0000BF0000BF0000
BF0000BF0000C00000C00000C00000BF0000BF0000C00000C00000C00000C00000C00000C00000\
C20000C10000C10000C10000C10000C00000C20000C20000C00000C10000C10000
C20000C30000C20000C10000C10000C20000C20000C30000C20000C10000C10000C20000C20000\
C20000C10000C20000C20000C30000C30000C20000C20000C20000C30000C30000
C30000C20000C20000C30000C30000C40000C20000C20000C20000C30000C30000C30000C20000\
C20000C30000C40000C40000C30000C20000C20000C30000C30000C30000C20000
C20000C20000C30000C30000C20000C10000C20000C30000
B90000BB0000BA0000BA0000B80000BA0000BB0000BC0000BC0000BA0000BA0000BB0000BD0000\
BB0000BB0000BB0000BC0000BD0000BC0000BD0000BC0000BC0000BC0000BE0000
BE0000BD0000BD0000BD0000BF0000BF0000BF0000BE0000BE0000BF0000BF0000C00000BF0000\
BE0000BE0000BF0000BE0000BF0000BE0000BE0000BE0000BF0000BF0000BF0000
BF0000BF0000C00000C00000C00000BF0000C00000C00000C10000C00000BF0000C00000C00000\
C10000C10000C10000C10000C00000C00000C10000C20000C10000C00000C10000
C20000C20000C20000C10000C10000C20000C20000C20000C10000C10000C10000C20000C20000\
C20000C20000C10000C20000C30000C30000C20000C20000C20000C30000C30000
C30000C20000C20000C30000C30000C30000C20000C20000C20000C30000C30000C30000C20000\
C20000C30000C30000C30000C20000C20000C20000C30000C30000C30000C20000
C20000C20000C30000C30000C20000C20000C10000C30000
B90000BA0000BB0000BA0000BA0000BA0000BC0000BC0000BB0000BB0000BA0000BC0000BD0000\
BC0000BB0000BB0000BB0000BD0000BC0000BD0000BB0000BC0000BC0000BE0000
BE0000BD0000BC0000BD0000BF0000BF0000BF0000BE0000BE0000BE0000C00000BF0000BF0000\
BE0000BE0000BF0000BE0000BF0000BE0000BE0000BD0000BF0000BF0000BF0000
BE0000BF0000C00000C00000C00000BF0000BF0000C00000C10000C10000C00000C00000C00000\
C20000C20000C10000C10000C00000C10000C10000C10000C00000C10000C10000
C20000C20000C20000C10000C10000C10000C20000C20000C10000C10000C20000C20000C20000\
C20000C10000C10000C20000C30000C30000C20000C10000C20000C30000C30000
C30000C20000C20000C30000C30000C30000C20000C20000C20000C30000C30000C30000C30000\
C20000C30000C30000C30000C20000C20000C20000C30000C30000C20000C20000
C10000C20000C20000C30000C20000C20000C10000C20000
B90000BA0000BB0000BB0000BA0000BB0000BB0000BC0000BB0000BB0000BB0000BB0000BC0000\
BC0000BC0000BA0000BB0000BC0000BC0000BC0000BB0000BC0000BC0000BD0000
BE0000BD0000BD0000BD0000BE0000C00000BF0000BE0000BE0000BE0000BF0000BF0000BE0000\
BE0000BE0000BF0000BF0000BF0000BD0000BD0000BD0000BF0000BF0000BF0000
BE0000BE0000C00000C00000C00000BF0000BF0000C00000C10000C10000C10000C00000C00000\
C10000C20000C10000C00000C00000C10000C10000C10000C10000C00000C10000
C20000C20000C20000C10000C10000C10000C20000C20000C10000C10000C10000C20000C20000\
C20000C10000C10000C20000C20000C30000C20000C10000C20000C30000C30000
C30000C20000C20000C20000C30000C30000C30000C10000C20000C40000C30000C30000C20000\
C30000C30000C30000C30000C20000C20000C20000C30000C30000C20000C10000
C10000C20000C30000C30000C20000C10000C10000C20000
B80000BA0000BB0000BB0000BA0000BB0000BB0000BB0000BB0000BB0000BA0000BA0000BC0000\
BC0000BC0000BB0000BB0000BC0000BD0000BC0000BB0000BB0000BC0000BD0000
BD0000BD0000BD0000BD0000BE0000BF0000BF0000BE0000BE0000BE0000BF0000BF0000BF0000\
BE0000BE0000BF0000BF0000BE0000BE0000BD0000BE0000BF0000BF0000BE0000
BE0000BE0000C00000C00000C00000BF0000C00000C00000C00000C10000C00000C00000C00000\
C10000C10000C10000C00000C00000C00000C10000C10000C10000C00000C10000
C20000C20000C20000C10000C00000C10000C20000C20000C10000C10000C10000C20000C20000\
C20000C10000C10000C20000C20000C30000C20000C20000C10000C30000C30000
C20000C10000C20000C20000C30000C30000C30000C10000C20000C40000C30000C30000C20000\
C20000C20000C30000C30000C20000C20000C20000C30000C30000C20000C10000
C10000C20000C30000C30000C10000C10000C10000C20000
B80000B90000BB0000BA0000BB0000BA0000BB0000BB0000BB0000BA0000BA0000BA0000BC0000\
BC0000BB0000BB0000BA0000BB0000BC0000BD0000BB0000BC0000BC0000BD0000
BE0000BD0000BC0000BD0000BE0000BE0000BF0000BD0000BD0000BD0000BF0000BF0000BF0000\
BE0000BE0000BE0000BF0000BE0000BD0000BD0000BE0000BF0000BF0000BE0000
BE0000BE0000BF0000C00000C00000BF0000BF0000C00000C00000C00000C00000BF0000C00000\
C10000C10000C10000C00000C00000C10000C20000C10000C00000C10000C10000
C10000C20000C20000C10000C10000C10000C20000C20000C10000C00000C10000C20000C30000\
C20000C10000C10000C10000C20000C20000C20000C10000C20000C20000C30000
C20000C10000C10000C20000C30000C30000C20000C10000C20000C30000C30000C30000C20000\
C20000C20000C30000C30000C20000C10000C20000C30000C30000C30000C10000
C20000C20000C20000C20000C10000C10000C10000C20000
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.35119 0.00744048 0.64881 0.30506 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00744048 0.0238095 0.00744048 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
384 string
128 128 8 [128 0 0 128 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
00C30000C40000C40000C60000C60000C50000C60000C60000C70000C70000C70000C80000C800\
00C70000C80000C90000C80000CA0000CA0000CA0000CB0000CB0000CC0000CC00
00CB0000CB0000CB0000CB0000CA0000CA0000CB0000CD0000CF0000D00000CE0000C70000B100\
008200006300006700007600008200008D00009A0000A00000A20000A80000AE00
00AC0000A600009300006E00006000006600007000007C00008800009300009600009E0000A200\
00A70000AA0000AD0000B30000B60000C10000CB0000CE0000CE0000CE0000CE00
00CE0000CF0000CE0000CE0000CF0000CE0000CD0000CD0000CD0000CE0000CE0000CF0000CF00\
00CF0000CD0000CA0000C80000C40000BF0000B90000B30000B30000B70000BA00
00C00000C40000C80000CC0000CD0000CD0000CE0000CF0000CE0000CF0000CF0000CE0000CF00\
00CD0000CE0000CD0000CC0000CB0000CD0000CD0000CE0000CD0000CF0000CE00
00CF0000CF0000CE0000CF0000CE0000CF0000CF0000CF00
00C50000C40000C40000C50000C40000C50000C70000C70000C60000C60000C70000C90000C900\
00C90000C90000C90000C90000CB0000CB0000CB0000CC0000CC0000CC0000CB00
00C90000C70000C40000C10000BD0000BC0000BC0000C20000C60000CB0000CC0000C20000A300\
007200006000006B00007300008200008B00009300009B00009D0000A50000A900
00AC0000A300008F00006300005700005C00006A00007E00008E00009800009B0000A10000A500\
00AB0000AD0000AC0000B00000B30000BC0000C80000CE0000CE0000CF0000CF00
00CF0000CF0000CD0000CE0000CD0000CD0000CB0000CB0000CC0000CE0000CF0000D00000D000\
00CE0000CC0000C50000B80000A700008E00007F00007100007000008000008500
00920000A40000B50000C30000C90000CC0000CD0000CF0000CF0000D00000CE0000CE0000CE00\
00CC0000CA0000C70000C40000C40000C40000C80000CA0000CC0000CD0000CE00
00CF0000CF0000CF0000CE0000CE0000CE0000CF0000D000
00C40000C50000C50000C50000C50000C70000C70000C60000C80000C80000C80000C90000C900\
00C90000CA0000CB0000CB0000CC0000CC0000CD0000CE0000CD0000CD0000CB00
00C50000BB0000AD00009D00008E0000890000870000930000A20000B40000BE0000B800009600\
006800005C00006500006F00007D00008A0000930000990000A00000A40000A700
00A90000A400009500006B00005200005A00006700007F00008E00009A00009E0000A20000A900\
00AB0000AE0000AE0000AF0000B40000B80000C30000CD0000CF0000D00000D000
00D00000CF0000CE0000CD0000CB0000C60000C00000BA0000BC0000C30000CB0000CF0000CE00\
00CA0000C00000AA00008A00006B00005600004E00005300005B00006400007400
007500007D00008E0000A60000BB0000C80000CD0000CF0000D00000CF0000D00000CF0000CC00\
00C80000BE0000AF0000A000009D0000A70000B30000BD0000C50000CA0000CD00
00CE0000CF0000CE0000CE0000CE0000CF0000CF0000CF00
00C40000C60000C50000C60000C60000C70000C80000C70000C80000C90000C80000CA0000CB00\
00CB0000CB0000CB0000CC0000CE0000CE0000CF0000CF0000CF0000CD0000C600
00B700009900007C00006B00006200006A00007B00008700009100009800009E00009700007E00\
005800005200006000006D00008000008C0000960000990000A00000A40000A900
00A90000A700009B00007F00005700005C00006C00007E00008D0000990000A00000A70000AE00\
00B20000B20000B10000B00000B20000B50000BF0000CD0000D00000D10000D200
00D20000D20000CD0000C70000B800009F00008800007A0000800000920000AF0000C00000C500\
00BC0000A200007A00005B00004B00004700005000004F00004C00004B00004700
004B00005300005F0000720000900000B10000C70000CF0000D10000D20000D00000CE0000C600\
00B200009500007D00007B00009000009D0000A70000AE0000B80000C20000C900
00CC0000CF0000CE0000CE0000CE0000CE0000CF0000CF00
00C50000C50000C50000C50000C60000C70000C70000C70000C90000C80000C90000C90000CB00\
00CB0000CC0000CD0000CE0000CE0000D00000D00000CF0000CD0000CB0000BD00
009B00007400005E00005C00007100008000008700009000009500009C00009800008600006B00\
004C00004700005400006E00007F00008E00009600009E0000A40000AB0000AE00
00AD0000A90000A000008D00005D00006000006D00007E00008C0000990000A10000A80000AE00\
00B70000B90000B70000B40000B40000B60000BA0000CA0000D10000D40000D300
00D30000D00000C50000A900008300006000005A00006100006200006600008000009200009F00\
009200007100005200004800004700004B00004200003800003600003400003600
003A00003A00004500005000005F00007B0000A90000C90000D10000D20000D00000C60000AE00\
008700006E00007700008900009300009800009F0000A60000AB0000B30000BF00
00C80000CC0000CC0000CF0000CE0000CE0000CF0000CF00
00C60000C60000C60000C60000C60000C70000C80000C80000C90000C90000CB0000CC0000CB00\
00CC0000CC0000CD0000CF0000CF0000D00000D00000CF0000CD0000C50000AB00
007E00006000005C00006B00007900008300008A00009100009600009B00009C00009400008000\
005B00004500005600006A00007E00008D0000970000A00000A90000B50000B800
00AF0000AA0000A500009700006E00006300007000007E00009000009B0000A20000A80000B200\
00BE0000C60000C10000B80000B30000B40000B40000C50000CE0000D20000D300
00D20000C80000AB00007A00005C00005400005400004E00004800004600005100005D00006300\
005800004B00004900004300004900003D00003500002F00002C00002A00002900
002C00002F00003700004000004E00005B0000770000AF0000CC0000D00000CB0000B900008D00\
006C00006F00008400008B00009000009500009D0000A10000A80000AE0000B300
00BC0000C80000CD0000CF0000CE0000CE0000CF0000CF00
00C60000C60000C60000C60000C60000C70000C80000C80000C80000CA0000CB0000CB0000CB00\
00CC0000CC0000CD0000CE0000D00000D00000D00000CF0000CD0000C10000A100
006D00005900006200006800007500008000008A00009500009800009B00009F00009C00008F00\
007500004C00005500006700007C00008D00009900009F0000AA0000BE0000C400
00B60000AD0000A700009F00008400007900007200007B00008C00009A0000A20000A80000B200\
00BE0000CA0000C90000BA0000B50000B40000AE0000AF0000B80000C60000CD00
00CC0000B700008700005D00005000004E00003F00003700003600003300003800004000004900\
004200003900004000004300003D00002D00002900002800002700002200002400
002900002700002A00003300003D00004C00006000007B0000BD0000CD0000C50000A500007700\
006900007800008100008800008D00009400009B0000A10000A80000AD0000B000
00B50000BE0000C90000CD0000CD0000CD0000CD0000CD00
00C60000C50000C50000C60000C70000C80000C90000C80000C80000C90000CC0000CC0000CB00\
00CD0000CC0000CE0000CE0000CF0000D00000D00000CF0000CC0000BF00009D00
006600005500006500006700007500008400008E00009400009900009E0000A000009D00009700\
008900006300005300006800007C00009200009E0000A30000AD0000C00000C600
00B90000AE0000A80000A200009A00009D00007F00007F00008A0000990000A20000AB0000B100\
00BA0000C20000C50000BD0000BA0000B50000A900008900007E0000930000AE00
00B500009800005E00004D00004800003B00003000002E00002B00002B00002E00002F00003700\
003400002C00002D00002E00002E00002500002700002400002400002500002600
002400002500002A00002700002F00003800004A0000590000910000C90000BD00009400006F00\
006D00007000007B00008700009100009600009E0000A10000A80000AA0000AC00
00B30000B70000C20000CB0000CA0000C80000C50000C300
00C50000C70000C60000C60000C60000C80000C90000C90000CA0000C90000CA0000CB0000CB00\
00CC0000CE0000CD0000CE0000CE0000D00000D00000CF0000CB0000C000009D00
006800005700006100006400007600008600009000009700009C0000A30000A10000A20000A100\
009500007F00005900006C0000830000960000A10000A80000AB0000B50000BA00
00B30000AB0000AA0000A50000A90000B90000A20000800000870000950000A10000A80000B000\
00B60000BB0000BE0000BC0000B70000B100009D00006400005400005D00006A00
007500006400004400004000003A00002D00002900002600002600002800002B00002900002A00\
002900002800002400002600002600002400002200002800002300002400002400
002C00002F00002900002500002800002B00003C00004200006A0000C10000BA00008E00006A00\
006700006700007900008C00009300009B0000A30000A60000AC0000AC0000AE00
00B10000B50000BD0000C50000BF0000B10000A300009A00
00C50000C60000C60000C70000C70000C70000C70000C80000C90000C90000C90000CB0000CB00\
00CB0000CC0000CC0000CD0000CF0000D00000D00000CE0000CB0000C10000A700
007300005300006200006700007900008600009000009A0000A50000AB0000A90000A80000A400\
009E00009200007200006B00007E00009600009F0000A80000AA0000AC0000B000
00AD0000A90000A90000A80000AE0000C10000BB00009B00008000009200009B0000A50000AF00\
00B20000B70000B70000B80000B40000AB00007F00003F00003B00004200004600
004500003900003500003200002700002400002500002100002700002500002700002600002800\
002600002200002000002200002300002200002500002500002300002C00002F00
003D00004F00004000002E00002A00003000003E00003E0000590000BC0000BB00008F00006800\
006600006300007B00008E0000970000A00000A60000AB0000B00000B20000B100
00B40000B60000B80000B400009E00008700008500009000
00C60000C50000C60000C70000C70000C70000C80000C80000C90000C90000C90000CA0000CB00\
00CA0000CB0000CC0000CC0000CE0000CE0000CE0000CE0000CC0000C50000B200
008700005F00005E00006700007400008400008C0000990000AA0000B00000B60000B20000AB00\
00A500009D00008C00006F00007B0000900000A00000A90000A90000AA0000AB00
00AC0000A80000A700009F0000950000A10000AD0000B100009800008B0000980000A20000AA00\
00B20000B30000B50000B20000AC00009700005100002C00003000002F00003400
003600002D00002900002700002500002200002100002200002600002800002B00002B00002700\
002300002200001D00001F00001D00002000001F00002200002500002A00004200
008000009E00007F00003C00002900002B00004200004100005A0000BC0000BD00009700006500\
006400006300007C00008F00009A0000A30000AA0000B00000BA0000BF0000B800
00B50000B50000B50000A700008100008300009400009C00
00C40000C40000C60000C70000C60000C70000C80000C90000C80000CA0000CA0000CB0000CB00\
00CB0000CB0000CC0000CD0000CD0000CD0000CD0000CC0000C90000C20000B400
009200006300005800006500007100008200008D0000970000AA0000B30000BE0000BD0000B000\
00A70000A200009D0000870000860000890000980000A10000A50000A80000AB00
00AA0000AA0000A300008E00006100005D0000690000850000A000009E00009600009D0000A700\
00AD0000B00000B40000AD00009700006300002E00002B00002600002C00002D00
002B00002900002100002200002000001D00001E00002000002400002900003200003800002F00\
002500002400002300001F00002000002000002200002400002600002B00004800
00930000B300008F00004700002F00002900003400003F0000680000C10000BF0000A100006B00\
005D00005D00007E00009000009B0000A40000AC0000B40000C30000CA0000C100
00B90000B50000B30000A600007F00008700008E00009500
00C50000C50000C60000C70000C70000C90000C90000C80000C90000CA0000CA0000CB0000CB00\
00CD0000CC0000CD0000CD0000CD0000CC0000C80000C30000BA0000AB00009100
006700004800004600005C00006900007C00008B0000990000A60000B00000BA0000BA0000AE00\
00A80000A10000A000009F0000B500009800009300009E0000A10000A70000A700
00A70000A300008C00005F00003A00003900003F00004800006700009F0000B60000AB0000A700\
00A90000A90000A500008C00006300003D00002C00002700002700002900003100
002B00002600002000001E00001F00001B00001D00002100002300002D00004D00007300003F00\
002C00002900002200002300002400002900002400002300002800002600003900
006000007200005300003D00003100002900002F00003700006B0000AE0000AB00009400006B00\
005100005D00008200009500009C0000A70000AC0000B30000BE0000C50000C000
00B90000B60000B30000A500007D00007C00008600009200
00C50000C70000C70000C70000C80000C90000C90000CA0000C90000CB0000CC0000CC0000CC00\
00CE0000CE0000CE0000CE0000CC0000C70000B800009F00007E00006200004900
003B00002D00002E00004A00006500007700008A0000960000A00000A60000AA0000AC0000AC00\
00A80000A50000A00000A70000C60000BE0000A300009800009C0000A000009E00
009A00008700005A00003C00003800003800003700003B0000440000630000AE0000C90000C200\
00AF00009100007800004C00004000005100004000002300002700003600005300
003D00002900001E00001E00001D00001B00001B00001D00002400003000005E00009200006400\
003500002B00002800002600003D00003400002B00002700002B00002900003100
003800003900003300003000002C00002E00003100004100007800009100008300006D00005500\
005100006000008100009200009C0000A90000AD0000B20000B80000BA0000B900
00B70000B30000B100009E00007700007F00008D00009600
00C50000C60000C70000C70000C80000C90000CA0000CA0000CB0000CB0000CC0000CD0000CE00\
00CE0000CE0000CF0000CD0000C40000B100008C00006300005100004800004200
003700002800002300003100005100007100008400008F00009800009E0000A10000A50000A600\
00A40000A20000A00000AA0000C60000CA0000C60000B80000A900009700008400
007200004F00003700003300003500003800003C00004000004B00004300006C0000C00000CC00\
00BC00009100006600003900003A00004900004300002800002E00005700009B00
006300002C00002500001D00001E00001B00001F00001C00002000002D00005B0000AA00009C00\
004100002900002700003000008400008B00003D00002C00002B00002B00002D00
003000002F00002C00002600002D00003200004300005C00008100009200008D00007F00006B00\
005800005F00007C00009000009D0000A80000B00000B30000B50000B70000B500
00B40000B30000AC00008F00007300008200009000009C00
00C60000C60000C60000C80000C80000C90000CA0000CA0000CD0000CC0000CC0000CD0000CE00\
00CF0000CF0000CD0000C80000B300008B00006100004E00004A00004100003500
002700002200002000002000003600006000007700008A00009500009700009C0000A20000A200\
00A300009C00009600008E0000A90000C20000CA0000CB0000C30000AB00007900
005600003A00003300003400003500003900004600004F00005900004B00004E0000A00000CD00\
00C60000A700007100003C00002D00003200002600002400003000006200009C00
005700002B00002400002000002000001C00001D00001A00002100002C0000520000AC0000A700\
004B00002C0000280000330000980000B600008500004500003700003300003300
003400002F00003000003000003600004500006000007500008B00009A00009F00009D00009400\
008000006B00007600008E00009A0000A50000AB0000B00000B20000B40000B200
00B00000AD00009F00007700007400008700009000009C00
00C60000C70000C70000C70000C80000C90000CA0000CC0000CC0000CC0000CD0000CE0000CF00\
00CF0000CF0000CA0000BD00009A00006900005000004700004500003200002600
001F00002100001C00001E00002100003B00006200007C00008900009200009500009B0000A000\
00A000009700008000005E00006E0000960000BC0000C90000C70000B200008500
005900003500003000003100003500004800007400007F00006D00006000004D0000750000C900\
00CD0000BB00009000004900002D00002900002400002500002E00003E00004E00
003500002A00002900003400002000001A00001B00001E00001E00002600004300008A00008500\
004100002A00002800003300007400009F00009600007C00006100005300004900
004100003700003B00004400005700007200008000008F0000990000A20000A60000A70000A600\
00A000008F00007F00008D0000990000A40000AA0000AD0000B10000B00000AF00
00AC0000A200008700006B00007F00008F00009700009A00
00C60000C70000C70000C80000C90000CA0000CA0000CA0000CC0000CD0000CD0000CF0000CF00\
00D00000CD0000C40000AE00007D00005900004900004600003400002500002100
001D00001B00002000001F00002000001F00003600005B00007100008200008B00009400009400\
009100007900004600003400003C00005000007C0000B00000C50000BA00009400
006300003900003000003500003900004C0000900000AC00007F00006B0000510000600000BD00\
00C70000B800009400004F00002D00002900002900002900002E00002F00003300
002D00002F00004300005200002900001E00001C00002000001F00002900003600005100004600\
003400002600002800003100005400006C00007200007800007900007200006300
005400004E00004D00006800008000009000009700009F0000A60000A70000AA0000AC0000AB00\
00AA0000A600009B00008F0000970000A10000A80000AA0000AB0000AC0000AA00
009E00008200006800006900008400009000009E00009D00
00C60000C70000C70000C90000CA0000CA0000CB0000CD0000CC0000CD0000CE0000D00000D100\
00D10000CC0000C000009D00006A00005400004A00003900002700002500001F00
002000002000002100002400002700002400002400003000004C00006100006D00007100006700\
005200003A00002900002A00002D00003400004100005C0000AE0000C00000AB00
007D00004700003000003300003700004B00008B0000B900009300006E00005600005500009600\
00A000008900006D00005300003600003100002B00002D00002D00002D00003300
003800005500008D00007E00004100002200002100002000002100002500002C00003200003300\
002C00002600002C00003700005200006400006F00007A00008100008B00007E00
006300005000005C00007E00009000009A0000A20000A50000AA0000AA0000AF0000B00000B100\
00AF0000AC0000A70000A300009C0000A90000AC0000A90000AB0000B10000B200
009D00006D00005A00006800008900009600009F0000A200
00C60000C70000C80000C80000C90000CA0000CB0000CC0000CD0000CD0000CF0000D00000D100\
00D00000CA0000BA00009100006300004E00004500002E00002200001D00002000
001E00002100002600003700002C00002500002100002200003500003F00004100003500002A00\
002700002700002600002400002700003000003300003B0000630000B90000BB00
009F0000670000300000320000340000460000730000AB00008800006100004E00004600006000\
006D00006E00006900005800005100004400003B00003500003600003800004100
00710000AC0000B800009D00006100002C00002200002200001E00002200002700002600002700\
002400002800003000003B00005800007500008A0000990000A30000AC0000A900
009700006800007000008D00009800009F0000A30000A80000AB0000AE0000B20000B50000B500\
00B40000AF0000AD0000AA0000A80000B80000C10000BD0000BC0000B90000B200
009700006800004F00006000008400009500009D0000A300
00C60000C60000C70000C80000C90000CA0000CA0000CA0000CB0000CD0000CE0000D00000CF00\
00CF0000C90000B900008B00005E00004D00003F00002800001E00001E00001D00
001A00002400004000007D00004700002100002000002200002E00003300002E00002200002500\
002500002100002200002700002700002A00002B00002C00003E00009A0000BC00
00A900007A00003700003000003500003D00005300006700005500004300004100003F00005600\
006D00007400007600007500007F00007B00006F00006100005D00006800009E00
00BE0000C70000BE00009F00006B00003500002200001C00002100002200002600002400002600\
002800002C00003500004A0000770000940000A80000B10000B50000BB0000BB00
00B300009300007F00009000009D0000A10000A80000AB0000AE0000B30000B80000BF0000C300\
00BC0000B70000B40000B10000AC0000AD0000AF0000A100009100008500007600
005D00004400003D00005400007A00009000009C0000A600
00C50000C60000C70000C70000C80000CA0000CA0000CB0000CC0000CD0000CE0000CE0000CF00\
00CF0000CC0000BB00009300006400005500003600001F00001C00001700001A00
001E00002B00005C00009A00004F00002200002100002200002C00003000002500001C00002100\
001F00002300002000002400002B00002C0000290000280000320000610000A300
008A00005E00003500002E00002F00003300004200004500004100003E00004000003F00004E00\
006300007A00008B00009400009E0000A10000A30000A100009D00009E0000B300
00C60000BF0000A700007F00005300003A00002D00002400002100002000002400002300002300\
002C00002E00003C00006800008F0000A60000B40000BB0000BF0000C30000C100
00BE0000AF00008D00009200009C0000A40000A70000AB0000AE0000B20000B80000C30000CA00\
00C20000BD0000BA0000B60000AF0000A200007900006100006000006400005900
003E00002A00002C00003F00006E00008E00009C0000A300
00C50000C60000C60000C70000C90000CA0000CB0000CC0000CC0000CD0000CE0000CE0000CF00\
00D00000CC0000C10000A500007500005B00003700001F00001E00002200002600
001E00002800004000005A00003100002100001F00002200002B00002D00001B00001B00001E00\
001B00002000002400002A00004200004900002F00002A00002900003800005F00
005300003F00003100002900003100003800003E00003D00003C00003B00003A00003E00005800\
00770000930000A20000AB0000B20000B40000B50000B50000B60000B40000B100
00B400009E00007600005900004700003400002900002800002600002000002000002300002800\
002E00003300004700007D00009D0000B10000BB0000C10000C70000C70000C600
00C30000BC00009F00009100009B0000A30000A50000AB0000AE0000B30000B50000BC0000C200\
00C00000BD0000B90000B70000AE00009C00005F00005600005300004600003800
002B00002400002100002A00005800008900009C0000A300
00C60000C50000C60000C70000C70000C80000CA0000CB0000CB0000CB0000CC0000CF0000CE00\
00CF0000CE0000C80000B900009700006B00003700002000002300003000003D00
002700002700002C00002B00002200002000001F00002600003100002200001C00001800001E00\
001D00002300002200003500007E00008900003F00002C00002800002900003900
003700003600002900002600002A00003500003900003A00003C00003700003B00005200007800\
00940000A60000B00000B80000BC0000BF0000BD0000BE0000C00000BD0000BB00
00AA00007B00005800004B00003E00002700002000001F00002300002700002200002400002900\
002D00003300005800008C0000A40000B50000C00000C60000CC0000CC0000C800
00C60000C10000AF0000970000980000A10000A70000A90000AD0000B30000B40000B80000B900\
00B90000B90000B70000B50000AF00008F00004C00003600002E00002900002900
002900002A00002900002700003900006E00009100009F00
00C40000C50000C60000C60000C70000C70000CA0000C90000CB0000CB0000CB0000CE0000CE00\
00CF0000CF0000CC0000C60000B700009700004900002900003000003600003D00
004100002600002300002300001F00001B00001E00002600002F00001E00001D00001800001E00\
001900001D00002500003E0000A000009700003D00002500002200002300002F00
002B00002A00002600002700002C00002C00003100003500003400003700004200006900009000\
00A40000B10000B90000BE0000C00000C30000C30000C20000C50000C30000C000
00B400008500004B00004300002F00001D00001A00001B00001E00001C00002100001F00002200\
002D0000370000640000940000AA0000B80000C20000C70000CC0000CC0000C800
00C70000C10000B500009E00008900009A0000A20000A60000AC0000B00000B20000B50000B700\
00B60000B60000B60000B30000A700007200002F00002900002A00002B00002A00
002E00002D00003100002F00003100004300007200009000
00C40000C50000C60000C60000C60000C80000C90000C90000CA0000C90000CB0000CD0000CD00\
00CD0000CE0000CF0000CC0000C80000B900007B00002D00002800003600004000
003A00002300002400002200001C00001E00002400003300002E00001D00001A00001B00001D00\
001E00002100002300003600006C00006300003300002500002500002000002500
002200002400002A00002B00002E00002F00003100002D00002C00003200004D00007E00009D00\
00AC0000B60000BB0000C10000C40000C70000C90000C90000C90000C80000C600
00BB00008D00004400002C00002200001B00001B00001B00001E00001C00001A00001800001C00\
002500003700007300009B0000AD0000BB0000C00000C60000CB0000CB0000C900
00C70000BF0000AB00007500006700008800009B0000A50000AE0000B10000B00000B00000B400\
00B50000B40000B20000AC00008E00004300002A00002A00002B00002800002D00
003300003300003400003100003400003800004700005800
00C30000C50000C40000C40000C70000C70000C80000C80000C90000C90000CB0000CB0000CD00\
00CD0000CE0000CF0000D00000CE0000C80000AF00005600002800002C00003600
001F00001F00001E00002100001F00002000003100003100002A00001D00001C00001B00001A00\
001F00002100002100002900003400003000002800002200002300001B00001D00
002100002500002800002E00003100003400003200003100002C00003300006100008E0000A700\
00B40000B90000BE0000C30000C60000CB0000CF0000D00000CC0000CB0000C700
00BD00008D00003600002400001E00001D00001C00001B00002200001F00001C00001B00001900\
002100003800007D0000A10000B20000BA0000C00000C50000C80000C90000C900
00C70000BF00009A00004D00003B00005300008000009A0000A70000AB0000AD0000AF0000B300\
00B40000B20000AC00009600005E00002C00002900002900002A00002900002D00
003200003900003B00003A00003400003500003600003500
00C30000C40000C50000C60000C50000C60000C90000C80000CA0000CA0000CB0000CB0000CD00\
00CD0000CD0000CF0000CF0000CE0000C80000B900008B00004700002E00002500
002100002200002400002500002200002300002A00002A00002800001C00001D00001D00001A00\
001D00001F00001F00002800002A00002400001F00001D00001C00001C00001E00
002300002900002C00003100004200004400003700003100003100003800006D0000950000AC00\
00B60000BB0000C00000C30000C80000CD0000D10000D10000CD0000CB0000C800
00BA00007D00003200002700001F00001C00001B00002200002900002400002100001F00001C00\
001D0000390000820000A40000B30000BA0000C00000C40000C70000C80000C800
00C30000B500007E00003A00002E00003300004900007100008E00009C0000A30000AA0000AF00\
00B10000AF00009A00007500003F00002700002800002800002B00002C00003000
003D00004B00005200004300003600003800003700003000
00C40000C40000C40000C40000C50000C60000C60000C80000C80000C90000CA0000CB0000CB00\
00CD0000CD0000CE0000CE0000CC0000C10000A600007600004900003A00002600
001F00002100002300001F00001F00002300002400002600002200001C00001D00001800001C00\
001C00001F00002100002600002100002000002000002000001E00002900001D00
002300002500002C00003800006E00007D00003F00003500003400003D0000730000980000AD00\
00B90000BE0000C10000C40000C80000CC0000CE0000CE0000CA0000CA0000C700
00B300006900002F00002600001B00001B00002000002800003F00005500002D00002000001900\
002200004200007B00009F0000B10000BA0000C00000C30000C50000C50000C500
00BF0000A300005300003500003300003000003700003D00004E00006400007D00009E0000B700\
00BA0000B100008B00006200003700002700002800002800002800002A00003200
004600007800009800006100003D00003B00003400002800
00C50000C40000C40000C50000C60000C70000C70000C70000C80000C90000CA0000CB0000CC00\
00CC0000CD0000CE0000CD0000C70000B100008100005300004100003800002A00
002200002100002100002600002700002800002800002900002200001F00001F00001B00001B00\
001E00001E00002000001F00001F00002100001F00001E00002A00003A00001F00
002300002800002C00003500005200006600003E00003700003700004000007200009A0000AE00\
00B80000BE0000C10000C30000C70000CA0000CB0000CA0000C90000C90000C200
00A500005600002E00002000001C00001A00001F00003600007500009F00005100001E00001C00\
00240000600000880000980000AF0000B90000C00000C20000C40000C40000C000
00B400007E00003F00003900003300003300003300003700003800003800004200007C0000C400\
00CA0000C20000A300007700003D00002600002600002700002B00002C00003400
004600007C0000AB00007300003E00003600003300002E00
00C30000C40000C40000C50000C50000C70000C70000C80000C80000C90000CA0000CB0000CB00\
00CD0000CE0000CE0000CC0000C10000A300006F00005000004700003A00002C00
002400002800002700002800002E00002F00003100003000002C00002400002400001D00001D00\
002100001D00001D00002000001F00002200001F00001E00002600002700001E00
002500002800002B00003400003900003E00003C00003A00003B0000440000640000920000AA00\
00B50000BE0000C00000C10000C70000C90000CB0000CA0000C80000C60000BB00
009300005B00002D00001E00001C00001A00002100002B00005400008100004300001C00001C00\
002500004B0000790000810000A60000B60000BE0000C00000C10000C10000B900
009300004B00003A00003B00003400003400003800003B00003C00003F00003B00004E0000B000\
00CE0000CC0000BE0000A000005900002A00002C00002B00002D00003000003500
003F00005D00007B00005200003900003700003500002A00
00C40000C40000C40000C50000C50000C70000C80000C80000C80000CA0000CB0000CA0000CB00\
00CE0000CE0000CE0000CB0000C000009F00006700004F00004200002B00002400
002500002700002A00003000003000003E00004400003900003000002F00003400002B00002000\
002300002600002200002200002100001B00001D00001700001A00001900001900
001E00002400002800002E00003600003A00003B00003E00003F0000470000540000800000A200\
00B40000BC0000BF0000C30000C60000C90000CA0000C90000C70000C20000B900
009500006700002F00001E00001F00001D00001F00002400002C00003400002600001F00001E00\
002500003600004E00006100008C0000AE0000BA0000BE0000BE0000B800009900
005A00003E00003600003400003600003400003600003A00003F00003A00003900004400008200\
00CA0000CF0000CA0000BD00008B00003600002E00002B00002E00003100003400
003C00004600004600003E00003B00003600003000002A00
00C30000C40000C40000C30000C60000C60000C80000C70000C80000C90000C90000CB0000CC00\
00CC0000CE0000CD0000CC0000C30000A600007300005300003F00002900002200
002300002400002B00002F00003E00007C00008700004000003600003800006000005E00002600\
002100002300002300001E00001E00001900001500001500001600001600001A00
001C00002200002700003100003300003800004000004400004900004900005700007800009900\
00AF0000B90000BC0000C10000C40000C70000C60000C30000C40000C90000C400
00AD00008100003C00002500002000001F00002200002000002400002300002100002300002600\
002900003500004C00005E00007E00009E0000B10000B40000AA00008900005E00
003E00003700003500003200003500003900003900003D00004200003C00003B00004100006000\
00BD0000CB0000C90000C40000B500006900003700003200003000003300003600
003700003C00003C00003C00003800002F00002700002600
00C30000C30000C50000C40000C40000C60000C70000C60000C80000C80000C90000CA0000CC00\
00CD0000CE0000CD0000CC0000C70000B700009200006500003F00002900002500
002A00002900002C00003300004A00008900008300004100003800003D00007000005F00003500\
002800002100001900001A00001800001900001500001700001400001600001600
001F00002600001E00002500003000004400004A00004C00004A00005500007C0000970000A400\
00AD0000B50000BA0000BF0000C20000C30000C10000BF0000C40000CF0000CE00
00C30000A300004F00002400001D00001D00001D00002100002300002000002200002200002900\
002800003800005A00008200009D0000AD0000B50000B40000A700007F00004D00
003C00003100003500003200003700003C00004300004900004F00004A00003F00004100004E00\
00960000A800009E00009A0000A000009700006300004200003700003800003800
003700003800003A00003A00003300002E00002B00002700
00C20000C30000C40000C40000C40000C60000C60000C70000C70000C80000C90000CA0000CB00\
00CC0000CD0000CD0000CC0000CB0000C50000B200008F00005300002B00002800
002C00002F00003100003600003D00004B00004500003600003900004500007C00005300003100\
002900001C00001B00001900001800001800001A00001600001500001700001D00
002600003300001F00001B00002200003400004200004400004E00007500009A0000AA0000B200\
00B70000BA0000BD0000C00000C30000C50000C40000C20000BD0000CB0000CE00
00C60000B100006F00002E00002000001E00001E00001B00001E00002000002100002500002700\
002E00005000007D00009E0000B00000BB0000BF0000BD0000B80000A200005900
003E00003400003400003300003A00004000005200007800008F00006900004500004000004200\
005C00006D00007200007300007100007B00008400007400005100004100003900
003700003100002F00002F00002E00002E00002E00002C00
00C30000C30000C40000C40000C50000C60000C60000C70000C70000C70000C90000CA0000CC00\
00CB0000CC0000CD0000CD0000CC0000CA0000C50000B500007D00003000002B00
002F00003100003300003600003A00003D00003B00003700003500005700007300004700003100\
002500001C00001700001A00001900001800001600001700001500001A00002300
002D00004200003000001A00002100002200003400004100006300008E0000A40000B00000B700\
00BB0000BD0000C30000C50000C90000CA0000CA0000C70000C30000BE0000C300
00B300008E00005900002B00002100002000001F00001E00001E00002000002300002300002500\
003E0000720000980000AE0000B80000C00000C10000C20000BF0000B300007F00
004A00003A00003200003400003A00004600006300009D0000B500008200004A00003F00004400\
005300006500006E00007300007500007E00008300007A00005600003E00003800
003000002C00002D00002E00003000003000002F00003000
00C40000C50000C40000C40000C50000C60000C70000C60000C70000C80000C90000CA0000CB00\
00CC0000CC0000CC0000CD0000CD0000CD0000CB0000C50000AA00005200003000
002E00002F00003100003300003500003700003700003500003400003B00003B00002E00002800\
002200001D00001C00001800001800001A00001A00001600001600001800001C00
002500002600002100001E00001B00002300003000004800008000009D0000AA0000B00000B700\
00BC0000C00000C40000CA0000CE0000CE0000CE0000CA0000C40000B600009800
007600005700004100002E00001F00001F00001E00002300002300002500002100002700003100\
005900008A0000A60000B70000BE0000C10000C30000C40000C20000BC00009F00
005D00004600003800003600003900004000005200007500008A00006700004B00003E00004700\
005000005A00007200008200008E00009700009C00009300006C00003A00002E00
002900002C00002F00003000003200003100003300003300
00C30000C50000C50000C40000C40000C60000C70000C60000C80000C90000C90000CB0000CB00\
00CC0000CC0000CD0000CE0000CF0000CE0000CC0000C50000B600008500004300
003500003500003400003100003100003400003600002F00003600003200002900002300002300\
002000001A00001500001700001600001700001400001600001800001900001C00
001D00001C00001D00001D00002200002400002D00005500008C0000A00000AB0000B00000B500\
00BC0000C10000C90000CE0000D10000D30000CF0000C90000C30000B100007300
005100004B00004200002900002200002600002100002600002700002700002200002A00003F00\
007500009C0000B10000BC0000C30000C50000C70000C80000C60000C10000B000
007500004D00003D00003A00003B00004000004600004D00005200004E00004200004200004B00\
005200007000008B00009700009E0000A70000A80000A500008700003D00002B00
002C00002E00002F00003500003300003800003B00003A00
00C40000C50000C60000C60000C60000C70000C80000C80000CA0000C90000CA0000CC0000CB00\
00CD0000CD0000CE0000CF0000CF0000CE0000CA0000BE00009F00007200004900
003B00003400003100002E00002900002F00002600002100002000002600002100001C00001C00\
001E00001C00001700001500001400001900001900001B00001D00001D00002200
00210000230000210000200000260000270000350000640000930000A40000AB0000AE0000B400\
00BC0000C40000CA0000D00000D20000CF0000CB0000C80000C20000AE00006200
004B00004800003100002800002600002900002900002A00002A00002C00002700002600004A00\
00880000A40000B50000BF0000C50000CA0000CA0000CA0000C70000C40000BA00
009700005F00004500003B00003E00004200004100004600004500004400004300004500004E00\
006600008A0000980000A10000A90000B00000AF0000AB00009200004100002F00
002D00002E00003300003600003900004300004C00004400
00C40000C50000C70000C60000C60000C80000C90000C90000CA0000CA0000CC0000CC0000CE00\
00CE0000CF0000D00000D10000D10000CF0000C30000AB00007B00005100004400
003700002A00002100002500002100002200002200002200002000002500001F00001C00001800\
001800001A00001700001800001B00001A00001F00001D00001E00002300002E00
003C00004A00003100002100002B00003000005000008F0000910000A40000AB0000AE0000B300\
00BC0000C40000CA0000CE0000CE0000CA0000C80000C70000BF00009F00004A00
003800003000002D00002900002C00002A00002E00003000003000002F00002B00002800005A00\
00930000AD0000B80000C00000C80000CE0000CE0000CB0000C90000C60000BE00
00A200006A00005200004800004300004100004400004700004700004500004900004A00005500\
007700009300009F0000A80000B10000C00000BA0000B000009700004500003200
002F00003000003600003800004600007200009000005D00
00C50000C60000C70000C70000C60000C90000CA0000CA0000CA0000CA0000CB0000CD0000CD00\
00CF0000CF0000D00000D20000D00000CB0000B900009100005F00004D00004000
003800002A00002000001F00001B00001C00002300002F00002500002A00003400001C00001A00\
001C00001D00001800001B00001B00001D00002000001B00001F00002B00004100
007D00009D00006100002800002A00003800007D0000B600009C00009F0000A80000AA0000B300\
00BB0000C30000C80000CA0000C80000C80000C70000C30000B300007700003E00
003300003200002F00002D00002F00002F00003400003A00003D00003700002F00002B00005C00\
00960000B00000BA0000C10000C80000CE0000CC0000CB0000CA0000C70000C000
00A400006E00006300005D00005100004C00004E00005000004F00004D00004E00004B00006100\
00800000930000A20000AD0000BD0000CB0000C20000B100009700004600003300
003300003100003400003B0000540000940000AF00006500
00C30000C60000C70000C70000C70000C80000C90000CA0000CB0000CC0000CC0000CD0000CE00\
00CF0000D00000D10000D20000D10000CA0000B100007F00005800004C00004400
002F00002700001C00001D00001C00001E00002300003A00003700003600002E00002400001F00\
001C00001E00001B00001D00001E00002200002000001F00002300002C00003700
005800007400004800002600002700003A00009A0000C00000B200009900009F0000AB0000B200\
00B90000C20000C60000C70000C70000C70000C40000B900009100004A00003E00
003400002F00002F00002C00003000003600003C00003F00004100003A00003100002E00005400\
00950000B00000BB0000C00000C50000CA0000CA0000C90000C90000C70000C000
00A200008B00009000009600008700007400007000006B00007000007600006800006200006E00\
008700009A0000A80000B30000C10000C80000BB0000B000009100004500003300
003200003100003800003C00004B00007100008A00005800
00C40000C50000C60000C70000C80000C90000C90000C90000CC0000CC0000CC0000CE0000CF00\
00CF0000D00000D10000D10000D10000C80000AE00007C00005B00004F00003F00
002700002200001D00002000001E00001C00002200003100003000002A00003100003000002500\
002300001F00001E00002000002300002300002300002200002500002400002D00
003100003600002D00002B0000320000510000AE0000B70000A20000840000880000A00000AE00\
00B80000BF0000C30000C50000C60000C30000B800009800005800003B00003600
002F00003000003200003300003400004500006500006700004700003A00003300003200005000\
00900000B00000B90000C00000C50000C80000C80000C80000C60000C40000BB00
00A70000A70000AE0000B30000B30000B10000AD0000AD0000AB0000A700009100007C00007D00\
009000009F0000A90000B10000B90000B90000B40000A800008300004800003700
003500003200003700003A00004300004D00005700004A00
00C40000C50000C70000C70000C60000C90000C90000CA0000CB0000CB0000CC0000CD0000CF00\
00CE0000D00000D10000D20000D10000CA0000B300008400005F00005200003700
002300001E00002000001B00002000001F00002400002600002D00004600007400007D00004200\
002C00002200002500002200002800002400002500002500002700002900002A00
002C00002D00002C00002F00003E0000820000AD00009600007700006400006700007900009500\
00AD0000B90000BE0000C20000C00000B500008B00005700004100003800003000
002F00002C00003100003800004400007A0000AA00008E00004700003700003900003700005100\
00810000AC0000B90000BE0000C10000C50000C70000C60000C40000BD0000AE00
00AE0000B30000B80000BB0000BD0000BE0000BF0000C00000BC0000B90000B000009700008400\
009800009F0000A70000AD0000B20000B10000AD00009900005E00004400003700
003500003600003800003900004000004600004900004500
00C40000C50000C60000C70000C70000C90000C90000C90000CA0000CC0000CC0000CE0000CE00\
00CF0000CF0000D10000D20000D10000CD0000BF00009F00007200005A00003200
001F00002000001F00002000001F00001F00002300002B0000370000660000A100009900004700\
002A00002900002C00002600003300002E00003100002E00002E00002A00003600
003100003400003700004500006C00009900008800006E00006000006400006B00006C00008700\
00A10000B00000B80000BC0000BC0000AF00008500004B00003B00003300003000
003000002E00003500003C00004C00007A00009300006300004200003C00004100004200004E00\
006800009C0000B30000BC0000C00000C20000C50000C20000B80000A50000A500
00B20000B70000BB0000BE0000C00000C20000C40000C50000C30000C00000BB0000B300009F00\
009900009F0000A40000AC0000AD0000AF0000A500008A00005F00004400003E00
003600003700003900003A00003E00004800004A00004400
00C40000C40000C60000C60000C70000C80000C90000C90000CA0000CC0000CC0000CE0000CE00\
00CF0000D10000D10000D20000D30000D10000C90000B800009A00006900002D00
002100002100002000002000001F00002000002400002900002D00004200005E00005400003200\
002A00002700002A00002D00003600003900005300005B00005A00005800005700
005D00006C00007C00008D00008F00007D00006400005B00006000006E00006400008000009C00\
00AB0000B40000BC0000BF0000C10000BA00009F00005700003F00003000003200
003000003300003700003E00004600004D00005000004700004100004200003E00004800004B00\
005E00008C0000AB0000BA0000C00000C10000C10000BA00009D0000840000A400
00B40000B90000BD0000C00000C30000C50000C60000C60000C60000C40000C20000BE0000B500\
009700008C0000960000A10000A60000A90000A20000A300009700007300004F00
004000003800003A00003D00003E00004300004700004500
00C50000C40000C60000C60000C70000C90000CA0000CA0000CA0000CB0000CC0000CD0000CE00\
00CF0000CF0000D00000D20000D20000D20000CE0000C80000B500008900003800
002300002500001F00002300002100002300002300002300002500002C00003000002E00002B00\
002700002900002600002F00003B00004100006900007D00008800009100009200
00980000A00000A60000A500009B00007C00005500005700006B0000630000730000960000AA00\
00B30000BA0000BF0000C10000C10000BF0000AF00006F00004400003300003000
003000003300003800003D00004300004100004600006700006200004C00004400004900005500\
00800000A00000B20000BC0000C00000C20000C00000B90000A30000820000A500
00B30000BA0000BE0000C10000C40000C90000C90000C90000C90000C70000C60000C40000BE00\
00A500007000007D0000930000A50000B00000AF0000B30000B10000A500007D00
005900004400003D00003C00003F00004100004200004000
00C50000C50000C50000C60000C80000C80000C80000CA0000CB0000CB0000CB0000CE0000CD00\
00CF0000D00000D00000D10000D20000D20000CF0000C50000AF00007F00004200
002900002600002400002300002200002400002300002500002300002700002A00002800002700\
002B00002800002A00003A00003700004600006E00008400009000009600009F00
00A60000AA0000AE0000AA0000A200008700005000004F00005700006700008E0000A80000B200\
00B90000BE0000C20000C30000C40000C30000BB00009200005300003D00003500
003400003700003A00003A00003F00003F00004C00006100005000004600004600004900006800\
00990000B00000BA0000C00000C30000C30000C20000BF0000B700009B0000A700
00B20000B90000BE0000C20000C40000C90000CC0000CD0000CB0000C90000C70000C70000C300\
00B30000840000920000A30000AD0000B70000BA0000BB0000BC0000BA0000AF00
008900005A00004600003F00003D00004100003F00004200
00C60000C60000C60000C60000C60000C70000C90000CA0000CB0000CB0000CD0000CE0000CF00\
00CF0000D00000D00000D30000D30000CF0000C60000AD00008100005700004400
003100002800002700002500002300001F00002000002100002500002600002600002600002900\
002900002800002C00003000003200004600007000008900009200009C0000A300
00AF0000B80000B50000AD0000A600008800004A00005000005C0000830000A20000B00000B600\
00BC0000C10000C50000C60000C60000C70000C10000B100007700004800003500
003400003400003800003B00003B00004200005C00005200004200003800003F00004900007A00\
00A30000B50000BB0000BF0000C20000C40000C30000C50000C00000B70000AB00
00B20000B80000BF0000C20000C70000C80000CC0000CE0000CC0000CA0000C80000C70000C500\
00B800009D0000A60000AC0000B30000BA0000BE0000BD0000C10000C20000C000
00B300009200006300004D00004400004300004600004900
00C40000C60000C70000C60000C70000C80000C90000CA0000CB0000CC0000CD0000CF0000D000\
00D00000D00000D00000D10000CF0000C50000AB00007D00005900004C00003E00
002F00002900002700002800002200002600002300002600002700002800002500002B00002A00\
002700002B00002800002300002A00004400007000008700009200009D0000A700
00B40000C40000BC0000B00000A500007F00004600005800007800009A0000AC0000B40000B900\
00C00000C40000C70000C80000C80000C80000C60000BF0000A100006A00004500
003C00003800003A00003B00003C00003A00003500003000002F00002A00003400004800008400\
00A80000B70000BD0000C00000C30000C40000C40000C50000C40000BE0000AC00
00AF0000B60000BE0000C20000C60000C70000C90000CC0000CB0000C90000C90000C70000C400\
00B80000A50000AB0000B30000B70000BE0000C00000C10000C60000C80000C500
00C20000B900009B00007100005A00005300005000005C00
00C40000C60000C60000C60000C70000C90000C90000CA0000CA0000CB0000CC0000CF0000CF00\
00D00000D00000D10000D00000CB0000B600008A00006300005000004700003900
003200003000002A00002800002800002900002600002800002500002600002300002500002900\
002B00003000002E00002900002500004000007400008A0000990000A30000AB00
00B50000C00000BB0000B00000A400007500005000006900008A0000A30000AF0000B80000BF00\
00C40000C70000CC0000CC0000CC0000CB0000C90000C30000B200008900005E00
004900003B00003400002F00002B00002B00002700002600002800002200002600004600008800\
00AA0000B70000BC0000C20000C30000C40000C50000C70000C60000C10000B200
00A30000AF0000B90000C00000C30000C50000C80000C90000C90000C90000C80000C50000C100\
00AD0000A30000AB0000B40000BB0000BF0000C30000C40000CB0000CA0000C900
00C60000C10000B500008F00006E00005F00006300007700
00C40000C50000C50000C60000C70000C80000C80000C90000CB0000CB0000CC0000CF0000CE00\
00CF0000CF0000CF0000CC0000C100009F00006F00005A00004D00003C00003400
003000002E00002F00003000002D00002E00002600002700002600002400002400002700003000\
003100003300003400003000002A00003C00006B00008A00009A0000A50000AD00
00B10000B40000B50000B10000A100006A00005C0000790000950000AA0000B50000BD0000C200\
00C60000CC0000D00000D10000CF0000CB0000C90000C30000AF00007F00006400
005000003700002700002500002500002600002800002100002600002500002700003E00008600\
00A70000B40000BB0000C00000C30000C60000C60000C70000C70000C40000B300
008300009D0000B10000BB0000C00000C30000C50000C80000C70000C70000C60000C20000B800\
008F00009B0000A80000B40000BB0000BE0000C30000C70000CF0000CE0000CB00
00C80000C70000BD00009B00007300006900007600008F00
00C30000C40000C50000C70000C70000C70000CA0000C80000C90000CA0000CC0000CD0000CE00\
00CE0000CE0000CE0000C90000B800008F00006400005800004900003500003400
002F00003100003200003700003300002F00003100002A00002A00002200002A00002C00003200\
00370000360000370000370000320000340000600000870000990000A30000A900
00AC0000B00000B20000AD00009F00006200006300008200009C0000AD0000B90000BF0000C500\
00CA0000CF0000D10000CF0000CE0000CC0000C70000BE00009D00007000005B00
004F00003100002E00002500002500002800002700002600002700002300002300003400007B00\
00A30000B30000BA0000C00000C30000C90000CA0000C90000C70000C30000B000
006B0000650000960000B00000B90000BF0000C20000C40000C50000C30000C20000BD0000AC00\
00850000890000A10000B30000BA0000C00000C10000C90000D00000CE0000CC00
00C90000C70000BF0000A700007700007400008800009900
00C30000C40000C60000C70000C70000C80000C80000C90000C90000CB0000CB0000CD0000CD00\
00CE0000CF0000CD0000C60000B200008200006200005600004100003000002F00
003100003400003400003C00003B00003700003300002E00002C00002800002C00002C00003600\
003900004100004800003F00003700003600004D00007E0000960000A20000A700
00AB0000AE0000AF0000AC00009D00006900006A0000860000A20000B20000BC0000C30000C900\
00CC0000CD0000CD0000CE0000CC0000CA0000C70000B300008300005F00004F00
003F00002E00002C00002500002400002800002B00002E00002A00002900002100002F00006E00\
009E0000B10000BB0000C10000C40000CB0000CC0000CA0000C80000C20000A700
00560000420000580000880000A40000B10000B80000BC0000BE0000BE0000BB0000B300009A00\
007000006F0000960000AE0000B90000BF0000BE0000C60000CC0000CC0000CB00
00CB0000C70000C10000A900007B00008000009300009D00
00C30000C40000C60000C60000C70000C80000C90000C90000C90000C90000CB0000CD0000CD00\
00CF0000CF0000CC0000C60000AB00008100006300005900003900003000002F00
003100003500003A00004C00004700003B00003500003300004200003300002E00003000003700\
004000005A00008900006B00004200003600003900006600008A00009B0000A200
00A70000AA0000A90000A500009600007D00006D0000870000A50000B50000BF0000C50000C900\
00CB0000CB0000CC0000CB0000CB0000C70000BE0000AB00009500007000004A00
003500002D00002C00002600002500002A00003300003700002A00002900002600002A00005000\
008F0000AC0000BB0000C00000C40000C80000CB0000CA0000C80000BF00009900
004500004200004300004C00006000007300008000008900009D0000B80000A700008200005F00\
004A00004A0000800000A80000B50000BE0000BE0000C60000C90000CB0000CB00
00C90000C80000BF00009F00006F00007F0000970000A100
00C30000C30000C30000C50000C60000C60000C70000C80000C90000CA0000CB0000CC0000CD00\
00CE0000CE0000CD0000C60000AF00008300006400005500003500002D00003000
003000003500004A00007600005E00003B00003900003E00005800005D00002E00003600003400\
003A00004E00009100008A00004700003B00003C00006300007A00008D00009A00
00A10000A20000A10000990000720000570000630000840000A40000B80000BF0000C50000C700\
00C80000C70000C90000C90000C70000C10000B80000B40000AC00009500004F00
003900002B00002700002700002900002B00005600008500004300002600002A00002A00004100\
00740000A40000B50000BE0000C20000C70000C90000C90000C50000B300006F00
004500004400004700004800004B00004F00004D00005000005900008900007000005900004C00\
003500002F00005800009A0000AF0000B80000BD0000C50000C70000C90000C900
00C90000C70000BF00009C00007B00008200009900009E00
00C40000C40000C40000C50000C60000C60000C70000C80000C90000CA0000CB0000CC0000CC00\
00CE0000CF0000CD0000C70000B800009400006B00005A00003600002B00002F00
003000003900004800008600007100003D00003C00004300004B00005800003200003400003400\
003800003F00004E00005100003F00003F00003F00006B00006A00006D00007C00
008700008A00007F00005D00003C00003400004600007600009D0000B30000BE0000C30000C600\
00C70000C50000C60000C50000C20000BD0000BC0000BC0000B90000AE00007A00
004400002F00002500002300002400003100005900009500005500002900002B00002E00004300\
005C00008E0000AE0000BA0000C10000C50000C70000C60000BC00009100004900
004500004900004300004500004D00004D00004B00004700004700005400005400004C00003500\
00290000280000320000700000A30000B00000BA0000C10000C50000C70000C600
00C70000C50000BF0000AE0000AA0000A70000A40000A700
00C30000C30000C30000C40000C50000C50000C60000C70000C80000C90000CB0000CB0000CD00\
00CE0000CE0000CF0000CC0000C30000A900007F00006300003700002F00003100
003100003700004400005800005000003E00003F00003800003C00003F00003A00003700003600\
003800003C00003D00003E00003B00003E00004A00006400005600004D00004200
003F00004500003D00003A00003900003600003900005800008A0000AB0000B90000C00000C200\
00C20000C00000C00000BD0000BF0000C00000C20000C30000C20000BF0000A300
005800003E00002900002300002700002B00003900004F00003E00002C00002800003A00004C00\
006700008E0000AA0000B60000BD0000C20000C30000BA00009900005500004300
004400004400004300004C00005200005000004D00004700004200004400004300002E00002400\
002100002500002600003A0000780000A50000B40000BC0000BE0000BF0000C300
00C40000C30000BE0000BD0000BF0000BE0000BC0000B600
00C30000C30000C40000C30000C50000C60000C60000C70000C90000C80000C90000CC0000CC00\
00CD0000CC0000CE0000CE0000C90000BE0000A600007700004000003300003200
003600003800003F00004500004200003D00004100003B00003C00004200005000005900004E00\
004000004000004100004200004400006000007900006300005100004200002F00
003600003800003C00003900003900003B00003B00004000005600008000009D0000AC0000B300\
00B10000B20000B80000BD0000C10000C50000C60000C80000C60000C40000B800
007F00004C00002A00002300002500002700002E00003100002E00002A00003100004200006100\
00890000A40000B40000BD0000BF0000C10000BE0000A600006700004F00003F00
003B00003E00004400005900008400006D00004F00004400003F00003A00002B00002400002000\
002000002700002E00003A00004D00006E0000990000AE0000B90000BC0000BB00
00BC0000BE0000C30000C30000C40000C50000C50000C200
00C20000C30000C40000C30000C40000C40000C60000C60000C80000C80000C90000CA0000CB00\
00CC0000CC0000CD0000CD0000CD0000C90000BF00009F00005100003900003000
003400003900003C00004000003D00003D00003D00003C00003E00005600006C00007800007C00\
007900007200006E00006F00007600009100008700006100004B00003400002F00
003200003600003900003B00003F00003F00004000003F00003D00004400005600006E00008900\
009F0000AF0000BA0000C00000C30000C50000C80000C90000C90000C60000C200
00A200005B00003500002300002500002600002D00002900002A00002E00003C00005300007C00\
009F0000B30000BB0000C10000C50000C50000C10000AD00005F00004E00003D00
003C00004100004D00006D0000AE00008700005100004500003F00003400002200002300002200\
002A00004300003F00003400002E00003000004700006600008400009400009500
00A80000BB0000C30000C60000C70000C90000C90000C700
00C30000C30000C30000C30000C40000C30000C50000C50000C60000C80000C90000CA0000CB00\
00CB0000CB0000CE0000CE0000CE0000CD0000CA0000BF00008700004500003800
003700003600003B00003A00003C00003E00003D00003F00005300007100007F00008A00009100\
009600009900009C00009C00009400009000008700005F00004800002B00003000
003700003500003A00003F00004700004E00004700003F00003E00003C00004B00006D00009100\
00A50000B30000BD0000C00000C40000C80000CC0000CD0000CB0000C80000C400
00A900005200003C00002A00002400002700002400002600002A00003400004700006300009100\
00AC0000B90000C00000C40000C80000C80000C60000B800007500004F00003F00
003D00004100004A00006500008D00006D00004E00004600003D00002F00002400002700002300\
003400002700002600002E00003000002B00002F00003300003B00005300007000
00A30000B90000C30000C60000CA0000CA0000CB0000C900
00C20000C20000C40000C30000C30000C40000C60000C60000C60000C70000C80000CA0000CA00\
00CC0000CB0000CC0000CD0000CE0000CD0000CD0000CB0000BB00008300004F00
004000003D00003D00003F00003F00004300004500004700006500008000008D00009400009900\
00A10000A30000A60000A70000A000009A00008800006600004700002E00003000
003300003800003F00004800005C00006100004D00004300003B00003500005200007C00009B00\
00AC0000B80000BE0000C30000C60000CA0000D00000D00000CD0000CA0000C200
009D00003800002600003000002B00002A00002B00002A0000300000350000440000710000A300\
00B40000C00000C30000C70000C90000CA0000C80000BE00008B00005B00004500
004000004600004B00005500005F00005100004700004100003B00003900002300002B00003A00\
003A00002400002C00003800003800002A00002800002B00002F00004700006C00
00A20000BB0000C30000C70000CC0000CD0000CD0000CA00
00C30000C10000C30000C20000C30000C30000C50000C50000C60000C60000C70000C70000C900\
00C90000CB0000CA0000CB0000CC0000CD0000CD0000CC0000CA0000C200009F00
006F00005200004A00004A00005200006600006300005600006E0000880000900000990000A000\
00A60000B10000AD0000AA0000A50000A000009600007400004C00003200003300
003700003B00004500006A00009E00009900005900004700003B00003800005E00008D0000A400\
00AF0000B80000C10000C50000C80000CB0000D00000CF0000CC0000C90000BB00
008300002900001F00001E00002600002600002C00002A00002800002B0000410000800000A900\
00B80000BF0000C40000CA0000CD0000CC0000CA0000C40000A700006900004D00
004200004300004700004D00004E00004A00004700003F00004500004B00002900004200003100\
002300002700003A00006000004E00002F00002500002800002800004000006A00
00A10000B80000C10000C50000CA0000CE0000CE0000CA00
00C10000C20000C20000C20000C30000C30000C40000C40000C50000C60000C70000C70000C800\
00C80000C80000CA0000CA0000CA0000CA0000CB0000CA0000CB0000CA0000C600
00BC0000A500009A0000A30000AD0000A300007E00006100007200008B00009300009C0000A200\
00B10000C00000B30000AB0000A50000A00000A700008C00005E00003500003100
003300003800004500007E0000BC0000B000005B00004300003B00003900006A0000990000AC00\
00B40000BA0000C20000C60000C90000CA0000CC0000CC0000C90000C40000AB00
005100002500001F00001D00002000002200001F00001C00001D00002100004E00008C0000AD00\
00BA0000BF0000C50000CC0000CE0000CB0000C90000C80000BA00009800005F00
004300004400004300004500004900004700004B00004B00006600005B00003200002A00002100\
002200002A00004000009500009300003F00002400002D00002900004000006800
009D0000B80000C00000C60000C90000CC0000CD0000CA00
00C10000C10000C10000C40000C20000C40000C40000C30000C40000C40000C60000C70000C800\
00C80000C90000C80000CA0000C90000CB0000CA0000CB0000CA0000CB0000CB00
00C90000C50000C30000C00000B70000A200007C00006400007600008800009300009B0000A800\
00B10000B60000AC0000A80000A10000A80000B90000A300007500003800003000
003400003800003D00005900008C00007700004B00004300004100003C00007300009D0000AE00\
00B70000BE0000C30000C70000C80000CB0000CA0000CA0000C50000B600007900
002F00002700002000002200002200002300002500001D00001F00002400004E00008F0000AD00\
00B90000C00000C60000C90000CD0000CB0000C90000C80000C40000C300009700
005F00004700004600004500004D00005300005D00006500007300005800004000002700002000\
002400002700003700006B00008A00004300002600002700002800004200006100
00940000B40000BF0000C40000C60000C90000C90000CA00
00C20000C10000C20000C30000C20000C20000C40000C40000C40000C50000C70000C70000C800\
00C80000C80000C90000CB0000CB0000CC0000CC0000CD0000CC0000CE0000CC00
00CB0000C30000B600009F00007A00005700004200004800006D00008900009200009C0000AB00\
00AD0000AB0000A60000A100009F0000B50000B70000A500007B00003D00002C00
003000003400003800004000004B00004E00005800004100003E00003F0000720000A00000AF00\
00B80000BE0000C30000C70000C70000C80000C80000C50000B700008400003B00
002700002200002100002700002F00003400002400002100002000002000004A0000900000AC00\
00B90000C00000C50000C90000CA0000CA0000C90000C80000C80000CF0000C500
009C00006900005700005200005A00006700006A00006E00006500005F00004400002E00002300\
002200002400002A00003800004100003200002200002000002D00003D00005A00
008C0000AE0000BB0000C10000C50000C80000C80000C900
00C20000C20000C10000C20000C30000C40000C30000C40000C50000C60000C70000C70000C800\
00C90000CB0000CB0000CC0000CD0000CD0000CE0000CE0000CF0000CF0000CD00
00C30000AB00008500006000004800003F0000300000280000430000700000890000980000A000\
00A90000A400009C00009500009D00009B00008A00006F00004900003000002900
003000003500003600004800006700005F00006200004600004500004500006400009C0000AE00\
00B70000BE0000C10000C40000C60000C60000C20000B200008300004900002B00
002300001E00002000003700007C0000850000410000270000220000240000480000880000AA00\
00B70000BE0000C30000C70000C80000C90000C70000C60000CA0000D20000CF00
00C40000A200007C00006F00007300008000007F00007700006C00006000004700003A00002A00\
002500002400002700002A00002E00002B00002400002600003500006100007600
008E0000AB0000B90000C00000C40000C60000C60000C700
00C10000C20000C20000C30000C30000C40000C50000C50000C50000C50000C70000C70000C800\
00CB0000CB0000CB0000CD0000CD0000CE0000CE0000CF0000D00000CF0000C500
00A900007B00005E00004C00004800003200002100002000002600003600005C00007D00009000\
009500008E00008700008300007300005B00004B00003F00002F00002900002700
002900003200003500004000006200005D00005F00004900004A00005600007500009A0000A800\
00B50000BB0000C00000C40000C20000C10000B900009C00006400004300002C00
001E00001C00002100003500007A00007F00003F00002300002000002C0000800000930000A100\
00B20000BE0000C10000C40000C70000C70000C40000C40000CF0000D10000CC00
00BC00009F00008B00008400008500008000008300008D00009700009800008100005B00003C00\
002A00002500002200002500002600002200002700002B0000530000940000AB00
00AA0000B00000B80000BE0000C10000C30000C50000C300
00C20000C20000C20000C20000C20000C50000C50000C60000C60000C60000C60000C80000C800\
00CA0000CA0000CD0000CD0000CE0000CE0000D00000D00000D00000CB0000B800
008B00006500005200004900003400002700001F00001E00002000002300002400003700004A00\
005000005400005E00005500004400004300003D00003E00002E00002300002500
002700002E00003700003E00005500005A00005400004700004D00007A0000950000A50000AF00\
00B70000BA0000BF0000C20000C20000C30000BD0000B300009100004E00003600
002300002000001E00002900003900003600002B00001F00002D0000480000A000009D00008A00\
00A80000B70000BD0000C20000C40000C40000C10000BF0000C80000CB0000C100
00A800008D00008400008B00008500008700009C0000A90000B00000B50000B200009E00006C00\
004100002C00002700002500002600002400002B00003B0000860000B10000BD00
00C00000C00000BC0000B90000BD0000C00000BF0000B800
00C10000C20000C20000C10000C40000C40000C50000C40000C60000C60000C80000C80000C900\
00CA0000CA0000CB0000CE0000CF0000CF0000D10000D10000D00000C80000AB00
007600005F00004D00003A00002B00002500001E00002000002800002800002300002500002800\
002D00002800003200003300003600003800003900003100002800002500002700
002800002A00003300003700003F00004000003E00004500006000008B0000A40000AF0000B600\
00BB0000BF0000C20000C40000C40000C60000C20000BF0000B300008400004900
002900002300002000002300002700002400002300002000003D00007800009C00007300005D00\
00800000A90000B80000BF0000C10000BE0000BA0000B90000BD0000BB0000AD00
008E00007F00008300008D00008B00009E0000B00000B80000BC0000BE0000BE0000BB0000AB00\
007E00004A00002F00002A00002E00002E00003B0000680000A80000BC0000C400
00C80000C80000C60000BE0000A80000A200009900007D00
00C10000C20000C20000C30000C30000C40000C50000C60000C60000C70000C70000C80000C800\
00C90000CA0000CC0000CE0000CF0000D00000D10000D20000D00000C70000A900
007700005E00004200002E00002300001F00002000002800003500003100002200002400002600\
001E00002300002300002500002F00002F00002B00002800002800002900003200
002D00002E00003000002F00003200003300003400003D00006E0000970000AC0000B40000B800\
00BD0000C00000C30000C60000C60000C70000C60000C50000BF0000AD00006F00
003900002300002300002200002000002000001F00002900004400006A00006900004500004000\
005100007200009E0000B50000BE0000C00000BF0000BD0000BD0000B90000A700
008100007800008600008B0000990000AC0000B80000BE0000C10000C30000C20000C20000BF00\
00B300009400006400003D00004200004E00006900009B0000B60000C10000C900
00CE0000CC0000CA0000BF00008D00005900004800003100
00C10000C10000C20000C20000C20000C40000C50000C60000C50000C40000C60000C70000C800\
00C80000CB0000CB0000CD0000D00000D00000D10000D00000CF0000C90000B200
008500006100003A00002300001E00001A00001E00002D00003400002F00002C00002100002500\
002200002000002000001C00002400002400002800002B00002C00003000003800
003B00003800003500003200003300003500002B00004600007A00009E0000AE0000B70000BA00\
00BF0000C20000C50000C80000C80000C90000C70000C90000C40000BE0000A300
005E00002E00002800002300002200001E00002100002100003200003A00003400003300003900\
00540000780000A20000B90000C10000C40000C20000C00000C20000BD0000B600
00970000760000870000920000A30000B30000BB0000C10000C40000C50000C50000C50000C300\
00BE0000B000009300006800006A0000780000890000AD0000BC0000C40000CC00
00D00000CE0000C90000C000008A00003F00003200002B00
00C00000C10000C20000C10000C40000C40000C40000C40000C60000C50000C70000C80000C800\
00C90000CA0000CC0000CC0000CE0000CF0000CF0000D10000D00000CC0000BE00
009D00007300003D00002100002200001C00001E00001D00002000002000002700002800002D00\
002200001D00001B00001A00001900001F00002900002D00003000003700004A00
005B00004500003E00003900003800003500003000004200008000009E0000AE0000B70000BC00\
00BE0000C20000C60000C90000CC0000D00000CC0000C90000C70000C40000B600
007300003200002200002200001E00001E00001E00001700001D00001E00002300002000003200\
005800008E0000B00000BE0000C30000C40000C50000C40000C20000C00000BC00
00AF0000820000910000990000A70000B70000BE0000C40000C80000CB0000CA0000C60000C500\
00C30000B800008D00007000008100008400009E0000B40000BF0000C60000CB00
00CE0000CF0000CD0000BF00007B00003A00003100002200
00C10000C10000C20000C10000C30000C30000C40000C30000C40000C40000C50000C60000C800\
00C90000CA0000CA0000CA0000CC0000CF0000CF0000CF0000D00000CD0000C700
00B700009300004C00002300001C00001900001A00001C00001800001F00002700003C00005E00\
003B00002200001C00001B00001800001E00002600002A00003100003D00006000
009600006800004300003E00003700003700003500003E00007400009C0000AF0000B40000BA00\
00BF0000C20000C60000C80000CC0000D10000D00000C90000C80000C60000B700
007500002700001D00001A00001900001B00001900001D00001C00001F00001F00001E00002C00\
006900009C0000B50000BF0000C30000C70000C70000C60000C40000C50000C100
00B70000900000980000A20000AD0000BA0000C10000C60000CA0000CD0000CC0000C80000C600\
00C40000BC0000960000800000890000920000AC0000BA0000C30000C90000CC00
00CF0000CF0000CB0000B800006300003B00002E00002100
00C10000C30000C20000C20000C30000C30000C40000C40000C30000C40000C50000C60000C800\
00C80000C90000CA0000CA0000CC0000CC0000CE0000CF0000D00000D00000CC00
00C70000B600007900002C00001B00001B00001900001B00001800001A00002500003B00008E00\
007A00002C00001C00001D00001C00002000002900002B00003200003700004400
005D00005800004200003F00003900003A0000360000360000620000910000A80000B20000BA00\
00BE0000C30000C50000C50000C80000CB0000CC0000CA0000C40000C40000B100
005D00002400001E00001800001800001C00002000002100002200002000001D00001800002A00\
00740000A40000B70000C00000C50000C80000C80000C90000C70000C50000C300
00BD0000A400009D0000A50000AF0000BA0000C00000C50000C90000CA0000C90000C80000C700\
00C50000BF00009F00008F0000980000A70000B60000BF0000C50000CA0000CD00
00CE0000CE0000C90000AF00004F00003300002700002100
00C00000C00000C10000C00000C30000C30000C40000C40000C30000C40000C60000C70000C700\
00C70000C80000C90000CA0000CC0000CC0000CD0000CE0000D00000D00000CF00
00CE0000C50000AB00005100002300001C00001A00001C00001900001900002100002800003900\
004300002400001B00002100003200003A00002A00002A00002F00003900003A00
003E00004100003D00003A00003D00003A0000370000350000500000820000A00000B00000B700\
00BC0000C00000C30000C40000C50000C80000CA0000C80000C30000BC0000A100
003D00002200002000001C00001A00001F00002B00004800004400002800002200001C00002E00\
007A0000A40000B80000C00000C40000C60000C80000CD0000C90000C50000C300
00BF0000B100009E0000A70000B00000BA0000BF0000C40000C70000C80000C70000C70000C600\
00C50000BF0000A70000A50000AF0000B60000BC0000C10000C70000CB0000CE00
00CE0000CD0000C600009F00004B00003100002600001E00
00C00000C10000C20000C20000C20000C30000C40000C50000C40000C40000C60000C60000C600\
00C70000C80000CA0000CA0000CB0000CC0000CD0000CD0000CF0000D00000CF00
00CF0000CC0000BF00008B00003700002200001B00001B00001800001C00001F00002100002500\
002300001F00002000002400005200004300002900002E00003000003800003900
003700003B00003C00003C00003A00003900003700003300003E0000580000900000A90000B500\
00BB0000BD0000C00000C30000C40000C60000C50000C50000C10000AE00006C00
002700002100001E00001B00001800002600004D00009500008600003200001E00001C00002800\
00720000A20000B70000BD0000C10000C40000C40000C80000C80000C50000C400
00C20000B80000A00000A70000B00000B90000BD0000C20000C50000C70000C60000C50000C500\
00C30000BD0000AD0000B10000B70000BC0000C10000C50000CA0000CB0000CE00
00CC0000CC0000C400009600005300003500002100001D00
00C00000C00000C30000C30000C20000C30000C40000C40000C60000C50000C60000C60000C700\
00C80000C80000C90000CB0000CB0000CC0000CD0000CD0000CF0000D10000D000
00CF0000C80000B400008900005600003200002100001E00001A00001D00001E00002000002100\
002000002200001E00003000004000003200002A00002E00002F00003500003E00
003A00003A00003D00003F00003B00003C00003700003000002800002A0000550000900000AC00\
00B50000B80000BC0000BF0000C10000C30000C30000C00000B400008700003D00
002300001D00001500001C00001A00002900004200007000005700002300001A00001A00002C00\
006000009A0000B20000BA0000BF0000C10000C20000C60000C50000C50000C300
00C30000BD0000B20000A70000AC0000B60000BC0000C10000C40000C50000C50000C50000C400\
00C00000B40000A80000B50000BB0000BF0000C20000C50000C90000CB0000CB00
00CB0000CB0000C40000AE00006F00003300002600001E00
00C00000C10000C30000C30000C40000C30000C40000C40000C50000C50000C70000C60000C800\
00C80000C80000C90000CA0000CC0000CD0000CD0000CE0000D00000D10000D100
00CE0000BE00009700006A00005300004400002E00002600002000002200002100002000002300\
002500001F00002700003300003000002F00002400002600002E00003400003A00
004000003F00004000004300004100003C00003100002800001F00002100002C00004600007700\
009C0000AE0000B50000BA0000BC0000BD0000BA0000A900007F00004900002900
001A00001900001900001C00001C00002300002A00002D00002700001F00001C00001A00002100\
003E0000860000A90000B50000BB0000C10000C20000C40000C40000C50000C300
00C20000BF0000C20000B70000A80000B10000B90000BE0000C10000C40000C50000C40000C100\
00B500008A0000950000B20000BA0000BF0000C40000C60000C80000C90000CA00
00C70000C50000C70000C600009F00003C00002A00002200
00C20000C20000C30000C30000C40000C30000C40000C40000C50000C70000C70000C70000C900\
00C80000C90000C90000CB0000CC0000CD0000CD0000CF0000D00000D20000D100
00CC0000B400008300006500004F00003300002600002300002200002200002800002900002E00\
002B00001D00002000003000003100002100002300002600002B00002F00003B00
003D00004300004900004A00004D00004300003B00002000002000002500002700002C00003600\
004600006A00008000008D0000980000B500009F00007300004B00003100002200
001B00001B00001700001900001E00001F00001F00002000001F00001900001F00001A00001B00\
002500005C00009A0000B00000B70000BE0000C00000C10000C10000C40000C000
00BD0000B90000C60000C50000B00000A90000B40000BB0000BF0000C10000C10000C00000B800\
008F00004A0000780000AA0000B70000BE0000C40000C60000C80000C80000C700
00C00000AD0000AD0000C50000C100007700003500002A00
00C20000C30000C30000C30000C50000C50000C50000C40000C50000C60000C70000C70000C800\
00C80000C90000CA0000CC0000CC0000CE0000CF0000D00000D00000D30000D100
00CB0000B500008300006700004700002E00002300002000002000001E00001E00002300002300\
002300002000001A00002000002000002000002900002A00002C00002E00003200
003B00003900003F00004800005A00004F00003300001E00002200002300002400002E00003000\
003600003800003700003900004600008500007300004F00003900002300001D00
001900001800001B00001F00001F00001F00002000001F00002300001F00001B00001300001500\
001C00002C00006B00009B0000AF0000B80000BD0000C10000C20000C00000BC00
00AD0000990000AE0000BC0000AE0000900000A00000AE0000B50000B70000B50000AA00008400\
004D00003E00005000009A0000B20000BB0000C10000C40000C60000C50000BE00
009F00006400005B0000860000B90000BB00007300003000
00C10000C00000C30000C20000C40000C40000C50000C50000C50000C50000C70000C70000C800\
00C80000C90000CA0000CB0000CC0000CD0000CE0000CF0000CF0000D20000D200
00CD0000BE00009B00007300004100002E00002E00003400003200002000002700003800003600\
002800001F00001A00001900002000002500002B00002D00003200003200003200
003200003700003500003700005100005000002C00001E00001C00002200002800002E00004100\
004900003800003100003100003300004200005000004000002800002100001700
001800001C00001E00001F00001F00001E00002100002300001F00001900001600001600001A00\
001E00002100003100005E00008C0000A90000B60000BA0000B90000B20000A700
009700009400009500009900008A00006C00006700007500007800007700006800005600004600\
004000003D0000410000740000A80000B50000BD0000C10000BE0000AF00008A00
005300004000003D0000420000630000AC0000A600006300
00C00000C10000C40000C20000C30000C30000C40000C40000C60000C60000C70000C80000C800\
00C80000C90000C90000CB0000CA0000CC0000CD0000CE0000CF0000D00000D100
00CF0000C70000B500008E00004500003A00004200004600003900002700004400009400007600\
002F00002600001C00001B00002000002800002C00002E00003300003900003800
003800003500003300003500003E00005700002F00001E00001C00002000002400003800007400\
009100004900003300002E00002C00003200004000002900002000001C00001E00
001B00002000002300002300002900003000003600002300001C00001600001600001800001B00\
001F00002300002C00003300005C00007300008300007C00007900008800009C00
00A60000A70000A400009C00008200005F00005800004D00003B00003900004100004500004500\
004400004100004100004500006A0000980000A400009B00008300005F00004800
004300004100003F00004300004400006000007600005E00
00C00000C20000C20000C30000C40000C40000C40000C40000C50000C60000C70000C60000C800\
00C90000C90000CA0000CB0000CB0000CC0000CC0000CD0000CF0000CF0000D000
00D00000CE0000C70000B500006900004100004A00004600004300002F00003A00007700005E00\
003000002600002400001F00002500002700002F00003400003D00004800004300
003E00003700003400003400003A00005A00003C00002600002000002100002800003400006900\
00A000006300003500002C00003200002D00003500002000002000001F00001E00
001D00002300002200002100001D00002500003900002C00001900001300001700001800001A00\
002100002D00002D00002900002E00003200004E0000450000660000910000A400
00AC0000B20000B00000AB00009800006500004A00003700003700003C00003D00004300004600\
004800004700004700004200004100004F00004700003D00003F00004100004400
004300003F00004300004600004200004100004600005100
00C20000C20000C30000C40000C40000C50000C40000C40000C60000C60000C60000C70000C700\
00C90000C90000CA0000CA0000CB0000CC0000CD0000CD0000CE0000CF0000D100
00D10000D10000CF0000C90000A700005600004D00004D00004300002B00003000003900003300\
002E00003400004400003D00002800002B00003100003900005700009100007E00
004700003D00003900003700003D00006600006700002E00002500002300002700002C00004000\
005D00004B00003100002D00002E00002700002200001D00001E00002200002100
002700003000002A00002300001F00002300003200002200001700001700001B00001C00001B00\
002D00005500005300002F00002900002900003C00004B0000770000960000A600
00B00000B70000B90000B30000A300006F00003D00003200003400003A00003D00004700005C00\
006C00005200004600004100003D00003E00003500003800003B00003E00003E00
003E00004400004C00004F00004800004000003B00004B00
00C30000C30000C30000C30000C50000C30000C40000C50000C50000C60000C60000C70000C800\
00C90000C80000C90000CA0000CB0000CB0000CC0000CD0000CE0000CE0000D000
00D00000D10000D20000CF0000C700009A00005300003A00003200003000003100003800003900\
004600007200009000006C00003000002E00003100003A00005200008C00009100
004D00003C00003800003A00003E00007200009C00004300002E00002800002800002700003100\
003400003000002B00002900002C00002C00001E00001D00001D00002000002700
003600006300004700002C00002400002300002900002500001B00001D00001A00001A00002500\
003C00009300008100003400002800002A0000300000540000800000980000A500
00B20000BF0000C20000B90000AB00008100003B00003200003100003800004400005400008F00\
00A000005A00004700004200003E00003900003100003300003400003700003C00
004400005400007900007700005300004100003B00003E00
00C10000C30000C30000C30000C30000C40000C40000C40000C60000C50000C50000C70000C700\
00C70000C70000C80000C90000CA0000CB0000CB0000CB0000CB0000CD0000CE00
00CE0000CF0000CF0000CF0000CC0000C70000AB00007F00005600004500004A00004F00006600\
00970000B90000B700009700004B00003200003400003900004000005100005500
004500003D00003B00003B0000450000810000BE00008D00003F00003000002A00002700002D00\
002E00002B00002D00003200003100004000002900001F00002100001F00002600
00480000A300009700004E00002B00002700002F00002D00001C00001A00001C00001E00002200\
003600006800005200002A00002600002E00003700005D00007E0000940000A300
00B10000BD0000C30000BA0000B100009300004800003B00003700003A00004200005400007400\
007600004B00004300004400004200003E00003300003200003700003B00004200
004A0000650000A300009100005C00004600003B00002E00
00C20000C10000C20000C30000C40000C40000C40000C50000C50000C40000C50000C60000C600\
00C70000C70000C80000C70000C80000CA0000C90000CA0000CA0000CB0000CA00
00CC0000CC0000CD0000CD0000CD0000CB0000C80000C10000B40000A80000A40000AD0000BC00\
00C80000CA0000C50000B900007F00003E00003900003A00003B00003E00004200
004200004000003D00003F00004F0000970000CC0000C300008700004700003800002E00002E00\
002E00003200003500003F00005400007800004F00002A00002700002300002A00
003B00007F00008500005500003400002C00004800005600002500001D00002000001F00002400\
002800003600003100002B00002B00003B00006C0000660000830000960000A200
00AD0000B50000B80000B80000B20000A500007B00004500003C00004000004500004B00005100\
005100004900004900004E00005200006600004000003400003600003D00004600
004C00005900007500007700005A00004900003900002600
00C10000C20000C30000C30000C20000C40000C40000C50000C40000C30000C60000C60000C600\
00C60000C70000C70000C70000C90000C90000C90000C90000C90000CB0000CA00
00CB0000CB0000CB0000CB0000CC0000CC0000CB0000CA0000C80000C90000C90000CA0000CB00\
00CD0000CE0000CD0000C70000B100006200003C00003D00003900003F00004400
004200004000003C0000440000650000B00000D00000D00000C300008800004D00004000003A00\
003A00003C00004D00006C00009D0000B400008F00004200003200002900002600
003400005C00004000003B00003A00004300008500009B00004100002900002200002200002200\
002800002D00002A00002D00003B0000670000A800008A00008C0000990000A300
00AA0000B00000B50000B70000B50000BA0000B600007500004C00004400004500004A00005000\
004E00005000005A00007C0000980000A000006200003B00003A00003F00004000
004800005100005900005F00005000004900004100003000
00C30000C20000C20000C20000C30000C50000C40000C50000C30000C50000C50000C60000C700\
00C70000C60000C70000C90000C90000C80000CA0000CA0000C90000CB0000CB00
00CB0000CB0000CC0000CB0000CD0000CC0000CC0000CD0000CC0000CC0000CC0000CD0000CD00\
00CE0000CF0000CF0000CD0000C70000A400005E00004500003D00003C00003D00
00400000410000450000530000830000C20000D00000D10000CF0000C30000A000007900006800\
006900007400008A0000AF0000C80000CB0000B700006800003A00002C00002800
002E00003700003400004300004E0000720000B40000C100008A00004000002900002300002400\
002800002C00002F00003C0000640000AE0000C60000B500009700009B0000A200
00A70000B00000B20000B40000B90000C50000CB0000B300007600005500004D00005000005700\
005700006A00008F0000B30000C60000BF00008F00004B00003E00004000004200
004900004B00004E00005400005000005700007200005F00
00C20000C20000C20000C20000C30000C50000C40000C50000C50000C40000C50000C60000C600\
00C70000C70000C70000C90000CA0000C80000CA0000C90000CA0000CA0000CB00
00CB0000CA0000CB0000CC0000CD0000CC0000CC0000CC0000CB0000CD0000CD0000CD0000CD00\
00CE0000CF0000CF0000CE0000CD0000C60000A700006F00005100004800004300
004400004800005B00007C0000B10000CA0000CE0000CF0000CF0000CC0000C90000C10000B900\
00B70000BE0000C60000CE0000D10000D10000CB0000A500005200003600002F00
002F00002C00003600004200006200009A0000C80000CC0000BB00007900004400003300002C00\
002D0000320000410000630000A60000C80000CD0000CA0000B80000A20000A200
00A70000AA0000B10000B60000C10000CC0000CF0000CB0000B800008E00006C00006600006B00\
007B0000A30000BC0000CE0000CF0000CD0000BB00007600004D00004400004700
004900004900004C00005300005E0000840000B300009700
00C10000C20000C40000C20000C40000C40000C40000C50000C50000C50000C50000C70000C700\
00C80000C70000C70000C80000C90000C90000C90000CA0000C90000CA0000CA00
00CB0000CA0000CB0000CC0000CC0000CB0000CC0000CC0000CB0000CC0000CC0000CD0000CD00\
00CD0000CD0000CE0000CE0000CD0000CC0000C70000BA00009600007300006100
00650000750000940000B40000C70000CD0000CE0000CF0000CF0000CE0000CD0000CC0000CC00\
00CC0000CC0000CF0000CF0000D10000D10000D00000C700009B00005300004200
004400004200004F0000670000900000BE0000CD0000CF0000CA0000B700007F00005300004900\
004800005800007E0000AE0000C70000CD0000CE0000CD0000C90000BE0000AE00
00AB0000B00000B60000C10000CC0000D00000CF0000CF0000CB0000C50000B60000AD0000AF00\
00B90000C70000CF0000D10000D20000D20000CD0000B000007600005700005400
004C00005400005600006800008B0000BC0000CC0000BB00
00C10000C10000C30000C20000C40000C40000C50000C50000C50000C60000C50000C60000C700\
00C70000C70000C70000C70000C80000C90000C90000CA0000C90000CA0000CA00
00CB0000CA0000CB0000CB0000CB0000CB0000CB0000CC0000CB0000CB0000CC0000CC0000CC00\
00CD0000CC0000CC0000CC0000CC0000CA0000CB0000C80000C30000BB0000B300
00B00000B80000C20000C80000CC0000CE0000CE0000CE0000CE0000CE0000CD0000CD0000CC00\
00CD0000CD0000CE0000CE0000CF0000CF0000CF0000CC0000C40000AB00008800
007600007B0000900000A90000C00000CA0000CD0000CD0000CC0000C90000BF0000A900009600\
00960000A60000BC0000C70000CB0000CE0000CD0000CE0000CD0000CB0000C800
00C40000C50000C80000CD0000CE0000CF0000CF0000CE0000CE0000CD0000CC0000CB0000CB00\
00CD0000CE0000D00000D10000D10000D10000D00000CC0000BA00009700007A00
00710000740000850000A40000C10000CF0000D20000CD00
00C30000C20000C40000C30000C30000C40000C40000C50000C60000C60000C60000C70000C800\
00C60000C70000C70000C80000C90000C90000C90000CA0000C90000CA0000CA00
00CA0000CA0000CB0000CB0000CA0000CB0000CB0000CB0000CC0000CB0000CB0000CB0000CC00\
00CC0000CD0000CD0000CC0000CB0000CC0000CB0000CB0000C90000C90000C800
00C80000C90000CA0000CB0000CC0000CD0000CD0000CE0000CD0000CD0000CD0000CD0000CD00\
00CD0000CC0000CD0000CD0000CE0000CE0000CD0000CD0000CA0000C80000C400
00C00000C00000C40000C70000CA0000CC0000CD0000CD0000CC0000CB0000CB0000C70000C600\
00C50000C80000CA0000CC0000CD0000CD0000CE0000CD0000CD0000CE0000CD00
00CC0000CC0000CD0000CE0000CF0000CF0000CF0000CF0000CE0000CE0000CE0000CE0000CE00\
00CE0000CF0000CF0000CF0000D00000D00000CF0000CE0000CC0000C60000BE00
00B90000BB0000C10000C90000CE0000D00000D20000CF00
00C20000C20000C30000C30000C40000C40000C50000C40000C40000C60000C60000C60000C700\
00C70000C70000C70000C80000C80000C80000C90000C90000C90000C90000CA00
00C90000CA0000CB0000CB0000CB0000CC0000CD0000CB0000CC0000CC0000CB0000CC0000CC00\
00CC0000CC0000CC0000CC0000CC0000CC0000CC0000CB0000CB0000CB0000CA00
00CA0000CC0000CC0000CC0000CD0000CD0000CD0000CD0000CD0000CD0000CD0000CE0000CE00\
00CE0000CD0000CD0000CE0000CD0000CD0000CD0000CC0000CC0000CB0000CA00
00CA0000CA0000CB0000CC0000CD0000CD0000CD0000CE0000CE0000CD0000CC0000CC0000CB00\
00CB0000CC0000CC0000CD0000CD0000CF0000CE0000CE0000CE0000CE0000CE00
00CD0000CD0000CE0000CF0000CF0000CF0000CF0000CF0000CE0000CE0000CE0000CF0000CF00\
00CF0000CF0000CF0000CF0000CF0000CF0000CF0000CE0000CC0000CD0000CB00
00CA0000CB0000CB0000CC0000CE0000CE0000CF0000CE00
00C20000C20000C20000C10000C30000C50000C50000C40000C40000C50000C60000C50000C700\
00C80000C70000C70000C80000C80000C80000C90000C90000C90000CA0000CA00
00CA0000CA0000CB0000CA0000CB0000CB0000CB0000CB0000CC0000CC0000CB0000CC0000CC00\
00CB0000CB0000CC0000CB0000CB0000CC0000CC0000CC0000CC0000CC0000CB00
00CC0000CC0000CC0000CD0000CC0000CD0000CE0000CE0000CE0000CE0000CD0000CE0000CE00\
00CE0000CD0000CE0000CE0000CE0000CD0000CD0000CE0000CD0000CC0000CC00
00CD0000CD0000CD0000CD0000CE0000CD0000CD0000CE0000CE0000CD0000CE0000CD0000CD00\
00CD0000CD0000CE0000CE0000CE0000CF0000CE0000CE0000CF0000CE0000CE00
00CE0000CE0000CF0000CE0000CF0000CF0000CF0000CE0000CE0000CE0000CF0000CF0000CF00\
00CF0000CF0000CF0000CF0000CF0000CF0000CF0000CE0000CE0000CD0000CE00
00CD0000CD0000CD0000CE0000CE0000CE0000CE0000CE00
00C20000C30000C10000C30000C40000C50000C50000C40000C40000C60000C70000C60000C600\
00C80000C70000C60000C80000C90000C90000C80000C90000CA0000C90000CA00
00CA0000CA0000CB0000CB0000CA0000CB0000CB0000CC0000CB0000CC0000CB0000CC0000CC00\
00CB0000CC0000CC0000CB0000CC0000CC0000CB0000CC0000CC0000CC0000CC00
00CC0000CC0000CC0000CC0000CD0000CD0000CD0000CE0000CE0000CD0000CD0000CE0000CE00\
00CE0000CE0000CE0000CE0000CD0000CE0000CE0000CE0000CD0000CE0000CE00
00CD0000CE0000CD0000CE0000CE0000CE0000CE0000CE0000CF0000CE0000CE0000CE0000CE00\
00CE0000CE0000CE0000CE0000CF0000CF0000CE0000CF0000CF0000CE0000CF00
00CF0000CE0000CF0000CF0000CF0000CE0000CF0000CF0000CF0000CF0000D00000CF0000D000\
00CF0000CF0000CF0000D00000CF0000CF0000D00000CF0000CF0000CE0000CE00
00CE0000CE0000CE0000CE0000CF0000CE0000CF0000CE00
00C30000C10000C20000C30000C40000C50000C30000C50000C50000C50000C60000C60000C600\
00C60000C60000C70000C80000C80000C80000C80000C80000C80000C90000CA00
00CA0000C90000CB0000C90000CA0000CB0000CB0000CB0000CB0000CC0000CB0000CC0000CC00\
00CC0000CC0000CC0000CC0000CB0000CC0000CC0000CC0000CC0000CC0000CC00
00CB0000CC0000CC0000CC0000CC0000CC0000CD0000CE0000CD0000CD0000CD0000CD0000CE00\
00CD0000CD0000CE0000CE0000CE0000CE0000CF0000CD0000CD0000CE0000CE00
00CE0000CE0000CD0000CF0000CE0000CE0000CE0000CE0000CE0000CE0000CE0000CE0000CE00\
00CD0000CE0000CF0000CF0000CF0000CF0000CF0000CF0000CF0000CF0000CF00
00CE0000CF0000CF0000D00000CF0000CF0000CF0000CF0000CF0000CF0000D00000CF0000CE00\
00CF0000D00000D00000CF0000CF0000D00000CF0000CF0000CF0000CE0000CE00
00CE0000CF0000CF0000CE0000CE0000CF0000CF0000CF00
00C10000C20000C30000C40000C40000C40000C50000C40000C40000C40000C60000C60000C600\
00C70000C60000C70000C70000C70000C80000C90000C80000C80000C90000C900
00C90000CA0000CA0000CB0000CB0000C90000CB0000CB0000CB0000CB0000CB0000CB0000CB00\
00CC0000CC0000CC0000CB0000CC0000CC0000CC0000CB0000CC0000CC0000CB00
00CC0000CD0000CC0000CD0000CD0000CD0000CD0000CD0000CD0000CD0000CD0000CE0000CD00\
00CD0000CD0000CD0000CE0000CE0000CE0000CE0000CE0000CE0000CD0000CE00
00CE0000CE0000CE0000CE0000CD0000CE0000CE0000CF0000CE0000CE0000CE0000CE0000CF00\
00CE0000CF0000CE0000CF0000CE0000CF0000CE0000CF0000CF0000CF0000CE00
00CF0000CF0000CF0000CF0000CF0000CF0000CF0000CF0000D00000CF0000D00000CF0000D000\
00CF0000D00000D00000CF0000CF0000D00000D00000CF0000D00000CF0000CE00
00CF0000CF0000CF0000CF0000CF0000CF0000CF0000CF00
00C20000C30000C30000C40000C40000C40000C50000C50000C50000C50000C50000C50000C600\
00C70000C70000C70000C60000C70000C80000C90000C80000C90000C80000C900
00CA0000CA0000C90000CA0000CB0000CA0000CB0000CB0000CA0000CC0000CB0000CB0000CB00\
00CB0000CC0000CC0000CB0000CB0000CC0000CC0000CB0000CC0000CC0000CB00
00CC0000CC0000CC0000CC0000CC0000CC0000CC0000CD0000CD0000CE0000CD0000CD0000CD00\
00CE0000CE0000CD0000CE0000CE0000CE0000CE0000CE0000CD0000CE0000CF00
00CE0000CE0000CE0000CE0000CE0000CF0000CE0000CF0000CE0000CE0000CF0000CF0000CF00\
00CF0000CF0000CF0000CF0000CF0000CE0000CE0000CF0000CF0000CF0000CE00
00CE0000CF0000D00000D00000CE0000D00000CF0000CF0000CF0000CF0000CF0000CF0000CF00\
00CF0000D00000CF0000D00000CF0000D00000D00000CF0000D00000CF0000CF00
00CF0000CF0000CE0000D00000CF0000CF0000D00000CF00
00C10000C20000C20000C20000C40000C30000C40000C40000C50000C50000C60000C60000C600\
00C60000C60000C60000C70000C70000C70000C80000C80000C90000CA0000C900
00CA0000C90000C90000CB0000C90000CB0000CA0000CB0000C90000CB0000CB0000CB0000CB00\
00CB0000CC0000CB0000CB0000CB0000CC0000CB0000CC0000CC0000CB0000CB00
00CB0000CB0000CC0000CB0000CC0000CD0000CD0000CD0000CC0000CC0000CD0000CD0000CD00\
00CE0000CD0000CE0000CE0000CD0000CE0000CE0000CE0000CD0000CE0000CE00
00CE0000CF0000CE0000CE0000CE0000CF0000CE0000CE0000CE0000CE0000CF0000CE0000CE00\
00CF0000CF0000CE0000CF0000CF0000CF0000CF0000CF0000CF0000CF0000CE00
00CF0000CF0000CF0000CF0000CF0000CF0000CF0000D00000CF0000CF0000CF0000CF0000CF00\
00CF0000CF0000CF0000D00000D00000CF0000D00000CF0000CF0000D00000D000
00CF0000CF0000D00000D00000CF0000CF0000CF0000CF00
00C10000C10000C20000C10000C20000C30000C40000C30000C50000C50000C60000C60000C600\
00C60000C60000C60000C70000C80000C70000C80000C80000C90000C90000C900
00C90000CA0000C90000CA0000CA0000C90000CA0000CB0000CA0000CB0000CB0000CA0000CB00\
00CB0000CA0000CC0000CC0000CB0000CA0000CB0000CB0000CB0000CC0000CB00
00CC0000CC0000CC0000CC0000CC0000CC0000CC0000CC0000CC0000CD0000CD0000CD0000CD00\
00CD0000CD0000CE0000CD0000CE0000CD0000CD0000CD0000CD0000CE0000CE00
00CE0000CE0000CD0000CE0000CE0000CF0000CD0000CE0000CF0000CF0000CF0000CF0000CE00\
00CE0000CF0000CF0000CF0000CF0000CF0000CF0000CE0000CE0000CF0000CE00
00CF0000CF0000CF0000CF0000CF0000CF0000CF0000CF0000CF0000D00000CF0000CF0000CF00\
00D00000CF0000D00000D00000D00000CF0000CF0000CF0000D00000CF0000CF00
00CF0000D00000CF0000CF0000CF0000CF0000D00000D000
00C20000C10000C20000C10000C40000C30000C30000C40000C50000C50000C60000C50000C500\
00C60000C60000C60000C70000C70000C80000C80000C80000C80000CA0000C900
00CA0000C90000CA0000CA0000CA0000CA0000CB0000CA0000CA0000CB0000CB0000CA0000CA00\
00CA0000CB0000CB0000CB0000CB0000CB0000CB0000CC0000CB0000CB0000CB00
00CB0000CB0000CD0000CC0000CC0000CD0000CD0000CD0000CC0000CD0000CD0000CD0000CD00\
00CD0000CD0000CD0000CE0000CE0000CE0000CE0000CE0000CD0000CE0000CE00
00CE0000CE0000CE0000CD0000CE0000CE0000CE0000CE0000CE0000CE0000CF0000CF0000CE00\
00CE0000CE0000CE0000CF0000CF0000CF0000CE0000CE0000CE0000CF0000CF00
00CF0000CF0000CF0000CF0000CF0000D00000CE0000CF0000D00000D00000D00000CF0000CF00\
00CF0000CF0000D00000D00000D00000CF0000CF0000D00000CF0000CF0000D000
00CF0000D00000CF0000CF0000D00000CF0000CF0000CE00
00BF0000C10000C20000C30000C30000C30000C40000C40000C50000C50000C50000C60000C400\
00C50000C50000C70000C80000C70000C70000C70000C70000C80000C80000C900
00C90000C90000CA0000CA0000CA0000CA0000CA0000CB0000CA0000CB0000CB0000CB0000CA00\
00CA0000CB0000CC0000CB0000CB0000CB0000CB0000CB0000CB0000CB0000CB00
00CB0000CC0000CC0000CB0000CC0000CC0000CC0000CD0000CC0000CD0000CD0000CD0000CD00\
00CD0000CD0000CE0000CD0000CD0000CE0000CE0000CE0000CD0000CD0000CE00
00CE0000CE0000CD0000CE0000CE0000CE0000CE0000CE0000CE0000CE0000CF0000CE0000CE00\
00CF0000CE0000CE0000CF0000CE0000CE0000CE0000CE0000CE0000CE0000CF00
00CE0000CE0000CE0000CF0000CF0000CF0000CF0000CF0000D00000CF0000D00000CE0000CF00\
00D00000CF0000D00000CF0000CF0000CF0000CF0000CF0000CF0000D00000CF00
00D00000D00000CF0000CF0000CF0000CE0000D00000CF00
00C00000C10000C10000C30000C20000C40000C40000C40000C40000C40000C40000C50000C500\
00C40000C50000C60000C70000C60000C70000C80000C80000C80000C80000C900
00CA0000CA0000C80000CA0000C90000CA0000CA0000CB0000CA0000CB0000CB0000CA0000CB00\
00CB0000CB0000CB0000CA0000CA0000CA0000CB0000CB0000CB0000CC0000CB00
00CC0000CC0000CC0000CC0000CC0000CC0000CD0000CD0000CD0000CC0000CC0000CC0000CD00\
00CD0000CD0000CC0000CE0000CD0000CD0000CE0000CE0000CE0000CE0000CF00
00CF0000CE0000CE0000CE0000CE0000CF0000CE0000CD0000CE0000CD0000CE0000CE0000CE00\
00CF0000CE0000CF0000CF0000CF0000CF0000CE0000CF0000CF0000CF0000CE00
00CF0000CF0000CE0000CF0000CE0000D00000CF0000CF0000CF0000CF0000CF0000CF0000CF00\
00CF0000D00000CE0000CF0000CF0000CF0000CF0000CF0000CF0000CF0000CF00
00CF0000CF0000CF0000CF0000CE0000CF0000CF0000D000
00C10000C20000C10000C10000C10000C30000C30000C30000C30000C40000C40000C50000C500\
00C50000C60000C60000C60000C60000C70000C70000C80000C90000C90000C800
00CA0000C90000CA0000CA0000CB0000CB0000CA0000CB0000CB0000CB0000CB0000CB0000CA00\
00CA0000CB0000CB0000CB0000CB0000CB0000CB0000CC0000CB0000CB0000CC00
00CB0000CC0000CB0000CC0000CD0000CC0000CC0000CC0000CD0000CC0000CC0000CD0000CD00\
00CE0000CD0000CD0000CD0000CD0000CE0000CE0000CE0000CE0000CE0000CE00
00CE0000CE0000CE0000CE0000CE0000CE0000CE0000CE0000CF0000CE0000CF0000CF0000CE00\
00CE0000CE0000CE0000CF0000CF0000CF0000CE0000CF0000D00000CF0000CF00
00CF0000CE0000CF0000CF0000CF0000CF0000CF0000D00000CF0000CE0000CF0000CF0000CF00\
00CF0000CF0000CF0000CF0000CF0000CF0000CF0000D00000CF0000CF0000CF00
00CF0000CF0000CF0000CF0000CF0000CF0000CF0000CF00
00C20000C10000C20000C10000C20000C40000C40000C30000C30000C40000C50000C40000C500\
00C60000C50000C60000C60000C60000C70000C80000C80000C90000C90000C800
00C80000C90000CA0000CA0000CA0000CA0000CB0000CB0000CA0000CA0000CB0000CB0000CB00\
00CB0000CB0000CB0000CB0000CB0000CB0000CB0000CB0000CB0000CA0000CB00
00CC0000CD0000CC0000CC0000CC0000CC0000CD0000CC0000CE0000CC0000CD0000CE0000CD00\
00CD0000CE0000CE0000CD0000CE0000CE0000CE0000CE0000CE0000CE0000CE00
00CE0000CE0000CE0000CE0000CD0000CF0000CE0000CE0000CF0000CF0000CE0000CF0000CF00\
00CE0000CF0000CE0000CE0000CF0000D00000CE0000CF0000D00000CF0000CF00
00CE0000CF0000CE0000D00000CF0000CF0000CF0000CF0000CF0000CF0000CE0000CF0000CF00\
00CF0000D00000D00000D00000CF0000CF0000CF0000CF0000D00000CF0000CF00
00CF0000CF0000CF0000CF0000CE0000CF0000CF0000D000
00C00000C10000C30000C20000C20000C30000C40000C30000C40000C50000C40000C50000C600\
00C60000C50000C60000C60000C60000C60000C70000C70000C80000C90000C800
00C90000C80000C90000CA0000CA0000CA0000CA0000CA0000CA0000CB0000CB0000CB0000CA00\
00CB0000CB0000CB0000CB0000CA0000CA0000CB0000CB0000CB0000CB0000CB00
00CC0000CC0000CC0000CC0000CC0000CC0000CD0000CC0000CC0000CD0000CD0000CD0000CD00\
00CE0000CE0000CD0000CE0000CD0000CF0000CE0000CE0000CE0000CE0000CE00
00CD0000CE0000CE0000CE0000CE0000CE0000CE0000CE0000CE0000CE0000CF0000CE0000CE00\
00CE0000CE0000CF0000CF0000CF0000CE0000CF0000CE0000CF0000CF0000CF00
00CE0000CF0000CF0000CF0000CF0000CF0000CF0000CF0000D00000CF0000D00000CF0000CF00\
00D00000D00000D00000D00000CF0000CF0000D00000CF0000CF0000CF0000CF00
00CF0000D00000CF0000CF0000CE0000CF0000CE0000CF00
00C10000C20000C10000C20000C20000C30000C40000C30000C20000C40000C40000C50000C500\
00C50000C50000C60000C70000C60000C70000C70000C90000C80000C80000C800
00C80000C80000C90000C90000CB0000C90000CA0000CA0000C90000CA0000CB0000CB0000CA00\
00CA0000CB0000CB0000CB0000CA0000CA0000CB0000CB0000CC0000CB0000CC00
00CB0000CB0000CC0000CC0000CC0000CD0000CC0000CD0000CD0000CD0000CD0000CD0000CD00\
00CD0000CE0000CE0000CE0000CE0000CE0000CE0000CD0000CE0000CE0000CE00
00CE0000CE0000CF0000CD0000CF0000CE0000CD0000CE0000CD0000CE0000CE0000CE0000CE00\
00CE0000CF0000CE0000CF0000CF0000CE0000CE0000CF0000CF0000CF0000CF00
00CF0000CF0000CE0000D00000CF0000CF0000CF0000CF0000D00000CF0000D00000CE0000CF00\
00CF0000D00000CF0000D00000CF0000CF0000D00000CF0000D10000CF0000D000
00CF0000CF0000CF0000CF0000CF0000CF0000D00000CF00
00C10000C20000C00000C10000C10000C30000C40000C40000C40000C30000C40000C30000C400\
00C40000C40000C60000C60000C70000C80000C70000C70000C80000CA0000C900
00C90000C90000CA0000C90000CA0000CA0000CB0000CA0000CA0000CB0000CA0000CB0000CA00\
00CA0000CB0000CA0000CB0000CC0000CB0000CB0000CB0000CA0000CC0000CB00
00CB0000CD0000CC0000CB0000CB0000CC0000CD0000CD0000CC0000CD0000CD0000CC0000CD00\
00CD0000CD0000CE0000CD0000CE0000CE0000CE0000CE0000CD0000CD0000CF00
00CE0000CE0000CD0000CE0000CD0000CF0000CF0000CE0000CF0000CE0000CE0000CE0000CE00\
00CD0000CE0000CE0000CE0000CE0000CF0000CE0000CF0000CE0000CF0000CF00
00CF0000CF0000D00000CE0000CF0000CF0000CF0000CF0000CF0000D00000CF0000CF0000CF00\
00CF0000D00000CF0000CF0000CF0000CF0000CF0000CF0000CF0000CF0000D000
00D00000CE0000CF0000CE0000CF0000CF0000D00000CF00
00C00000C10000C20000C20000C30000C30000C30000C40000C30000C30000C40000C50000C400\
00C50000C50000C50000C60000C60000C70000C70000C70000C80000C90000C900
00C90000C90000C90000CA0000CA0000C90000CA0000CB0000CB0000CA0000CA0000CA0000CA00\
00CB0000CB0000CB0000CB0000CB0000CA0000CB0000CB0000CB0000CC0000CC00
00CB0000CC0000CC0000CB0000CA0000CC0000CC0000CD0000CD0000CB0000CC0000CD0000CE00\
00CC0000CD0000CE0000CE0000CE0000CE0000CD0000CE0000CD0000CE0000CE00
00CE0000CD0000CD0000CE0000CE0000CE0000CF0000CF0000CE0000CF0000CF0000CF0000CE00\
00CE0000CE0000CF0000CF0000CE0000CF0000CD0000CE0000CF0000CE0000CF00
00CF0000CF0000CF0000CF0000CF0000CF0000CE0000CF0000CF0000CF0000CF0000CF0000CF00\
00CF0000CF0000D00000CF0000CF0000D00000CF0000CF0000D00000CF0000CF00
00CF0000CF0000CF0000CF0000CF0000CF0000CF0000CE00
00C00000BF0000C10000C30000C30000C30000C40000C40000C30000C30000C40000C40000C400\
00C30000C50000C50000C60000C50000C60000C70000C80000C80000C90000C900
00C90000C90000C90000C90000CA0000CA0000CA0000C90000CA0000CA0000CA0000CA0000CB00\
00CB0000CB0000CB0000CB0000CB0000CA0000CB0000CB0000CB0000CA0000CA00
00CB0000CB0000CC0000CC0000CC0000CC0000CC0000CC0000CC0000CC0000CC0000CD0000CD00\
00CD0000CE0000CD0000CD0000CE0000CE0000CE0000CE0000CD0000CE0000CE00
00CE0000CE0000CD0000CE0000CF0000CE0000CE0000CE0000CE0000CD0000CE0000CE0000CE00\
00CE0000CE0000CE0000CF0000CE0000CE0000CE0000CF0000CF0000CF0000D000
00CF0000CE0000CF0000CF0000CE0000CF0000CE0000CF0000CF0000CF0000D10000CF0000CE00\
00CE0000CF0000CF0000CF0000CF0000CF0000CF0000CF0000CF0000CE0000CE00
00CF0000CE0000CF0000CE0000CF0000CF0000CF0000CE00
00C00000C00000C10000C10000C20000C40000C30000C40000C40000C30000C40000C50000C400\
00C40000C50000C50000C50000C60000C70000C80000C70000C70000C80000C900
00C90000C80000CA0000C90000CA0000CB0000CA0000CA0000CA0000CA0000CB0000CB0000CA00\
00CA0000CC0000CB0000CB0000CB0000CA0000CB0000CB0000CB0000CB0000CB00
00CC0000CB0000CC0000CC0000CB0000CC0000CC0000CD0000CC0000CD0000CC0000CD0000CD00\
00CD0000CE0000CD0000CE0000CE0000CE0000CD0000CD0000CD0000CE0000CE00
00CE0000CE0000CE0000CE0000CD0000CE0000CE0000CF0000CD0000CF0000CE0000CE0000CE00\
00CF0000CE0000CE0000CF0000CE0000CF0000CE0000CF0000CE0000CF0000CF00
00CF0000CE0000CF0000CF0000CF0000CE0000CE0000CF0000CF0000CF0000CE0000CF0000CF00\
00D00000D00000CF0000CF0000D00000CF0000D00000CF0000CF0000CF0000CE00
00D00000CF0000CE0000CF0000CE0000CF0000CF0000CF00
00C00000C00000C10000C20000C30000C30000C30000C30000C30000C30000C30000C40000C400\
00C40000C40000C50000C60000C70000C70000C70000C70000C80000C80000C800
00C80000C90000C90000CA0000CA0000CA0000C90000CA0000CA0000CA0000C90000CB0000CB00\
00CA0000CB0000CB0000CB0000CB0000CB0000CB0000CC0000CB0000CB0000CC00
00CC0000CC0000CC0000CB0000CC0000CB0000CC0000CD0000CD0000CC0000CC0000CC0000CC00\
00CD0000CD0000CD0000CE0000CE0000CD0000CE0000CD0000CC0000CE0000CE00
00CE0000CE0000CE0000CE0000CE0000CD0000CE0000CE0000CE0000CF0000CE0000CE0000CE00\
00CF0000CE0000CF0000CF0000CE0000CF0000CF0000CE0000CF0000CE0000CE00
00CE0000CF0000CF0000CE0000CF0000CE0000CE0000CE0000CF0000CF0000CE0000CE0000CF00\
00CF0000D00000CE0000CF0000CE0000CF0000D00000CF0000CF0000CE0000CE00
00CF0000D00000CF0000CF0000CF0000CF0000CF0000CF00
00C10000C10000C10000C00000C20000C30000C20000C30000C30000C40000C20000C40000C400\
00C40000C40000C50000C40000C50000C60000C70000C70000C80000C80000C900
00C90000C80000C90000C90000C90000CA0000CA0000CA0000CB0000CB0000CB0000CB0000CA00\
00CB0000CB0000CA0000CB0000CB0000CB0000CB0000CC0000CB0000CB0000CB00
00CC0000CC0000CC0000CC0000CB0000CC0000CD0000CC0000CC0000CC0000CC0000CE0000CD00\
00CD0000CD0000CE0000CE0000CD0000CE0000CD0000CE0000CD0000CD0000CE00
00CD0000CD0000CD0000CE0000CE0000CE0000CE0000CF0000CE0000CE0000CE0000CE0000CE00\
00CE0000CF0000CF0000CE0000CF0000CF0000CE0000CF0000CF0000CE0000CF00
00CE0000CD0000CF0000CF0000CE0000CF0000CE0000CF0000CF0000CF0000D00000CF0000CF00\
00CF0000CF0000CF0000CF0000CE0000CE0000CF0000CF0000CF0000CF0000CF00
00D00000CF0000CF0000CF0000CF0000CE0000CF0000CF00
00BF0000BF0000C00000C10000C20000C20000C30000C20000C40000C30000C40000C40000C300\
00C40000C40000C50000C50000C50000C50000C70000C60000C70000C80000C800
00C90000C80000C80000C90000CA0000C90000CA0000CA0000C90000CA0000CA0000CA0000CA00\
00CB0000CA0000CA0000CA0000CB0000CB0000CA0000CC0000CB0000CC0000CB00
00CB0000CB0000CB0000CC0000CC0000CC0000CB0000CC0000CC0000CC0000CC0000CD0000CC00\
00CE0000CE0000CD0000CC0000CC0000CE0000CD0000CD0000CD0000CD0000CD00
00CE0000CE0000CD0000CE0000CD0000CF0000CE0000CE0000CE0000CE0000CF0000CE0000CE00\
00CE0000CE0000CE0000CE0000CF0000CF0000CE0000CF0000CF0000CE0000CE00
00CE0000CF0000CF0000CF0000CE0000CF0000D00000CF0000CF0000CF0000CF0000CF0000CF00\
00CF0000CF0000CF0000CF0000CF0000CE0000CF0000CF0000D00000CF0000CE00
00CE0000D00000CF0000CE0000CE0000CF0000CE0000CF00
00BF0000BF0000C10000C10000C20000C20000C30000C40000C30000C30000C30000C30000C400\
00C40000C40000C40000C50000C70000C70000C60000C50000C60000C70000C800
00C80000C80000C80000C90000C80000C90000C90000CA0000CA0000CA0000C90000CA0000CA00\
00CA0000C90000C90000CB0000CA0000CA0000CA0000CB0000CB0000CC0000CB00
00CB0000CC0000CC0000CC0000CC0000CB0000CC0000CC0000CB0000CC0000CC0000CE0000CD00\
00CD0000CD0000CD0000CD0000CD0000CD0000CD0000CD0000CD0000CE0000CE00
00CE0000CE0000CD0000CE0000CD0000CE0000CE0000CD0000CD0000CD0000CE0000CE0000CE00\
00CE0000CD0000CE0000CE0000CE0000CF0000CE0000CE0000CE0000CE0000CE00
00CF0000CE0000CE0000CF0000CF0000CF0000CE0000CF0000CF0000CF0000CF0000CF0000CF00\
00CF0000CF0000CE0000CE0000CF0000CF0000CF0000CF0000CF0000CF0000CF00
00CE0000D00000CF0000CF0000CE0000CF0000CF0000CF00
00C00000BF0000C00000C00000C10000C20000C30000C20000C30000C30000C40000C40000C400\
00C40000C40000C50000C60000C70000C70000C70000C70000C70000C80000C800
00C80000C80000C90000CA0000C90000C90000C90000C90000CA0000C90000CA0000CA0000C900\
00CA0000CA0000CB0000CA0000CB0000CA0000CA0000CB0000CA0000CC0000CB00
00CC0000CC0000CC0000CB0000CC0000CB0000CB0000CC0000CC0000CC0000CD0000CD0000CD00\
00CD0000CC0000CD0000CD0000CD0000CD0000CE0000CD0000CD0000CD0000CD00
00CD0000CE0000CD0000CD0000CE0000CE0000CE0000CE0000CE0000CE0000CE0000CE0000CF00\
00CF0000CE0000CE0000CE0000CF0000CF0000CE0000CE0000CF0000CE0000CE00
00CF0000CE0000CE0000CF0000CE0000CF0000CF0000CF0000CE0000CF0000CF0000CE0000CF00\
00CF0000CF0000CF0000CF0000CF0000CE0000CF0000CF0000CF0000CF0000CF00
00CF0000CE0000CF0000CF0000CF0000CF0000CF0000CF00
00BF0000C00000C10000C10000C10000C10000C10000C20000C30000C30000C30000C40000C400\
00C50000C30000C40000C50000C60000C70000C70000C60000C70000C90000C600
00C70000C80000C90000C90000C90000C90000CA0000C90000C90000CA0000CA0000CA0000C900\
00CA0000CA0000CA0000CA0000CA0000CA0000CA0000CB0000CA0000CB0000CA00
00CB0000CB0000CB0000CB0000CB0000CC0000CC0000CB0000CC0000CC0000CC0000CD0000CD00\
00CD0000CD0000CD0000CD0000CC0000CE0000CE0000CD0000CC0000CC0000CD00
00CE0000CD0000CD0000CD0000CD0000CE0000CD0000CD0000CE0000CE0000CF0000CE0000CF00\
00CF0000CE0000CE0000CF0000CE0000CE0000CE0000CE0000CE0000CF0000CF00
00CE0000CE0000CF0000CF0000CE0000CF0000CE0000CF0000CF0000CF0000CF0000CF0000CE00\
00CF0000CE0000CF0000CF0000CE0000CE0000CF0000CE0000CE0000CF0000CF00
00CE0000CE0000CE0000CE0000CE0000CE0000CF0000CE00
00BF0000C00000BF0000C00000C20000C10000C20000C20000C30000C40000C30000C30000C400\
00C40000C40000C40000C50000C70000C70000C70000C60000C70000C80000C700
00C80000C80000C90000C90000C90000C90000C90000C90000C90000CA0000C90000C90000CA00\
00CA0000CA0000CA0000CA0000CA0000CB0000C90000CA0000CA0000CA0000CA00
00CB0000CB0000CC0000CB0000CC0000CB0000CC0000CC0000CC0000CB0000CC0000CD0000CC00\
00CC0000CC0000CD0000CC0000CD0000CC0000CD0000CC0000CD0000CC0000CD00
00CD0000CE0000CD0000CD0000CD0000CE0000CE0000CE0000CE0000CD0000CE0000CE0000CE00\
00CE0000CD0000CE0000CE0000CF0000CE0000CF0000CE0000CE0000CE0000CF00
00CE0000CF0000CF0000CF0000CE0000CF0000CE0000CF0000CF0000CE0000CF0000CE0000CF00\
00CE0000CE0000CF0000CE0000CF0000CE0000CF0000CE0000CF0000CE0000CE00
00CE0000CE0000CE0000CE0000CE0000CE0000CF0000CF00
00C00000C00000C00000C10000C10000C10000C20000C20000C20000C20000C30000C30000C400\
00C30000C40000C50000C50000C60000C60000C60000C70000C70000C70000C700
00C80000C90000C90000C80000C90000C90000CA0000C90000C90000CA0000CA0000CA0000C900\
00CA0000C90000CA0000CA0000C90000CA0000CA0000CA0000CA0000CB0000C900
00CA0000CB0000CB0000CA0000CB0000CB0000CB0000CC0000CC0000CC0000CC0000CB0000CB00\
00CC0000CC0000CC0000CD0000CD0000CD0000CC0000CD0000CD0000CE0000CE00
00CD0000CD0000CD0000CE0000CE0000CD0000CD0000CE0000CD0000CD0000CE0000CE0000CD00\
00CE0000CD0000CD0000CE0000CE0000CE0000CE0000CE0000CE0000CF0000CF00
00CE0000CE0000CE0000CF0000CF0000CF0000CE0000CE0000CF0000CE0000CE0000CE0000CE00\
00CE0000CF0000CE0000CF0000CE0000CE0000CE0000CF0000CE0000CE0000CE00
00CF0000CE0000CE0000CE0000CE0000CE0000CE0000CE00
00BF0000BF0000C00000C00000C00000C00000C10000C20000C30000C10000C30000C30000C300\
00C40000C40000C50000C50000C50000C50000C60000C60000C60000C70000C700
00C80000C70000C80000C80000C90000C90000C90000C90000CA0000C90000C90000CA0000CA00\
00C90000C90000C90000CA0000C90000CA0000CA0000CA0000C90000CB0000CB00
00CB0000CA0000CB0000CB0000CB0000CB0000CC0000CB0000CC0000CC0000CC0000CB0000CB00\
00CC0000CC0000CC0000CD0000CD0000CD0000CE0000CE0000CD0000CD0000CE00
00CD0000CD0000CE0000CE0000CD0000CE0000CD0000CD0000CC0000CE0000CE0000CE0000CE00\
00CD0000CD0000CD0000CE0000CE0000CD0000CE0000CE0000CE0000CE0000CF00
00CD0000CE0000CE0000CE0000CE0000CF0000CE0000CE0000CE0000CE0000CF0000CE0000CE00\
00CF0000CE0000CE0000CF0000CF0000CE0000CE0000CF0000CE0000CF0000CE00
00CE0000CE0000CE0000CF0000CE0000CE0000CE0000CE00
00BE0000BF0000C00000C00000C10000C10000C10000C10000C10000C00000C10000C30000C300\
00C30000C40000C50000C40000C50000C40000C50000C60000C70000C70000C600
00C70000C70000C80000C90000C90000CA0000C80000C80000C90000CA0000CA0000CA0000CA00\
00CA0000CA0000C90000CA0000C90000C90000C90000CA0000CB0000CB0000CA00
00CC0000CB0000CA0000CA0000CA0000CB0000CA0000CB0000CB0000CB0000CB0000CC0000CC00\
00CB0000CD0000CD0000CC0000CE0000CD0000CD0000CD0000CD0000CD0000CE00
00CE0000CD0000CD0000CE0000CD0000CD0000CD0000CE0000CD0000CE0000CE0000CE0000CD00\
00CD0000CE0000CD0000CE0000CD0000CD0000CE0000CD0000CE0000CF0000CE00
00CE0000CE0000CE0000CE0000CE0000CE0000CE0000CE0000CE0000CE0000CF0000CE0000CE00\
00CF0000CE0000CF0000CE0000CE0000CE0000CF0000CF0000CE0000CE0000CE00
00CE0000CF0000CF0000CE0000CE0000CE0000CE0000CF00
00BD0000C00000C00000BF0000C00000C10000C20000C20000C10000C10000C10000C20000C400\
00C40000C30000C40000C40000C50000C60000C50000C60000C60000C60000C700
00C70000C70000C80000C80000C80000C90000C80000C80000C90000C90000CA0000C90000C900\
00C90000C90000CA0000C90000C90000C90000C90000CA0000CA0000CA0000CB00
00CA0000CB0000CB0000CB0000CB0000CB0000CB0000CC0000CB0000CB0000CB0000CB0000CC00\
00CB0000CD0000CC0000CD0000CC0000CD0000CD0000CC0000CC0000CD0000CE00
00CE0000CD0000CD0000CD0000CD0000CE0000CD0000CD0000CD0000CD0000CE0000CE0000CE00\
00CE0000CE0000CD0000CE0000CE0000CE0000CD0000CE0000CE0000CE0000CE00
00CE0000CE0000CE0000CE0000CE0000CF0000CE0000CE0000CE0000CF0000CE0000CE0000CF00\
00CF0000CF0000CF0000CE0000CF0000CF0000D00000CE0000CE0000CE0000CE00
00CE0000CE0000CF0000CE0000CE0000CE0000CF0000CE00
00BF0000BF0000BF0000C00000C00000C10000C20000C10000C10000C10000C30000C30000C300\
00C30000C30000C30000C40000C50000C50000C60000C50000C60000C60000C600
00C70000C70000C70000C80000C90000C80000C90000CA0000C90000C90000C90000C90000C900\
00C90000C90000CA0000C90000C80000C80000C90000CA0000C90000CA0000CA00
00CB0000CB0000CB0000CB0000CB0000CB0000CB0000CB0000CB0000CB0000CB0000CC0000CC00\
00CC0000CC0000CC0000CC0000CC0000CC0000CE0000CC0000CD0000CC0000CD00
00CD0000CD0000CD0000CD0000CE0000CD0000CC0000CD0000CD0000CE0000CE0000CD0000CD00\
00CE0000CE0000CD0000CE0000CE0000CD0000CE0000CE0000CE0000CE0000CF00
00CE0000CE0000CD0000CF0000CD0000CE0000CE0000CE0000CE0000CF0000CF0000CE0000CE00\
00CE0000CE0000CE0000CE0000CF0000CF0000CF0000CF0000CE0000CE0000CD00
00CD0000CE0000CE0000CE0000CE0000CE0000CF0000CE00
00BF0000BF0000BE0000BF0000C00000C00000C00000C10000C10000C30000C10000C30000C300\
00C20000C20000C40000C40000C40000C50000C40000C40000C60000C50000C600
00C70000C60000C70000C70000C70000C80000C90000C90000C90000C90000C90000C90000C900\
00C90000C90000C90000C80000C80000C90000C90000C80000CA0000C90000CA00
00CA0000CB0000CB0000CB0000CA0000CC0000CB0000CB0000CA0000CB0000CB0000CC0000CB00\
00CB0000CC0000CC0000CC0000CC0000CC0000CD0000CC0000CC0000CE0000CC00
00CD0000CC0000CD0000CD0000CD0000CD0000CD0000CD0000CD0000CE0000CE0000CE0000CE00\
00CE0000CD0000CD0000CD0000CE0000CE0000CD0000CE0000CE0000CE0000CD00
00CE0000CE0000CE0000CE0000CE0000CE0000CE0000CF0000CE0000CE0000CE0000CD0000CE00\
00CE0000CE0000CE0000CE0000CE0000CE0000CE0000CE0000CE0000CE0000CD00
00CE0000CE0000CE0000CE0000CD0000CE0000CE0000CE00
00BD0000BF0000C00000BF0000C00000C00000C10000C00000C20000C20000C30000C30000C200\
00C30000C20000C40000C40000C50000C30000C50000C40000C60000C50000C600
00C70000C80000C60000C70000C80000C80000C80000C90000C90000C90000C90000C90000C800\
00C90000C90000C80000C90000C90000C90000C90000CB0000C90000C90000C900
00CA0000CA0000CA0000CA0000CA0000CB0000CC0000CB0000CB0000CB0000CB0000CC0000CC00\
00CB0000CC0000CC0000CC0000CD0000CC0000CC0000CC0000CC0000CC0000CC00
00CC0000CD0000CD0000CC0000CE0000CD0000CE0000CD0000CD0000CE0000CE0000CE0000CC00\
00CE0000CD0000CD0000CD0000CE0000CE0000CC0000CD0000CE0000CE0000CD00
00CE0000CD0000CD0000CD0000CE0000CF0000CE0000CE0000CE0000CE0000CE0000CD0000CD00\
00CE0000CE0000CD0000CE0000CE0000CE0000CF0000CF0000CE0000CE0000CE00
00CD0000CE0000CD0000CD0000CE0000CD0000CE0000CD00
00BD0000BE0000BF0000BE0000C00000C10000C00000C00000C10000C00000C20000C10000C200\
00C30000C20000C40000C30000C60000C50000C40000C50000C50000C50000C600
00C70000C70000C70000C70000C80000C80000C80000C80000C70000C80000C80000C80000C900\
00C90000CA0000C90000C80000C90000C90000C90000C90000C90000C90000C900
00CA0000CA0000CA0000CA0000CB0000CA0000CC0000CB0000CC0000CC0000CB0000CB0000CB00\
00CC0000CC0000CC0000CC0000CC0000CD0000CB0000CC0000CB0000CC0000CC00
00CD0000CC0000CC0000CC0000CD0000CC0000CD0000CD0000CD0000CD0000CD0000CD0000CD00\
00CC0000CE0000CD0000CD0000CD0000CD0000CC0000CD0000CD0000CD0000CD00
00CD0000CD0000CD0000CD0000CE0000CE0000CE0000CD0000CE0000CD0000CE0000CD0000CE00\
00CD0000CE0000CE0000CE0000CD0000CE0000CE0000CE0000CE0000CD0000CD00
00CE0000CE0000CD0000CD0000CD0000CE0000CE0000CE00
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.678571 0.00744048 0.97619 0.30506 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00744048 0.0238095 0.00744048 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
384 string
128 128 8 [128 0 0 128 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
00009500009300009600009600009800009600009700009600009900009900009800009A000099\
00009B00009C00009C00009B00009C00009E00009F0000A100009F00009F0000A0
0000A100009E00009E00009D00009E00009B00009E0000A000009E00009C000093000082000060\
00004700004000004200004400004700004700004C00004C00004C000050000050
00005000004D00004900003F00003C00003E00004100004300004300004800004700004900004B\
00004D00005000005600006000006000007D0000A80000AF0000B00000B00000AF
0000B10000B00000B00000B00000B00000B00000AF0000AE0000B00000B00000B10000B10000B0\
0000AC0000A90000A300009900008E00008000007800007000007B000079000083
00008F00009C0000A60000AE0000B10000B30000B40000B40000B40000B40000B40000B40000B3\
0000B30000B30000B00000B00000B00000B00000B30000B30000B50000B60000B7
0000B60000B60000B60000B60000B60000B60000B70000B6
00009500009400009300009500009700009600009800009700009A00009700009A00009A00009B\
00009B00009C00009D00009D00009D00009F0000A000009E00009F00009F00009C
00009700009100008B00008400007D00007B00007E00008400008C00009000008D000077000057\
00004300004000004400004400004800004900004C00004C00004D00004F00004E
00005000004D00004700003F00003E00003C00004000004300004600004900004900004A00004B\
00004F00005200005200005A00006000006600009A0000AE0000AF0000B10000B0
0000B00000AF0000B00000AE0000AF0000AC0000AA0000AA0000AC0000AE0000B00000AE0000AB\
0000A400009700008700007000005800004800004100003E00003D00005D000055
0000540000640000790000980000A90000B10000B30000B40000B40000B30000B30000B20000B0\
0000AD0000A600009D00009600009300009A0000A10000A90000B10000B50000B6
0000B70000B60000B70000B70000B60000B70000B60000B7
00009300009400009500009500009700009700009600009900009800009A00009B00009B00009D\
00009D00009D00009E00009D00009F00009F0000A00000A000009D00009900008F
00008300007100006000005100004B00004B00004C00004F00005700006300007400006B00004F\
00004200003F00004300004300004800004800004C00004C00004E00004D000050
00004F00004C00004900004000003C00003D00003F00004300004600004A00004A00004C00004D\
00004F00005200005400005700005F00005F0000850000AD0000B00000B10000B1
0000B00000AE0000A80000A400009D00009200008300007F00008300008F0000A00000A500009D\
00009300007A00005B00004700003C00003900003900003B00003E00003B000057
00004900004E0000570000670000850000A60000B10000B50000B40000B30000B00000AB0000A1\
00009300007900006100005300005200005C00006900007C0000950000AC0000B3
0000B50000B60000B70000B60000B60000B70000B60000B7
00009400009400009400009600009600009700009700009900009B00009C00009C00009C0000A0\
00009E00009F00009E0000A00000A00000A00000A000009E000099000091000081
00006800005100004500004300004100004500004900004B00004D00004D000050000050000048\
00003F00003E00004100004300004800004900004B00004C00004F00005000004D
00004F00004F00004B00004400003B00003F00004100004300004600004A00004D00004F000050\
00005100005100005400005600005E00005F0000730000AB0000B10000B20000B0
0000AC0000A500009900008500006B00005500004900004800004B00005300006500007C000085\
00007300005600004100003C00003800003900003A000037000036000035000037
00003900003B00004300004B0000560000780000A60000B20000B10000AD0000A700009E000086\
00006300004800003F00004300004D00005200005A00006300006B0000860000A5
0000B10000B50000B60000B60000B60000B60000B60000B6
00009300009600009300009600009900009800009800009A00009B00009B00009D00009D00009E\
0000A000009F0000A00000A10000A10000A000009E00009B000093000088000070
00005300004500004200004100004600004900004A00004C00004C00004D00004B00004A000043\
00003E00003D00003F00004600004700004A00004B00004F00004F000053000053
00005300004E00004B00004A00003E00003F00004200004500004900004B00004F000050000050\
00005900005E00005900005800005F0000600000660000A40000B00000AF0000AB
0000A500009B00007F00005C00004600003F00003E00004400004300004200004800004F000057\
00004F00004000003A00003A00003A00003B000038000033000035000034000033
00003600003700003A0000410000490000500000700000A50000AE0000A80000A000008D00005E\
00004500003F00004000004800004800004A00005000005600005A000064000077
00009E0000B30000B50000B60000B60000B60000B70000B7
00009500009500009600009500009600009900009900009C00009A00009C00009D00009F00009D\
0000A000009E0000A00000A20000A00000A000009F00009A00008F00007F00005E
00004700004100004000004600004500004900004B00004B00004D00004D00004D00004B000047\
00004100003B00003F00004400004900004C00004C00005100005000006200005C
00005300004F00004D00004D00004200004100004400004500004B00004E000051000056000055\
00006100008400006B00005B00005C00006000005D0000920000A80000AA0000A7
00009D00008800005F00004700003F00003F00003F00003E00003B00003B00003D00003F000041\
00003E00003B00003F00003C00003D000039000038000034000034000033000033
00003400003700003700003D00004300004A00004C0000730000A40000A4000096000071000049\
00004100004200004600004600004900004A00004D00005000005400005C000063
00007200009F0000B30000B60000B60000B50000B60000B7
00009600009500009600009800009700009900009800009A00009A00009C00009E00009F00009D\
0000A10000A00000A00000A10000A30000A000009F00009800008F00007A000058
00004400004200004300004500004700004800004B00004C00004B00004D00004E00004B00004C\
00004500003F00003E00004300004800004D00005000005300005000007C000078
00005600005300004F00004F00004800004800004400004600004A00004F000052000056000059\
00005C00008500007800005900005900005A00005C000067000074000087000097
00008F00006B00004B00004100003F00004000003C00003B00003A00003900003A00003900003E\
00003B00003900003E00003C000039000037000038000035000034000034000033
00003300003300003300003600003D00004200004A00004500008700009D000087000056000042\
00004100004500004400004700004700004A00004B00004D00005000005500005E
0000630000710000A20000B50000B40000B10000B10000AF
00009400009400009500009700009800009800009B00009A00009A00009C00009E00009C00009D\
0000A00000A00000A00000A20000A10000A000009C00009800008E000076000053
00004300004100004400004200004500004A00004B00004C00004C00004E00004E00004D00004B\
00004A000040000041000043000047000051000054000054000051000069000079
00005B00005300005200004F00004F00005D00004800004800004C00004F000050000054000059\
00005700005F00006300005900005700005700005500004E00004E000051000065
00006F00005500004000003F00004300003C00003A00003A00003900003B00003900003A00003B\
000039000039000038000037000038000035000036000034000035000035000035
00003600003400003300003400003800003A00004500003D00005800009600007800004C000042\
00004300004100004300004600004800004900004B00004B000050000052000057
00006000005F00007B0000A70000A500009B00008F000087
00009300009300009500009700009600009A00009A00009900009B00009B00009E00009D00009F\
0000A00000A00000A30000A30000A30000A000009E00009900008D000078000058
00004200004100004000004200004700004900004B00004D00004E00004F00004F00004C00004E\
00004C00004900004000004400004B00004F00005400005300005100005500005C
00005700005600005700004F00005E00007E00005E00004A00004C000050000053000056000056\
00005A00005800005900005B000054000053000051000041000040000040000042
00004600004300003C00003F00003D00003B00003B00003A00003A00003A00003900003800003A\
000038000038000037000037000038000036000036000037000036000035000034
00003600003700003400003400003800003800004000003B00004000008C00007100004B000041\
00004200004000004300004800004A00004B00004E00004E000050000053000055
00005700005A00005C00008100007900006100005300004E
00009300009600009600009600009800009800009900009A00009900009D00009C00009F00009E\
00009F0000A10000A20000A00000A200009F00009D00009700008D00007C00005F
00004500004100004200004200004600004A00004B00004F00005400005700005900005200004F\
00004C00004C000045000046000049000051000052000055000051000051000053
00005400005600005800005100006700008300008100005D00004A000050000053000055000056\
00005600005700005800005700005400005300004800003B00003C00003C00003E
00003F00003B00003B00003B00003800003A000039000038000039000039000039000037000038\
000037000037000037000036000035000036000035000034000036000037000036
00003800003E00003900003500003800003800004200003C00003800008600007100004B000041\
00004100004100004500004900004C00004E000050000050000054000055000053
00005400005400005600005800004F00004700004700004E
00009300009500009600009600009800009900009A00009800009900009D00009C00009D0000A0\
00009F00009F0000A10000A10000A10000A000009D00009A00009100008500006D
00004E00004100004200004200004600004900004B00004F00005900005C00006400005A000050\
00004F00005000004A00004400004700004E000054000056000050000051000052
00005300005200005400005100005200005900006600007200005700004C000051000055000055\
00005700005600005700005500005400004E00003F00003C00003A00003A00003B
00003B00003900003C00003900003900003A000039000038000038000039000039000038000039\
00003600003600003400003600003500003600003800003600003900003C000037
00005500007800005200003B00003B00003700004500004100003B00008D00007C000052000042\
00004400004100004700004D00005000005300005600005500006B00007400005C
00005500005300005600005200004500004A00004E00004E
00009300009400009500009600009800009A00009900009A00009A00009900009E00009D00009E\
00009F00009F0000A10000A00000A000009F00009A00009500008E00008300006F
00005300004300004100004300004500004B00004E00005000005900005E000072000069000054\
00005200005000004F00004A00004C00004A00004D000050000050000050000050
00005000004D00004E00004800004000004000004100004900006100005D000052000054000053\
00005400005700005400005300005100004100003C00003900003C00003C00003A
00003B00003A00003900003900003800003900003800003700003800003900003B00003B000038\
00003800003800003600003500003600003300003500003700003900003D000036
00005E00008300005300003B00003900003900004100003A00004400008C00007C000058000042\
00003F00004100004500004A000050000052000058000054000073000096000068
00005600005300005400004F00004600004900004900004C
00009500009300009500009500009900009A00009900009A00009A00009B00009D00009D00009D\
00009F0000A000009F00009F00009D00009500008D000081000072000060000050
00004300003B00003D00004100004500004900004B000050000057000059000060000064000056\
00005100005400004C00005500007C00005000004B00005100004E000050000050
00004E00004900004500003700003500003400003800003A00003D00006600007C000062000054\
00005100005300005000004A00004200003E00003C00003A00003B00003B00003A
00003B00003800003800003700003700003700003700003800003B00003800004200005000003D\
00003A000038000037000036000036000035000037000036000035000036000034
00003E00004200003800003900003700003700003900003500004000006100005D00004E000042\
00003E00004000004500004A00004E00004F00005300005400005D00006B00005D
000056000053000052000050000045000046000048000049
00009400009300009700009800009700009800009900009900009A00009B00009C00009F00009F\
00009F00009F00009E00009700009000008200006C00005600004800003E00003D
00003B00003900003900003F00004200004600004B00004D00004F00005100004F000053000055\
00005400005800005300005C00009800008800005B00004F00004D00004C00004C
00004800004200003600002F00002F00003200003400003A00003E00003D000079000095000080\
00005F00004C00004800003D00004000004800004300003B00003B00003A000043
00003D00003A00003900003700003800003700003800003900003C00003900004200005F000046\
00003C00003900003700003700003D000038000037000037000037000038000035
00003800003600003600003600003800003700003900003700004700004B00004500004100003F\
00003D00004100004500004900004D00004F000052000053000057000057000055
00005400005100005400004D00004400004600004B00004B
00009500009300009700009800009700009B00009800009A00009D00009D00009F00009E00009E\
00009F00009D00009B00009000007D00006400004D00004200003B00003C00003D
00003900003800003600003900003F00004400004700004B00004B00004C00004D00004F000051\
00005400005900005300006D00009600009B00009300007A00005D00004C000046
00004000003600003000002E00002D00003100003300003800004200003D00004100008E000093\
00007100004D00004300003A00003E00004400004200003F000038000042000072
00004300003800003800003600003400003500003800003900003D00003D00003800007E00006D\
00003E00003B00003D00002F00006300005D000039000038000038000036000038
00003700003700003700003500003700003900003C00003F00004600004B000048000046000042\
00004000004200004500004B00004D000050000053000051000054000053000054
00005300005200005200004900004500004700004B00004C
00009500009600009500009700009A00009A00009D00009C00009E00009F0000A00000A000009E\
00009D00009A00009200008400006700004C00004100003D00004000003D000039
00003800003800003800003800003900004100004500004B00004A00004C00004C00004E00004F\
00005200005300005400005600006F00008900009A00009700008400005F000042
00003C00003300002F00002F00002E00002F00003600003A00004400004400003500006C000099\
00008200005D00004600003B00003C00003C00003C00003D000038000048000064
00003D00003900003700003700003400003700003800003700003D00003C00003600007E000071\
00003F00003C00003D00003100006500007D00005000003A000037000037000038
00003600003700003600003800003A00003B00004200004400004800004C00004D00004D00004A\
00004800004300004400004900004D00004E000050000053000052000051000051
00004F00005200004E00004200004400004A00004B00004C
00009500009800009800009600009800009900009C00009D00009D00009F00009F0000A000009D\
00009B00009600008B00007500005500004500003F00004000004100003B000039
00003900003800003600003700003800003B00004100004700004900004C00004B00004900004D\
00004F00004D00004B00004700004B00005A00007F00009200008A000069000047
00003B00003400003000003100003100002F00005300004E00004E00004F00003C00004D00009A\
00009100007500005300003D00003C00003900003A00003A00003900003B00003B
00003A00003800003700003A00003600003700003800003600003A00003800003600005600004C\
00003B00003600003800003600004500005300004E00004500003D000039000038
00003900003700003800003C00003F00004500004600004A00004D00004D00004E00004F00004D\
00004E00004C00004700004800004B00004E000050000051000052000053000051
00005000004E00004700004200004900004D00004F00004F
00009600009800009700009800009B00009900009B00009C00009C0000A000009F00009F00009E\
00009700008E00007D00006200004900004100004100004000003C00003B00003A
00003800003800003600003700003700003900003A00003E00004300004800004900004A000048\
00004800004100003800003900004000004100004500007300008A00007200004F
00003F00003300003000003500003700002E00006600007300004C00004F00003F00003D000086\
00008100006C00005000003E00003B00003900003A00003800003A00003900003A
00003900003800003C00003E00003800003700003700003700003600003800003500003C00003A\
00003800003500003500003300003A00003D00003E00004000004000004000003C
00003B00003E00003C00004400004900004900004B00004D00004E000050000050000051000051\
00004F00005000004E00004A00004C00004D00004F00004F00005000004F00004F
00004D00004400004300004400004A00004D00005200004E
00009500009600009500009900009A00009B00009C00009D00009F0000A000009E00009E00009E\
00009500008900007600005800004600004100004300003F00003C00003800003A
00003800003800003800003900003900003800003A00003900003F00004100004200004200003E\
00003A00003800003400003700003900003D00003D00003800006F00007E000061
00004700003700003200003200003B00003100005A00008600005300004A00003C000038000056\
00005000004800004100003F00003A00003A00003A00003A00003B00003900003E
00003800004000005500004B00003B000038000036000037000038000037000036000036000035\
00003600003300003700003600003900003C00003C00003E000040000041000042
00003E00003C00003F00004800004B00004C00004F00004F000050000050000052000051000052\
00005300005100005300005100004D00006900006400005D00005C00006600006F
00005E00004200003F00004200004C00005100005200004E
00009700009600009700009800009A00009800009D00009F00009E0000A000009F00009E00009B\
00009500008A00006F00005300004500004200004100003E00003A000039000038
00003900003900003A00003C00003900003A00003900003900003A00003D00003D000038000036\
00003500003300003300003500003700003900003E00003A00003C00007E000075
00005800004000003200003200003600003100004400007000004A00003B00003700003300003C\
00003E00004100004100003C00003A00003700003900003C00003C00004000003E
00004E00007B00007400005900003E000037000038000035000035000035000035000034000034\
00003300003300003400003300003800003D000040000041000044000044000047
00004500003B00004300004800004A00004E00004F00004E000051000050000053000058000055\
00005500005300005700005C00005300007A00009300008600007D00007900006E
00005500004200003C00004000004A00004D00004E00004F
00009500009700009800009800009C00009B00009E00009F00009E0000A00000A100009D00009B\
00009700008900006D00005000004300004400003F00003C00003A00003A00003A
00003B00003800003E00005C00003F00003A00003900003900003B00003B00003A000034000035\
00003700003500003400003400003600003800003B00003F00003300006500007B
00006000004500003000002E00002E00002E000035000039000035000030000033000031000038\
00003D00003F00004000003D000041000040000043000043000049000043000071
00009200008E000075000057000040000039000038000034000034000035000035000033000033\
00003400003600003500003700003D00004100004700004600004700004900004A
00004A00004400004400004A00004C00004E000050000052000054000058000054000074000075\
00005C00005800005500005700005100005700006400005500004A000045000040
00003C00003B00003C00004000004600004B00004D00004F
00009600009700009600009900009A00009D00009D00009D0000A000009F0000A100009E000099\
00009500008C00007100005200004400004400003E00003A00003A00003900003B
00003E00003700004900006800003E00003A00003900003800003C00003B000037000037000038\
00003700003700003700003600003800003900003A00003B00003400003F00005E
00004900003800003300002E00002D00002C00002E00003000002F000030000031000030000035\
00003800003E00004100004400004600004700004900004C000050000049000066
00008800007500005900004400003D000038000038000033000034000033000033000031000032\
00003500003500003300003900003F00004600004800004700004C00004C00004C
00004C00004A00004500004A00004C00004F00005100005300005400005900005500006D000086\
00006500005A00005600005100005200004F00004200003C00003D00004000003E
00003700003300003500003900004300004B00004F00004F
00009600009700009700009900009C00009B00009B00009D00009D0000A000009F00009D00009C\
00009800008C00007A00005C00004800004500003D00003B00003900003B00003D
00003A00003900003F00004000003A00003900003800003900003B00003C000037000037000038\
00003800003900003600003700003C00003D00003800003800003300003500003D
00003800003600003200002E00002B00002C00002D00002C00002E00002F00002F000031000037\
00003C00004300004600004900004900004A00004B00004900004C00004C000049
00005A00004F00004300003D00003C000037000037000034000034000035000032000033000034\
00003600003600003500003D00004200004900004B00004C00005800005100004C
00004B00004D00004600004800004D00004F00005000005100005300005600005400005800005F\
00005C00005700005600005200005000004B00003B00003D00003800003400002E
00003000002F00003100003300003E00004900004E000050
00009600009700009700009900009800009A00009900009D00009E00009E00009E00009F00009C\
00009A00009400008700006F00005500004900003E00003B00003C00003E000043
00003B00003900003B00003B00003800003900003700003A00003B000038000037000037000038\
00003700003B00003B00003400006300005600003D000038000035000034000036
00003500003400002F00002D00002B00002B00002C00002D00002E00002F00003000003400003C\
00004100004500004A00004B00004C00004E00004C00004D00004E00004D00004B
00004B00004100003E00003D000039000036000035000034000033000033000031000031000031\
00003400003200003600004200004600004C00004F00004E00007C00006600004E
00004F00004B00004E00004C00004A00004E000050000051000050000056000053000054000057\
00005500005500005200004F00005000004700003600003100002E00002D00002D
00002C00002D00002F00002F00003200004100004C000051
00009400009600009800009800009800009A00009B00009C00009C00009F00009F00009F0000A1\
00009E00009B00009400008600007100005C00004100003B00003F00003E000041
00004300003A00003A00003800003A00003900003600003B00003B000038000036000036000039\
00003800003E00003D00003400007600005C000038000036000035000032000034
00003300002E00002C00002B00002B00002900002C00002C00002E00003100003100003A000040\
00004500004800004C00004D00004F00005000004D00005000005000004D00004D
00004C00004100003D00003B000038000036000034000034000033000032000032000031000031\
00003600003300003900004200004700004C00004F00004E00007500006000004F
00004F00004B00005000005300004500004D000050000050000053000055000055000053000054\
00005400005200004F00004F00004E00003C00003000002E00002E00002C00002C
00002B00002D00002E00002F000030000033000042000049
00009500009500009700009800009800009800009A00009B00009C00009E00009E0000A10000A0\
0000A200009F00009B00009300008A00007E00004F00003C00003D00003F000044
00003F00003A00003800003800003800003A00003A00003A00003C000037000038000036000038\
000037000038000038000037000048000040000038000036000034000033000031
00002E00002B00002A00002B00002A00002B00002C00002B00002E00003100003200003E000044\
00004800004900004B00005000005000005200005500005600005300005000004D
00004C00004300003B000036000037000035000035000034000033000033000032000033000031\
00003300003400003B00004200004700004900004C00004E00005500005100004D
00004D00004C00004A00003F00003E00004800004E00004F000056000055000053000054000054\
00005300005100004E00004E00004300003100002E00002E00002B00002B00002D
00002D00002E00002E00002E00002F000030000031000036
00009600009500009300009700009900009900009A00009B00009B00009F00009F0000A00000A1\
0000A20000A200009E00009C00009500008F00007400004300003A00003E00003E
00003A00003A00003900003900003900003900003B00003D00003B000037000038000037000038\
000038000038000038000037000038000038000035000034000033000032000031
00002D00002C00002A00002C00002B00002D00002C00002D00002E00002F000038000040000047\
00004800004C00005000005300005800005800007300007300005800005200004C
00004C000042000039000037000035000033000034000033000033000033000031000033000031\
00003200003300003E00004300004900004900004C00004C00005000004F00004C
00004B00004C00004300003800003500003800004500004C000051000051000052000054000054\
00005100005100004A00004900003900002F00002D00002C00002B00002A00002D
00002D00002E00003000002F00002E00002C00002F000030
00009500009600009600009800009900009900009B00009B00009C00009E00009F0000A10000A1\
0000A20000A10000A000009E00009500008D00007B00005300004200003D00003B
00003B00003900003900003A00003600003900003900003A00003A000039000038000038000038\
00003600003600003600003800003700003500003500003400003100003100002D
00002B00002A00002A00002B00003100003200002C00002E00002C00002E00003B000042000047\
00004B00004D00005100005400005700006900007F00006800005300005000004E
00004D00003D00003A000038000035000036000034000035000036000033000033000033000031\
00003300003100003C00004300004800004A00004C00004C00004C00004D00004B
00004800004800003A00002F00002F00003000003400003E00004800004C00004F000051000052\
00005200005000004700003F00003400002E00002B00002C00002E00002B00002E
00002F00003600003800003200002F00002E00002F00002D
00009600009400009500009700009800009800009A00009900009C00009E0000A000009E0000A0\
0000A000009F00009D00009800008F00007D00006000004700004000003B000038
000036000036000034000034000032000034000035000037000039000039000037000037000038\
00003700003500003600003600003600003400003600003100003200003500002E
00002B00002C00002D00002500004F00004A00002D00002D00002E00003000003B000043000047\
00004B00004C00005000005300005200005D00005D00005300005100004D00004D
00004B00003900003800003600003500003500003600003400003B000041000033000030000032\
00003000003600003A00004300004500004800004B00004D00004C00004B00004B
00004A00004000002F00002D00002B00002D00002F00003200003400003D000041000058000070\
00007600006700004600003D00002E00002B00002B00002C00002E00002D000034
00003000004C00006E00003C00003000002F00002E00002C
00009500009300009600009700009800009A00009B00009900009B00009E00009D0000A00000A0\
00009E00009D00009900009300008500006900004B00003F00003C00003A000035
000032000031000030000030000032000033000032000034000034000037000037000037000038\
00003800003600003600003600003500003500003500003100003600003500002D
00002A00002B00002C00002900003600003900002C00002D000030000030000039000043000046\
00004A00004C00004C00004E00004F00005300005500005000004E00004F00004C
00004700003A00003600003600003800003600003C000032000050000076000039000032000034\
00002F00004600004500004300004700004800004B00004B00004B000049000048
00004800003400002F00002E00002C00002B00002D00003000003200003D00003700005300009D\
00009C00008400005A00004300003000002B00002B00002D00002F00002F000035
00003000004800007C00004100003000002E00002E00002E
00009400009600009500009700009900009900009900009900009C00009C00009C00009F00009D\
00009F00009B00009800009000007D00005C00004500003F00003D000039000032
00003200003000002F000030000030000030000032000033000033000032000035000037000037\
00003800003700003700003800003600003500003400003300003300003200002C
00002A00002B00002A00002B00002D00002E00002C00002E00002F000033000038000041000047\
00004900004C00004D00004E00005100005300005900005100004E00004F00004B
00004500003D00003700003500003500003500003800003400003B000050000036000032000033\
00003000003A00004000003C00004600004800004900004B00004A000047000048
00003A00002E00002B00002C00002B00002900002C00003000003300003A00003C000036000086\
0000A500009700007D00006100003500002B00002A00002B00002A00002D00002F
00002F00003700004500003400002E00002D00002F00002E
00009400009600009500009700009800009800009900009A00009C00009D00009E00009F00009E\
00009E00009B00009700008F00007900005900004200003D00003B000033000030
00003000002F00003000002F00002F00003400003500003500003200003000003B000038000038\
00003800003700003900003400003800003400003400003300003200003100002F
00002C00002A00002900002B00002C00002E00003000003000003200003700003700003F000044\
00004B00004F00004F00005400005700005C00005D00005800005000005300005B
00004D000040000038000036000036000035000035000034000035000036000035000033000032\
00003400003400003800003A00003E00004600004900004900004800004700003E
00002E00002E00002C00002B00002B00002C00002A00002E00003300003500003F000038000058\
0000A60000A500009500008B00005600002D00002D00002C00002D00002D00002E
00002E00003300003100003000003000002D00002F00002E
00009400009400009600009700009700009700009900009B00009B00009C00009D00009E00009F\
00009E00009C00009900009200007F00005F00004400003E00003700003100002D
00003100003100003300003500002C00006200005800003600003600002E00004D00004400003A\
00003900003A000038000034000036000035000035000033000033000032000031
00002E00002E00002B00002C00002D00002D00003000003200003600003800003800003D000043\
00004A00004C00004E00005300005B00005E00006000005400006500008500007E
00006300004900003B000037000038000036000036000036000033000037000034000034000036\
00003300003600003800003900003E000043000045000046000044000039000034
00002E00002C00002C00002A00002B00002C00002C00002D00003300003300003C00003E00003F\
0000970000A000009100008800008300004200002F00003000002D00002E00002E
00002E00002F00003000003100002F00002D00002C00002E
00009500009200009700009600009600009800009700009B00009C00009B00009F0000A00000A0\
0000A000009C00009B00009300008700006F00004F00004100003600003000002E
00002F00003100003200003400003100006200004B00003600003500003100004D00004200003D\
00003A000037000036000035000035000034000033000032000032000033000032
00003300003400002F00002F00002D00003400003400003800003600003500003E000043000045\
00004700004900004B00004F00005500005800005C00005300008200009E000094
00008200006200003D000037000035000035000034000035000034000033000033000034000036\
00003400003500003A00003E000045000047000047000047000044000039000033
00002F00002B00002A00002A00002D00002E00002E000031000037000034000034000034000033\
00005E00005F00005300004C00005500005900003F00003200003100002F00002E
00002F00002D00002F00002F00002D00002B00002C00002C
00009600009700009700009800009700009800009900009D00009C00009D00009F00009F00009F\
0000A100009F00009F00009900009100008300006B00005300003A00003000002E
00002F00003000003000003000003200003700003400003500003200003900005100004100003C\
00003A000037000038000038000036000034000035000035000034000034000035
00003500003900003200003200003100003300003500003700003500003C000043000046000049\
00004900004900004C00004D00005200005500005A00005A000058000094000097
00008600006A000041000037000037000033000034000033000033000033000035000033000034\
00003400003700003D00004400004A00004900004B00004A000047000043000034
00003000002F00002D00002D00003100003500003600004900006300003F000032000034000031\
00003A00004100004500004500004200004400004C000046000038000033000030
00002E00002C00002B00002B00002B00002A00002C00002B
00009500009700009600009700009800009700009A00009B00009C00009D00009F00009F0000A1\
0000A00000A00000A10000A000009900009200008400007A000048000031000030
00003100003000003000003000003100003500003500003600003200004500004B00003D00003D\
000038000037000036000037000035000035000037000036000035000034000039
00003700004100003500003100003400003300003700003500003A00004100004700004900004B\
00004B00004A00004F00005000005400005700005800005800004D00006800007D
00006500004B00003D000036000036000036000034000033000033000035000033000035000034\
00003500003C00004400004900004900004A00004D00004C00004800004800003A
00003200003000003000003100003600003A00003D00006300008E00004B000036000035000034\
00003B00004300004600004700004600004800004700004600003A000035000034
00002F00002B00002B00002C00002D00002C00002D00002F
00009400009700009700009600009900009A00009900009900009B00009C00009E00009F00009F\
0000A00000A10000A20000A000009D00009900009200008D00006C000038000031
00002F00003000002F00003000003000003200003300003400003700003C00003C00003900003C\
000038000036000037000035000035000036000034000036000035000034000034
00003300003400003100003200003300003300003300003500003E00004300004800004800004B\
00004D00004F00005400005B00005E00007600006800005200004C00004C00004B
00003F000038000038000033000031000032000031000032000033000032000032000033000033\
00003700003F00004600004900004D00004C00004D00004D00004800004A000043
00003500003200002D00003000003000003400003500004200004F00003B000035000033000036\
00003B00004100004700004A00004B00004C00004C00004C000042000038000031
00002C00002D00002B00002B00002A00002E000030000037
00009400009600009700009600009600009800009900009A00009A00009C00009D00009D0000A0\
00009E0000A00000A000009F00009D00009C00009400008700007200004B000038
00003200003100003000003200003100003300003500003400003B00003B00003900003900003A\
000037000037000036000035000035000034000035000032000035000034000033
00003100003000003200003100003200003400003200003600003E00004300004800004A00004D\
00005100005400005C00008300009400008300005E00004F00004B00004A00003C
00003500003600003300002C00002C00002C00002C00002D00002E00002F00002D000033000031\
00003C00004300004800004B00004E00004F00005000004D00004C000048000047
00003A00003200003000002F00002E00002F000033000033000034000035000032000036000039\
00003E00004500004C00004F00004E00004F00004D00004E00004600003700002F
00002D00002C00002C00002D00002C000030000032000034
00009500009600009800009800009800009A00009C00009A00009C00009C00009F0000A000009E\
0000A00000A30000A100009E00009C00009600008B00007600005900004400003C
00003600003600003400003200003300003500003600003800003700003B000037000037000038\
000035000036000036000036000035000034000036000034000035000034000035
00003200003200003100003100003200003200003400003800004000004400004600004A00004C\
00005300005200006200009700009600006700005000004D00004A000046000036
00003400003100002D00002800002A00002900002900002A00002A00002D00002C00002F000034\
00003F00004500004A00004B00004E00005B00005800004F00004E00004C000049
00004100003700003100002F00002F00002F000031000031000031000032000032000034000038\
00004300004A00004D00004E00005000005400004F00004D00004A000035000030
00002E00002D00002D00002E00002E000031000036000033
00009400009700009800009600009A00009A00009B00009C00009C00009C00009F0000A10000A0\
0000A20000A20000A200009E00009A00008F00007B00006200004800004100003E
00003D00003900003900003600003700003700003A000038000038000039000038000036000038\
000035000036000034000037000035000035000035000033000037000036000037
00003700004100003400003400003800003100003E00004E000042000043000047000047000049\
00004D00004E00005400006C00006000005100004C00004B00004800003F00002F
00002B00002C00002900002900002800002800002900002A00002A00002C00002B00002C000036\
00004300004800004C00004F00005000007200006500005200004E00004B00004A
00004500003900003400003200003100002E00003100002F00003100003300003600003600003E\
00004600004C00005300005000005500007800005B000051000049000036000031
00002E00002F00003000003300002F00004C000067000039
00009400009600009600009800009900009A00009B00009C00009E00009D0000A10000A10000A2\
0000A40000A10000A100009F00009400008700006D00004F00004300003F00003D
00003D00003A00003800003800003700003700003A00003B00003800003B00003A000037000037\
00003600003300003400003400003300003200003400003700003700003E000036
00005100007800004100003600003D00002C00005C00007F000048000042000045000044000047\
00004800004B00004F00005000004E00004F00004900004800004500003300002D
00002A00002900002900002900002A00002800002A00002B00002D00002C00002C00002A000036\
00004200004700004E00004C00005100006800005E00005000004E00004B00004B
00004400003A000038000037000034000032000032000032000032000035000036000038000042\
00004900004F00005600005000007000009E00006500004E00004A000034000031
00002F00002F00003300003700003000006200008300003B
00009600009700009800009900009700009A00009C00009C00009E00009F0000A10000A20000A3\
0000A40000A200009F00009C00009300008300006500004A00004000004000003F
00003A00003A00003700003600003700003600003700003F00003D00003E000038000037000035\
000035000035000034000034000035000035000034000034000035000037000035
00003A00004700003A00003A00003D00003000007300008C000068000044000042000044000047\
00004700004900004D00004D00004B00004B00004600004500003900002E00002C
00002A00002800002900002800002A00002800002A00002B00002E00002A00002B00002A000033\
00004100004600004900004900004F00005200005500005000004E00004C00004B
00004200004000004500004300004000003A00003B00003800003A00003E00003D00003D000044\
00004A00004F00005300005000006800007800005500004E00004600003600002D
00002E00002F00002E00003200002F00004000004D000036
00009400009600009700009800009800009A00009A00009D0000A000009F00009F0000A20000A2\
0000A10000A10000A000009900009200008100006200004800004400004300003D
00003B00003800003600003500003600003600003700003C000037000038000039000038000036\
000035000036000035000033000036000035000034000036000033000036000033
00003500003800003700003A00003900003900007800006E00005500004000003E000042000046\
00004700004900004C00004B00004A00004700004700003A00002E00002B00002B
00002700002900002800002A00002B00002C00003F00003C00002D00002900002B000029000032\
00003D00004500004700004800004C00004E00005100004E00004800004B000047
00004300004400004B000048000048000047000049000048000045000047000045000043000044\
00004A00004D00004F00005100005400005500004E00004B00004200003300002F
00002D00002C00002D00002C00002F000031000033000031
00009500009600009800009900009B00009B00009B00009C00009E00009F0000A00000A10000A2\
0000A10000A30000A000009B00009300008300006600004C00004300004200003C
00003900003600003700003600003600003600003900003900003C00003900005500005500003C\
000037000036000037000034000036000037000035000036000035000035000037
00003500003600003700003800003300005500006000004A00003E00003A00003900003A00003E\
00004300004500004800004800004600004500003700003200002D00002A000029
00002A00002A00002E00003400002C00004B00007F00005000002E00002800002A00002A000033\
00003900004400004500004A00004900004B00004C00004C000049000047000045
00004600004500004A00004A00004900004900004A00004A00004A00004800004B000043000044\
00004A00004C00004E00004F00005000004E00004C00004700003800003600002F
00002D00002D00002C00002D00002D00002E00003200002F
00009500009500009700009900009B00009B00009B00009B00009E00009F00009E0000A10000A4\
0000A20000A10000A000009E00009700008A00007300005900004600004200003A
00003800003600003500003400003500003800003800003C00003D00004200007000006200003B\
00003600003800003900003600003A000037000037000036000037000036000037
00003600003500003900003700004400005300004300003C00003900003D00003F00003900003F\
00004200004400004600004800004600004300003B00003000002C00002800002A
00002900002900002B00002E00002D00004200005400003200002A00002C00002C00002F000035\
00003400003F00004500004600004700004A00004A00004C00004700003F000043
00004800004600004800004900004900004A00004A00004900004B00004A000049000049000046\
00004900004B00004C00004C00004C00004C00004600003F000038000033000030
00002D00002C00002C00002D00002C000030000031000030
00009500009800009800009900009A00009B00009C00009E00009E0000A10000A00000A20000A2\
0000A30000A40000A40000A300009B00009300008400006D00005800004500003B
00003A00003700003700003800003500003700003700003700003A00003800003F00003A000038\
00003800003600003700003800003B00003900003E00004000004000003F00003E
00003F00004000004300004700004800004100003B00003A00003C00003F00003800003D000044\
00004600004700004800004800004800004500004100003100002C000029000028
00002800002700002A00002C00002E00002E00002D00002D00002C00002B00002B000035000032\
00003400003B00004200004500004700004700004700004A00003E00003A000041
00004500004600004900004800004900004C00004C00004B00004B00004B00004A000048000049\
000043000042000045000046000049000046000043000042000041000039000033
00002D00002C00002C00002D00002E00002F000030000030
00009700009600009700009800009800009A00009B00009D00009D0000A10000A10000A10000A2\
0000A50000A40000A60000A400009F00009D00009300008600007000004F00003C
000039000037000037000038000036000036000036000036000036000035000037000036000036\
00003600003700003400003800003900003B00004200004600004900004B00004B
00004C00004D00004E00004A00004A00004100003900003700003F00003800003C000041000044\
00004700004800004A00004A00004700004500004500003500002D00002B00002A
00002700002900002A00002D00002E00002D00002C000040000039000030000031000031000032\
000039000040000044000047000048000048000046000047000041000039000041
00004400004700004900004B00004900005000005400005000004C00004900004A00004900004A\
00004400003B00003D00004100004300004800004500004500004500004400003C
00003200002F00002D00002D00002E00002F00002F00002E
00009600009600009600009900009B00009900009C00009B00009D0000A10000A10000A00000A1\
0000A30000A50000A30000A30000A000009C00009300008400006600004C00003E
00003A000038000036000037000036000039000035000034000035000036000037000035000036\
00003400003500003700003900003800003B00004300004800004900004B00004E
00004F00004E00004F00004B00004C000043000036000039000036000038000040000044000044\
00004900004B00004C00004B00004800004700004700003C00003200002F000028
00002700002B00002900002B00002D00002900003000003A000030000030000034000031000034\
00003E00004300004700004700004700004800004700004700004700003C000041
00004500004900004B00004E00005000004E00006E00006A00005200004D00004900004900004B\
00004600003D000040000044000045000048000049000047000048000047000045
00003C00003300003000002E00002E000030000030000030
00009600009800009800009B00009A00009A00009C00009D00009F0000A10000A30000A10000A5\
0000A40000A50000A20000A000009C00009300008100006300004A00003E00003F
00003B000038000039000038000035000036000036000036000036000035000034000034000036\
00003300003200003400003500003500003A00004200004900004900004D00004F
00004F00006600005100004B00004A00004200003800003600003500003D000042000045000046\
00004900004C00004C00004C00004A00004900004700004500003700002D00002A
00002900002A00002800002C00002900002B00003900003100002F00003100003300002F000037\
00003F000044000047000047000048000049000048000048000048000045000041
00004400004900004E00005300005800004A00006B00008100005500004D00004A000049000049\
00004900004100004200004400004600004900004900004900004B00004B00004A
00004700003F000036000031000031000031000033000036
00009500009700009700009A00009900009A00009C00009E00009E0000A20000A30000A40000A5\
0000A30000A200009E00009C00009200007F00005F00004700004000003D000039
000036000037000038000036000035000037000036000035000036000035000032000035000033\
00002E00002E00002F00003300003400003800004300004900004A000051000051
00005400008800005900004D00004C00004100003800003500003B000041000044000046000048\
00004C00004C00004F00004F00004C00004A00004900004700004100003700002E
00002B00002C00002B00002C00002C00002A00002E00002D00002F00003000002F00002F000039\
000040000044000045000047000049000048000047000047000046000048000043
00004300004500004D00005000005600004C00004F00005500005000004B00004B00004C00004C\
00004500004200004400004600004700004900004A00004900004F00004D00004D
00004B00004700004400003B00003600003700003600003A
00009600009700009600009900009900009C00009D00009D00009F0000A20000A20000A30000A4\
0000A30000A100009D00009600008800006900004A00004000003C00003B000033
00003300003000003200003300003400003500003400003400003400003200003000002E00002C\
00002A00002B00002D00002F00003300003800004300004700004B00004E000052
00005300006400005300004C00004D00003C00003900003900003D00004300004600004900004C\
00004E00004F00005C00006000005100004E00004D000048000048000044000037
00003400002F00002E00002E00002D00002E00002F00003000003000003100002D00002F00003A\
00004200004400004500004800004A000048000049000048000047000048000045
00004000004300004C00004C00005200004B00004A00004C00004B00004900004900004A00004A\
00004300004200004400004700004900004B00004B00005000005900005300004F
00004C00004D00004A00004400003F00003D00003F000044
00009600009500009800009900009900009B00009C00009A0000A00000A10000A10000A30000A1\
00009F00009C00009700008F00007700005600004200003C00003A000033000031
00002E00002D00002D00002E00002C00002F00002E00002E00003200002D00002D00002B00002B\
00002A00002E00002D00002E00003000003800004100004500004C00004C00004F
00005100005000005100004C00004C00003C00003900003C00004000004500004900004E000050\
00005000005F00008800006900005200004F00004D00004D00004A00004100003D
00003A00003400003200003100003100003100003000003000002F00003000002F00002E000039\
00004000004500004700004800004800004B00004B00004A000049000049000045
00003800003D00004400004600004800004A00004A00004A00004900004B00004A000047000048\
00003F00003F00004600004900004B00005200004D00005D000090000068000051
00004E00004B00004D00004600004200004200004600004B
00009500009700009700009A00009C00009A00009D00009D0000A00000A10000A10000A40000A0\
00009E00009F00009300008700006D00004C00004000003D000038000032000031
00002E00002D00002E00002E00002F00002E00002C00002F00003000002C00002C00002B00002A\
00002C00002D00002D00002F00002F00003100003D00004500004900004D00004D
00004E00004D00004D00004C00004B00003A00003B00003D00004100004800004B00004E000050\
00005500007000006C00005400005000004F00004E00004B00004800003C00003B
00003A00003300003500003100003000003100002E00003000002F00003200003100002D000038\
00004000004500004800004B00004800005600005D00004B000047000046000045
00003500002E00003D00004400004400004800004A00004900004900004B00004800004D000056\
00004200003D00004200004800004A00004F00004E000054000088000073000053
00004F00004C00004E00004900004300004200004800004E
00009400009600009800009900009900009C00009F00009E00009D0000A00000A10000A30000A1\
00009E00009A00009000008500006400004800003E00003F00003600003100002E
00003000002E00002F00003000002F00002D00002E00002C00003000002C00002A00002B00002C\
00002E00002F00003200002F00003000002F00003800004300004900004D00004D
00004E00004E00004C00004C00004900004000003B00003E00004300004800004C00004D000050\
00005300005500005400005200004F00005000004E00004A00003F00003A000039
00003600003400003400003200003000003000003200003000003000002F00003000002D000034\
00004100004500004900004C00004900005800007000004C000045000044000041
00002E00002D00002C00003800003F00004600004800004B00004B00004B000056000062000051\
00003B00003700004000004400004800004C00004A00004F000059000057000051
00005100004D00004D00004A00004300004500004A00004C
00009300009600009700009800009A00009E00009D00009C00009C0000A10000A10000A20000A2\
0000A000009B00009100008100006000004600003E00003D00003300003000002D
00002F00002E00002E00003700003100003000002E00002A00003700002D00002C00002D000031\
00002F00003300006000003C00003000002D00003000003D00004600004A00004C
00004D00004C00004D00004B00004600004C00003E00004100004400004800004B00004D00004F\
00005100004F00005100005000004E00004D00004B00004800004500003C000038
00003500003400003300003300003200003200003200003300003000003000003100002E000030\
00003C00004300004800004800004900004C00005000004B00004700004700003A
00002C00002D00002900002D00003100003300003E00003700004B00006F00005A000041000038\
00003500003200003A00004400004700004B00004800004F000051000051000050
00004E00004C00004D00004600003F00004200004A00004D
00009500009600009600009800009A00009C00009D00009D00009D0000A00000A10000A200009F\
00009E00009A00009100008400006400004500004100003C00003300002F000030
00003000003000003200004D00003A00003000003100002C00004100003900002D000030000031\
00003200002A00006800004F00003000002F00002E00004200003F000046000049
00004C00004800004800004700003800003800003800003F00004500004900004C00004E00004D\
00004E00004F00004F00004F00004D00004C000047000047000047000043000037
00003500003700003400003500003800003000003C00005B000036000030000032000030000030\
00003500004100004600004700004A00004A00004A000049000049000046000030
00002D00002E00002E00002D00003000003000003100003000002F00004700003A000036000037\
00003300003200003300003F00004600004700004800004E00005000004E00004F
00004C00004D00004C00004500003F00004200004900004D
00009700009600009600009700009800009B00009C00009D00009D00009F0000A10000A000009F\
00009F00009C00009400008700006F00004E00004300003D000033000032000030
00003100003200002E00005D00003D00003100003200002C00003600003A00002D00002B00002B\
00002C00002C00003000003000002E00002E00002B00004100003A00003D00003E
00003F00003F00003C00003000002F00002F00003100003C00004200004600004900004D00004E\
00004D00004D00004E00004E00004C00004A00004A00004900004800004800003B
000034000034000036000034000038000033000039000062000039000031000030000031000034\
00003300003C00004400004600004900004A00004900004900004900003800002C
00002E00003000002E00002D00003100003000003100002F00002E000034000035000036000032\
00003000003200002E00003500004000004500004900004B00005000004E000052
00004B00004B00004B00004600004800004800004800004B
00009500009600009600009700009B00009C00009C00009D00009F00009F0000A10000A00000A1\
0000A000009E00009800008F00007F00005E00004C000041000033000031000031
00003000003000003200003A00003300003300003300003000003300003800003600003000002C\
00002D00002D00002D00002E00002F00002D00003400003E00003800003700002F
00002E00002B00002C00002D00002D00002E00002F00003300003E00004600004900004B00004D\
00004C00004B00004C00004C00004D00004D00004D00004D00004B00004B000044
00003A000037000034000033000033000032000033000035000034000031000030000032000034\
00003800003C00004500004600004900004900004800004900003C00002F00002E
00002F00002F00002F00003000003400003100003200002E00002D000031000034000031000032\
00003000003100003200002F00003E00004700004600004E00004C00005000004F
00004B00004B00004900004A00004A00004D00004C000048
00009600009500009700009700009900009B00009B00009B00009D00009F00009F0000A10000A1\
00009F00009F00009E00009700008E000078000060000047000035000031000030
00003100003000003000003300003200003100003600003200003800003A00003900003D000036\
00003000002F00003000003200002E00003C00004400003900003600003200002C
00002B00002B00002B00002C00002E00002C00002E000030000032000038000041000044000046\
00004600004500004800004B00004C00004E00004E00004D00004B00004A00004B
00003C00003A000033000032000032000032000033000033000033000031000031000034000037\
00003D000042000047000048000049000047000049000041000034000032000030
00002E00003200003200003200005A00003C00003400003000002E000030000032000032000031\
00003300003300003C00004500003F00003B00004A000049000048000048000049
00004800004800004B00004C00004D00004B00004D000049
00009300009600009700009800009800009900009A00009B00009C00009C00009F0000A10000A2\
0000A10000A30000A000009D00009900008C00008300005D000039000033000030
00003100002F00003100003200003100003200003500003600003C00003F000043000044000046\
00004500003E00003F00004000003D00005100004700003900003600002E00002C
00002B00002C00002D00002C00002E00002F00002F00002E00002D00003300003400003900003F\
00004300004600004900004B00004C00004E00004F00004F00004E00004A00004B
00004300003A00003400003300003200003100003400003000003200003000003500003400003B\
00004100004600004800004A00004C000048000049000046000034000035000032
000031000039000034000039000083000049000033000033000031000031000035000035000033\
00003900004A00004000003300003100002F00003000003000003B00003D00003D
00004300004900004B00004C00004D00004D00004C00004B
00009600009600009800009700009700009900009B00009C00009C00009F00009F0000A30000A1\
0000A20000A30000A10000A10000A000009500009000008900004B000036000032
00003100003000003300003300003400003400003500003A00004100004600004800004B00004B\
00004D00004B00004900004B00004600004700004600003900003400002E00002B
00002C00002D00002E00003000003100003400003000002E00002E000031000032000039000041\
00004400004600004B00004D00004D00004D00005800005800005100004900004C
00004400003500003500003300003200003100003200003000003200003300003500003700003F\
00004600004A00004C00004C00004D00004C00004C00004B000036000035000033
00002F00003400003300003700005400003A000034000033000031000032000034000036000032\
000045000032000033000033000032000031000032000030000032000034000038
00004400004800004C00004E00005300005200004D00004D
00009500009600009700009700009700009A00009B00009C00009D00009E0000A00000A10000A3\
0000A20000A30000A40000A30000A200009F00009900009800008600004D000037
00003400003400003500003500003400003600003B00003E00004300004800004B00004C00004B\
00004E00004E00004C00004B00004A00004700004900003B00003500002C00002D
00002D00003000003300003500003A00003B00003200003100002F00003000003400003E000043\
00004500004A00004D00005000005300005400007800007200005200004C00004B
00004000003400003200003400003400003100003200003300003300003500003300003A000045\
00004800004B00004D00004E00004F00004E00004A00004C00003D000038000033
00003000003200003300003500003700003300003200003200003200003700003400003800004D\
00003B000033000036000035000035000030000030000030000030000034000039
00004500004C00005000004D00005900007B00005500004B
00009400009300009500009700009500009800009A00009B00009A00009C00009F00009D0000A0\
0000A00000A20000A20000A30000A30000A100009F00009C00009700008F00006B
00004400003900003A00003600003C00004500004400004000004700004B00004A00004D00004D\
00005000005E00005000005100004B00004700005300004000003600002F000030
00003000003600003200004000007200006700003600003100002E00002F000037000041000045\
00004300004800004D00005100005100005600006800005C00004F00004C00004C
00003900003300003200003200003200003200003100003300003400003100003200003D000046\
00004A00004D00004C00005E00006100005100004D00004E00004500003B000033
00003200003100003300003200003200003200003500003000003900003A00003800004D000038\
00003500003400003600004500003B00003400002F000031000030000033000037
00004500004900004E00004D00005000008000005B00004B
00009500009700009600009600009700009900009A00009A00009900009C00009C00009D00009F\
00009F00009E00009F00009F0000A20000A30000A10000A20000A100009D00009E
00009400007A00007000007900007900006700004D00004300004700004D00004F00005200004C\
00005A00007D00005100005300004B00004B00006700004A00003B000030000031
00003200003A00003500004B00009600008400003500003100002E00002D00003A000043000046\
00004600004800004D00004F00004F00004F00005100004F00004D00004C000044
00003300003400003300003100003300002F00003000002F000032000030000032000040000046\
00004B00004F00004800006C00007400005100005000004E00004A000052000039
00003200003100002F00003200003300003300003500003300004100003A000040000039000036\
00003700003B00002E00006E000066000035000031000033000031000035000036
00004000004700004800004B00004C00005200005000004B
00009400009400009600009800009800009800009900009B00009A00009C00009D00009D0000A0\
00009E00009F0000A00000A00000A20000A20000A10000A40000A60000A50000A5
0000A200009A00009400008A00007900006300004B00004400004800004B00004D00004D000056\
00005D00005900005300005400004800006C00007900005C00004300002F00002C
00002F00003100003000003500005600004100003100003100003100003000003C000045000048\
00004900004A00005000004F00004E00005100005000004B00004E00004A000035
00003300003200003200003300003100003200003000003100003300003000003200003F000046\
00004900004D00004C00005500006000005600005700005200004B000094000058
00003800003300003200003300003400003800003700004100004000003E000049000037000037\
000036000038000030000047000058000036000031000031000032000035000037
00003F00004700004900004A00004D00004D00004D000049
00009600009400009700009800009600009800009900009C00009A00009E00009E00009F0000A1\
0000A100009F0000A30000A10000A30000A30000A40000A60000A50000A300009F
00009900008900007400005C00004900003F00003D00003D00004600004C00004C000050000055\
00005D00005200005400004F00005300007C00007300005D00004400003200002D
00002B00002D00002F00003000003200003500003E00003000003100003100003B000046000046\
00004900004A00004E00004F00004F00004E00004F00004D00004C000037000034
00003500003400003400003100003400003500003200003200003200002F00003300003F000045\
00004800004A00005100005E00006400006100005C0000560000630000A200009E
00005F00003C00003900003700003900003B00003E00003C00004000004C000039000038000035\
000035000035000034000034000037000035000030000032000032000033000034
00003D00004500004800004B00004A00004A00004B000049
00009400009600009500009800009700009900009900009B00009B00009E00009F00009E0000A0\
00009F0000A20000A20000A20000A30000A40000A40000A30000A300009E000096
00008500006700004E00004100003D00003F00003E00003B00003C00004700004A00004D000052\
00005300005000004C00004A00005A00005600004900003C00003500003200002E
00002D00003000002C00003500004100003E00003F000032000033000033000038000044000047\
00004800004B00004D00004E00004F00004C00004D00004700003C000036000034
00003500003500003900003000005E00005700003800003300003200003000003400003E000043\
00004800004A00004B00005400005900005E00005D0000520000890000A700009F
00008A00005900004300003E00003D00004300004300003E00004300003A000037000038000035\
00003500003400003300003300003300003300003000003200003100003800003A
00003D00004500004800004C00004B00004B000049000049
00009500009500009600009900009900009700009B00009900009A00009C00009F00009E0000A1\
0000A10000A30000A30000A40000A50000A40000A30000A100009E000097000086
00006300004D00004500004100004100003B00003800003900003900003900003E000046000049\
00004B00004700004800004A00004300003D00003800003500003200003200002F
00002C00002E00002D00003000003D00003F00003C00003300003300003500003D000043000044\
00004600004B00004C00004E00004B00004A00004B00004400003A000036000034
00003400003300003700002E00005200004E00003600003500003400002900006100004A000043\
00004700004A00004E00005100005800006000005800006300009F0000A2000090
00006800004C00004500003F00004300004000003F00004200004400004400003F000039000036\
000035000033000033000032000032000032000033000031000033000041000045
00004500004600004A00004B00004B00004C000049000049
00009400009600009400009900009700009900009A00009A00009B00009D00009F00009E0000A2\
0000A10000A40000A40000A40000A50000A40000A30000A000009B000092000072
00005200004600004500004400003E00003B00003900003900003900003900003700003600003A\
00003A00003D00003E00003C00003900003A00003700003700003200002F00002D
00002B00002C00002F00002E00003800003B00003600003200003200003D000044000045000045\
00004800004A00004C00004E00004D00004B00004A000049000043000038000036
00003300003300003200003000003500003800003400003700003400003500007300005600003C\
00004500004800004A00004E00005100005600005500005D00007A00008D000076
00005000004400004000004700004000004100004500004800004900004A00004900004400003C\
00003500003400003200003300003100003300003300003100003E000047000048
00004A00004C00004B00004900004B000049000048000047
00009300009600009600009800009900009800009B00009D00009B00009C00009F00009D0000A1\
0000A10000A30000A20000A50000A50000A20000A300009F000099000089000063
00004A00004800004500003F00003D00003C00003900003800003C00003A000037000038000039\
00003800003600003800003600003700003600003600003200002D00002C00002C
00002A00002B00002D00002C00002F000031000030000032000038000040000047000046000047\
00004900004B00004E00005000004E00004D00004D00004D00004B000040000038
00003600003400003400003100003500003400003400003600003600005200005D000041000037\
00003A00004500004A00004C00004D00004E00004E00004F00005500005C000055
00004400004100004300004300004100004400004900004B00004C00004C00004B00004B000047\
00003E00003500003400003500003400003700003300003900004600004C00004E
00005300004E00004D00004C00004200004000003E000037
00009300009500009600009500009900009900009A00009B00009D00009D0000A000009F0000A0\
0000A10000A50000A60000A40000A60000A50000A30000A0000099000086000062
00004C00004900004200003E00003C00003B00003A00003F00003E00003F000038000038000038\
00003600003600003500003400003700003300002F00002E00002C00002B00002C
00002B00002B00002B00002B00002D00002D00003100003000003A000042000046000047000046\
00004B00004A00004D00004F00004F00004E00004F00004D00004C00004900003C
00003800003400003500003300003300003200003400003200003900004400003F000036000036\
00003700003900004100004700004A00004C00004C00004A00004A00004B000046
00003F00003D00004000003E00004200004500004900004C00004B00004D00004C00004B00004A\
00004700004700003C00003600003A00003900003B00004600004E00004A000058
00007000005000004C00004D00003F000037000032000032
00009300009400009800009700009800009900009B00009900009D00009B00009B00009D00009F\
00009F0000A40000A40000A30000A60000A30000A20000A000009800008B00006B
00004F00004A00004000003D00003C00003900003C00003C00003D00003C00003B000038000037\
00003600003400003600003400003400003000002D00002C00002B00002B00002D
00002D00002F00002C00002A00002C00002F00002F00003000003B000042000047000047000048\
00004900004D00004F00005100005300005400005100004F00004E00004C000047
00003B000038000036000035000036000034000033000032000033000036000033000034000036\
00003600003B00004300004A00004B00004C00004B00004B00004A000048000049
00004200003C00003F00004100004300004800004900004C00004D00004E00005000004E00004B\
00004A00004A00004700003C00003C00004100004100004800004F00004D00005A
00007000005000004E00004F00003F000037000035000033
00009500009600009600009500009A00009900009A00009A00009A00009B00009E00009E00009F\
0000A10000A40000A40000A40000A70000A50000A50000A100009C00009200007B
00005C00004F00003F00003C00003C00003800003800003800003A00003800003800003B000037\
00003800003500003500003300003100002C00002D00002D00002E00002C000038
00003D00003300002F00002C00002E00002F00002D00003000003C00004200004600004700004C\
00004E00005000005500005300006B00008600006000005100004F00004D00004D
00003D00003700003500003500003200003200003200003200002F000031000031000031000032\
00003600004100004600004800004B00004B00004C00004B00004B00004A00004C
00004700003D00004200004100004600004900004F00004C00005800007100005A00004F00004B\
00004B00004C00003F00003E00004300003F00004600004A00004E000050000054
00005800005100005100005100003B000039000038000035
00009500009600009400009600009A00009800009800009A00009B00009A00009E00009F0000A0\
0000A20000A10000A30000A30000A60000A50000A50000A30000A0000098000089
00007200005C00004300003C00003B00003900003900003800003900003900003900003B00004E\
00003B00003700003300003200003000002D00002E00002F00003300002E00003D
00006900003C00003100002E00002D00002F00002F00002F00003900004200004600004600004A\
00004C00004F00005500005200005800008400006C00005200004F00004D00004E
00003B000036000035000033000031000031000031000031000031000030000030000030000030\
00003900004200004900004B00004D00005200004F00004E00004D00004B00004C
00004B00003F00004200004600004800004D00005000004F00005A00007C00006600004F00004C\
00004C00004D00004000004200004200004300004A00004D000050000053000053
00005400005300005100004F00003900003A00003A000037
00009500009400009700009600009900009900009B00009B00009C00009C0000A000009D00009F\
0000A10000A10000A20000A20000A40000A50000A50000A70000A300009D000096
00008A00007800004E00003B00003B00003700003900003900003700003B00003C00003600006D\
00005100003900003400003400003100002D00002D00002C00002D00002D000030
00003900003500003000002E00002E00002E00003000002C00003500004000004400004500004A\
00004B00004D00004E00004F00005200005600005600004F00004B00004B00004B
00003700003500003300003300003200003200003400003200003300003100003000003100002F\
00003900004500004A00004E00005000005500006700006100004F00004D000049
00004D00004200004300004500004700004900004C00004D00005000005600005300004E00004D\
00004C00004C00004300004200004500004A00004E00004E000054000065000063
00005200005100005100004A00003A00003B00003900003A
00009400009500009600009600009800009800009900009C00009900009B00009D00009D00009E\
00009F0000A20000A00000A20000A40000A60000A60000A70000A80000A500009E
00009600009000007400004200003B000039000038000038000037000036000038000038000038\
00003900003700003400003100003A00003300002C00002C00002C00002E00002F
00002E00003100002D00002C00002F00002E00002F00002D00003300003D00004300004C00004B\
00004B00004B00004D00004D00005100005100004F00004F00004D00004D000043
00003400003600003500003400003300003200003200003D00003800003300003100003100002F\
00003C00004600004B00004D00005300005300005D00008300005800004D00004B
00004E00004600004300004400004700004800004C00004D00004F00004F00004E00004D00004D\
00004A00004C00004400004700004A00004D00004F00005100005B000061000067
00005200005000005100004600003B00003D00003900003A
00009300009300009500009500009800009600009900009A00009900009C00009C00009C00009C\
00009E00009F0000A10000A20000A30000A50000A30000A80000A90000A60000A3
00009E00009400008700005800003F000039000039000039000036000036000036000038000038\
00003800003600003400003200004200003500002E00002C00002C00002F00002E
00002D00002F00002E00002D00002C00002D00002F00003000003500003400004000004A000050\
00005200004B00004C00004D00004E00004D00004D00004B00004A000049000035
00003300003400003600003400003700003700003600007400005800003600003300003100002E\
00003900004300004800004900004C00004E00004F00005A00005100004D00004A
00004B00004900004300004400004600004800004B00004B00004D00004C00004D00004B00004C\
00004D00004900004600004B00004C00004E00004F00004F00006300006400005A
00005300005000005000004C00003D00003C000037000037
00009300009200009500009600009600009500009700009900009A00009C00009B00009C00009C\
00009E00009E0000A10000A30000A30000A40000A60000A60000A60000A30000A2
00009900008E00007000005000004600003E00003B000039000038000038000038000036000037\
00003700003600003300003800003700003400003100002F00002E00002D000031
00002F00002E00002E00002F00002F00002E00002E00003100003200003300003200003F00004C\
00005000004A00004B00004D00004D00004D00004C00004C00004A00003F000034
000035000033000034000033000033000034000036000047000038000032000031000030000032\
00003500004000004600004700004A00004C00004C00004C00004D00004D00004D
00004D00004800006600004600004500004600004900004C00004C00004C00004B00004B00004B\
00004C00004600004500004900004B00004E00004D00004F00005300005B000058
00005500004F00006000006F000044000039000038000036
00009500009500009600009700009800009900009800009B00009C00009D00009D00009E00009D\
00009F0000A00000A10000A30000A30000A70000A50000A50000A40000A100009E
00009600007900005700004700004500004100003C00003B000038000038000038000037000037\
00003800003500003600003600003500003500002F00002F00002F00002F000031
00003200003100003000003200003100002F00003100003000003100003300003300003300003D\
00004200004900004C00004C00004E00004C00004C00004800003F00003A000035
00003300003500003500003500003000003300003300003300003100003000003000002F000032\
00003000003B00004300004600004900004A00004900004D00004D00004F000053
00005000004C00009400007000004400004700004800004B00004B00004B00004C00004B00004C\
00004B00003900004200004700004B00004A00004D000051000053000056000059
00005A00005200008200009500006E00003A000038000038
00009500009600009700009700009800009800009A00009A00009A00009A00009D00009C00009F\
00009E0000A00000A00000A20000A50000A30000A50000A40000A40000A100009A
00008D00006B00004C00004900004200003F00003B00003A00003900003800003900003900003A\
00003700003400003200003600003400003000002D00002C00002D000030000032
000031000034000033000037000039000036000038000035000034000034000035000033000036\
00003600003800004000003F00004700006B00005700004000003A000038000036
000036000035000034000035000034000034000031000031000030000031000030000031000030\
00002F00003300004100004400004700004900004900004A00004E000050000056
00005000006400009400009900005E00004700004800004A00004B00004B00004B00004800004B\
00003D00002E00003B00004600004A00004E00004D00004E000051000055000057
00005900005300006A00008E0000A000005600003A000039
00009500009500009700009600009600009800009900009900009800009B00009D00009C00009C\
00009E0000A10000A00000A20000A40000A60000A70000A50000A30000A200009A
00008D00006D00004F00004B00004200003B00003B00003A000039000038000039000039000038\
00003600003400003300003400003000002D00002D00002C00002E00002F000030
00003400003500003200003800003F00003F000039000036000036000037000038000036000037\
00003B00003800003A00003A00003600005100004500003E000039000037000035
000038000035000037000034000033000035000032000032000032000032000030000031000031\
00003000003000003500004300004600004A00005000004F00005600004E000050
00004F00004C00006300007F000063000042000044000047000048000046000045000044000037\
00003000003000003100004400004900004B00004C00004C00004D00004D000053
00004800003E00003F00004F00008B00009D000053000038
00009400009500009500009600009500009800009800009800009900009900009C00009E00009F\
00009E00009F0000A00000A20000A40000A30000A70000A60000A30000A100009B
00009000007800005A00004D00004000003E00003C00004200003C00003700003900003D00003A\
00003700003600003300003200003000002E00002C00002D00002F00003000002F
00003200003200003300003200003D00003F00003800003700003700003800003A00003800003E\
00003F00003900003A00003A00003700003B00003E00003C00003A000036000037
000037000037000037000037000035000034000035000034000035000034000031000033000032\
00003200003400003100003600003E00004900005200005300005100004900004A
00004900004A00004900004D00004700003C00003900003700003300003100002F00002D00002F\
00002F00003000002E00003800004600004A00004B00004B00004C000046000039
00003400003500003900003900003D00007C00006F000043
00009400009400009500009400009700009800009800009800009900009A00009A00009C00009E\
00009F00009E0000A30000A00000A10000A20000A40000A40000A30000A200009F
00009700008900007200005700003C00004100004400004800004200003A00003A00007800004F\
00003800003500003400003300002E00002D00002D00002D00002F00002E000032
00003100003100003300003200003600004100003800003900003900003B00003E000036000056\
00006400003F00003B00003900003800003900003E000039000035000037000036
00003900003800003A00003800003800003A000039000036000034000036000033000035000035\
00003700003900003900003300005A00005800005100003C00003F00004600004D
00005000004F00004D00004A00004200003B00003700003400002D00002B00002C00003000002D\
00002E00003000003000002F00003300003F00004200003E000038000031000030
00003100003400003300003600003500003E000048000040
00009400009300009400009600009600009700009800009800009800009A00009C00009B00009B\
00009E00009F0000A00000A00000A00000A30000A20000A40000A50000A40000A3
0000A000009500008B00007B00004400004300004600004600004200003C000038000051000041\
00003800003400003300003300002E00002D00002D00002F000033000034000033
00003100003100003100003300003100004400003800003900003C00003B00003E00003900004A\
00006D00004500003C00003B00003B00003900003B000037000037000038000038
00003900003900003800003900003900003700003C000039000036000036000035000035000034\
00003600003700003600003500003600003500003C00003B00004200004A00004E
00005200005100005000004E00004800003E00003400002D00002D00002E00002E00002F000031\
00003200003100003100003000002D00003400002E00002D00002F000030000031
00003300003300003300003700003600003400003900003E
00009200009200009600009700009700009700009900009700009800009900009C00009C00009D\
00009E00009E0000A00000A10000A10000A40000A30000A40000A50000A70000A6
0000A40000A000009700009800006D00004300004500004700003F00003800003A00003900003A\
00003800003400003A00003500002F00002F00003300003200003600006C00004D
00003400003300003300003500002F00004900004200003700003900003900003900003900003B\
00004100003F00003B00003C00003900003900003700003A000038000037000038
00003900003900003900003900003700003600003A000034000034000035000034000037000036\
00003500004600004000003700003800003500003A00003D00004700004C000050
00005100005600005300004F00004D00003E00003400002E00002E00002E00003000003100003A\
00004400003400003300003000002F00003000002C00002E00002E000030000031
00003200003300003800003900003700003400003300003E
00009500009500009700009500009700009700009700009900009A00009B00009C00009A00009D\
00009E00009F00009E00009F0000A10000A10000A20000A40000A40000A60000A8
0000A70000A40000A000009900009800006400004000003C00003A00003A00003900003C00003B\
00003700004B00005400004200003100002F00003100003300003200005D000055
00003700003100003600003800002D00005200006200003900003B00003800003800003A00003A\
00003900003A00003A00003900003B000039000037000038000038000039000038
00003900004D00003C000039000037000034000039000033000035000037000035000039000039\
00003200007100005400003600003700003800003600004100004900004F000053
00004F00007100006A00005000004F00004000003200003100002F00003200003800002E000067\
00006E00003500003100003000003100002C00002D00002E000030000031000035
00003500003500004F00004900003800003500003300003A
00009200009300009500009200009700009800009800009700009700009A00009900009900009C\
00009D00009D00009E00009F0000A00000A00000A10000A30000A30000A20000A6
0000A60000A30000A40000A000009900009700007C00005100004300004000004400004300004B\
00006F00007F00006F00005700003300002F00002E00002E00002E000034000035
00003500003400003700003C00003000005D00008900005900003C00003B00003C000039000039\
00003A00003800003800003900003800003C00003800003A00003900003E00003C
00003600007F00006A00003F00003900003800003B000035000036000036000035000036000037\
00003400004700003C00003600003800003600003A00004100004700004F000051
00005000005F00006700005100005100004500003700003200002E000032000033000033000045\
00004200003300003000003100003100003000002E00002F000031000034000038
00003700003D00006F00005700003C000035000033000037
00009200009200009100009400009600009600009500009800009500009700009900009900009B\
00009B00009A00009D00009C00009E00009E00009F0000A10000A10000A10000A2
0000A30000A30000A30000A10000A300009F00009E00009C00008F00008400008300008B000097\
00009900009300008600007800004700003000002F00002D00002D000030000031
00003300003600003A00003F00003800007000009900009000005400003C00003900003800003A\
00003900003800003C00003B00003D00005100003D00003B00003B00003B00003C
00003800005600005600004100003C00003400003F00003E000037000035000034000036000036\
00003600003800003700003800003700003800004800004100004900004A00004E
00005000005200005600005100004D000050000046000031000030000031000031000032000037\
00003400003100003400003400003400004100003300002E00002E000031000033
000035000038000041000045000038000036000033000035
000091000093000092000093000093000093000095000097000097000097000099000098000099\
00009900009C00009A00009D00009E00009D00009F0000A00000A10000A20000A1
0000A10000A20000A30000A20000A20000A20000A40000A20000A20000A40000A40000A30000A3\
0000A200009B00009300008D00007500003800003000002E00002C00002C000030
00003300003600003C00004100004000008A0000A200009E00009500005400003C00003A00003B\
00003D00003E00004100004400006700007500005500003D00003A000038000036
00003700004900003C00003C00003F00003500005B00006100003A000037000037000034000033\
00003700003600003800003C00003700004900007600004C00004900004B00004E
00005000005300005500005800004D000062000085000042000032000031000031000033000036\
00003600003700003B00004800006200005F00003A00002F000030000032000032
00003300003500003700003C000036000034000035000034
00009000009000009000009200009400009300009600009400009800009600009700009900009A\
00009900009B00009B00009B00009E00009F00009D00009F0000A00000A00000A1
0000A30000A10000A30000A30000A20000A40000A40000A40000A50000A60000A70000A60000A8\
0000A60000A300009E00009400009500006A00003700002F00002C00002D00002E
00003300003700003E00004000005C0000A10000A70000A50000A100009700006F00004C00004B\
000050000053000060000085000095000093000081000041000039000038000037
00003700003B00003C00004500004400004500008500009100005300003A000037000033000032\
00003800003A00004000004000004500008600009C00007800004C00004B00004C
00005100005500005800005B0000560000860000A200007F00004200003700003300003600003E\
000042000046000059000083000092000089000052000033000030000030000033
00003400003400003600003900003900003500004F00003F
00009200008F000091000092000094000095000096000096000096000095000097000099000098\
00009A00009A00009C00009C00009D00009E00009D00009F00009F0000A00000A1
0000A10000A00000A20000A30000A40000A40000A40000A50000A60000A50000A40000A60000A8\
0000A70000A60000A300009F00009800009500007000003D00003000002F000031
00003500003B0000450000530000930000A80000AA0000AA0000A90000A80000A800009E000096\
00009700009E0000A50000AA0000A600009C00009E00006D00003C000037000036
00003700003900003E00004800004600007000009C00009E00008F00004A000038000035000038\
00003A00003F0000440000490000870000A50000A20000A100007800004F000050
00005000005500005F00005C0000810000A80000A70000A200008800005800004100004500004A\
0000540000720000990000AB0000A300009F000089000042000034000031000031
00003300003800003800003E00003C00004A000087000061
00008E00009100009000009200009300009300009500009600009500009600009600009A00009A\
00009800009B00009A00009E00009D00009F00009F00009F00009F0000A00000A0
0000A10000A00000A30000A30000A20000A40000A30000A40000A30000A60000A50000A60000A7\
0000A70000A60000A60000A30000A100009D000097000089000063000044000041
00004500004D00006C0000970000A80000AB0000AB0000AC0000AD0000AE0000AC0000AC0000AD\
0000AC0000AD0000AE0000AD0000AB0000A700009E00009E00006700003A00003B
00003D00003E00004700004C00006C0000A10000A70000A00000A000008A00004D00003D00003E\
00004400004700005A0000930000AA0000AA0000AB00009F00009600008A000064
00005E0000610000700000920000AC0000B20000B20000AF0000AD0000A800009300008700008C\
00009B0000AE0000B30000B20000AE0000A40000A500007F000043000037000036
00003900003D00004300004700005600008B0000A0000092
00009000009100009200009200009400009500009600009400009600009900009600009900009A\
00009A00009A00009C00009B00009C00009D0000A000009E00009E0000A00000A0
0000A20000A00000A10000A30000A10000A10000A20000A10000A30000A40000A50000A30000A6\
0000A60000A50000A50000A50000A40000A50000A30000A10000A000009700008E
00008F0000970000A10000A70000A90000AA0000AA0000AB0000AB0000AC0000AB0000AC0000AC\
0000AC0000AA0000AC0000AC0000AD0000A90000A60000A100009E000082000061
00005500005B00006C0000890000A60000AD0000AC0000A90000A70000A700009E000085000072\
0000700000830000A20000AD0000AE0000AF0000B00000AF0000AE0000AE0000AA
0000A20000A30000AB0000B00000B10000B20000B30000B40000B30000B40000B20000B30000B3\
0000B30000B40000B60000B50000B30000AE0000A80000A600008E00006200004B
00004A00005200005B00007C0000A20000AC0000A50000A8
000090000091000091000093000094000094000094000094000095000096000097000099000099\
00009700009B00009C00009C00009C00009C00009D00009F00009E00009E0000A1
0000A20000A00000A10000A20000A10000A30000A30000A10000A40000A60000A50000A60000A5\
0000A70000A50000A40000A50000A50000A40000A50000A60000A30000A40000A5
0000A60000A50000A50000A90000A90000AA0000AA0000AA0000AB0000AB0000AC0000AC0000AB\
0000AB0000AC0000AB0000AD0000AC0000AB0000AC0000AD0000AB0000AA0000A7
0000A30000A50000A90000AB0000AD0000AD0000AD0000AD0000AE0000AF0000AC0000AC0000AB\
0000AA0000AC0000AD0000AF0000B00000B00000B00000B00000B20000B00000B0
0000B00000AF0000B10000B20000B30000B20000B20000B40000AF0000B10000B40000B30000B5\
0000B40000B40000B50000B60000B60000B40000B30000B10000AF0000AB0000A1
00009A00009C0000A80000B10000B30000B20000AC0000A7
00009100008F000093000093000094000094000093000095000096000097000098000098000096\
00009A00009B00009A00009D00009D00009C00009C00009E00009F00009F00009F
0000A10000A10000A10000A20000A00000A20000A20000A20000A40000A40000A50000A50000A5\
0000A50000A50000A50000A60000A60000A70000A60000A60000A70000A70000A8
0000A80000A70000A90000A90000AA0000A80000AB0000AB0000AB0000AB0000AC0000AC0000AC\
0000AC0000AC0000AC0000AD0000AC0000AC0000AC0000AD0000AC0000AD0000AC
0000AC0000AC0000AC0000AD0000AD0000AE0000AD0000AF0000AF0000AE0000AE0000B00000AF\
0000AD0000AE0000AE0000AF0000AF0000B00000B00000B00000B10000B00000B0
0000B10000B10000B10000B20000B30000B20000B30000B20000B30000B20000B30000B40000B5\
0000B50000B40000B50000B50000B40000B50000B60000B30000B20000B20000B2
0000B20000B10000B20000B20000B50000B30000B10000B0
000091000092000093000090000094000094000092000095000095000097000097000096000099\
00009900009A00009B00009B00009C00009A00009D00009E00009D00009F00009C
00009F0000A00000A20000A10000A20000A20000A10000A20000A30000A30000A50000A40000A3\
0000A50000A50000A50000A50000A40000A60000A50000A50000A50000A70000A6
0000A70000A80000A80000A90000A80000AA0000AB0000AC0000A90000AA0000AA0000AB0000AC\
0000AC0000AA0000AD0000AC0000AE0000AC0000AA0000AD0000AD0000AD0000AD
0000AD0000AC0000AD0000AD0000AE0000AE0000B00000AD0000AF0000B00000AF0000AF0000B1\
0000AE0000B00000B00000B00000B00000B00000B00000B00000B10000AF0000B0
0000B00000B10000B20000B00000B10000B20000B20000B30000B30000B30000B40000B40000B4\
0000B50000B40000B40000B50000B40000B40000B50000B40000B40000B20000B3
0000B30000B20000B30000B30000B40000B40000B30000B3
000091000094000092000092000092000095000095000095000096000097000097000099000097\
00009800009A00009B00009A00009D00009B00009A00009D00009C00009D00009D
00009E0000A00000A10000A10000A100009F0000A00000A30000A20000A20000A40000A50000A4\
0000A50000A30000A50000A40000A50000A70000A50000A60000A60000A60000A8
0000A80000A90000A80000A70000A80000A80000AB0000AD0000AA0000AA0000AA0000AC0000AC\
0000AC0000AD0000AD0000AD0000AD0000AA0000AC0000AE0000AC0000AE0000AD
0000AC0000AE0000AD0000AE0000AF0000AD0000AE0000B00000AF0000AF0000AF0000B00000B1\
0000B00000B00000B00000B00000B20000B10000B10000B10000B00000B00000B1
0000B10000B20000B10000B10000B20000B30000B40000B30000B30000B30000B30000B40000B3\
0000B40000B50000B30000B50000B40000B40000B50000B40000B40000B30000B3
0000B40000B40000B30000B50000B40000B40000B40000B3
000091000093000091000093000095000096000095000096000096000096000096000096000096\
00009700009900009A00009800009C00009C00009B00009C00009E00009C00009B
00009E0000A00000A000009F0000A00000A00000A00000A30000A20000A30000A30000A40000A3\
0000A40000A40000A50000A60000A50000A60000A40000A50000A60000A50000A7
0000A40000A80000A70000A60000A70000A80000AA0000AB0000AB0000AA0000AA0000AB0000AC\
0000AA0000AC0000AB0000AC0000AC0000AB0000AC0000AD0000AC0000AC0000AD
0000AD0000AD0000AE0000AE0000AF0000AD0000AF0000AF0000AE0000AE0000AF0000B00000AF\
0000B00000B00000B00000B00000B10000B00000B10000B00000B10000B00000B0
0000B00000B00000B10000B20000B30000B20000B40000B40000B30000B30000B30000B30000B2\
0000B30000B40000B40000B30000B40000B30000B40000B40000B40000B40000B3
0000B40000B40000B30000B30000B40000B30000B30000B3
000092000092000093000094000094000093000094000096000094000096000096000097000095\
00009800009800009800009900009A00009A00009C00009B00009B00009B00009D
00009D00009E00009F00009F00009F00009F0000A10000A20000A10000A30000A20000A20000A3\
0000A40000A30000A40000A30000A30000A40000A30000A30000A50000A50000A5
0000A50000A70000A70000A80000A80000A90000A90000A90000A90000A90000AA0000AA0000AB\
0000AB0000AA0000AB0000AC0000AC0000AD0000AC0000AC0000AD0000AC0000AE
0000AC0000AC0000AE0000AD0000AD0000AE0000AD0000AE0000AE0000AE0000B00000AE0000B0\
0000B10000B00000B00000B00000B10000AF0000AE0000B00000B10000B00000AF
0000B10000B00000B10000B20000B10000B40000B40000B40000B40000B40000B30000B40000B4\
0000B40000B30000B40000B40000B40000B30000B50000B40000B50000B50000B4
0000B50000B40000B30000B30000B30000B30000B50000B5
000091000092000091000094000094000096000094000095000095000095000098000097000098\
00009800009800009A00009900009C00009C00009B00009C00009C00009D00009E
00009D00009E00009E0000A00000A000009F0000A20000A20000A10000A20000A20000A30000A3\
0000A40000A40000A60000A40000A40000A50000A40000A40000A70000A40000A5
0000A60000A80000A60000A90000A90000A90000A80000A90000A90000A90000AA0000AA0000AC\
0000AB0000AB0000AB0000AC0000AC0000AD0000AD0000AB0000AD0000AD0000AD
0000AD0000AC0000AC0000AE0000AE0000AE0000AE0000AE0000AF0000AF0000B00000AF0000B1\
0000B10000B00000B10000B00000B00000B10000AF0000B00000B00000B00000AF
0000B10000B10000B10000B20000B20000B30000B30000B30000B40000B20000B30000B30000B3\
0000B30000B40000B30000B30000B40000B40000B40000B40000B40000B40000B5
0000B50000B50000B30000B30000B40000B30000B50000B4
000090000090000091000093000093000093000094000095000094000095000098000097000097\
00009600009800009800009900009A00009B00009B00009C00009B00009E00009D
00009D00009C00009F00009F0000A000009F0000A10000A10000A00000A20000A10000A30000A3\
0000A30000A40000A40000A40000A30000A30000A50000A50000A50000A50000A6
0000A60000A70000A50000A70000A70000A90000AA0000A90000A90000A90000AB0000AB0000AB\
0000AC0000AC0000AD0000AD0000AD0000AD0000AD0000AD0000AE0000AE0000AE
0000AE0000AE0000AD0000AD0000AF0000AF0000AE0000AF0000B00000AE0000B10000B10000B0\
0000B10000B10000B00000B20000B10000AF0000B00000B10000B10000B10000B0
0000B20000B20000B20000B20000B20000B20000B30000B30000B30000B30000B30000B30000B3\
0000B30000B40000B40000B30000B40000B40000B30000B50000B40000B50000B5
0000B50000B40000B30000B40000B60000B40000B40000B5
00008F00008F000091000092000096000093000093000094000096000096000098000097000098\
00009700009900009A00009800009A00009B00009C00009B00009C00009E00009E
00009E00009E00009E00009F00009F0000A00000A10000A10000A10000A20000A20000A10000A3\
0000A30000A30000A30000A40000A30000A30000A30000A30000A50000A60000A6
0000A70000A80000A90000A90000A60000A80000AB0000A80000A90000A70000AA0000A90000AB\
0000AB0000AC0000AC0000AD0000AC0000AD0000AD0000AC0000AC0000AD0000AE
0000AD0000AD0000AD0000AE0000AF0000B00000AE0000AE0000B00000B00000B00000B00000B0\
0000B10000B10000B10000B10000B10000B00000B10000B10000B00000B00000B0
0000B30000B20000B00000B10000B20000B20000B30000B20000B30000B40000B30000B30000B3\
0000B30000B30000B40000B50000B40000B40000B30000B50000B40000B50000B6
0000B50000B40000B40000B40000B40000B50000B30000B4
000090000091000091000091000093000095000092000095000096000095000098000095000098\
00009600009800009A00009A00009B00009C00009C00009C00009D00009E00009E
00009E0000A00000A10000A00000A10000A00000A30000A20000A30000A30000A30000A30000A3\
0000A30000A30000A40000A40000A50000A50000A40000A40000A50000A60000A6
0000A80000A80000AA0000A90000A80000A80000AA0000AA0000AA0000A70000A90000AA0000AB\
0000AB0000AA0000AD0000AE0000AD0000AE0000AC0000AD0000AD0000AE0000AE
0000AD0000AD0000AF0000AD0000AF0000B00000B00000AE0000AF0000AF0000B00000B10000AF\
0000B00000B00000B00000B10000B20000AF0000B10000B00000B00000B10000B0
0000B10000B20000B10000B10000B30000B20000B20000B10000B20000B40000B30000B30000B3\
0000B40000B40000B30000B40000B50000B50000B40000B50000B40000B40000B4
0000B50000B30000B50000B40000B50000B40000B50000B4
000090000091000091000091000092000094000093000094000095000095000095000098000096\
00009800009900009900009A00009A00009B00009C00009E00009D00009F00009E
00009F00009E0000A10000A00000A100009F0000A30000A00000A10000A20000A20000A30000A3\
0000A40000A20000A40000A40000A30000A50000A40000A30000A70000A60000A6
0000A70000A70000A90000A80000A80000A90000AA0000AA0000A90000A90000AA0000A90000AB\
0000AB0000AC0000AC0000AD0000AC0000AD0000AC0000AC0000AE0000AD0000AC
0000AD0000AC0000AD0000AD0000AE0000B00000B00000B00000AF0000B00000B00000B00000B0\
0000B00000B00000B10000B00000B10000B20000B10000B20000B10000B10000B1
0000B20000B20000B20000B20000B10000B20000B10000B20000B40000B30000B20000B40000B3\
0000B40000B40000B40000B40000B50000B50000B40000B50000B40000B40000B5
0000B40000B40000B40000B50000B40000B40000B40000B3
00008F000090000091000092000093000097000093000094000095000094000096000097000095\
00009600009700009A00009A00009900009C00009D00009C00009E00009E00009E
00009F00009E00009E00009F0000A10000A10000A20000A30000A20000A30000A20000A20000A3\
0000A30000A40000A20000A20000A20000A40000A50000A50000A50000A70000A3
0000A70000A70000A70000A80000A80000A80000AA0000AB0000A80000A90000AB0000AA0000AC\
0000AC0000AC0000AC0000AD0000AE0000AC0000AC0000AC0000AD0000AD0000AE
0000AD0000AD0000AD0000AE0000AE0000AF0000AE0000AE0000AF0000B00000AF0000B00000B0\
0000B00000B10000B10000B00000B20000B10000B10000B20000B20000B10000B1
0000B20000B30000B20000B20000B10000B20000B30000B30000B30000B30000B40000B30000B4\
0000B40000B40000B20000B40000B40000B50000B40000B40000B40000B30000B4
0000B40000B40000B40000B30000B40000B40000B40000B4
00008E000091000090000092000093000095000093000093000094000094000096000096000096\
00009700009800009800009800009800009A00009C00009C00009C00009D00009B
00009F00009F00009F0000A00000A10000A10000A00000A20000A30000A10000A30000A30000A2\
0000A30000A30000A30000A30000A40000A50000A30000A60000A40000A50000A4
0000A60000A70000A60000A60000A60000A80000A90000A90000A80000A70000AB0000AB0000A9\
0000AC0000AB0000AB0000AE0000AC0000AB0000AC0000AD0000AC0000AE0000AD
0000AE0000AE0000AC0000AF0000AD0000AF0000AF0000AD0000AF0000AF0000B00000B10000AF\
0000B00000B10000B10000B00000B20000B00000B00000B20000B20000B10000B2
0000B10000B10000B20000B10000B20000B20000B20000B40000B40000B30000B40000B30000B4\
0000B40000B40000B40000B40000B40000B30000B30000B40000B50000B30000B5
0000B40000B40000B30000B50000B40000B40000B40000B4
000090000091000090000091000091000093000094000092000093000096000096000097000095\
00009800009600009800009900009800009900009C00009B00009C00009B00009D
00009E00009D00009F00009F0000A00000A100009F0000A00000A20000A00000A30000A20000A1\
0000A30000A30000A30000A40000A20000A40000A40000A50000A60000A50000A6
0000A60000A60000A70000A60000A60000A80000A80000A80000A90000A70000A90000AB0000A9\
0000AB0000AA0000AC0000AC0000AB0000AA0000AC0000AD0000AE0000AD0000AD
0000AD0000AD0000AD0000AE0000AE0000AF0000AD0000AD0000AF0000B00000AF0000AF0000B0\
0000B00000B10000AF0000B00000B00000B00000B00000B20000B10000B10000B1
0000B30000B20000B20000B10000B20000B30000B20000B40000B30000B30000B40000B30000B3\
0000B40000B40000B40000B30000B30000B40000B40000B40000B40000B40000B4
0000B50000B30000B40000B30000B30000B40000B30000B3
00008F000090000091000092000093000095000092000093000095000095000094000094000095\
00009700009600009800009A00009700009A00009D00009C00009D00009C00009D
00009C00009D00009F00009E0000A00000A10000A000009F0000A10000A10000A20000A40000A3\
0000A20000A20000A40000A40000A30000A40000A50000A50000A30000A40000A6
0000A70000A70000A60000A70000A70000A70000A90000A80000AA0000A80000A90000AA0000AB\
0000AA0000AC0000AC0000AD0000AC0000AC0000AD0000AE0000AE0000AD0000AD
0000AD0000AB0000AD0000AD0000AE0000AE0000AE0000AE0000AE0000AF0000B00000AF0000AF\
0000B00000B00000B10000B00000B10000B00000B00000B20000B10000B10000B0
0000B10000B10000B10000B20000B10000B20000B30000B30000B30000B30000B30000B30000B4\
0000B40000B30000B40000B40000B30000B40000B40000B40000B40000B40000B5
0000B40000B30000B40000B30000B40000B40000B30000B2
000091000091000093000091000091000094000094000096000094000095000096000095000096\
00009500009600009800009900009A00009A00009A00009D00009D00009C00009E
00009C00009E00009D00009F0000A000009F0000A10000A10000A20000A20000A10000A30000A3\
0000A10000A20000A30000A30000A30000A40000A40000A40000A50000A60000A5
0000A70000A60000A70000A60000A50000A70000A80000A70000A70000AA0000AA0000AB0000AB\
0000AC0000AB0000AD0000AD0000AD0000AE0000AE0000AD0000AE0000AE0000AF
0000AC0000AD0000AE0000AE0000AE0000AD0000AF0000AE0000AF0000AF0000AF0000B00000B0\
0000B00000B00000AF0000B00000AF0000B00000B20000B00000B00000B10000B1
0000B10000B20000B10000B30000B40000B30000B40000B20000B40000B40000B20000B40000B3\
0000B30000B30000B40000B30000B40000B50000B40000B40000B40000B40000B5
0000B40000B30000B30000B40000B40000B30000B40000B3
000091000091000090000090000091000092000093000094000093000095000095000097000095\
00009600009600009700009900009A00009B00009900009A00009D00009D00009C
00009E00009E0000A000009F00009F00009E0000A00000A00000A30000A30000A20000A30000A2\
0000A10000A20000A20000A50000A40000A60000A30000A30000A60000A50000A6
0000A60000A60000A50000A70000A60000A70000A80000A80000A90000A90000AA0000AB0000AC\
0000AA0000AB0000AE0000AC0000AD0000AD0000AC0000AE0000AE0000AD0000AD
0000AE0000AC0000AF0000AE0000AE0000AF0000AF0000AE0000AF0000B00000AE0000AE0000B0\
0000B10000B00000AF0000B00000B00000B10000B00000B00000B00000B10000B2
0000B10000B20000B00000B20000B10000B20000B30000B30000B30000B20000B30000B30000B3\
0000B30000B30000B40000B20000B20000B50000B40000B30000B50000B40000B4
0000B40000B40000B50000B30000B30000B40000B30000B3
00008E00008F000090000090000094000092000094000093000094000092000093000094000096\
00009400009500009600009800009900009A00009900009A00009C00009C00009D
00009F00009E00009E00009F00009F00009F0000A00000A00000A20000A000009F0000A20000A2\
0000A30000A60000A30000A30000A40000A40000A40000A40000A40000A40000A5
0000A70000A60000A60000A80000A70000A90000A90000A70000A80000A80000AA0000AA0000AA\
0000AA0000AB0000AC0000AC0000AC0000AC0000AC0000AD0000AC0000AE0000AB
0000AE0000AE0000AB0000AE0000AE0000AE0000AE0000AE0000B00000AF0000AF0000AF0000AE\
0000AF0000B00000B00000B10000AF0000B00000B10000B00000AF0000B10000B1
0000B00000B10000B10000B10000B20000B20000B10000B30000B30000B30000B30000B30000B3\
0000B30000B30000B30000B20000B30000B40000B50000B30000B40000B30000B4
0000B40000B50000B50000B40000B40000B30000B20000B3
00008F00008E00008F000091000092000093000092000094000095000093000095000096000094\
00009400009600009800009700009800009B00009A00009B00009B00009B00009E
00009F00009F00009E00009E00009F0000A00000A000009F0000A10000A30000A20000A10000A2\
0000A10000A30000A40000A30000A40000A50000A40000A50000A50000A40000A3
0000A40000A30000A70000A50000A60000A70000A60000A70000A80000A70000A90000AA0000A8\
0000AA0000AA0000AB0000AC0000AB0000AA0000AC0000AC0000AD0000AD0000AC
0000AD0000AE0000AC0000AD0000AE0000AD0000AE0000AF0000AF0000AE0000AF0000AF0000AE\
0000AF0000AE0000B00000B00000AF0000B00000B00000B00000AF0000B00000B1
0000B10000B00000B10000B20000B10000B20000B20000B10000B20000B20000B30000B30000B3\
0000B30000B40000B30000B30000B40000B30000B50000B20000B50000B40000B3
0000B30000B40000B40000B40000B30000B30000B30000B3
00008C00008E000091000090000092000094000093000094000094000093000092000095000097\
00009400009700009600009800009800009900009A00009C00009C00009C00009E
00009D00009F00009D00009E00009F0000A10000A00000A00000A10000A20000A10000A20000A1\
0000A20000A40000A30000A20000A40000A50000A40000A50000A50000A30000A3
0000A40000A50000A40000A40000A50000A70000A70000A70000A80000A70000AA0000A90000A9\
0000AB0000AA0000AC0000AB0000AD0000AC0000AB0000AB0000AC0000AD0000AC
0000AC0000AD0000AD0000AD0000AD0000AC0000AE0000AE0000AE0000AF0000AD0000AF0000AF\
0000B00000AF0000AF0000B00000B00000AF0000AF0000B00000B10000B00000B1
0000B00000B00000B10000B20000B20000B10000B30000B10000B30000B20000B40000B30000B3\
0000B30000B30000B30000B40000B30000B40000B30000B30000B30000B40000B4
0000B40000B40000B30000B50000B30000B30000B30000B2
000090000090000091000091000094000095000093000093000095000096000094000095000096\
00009500009600009800009900009700009A00009B00009C00009B00009D00009D
00009D00009F00009E00009F0000A10000A00000A10000A30000A30000A10000A10000A20000A3\
0000A20000A30000A50000A30000A30000A40000A30000A50000A60000A50000A5
0000A60000A60000A70000A60000A50000A80000A80000A80000A90000A80000AA0000AA0000AA\
0000AB0000AB0000AA0000AC0000AC0000AC0000AB0000AC0000AD0000AD0000AC
0000AD0000AD0000AD0000AD0000AE0000AE0000AD0000AD0000AE0000AF0000AE0000B00000AF\
0000AF0000B00000B00000B10000B10000B20000B00000B10000B10000B00000B2
0000B20000B00000B10000B00000B10000B20000B20000B10000B20000B30000B20000B30000B2\
0000B10000B20000B30000B30000B20000B30000B30000B30000B30000B30000B3
0000B40000B30000B30000B40000B40000B40000B30000B3
00008F00008F000091000092000090000093000094000093000095000096000093000094000095\
00009400009500009600009800009700009800009A00009A00009B00009C00009C
00009D00009E00009F00009F00009E00009F0000A00000A10000A20000A30000A10000A10000A2\
0000A20000A30000A30000A30000A20000A40000A50000A40000A60000A60000A6
0000A40000A60000A70000A60000A50000A70000A70000A80000A70000A90000A90000AA0000A9\
0000A90000AB0000AA0000AC0000AC0000AC0000AC0000AC0000AC0000AC0000AD
0000AC0000AD0000AC0000AF0000AE0000AE0000AE0000AE0000AE0000AE0000AE0000AF0000AF\
0000B00000AF0000B00000B00000B00000B00000B10000B00000B00000B00000B0
0000B00000AF0000B00000B10000B10000B20000B20000B30000B20000B20000B20000B20000B3\
0000B10000B30000B30000B20000B30000B40000B30000B30000B30000B40000B4
0000B40000B40000B40000B40000B30000B30000B30000B4
00008D00008D000091000091000090000095000094000094000096000096000095000093000094\
00009400009600009700009600009700009700009700009900009B00009B00009A
00009D00009E00009F00009F00009D00009F0000A100009F0000A00000A10000A10000A20000A1\
0000A30000A20000A20000A40000A20000A40000A50000A50000A40000A60000A5
0000A40000A60000A60000A60000A70000A60000A60000A70000A70000A70000A90000A90000AA\
0000AB0000AB0000AC0000AC0000AC0000AC0000AB0000AC0000AC0000AB0000AC
0000AC0000AD0000AD0000AE0000AC0000AE0000AD0000AD0000AE0000AD0000AF0000AF0000AF\
0000AE0000AF0000B00000B00000AF0000AF0000B10000B10000B10000AF0000B0
0000B00000B10000B10000B20000B10000B10000B10000B20000B20000B10000B30000B20000B2\
0000B20000B30000B20000B30000B30000B20000B20000B20000B40000B40000B3
0000B30000B40000B30000B20000B30000B20000B30000B3
00008E00008C00008E000092000093000091000093000093000094000093000094000093000095\
00009300009600009600009800009700009A00009A00009900009A00009B00009C
00009E00009E00009F0000A000009D00009E0000A00000A00000A00000A30000A00000A20000A3\
0000A30000A10000A20000A40000A20000A30000A40000A40000A30000A70000A5
0000A60000A60000A70000A60000A80000A60000A70000A70000A60000A80000A90000A90000AA\
0000AA0000AA0000AA0000AB0000AC0000AB0000AB0000AB0000AD0000AC0000AC
0000AB0000AC0000AD0000AC0000AD0000AE0000AE0000AD0000AE0000AE0000AF0000B00000AF\
0000AF0000AF0000B00000B00000AF0000B00000B10000B10000B00000B00000B1
0000B10000B00000B20000B20000B10000B20000B20000B20000B10000B10000B10000B20000B3\
0000B10000B20000B20000B30000B30000B30000B20000B20000B30000B30000B4
0000B40000B40000B20000B30000B30000B30000B20000B3
00008E00008C00008F00008F000090000092000091000090000093000095000093000095000097\
00009500009700009600009800009900009A00009900009800009B00009A00009B
00009D00009D00009F00009F00009F00009F0000A00000A10000A20000A10000A00000A30000A1\
0000A30000A30000A10000A20000A20000A30000A30000A40000A30000A50000A7
0000A60000A70000A60000A60000A60000A70000A60000A60000A70000A80000A90000A90000AA\
0000AA0000AB0000AB0000AB0000AB0000AB0000AC0000AA0000AC0000AD0000AD
0000AD0000AC0000AD0000AD0000AD0000AE0000AE0000AD0000B00000AF0000AE0000AF0000AF\
0000B00000AD0000B00000B00000AD0000AF0000B00000B00000B00000B00000B1
0000B10000B10000B20000B00000B10000B10000B20000B20000B10000B10000B10000B30000B1\
0000B30000B30000B30000B20000B30000B20000B20000B20000B30000B20000B3
0000B30000B20000B20000B40000B30000B30000B30000B4
00008D00008E00009000009100008F000091000092000093000093000095000093000095000096\
00009500009600009500009B00009800009A00009B00009800009B00009A00009B
00009B00009C00009E00009F00009E0000A10000A000009F0000A100009F00009F0000A30000A1\
0000A30000A30000A20000A10000A30000A30000A40000A40000A30000A50000A5
0000A60000A60000A50000A60000A50000A50000A50000A70000A60000A50000A90000A90000A9\
0000AA0000AA0000AC0000AB0000AC0000AA0000AC0000AB0000AC0000AC0000AC
0000AD0000AD0000AD0000AE0000AD0000AF0000AD0000AC0000AF0000B00000AD0000AF0000AF\
0000AF0000AF0000AF0000AF0000AF0000AF0000B00000AF0000B00000B00000B0
0000AF0000B20000B10000B00000B10000B00000B20000B20000B20000B10000B10000B30000B2\
0000B20000B20000B30000B30000B20000B20000B30000B30000B20000B20000B3
0000B30000B10000B20000B20000B40000B30000B30000B3
00008E00008E00008E00008E000090000091000090000094000093000095000093000095000096\
00009400009600009600009800009800009800009A00009800009900009B00009A
00009D00009C00009F00009F00009E00009F0000A10000A10000A20000A00000A00000A20000A0\
0000A10000A20000A200009F0000A20000A30000A30000A20000A30000A20000A5
0000A40000A30000A40000A40000A70000A60000A50000A50000A80000A60000A80000A70000A5\
0000A60000AB0000AB0000AB0000AB0000AA0000AA0000AB0000AC0000AB0000AB
0000AC0000AC0000AC0000AD0000AD0000AE0000AC0000AD0000AE0000AD0000AC0000AE0000AE\
0000AF0000AF0000B00000AF0000B00000AF0000AF0000AF0000AF0000B00000B0
0000B10000B10000B20000B00000B10000B20000B10000B20000B20000B10000B10000B20000B2\
0000B30000B30000B30000B20000B30000B30000B20000B20000B30000B30000B2
0000B30000B20000B20000B20000B30000B10000B20000B2
00008E00008F00008E00008F000091000090000092000092000094000094000095000095000096\
00009500009400009600009700009600009700009800009B000098000099000098
00009C00009A00009D00009D00009E00009D00009F0000A000009F0000A00000A10000A20000A0\
0000A10000A10000A10000A10000A10000A30000A30000A10000A20000A30000A4
0000A30000A40000A40000A50000A70000A60000A50000A60000A70000A70000A80000A60000A5\
0000A50000A80000A80000AB0000AB0000AA0000AC0000AA0000AC0000AB0000AC
0000AB0000AC0000AC0000AC0000AD0000AC0000AC0000AD0000AE0000AD0000AE0000AE0000AE\
0000AF0000AE0000AE0000AF0000AE0000AE0000AF0000AF0000AF0000AF0000AF
0000B00000B10000B10000B00000B00000B00000B10000B10000B20000B10000B00000B10000B1\
0000B20000B10000B10000B20000B30000B10000B20000B10000B30000B20000B3
0000B20000B20000B10000B20000B20000B20000B20000B3
00008B00008E00008F00008D000091000093000090000090000092000093000094000092000095\
00009300009500009600009600009700009800009800009A00009A00009B00009A
00009A00009B00009D00009C00009C00009E00009F00009E0000A00000A000009E0000A00000A0\
0000A10000A200009F0000A00000A10000A10000A10000A20000A20000A20000A4
0000A50000A50000A40000A40000A60000A50000A40000A60000A50000A60000A80000A20000A3\
0000A60000A60000A70000A90000AA0000AB0000AB0000AA0000AB0000AD0000AC
0000AC0000AB0000AB0000AD0000AC0000AC0000AD0000AB0000AC0000AD0000AF0000AE0000AD\
0000AE0000AE0000AD0000AE0000AD0000AD0000AE0000AD0000AE0000AE0000AE
0000B00000B00000B00000B00000B00000AF0000AF0000B00000B00000B00000B10000B20000B1\
0000B20000B20000B20000B20000B30000B30000B20000B20000B20000B10000B2
0000B20000B20000B10000B20000B10000B10000B20000B2
00008C00008E00008F00008F000091000090000090000092000090000091000092000092000094\
00009400009400009600009500009600009600009800009900009900009900009A
00009A00009C00009D00009D00009D00009F00009F00009E0000A000009F00009E0000A00000A1\
0000A00000A100009F0000A00000A20000A10000A00000A20000A20000A20000A3
0000A30000A40000A40000A30000A50000A40000A30000A60000A60000A30000A30000A40000A5\
0000A70000A70000A90000A90000A90000AA0000AB0000AA0000AB0000AC0000AC
0000AB0000AB0000AC0000AD0000AB0000AC0000AC0000AC0000AC0000AC0000AE0000AC0000AD\
0000AC0000AE0000AD0000AD0000AE0000AF0000AD0000AD0000AF0000AE0000AF
0000AF0000AF0000AF0000AF0000B00000B00000B00000B00000AF0000B00000B10000B00000B1\
0000B10000B10000B10000B20000B10000B10000B30000B10000B20000B20000B0
0000B00000B10000B20000B30000B10000B20000B10000B2
00008D00008E00008F00008E000090000090000091000092000092000092000092000091000094\
00009500009500009600009600009800009900009800009800009900009800009A
00009D00009B00009E00009E00009F00009E00009F00009F00009F00009F0000A000009F00009F\
0000A00000A00000A100009F00009F00009E0000A10000A20000A00000A30000A3
0000A30000A40000A40000A30000A20000A50000A40000A40000A20000A20000A00000A70000A5\
0000A70000A80000A70000A90000AA0000A90000AA0000AA0000AB0000AB0000AC
0000AC0000AB0000AD0000AC0000AC0000AC0000AC0000AC0000AC0000AC0000AE0000AC0000AD\
0000AE0000AD0000AE0000AD0000AE0000AE0000AF0000AF0000AE0000AE0000AE
0000AF0000AF0000AF0000B00000B00000B00000B10000B10000AF0000B00000B00000B00000B1\
0000B20000B10000B10000B10000B20000B30000B20000B20000B30000B10000B1
0000B00000B10000B20000B20000B00000B10000B10000B3
00008C00008D00008E00008E000090000090000093000092000091000093000090000092000094\
000094000094000096000096000095000096000097000098000097000096000098
00009B00009A00009A00009D00009C00009D00009C00009F00009E00009E00009F00009E00009C\
00009D0000A000009E00009E00009C00009F00009E00009F0000A00000A20000A3
0000A30000A50000A40000A40000A30000A40000A40000A40000A40000A30000A50000A60000A6\
0000A70000A80000A70000A80000A90000AA0000AA0000A90000AB0000AB0000AB
0000AA0000AB0000AC0000AB0000AC0000AB0000AD0000AC0000AE0000AD0000AD0000AC0000AC\
0000AC0000AD0000AD0000AE0000AE0000AD0000AE0000AD0000AE0000AD0000AD
0000AE0000AE0000AF0000B00000B00000AF0000B00000B00000B00000B00000AF0000B00000B1\
0000B00000B00000B00000AF0000B00000B20000B20000B10000B10000B10000B1
0000B00000B10000B00000B10000B10000B10000B20000B2
00008D00008E00008D00008F00008F00009000008E000091000090000093000092000092000092\
000093000094000093000095000095000096000096000097000096000096000098
00009A00009900009B00009B00009D00009D00009D00009E00009F00009D00009D00009F00009D\
00009E00009E00009C00009F00009C00009F00009E00009E00009F0000A10000A2
0000A20000A20000A40000A50000A30000A50000A60000A60000A50000A60000A60000A70000A7\
0000A60000A80000A80000A80000A90000A90000A90000A90000AB0000AC0000AA
0000AB0000AC0000AB0000AA0000AC0000AB0000AC0000AD0000AD0000AE0000AD0000AC0000AC\
0000AC0000AE0000AC0000AC0000AD0000AE0000AC0000AE0000AF0000AE0000AD
0000AE0000AE0000AF0000AE0000AE0000AE0000AF0000AF0000AE0000B00000AF0000AF0000B0\
0000B00000AF0000AF0000AF0000B10000B10000B20000B00000B10000B10000B1
0000B00000B00000B00000B00000B10000B00000B10000B2
00008C00008D00008F00008D00008F00008F00008F000090000090000091000090000093000094\
000093000094000093000096000096000097000095000096000098000097000098
00009800009A00009B00009A00009B00009D00009D00009E00009D00009D00009E00009E00009F\
00009F00009C00009E00009F00009E0000A000009C00009D0000A000009F0000A1
0000A10000A20000A20000A40000A40000A60000A60000A50000A40000A70000A50000A50000A6\
0000A60000A70000A80000A70000A80000A90000A90000A80000A90000A90000A9
0000A90000AB0000A90000AC0000AC0000AB0000AA0000AC0000AB0000AE0000AD0000AB0000AC\
0000AC0000AC0000AC0000AC0000AD0000AC0000AC0000AD0000AF0000AE0000AD
0000AD0000AF0000AE0000AD0000AF0000AD0000AF0000AF0000AF0000AF0000AE0000B00000B0\
0000B00000B00000B00000B00000B00000B00000B10000B10000B10000B20000B1
0000B10000B10000B10000B10000B10000B10000B10000B2
00008C00008E00008F00008D00008E00009100008F00008E00009000008F000091000091000093\
000092000095000094000096000095000095000096000096000098000098000098
00009900009900009900009B00009D00009C00009B00009D00009C00009C00009E00009C00009F\
00009F00009E00009D00009F00009F0000A000009F00009F00009F0000A00000A2
0000A10000A30000A20000A50000A40000A40000A50000A40000A50000A60000A60000A50000A5\
0000A50000A60000A70000A80000A80000A90000A80000A90000A90000AA0000A9
0000AA0000A90000AB0000AA0000AB0000AB0000AC0000AB0000AC0000AC0000AB0000AC0000AC\
0000AC0000AD0000AC0000AD0000AD0000AD0000AE0000AD0000AE0000AE0000AC
0000AD0000AF0000AE0000AE0000AE0000AE0000AE0000AF0000AF0000AE0000AE0000B00000AF\
0000B00000B00000B00000B10000AF0000B00000B10000B00000AF0000B00000B0
0000B00000B00000B00000B00000AF0000B10000B10000B1
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[33]:=",
  ImageSize->{408, 127.5},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006H0000Oa000`40O003h00OogooVGoo003oOonI
Ool00?mooiUoo`00ogooVGoo003oOonIOol00?mooiUoo`00ogooVGoo000=Ool2G0000f00G01L0004
H0000e`0H01P000<H0000e`0H01P0004H0000d00C00d00029002:0000b@0:00X0002;002<0001S@0
:00T0200000L00@P0006900X0300@01@05`04F000U`000IH05@0D01<0400E002F002G00;H003G00;
H00BOol:0`020b000`<00b03800>0b001@=00b0300;00P000P6000<1`0800V000P:00`:P00L2P000
0H01P0700N0280020T0010800X02X0:P0P;000<300<P0b004@<P00<300;P0^000`;000<200<00b00
6P<P4Woo1`0B2`0C00D0500C01<0500@00D04`0501@04`0C0100300600P200T300X200T300L200P0
0`0900P02@0200T0100:00P0300?0P0E0P0F00<05@0F01H00`0F0P0E100F0P0E00`0500C0140400?
00h03`0@01404`0D01DI01H?Ool000eoo`05G01P0600G010000AH0000d00F01H0004E0001EP0G01H
04P0;0000b@00b000R@00bP00R@000@P01`0600L008P008T008X0004800h04@0F00:H002G004H000
3U`0F01@04P0?00d0300=01004@0C01D05P0G007H002G002F0001500F01L05`02F004Woo2P<030<P
0`<00`;P00/300<P0b0300:00L01P06P0L0200900082H00:0X02X0:P0X0000500F01X07P0R020V00
10:00Z02X0:P0P;000<2h0<P0b0030<P0P=000H380<00^02P08P0N020L020P000`:00/0300050b00
0`<00b0380020b040`0:0b000`=0Oomoo`0@Ool50180100C01804`0B200C00<0500C01<00P0C00<0
4P0A01000`0?00D0400A0180000:00@020H02@0300X02@0800<01`8020D02@802P80300301<05@0E
00<05P0301@05@0E00D05@0;01H05@0D0180400>00/02@0800L00`0200X0100<00l04`0E1`0F00<0
5@0D01<00P0B00<0500E01H02@0F3goo000=Ool01E`0H01P0600@0004F0000AD04`0@00h008d0009
>01004`0D01002P0800T0200008L008P00@T00<P008H0004700P02@09002:0001B`0:00d0400E000
1f0000eL05P0E01@05@0F01L0600G01D04P0?00/0002:0002B`0<00h03`0@01404`0E01L0005H000
15`0F01@04P00T0000=<05@0F0000U`01f004Woo1`<03P<P00@300;P0Z02H0828082000;0/02h0;P
0T01X05P0H01X00P0T02H0030X0020:P0X0000500F01P07P0R020V000`:00Z02X0020Z0010;00^03
00<P0`=010<P00@300;P0^0300@3800=0P02806P0D0180500F01P0700N0280:00^000`<P00<3@0<0
0b000P<P00L2h0:P0X02H0:00^0300090b0BOol6018;01<201@201<0100A0000300:100900H02P0<
00`02@0800L200P500T01@0:00T02@0900P00P0700<0000800T010090P0:0P0;00<0400E01H00`0F
00h05@0D01<04P0@00l0400A01@0400B00l02`081@0700L02P0900T02P0<0100500401H01@0E01@0
4P0?00`00P0:00@03@0?01805@P05Pmoo`003Goo00EL0600H01P040000mP0003@01D0000008P00<X
008P0004:00P02001003600370002200900T0200900P01`00002600031`0800T02P0800`0000800`
03P0A01L00AP0008@01800@0000X0300=00000=00004000P02008002:003900022P0800T03002010
0500@002H0003UP0B00002P0;00`0200<00400`0A01@05P0@005H00BOol70`090b020`020b001P80
0T00@05P0B01P08000060P02H09P0P01X04P0P4000@1X0000T02H082P082X0080X0000500@01X07P
0R02H082P0H2`0030^0300=000<3@0050`0200800001P00200030P000`90000180030@002`0P0000
0000040100500400`0800b000P=000`300800P0000700202@0800X02X0800R070b0BOol6018501<3
010301@01@0@01<04P0@00001@0810090P080P0700<0000800P00`0900<02P0800P00P0900<02007
00L00P080P0900<0200:00X00P0:00D02`0800`0500F00<05080000300P00P0100@0200400002008
000400L500H03@0000P0200:00@0500E01@04@0000P00@000080200600X020090000100B1P0F3goo
000=Ool01E`0H01P0600@000360000IT0600H01L0500:0039003800290001B00700H01P050000QP0
00<L020090000T0000</02@090000b0000TH01`0800T02P0<014050000000S0000<h05@0H0000f00
00=803@0:0000b`00RP000</0300<0000b@00RP000<T020080000R000R@000TX0300>0100500H01L
0500>0000RP000//02P0900T02P0<00h0400C01H05`000AP019oo`D300/38083@08380090P01h060
0F01X07P0P0280900082H00<0T02005P0@01@06P0202@0:00Z02`0;P0P:P00L2006P0H01`07P0T02
H0020X0010;P0`0300;P0`;000T300=00d03@0<P0Z01h05P0D000P4P00X100500F01P05P0B01004P
0>00`0D0X00:0<01004P0F01`0:P0b0300;P0R020J001@800R02@0900X000P:P00<2`0;P0b001@<P
4Woo1@0B1`0C00<0500@01@00P0D0P0C00<04@0?00/010081P090P080P0700P0200900T02@0:00`0
2`0:0`090`080P090`0:00L0300@00T02`0<00/04P0201D0100D01<00@081`0700<0000700L01@07
1P0600T01`0800T02@0401@04P0>00T010080P090P0:00@02`0<00h04`D05Pmoo`003Goo00=L0600
H0003F000V@00V0000EH04P0800T020000<L00@P0003700H01P0008H008L0006900P04`0D00h02P0
0R@000/X0300000L0200900X0300@01@00P000<`0003A01@05P0009L0003400X02P0008X0004900P
02009002:002800390001200700L01`00b0000TT02`0<00h0400G01H04P0<0000bP00b0000PT02P0
<00d0400C01H06000e`04Woo1@<02P<P0`=00P<P00T2006P0F01P06P0L02008P0T000`9P00H28070
0B01@06002020V001@:P0^0300;00Z000P8000D1h0700N02809P0082P0040^0380<P0^020/020Z00
20<00b0380;00P01H05002030<001`3P0@0180400001003P00<0X0@0P00=0:00`03P0B01P07P0^03
00:00L01X07P0P000P8P00@2@0:00Z02X082`0030^0380<P00<3819oo`<04P0301<04P0C00H04`D0
50804`0301403`0;00@020L02@0400P01`0700P200T200X200l200X400T00`0800T02@0200X200/0
0`0@00/02`0200/02@0<00h0400B01402@0800L0200;00L00`0600L01P0600H01`0700P02@0001<0
400:00H020802@802P0400/0300>01@301H00`0EOomoo`0=Ool000eoo`03G01P060000eP009T009P
0004F0180200900470048002700360001a`0900X0200A01<03P000<X000<=0140200700P02@0:00/
03@0@00003000R`000Hd03`0A01<05001002900780000b@0800L00028004700580001b@0:00`00@0
F01D0400008X00@P008T008X0008;00d0400D01L05P0E01@019oo`D300/38083@08380030V01P050
0081P00@0L02008P0T02H0:00V02@08P0H01@06P0402H0:00Z020`000`;P0Z02P0020V020N001@8P
0V02P0:00^000P<00P;P00P2`0:P0202@0:P0/02H05P0P4P00<0`02P0:000`2P0P300`2P1`2000T0
X0200:00h04P0F02@08P0T000P6P00<1`07P0P000P9000@2P0:P0Z02X082`0030`0380<P0083019o
o`@04PP04`D050804`0301403P0:00@020P02@@020<02P0300d03`0;00802P802@0400/02@0900T2
00X0100;00X02`080`0:0P0900H02P0<00d0200700P:00L00`0600L01P0800H200L01@0800<04P0?
00T01@080`090`0:00L0300;00l0500C0140400?Ool000eoo`05G01P0600H010000<H0001F@0H01P
05P0C0000R@000DL01P0700L0200008T008P0006700H01P0600P02P00R`000Td03P0;00T02P0;014
05@020000R000R@000@/0300<00`008/008X0005;00`03@0=00T00028004700480000a`0600L0004
70000b00900T00029002800022@0:00X05P0E00l02P0900370003B00900X02`0:00/0300>0140500
A00l03P0019oo`D300/38083@08380030P01X0500081P0040L0200900T040X001P900N01H06P0P02
P082X0080/02h0;00Z02P0:P0^02P08200040T02P0:00/030^020/001P9P0@01H06P0L01P0810004
0>00X02008050:050800102P0800P0200P2P00T0P02P0:00h0400J02008P0J000P6000D1h08P0T02
00:000<2X082`0050^0200;00X02H00BOol5018701<501@201<00`0A00l02`0400P900T200P200T3
00X01`0;00X02P0:00T02`0?00802@@02P<02`<02PD0200300001`0700T01`801P0300L01P0600L0
1P801`0500P0000A00h02@0400P400T400X200/0100000`02P093goo000=Ool00e`0H01P000AH000
1E`0D00X020060000Q`000<P02@0;0000S0000PT0200700H01`0800X02`012P000LT02P0<01805P0
@00/000390000bP0;00/0002;0001BP0800P020090000RP000@P01`0700H00<L00@P0003700H01P0
00@L0006800X03@0>00`02P00R@000L/02@0E01D03`0:00T0002700280001bP0;00d03@0<00/0300
008h008`0003=01oogoo011oo`H300X38083@08380030P01`0500081P0040N0200900P030Z001`:0
0V02@0700J00@09P00<2X0030/02X0:P0082X0070`02h09P0P02@09P0X000`;000D2h0;00Z01h03P
00<100030>00`03000L0P0030:00P02000H0P080X0050B01002P0:00`0020>00105P0^02806P0P60
00D1h08P0T02P0:P00D2`0050^02@0800P02@00BOol4018901<301@201<0100B01403`0;10080`09
0`0:0`090P0800<02@0:00X01@0:00H02`0:00`0400000T900X00`0900L01`0<00L;00H300L02006
00L01`0800L0400>00T400P200T800X0100900P020093goo000=Ool00e`0H01P000AH00015`0E004
02@00QP000TL0200900d03P0000X02@080000Q`000lP02@0;00X02@0:00T02P0;00`0400C01@04P0
<0000R@00RP00R`000<X02@070000Q`000DP02@0900001`000<H008L00@P0003700H01P000@L0006
800d04P0D01402`00R@000L/0300F01D04@0;00T000370002b00;00d04@0C00l0300;00`02P0;000
0S004Woo1@<03`<P0P800P5P00<1P0700P000P8P0`;000L2X0:00V02806P0402P0060Z002@800T02
P0:P0/02H08P0V02P0040/001@:P0T01@0200:000P300P2P1@200`2P0P2000D0001P0600P01P0080
P0050:00009P0N00h0020:020@000`5P0^02@0030H001@7P0R02H0:00/000`;P0`;00P8000<2@09P
Ool04Goo100B1`0C00<0500C01000`0D0P0C00<04P0@00d010080`090P0;00D0200:00T02P090080
200300T02P0:00L02P0400/0300:00T700X00`0900L01`0>00L600H01`0700H01`0600X03`0:0080
1`0600H0200001403`0:100800L02@0:00X02P0=00h02`0300X0100800T02@093goo000=Ool00e`0
H01P000@H0003e`0F01D00@0800L01P0700P02@0=00l04P0<00T000280000b@0<00T000490002RP0
;00`03@0?0140400E01<03`012`000<P02@0700011`00R0000<001P060000QP00Q`000@P02P0900P
008L0003600L01`0008L0008800`04P0D0140300:00T008X009D0004A00/01`0600270001b00;00h
04`0E0140300008/0004800T02@0:00BOol50`0?0b002P800T01P05P0H01`0800R0200;00P;P00@2
`0:00X02H08200030V02P0:000@2X00:0P01P05P0J0200:00V02@0800Z020/001@:P0T01P02P0800
102P0`2000L0H0200800X0300>00X00208000`1P0800P00308001@2P0002`08P0@000P2P00H0`03P
0J0200:00J020F002@7P0T02H0:00/0300<P0`02h0020/0010200P0280904Woo100B2@0C00<0400D
01@00P0C00@04P0A01003@@020802@0400X02`0;00`300X500T400X300T300P00`0<00/02P0600X0
0`0800L01`0900L00`0600L01`0400L600H01@0700H02`0@00X00`0700L0200001403`0;00P01`02
00P01`0900X02`0:00h04P0=00<02P0400P02@0900T?Ool000eoo`03G01P060000iP0006G01H05@0
B01002000Q`00QP000HL0200;00d0000<002900012P0=01<03`00R@00RP000H/0300=01004`0D002
E002F00014`0@00h03@012000Q`000@P02@0900000@H0007700P02@0=00002@080000a`0120000HX
03@0>00`02`0:00290001b00B01403P0:00L01P0008L0007800X0300@01403`0<0000R`000@401P0
700P019oo`D300d3800<0`02h0800H0180400F01X07P0R0200;00P;P0P:P0P:000@2H0900T02H0D2
P0090200h03P0>0180600V02`0:00082X0090X0280600>00X0200:00`02P0080P0<0H080P0050:01
80700>00X0030800102P0800P02P0P2000@1`0500>00`080X00=0<01X0:P0T01X0500F0200900V02
P0;00^000P<000L2h0;00/00P07P0P02@00BOol4018901<02`0@01<04`0B0140400>00`02P0000L0
0P080P090P0:00<02`0<00X00P0:00H02@0:00l02P0900P200X200T0100800H01P060P0700<0300?
00`00`0:0P08200710060`0700@0200200L01`P01P0400L0200700L200H01`070000300;00T02007
008020802@802P0300/03@0;00<02P8020802@moo`003Goo00=L0600H000360000A00500@00000<X
0003100H01P0008H000D70000200800T0200900P02P0101H05@0A00002P0800/0300@01@00E00007
G01P0400D01002009000120000@X00P0<00400@H0005700P02@0>010000480000`00200P00028000
12@0800P020012@000DP02@0800P01`0008H0005700P0200:00P0002900280001RP0800001P0700P
019oo`@300/3800<0`02008P0001@0400<00X020000100700`801`:00P8000/2H08P0P0200100000
@0300>00`000008100070:0300:P0T01P00P00000P4000H0P0100400P02P000406020800105P0P00
00000P200P0000H0X0200:00X0200:0208003P2P080000400002006P0@01@0400002@09P0X060/00
1@:0000000800T004Woo0`0B00<04`0B01<0200C00H04P0200002@08004300L00`0600L0000200P2
00T200P200X01P0;00X02@0B01400P802@80200400001P0500D200H00`0000L020020100100:00T0
00000P080P0700@0000800001`<01P@01`050000200700L01P0200@00`0300H01P0800H00`070000
2@0200P2000200P00`0900P02P0700X200P200T?Ool000eoo`]P009T0005H01L05@0@00/0003:000
0b@0000H000360027004800290003BP0>01<05P0G01H0500?00d03P0D01L060000AT00AP0003E004
0200008L0007800T03P0A00`00@070000aP00Q`000@T03@0@00`008T0006:01<05@0B00d02`012P0
0b@00R000RP000DT0200700H01`0008P0003:00/02`000</0003:00T01`000<P019oo`<300`38003
0/028060008180030000P0200080P0060<01P0700P02@09P0`:000@2H0900R02008380050`02X07P
0D00h0020<00103P0@01805P0P4P00L200<00X01`03P0:00`002080010600V01@02P0`200P1P00`0
P02P0D02X0:00B00X0300V02`0800@030<00202P0<00`0300@01P0700R020V001`900P01X0700R02
H0:000D2`0060Z02H0700P02@09P4Woo100B1@0C0P0D0P0C00L04P0@00`02@0800L0200600L200P5
00T400X0200=01404`0@00/0200700H400D02@0600P0200600d04`0@00/0000500L00`0900`01`04
00H01P0700H01`0700H03P<01`0700H0300?00X01`0600L00`060`070P081@090P080P091@0:00@0
2@0:00T020<02@moo`003Goo2V000f@000AP05P0B00d00<X0003800L01`000@H008L00@P000?900P
0200;00d04@0E01L05@0A00d03`0D01L060000ET00=P0003G0000200008L0007800T02P0;00X0200
900011P000DL0200;01002`0008P000::00l04`0C0180000>00d02`0:00580000b@0:00X00029000
1B00700P0200:0000b`000P`02`0:00X0200:00T02004Woo10<02P<P00@2h09P0J01@08100030800
H0200080H0040800h06002020T003@9P0X02P0900P01H0000^0380<00/02005P00<0`00;0B01`07P
0J01P04P0@0380;P0T0180020:0208000`3P0B00`0020:000`300800H00206005P200@0280800@00
X0300L02H0900N01P0500@00`03P0@01@0700P02809P10:000H2807P0R02H0:00Z020/020Z001P:0
0P01X08P0T02H19oo`0401804`0C018601<0200D01<04`0@00h02P0800L200P300L200H200L200P7
00T0200800T02`0?01003@0800L400H02P0500P02@0900L02@0C01803P02200700H01P0700H01P07
00H200L02P0600P01`0600L01P0800X02@080`0700@01P0700L01`8020L02@0300P02@0900H02P03
00T0200800<02@moo`003Goo2V000f@000A00500?00/008X0005800L01`0700H000470000aP0700P
000280002Q`0600H01`0800X03P0C01H04`00S`000=@05`0H0001F@00V0000EL05P0100T01`000<P
00<T0003800d0200008H008L000:800T0200900P02@0:00h0400A002B0001400=00/02000Q`00R00
0R@012P00R@000@P02@0<00`008d0005?00h0300;00P0002:0000b@0Oomoo`0@Ool30`090b020`00
1`:P0N01H04P0@00`0200080H0080800H0200600`0500P0280<2@00H0N0100300401h0;00`02h090
0H00h0300>0180900Z01h06P0D00P0<00^02@04P1@2P01<0`02P0:0100500:00H0200600X0300D01
00300800`0500J01`0020N001P700@01804P0J020082@0030V02P0:000<2X0050X02H08P0T02P004
0Z001@9P0P01X0000T000P9P4Woo00<04P0C01801@0C00P0500C01<04`0B004030090`0810070`06
0`0700<0200900T00P0900<0200700L00`0800@0000>00T01`@01P0400D0300900T200L201000`0=
00801`0:00L400H0100700H01`070`060`070P08100700<0200900T00P09100:00<02@0:00T01009
00@02P0900T02@<0200300T02P0900moo`003Goo2V000f@000I004P0=00/02P0900670001200700L
01`00R0000<001P060000QP00Q`000TP02@0001H05@0B0100500G0001V@000IP05P0D01<0000;002
900380001b@0:00<04@0;00L01P000<L000@800T0200800T02`0>01404`0D01D0500@00/02007002
80000b@0800X0004;003:0001000C01804`00U0000A803P0;00P008X0003901oogoo011oo`<300L3
8083@08300070V01X0500B00h02000001`2000L000600J01`0600D00h0020:0020200@01H0:P0`02
X07P0@020<002`4P0R02h0900J01@0100X02806P0D000P300`2P00H0`03P0D02807P0@0408004P2P
0<00`02P0800`0500H01X07P0P0280600D01H07P0T02H082P082X082`082X082P0040V02X0:P0Z02
0/001`9P0J01H00P0T02H0:0019oo`<04PD04`0701@04`0C01<04P0000/00`0830070P080`070P06
0`0700@01@0?00`020<01P0500L01P0000X02@0200L200X00`0900001`0700L0100800T01`070P06
00<01`0600H01@0610070P080`07100900<0200:00X01P0:00X02@0<00/02`0<00d02`0800L02080
2P0300Uoogoo00eoo`003Goo2V000f@000I004P0=00/02P0800470001200:00T02000Q`00R0000@0
01P0600H00<L008P0008901D05P0D01404`0G01P00ET000AH01@04P0C01003`0>00`02`0:00/03@0
B01H04`0>00T0004700380001R@0:00`04@0D01H00=L0003E00l02@0008P008T0003:00/03@0008h
0005<00/02P0;0000003F0001U@0D01403P0:00000<T019oo`8300P38083@00:0`02h0900H018040
0:00P000060208000`300:00P0020800103P0@00`02P1@2000<0`03P0H000P;P00/2H0600<00`040
0L02X08P0H01804000<1X00<0F01@0400>00`03P0@01`0:P0^02H0600P2000<0H0200800102000/0
h05P0L02809P0X02X0800J01`08P0082H0040X02X0:P0X030/040Z0030800^02h0;P0/02@06P0B00
00900V02P19oo`<04PD04`0701@04`0C01<04P0100X00`083P071P060`0700@03`0>00/020@01P03
00P02@0700801P801`0400P0000700H300L0200800L02@0>00/01`0600L900H200L500P00`0700P0
2@0300T0100800X02P0;100:00@02`0:018040803`0500d02P0800L0200300T?Ool000eoo`YP00=T
0006@01803@0;00X01`00QP000HL00@0<0140300800370000b00600H00026002700480000d@0F01@
0002A0000eP0H01T0004I0000e`0C01<0004D0002d`0B01804P0E01L05P0C00h02P0800011`00R00
00HX02`0?01@05P0G003H0000e`0D00`0004900022P0<00l04P0C01003@0<002;002C002B00024@0
>00`02P0000L0200900BOol30`070b002@=00b0380;P0R01H04P0>00X003060010200@01h0400`20
00<0`02P08001P200P2P00D0h09P0^02X07P0080`0040>01@0600D020@000`100J01`0020L020N00
2`6P0@01X09P0^0300;P0V01X02006001@2000H0X0200B01`0900Z020/001`;P0/02@07P0T02H0:0
00<2X0040/02h0<00^030/020Z002`:00T0200700F01003P0D02@09P0X004Woo0P0B1P0C0P0D0P0C
00<04P0100X00P081`0700<02`0700L010071`060P0700H01P0<00l0300800H300D500H300L00`00
00P0200200P01`0900P03P0B00002P0800801`T01P0300L02008008020802@8020<02@802P0400/0
2P0>00h200/300X00`0<00X02@0200P300L0100800T02@093goo000=Ool:H003I0001T00B00d02`0
900L008H0006700P03@0A00`02000a`000<P01P060000QP00Q`000LP02@0800P0300B0100002>000
0e00G01T0003I0000f00G01@0002E0000eP0G01L0006G0001E00@00`02P0900011`000LP02@0:00d
04P0F01L0003H0001F@0H01H0400;0000b@000LX0300>0180500B00h0002<0000b00?0100002B000
14@0@00h03000R000R@04Woo10<02@<P00D2h0900H01@0300080H0060400H02P0F02H04P0`2000D0
`0200600P01P00<0P0<0X0080<01P0:00R01H0200:00`0<100080>01000P0H01h08P0T02H082P009
0P02H0;00`02h0:00N01@02P00H0P080X0040J0280:00/020^001P<00P02X08P0T02H082P082X004
0/0300<P0`020^000`;00Z00P0030H000`5P0>00X0020:000`8P0V02P00BOol3018401<00`0D01<0
500201<00`0B00002P0200P500L00`0600T03@0600L00`0600L01P0300H300L01P0600L02`0900L0
1P<01@0300@01@0600<01P801`<020802@0600X02@0<01402P080`0720060P0700<0200900P01009
00@0200900T02@802P0600/02P0=0100300;0P0:0P080P0700<0200700H00P0600@0000900T02@mo
o`003Goo2V000f@000E00500?00`02@000<L008P0004;00`02@0800270000b00700H000260002A`0
800T0300=00T0200900`0002;00013@0A01H06000f@000IP05P0F01H05`0@006H0001e`0F00<0300
:00P01`0008P008L0006800X02`0>01@05`00V000f@000EP05`0D00h02P0008T0004:00/0300>002
?0001C@0<00`0300?0000T@000U804`0D01@04`0000X02@0:0004Woo10<020<P0P<000@2P0700F00
`080H00:0800H02P0@01H0300800H0200:04060208000`2P0@00X0020:001P3P0F01@03P0800`0H0
h0050601`0900X02X0070/001P9P0L01H0400800X0@0P080X0050001h09P0/02h0040`0010;P0V02
@09P0P:00P:P00@2`0;P0`030082h0030/02X01P0081@0030@00h02P0080P0040202809P0X0BOol3
018501<00`0D01<04`0201<0100100/02@081`0700<0200700L0100700@01P0700L01`801P<01`80
1P801`801PL01@801P0300L0200800L02@0400/0200700L:00H00`0700P02@0200T01@0:00T02@09
00P00`09100:0`0;0`0:00P0200700L01`0600D01P050P060P0900<02WooOol03Goo000=Ool;H002
I0002F00@01800`0800L0000900X000380001@00700L0000800011P000HL0200:01004@0;0028000
1b@0:00d00`0@01@05`000900006B01@05P0F01L04000f0016@000EP05`0000X020000@H008L0006
000T02`0@01@04000V0016@000AP05P0A00`008X00PP008`0004>0100400D002@002A00014005000
02@04Woo1@<02@<P00@2009000000080P0030<0000200080P08000030600P00000@0H0050000P030
0000h00308001P2P0800P0200:00P0@0`08000040P02P0;00^060P001`:0000180400:00001P0080
0008080000200:0000800X02`0830083808300040X02@08P0P020X000`:P0/02`0050/000`:00000
P0050:0208000`400402@00BOol3018801<01`0@01<0400000X02@0000<01`0300P0000700<01`07
00H01`0700L01P0700H00P0700@01P0<00X01`@01P0300@01@0500@01@0400@01P06000200P200T0
100800T020080`0900<0000700L02P060P080`0900@0300900T02@<0200300T02P0:00H02P0500P0
2@0000H0100600D01004000020083goo000=Ool00e`0H01P0008H003I002H0001UP0A00T0200900X
008P0006700P0200800T02000aP00Q`000DP02@0=00d02@0008P0005900d04P0E01L0003H0001E@0
A01@05P0G0000V0026@000=L00`0800021P000@P0300C01H009P00ET0008H01H04@0=00`02`0900`
00H/008`0004B01D05`0H003I0001FP0H01P05@0@0004Woo1@<02`<P00H2h07P0:00X0000>030802
06020805060208000`300H00`00608030:002@300:00X0300B00H0:P0/02h0030`030b001P<00^02
80400:00P0L0H0050800`09P0Z02h0020`020b002@<00^02X0700H02809P0X02X0060/000`:P0R00
00040:040<000`3P0@01H00BOol3018701<301@01@0C01804@0?00T00`0700<0200700L01P070P06
00P01`0600L01`0600T020070`0620050P0600D01`0800T02@0800H02P802@0300001P0600T01P03
00L0200800<02@0300X02@0900802@801`802@0300P02P0:00@02P802@0300001@0500L01@<01Pmo
o`003Goo00=L0600H0002F000f@000MP05`0E00d02@0800T0003800490001200600H01P00Q`000@P
02@0900T00<P0005;0100500G01P0002I0001V00F01<05@0F01L009P00QT0005G0080200700H0007
70000c00D01L0002H005I0000f00F0140002@0001C`0<00`0300;000130000Dd0000D01L060000=T
00=X0003I01P04`0019oo`D300T380070d0380<P0Z01@02P08000`1P00D0P01P0800`02000D0H080
P0030:00`02P0080P080H080P0030:00`0300080`0050:00`0600P02`0020^020`020b001`<00b03
00;P0R00`02000<0H0030800H01P0080H0050800h0:00/02h0020`020b002@<00^02H04P0>01@080
0V02P0020Z030/000`:P0T01H0050:000`300>00h0040<0BOol4018601<301@01P0@01<04P0A00h0
20/01`801P@01`0300H01`0700@01PT01@0300L0200800802@0300X02`0;00803P0500/02P0900T0
000;00H00`0700P02@0300T0200800T02@0900P01`0600L200P600X200T800D01@0600D01@0500H0
3goo000=Ool00e`0H01P000>H0000eP0A00/000290002R00900/0300=00`02P0800L01P00a`01B00
00L002@0=01<05P0G01P0003I00015`0D01D05`00f001f@000AP05`0000P00<L00<P008L0004800`
0500G002H005I0002600F01D05@0F01D04@0?004>002?0001400A01H06000f@016P000=T0600E000
4Woo1@<030<P00<2h08P0@001`200P2P1`1P00<0X0200600101P00<0P02P08000P400`3000D0h06P
0P02`0;P0083008380080d0300<P0b02h07P0<00P080H0040800X0200803060010000X02`0;P0`<0
00/380<00/01h03P0:00`04P0L0280800082X0060/02X09P0L00h0200`2P00H0`03P0B01@0000>02
0<0BOol3018701<401@01P0C01804@0?00X020D01`0300H01`0700D01`<01P0300L01P0600<01PD0
1@801P<01@0300L0200800802@802P0300d03`0=00802P802@801`X01P0300L0200900L02@0300L0
1@0500801P0300402@0900@02P0300P01`0400H01@0300H01`0400<01@moo`003Goo00=L0600H000
3F0000AL0500@00`008/0003800h040000=80003?00/02@0008H00<L00DP0004;00l0500F002H003
I0000f00E01D0002G002H007I0002f00F00001`0600L0200900`03`0:0000R0000<d0500G0000V00
1F@000=P05`0G0000f0000AH05@0D01@00=D0005C0180400F01P0003I00016P0I01T06P00V@000=H
07ooOol047oo1P<02P<P00H300:00L0180200602080206030806060508000`1P0:00H0020800102P
0J01h03P0P3000<0h0700R000P;P0P<01@<P018300;00J00X0200600002P0>01@02P0800H0200@02
H0;00^040`000`800X01@0040<002`3P0B01P09P0/02h0;00R01P03008000`2P00P0`0400N02H020
0>00`02P4Woo100B1@0C00@0500C01@050804`0301403`0<008020801`L01P801`0300H01`0600P0
1P@01@0300@02@0900801@0400H01`0800P200T200X200/200X300T00`0700H01P0300H00`0700P0
1P0300H00`0700P0200600T00`0800D01@0300D0100600L0200;0P0>00<0300800L01@050P0600<0
2@0=00H00`053goo000=Ool00e`0H01P000<H0002U`0E01403@0<00d03P0@01<05@00eP000AD04P0
<00400DL008P0007700402`0>01@05`0H00016@000AP05P0E01H00=P00MT000;H01D02@0700H01`0
800X03`0B00`000280000cP0C01H0004H003I003H004I002H002G0001f00G01H0500A01L060000=T
0007J01T06@0J01T0600F0004Woo1`<020<P00H300;00P01@0400:0508020:000`200600H0040600
0`200600000206002@2P0>00H0200:00P0500H00h0020<000`400L0280020^030`040b001@<00X01
@02P08000P1P00@0`0700V01@080H0050800009P0Z02h0040`0010800N00h03P103000T0h0000N03
00<P0`02P0700>000P200P2P00@0`0400N02X0<0`0030:1oogoo011oo`@04PH04`8050804`040180
400=00T300L;00H200L800H500D00`0600L01@0200H00`0700P0200400T300X300T0300800H01P07
00H01`0600X03P0700H01@@020H02@0300H01@0500<01@0400H01`0600X201<0100@00/020041005
0P0600<02@0?00000`053goo000=Ool?H0002U`0D00l03@0>01004@0@01H05`0160000=H04P08000
11`00R000Q`000H00200<01<05P0H004I0001F00D01<05P0G0000V001f@0015L0500:00L01P0700P
02@0<00h02P0800T0300@01<05`000QP00MT00AP0005G01H0500G01P0002I003J0001F@0H01T05P0
D0004Woo1P<02@<P00T300:00J01@0400:00P02P08000`2P00@0`0200800P080H0050800H01P0800
000206020800101P0800X0201@3P00D100600P02`0;P00<300<380050`02h0900F00X00206001@00
0:01@0800@000P1P00H0P04P0P02P0;00^030`0010900B00h03P0P30103P00L180;00b0380;P0X01
H0030:020<00103P0F01h0100P3000<0X7ooOol047oo100B2P0C00@04P0?00/020<01`801P0300D0
1P0600L01P0400L01P0600L500H900D0100600L020080`090P0:00<02`0:00T00P0900<0200600H0
0P0600@01`0600L02P<01P0400L0200700P300T00`0800T01`0600D02P0600L01`060100500B00l0
30041P0500<01P0800@00`053goo000=Ool00e`0H01P000<H0002U`0D00l03@0@01404`0D01L0600
16@000=P05P000000a`00R000Q`00QP000HL02@0>01@05`0H002I0001T00E0100400D01L009P00MT
0005G01@0000700H000270000b00900T000280001B@0:00h0400E0000f0000=005P0G0000V000V@0
00=X06@0I0000f@01F0000=@05`0H0000V@016P00V0000=@04`0Ool04Goo1@<02P<P00D3009P0H01
804000<0P0090:00`0300>0100300:00`02P00D0P0030000H01000@0H0030800X03000@0h0040@01
@0800/020^020`020b020`0010;P0T01P02P0`1P00@0P02P0<00P080H005080000600R02X0040^00
0`1P0>00`0040<030>000`400P0380020b000`;P0R00P0020:020<00103P0@01003P0P3000<0X7oo
Ool047oo100B2@0C00D04P0A00l02`0800801`801P0400@01P0500D500H300L0100600L01P071006
1`05100600H01`0800T02@0800X300/200X00`0;00T0000;00H300L01@0800T02@0800L01`0500D0
100600L01`0;0080500301804@0000H01@<01P<01@moo`003Goo00=L0600H000360000QL05@0@00h
04@0B01@05P00V001F@000=L0100800011`00QP000PD0100600L02@0?01@05P00U`000I@04@0@018
05@0G003H006I0000f00F00000057002800021`0800T02`0>01805@0G002H0000e@0C01H0002H000
1V@0J01X06P0I01X009T0003H01L05`0009L0004D01H05`0H002I003J002H0000eP0D01oo`0AOol5
0`000`<P0`0380070b001@<00X01`0500>000`200P2P00L0h07P0P00003P0H01H004080206040402
0602080010300>0100400P4P00<1@01P0Z000P;P1@<000D380<00Z02003P0080P0030000P02000@0
P0050:00005P0N02H0020/000`:P0R00H0040<030>001@400>0100600^000P<P00<300;008001@30
0`3P00<0X02008004Woo1@0B2@0C00D04P0?00/0200700801P0700D01P0600H01@0<00/00P0600<0
1@0800L00`071`061P050P060`0700@0200900T020802`0900`02P0<01003`0<00401P0700T01P<0
1`<0200300001P0500H01@0300@01P0700801`070180500B0140000500H01@0500<01P0400D00P05
3goo000=Ool00e`0@01P000=H0002400B01004P0@01@0400H003I0002600I01P05P0000T02007005
60000a00600L0004800020@0200000@0A01H05`0@004H003I003H00015`0000P00001Q`000dP02P0
001005@0@01P06@0H01004@0F01P0002I003J0001f00J01X06@0H01@00`000<00004@0180500@002
A0001V00I01T06@0H014019oo`P300L380060`0200900000@0200P2P00@0P030020080<000050L01
@0300:000003060504001@000800002000000P4000P18050060200:00/02h0800`<000T200<P0b03
00:00B00P00006000P00102000D0X0100P02@0:P0082`0030X00P00P00@0`0050001004P02000002
0@002P100:00@010080000400400003P0P3000D0X0200:00X020019oo`H04P@04`80400701@04`0B
0100000900P00P0600<01@0400H00P0600<0100000H00P0600<0200700L02`060`04100600@00008
00P020802@802P0300/02P0000804P030100000600X01P0300L0000800<0200300001P0400<01@<0
100300001P0600801P0300<020080080200300400006008010L01@moo`003Goo00EL0600H01P0400
00eP0006G01D0500F01006001F@000AL04`0;00P008L00LH0004700P02P09002700280000d`0F01L
0003H007I0001V00G01D0400<00T00LP0003>01<05P0009P00=T0004H01L05`0H002I003J00026@0
J01X06@0H01<0300:00280001b@0;00d03`0A01D05`000ET019oo`T300P380050`02`07P0800X003
0<030>0020300D01`0400<00P01P0402060304001@1P0800X04004000P2000H0`0400H0280:00/02
0^020`030b002@<00^0300;00R01H02P0800000206040800103P0402X0;P0`<000@2h0;00B00h080
`00;0>0100600V02`0000>0100500H01X0020L000`000N01@0020>001`300:00X0200<00X030019o
o`D04PH04`@0500501<04P0@00l02@0:00H0100800401`07200600<01`0600P01@0600<01`0800P0
100900<0200:00X00P0;00D02@0=00l0300100X01P0300L0200900D02@0300L01P0600<01P801`03
00002@0600801P0300L0200800@0200300L01P0600L01@moo`003Goo0U`00V0000=00600H0003600
00EH05@0F010060000AT0004G01<03@080037007600270001b00700L01`0800T05@0009L00=P00MT
0007G01@04P0@00h03@0<00012`000HX0200B01D05`0H005I0000f00G01P0002I003J0001f00J01X
06@0G01002@000<P00<T0004<01005@0H004I0000fP0Oomoo`0@Ool80`0:0b000`<00Z00@0020:06
0<020>020:000`200600H00306020402060208002P000600P0300B02009P0Z02`0;P0P<010<P00L3
00;00V01`0500@00X002060508001@300F0200;00^0010<00182h01P0@00h0300>0100500L028040
0>0100500F01`0800R020T000`6P0>00X0030:040<0BOol4018801<301@201<01`0B01403@0700H0
100500H01P@01a001P0300L0200900@02@0500X02`0>00d02P0300T200L:00H00`0700P02@0500T0
100800H01P05100600<0200700H00P0600<01`0800P0100900<0200700H01@050P063goo000=Ool2
G002H0000d00H01P000;H0001U`0F01<0500E01L00=P0006F01803@0:00001`02QP011`000@P02@0
001D00=L00=P00ET0004H01L04`0A003B005C0001400<01@05`00V001V@00V000V@01VP000=T05P0
=000120000TX02@0900/0400E01P06@0H0000fP04Woo1`<02`<P00<300;000001`3000<0P0300:00
0`2000<0H01004000`101P1P0P2000P0X0500R02P0:P0/02h0<00P<P0P=000P380<00/01`0500B01
002P1P2000D0X03P0L02@0;P00<300050b0300<00<0180030>020@002P4P0D0100400B01@0700R02
@09P0P:000<2003P0:000`2P00@0`03P0>00h19oo`D04PH04`0301@04`0D00<04`050180400>00T0
1`0700H400LA00H00`0700P02@0200T200X010000180400;0`0900<01`0600H0200500<01P0700P0
100900D02P0900T0200700801P<01@D01P801`0300P02@0900<02@0300P01P0500@01@<01Pmoo`00
3Goo00=L0600H000360000UT0600H01H04`0?00h00@0B0000T`000=403P0:0000R0000<L01P06000
1aP00Q`0120000@T02P0101D00=L00=P00ET0007H01L04`0C01@05@0F0001E`000AD00P0E01L009P
00IT0004H01L0600I005J00016@0H01<02P012@000P/02P0:00/04@0F01P06@016P04Woo1@<03@<P
00@2h09P0@00h080`0<0X0@0P0@0H0<0@0@0H0H0P0090<01P0900X02X0:00^0300<P0083@0838003
0`02X060008180030<00X02000@0X080P0050B0280:00^0300030b020`000`900F0100020>060@00
2P4P0H02809P0X02X0:00Z02@0400`2P0P3000<1004P0@004Woo0P0B200C00@0500C01@050804`06
01804@0>00/020071P0600D01`0600L01P0701401P<020802@802P0400004P0<00X200T0100800H0
1P04200500<0100700P00`090P0;0`0900<0200600H00`051@0600<01`0800T00P0900@02P0900T0
2@801P@01@<01Pmoo`003Goo00=L0600H0002F0016@000MP05`0D00l0300;00X0006900270000`00
600H0004600270002`00900X0300=00X0200:00/0100E0000e`00V001V@000IP05`0D01D0500G002
H003I0001F00G01805P0G0000V001V@000=L05@0H0000V@00fP000AT0600E00d00<T000;:00<03`0
;00X02`0B01H0600I01X0002I0000fP0Oomoo`0@Ool50`080b030d001`<P0`02X07P0@00`02P00L0
P0D0H0030400H01P00<0H00?0800X03P0B00P02P0<01@08P0T02P0:P0X02h0<000D380050P02H04P
0>00`0040:020<030:00105P0T02X0<01@<P00D300:00J01@04P00H1000=0B01@0700T02H0:P0/02
00;00T0100300:000P3000@000700T01H19oo`804P0301<04P0C00D04`@050804`0501403`0<00T0
200300L300H400L00`0600L01P0:00H01P0800H01P0700H00@@020<02@0300P0300:00<02@0300L0
1@0500T01@0300@0200900802@0400X03P0<00X200T00`0800L01P0200H00`0500H0100300H00`07
00P02@0300X00`0;00X02@0200H200D01@0600@02@0<00L03goo000=Ool00e`0H01P0009H004I000
1f00F01403@0;00X020000<L008P0005:00T02@0100L0004600470002B@0;00l04P0=00P02P0;010
0002F002G003H005I0001F00F01H05P0@0000V001F@000AP0500F01L009P00IT0003G01D05`000AT
0005H01T05P0@00T0002800032P0<0100400;00X0300B01L0600I01P009T0003J01oogoo011oo`D3
00P380<3@0080b02h0900F01003P0:00P0<0H080P0030:00`01P00H0H00<0800H01P0:01007P0V00
P02P0>01h0;00P9P00@2X0:00^0300@380040`0200700>020<030:0010200>00h0300P2P00@1H090
0/0300D380060`02006P0H01H0500P4P00h1@04P0B0180600P02@0:00Z02h0<00/02@040103000@0
@0900Z01P19oo`<04PH04`D0500601<04P0@00d02@081@070P0610072P0600X01`0600X03`0800H0
1`0500/02@@020802@0300P02@0900802@0300P01P0500X01@0300@0200800802@0400X03@0;00X2
00T00`0800L01`0700H0100700P02@090P0:00@00P0<00T02@801P801@801P0300`0400700moo`00
3Goo0U`02V000f@000QP05`0E0100300;00X020011`000DP02P0:00T0200008L008H00DL0005800X
0300=00X000290001B`0B01D0500F0000U`00V000f@00V000eP000=L0400I0001f@000=D05`0G000
0V001V@000AP05`0H01P00AT0004G01@03P09002800032P0<01003@0;00X03@0C01L0600I01X009T
0003J01oogoo011oo`D300L3800;0`03@0=00d0380;00N01H0400:00P00406001@200<00`02P0800
1@1P00h000200600P02P0<01H0700000P03P0V0300;00P9P00<2P0;P0`001@<000@2@04P0>00`0<0
X080`0080>01003P0<00X0500T02`08300@380030`02008P0082@0050P01`0700J01`0020H002P6P
0P02H0:P0/03008P0/02@0400`3000D0h00P0L02805P019oo`804P804`0301804`0C00804`@05006
01004`0B010030090P080P071@060`07300600<01`0800L00P0700<01P0000d01@0810090P0800<0
1`0500D02P0500<0100800P00`090`0:0P091@081P0700<0200900T00P0:00D03@0:00T0200600@0
1@0400@0200900H?Ool000eoo`03G01P060000UP00=T0008H01L05@0@00`02`0:00000<L008P00<T
0003:00T020000LL00<P00<T0008:00h0500B01004P0E01L00EP0003G01D05@0009H0003G01P06@0
00AT0006J01T06@0@01H05`00f0016@01F000f@00V00011D04@0;00T0200900/0300;00X02`0=01<
05`0H01T00AX019oo`@300P380090`03@0=00d0380:P0N01H00P0080P0070600P01P0600P0300:00
0P300P200P1P1P2000`0X0300<00X0300D02X0;00X02008P0X020^040`001@;P0600h0300:001030
00@100600@00h080`0030D02@0;0008300<380830082P0040Z02`0;00/030Z0030800N01h0900V02
X0;00^02`0:P0P0180@0`004000180500B0BOol3018401<00`0D01<04`0401@01@0C0180400<00T0
0P080P071@0600@01`0600L01``01P0300L01P0700801`0400d02P0800L300P300T200P01@0700D0
1@0500@010050P070`0500@0100700P020<02@0300X02@0900<020<02@0300P02@0800@020<02@80
2P802@0300P01P0500@01@<01Pmoo`003Goo00=L0600H0002F000f@00V0000ED04@0=00`020000@L
008P0004900X0300@0038002000280000`@0000P000380002b@0:00P0400000`03@0001005@0G000
0f0000I00500B01D05P0G002H007I0001600@01405P00f0000AT0600H01000AP00ET0009H0100500
400`0200900X020000@00004@01L06@0I004J00BOol50`070b002@<00d03@0=00b02`0800D00@005
0000201P0800P0400800H0400:0708002@2P0800P0200000X0800R0000030H0010000X02`0;P0P80
00<2P08000000P3000D0P02P0<00h040008000080@00`000000100000P02h0@300040P02P0:00/02
0^030P001@<00P0200900P000P9P00L2P0:P0X02P08P0F0100030<001@3P0001004P0@004Woo0`0B
1P0C00<0400D01@00P0D00D04`0B010030090080200300L01P0600<01P<01`030000200700h01P03
00002P0000D01`D020801PD01@0500@01@0800X00P0300D00`0400H0000300P300T0100000P02008
20090P0810090P0800@0000700H010@01@0300@01P0400moo`003Goo00=L0600H0002F0000=T0600
I0000V@000EP05P0C00h02@000@L00<P0004900/03009004800012@0700L01`00R000b@00RP00S00
00Dh0400A01@05`0009P0004I01P0600G002E0000eP0H01P0004I002J0001V@0H01H04@0D01H00IP
0003D01P0600009P00MT0007H01L04`0?00h03`0@0000eP000=D0500G0000V@016P04Woo1@<01`<P
00<300=00d000P=000@380;P0V00X0@0P00:0600P0200:01005P0D00`02P08020:000`300D01H002
0F003P500F01X00P0R01h0600F01P06P0H0200:P0/020^0010<00^02H0101@3000<0h0400@000`40
00H0h04P0B01H08P0^030`0010;P0V0200:00P;P1`<000D2h0;00T02809000@2P0040T01`04P0@03
0>030@0BOol00`0B01<04`0501<701@01`0C0180400=00/0200700801P0300L01P0600801PD01`80
1P@01`0400P01`0700L300P00`0900P01`0400L300P200T200P00`0600D01@0200D00`0400D01@06
00D200H00`0700P0200300P00`0900L0200200P:00T800P00`0700H01@0400D200H?Ool000eoo`03
G01P060000]P00=T0005H01L05@0A00X000370000b00700P000380000b@0800P0002800012@0800H
01P00Q`000<P02@090000RP000PT02P0800h03`0C01H05`00V000f@000EP05P0F01L060000MT0005
H01H04P0401H0003H002I002H0000eP0G01P0002H008I0000f00F01<0002D0000eP0G01P0002H000
15`0H01T06@016P04Woo1@<020<P10=00P<P00D2`00P0800P01P00D0P00<0:00`02P0:00P02P0800
X0000J01h08P0P9000D2H0:00X02H07P0081@0050J01P0700P02`0020^020`000`;P0Z0100040<02
0>020@020H001`4P0@0180500P02P0;P00<300040^02P0800X020^020`040b020`001@;P0X01`07P
0T000P:00P;000@2P07P0F010080h0<1019oo`<04PD04`L050804`050180400>00T01`0200H00`07
00H01P0900H300L200P700T00`0800H01`0200L300P200T300P01@0600D01@0500@01@0500<02007
00H00P0600@01`0800P020802@8020040000200800P300T200X00`0800T02@0200T00`0800L01`06
00P00`0700H01@0500D?Ool000eoo`9L00aP00=T0009H01L0500@00/0000700P01`000TP0009900X
0200700H01`0800T02P0008/008X0006900X03@0A01D05`00f0016@000AP05`0G01P00IT0006H01H
04@0=01005`00f000V@026001f@000IP05`0E01H05`0@003H0000f@0H01P0002I0001600J01X06P0
4Woo10<020<P00<300=00d000P=000D380<00Z01002P00P0P080X0080800X02P0:00h0000J020082
@00<0V02P0:P0Z02P0800D0180500H0280:00P;P10<000<2h0100>000`300`3P00<080600D000P40
00@1806P0V02`0@300040^02`09P0X020^020`040b030`001P;00P02@0:00Z02`0<2h0080Z02805P
0@00h0400>01019oo`<04PD04`P0500501<04P0@00`02@0200L300H00`0700H01P0700H300L00`08
00T02@0600T0100800H01P070`0810090P0800D01`0600D01@0400@01@0300H01`0600<01P0300L0
20080080200400T02008000200P300T0100:00T03@08100900<0200700P00P0800<02@0800T00P08
00@01`0600H01@<01Pmoo`003Goo00EL0600H01P040000MP00AT0006H01L0500@00d03001R000Q`0
0R000RP00S00010T0200700H01`0900X0300A00h02`0:00P02@0@01@009L009P00ET0003H01L05`0
009P00=T0008H01L0500?00/0300@01L00=P009T00QP00MT009P009L00=P00YT0003H01oogoo011o
o`D300L3800;0`03@0=00d0380<00Z0200400<00X00308000`1P0800P00308040:002@300001`08P
0T02H0:00Z02h0020X00208P0B01@05P0P02P0;00^060`000`300B00`0020<030>000`400D010002
0>001@4P0N02P0;00^001@<000@2`0:00^02h08300D3808300050^02H0:00Z02`0020^030`000`;0
0T01P0030@000`4POomoo`0@Ool00`0B01<04`0501<701@01@0C0180400<00T01@073@0600<01`08
00T00`0900D0300:00T02@0800801P0400L0200800P500T200P00`0600D01@0500D00`0700H01@02
00H00`0400L0200200P400T300P200T01@0:00/02@0=00001@0910081@0900<0200700H010063goo
000=Ool00e`0H01P0009H003I0001600G01@04000SP000<l03@0;0000R@01B0000HT03P0A01<04P0
>00280003QP0000T02`0>01<0400;00T0200901<05P0G002H007I0000f00G01L0002H0002U`0F01@
0400<00X02@0:01005`00f000V@026001f@00V0000=L0600H0000V001V@000EP05`0G01D04`0019o
o`D300H380@3@0060b0300:P0N01H00P0P2P00<0P02P08000`2000D0X0200:00X0200080X00B0800
00700P02@09P0X02`0<00/02P07P0@01H07P0V02X0;00`<00`<P00@300:00J0100D0h080`080X005
0<0180800Z02`0060`0010;P0Z02`0;P0`<010<P0P<000<2h0:00Z000P;000@200<00`0380830003
0^02H0500081@0030F1oogoo011oo`<04PD04`D0500501004`0B00l02`0200P200L00`0600L01P08
00H300D200H00`0700P02@0300X01`0A00/02@0900P01P0700<020L02@80200300H01@0500L01@03
00H01@0500@020802@H0200300T02P0:00802@0300X02@0900802@D020H02@8020<01P0300Moogoo
00eoo`003Goo00=L0600H0003600019L05@0A00h03`0A01<0500C01403`0=00/02P0900X00@0D003
F00044`0=00T01`0000T02`0=01003@0;00T01`0001D05`00f001f@000UL0500C01<0400?00d02`0
:00012@000<H05`0H0000V000V@016000U`00f001V@000=P05`0G00016001V@000EP04@0>00d02`0
019oo`D300L380<3@0060b02`08P0H01@0000P30102P1@200P2P01@0`02P0:0000700R02H0:00Z02
`0<00/02P0700D01X08P0X02X0;P0P<01@<P00H2008P0F01803P0<020:0208001`2P0800P0400R02
X0;000L300030X02X0;P00<300@3808300070Z02P0:P0/02h0800`000`<P0P<000D2`00P0F01P070
019oo`<04PD04`D0500601004P0A00d02@080P072P0600<0100500D00`0500D01P0700P020090080
2P0400`02P0900T300L200P400T00`0800X02@0300T00`0800H01P0500D300H200D300P500T400P2
00T00`0:00T02@0500T400P200T00`0:00/02P0400T0100000L01`083goo000=Ool00e`0H01P0008
H00036@0H01P0600F01<03`0>01404`0E01H00=L0007E01@04P0=00l04@0G0000f00011H04`0;00P
0000900X02`0<00/02P0900P00P0F01L00=P00IT0006H01H04P0?00h02P01B@000DP02@0900@05`0
00=P00AT009P0003E01H05`0009P00ET0004H01L05@0G004H006I0000f00400/0002:00BOol50`0:
0b001@<00V01X05P0B000P300P2P00<0`02P0:001@201@3000H0X06P0R02H0:00Z030/002P:00J01
H07P0T02X0;00P0300<P0P=00`<P00D2007P0H01@03000P0P0040>0200:00/070`0010800V02`0;P
0`<000`380<00`0300;P0R02H0:P0/02h0800`040b001P<00^00@06P0L02819oo`804PD04`D05006
01<04P0A00h02P080P070P061`0500<01P0500D01@0500@01P0700P020802@<02P802@801`802080
2@802P0300/00@0:00@02@0300P01`0700H01P0400D01P0500D300P600T00`0800L01`0200P600T0
300800T01`0700P02@0800T02`0B00d02P<02@<0200300Uoogoo00eoo`003Goo0U`02V0000]T0600
G01H04P0>00l04P0C01H040000AP0005G01H0400B01D0002H002I0001V00F01402`0800T008X0003
;00X02P0008T0003101L0600009P00MT000:H01@0400>00`0200900P02@0:00290001200900005`0
0f0016@00V000U0000=L0600H0000V000V@00V0000AH04`0E01L00=P00IT0005H01002`0;00X000B
Ool50`0:0b001`;P0R01P05P0B00`02P00@0`0040:00`02P08020:060<0010600P02H0:00P:P00<2
`0:00V000P6000D2009P0Z02h0800083800;0d0380<P0b03009P0L01H04P0<00X007080010300N02
P0;00P<00`<P0P<000@0P0600T02`082h0@3000:0^02X0800R02P0;00^0300<P0d030b001P<00^00
P0700R02H19oo`<04P@04`D0500601<04P0@00d02@080P070P061`0500<01P0500D01P0500<01P07
00P01`090P0700@0200900T02@802P0300h0200:00@02@<01`@01P0300D01P0500801P0300D02008
00<02@0300X02`090080200300H01@07008020H02@0400X0200700P300T0100:01403P0:0`090P08
0P093goo000=Ool00e`0@01P000;H0002U`0E01403P0@0180500F01006000f@000IP0400A01@0400
H004I0001600@00@02000R@000<P02P0:0000R000P0000AL0600H01P00MT0006@01@00P0<00X02@0
0R0000@T02P0800P008T0003201@0400009P00AT009P00900003A01P060000=P0008@01@04@02000
00P0D010009P00IT0005H0100300;00X000BOol50`090b001`<00X0200600D00002000<0`00@0200
00300<0000200:00P0300001000P0:00000P0H020P020X000`:P0X02@0020J001@800X02`0;P0`00
1@<P00H300800P01@04P0<020:0408020:001@200:01008P0X000P<010<P01@200000@01000P0800
`0800R02H0:00P00H0400B0200:P0/02h0<010<P00H30080020000900P0BOol3018501<401@01@0@
0180400<00P00P070P0600@01@0400D01P8010801@0500H01@0500@01@0200@01@0500H01@060000
1P090P0800<0000800T00P0900H0200:00P02P0900P200T00`0000L01`0800H01@0400H0100000P0
100900@02P0900P000@01@0800H0000100002@0:00P00P801P030000200800802@<02P0500P02@09
0000200200T?Ool000eoo`9L009P0003@01P060000MP0009G01D04@0?01404P0E01L060000ET0005
H01H0500F01P0006I00035`0000T02P0;00`03P0?01004@0@01L00=P00MT0006H01L05@0?00/0200
0R@000@X03P0B00d008T0003801805`0009P00ET0004H01T06@0I004J0001F00D01403P0<0000RP0
00@l05P0@01P00IT0005H01804@0>00`000BOol60`080b001`<00Z0200600D00`0200080`0030B01
`05P0080h0030601H02P0080`00:0>0180900R00003P0H01h08P0V020X001P800L01@0600P02P082
h0030`0380<00083808300060^02P0900B00h02P0P2000D0X0000P0100200080X0040@01`0:00^02
0`020b000`<00/0100020@040B002`500F00005P0B00`02P0F02H0:P0^000P<00`<P00@300;P0602
0082H19oo`<04PD04`<050804`030180400<0080200300L01P0500<01P0800T01`0600H01@0800L0
10801P0400D03@0900H200D00`0000P02@0300T01@0800L01`0700P02@091008100600@01`0600L0
2`D01P<020@02@0300P01P0500<01@<01P0300@0200700D01P0500L0200900T02P0500T0100000P0
2@093goo000=Ool2G0000f00G0100009H0002E`0F01<0400B01<05@0G01P0005I0001E`0D00l04P0
H0001V@000UL0000;00/03@0@01<05@0F0000U@000AL0600H01P00QT0004H01L04`0>00380001BP0
=01403@0:0000R@000A005@0G01P00AT0003@01P06@000IX0005H01@03`0<00T000280000b`0A01H
0002H006I0001400F01@04P04Woo1P<020<P00`300;P0T01X05P0<00X0300>0180800L020>000`40
0F00`0020<020>00104P0D00h03P0`6P00/1h0800R01H03P0<0100700V02`0;P00H300<2h0040Z01
h0400:0308000`100T01@0030:0010400F0280;P10<000@2h0900@01808100<1808100030D018030
0080X0040<01`0:00/060`000`;P0Z02P0020X0BOol4018501<201@201<01P0B01003@0900P01`@0
1P0300D02`0700801P0300D01P0700@01@801P<01@0300001`0700<01`0400H01@0500H200P<00T0
2@0700H01P0600L01P0700`01`0400H00`0700P0200400T0100100D01@060P050`0600<01@0600H0
100600<01@0600P00P0900<02P0900X00`0900@0200900T02@moo`003Goo15`000=00600H0002600
00QL05@0B01804`0E01L06000V@000UX06@0I01L04@0;00005P0H00016@000QP05P0000d03`0C01H
05`00V0000AL05P0F01L00=P00QT0003H01H04@000<P0009900X0300;00T02P0=01<05P0009P00=T
0003H01H0600009T009X009/0005J01P0500<00T0003800012@0;01405`016000f@00f0000=L07oo
Ool047oo1`<020<P00H300:P0N01P03008020<000`400F01@0050>020<050>001`4P0H01@04P0@00
h0400080h0060<00h05P0R02X0;P10<00P;P0`<000D2h0:00F00h02P0080P0030:01803P0080X006
0>0180600R02`0;P0P<000<2h09P0D000`4000@180500D0180<100030:00P0200080P0030>01h0:0
00<2h0<300@2h0030/1oogoo011oo`@04PD04`@0500601<04@0?00/02@081@0600<01`0600H00`06
00<01`0600D01P0500<01P0700H01`0500<0100700P0300900<0200700H02@060P070P0810091@05
100600<01@0600H01@0600<01@0000P00P0900<02P0900T01P093goo000=Ool4G0000d00H01P0009
H0001e`0E01@04`0E01L0600009T0005J01T0600F00d000290000d00E01L0002H00025`0F01<0300
?01<05P0H004I0001V00F01@05@0F01L009P00MT0003G01@02@0008P0003900X02P0008X0005;008
05P0G01P0004I00015`0D01P06@016P000I/06P0H01@02P0900280001b@0:00X02P0C01H05`000=P
00ET0003H01oogoo011oo`L300T380040^02P0700@020<020>020@001`3P0@00h0400D01H04P00D1
00060N01P0500@00X0301@3P00D100500P02H0:00082`082h0D300040^01h04P0:03080020300:00
X0300@01P08P0X020^001@<00^02P0600B000P3P00P1005P0P01X04P0@00h02P102000D0X03P0B00
80:P00D2h0D3019oo`@04PH04`8050804`0501804@0?00`0200:00H300L200H01P0500H01P0500L0
20801PL01@0300@01P0700D020P02@0300L01P0600P01P0300L0200800802@0300P02@0800801P08
00D01P0600H02`0700H010H01P0300L0200700`02@moo`003Goo1E`0360000IL05P0D01D05`0H004
I0000e`0C00X000280002bP0<00l0400A00l0400A00h0400E0000V0016@000QP05`0B0140500F01L
06001f@000=P05@0;0000R000b@000HX02`0=01405`0H005I0001600F01L06@00fP000MT06P0J01P
0500:00T0002800490001b`0>01404P0D01L060000ET019oo`L300X380030^02H0500080`080h003
0@00h03P0080h0030D01X07P0081h0090L01X06P040200600B00`02P0080`0<0h0090@00h03P0@01
@00P0V02X0;P00<30083808300030X01H03000<0P0<0X0050>01@07P0V02`0040`0030:P0F01803P
0@01806P0Z0200500@00h0<0P0080:01003P0<00X0000H020082@0040Z02h0<00`020b000`<0Oomo
o`0@Ool3018701<401@201<0100A01002`070P0600<0100600H010060P070`080P0700D0200700X0
200600X01@801P801`8020P02@0300P01P0600P01P8020D02@0900P01P0600H01`0600L0400900H0
1P0500L02@0800H0100200H300L00`0800T02@0400T?Ool000eoo`EL00eP0005G01H05@0G01P0003
I0000f00F00h000480000b@0:00X0003;0001D00>01805P0H0000V@00VP00V@000EP04`0B01D05P0
009P00MT0005H01D02@0900P0003900012P0;00h04P00V001V@000=L0600I00016P00V`000EP04P0
:00X020000DT0007800T02P0=01<05`0H0001F@04Woo20<02P<P00<2h08000000P301@3P00@0@070
0N028082@0<2H0050T02005P0B00X0030<00103P0@0180400`3P00D180000X02`0;P008300@38005
0`02X0500>00X0030800202P0<0100600T02X0800`020b003@<00^01`04P0>01004P0H02806P0B01
003P00<0P00<0<00P0200:00`02P0<00h0500L02P0;P0P<00`<P4Woo0P0B00<04`0B01801@0C1P0D
0P0B00<04@0900H01`0600<01`0800P01P090`0800<01P0500D00`050`0600D0100500H01P0700<0
20<02@802`0400X02@0900P:00H00`0800T02@0500T200H01P0500H01P0600X01`H01P0300P01P06
00H01P0600L0200900T0200:0P093goo000=Ool5G00?H002G0001d00H01P0600F01402@000<P0004
900X02`0;003:0001C`0>01805`0H0000V@00VP00V@000EP04`0D01H05`0009P00MT0003G01<0200
00DT0004:00/03@0C002H006I0000d00H01T0003J002K0000fP0A0140003:002900012P0;00T0200
0R@000@`04`0G01P00ET019oo`T300X380030^00004000@0h0<100040P0280900V040X001@800R01
P0400:000P3000/0h00P0F01P04P0@00h0300D00H0:P0082h08300090b03@0<00b03009P0>00P030
00<0X080`0040@01`0:00/020`030b000`;P0R01H0020@00104P0D01H0500P4000<0h0200:000P3P
00@0P02P0>00h0<0X0040@01X0:00^020`030b0BOol5018401<701@301<00`0@00T01P0500H200L0
0`0800T02@0600T00`0800T01P0300D300H200L01@0600D01P0600L00P0800L02@0800X02P0?00h0
2P0200T00`0800H01P0700H00`0000T02@0600T00`0700H01P0900H00`0700T01`0800H0200700P0
2@0:00T03`0:00T?Ool000eoo`IL019P009L0003C00h0200008L000=800X0300@00d02`0:00/04@0
101805`0H0001f@00U@000AH05`0H01P00IT0004H01H0400000270002200900T0200900h05@0H007
I002H00016@0J01X06P00V`000=X0400@0000RP00R0000@T02`0@00X00<T0004<01805`0H005I00B
Ool;0`090b000`800J01@0020B001`500H01P0400R02@09P0082P0070/02X0:P0X02@0700B000`30
00H0h0400V02H05P0@020>00105P0P02X0;P0P<00P<P00H3@0<P0b02h0800:02060208030:001@40
0P02X0;P0P0010<P00<300:00J000`400`4P00H1003P0@0080400<020800103P0H0180200P2P00@1
006P0X02h08300<3819oo`D04PH04`H050804`0701804@0=00001`0600L010080`0900T02P0;00X0
2P0900P02P0000D0100600@0200>00`01P801@0600H0200800P02@080P0:00<03@0;00T00P0900<0
1`0600H01`0600L0000900T02@0;00`02P0200T00`0000H01P0700H200L00`0900L01P0200H00`08
00H01@0400H01`0800T02@0801002`0900moo`003Goo1U`000=005`0G0000T00360000QL05P0D010
03@0800H01`00R0000Lh0000900X0200001@0002@0000e00H01P0004I0001F00I01@05P0G0000V00
1V@000=P05@040000R000`00120000@l0400H01P00MT0003H01T060000AX000AH0100000;00P0000
800T0200200002@0800X0300@01H0002H004I00BOol;0`090b000`<00R0200020P020X002P7P0H02
80900V02P0;00P02P0:P0P:000<200500<000P3000`0h0000R00`04P0@00003P0H0280;00^020`03
0b001@<00P00X00008000P0000X0P0000600H0200B0280:P0^0200D38082000:000100400@018040
0B0100600004080200002P800000P02P0@01P0900/0200<00`<P4Woo1@0B1P0C00@0400C010040D0
5080400600000P0100l030090P0800<02@0800P00P0;0P0:0P0900<0300000@00P040P0600@00002
00001P80100900L0200800P02@0800T0200:00<02@0300001P0600801P0300@01P0400<01P060000
2@0900T0200<0P0:00<0200000<00P0600<0100600H00P0600<0000700P00`0600@01`0400P000D0
1P040000200900T200P00`09Oomoo`0=Ool000eoo`IL0003H01L05`000eP000G@01@04@0=00/0200
700H01`0800`03@0;00X02`0?01@05@0A00l0500G01P0002I002J0001F00I01H05P0G0000V001F@0
00mP05P0@00X02@0800T02`0<00X02@0800T03P0@0000V003F@000IP05`0@01003@0:00380000b@0
:00X0002900012P0=01405P00V0016@04Woo2`<02`<P00X300;00V01h0500@01808P0T02H0<2X082
P0060T02`0:00N00h02P0P3000D0004P0B01H0400080h0040L02P0;P0^030`020b020P000`3P0800
P00208000`2P0800P00208001@4P0T02X0;P0`001`<P00H2006P0D01@05P0H020J000`600@00X003
08000`2P0>01000208001`2P0>01H08P0Z02h0<000<3819oo`<04P0301<04P0C00D04`8050030100
500D00D0500501<04@0>00/02@0300L01@0800T0200:00/00P0:00H02@0:00l03P0800H400D600H0
0`0700P0200800T:00H00`0500H0000200T02@0:00/0300<00/02P0401<02`0200L01P0600L01`07
00002@801`/01P0300L0200900@02@moo`003Goo1U`0460000I803P0;00X02@0800360001P00:00/
02P0;00d00940006?00`03@0A01H06001V@000=H05@0G0000V0016@000EP05P0A00/02@0008P0004
:01004@0<003900013P0E01P060026@00V0015`000IH0500C010030090028005900013@0C01D05P0
0V0016@04Woo2`<02P<P01H300:P0P01P04P0>00`0000L02809P0X02X0:00V02@09P0R01X04P0<00
X080`0040001P05P0H030@0010600R02`0;P1@<000T2004P0:00P01P0800`07P00000`2000H1808P
0Z02`0800`020b020`003P<P0d0300:00N01X0700P01h0700J01003P0:0308020:0208001P300H01
`08P0Z02h0@3019oo`<04P0301<04P0C00D04`0301@04`0D00H0500501<04P0000T0200500L00`08
00T02P0200X200T00`0;00X02@0200H200D01@0600D01P0800L00`0600<01`0800P01P0900<02007
00H0100600<02`0:00L0100600D0000900T02@0:00<02`0600X0400C01402`080P070P0800@00007
00H01`T01P<01`0300P02@0900<02@moo`003Goo1U`03f0000MH00P0;00/02P0800L000460003R00
900X03@0>00d0300;00P0300?01@05`0H004I0001600G01L05`00V0016@000]P05P0A00`02@0700P
02P0>00l02`0008T0003:014050000=P00ET009P0003G01H05@000=H00=L0004E014030090048000
12@0;01405P01F0000=T0600H0004Woo2`<020<P00D3@0<00Z01h05P008180060<00P0200<01H07P
0P9000H280800P01@04P0>020:001@200:00`0000H000P5P0P4P00D1@0700R02`0;P00@300040^00
00400:02060010200<01h03P0P2000H0X0800T02P0;00P050`001@<P0d02809P0R00108000H28090
0P01H03P0:0508000`2P0D02@0020Z000`;00^0200030`0BOol301800`0C01804`0501<801@00`0C
0180400400P500L0100000T02@080P0900<0200700L00P06100500<01P0700L00`0600@01`0800P0
20D02@0300P01`0600<01P0300D02P0900<01P0400D0300800P200T02`0:00/0300;00`0400B00d0
2@0800L00P0800<01`0800P00P072@0610081@093goo000=Ool6G00;H0002F@0H01P05`0E0000300
;00T00027004600270000b@0;00/0002:0001R`0>00l04@0C01H00EP0003G01P0600009P00IT0004
H01D03`0;0038002:00290001BP0=01<04`0F0000f000V@0160000=H05@0E0000UP000=L0600H000
0V0000YH04`0>00X02@0800T02P0>01D009P00=T009P0003G01H07oo015oo`X300L380<3@0828007
0H01@04P0<00P01P00000P2000L0`04P0D01@05P0D0100020>003`2P0800P0200:00`0500F01@040
0B01h0900X02`0020^030`0010;P0T0180300P2000`0H02P0>00P01P0:0180:00V0280:P0/040`00
1`;P0b0380800R02008P008200080V02X0;00/02H06P0@00X0@0P0040>0200;00^020`020^000`<0
0^02h00BOol301800`0C01804`0501<801@00`0C01803P0300P600L00`0600L01`0500L200H600D2
00L200H0100700P020081`0900<0200700H0100600<01`0600H00P0600<03P0200P00`090`0:00@0
2`0100h02PH020<02@0300P01`0600H01P0300L0200900H02@0300Qoogoo00eoo`003Goo1U`02V00
0f@000MP05`0D00`02`0900P0003700280047002800022P0;00d0400D01D05P0G003H0000e`0E01L
0004H007I00015`0D00h02P012000R@000H/0400B00`04@0E002H002I003H0001U`0E01@05@0F01L
00=P009T000:H01L0500?00/02P0800h0500G005I0001400C01803P04Woo2@<020<P0`=000X28070
0F01803P0:00P01P0800X080P0<0X0<0`0030>00`02P0080P080X0070<00h0400>0100600R000P:0
0P;P1@<000@2`0800B00X0H0P0090>01h09P0L01H0800Z02h0<000D2h0030R01h080008280030V02
`0;P00<2h0030Z01h04P00@0X0040J02X0;P0`020b001@<00Z02P09P0N004Woo0`0B200C1`0D0P0C
00@04@0<00T020L01`0500H01`0700H01`0400H00`0400D01@0500D200H00`0700P0200200P200T0
0`0800T02@0300T00`0800L01P0700H01@0:00/0000700P01P090P0:1P081@0900<0200700H01006
00D01`0800T02@0:00802@80200300L01Woo00ioo`003Goo1E`02f000V@00V0000EL0500<00X0200
00<L008P0003900001`000@L0005900/0400D01L0002H002I0001F00G01H0400G00016001f@000AP
05`0C00d00DP0009900/03@0<00X03P0C01L060000AT0007H01L05@0C01D05P0G0000f000f@000UP
05`0E01803`0101@05`0H0001F@000A003@0;00T019oo`X300H380@3@0070P01`05P0@00X0200600
0P2000D0`0200800P01P00<0P0D0X0040<00X02P08030<001P3P0J02@0:P0/02h0H300040P02X06P
0>0408000`000:0100020J020@001@500402`0;P0`0010;P00H2007P0P02809P0Z020^030`002P;P
0/02@0600>01004P0V02`0<010<P00@2805P0B00`19oo`@04PD04`0301@04`0D00L0500501<0400<
00T0200900L600H:00D00`0600L0200300P900T200L600H00`0700P01`0200H00`0700P0200500T0
1@0800L01`0800L00P081P090P0800D01`0600L01`0800802@0500/03P0:00T00@0300H?Ool000eo
o`EL00aP0007I01P0600G01D00@0900011`01B0011`000DP03@0C010060000IT0003H01@05`000AP
00QT0003H01H040000XP0004?01@05`0H004I002H00015`0D01H05`00f001F@000MP05`0E01<04@0
F01P0006I0001400;00X02004Woo2`<010<P10=000H380800P01P03P080306000`200:00X0050800
0`1P0800X0020:0010300>00h03P0`3000L0X0400N02H0:P0/02h0020`030b020`000`;P0X01H002
0:02080010000800`03P0P3000@0h0500802h0D300080^02@0700P02@0:00/02h0D300030^02`090
0081X0060202X0;P0`0380=00P<P00@2003P0<00X19oo`804P0301<04P0C00P04`H0500501<04@0=
00T0200800L700H:00D00`0400L0200200P300T0100800X02P0:0`0900<0200700H02P0600<01`08
00T01P0900<0200700L00P08100900<02P0900T00P0900@02007000020<02@0500/03P0:00T00@03
00H?Ool000eoo`EL00=P009L00]P0004@0080200700460001A`0000P02@080000P000R0000=00500
@0000V@000=P06@0J0000f@000=005P0G0000f0026@000AP05P0@000008H00HL0003001005P0009P
00ET009P0003F01L05`000=P00ET009P0004F01@0500@004I0001f00I01T0400<00P02@0019oo`/3
00L380080`03@0800T00@00P08000080H08000050800X00P08000003060020200:00`0300@00@040
00030<020000109P0Z02`0;P0P<00P<P00L3@0<00`0300;00L00P002000206000`100600H0020000
10200B0200;P1P<00P8000H2@0800X02`0800`020b030`000`;P0P0000020P000`;00P0300040b00
10200>00P0204Woo100B1`0C00<0400D01@01@0D00D0400B0040200000P01`0300001`0600<01P80
1@0600@01@0700D01P040`0500<0100700P00P080P0900H0200:00T0400<00X300T00`0700H01P04
00H00`0400H01P0200H200P200T00`0800T02@0200T00`0800L0200200P01@0900P02@0>00P01009
0`0000<0200900P01@0:00@0000700L01Pmoo`003Goo1U`00V000U`0360000=D0400800011P00Q`0
00@P03`0?00T008P0004:01405P0H004I003J0000f@0A01D0002G002H008I0001600F00h02000a`0
00<P02@090000b0000A<05`0H01P00ET00=P009L00=P00IT0003H01L05`0009P00MT0004600/02@0
800BOol;0`080b001P=00`0300;00N00X0D0H0050800h08P0N00X00206000`000:00X0020<001040
0F01H0000P3P0P3000D1P0900Z02`0;P00<300<3808300030/01H02000<0H0040000P02008020600
0`2P0L02P0020`030b020`001P800X02H0:00Z02h08300<3808300070^02H08P0V02P0;P0`001@<P
00@080300800P19oo`@04PD04`0301@04`0C00P0500401<04P0100T200L02@0600L01`0600L01P0=
00X01`0300H400D0100600L01P060`0500<0100600P00P0810090`0:10092P0600<0100700P00P09
0P0:0P0<0`0910080P0900<0200:00X010090`080P0900<02P0<00`00`0:00@00@0700L01`moo`00
3Goo1e`000AP05`0G01L00YP0004I0100500=00670000b00:00X000280001B@0<01405@0@00016@0
0VP00V@000=004P0E0000U`00V001V@000EP05`0C00/0200008L0005800/03P0>00X0002800014`0
G01P06000f@000EP06@0I01T0600009L00=P00MT00=P00MT0003H00@02`0008P019oo`d300H38007
0d0300<P0`02X0500800101P00P0P02P0>0100200600P0300`2P0`3P00@1003P0>00h080`0050D02
00:00/02h0040`020b0010<00^02P03P0P200P1P00T0804P0@00X0200600X07P0X000`<00`<P00H3
00800/02H0:00/020^060`001@;P0X02P0:P0/000P<010<P00D3000P0<00P01P019oo`@04PT04`H0
500601D0500C01803P0810070P060`070`0600<01`0600D0100500<01P0500D00`0500<01P0700P0
1@090P0:100900<0200600H010060P070P0600<0100700P00P090P0:00<02`0@00T00P0910082@09
0P080P0900@02P0;00`030<02P0400001`0700L?Ool000eoo`ML0003H01L05`000]P0005I01P05P0
A00X0005700480001b@0:00d03`0C010060000=T009X009T0005@00h03`0E01L0002H006I0003600
E00h02@0000L0200900d04P0@00X008P0003B01H0600009P0004I01P0600H002I0000f00G01L0003
H005I005H007I0000f00500X0002800BOol=0`070b001`<00b0380;P0R00`02000@0H0<0P0040600
P0200@020:0010300>00h030103P0P3000@0h05P0T02P082h0H300040Z01X0200803060010000T02
00300P1P00@0X0700X02h0<30083808300040^02P0:00/020^060`001P;P0Z02`0;00P0300D38005
0`00@0300800H00BOol5018801<00`0@01@0500201@201D201@00`0B01002`0400L300H200L300H0
0`0800H01@0900D01@0400H01P0800T00P0:20091`0600L03P0;00H01P0400L0200500T00`0;00P0
2@0200T300P900T00`0800T02@0200T200`01P0;00X02P0:00401`801Pmoo`003Goo1e`000=P05`0
G0002f0000MT0400D00l0300:00P000370001@00800P020090000R`000@`03`0E01P00=T009X0003
I01P0400008T0003=01<05P000=P009T0006H01L05@0@00T02000Q`000DP02@0;00h02`000<P0003
?01D05`000IP0004I01P0600H002G003H004I0001600G01P060026@000=P0400;0000R004Woo30<0
20<P00P3@0<P0b02`08P0D00`0200`1P102000<0H03000000`2P00<0`03P0>00103P0P300P2P00<1
@0800/000`;P0`<00P8000@0h0200600@080H0040001`050080206000`2P0H02@0020^060`001P;P
0/02P0:P0/02h0H300060/02X0;00^0200<01@<P00D3002P0<00P01P019oo`H04PL04`030100500D
00H0500401403P0:00P500L500H0100700H01P060P0500<01P0500D0100500L0100600H01P0700T0
2P0700T00`0700H01P0500H00`0800L01P0300H300P800T0100<00P020081`090P08100900L02P0;
00/02P0900`0200200L00`06Oomoo`0=Ool000eoo`YL00aP0006@01403@0;00X02@00R0000/L0200
800T0200900X02`0=00l0500009P00ET000:G0080200800T02`0?01@05P0G002H0001E`0D00l02P0
80000a`000@P02@0900X008P0005700002`0C01L000:H002G003H003I002H00015@0G01P06001f@0
00EP0400=00X02@0019oo`/300P38083@0070b02h0900J01@0400:001P2000<0H0200<000`2000D0
X0300>01003P0081000:0>00`02P0600P02P0@02H0:P0/040^000`2P0B00X00506000`200:00P003
06001@200>0200;00^001P<000D2h0<00/02X0;00082h0@300070/0280900/02h0800`000`<P0`<0
00@2003P0:00P19oo`@04PT04`P0500301<00P0:00<020@01`801P0300L01P0600<01P<01@H01P03
00D01P0600<01P0300L0200900D02@801`/01P0300@01P07008020D02@802P0300T04P0>008020L0
2@0300L0200800802@<02P802`0300X0400000<01`moo`003Goo1U`00V0000=L0600H0002F0000QT
0600@01003@0;00T02000Q`012000Q`000DX0300?01@05P0009P00=T0003H01L04`000DP000:900/
03@0@01805@0B00h02P080057004800370001200>01D05`01V0000AL05P0G01L009H0004G01P06@0
I002H0000e`0E01H0002H006I003G0000d`0=00X000BOol;0`080b020d001P<P0/0200600B00`0<0
P0@0X0030600P03000<0P080X080h0050@01804P0@00h00508002P400J02008P0V02`09P0@00`020
0P1P00D0@01P0600H02000D0H0050800H0;00/02h0040`001`800^0300<00/02X0;00082h0830008
0^02804P0N02X0;00P03008380830082X0040`01`0300:0BOol4018901<801@01@0C00402@0900P0
1`071P060P051P0600<01`0600H01P0600H01`0000P03@0:00P200L<00H00`0500H0200200P300T0
200800X02P0<01804`0;00P600T0100700D01`080`090`0:00D02`0:00d0400:00801`moo`003Goo
1U`00V000U`02V000V@00T0000<d02P0800011`00R000a`000DT03@0C01H060000AT0004H01L04`0
?00580000b@0:00X0002:002>00012`0900L01P011`0120000PL01P0600L02@0>01@05`00f0000E0
05P0B00l04@0009@0003B01@05P000IP0003G01P060000ET0003H01L05P0009H0003C00h07oo015o
o`/300L380<3@0060b02`0800H01002P0P200P1P102000<0H0200800102P00P0`03P0>00805P0B00
`01P102000T0`03P0<00h0400P01`00P08001P1P00<0001P08000P1P0P1000@0H02P0V02X082h0<3
00080Z02H0:P0^02X0900X02X082`0080Z02004P0>01@09P0/0200<300080^02H0600F0200;P0L00
`19oo`D04PP04`P0500501<00@0900T0200700L500H400D400H300L300H00`0700H01P0300L00`06
00X0200200L200H00`0700H01P0;00H200P01@0900X02@0800X00P0900<0300?00`01P08100600<0
200900T00`0900P02P0900L01`0101<02P073goo000=Ool6G002H0000e`0H01P0009H002I0001D00
C00l02P080000b@00R0000T`02@0800P02@0?01D0600I0000fP00V@0011L04`0?00P01`0800T02P0
<00h02`0900P02P0;00T008L0003600L000000<P0003900P020000<H000;700P02@0=01805@0F01D
0400?00/0002:0001c@0?00h03`0@01L060000ET00=P00IT0005H01005P0D010000BOol;0`090b00
1P=00b02h09P0L010080X0060<00P0200>00`02P0`1P00<0P02P0:001P300P5000P0X01P0600P02P
0001803P0`3000D100500000P01000D0H0040000P01P0602040206001@200F0280:P0/000P;P00`2
`0800T02@09P0R01X0600L01h0600D020@00403P0@01`0:P0/0300;P0Z0280500@00h0400Z02P060
4Woo1@0B200C00<0400D01@01@0D00D04`0200/02@0800801`0300P01`0600801`D01P<01@0300H0
1@0600<01P801`801PL01`0300H01`0700801a401P0500L02@0:00X0200500T00`0800L01`0200H4
00D0100600D01`080`0900@0200700H01P801`0300l03@0800moo`003Goo1e`000=P0400@0002f00
00IT0400F01002`08002:0001B009000030090000b0000A805`0H01P00AX0006I01P05@0@00T0000
0R0000@X0000B00`00@P0003700H01`000<0000380000200008P00<H0080008P0007900P0200800@
000080001BP000<T03P0@0000V001VP000I00500G01P06@0H003J0001600@01403`04Woo2`<02@<P
0`<00P8000P100000@0000200000@0500P2000T0001P0800X0200<0080000>000P3000<0h0500:00
0P000`2000@200400<00X080P0030000P01P0080H0<0P0040200P02006020402060020000800P00P
0<0000400H020P020X001`8P0P01004P0000`00000L100030000H00000<1008000<100030D1oogoo
011oo`D04PP04`030100500D00D05080400300002P0000@0200400L00P0800L300H300D200@600H0
0`0800L01`0200L0100600P0300010071006100700<01P0700H020060`0200@01`0000T02P802005
00T0200700H0100200D300@200H200@00`0000D01@0700H00`01001oo`0>Ool000eoo`IL009P009L
00]P009T0005H01L0500=00X00029002800290001RP0>00l0500G01P009T00AX0004I01P05@01003
800012@0;00`03000R@01A`000<P02@0:0000R0000<L020070000aP000H002P0?00h02P080027000
11P0000T02`00SP000H`02`0:00h0500I007J0000d@0F01P0002I003J0001F`0J01T05`0@0004Woo
30<020<P00<300=00d000P<P01H2P0500B01002P0<00h0300:00`0400>00X0300>01@0900N01003P
0<00h081P0080:00P0200800005P0B00`080X080P0080600P0200800`02P0800H080P080@0<0H003
0:01@02P0080X00;0>0180700T02P0;00^02`0:00J00h0020<001@3P0@01H06P0D000P4000<0h030
0>00103P00H1004P0B01003P0B0BOol501800`0C01804`0501<00`0@01@0500701@00`0B01<03@03
00P500L00`0600L01P0200D200H00`0=00T01P0300H00`0500T0000500L00`0800L01`0200L01006
00L01`0610070P0600<01`0600H010060P0800<01P0700H00P0700<0200:00X00P0:0P0900@01`06
00D01@801P0300L0200600801P0400@01@0500D400H01@0700H01P0600L03goo000=Ool7G0000f00
G01L000<H0001f@0H01P05`0D00h02P0008P0004900X0300A002C0000e00G01P0003I004J00016@0
G00@02@00b0000@T02P0900T008P00<L0005800T02`0000X000380002A`0600H01P0100`04@0?00X
0002800260000`00900`0002A0001S@0;00X03P0@01T009X009T00=X0004H01L0600I006J0000f@0
G010000BOol;0`090b0020<00d03@0=00b03009P0D030<020>002`400L02@06P0800`03P0D028090
0B000`3P00<1`09P0@000`2P00<0P0300<00102P0P1P0P2000@0`0600@00X0<0P0@0H0040800h080
0<020:002`300D02009P0X02h0<00^02X0800>000P3000D000500R02P05P008100030>00`0300080
`0060>0100500N01@0400P3P4Woo1P0B2@0C1P0D00<05@0D01@00P0C00<0300800L0100700H01P09
00X0200600D200H00`0;00X01P0200H0100700D02P042P0700<01P0700L00`0700D00@0700H01P07
00@01P0400L01P0>00X200H04P0700H0200900X02@0>00d02P0900P01P0400H01`0500`03@<01P03
00@01@0500D01P0500T00@0600H01`0?Ool000eoo`]L00mP0004G01D04P0>002<0000d00D01H0002
F00015@0G01P06@01VP000ET0600C00`02@000<P00@T000::00P01`0700P02@0<01803@090038000
1aP0700L00@0:00d02`0008T0009800L01P0700T02P0>00l0300008/0003?01006@000MX0004H01L
0600I006J0000f@0G00l000BOol=0`0=0b0010<00Z01@0400P4P00T1P0900^02`0900000`03P0@00
0P5000/1003P0>0100800^02803P0<00X02000<0X080`00<0@00X0000600P04P0X02@04P0:00P02P
101P01D0P0300@00X0200:00`05P0N02@0:00^0300;P0/02@04P0>00`0000D000P7000@180400@01
00<0`0090>01004P0H02P0100@00h02P019oo`D04P0301<04P0B00L04`X0500401<04P0?00X300P0
1P0900d03`0=00X01P<01@D01P0400L01P0;004?00L00`0600d01`0300L600H01P0800L01P0700H0
1`8020802P0700/0300:00X0200600@00`060P0810060P050P0600D01`0600L03@0200<01Pmoo`00
3Goo2e`000=P05`0G0000U`00V0000=L0600H0001V000U`000=H05@0D0000U`00V0000EL05P0F01P
06@000IX0006I01P0400B00/02@00R000R@000@P03P0@00d00<P0006900/03`0<00X02@00S000a`0
00<P02@0:00012@000<d020070000R@00b`000D`03P0C01006@000MX0004A01L0600I006J0000f@0
G00d000BOol=0`000`<P0`03800<0b001@800Z02P0:P0^000P<P00<300;P0>00103P0`4000P0h04P
0T0380<00P01003P0P2P0P3000@0h0500N018080P00?0:00h07P0P01@0300201@0200600P01P0800
X0300080X0070>01X0600P02@0:00/000P;P00L2`0:00N01003P0@0180020D030B003@500@00`030
0>01004P0F01`0500B00h020019oo`H04P0301<04P0B00T04`P050<04`0:0140400@01804`0B0100
3`0800H200D400H300L00`0>01802P0800L00`0:00L01`0400L0100:00P01`060P071@0600L01`06
00L01P0700T0200200T400X00`0900X0200900H0100000H01@050`0600<01`0800000`063goo000=
Ool?G003H0000e`0H01P0008H002G006H00015`0F01L06000f@00fP000IT0600H01L04P0<003:000
1S00001D05@0B00/00<P000<900P02`0;00`04P0C00/0200700002000R@000HX02`0@01<03P08002
900022P0;00/03@0C01L0400I006J0001F@0@01L0600I0001VP000=T05P0>0004Woo3`<05@<P00<3
00200>000`3P0`4000<000600/000P=000@3008P0B000080h00;0B01X09P0/0280000:00P0300F01
00020>0010000V01002P0`200`2P00<0h0600Z000P8P00<2H0:00/000`;000d2h0;00L0180400B01
@04P0D01H07P0V00P0030>0020400B01@05P0D0180400<0BOol9018901<@01@01P0C01804@0>00L0
1P801@<01P0700L020080140400B00X01@0700@0200<00h02P<01`801P0700401`0700H02`0<00L0
1@060P0700<01P0900h00`090`0:00D02`0900`0400000H01P0500L02@0800L01@0:00H?Ool000eo
oa1L009P0003G01P0600015P009L0003H01T06@000ET00=P0003G01@04P000900007B01@05`0G01D
03`09000120000</03@0A0000UP000A402P08000008P0006900/0400E01H050012@000@/0300@01H
009P00AT009X009T0003H01L0600009T00EX0003I01H0400019oo`h301L380030P01H04000<0h0<1
00070P0300=00d0380<00X000P6P00<1`08P0Z000P<P00<2`02P0:000P2P0P3000L1004P0<03008P
0@00X00208020:00203P0H02X0<00/02@09P0X030/001P;P0`0380;00L0100<1@0070J0280;00`02
804P0>000P400`4P0P5000<1`05POol04Goo1`0B00<04`0B01802@0C3@0D00@05@0D01@04`804P03
00d01P0500801@801P0300L0200;00<0500401803@0900T200X01@0001804P0@00P00P070P0600P0
1`0800P0200@01802P070P060P070`0800<0400C00l00P090P0:0P0;00@02P0@01@020<01P0400L0
200800/201000`0:00H01P0500H0100700H02@073goo000=OolEG00BH00015`0@01P06000V@01f00
0U`000=H05`0G0000f0000YL0500=00T0200900P0300?01@009L0009F01002`0800T02P0<01005@0
00=L0007400/02`0;00d0400E00016001f@016000V@016P000=T05`0C0004Woo3P<05`<P00D300:0
0J01@04P008100030B01H0;000H380050P02`0;P0`0380020d000`<P0000`0030:002@300@01P08P
0b02h07P0@00`0020:000`000H02P0030b0010;P0X02P0:P0P;000/300<P0b0380;P0201P06P0N02
P0;P008380030R01`04P008100<180040D0200;00T0BOol00`0B01404P07018:01<<01@0100E01@0
500D0P0C00@04P0>00H01@801P0400L0200:018501D0100C01804P0C0P0D0P0C00<03@0700H00P06
00@01`0900P03P804`0401402@0700H200L00`0800T0400301@0100900X02P0:0P0;00D0400E01@0
400;0080200800T02P0>01<05@0@014020@01P<01`0300T0400<00moo`003Goo5E`00V000U`01F00
00=L0600H0001f0000=L0600H0004V0000=L04`0>0000R`000@`0400D01L009P0009G01D04P0<00d
03`0B01H05`0009P0003G01@04`000940003C01H05`000UP009T00AP00AT0005J01P0600H01H000B
Ool>0`0H0b0010<00^02@0700P6000<1`0900`002`<P0`=000<200500@000P4000@180600T028083
80030/01h050008180030F02X0<000@380070^02X0;00/0300<P0d000`<P00H200:P0Z02h0<00b02
0d000`<00/01`0020D001`4P0D01@00P0^0380;P019oo`0301404P0B00L04PX04a80500301<04P00
00<0200300T03@0B00`05@0401@04`0C00`300L00`0000T03@0401@00`0A00T01`0200P00`0;0180
5@0201D0200C0100300;00`03P0B01D201H201D01@0B01004@0C01D00P0F0P0D00@03`0800H01P80
1`8020030140500B00moo`003Goo6E`00f000e`000AP0400G01000=P009L009000=L015P0008G01D
04`0B01005@0G01000=P0007G01H0500D01D05P0@00016000d0000=H0400@000660000=007ooOol0
47oo3`<06@<P00H3008P0P02008P0`0?0b000`<00R0200020@020P000`<00b0380020b000`8P0P02
00020P000`<00b0380040b020`0<0b020`001P=00`03808P0P00h080`08200030`03@0<P019oo`X0
4P804`0301804`0C00804`0401004`0C010D01@4010201@=01D201@00`0A0100100200000`0A01@0
5@0201D201@01P0A0000100@01@05@80500301H0500D00@050@05P0301@05P0F00H05P<050070140
100000400P0100@00`0D3goo000=OolJG003H002G002H002G003H002G003H0000e`0H01P000AH002
G00bH00BOol>0`1T0b0BOol00`0B01404P06018201<00`0B01<04`0801<D01@201D00`0D01D05@0L
01D00`0D01D05@0301DR01H?Ool000eooaUL00=P0003G01P0600009P009L00=P009L0003@01P05`0
04QP019oo`h306@3819oo`/04P/04`030100500D01<051X05@0701H05@0E01H05@0D01D01`0F00<0
500F01H0700F3goo000=OolIG003H003G002H002G003H0000e`0H01P0003H0000e`0H01P0014H00B
Ool>0`1@0b000`<00b03@0030b000`=00b03000;0b0BOol:01800`0C01804`0901<01@0@01@0500D
01<03`0D100E00<0500E01D05P0E00@05P0E01D05BP05Pmoo`003Goo6E`00f0000=L0600G0000V00
0U`00f000U`00f0000=L0600H000AF004Woo3P<0BP<P00<3@0<P0b000`<P00@300<P0b038083@083
80030`0380<P00T3819oo`d04PT04`030100500C01<0500401D0500D01@K01D00`0D01H05P0U01H?
Ool000eooaUL00=P009L00=P009L00=P009L0005@01P0600H01L0016H00BOol@0`1=0b001@=00`03
80=00b000P=00P<P00<3@0<P0d002@<P4Woo300B3`0C4`0D700E00<05P0D01H0100F0P0E0P0F00<0
5@0F01H06`0F3goo000=OolIG003H003G002H002G003H002G003H002G003H0000e`0H01P0010H00B
Ool@0`170b020d000`<P0d0380060b001`=00b03@0<P0d0380=000D380040`0380=00b0BOol90180
0`0C01804`0<01<201@00`0C01@0500?01@00`0E01@05@0K01D00`0F01@05P0501H0100E01H05P0E
7@0F3goo000=OolIG003H003G0001600G01L05`00f000U`000E00600H01P05`004IP019ooa4304/3
80030d0380<P00D38083@0030`0380<P0083@08380030d0300<P0083819oo`T04P0401<04P0B018<
01<00`0D01<0500D01@H01D00`0F01D05P0601H00`0E01H05P0O01H?Ool000eooaYL009P00=L0004
H01L05`0G003H002G0001D00H01P0600G000AV004Woo3`<000<380<00b00C0<P00D300<P0b03@0<P
00<3@08380050d0380<P0b03@0030b020d0BOol201470180100C01804`0B3@0C4P0D0`0E00D0500E
01D05@0D01405@0301H05@0E02/05Pmoo`003Goo6E`00T0000AP05`0G01L009P009L00=P009L0005
@01P05`0H01L0016H00BOol00`800`03000@0`170b001@<00b0380=00`000P<P00<300<P0d000P<0
00<380<00b000`<000H3@0<P0`0380<00b0BOol=018901<01@0@01@0500D01004P0D1P0E00<0500E
01D03`0E0P0F00D0500E01@05P0D00D05P0301@05P0F01l05Pmoo`003Goo6U`00V000e`000AP05`0
G01L00=P009L009P00=L04IP019ooa4304T380030d0380<P00D380030d0380<P00`380030d1oogoo
011oo`0301404P0B00/04P/04aD051/05@0301H05@0F02L05Pmoo`003Goo5U`000=P05`0G0000U`0
00EP05`0G01L060000=L00=P009L0003@01P05`0009L04IP019ooa83044380030d0380<P00H38003
0d0380<P00P380030d0380<P00P3819oo`0301404P0B00X04P/04aP050<05@0301@05@0E01@05@03
01H0500F02H05Pmoo`003Goo7e`000AP05`0G01L00=P009L0004@01P0600G017H00BOolA0`0o0b00
10=00b0380=010<P00<3@0<P0b001`<P0`=00`<P00<3@0<P0b001P<P00<3@7ooOol047oo300B00<0
4`0B01<02P0C0P0D00<04`0D01@04P0D0`0E00<0500E01D04`0E00<05P0E01@00P0F00<05@0F01H0
8P0F3goo000=OolFG0000d00G01L0003H003G0001400G01L05`00f000U`00f0000=L0600H000AF00
4Woo4`<0BP<P00@3@0<00b0380@3@0030b0300<P00@380030d0380<P00<3819oo`0301404P0B00/0
4P0301<04P0C00P04`<0500301<0500D018051T05@0301H05@0F02H05Pmoo`003Goo6E`00V0015`0
00=005`0G0000U`00V000U`0Bf004Woo4P<0AP<P00<3@0<P0b000P<P00<3@0<00b000P<P00T3@0<P
0d0380<00b03@0<P0d001@<P00<3@0<POol04Goo3P0B2`0C00<0500C01@05`0D600E0`0F00<05@0F
01D08P0F3goo000=OolFG0000d00G01L0003H003G0001400H01L05`00f000U`0Bf004Woo40<000<3
80<00`00A0<P00<3@0<P0b0010<P00D300<P0b0380=000L38083@0@380030d0387oo015oo`h04PT0
4`0401@04`0C01<F01@H01D00`0F01D0500201H00`0E01H05P0R01H?Ool000eooaEL0004H01005`0
G003H003G002H002G003H002G004H0001E`0H01P0600G000@V004Woo4`<0D0<P00H3@0<P0b0300<P
0d090b0BOol2014<018=01<401@00`0@01@0500<01@0100E01@05@0D5P0E00<05P0E01D00P0E0`0F
00D05@0F01H05P0D01h05Pmoo`003Goo5U`000A005`0G01L009P00=L0004H01L05`0G003H002G000
0d00H01P0018H00BOol00`<00^03000?0`130b000`<00b0380060b000`<00b03800A0b0BOol3014<
018;01<201@00`0C01@0500C01@00`0E01@05@0I01D201H01@0E01H05P0F01@07P0F3goo000=OolF
G0000d00G01L0003H003G0001600@01L05`0160000AL0400H010009L04IP019ooa@304d380040`03
@0<P0b020`040b020`050b0BOol2010<01800`0C01804`0801<00`0@01@0500F01@00`0E01@05@0F
01D401@201H201@P01H?Ool000eooaIL0003@01L05`000=P00=L0004@01P05`0G003H002G0000d00
H01L0002G016H00BOolC0`1;0b000`<00b03800:0b000`=00b0380040b0BOol2014<01800`0C0180
4`0:01<H01@I01D00`0F01D05P0801H00`0E01H05P0I01H?Ool000eooa]L0005H01L05`0G01P0003
G004H00015`0@01P06000U`0AV004Woo0P;P4P<0A`<P00<3@0<P0b002P<P00D3@0<P0b0380=000D3
819oo`804A004PT04`0301@04`0D01H051X05@805P805@805P0301@05P0F01`05Pmoo`003Goo6U`0
0V000e`000A00600G01L00=P009L0003@01P0600009L04IP019oo`82h1<305L380030d0380<P00<3
819oo`<04@/04P0301<04P0C00L04`0301@04`0C01@0500401D0500D01@H01D00`0D01D05@0201H0
0`0E01H05P0P01H?Ool000eooaYL009P00=L0004H01L05`0G002H003G0000d00H01L0002G003H000
0e`0H01P0010H00BOol00`<00^03000A0`1N0b0BOol4014:018=01<H01@E01D01P0F01D05@0E01H0
5@805P805B405Pmoo`003Goo6U`000=P05`0G0000U`000A005`0G01L009P00=L0003@01P05`0009L
00=P009L045P019oo`030^0300<001<305`3819oo`804@804P0301004P0B00L04P`04`80500401<0
500C010D01@E01D00`0F01D05@0601D01@0F01D05P0F01D0700F3goo000=OolXG0000d00H01L0002
G003H0000e`0@01P0010H00BOol00`;P0`02h00B0`1M0b0BOol4014:018=01<901@00`0C01@0500;
01@00`0E01@05@0301@F01D00`0F01D05P0301D00`0D01H05P0L01H?Ool000eoobQL0003@01P05`0
009L00=P0003G0100600041P019ooaD305d3819oo`@04@d04P/04`0301@04`0D01D0500401D0500D
01@N01DM01H?Ool000eoobeL00=P0003G010060000=P0003G01P060003YP019oo`82h1<300030b03
00<P05X3819oo`@04@`04Pd04`8050050100500D01@04`0@01@00`0E01@0500301@L01D501H201DF
01H?Ool000eooamL0003@01L05`000]L00=P0005G0100600H010000nH00BOol010;P0P0300804`<0
C`<P00<300<P0b002@<P4Woo100A3@0B300C00@0400C0100408050@041<051l05@0501@05P0F01H0
500E01H?Ool000eooamL0003@01L05`000]L00=P0003G0100600041P019oo`<2h1D305X3819oo`@0
4@h04P0301<04P0B00d04`0301@04`0C00<04`030100500D00d0500301D0500E01h05@805P0501D0
5P0F01H05@0501H00`0E01H05P0;01H?Ool000eooaYL0003H01L05`0011L00=P0003G0100600041P
019oo`@2h1H305P3819oo`@04@0301004@0B00h04Q@04`l052H05@0301H05@0E00805P<05@d05Pmo
o`003Goo;E`00f0000=L0600H000@6004Woo0P;P00<300;P0`004@<000<380<00`00F@<P4Woo1P0A
3@0B00<04`0B01<0400C00@0500C01004a0052H05A<05Pmoo`003Goo;U`00V0000=L0400H0000V00
00=L0600H000>f004Woo10;P5@<00`<P00<300<P0b00D`<P4Woo100A00D0400A01404P0A00X04Q<0
4`0301@04`0C014052H05@0301H05@0F00<05P0401@05P0F01D501H0100D01H05P0F3goo003oOonI
Ool00?mooiUoo`00ogooVGoo003oOonIOol00?mooiUoo`00\
\>"],
  ImageRangeCache->{{{0, 407}, {126.5, 0}} -> {-0.0835756, -0.0234425, 
  0.00778171, 0.00778171}, {{10.6875, 131.188}, {123.438, 
  3}} -> {-15.1622, -6.61824, 1.11594, 1.11594}, {{143.25, 263.688}, {
  123.438, 3}} -> {-163.059, -6.61824, 1.11594, 1.11594}, {{275.75, 396.25}, {
  123.438, 3}} -> {-310.957, -6.61824, 1.11594, 1.11594}}]
}, Open  ]],

Cell["Here are the histograms of each of the color channels.", "Caption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[
      GraphicsArray[
        \(ListPlot[Histogram[#], \ PlotJoined -> True, \ PlotRange -> All, \ 
              DisplayFunction -> Identity]\ &\)\ /@\ B[\([1]\)]]]; \)\)], 
  "Input",
  CellLabel->"In[31]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .19314 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.31746 0.00459847 0.31746 [
[ 0 0 0 0 ]
[ 1 .19314 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .19314 L
0 .19314 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.00459847 0.321429 0.188537 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0200747 0.00373483 0.0147151 0.000426216 [
[.20682 .00222 -6 -9 ]
[.20682 .00222 6 0 ]
[.39356 .00222 -9 -9 ]
[.39356 .00222 9 0 ]
[.5803 .00222 -9 -9 ]
[.5803 .00222 9 0 ]
[.76704 .00222 -9 -9 ]
[.76704 .00222 9 0 ]
[.95378 .00222 -9 -9 ]
[.95378 .00222 9 0 ]
[.00757 .09996 -18 -4.5 ]
[.00757 .09996 0 4.5 ]
[.00757 .1852 -18 -4.5 ]
[.00757 .1852 0 4.5 ]
[.00757 .27044 -18 -4.5 ]
[.00757 .27044 0 4.5 ]
[.00757 .35569 -18 -4.5 ]
[.00757 .35569 0 4.5 ]
[.00757 .44093 -24 -4.5 ]
[.00757 .44093 0 4.5 ]
[.00757 .52617 -24 -4.5 ]
[.00757 .52617 0 4.5 ]
[.00757 .61142 -24 -4.5 ]
[.00757 .61142 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.20682 .01472 m
.20682 .02097 L
s
[(50)] .20682 .00222 0 1 Mshowa
.39356 .01472 m
.39356 .02097 L
s
[(100)] .39356 .00222 0 1 Mshowa
.5803 .01472 m
.5803 .02097 L
s
[(150)] .5803 .00222 0 1 Mshowa
.76704 .01472 m
.76704 .02097 L
s
[(200)] .76704 .00222 0 1 Mshowa
.95378 .01472 m
.95378 .02097 L
s
[(250)] .95378 .00222 0 1 Mshowa
.125 Mabswid
.05742 .01472 m
.05742 .01847 L
s
.09477 .01472 m
.09477 .01847 L
s
.13212 .01472 m
.13212 .01847 L
s
.16947 .01472 m
.16947 .01847 L
s
.24416 .01472 m
.24416 .01847 L
s
.28151 .01472 m
.28151 .01847 L
s
.31886 .01472 m
.31886 .01847 L
s
.35621 .01472 m
.35621 .01847 L
s
.43091 .01472 m
.43091 .01847 L
s
.46825 .01472 m
.46825 .01847 L
s
.5056 .01472 m
.5056 .01847 L
s
.54295 .01472 m
.54295 .01847 L
s
.61765 .01472 m
.61765 .01847 L
s
.655 .01472 m
.655 .01847 L
s
.69234 .01472 m
.69234 .01847 L
s
.72969 .01472 m
.72969 .01847 L
s
.80439 .01472 m
.80439 .01847 L
s
.84174 .01472 m
.84174 .01847 L
s
.87908 .01472 m
.87908 .01847 L
s
.91643 .01472 m
.91643 .01847 L
s
.99113 .01472 m
.99113 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02007 .09996 m
.02632 .09996 L
s
[(200)] .00757 .09996 1 0 Mshowa
.02007 .1852 m
.02632 .1852 L
s
[(400)] .00757 .1852 1 0 Mshowa
.02007 .27044 m
.02632 .27044 L
s
[(600)] .00757 .27044 1 0 Mshowa
.02007 .35569 m
.02632 .35569 L
s
[(800)] .00757 .35569 1 0 Mshowa
.02007 .44093 m
.02632 .44093 L
s
[(1000)] .00757 .44093 1 0 Mshowa
.02007 .52617 m
.02632 .52617 L
s
[(1200)] .00757 .52617 1 0 Mshowa
.02007 .61142 m
.02632 .61142 L
s
[(1400)] .00757 .61142 1 0 Mshowa
.125 Mabswid
.02007 .03603 m
.02382 .03603 L
s
.02007 .05734 m
.02382 .05734 L
s
.02007 .07865 m
.02382 .07865 L
s
.02007 .12127 m
.02382 .12127 L
s
.02007 .14258 m
.02382 .14258 L
s
.02007 .16389 m
.02382 .16389 L
s
.02007 .20651 m
.02382 .20651 L
s
.02007 .22782 m
.02382 .22782 L
s
.02007 .24913 m
.02382 .24913 L
s
.02007 .29176 m
.02382 .29176 L
s
.02007 .31307 m
.02382 .31307 L
s
.02007 .33438 m
.02382 .33438 L
s
.02007 .377 m
.02382 .377 L
s
.02007 .39831 m
.02382 .39831 L
s
.02007 .41962 m
.02382 .41962 L
s
.02007 .46224 m
.02382 .46224 L
s
.02007 .48355 m
.02382 .48355 L
s
.02007 .50486 m
.02382 .50486 L
s
.02007 .54748 m
.02382 .54748 L
s
.02007 .5688 m
.02382 .5688 L
s
.02007 .59011 m
.02382 .59011 L
s
.25 Mabswid
.02007 0 m
.02007 .61803 L
s
.5 Mabswid
.02381 .01472 m
.02754 .01472 L
.03128 .01472 L
.03501 .01472 L
.03875 .01472 L
.04248 .01472 L
.04622 .01472 L
.04995 .01472 L
.05369 .01472 L
.05742 .01472 L
.06116 .01472 L
.06489 .01472 L
.06863 .01472 L
.07236 .01472 L
.0761 .01472 L
.07983 .01472 L
.08357 .01472 L
.0873 .01472 L
.09104 .01472 L
.09477 .01472 L
.09851 .01472 L
.10224 .01472 L
.10598 .01472 L
.10971 .01472 L
.11345 .01472 L
.11718 .01472 L
.12092 .01472 L
.12465 .01472 L
.12838 .01472 L
.13212 .01472 L
.13585 .01472 L
.13959 .01472 L
.14332 .01472 L
.14706 .01472 L
.15079 .01472 L
.15453 .01472 L
.15826 .01472 L
.162 .01472 L
.16573 .01472 L
.16947 .01472 L
.1732 .01472 L
.17694 .01472 L
.18067 .01472 L
.18441 .01472 L
.18814 .01472 L
.19188 .01472 L
.19561 .01514 L
.19935 .01599 L
.20308 .0194 L
.20682 .01898 L
Mistroke
.21055 .02537 L
.21429 .02963 L
.21802 .03773 L
.22176 .03517 L
.22549 .03773 L
.22923 .03773 L
.23296 .05009 L
.23669 .04199 L
.24043 .05563 L
.24416 .04498 L
.2479 .05307 L
.25163 .04796 L
.25537 .06245 L
.2591 .05009 L
.26284 .06203 L
.26657 .06586 L
.27031 .05478 L
.27404 .06799 L
.27778 .05819 L
.28151 .05734 L
.28525 .06416 L
.28898 .05734 L
.29272 .06543 L
.29645 .05307 L
.30019 .05435 L
.30392 .04796 L
.30766 .05563 L
.31139 .05435 L
.31513 .04966 L
.31886 .04668 L
.3226 .0437 L
.32633 .04583 L
.33007 .04455 L
.3338 .03901 L
.33754 .03986 L
.34127 .0437 L
.345 .03944 L
.34874 .03816 L
.35247 .04327 L
.35621 .04199 L
.35994 .03134 L
.36368 .03347 L
.36741 .03645 L
.37115 .03603 L
.37488 .03688 L
.37862 .02963 L
.38235 .03645 L
.38609 .03347 L
.38982 .03006 L
.39356 .0275 L
Mistroke
.39729 .03262 L
.40103 .02921 L
.40476 .02537 L
.4085 .03049 L
.41223 .0275 L
.41597 .02665 L
.4197 .02665 L
.42344 .0275 L
.42717 .02452 L
.43091 .02324 L
.43464 .02708 L
.43838 .0258 L
.44211 .03006 L
.44585 .02239 L
.44958 .02494 L
.45331 .02494 L
.45705 .02622 L
.46078 .0258 L
.46452 .02793 L
.46825 .02367 L
.47199 .02452 L
.47572 .02367 L
.47946 .02324 L
.48319 .02622 L
.48693 .02452 L
.49066 .02239 L
.4944 .02367 L
.49813 .02409 L
.50187 .0275 L
.5056 .02537 L
.50934 .02153 L
.51307 .02409 L
.51681 .02239 L
.52054 .02281 L
.52428 .02111 L
.52801 .02494 L
.53175 .0258 L
.53548 .02324 L
.53922 .02324 L
.54295 .02409 L
.54669 .02452 L
.55042 .02281 L
.55415 .02452 L
.55789 .02793 L
.56162 .02537 L
.56536 .02452 L
.56909 .02239 L
.57283 .02452 L
.57656 .02196 L
.5803 .0258 L
Mistroke
.58403 .02708 L
.58777 .02452 L
.5915 .02665 L
.59524 .02835 L
.59897 .02367 L
.60271 .02622 L
.60644 .02835 L
.61018 .02665 L
.61391 .02239 L
.61765 .0275 L
.62138 .02324 L
.62512 .02622 L
.62885 .02494 L
.63259 .02622 L
.63632 .02878 L
.64006 .03091 L
.64379 .0275 L
.64753 .02537 L
.65126 .02835 L
.655 .02921 L
.65873 .03091 L
.66246 .02537 L
.6662 .02963 L
.66993 .03389 L
.67367 .03219 L
.6774 .02878 L
.68114 .03134 L
.68487 .03347 L
.68861 .03219 L
.69234 .03219 L
.69608 .03944 L
.69981 .03176 L
.70355 .04029 L
.70728 .03816 L
.71102 .0454 L
.71475 .04455 L
.71849 .06842 L
.72222 .10294 L
.72596 .17114 L
.72969 .20779 L
.73343 .24828 L
.73716 .32628 L
.7409 .41195 L
.74463 .40939 L
.74837 .60332 L
.7521 .48526 L
.75584 .20864 L
.75957 .14599 L
.76331 .15707 L
.76704 .14514 L
Mistroke
.77077 .1673 L
.77451 .13576 L
.77824 .11743 L
.78198 .12255 L
.78571 .09697 L
.78945 .07225 L
.79318 .08035 L
.79692 .0518 L
.80065 .04839 L
.80439 .03901 L
.80812 .03347 L
.81186 .03603 L
.81559 .03517 L
.81933 .02835 L
.82306 .02239 L
.8268 .0194 L
.83053 .01898 L
.83427 .01472 L
.838 .01514 L
.84174 .01472 L
.84547 .01472 L
.84921 .01472 L
.85294 .01472 L
.85668 .01472 L
.86041 .01472 L
.86415 .01472 L
.86788 .01472 L
.87162 .01472 L
.87535 .01472 L
.87908 .01472 L
.88282 .01472 L
.88655 .01472 L
.89029 .01472 L
.89402 .01472 L
.89776 .01472 L
.90149 .01472 L
.90523 .01472 L
.90896 .01472 L
.9127 .01472 L
.91643 .01472 L
.92017 .01472 L
.9239 .01472 L
.92764 .01472 L
.93137 .01472 L
.93511 .01472 L
.93884 .01472 L
.94258 .01472 L
.94631 .01472 L
.95005 .01472 L
.95378 .01472 L
Mistroke
.95752 .01472 L
.96125 .01472 L
.96499 .01472 L
.96872 .01472 L
.97246 .01472 L
.97619 .01472 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.35119 0.00459847 0.64881 0.188537 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0200747 0.00373483 0.0147151 0.000503942 [
[.20682 .00222 -6 -9 ]
[.20682 .00222 6 0 ]
[.39356 .00222 -9 -9 ]
[.39356 .00222 9 0 ]
[.5803 .00222 -9 -9 ]
[.5803 .00222 9 0 ]
[.76704 .00222 -9 -9 ]
[.76704 .00222 9 0 ]
[.95378 .00222 -9 -9 ]
[.95378 .00222 9 0 ]
[.00757 .1155 -18 -4.5 ]
[.00757 .1155 0 4.5 ]
[.00757 .21629 -18 -4.5 ]
[.00757 .21629 0 4.5 ]
[.00757 .31708 -18 -4.5 ]
[.00757 .31708 0 4.5 ]
[.00757 .41787 -18 -4.5 ]
[.00757 .41787 0 4.5 ]
[.00757 .51866 -24 -4.5 ]
[.00757 .51866 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.20682 .01472 m
.20682 .02097 L
s
[(50)] .20682 .00222 0 1 Mshowa
.39356 .01472 m
.39356 .02097 L
s
[(100)] .39356 .00222 0 1 Mshowa
.5803 .01472 m
.5803 .02097 L
s
[(150)] .5803 .00222 0 1 Mshowa
.76704 .01472 m
.76704 .02097 L
s
[(200)] .76704 .00222 0 1 Mshowa
.95378 .01472 m
.95378 .02097 L
s
[(250)] .95378 .00222 0 1 Mshowa
.125 Mabswid
.05742 .01472 m
.05742 .01847 L
s
.09477 .01472 m
.09477 .01847 L
s
.13212 .01472 m
.13212 .01847 L
s
.16947 .01472 m
.16947 .01847 L
s
.24416 .01472 m
.24416 .01847 L
s
.28151 .01472 m
.28151 .01847 L
s
.31886 .01472 m
.31886 .01847 L
s
.35621 .01472 m
.35621 .01847 L
s
.43091 .01472 m
.43091 .01847 L
s
.46825 .01472 m
.46825 .01847 L
s
.5056 .01472 m
.5056 .01847 L
s
.54295 .01472 m
.54295 .01847 L
s
.61765 .01472 m
.61765 .01847 L
s
.655 .01472 m
.655 .01847 L
s
.69234 .01472 m
.69234 .01847 L
s
.72969 .01472 m
.72969 .01847 L
s
.80439 .01472 m
.80439 .01847 L
s
.84174 .01472 m
.84174 .01847 L
s
.87908 .01472 m
.87908 .01847 L
s
.91643 .01472 m
.91643 .01847 L
s
.99113 .01472 m
.99113 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02007 .1155 m
.02632 .1155 L
s
[(200)] .00757 .1155 1 0 Mshowa
.02007 .21629 m
.02632 .21629 L
s
[(400)] .00757 .21629 1 0 Mshowa
.02007 .31708 m
.02632 .31708 L
s
[(600)] .00757 .31708 1 0 Mshowa
.02007 .41787 m
.02632 .41787 L
s
[(800)] .00757 .41787 1 0 Mshowa
.02007 .51866 m
.02632 .51866 L
s
[(1000)] .00757 .51866 1 0 Mshowa
.125 Mabswid
.02007 .03991 m
.02382 .03991 L
s
.02007 .06511 m
.02382 .06511 L
s
.02007 .09031 m
.02382 .09031 L
s
.02007 .1407 m
.02382 .1407 L
s
.02007 .1659 m
.02382 .1659 L
s
.02007 .19109 m
.02382 .19109 L
s
.02007 .24149 m
.02382 .24149 L
s
.02007 .26669 m
.02382 .26669 L
s
.02007 .29188 m
.02382 .29188 L
s
.02007 .34228 m
.02382 .34228 L
s
.02007 .36747 m
.02382 .36747 L
s
.02007 .39267 m
.02382 .39267 L
s
.02007 .44307 m
.02382 .44307 L
s
.02007 .46826 m
.02382 .46826 L
s
.02007 .49346 m
.02382 .49346 L
s
.02007 .54385 m
.02382 .54385 L
s
.02007 .56905 m
.02382 .56905 L
s
.02007 .59425 m
.02382 .59425 L
s
.25 Mabswid
.02007 0 m
.02007 .61803 L
s
.5 Mabswid
.02381 .01472 m
.02754 .01472 L
.03128 .01472 L
.03501 .01472 L
.03875 .01472 L
.04248 .01472 L
.04622 .01472 L
.04995 .01472 L
.05369 .01472 L
.05742 .01472 L
.06116 .01472 L
.06489 .01472 L
.06863 .01472 L
.07236 .01472 L
.0761 .01472 L
.07983 .01472 L
.08357 .01472 L
.0873 .01472 L
.09104 .01472 L
.09477 .01572 L
.09851 .01623 L
.10224 .01925 L
.10598 .02177 L
.10971 .02278 L
.11345 .02883 L
.11718 .02883 L
.12092 .03739 L
.12465 .04394 L
.12838 .05352 L
.13212 .05049 L
.13585 .06309 L
.13959 .06662 L
.14332 .07468 L
.14706 .06259 L
.15079 .07317 L
.15453 .0772 L
.15826 .06057 L
.162 .06259 L
.16573 .06713 L
.16947 .06964 L
.1732 .06763 L
.17694 .06864 L
.18067 .06561 L
.18441 .06057 L
.18814 .06461 L
.19188 .04898 L
.19561 .06914 L
.19935 .06158 L
.20308 .06813 L
.20682 .05755 L
Mistroke
.21055 .05251 L
.21429 .05654 L
.21802 .06057 L
.22176 .05402 L
.22549 .05352 L
.22923 .06259 L
.23296 .05453 L
.23669 .0515 L
.24043 .05705 L
.24416 .05553 L
.2479 .04697 L
.25163 .05402 L
.25537 .04949 L
.2591 .05402 L
.26284 .04596 L
.26657 .04747 L
.27031 .04999 L
.27404 .04546 L
.27778 .04646 L
.28151 .04243 L
.28525 .04042 L
.28898 .04243 L
.29272 .03588 L
.29645 .03689 L
.30019 .03487 L
.30392 .03739 L
.30766 .03084 L
.31139 .03538 L
.31513 .03487 L
.31886 .03135 L
.3226 .03235 L
.32633 .03084 L
.33007 .03084 L
.3338 .03336 L
.33754 .02782 L
.34127 .02681 L
.345 .02681 L
.34874 .02782 L
.35247 .03084 L
.35621 .02782 L
.35994 .02731 L
.36368 .0253 L
.36741 .02731 L
.37115 .02681 L
.37488 .02883 L
.37862 .02883 L
.38235 .03034 L
.38609 .02731 L
.38982 .02429 L
.39356 .03638 L
Mistroke
.39729 .02832 L
.40103 .02479 L
.40476 .02429 L
.4085 .02983 L
.41223 .02731 L
.41597 .02631 L
.4197 .0258 L
.42344 .02832 L
.42717 .0253 L
.43091 .02479 L
.43464 .02681 L
.43838 .0253 L
.44211 .0253 L
.44585 .02328 L
.44958 .02883 L
.45331 .02983 L
.45705 .0258 L
.46078 .02832 L
.46452 .02681 L
.46825 .02832 L
.47199 .02379 L
.47572 .02429 L
.47946 .02479 L
.48319 .02681 L
.48693 .02983 L
.49066 .02782 L
.4944 .02832 L
.49813 .03386 L
.50187 .03185 L
.5056 .02379 L
.50934 .0258 L
.51307 .02681 L
.51681 .02832 L
.52054 .0253 L
.52428 .02127 L
.52801 .03135 L
.53175 .0253 L
.53548 .02883 L
.53922 .03185 L
.54295 .02883 L
.54669 .0253 L
.55042 .02883 L
.55415 .03034 L
.55789 .02933 L
.56162 .03386 L
.56536 .03135 L
.56909 .02782 L
.57283 .03084 L
.57656 .02832 L
.5803 .02933 L
Mistroke
.58403 .03386 L
.58777 .0379 L
.5915 .03185 L
.59524 .03487 L
.59897 .03386 L
.60271 .03185 L
.60644 .03739 L
.61018 .0379 L
.61391 .03336 L
.61765 .04092 L
.62138 .03588 L
.62512 .03437 L
.62885 .03941 L
.63259 .04092 L
.63632 .03437 L
.64006 .03739 L
.64379 .03286 L
.64753 .04596 L
.65126 .0389 L
.655 .0384 L
.65873 .03991 L
.66246 .04798 L
.6662 .04092 L
.66993 .04294 L
.67367 .04445 L
.6774 .04142 L
.68114 .04646 L
.68487 .04243 L
.68861 .04243 L
.69234 .04898 L
.69608 .04495 L
.69981 .05049 L
.70355 .03538 L
.70728 .04394 L
.71102 .05201 L
.71475 .051 L
.71849 .04646 L
.72222 .04546 L
.72596 .04848 L
.72969 .04646 L
.73343 .06158 L
.73716 .06813 L
.7409 .0898 L
.74463 .11349 L
.74837 .11953 L
.7521 .16741 L
.75584 .20369 L
.75957 .18202 L
.76331 .19765 L
.76704 .2042 L
Mistroke
.77077 .19765 L
.77451 .24905 L
.77824 .26064 L
.78198 .33018 L
.78571 .3191 L
.78945 .36294 L
.79318 .60332 L
.79692 .51009 L
.80065 .12457 L
.80439 .04344 L
.80812 .02883 L
.81186 .01875 L
.81559 .01522 L
.81933 .01472 L
.82306 .01472 L
.8268 .01472 L
.83053 .01472 L
.83427 .01472 L
.838 .01472 L
.84174 .01472 L
.84547 .01472 L
.84921 .01472 L
.85294 .01472 L
.85668 .01472 L
.86041 .01472 L
.86415 .01472 L
.86788 .01472 L
.87162 .01472 L
.87535 .01472 L
.87908 .01472 L
.88282 .01472 L
.88655 .01472 L
.89029 .01472 L
.89402 .01472 L
.89776 .01472 L
.90149 .01472 L
.90523 .01472 L
.90896 .01472 L
.9127 .01472 L
.91643 .01472 L
.92017 .01472 L
.9239 .01472 L
.92764 .01472 L
.93137 .01472 L
.93511 .01472 L
.93884 .01472 L
.94258 .01472 L
.94631 .01472 L
.95005 .01472 L
.95378 .01472 L
Mistroke
.95752 .01472 L
.96125 .01472 L
.96499 .01472 L
.96872 .01472 L
.97246 .01472 L
.97619 .01472 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.678571 0.00459847 0.97619 0.188537 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0200747 0.00373483 0.0147151 0.00159513 [
[.20682 .00222 -6 -9 ]
[.20682 .00222 6 0 ]
[.39356 .00222 -9 -9 ]
[.39356 .00222 9 0 ]
[.5803 .00222 -9 -9 ]
[.5803 .00222 9 0 ]
[.76704 .00222 -9 -9 ]
[.76704 .00222 9 0 ]
[.95378 .00222 -9 -9 ]
[.95378 .00222 9 0 ]
[.00757 .09447 -12 -4.5 ]
[.00757 .09447 0 4.5 ]
[.00757 .17423 -18 -4.5 ]
[.00757 .17423 0 4.5 ]
[.00757 .25398 -18 -4.5 ]
[.00757 .25398 0 4.5 ]
[.00757 .33374 -18 -4.5 ]
[.00757 .33374 0 4.5 ]
[.00757 .4135 -18 -4.5 ]
[.00757 .4135 0 4.5 ]
[.00757 .49325 -18 -4.5 ]
[.00757 .49325 0 4.5 ]
[.00757 .57301 -18 -4.5 ]
[.00757 .57301 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.20682 .01472 m
.20682 .02097 L
s
[(50)] .20682 .00222 0 1 Mshowa
.39356 .01472 m
.39356 .02097 L
s
[(100)] .39356 .00222 0 1 Mshowa
.5803 .01472 m
.5803 .02097 L
s
[(150)] .5803 .00222 0 1 Mshowa
.76704 .01472 m
.76704 .02097 L
s
[(200)] .76704 .00222 0 1 Mshowa
.95378 .01472 m
.95378 .02097 L
s
[(250)] .95378 .00222 0 1 Mshowa
.125 Mabswid
.05742 .01472 m
.05742 .01847 L
s
.09477 .01472 m
.09477 .01847 L
s
.13212 .01472 m
.13212 .01847 L
s
.16947 .01472 m
.16947 .01847 L
s
.24416 .01472 m
.24416 .01847 L
s
.28151 .01472 m
.28151 .01847 L
s
.31886 .01472 m
.31886 .01847 L
s
.35621 .01472 m
.35621 .01847 L
s
.43091 .01472 m
.43091 .01847 L
s
.46825 .01472 m
.46825 .01847 L
s
.5056 .01472 m
.5056 .01847 L
s
.54295 .01472 m
.54295 .01847 L
s
.61765 .01472 m
.61765 .01847 L
s
.655 .01472 m
.655 .01847 L
s
.69234 .01472 m
.69234 .01847 L
s
.72969 .01472 m
.72969 .01847 L
s
.80439 .01472 m
.80439 .01847 L
s
.84174 .01472 m
.84174 .01847 L
s
.87908 .01472 m
.87908 .01847 L
s
.91643 .01472 m
.91643 .01847 L
s
.99113 .01472 m
.99113 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02007 .09447 m
.02632 .09447 L
s
[(50)] .00757 .09447 1 0 Mshowa
.02007 .17423 m
.02632 .17423 L
s
[(100)] .00757 .17423 1 0 Mshowa
.02007 .25398 m
.02632 .25398 L
s
[(150)] .00757 .25398 1 0 Mshowa
.02007 .33374 m
.02632 .33374 L
s
[(200)] .00757 .33374 1 0 Mshowa
.02007 .4135 m
.02632 .4135 L
s
[(250)] .00757 .4135 1 0 Mshowa
.02007 .49325 m
.02632 .49325 L
s
[(300)] .00757 .49325 1 0 Mshowa
.02007 .57301 m
.02632 .57301 L
s
[(350)] .00757 .57301 1 0 Mshowa
.125 Mabswid
.02007 .03067 m
.02382 .03067 L
s
.02007 .04662 m
.02382 .04662 L
s
.02007 .06257 m
.02382 .06257 L
s
.02007 .07852 m
.02382 .07852 L
s
.02007 .11042 m
.02382 .11042 L
s
.02007 .12637 m
.02382 .12637 L
s
.02007 .14233 m
.02382 .14233 L
s
.02007 .15828 m
.02382 .15828 L
s
.02007 .19018 m
.02382 .19018 L
s
.02007 .20613 m
.02382 .20613 L
s
.02007 .22208 m
.02382 .22208 L
s
.02007 .23803 m
.02382 .23803 L
s
.02007 .26994 m
.02382 .26994 L
s
.02007 .28589 m
.02382 .28589 L
s
.02007 .30184 m
.02382 .30184 L
s
.02007 .31779 m
.02382 .31779 L
s
.02007 .34969 m
.02382 .34969 L
s
.02007 .36564 m
.02382 .36564 L
s
.02007 .3816 m
.02382 .3816 L
s
.02007 .39755 m
.02382 .39755 L
s
.02007 .42945 m
.02382 .42945 L
s
.02007 .4454 m
.02382 .4454 L
s
.02007 .46135 m
.02382 .46135 L
s
.02007 .4773 m
.02382 .4773 L
s
.02007 .50921 m
.02382 .50921 L
s
.02007 .52516 m
.02382 .52516 L
s
.02007 .54111 m
.02382 .54111 L
s
.02007 .55706 m
.02382 .55706 L
s
.02007 .58896 m
.02382 .58896 L
s
.02007 .60491 m
.02382 .60491 L
s
.25 Mabswid
.02007 0 m
.02007 .61803 L
s
.5 Mabswid
.02381 .01472 m
.02754 .01472 L
.03128 .01472 L
.03501 .01472 L
.03875 .01472 L
.04248 .01472 L
.04622 .01472 L
.04995 .01472 L
.05369 .01472 L
.05742 .01472 L
.06116 .01472 L
.06489 .01472 L
.06863 .01472 L
.07236 .01472 L
.0761 .01472 L
.07983 .01472 L
.08357 .01472 L
.0873 .01472 L
.09104 .01472 L
.09477 .01472 L
.09851 .01472 L
.10224 .01472 L
.10598 .01472 L
.10971 .01472 L
.11345 .01472 L
.11718 .01472 L
.12092 .01472 L
.12465 .01472 L
.12838 .01472 L
.13212 .01472 L
.13585 .01472 L
.13959 .01472 L
.14332 .01472 L
.14706 .01472 L
.15079 .01472 L
.15453 .01472 L
.15826 .01472 L
.162 .01631 L
.16573 .01472 L
.16947 .0211 L
.1732 .03705 L
.17694 .05778 L
.18067 .10085 L
.18441 .15828 L
.18814 .24441 L
.19188 .29386 L
.19561 .34331 L
.19935 .33374 L
.20308 .41669 L
.20682 .41031 L
Mistroke
.21055 .42147 L
.21429 .52037 L
.21802 .49964 L
.22176 .51878 L
.22549 .55227 L
.22923 .52356 L
.23296 .60332 L
.23669 .49166 L
.24043 .36883 L
.24416 .3162 L
.2479 .30503 L
.25163 .25239 L
.25537 .22846 L
.2591 .24122 L
.26284 .19177 L
.26657 .2476 L
.27031 .22687 L
.27404 .24441 L
.27778 .22687 L
.28151 .26356 L
.28525 .26037 L
.28898 .29546 L
.29272 .33055 L
.29645 .38319 L
.30019 .35129 L
.30392 .46295 L
.30766 .45816 L
.31139 .40233 L
.31513 .30024 L
.31886 .32258 L
.3226 .27472 L
.32633 .20613 L
.33007 .14392 L
.3338 .19497 L
.33754 .13275 L
.34127 .12478 L
.345 .11521 L
.34874 .08012 L
.35247 .09766 L
.35621 .06735 L
.35994 .05778 L
.36368 .04343 L
.36741 .07054 L
.37115 .05938 L
.37488 .053 L
.37862 .04662 L
.38235 .05459 L
.38609 .04024 L
.38982 .04343 L
.39356 .04981 L
Mistroke
.39729 .04183 L
.40103 .03226 L
.40476 .03705 L
.4085 .04183 L
.41223 .03545 L
.41597 .03067 L
.4197 .02429 L
.42344 .03705 L
.42717 .03545 L
.43091 .03545 L
.43464 .02588 L
.43838 .04024 L
.44211 .04821 L
.44585 .03545 L
.44958 .03864 L
.45331 .03545 L
.45705 .03067 L
.46078 .02907 L
.46452 .02907 L
.46825 .0195 L
.47199 .04502 L
.47572 .03545 L
.47946 .02748 L
.48319 .03067 L
.48693 .03864 L
.49066 .03226 L
.4944 .02748 L
.49813 .03864 L
.50187 .0195 L
.5056 .03226 L
.50934 .02588 L
.51307 .04662 L
.51681 .03545 L
.52054 .03705 L
.52428 .04343 L
.52801 .03864 L
.53175 .03067 L
.53548 .03705 L
.53922 .03226 L
.54295 .03067 L
.54669 .03864 L
.55042 .0514 L
.55415 .07533 L
.55789 .08809 L
.56162 .10723 L
.56536 .12318 L
.56909 .13275 L
.57283 .20932 L
.57656 .22368 L
.5803 .29227 L
Mistroke
.58403 .36086 L
.58777 .29227 L
.5915 .3162 L
.59524 .2827 L
.59897 .29227 L
.60271 .27153 L
.60644 .31939 L
.61018 .3162 L
.61391 .35767 L
.61765 .41669 L
.62138 .35288 L
.62512 .36405 L
.62885 .32258 L
.63259 .39117 L
.63632 .30822 L
.64006 .29227 L
.64379 .25877 L
.64753 .20135 L
.65126 .15828 L
.655 .16785 L
.65873 .1822 L
.66246 .24122 L
.6662 .39755 L
.66993 .36724 L
.67367 .3465 L
.6774 .32736 L
.68114 .49804 L
.68487 .43583 L
.68861 .39276 L
.69234 .49645 L
.69608 .40712 L
.69981 .13116 L
.70355 .06895 L
.70728 .03545 L
.71102 .01472 L
.71475 .01472 L
.71849 .01472 L
.72222 .01472 L
.72596 .01472 L
.72969 .01472 L
.73343 .01472 L
.73716 .01472 L
.7409 .01472 L
.74463 .01472 L
.74837 .01472 L
.7521 .01472 L
.75584 .01472 L
.75957 .01472 L
.76331 .01472 L
.76704 .01472 L
Mistroke
.77077 .01472 L
.77451 .01472 L
.77824 .01472 L
.78198 .01472 L
.78571 .01472 L
.78945 .01472 L
.79318 .01472 L
.79692 .01472 L
.80065 .01472 L
.80439 .01472 L
.80812 .01472 L
.81186 .01472 L
.81559 .01472 L
.81933 .01472 L
.82306 .01472 L
.8268 .01472 L
.83053 .01472 L
.83427 .01472 L
.838 .01472 L
.84174 .01472 L
.84547 .01472 L
.84921 .01472 L
.85294 .01472 L
.85668 .01472 L
.86041 .01472 L
.86415 .01472 L
.86788 .01472 L
.87162 .01472 L
.87535 .01472 L
.87908 .01472 L
.88282 .01472 L
.88655 .01472 L
.89029 .01472 L
.89402 .01472 L
.89776 .01472 L
.90149 .01472 L
.90523 .01472 L
.90896 .01472 L
.9127 .01472 L
.91643 .01472 L
.92017 .01472 L
.9239 .01472 L
.92764 .01472 L
.93137 .01472 L
.93511 .01472 L
.93884 .01472 L
.94258 .01472 L
.94631 .01472 L
.95005 .01472 L
.95378 .01472 L
Mistroke
.95752 .01472 L
.96125 .01472 L
.96499 .01472 L
.96872 .01472 L
.97246 .01472 L
.97619 .01472 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[31]:=",
  ImageSize->{413, 79.625},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006M0000Ca000`40O003h00OogooWWoo003oOonN
Ool00?mooiioo`00ogooWWoo003oOonNOol003=oo`03001oogoo009oo`03001oogoo00Eoo`D0009o
o`03001oogoo009oo`03001oogoo009oo`D0009oo`03001oogoo009oo`03001oogoo00Aoo`<000=o
o`03001oogoo009oo`03001oogoo00=oo`<000=oo`03001oogoo009oo`03001oogoo0;Ioo`03001o
ogoo009oo`03001oogoo00Ioo`D0009oo`03001oogoo009oo`03001oogoo00Aoo`D0009oo`03001o
ogoo009oo`03001oogoo00Aoo`<000=oo`03001oogoo009oo`03001oogoo00Eoo`<000=oo`03001o
ogoo009oo`03001oogoo00moo`00<Woo00<007oo00000Woo00<007oo000027oo00L007ooOomoo`00
Ool00002Ool00`00Ool00005Ool01`00Oomoogoo001oo`00009oo`03001oo`0000Eoo`03001oogoo
009oo`03001oo`00009oo`03001oo`0000Aoo`03001oogoo009oo`03001oo`00009oo`03001oo`00
0;Ioo`03001oo`00009oo`03001oo`0000Uoo`07001oogooOol007oo00000Woo00<007oo00001goo
00L007ooOomoo`00Ool00002Ool00`00Ool00005Ool00`00Oomoo`02Ool00`00Ool00002Ool00`00
Ool00006Ool00`00Oomoo`02Ool00`00Ool00002Ool00`00Ool0000@Ool003Aoo`06001oogoo001o
o`0027oo00L007ooOomoo`00Ool00002Ool00`00Ool00005Ool00`00Oomoo`03Ool01P00Oomoo`00
Ool000Ioo`07001oogooOol007oo00000Woo00<007oo00001Goo00<007ooOol00goo00H007ooOol0
07oo000fOol00`00Oomoo`02Ool00`00Oomoo`05Ool50002Ool00`00Oomoo`02Ool00`00Oomoo`03
Ool50002Ool00`00Oomoo`02Ool00`00Oomoo`03Ool30003Ool00`00Oomoo`02Ool00`00Oomoo`04
Ool30003Ool00`00Oomoo`02Ool00`00Oomoo`0aOol01P00Oomoo`00Ool000Uoo`07001oogooOol0
07oo00000Woo00<007oo00001goo00<007ooOol00goo00H007ooOol007oo0006Ool01`00Oomoogoo
001oo`00009oo`03001oo`0000Moo`03001oogoo00=oo`06001oogoo001oo`0047oo000bOol20003
Ool00`00Ool00008Ool01`00Oomoogoo001oo`00009oo`03001oo`0000Eoo`04001oogooOol20003
Ool00`00Ool00006Ool01`00Oomoogoo001oo`00009oo`03001oo`0000Eoo`04001oogooOol20003
Ool00`00Ool0000eOol00`00Ool00002Ool00`00Ool00008Ool01`00Oomoogoo001oo`00009oo`03
001oo`0000Ioo`07001oogooOol007oo00000Woo00<007oo000017oo00<007ooOol00Woo00<007oo
00000Woo00<007oo00001Goo00<007ooOol00Woo00<007oo00000Woo00<007oo0000<7oo0P000goo
00<007oo00002Goo00L007ooOomoo`00Ool00002Ool00`00Ool00007Ool01000Oomoogoo0P000goo
00<007oo00001Woo00L007ooOomoo`00Ool00002Ool00`00Ool00007Ool01000Oomoogoo0P000goo
00<007oo000047oo000bOol00`00Oomoo`02Ool00`00Ool00008Ool01`00Oomoogoo001oo`00009o
o`03001oo`0000Eoo`05001oogooOol00004Ool00`00Ool00005Ool00`00Ool00002Ool00`00Ool0
0002Ool00`00Ool00004Ool00`00Ool00002Ool00`00Oomoo`02Ool00`00Ool0000gOol01P00Oomo
o`00Ool000Qoo`07001oogooOol007oo00000Woo00<007oo00001Woo00<007ooOol00goo00H007oo
Ool007oo0005Ool01`00Oomoogoo001oo`00009oo`03001oo`0000Ioo`03001oogoo00=oo`06001o
ogoo001oo`00<7oo00<007ooOol00Woo00<007oo00002Goo00L007ooOomoo`00Ool00002Ool00`00
Ool00007Ool01@00Oomoogoo000017oo00<007oo00001Goo00<007oo00000Woo00<007oo00000Woo
00<007oo00001Woo00<007oo00000Woo00<007ooOol00Woo00<007oo000047oo000bOol30003Ool0
0`00Oomoo`06Ool20004Ool00`00Oomoo`02Ool00`00Oomoo`03Ool20003Ool30003Ool00`00Oomo
o`05Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`04Ool01000Oomoogoo0`000goo00<0
07ooOol0=7oo0P000goo00<007oo000027oo00L007ooOomoo`00Ool00002Ool00`00Ool00006Ool0
1000Oomoogoo0P000goo00<007oo00001Goo00L007ooOomoo`00Ool00002Ool00`00Ool00006Ool0
1000Oomoogoo0P000goo00<007oo0000<7oo0`000goo00<007ooOol01goo0P0017oo00<007ooOol0
0Woo00<007ooOol01Goo0P000goo0`000goo00<007ooOol01Goo00<007ooOol00Woo00<007ooOol0
0Woo00<007ooOol01Woo00@007ooOomoo`<000=oo`03001oogoo00moo`00]goo00<007ooOol00Woo
00<007oo000027oo00L007ooOomoo`00Ool00002Ool00`00Ool00006Ool01@00Oomoogoo000017oo
00<007oo000017oo00<007oo00000Woo00<007oo00000Woo00<007oo00001Goo00<007oo00000Woo
00<007ooOol00Woo00<007oo0000UGoo002gOol30003Ool00`00Oomoo`06Ool20004Ool00`00Oomo
o`02Ool00`00Oomoo`04Ool20003Ool30003Ool00`00Oomoo`04Ool00`00Oomoo`02Ool00`00Oomo
o`02Ool00`00Oomoo`05Ool01000Oomoogoo0`000goo00<007ooOol0U7oo000UOol00`00Oomoo`3o
Ool2Ool00`00Oomoo`1aOol002=ooeh00:IoofD0015oo`009Goo00@007ooOol000=oo`04001oogoo
0003Ool00`00Oomoo`020002Ool01000Oomoo`000goo00@007ooOol000=ooaX00003Ool007oo009o
o`04001oogoo0003Ool01000Ool000000goo00@007ooOol000=oo`04001oogoo000ZOol00`00Oomo
o`1lOol01@00Oomoogoo00000goo00D007ooOomoo`00009oo`05001oogooOol00003Ool01000Oomo
o`000goo00D007ooOomoo`0000=oo`03001oo`000080009oo`03001oogoo0080009oo`05001oogoo
Ool00003Ool01@00Oomoogoo00000Woo00D007oo001oo`0000=oo`04001oogoo0003Ool01@00Oomo
ogoo00000goo00@007ooOol000=oo`03001oogoo011oo`009Goo00<007ooOol03goo0P002Goo2000
0Woo00<007ooOol02goo0P000Woo200027oo0P00>7ooGP008goo0P003Goo00<007ooOol057oo3`00
47oo00<007ooOol0;7oo000UOol00`00Oomoo`0@Ool30004Ool6000OOol20007Ool00`00Oomoo`0j
Ool01@00Oomoogoo00000Woo10000goo00@007ooOol000=oo`04001oogoo0003Ool00`00Ool0000C
00000goo00000003Ool01000Oomoo`000goo00@007ooOol000=oo`03001oogoo0080009oo`04001o
ogoo0003Ool01000Oomoo`000goo00<007ooOol08Goo0P003Woo00<007ooOol047oo1@0000Moo`00
000007oo001oo`07000?Ool00`00Oomoo`0/Ool002Eoo`03001oogoo015oo`P002Aoo`03001oogoo
00Eoo`03001oogoo03Yoo`03001oogoo00Ioo`03001oogoo00eoo`D00004Ool007ooOol30003Ool0
1000Oomoogoo0P0000Aoo`00001oo`X000Aoo`03001oogoo00Ioo`03001oogoo03=oo`03001oogoo
00eoo`03001oogoo00moo`<00003Ool007oo009oo`03001oogoo00Qoo`03001oogoo00aoo`03001o
ogoo02eoo`009Goo00<007ooOol04goo10009goo00<007ooOol017oo00<007ooOol0>Woo00<007oo
Ool01goo00<007ooOol00goo00<007ooOol00Woo1@007Woo0P0000=oo`0000001P001Woo00<007oo
Ool0<goo0P003Woo00<007ooOol03goo0P004Goo00<007ooOol037oo00<007ooOol0;Goo000FOol3
0003Ool00`00Oomoo`02Ool01@00Oomoogoo0000@7oo00<007ooOol00goo0P00?7oo00<007ooOol0
1goo00D007ooOol007oo00P002Uoo`<000Ioo`03001oogoo02Yoo`03001oogoo009oo`05001oogoo
Ool0000?Ool00`00Oomoo`0?Ool2000BOol00`00Oomoo`0;Ool00`00Oomoo`0]Ool001Ioo`03001o
ogoo009oo`03001oo`00009oo`03001oo`00009oo`03001oogoo03ioo`03001oogoo00=oo`03001o
ogoo03]oo`03001oogoo00Qoo`L0009oo`03001oogoo02aoo`03001oogoo00=oo`03001oogoo02Uo
o`03001oo`00009oo`03001oo`00009oo`8000ioo`03001oogoo00ioo`8001=oo`03001oogoo00]o
o`03001oogoo02eoo`005goo00L007ooOomoo`00Ool00002Ool00`00Ool00002Ool00`00Oomoo`0n
Ool00`00Oomoo`03Ool00`00Oomoo`0kOol00`00Oomoo`09Ool2000eOol00`00Oomoo`03Ool00`00
Oomoo`0[Ool01P00Oomoo`00Ool0009oo`8000ioo`03001oogoo00ioo`03001oogoo019oo`03001o
ogoo00]oo`03001oogoo02eoo`005goo00L007ooOomoo`00Ool00002Ool00`00Ool00002Ool00`00
Oomoo`0nOol00`00Oomoo`03Ool00`00Oomoo`0kOol00`00Oomoo`10Ool00`00Oomoo`03Ool00`00
Oomoo`0YOol20003Ool00`00Ool00002Ool00`00Oomoo`0=Ool00`00Oomoo`0>Ool00`00Oomoo`0B
Ool00`00Oomoo`0;Ool00`00Oomoo`0]Ool001Ioo`03001oo`00009oo`03001oo`00009oo`03001o
o`00009oo`03001oogoo03ioo`03001oogoo009oo`8002ioo`<000=oo`03001oogoo009oo`05001o
ogooOol00012Ool00`00Oomoo`03Ool00`00Oomoo`0YOol00`00Oomoo`02Ool00`00Ool00002Ool2
000>Ool00`00Oomoo`0>Ool00`00Oomoo`0BOol00`00Oomoo`0;Ool00`00Oomoo`0]Ool001Moo`03
001oogoo009oo`03001oogoo009oo`05001oogooOol00010Ool00`00Oomoo`02Ool00`00Oomoo`0]
Ool00`00Oomoo`02Ool00`00Ool00002Ool00`00Ool00002Ool00`00Oomoo`11Ool00`00Oomoo`02
Ool00`00Oomoo`0YOol30003Ool01000Oomoogoo0P003Woo00<007ooOol03Goo00<007ooOol057oo
00<007ooOol02Woo00<007ooOol0;Goo000UOol00`00Oomoo`0oOol00`00Oomoo`02000`Ool01`00
Oomoogoo001oo`00009oo`03001oo`00009oo`80049oo`03001oogoo009oo`03001oogoo03=oo`03
001oogoo00eoo`03001oogoo00eoo`03001oogoo01Aoo`03001oogoo00Yoo`03001oogoo02eoo`00
9Goo00<007ooOol0?goo00<007ooOol00P00<7oo00L007ooOomoo`00Ool00002Ool00`00Ool00002
Ool00`00Oomoo`11Ool00`00Oomoo`02Ool00`00Oomoo`0cOol2000?Ool00`00Oomoo`0;Ool2000F
Ool00`00Oomoo`0:Ool00`00Oomoo`0]Ool001Moo`<0009oo`03001oogoo009oo`05001oogooOol0
0011Ool00`00Oomoo`02000_Ool00`00Ool00002Ool00`00Ool00002Ool00`00Ool00002Ool00`00
Oomoo`11Ool00`00Oomoo`02Ool00`00Oomoo`0SOol50002Ool00`00Oomoo`02Ool01@00Oomoogoo
000047oo00<007ooOol02goo0P005Woo00<007ooOol02Woo00<007ooOol0;Goo000HOol01P00Oomo
o`00Ool0009oo`03001oo`00009oo`03001oogoo03moo`03001oo`00039oo`03001oogoo009oo`03
001oogoo009oo`05001oogooOol00013Ool00`00Oomoo`02Ool00`00Oomoo`0UOol01`00Oomoogoo
001oo`00009oo`03001oo`00009oo`8000moo`03001oogoo00]oo`8001Ioo`03001oogoo00Eoo`03
001oogoo009oo`03001oogoo02eoo`005Woo100000Aoo`00Ool0009oo`03001oo`00009oo`03001o
ogoo03moo`03001oo`00041oo`03001oogoo045oo`03001oogoo009oo`03001oogoo02Eoo`07001o
ogooOol007oo00000Woo00<007oo00000Woo0P003goo00<007ooOol02goo0P005Woo00<007ooOol0
1Goo0P000goo00<007ooOol0;Goo000FOol00`00Ool00002Ool00`00Ool00002Ool00`00Ool00002
Ool00`00Oomoo`0oOol00`00Ool00010Ool00`00Oomoo`11Ool00`00Oomoo`02Ool00`00Oomoo`0U
Ool01`00Oomoogoo001oo`00009oo`03001oo`00009oo`03001oogoo00ioo`03001oogoo00]oo`80
01Ioo`03001oogoo00Eoo`8000=oo`03001oogoo02eoo`005goo0P000Woo00<007oo00000Woo00<0
07oo00000Woo00<007ooOol0?goo00<007oo0000@7oo00<007ooOol0@Goo0P000goo00<007ooOol0
9Goo00L007ooOomoo`00Ool00002Ool00`00Ool00002Ool2000?Ool00`00Oomoo`05Ool00`00Oomo
o`03Ool2000FOol00`00Oomoo`05Ool20003Ool00`00Oomoo`0]Ool001Qoo`05001oogooOol00004
Ool01@00Oomoogoo0000@Goo00<007oo0000<Woo0`000Woo00<007ooOol00Woo00D007ooOomoo`00
04Aoo`80009oo`03001oogoo02Aoo`8000Aoo`03001oogoo009oo`04001oogooOol2000?Ool00`00
Oomoo`05Ool00`00Oomoo`03Ool00`00Oomoo`0EOol00`00Oomoo`05Ool20003Ool00`00Oomoo`0]
Ool002Eoo`03001oogoo03moo`03001oo`0003=oo`06001oogoo001oo`000Woo00<007oo00000Woo
00<007ooOol0@Woo0P000Woo00<007ooOol0<goo00<007ooOol03Woo00<007ooOol01Goo00<007oo
Ool00goo00<007ooOol05Goo00<007ooOol01Goo0P000goo00<007ooOol0;Goo000UOol00`00Oomo
o`0oOol00`00Ool0000aOol4000017oo001oo`000Woo00<007oo00000Woo0P00A7oo00@007ooOol0
03Eoo`8000moo`03001oogoo00Aoo`<000Aoo`03001oogoo01Ioo`03001oogoo00Aoo`8000=oo`03
001oogoo02eoo`005Woo0P0017oo00<007ooOol00Woo00D007ooOomoo`00045oo`03001oo`00035o
o`03001oo`00009oo`03001oo`00009oo`03001oo`00009oo`03001oogoo04=oo`04001oogoo000U
Ool50002Ool00`00Oomoo`02Ool01@00Oomoogoo000047oo00<007ooOol017oo0`0017oo00<007oo
Ool05Woo00<007ooOol00goo00<007oo00000goo00<007ooOol0;Goo000FOol00`00Ool00002Ool0
0`00Ool00002Ool00`00Ool00002Ool00`00Oomoo`0oOol00`00Ool0000bOol20002Ool00`00Ool0
0002Ool00`00Ool00002Ool00`00Oomoo`13Ool01000Oomoo`009goo00L007ooOomoo`00Ool00002
Ool00`00Ool00002Ool2000?Ool00`00Oomoo`03Ool40004Ool00`00Oomoo`0FOol00`00Oomoo`03
Ool00`00Ool00003Ool00`00Oomoo`0]Ool001Ioo`03001oo`00009oo`03001oo`00009oo`03001o
o`00009oo`03001oogoo03moo`03001oo`0003=oo`05001oogooOol00004Ool01@00Oomoogoo0000
AGoo00@007ooOol002Moo`03001oogoo00=oo`06001oogoo001oo`000Woo0P003goo00<007ooOol0
0goo00@007ooOol000Aoo`03001oogoo01Ioo`03001oogoo00=oo`03001oo`0000=oo`03001oogoo
02eoo`005Woo0P000goo00<007oo00000Woo00<007oo00000Woo00<007ooOol0?goo00<007oo0000
@7oo00<007ooOol0A7oo00<007oo00009goo00@007ooOomoo`8000=oo`03001oo`00009oo`03001o
ogoo00ioo`03001oogoo00=oo`03001oogoo008000=oo`03001oogoo01Ioo`03001oogoo00=oo`03
001oo`0000=oo`03001oogoo02eoo`005Woo00<007ooOol00Woo00<007oo00000Woo00<007oo0000
0Woo00<007ooOol0@7oo0P00@7oo00<007ooOol0A7oo00<007oo00009goo00D007ooOomoo`0000Ao
o`03001oo`00009oo`80011oo`03001oogoo009oo`05001oogooOol00003Ool00`00Oomoo`0FOol0
0`00Ool00003Ool00`00Ool00003Ool00`00Oomoo`0]Ool001Moo`8000=oo`03001oogoo009oo`05
001oogooOol00012Ool20010Ool00`00Oomoo`14Ool00`00Ool0000VOol20003Ool30003Ool01000
Oomoogoo0P0047oo00<007ooOol00Woo00D007ooOomoo`0000=oo`03001oogoo01Ioo`03001oo`00
00=oo`03001oo`0000=oo`03001oogoo02eoo`009Goo00<007ooOol0@7oo0P00<Goo0P0017oo00<0
07ooOol00Woo00D007ooOomoo`0004Ioo`03001oo`0003Eoo`03001oogoo00moo`03001oogoo009o
o`05001oogooOol00003Ool00`00Oomoo`0FOol30003Ool00`00Ool00003Ool00`00Oomoo`0]Ool0
02Eoo`03001oogoo041oo`80035oo`03001oo`00009oo`03001oo`00009oo`03001oo`00009oo`03
001oogoo04Aoo`03001oo`0003Eoo`80011oo`03001oogoo009oo`05001oogooOol00002Ool00`00
Oomoo`0GOol200001goo001oogoo001oo`0000=oo`03001oogoo02eoo`005goo00<007ooOol00Woo
00<007ooOol00Woo00D007ooOomoo`00049oo`80035oo`03001oo`00009oo`03001oo`00009oo`03
001oo`00009oo`8004Eoo`8002Moo`<000=oo`03001oogoo009oo`04001oogooOol2000@Ool00`00
Oomoo`02Ool01@00Oomoogoo00000Woo00<007ooOol05goo0P0000Moo`00Oomoo`00Ool00003Ool0
0`00Oomoo`0]Ool001Ioo`03001oo`00009oo`03001oo`00009oo`03001oo`00009oo`03001oogoo
041oo`80035oo`8000=oo`03001oo`00009oo`03001oo`00009oo`03001oogoo04Aoo`8002Moo`03
001oogoo009oo`03001oo`00009oo`03001oo`00009oo`03001oogoo00moo`03001oogoo009oo`03
001oogoo009oo`03001oo`0001Uoo`800003Ool007oo0080009oo`800003Ool007oo02ioo`005Woo
00<007oo00000Woo00<007oo00000Woo00<007oo00000Woo00<007ooOol0@7oo0P00<Goo00<007oo
Ool00Woo00<007oo00000Woo00<007oo00000Woo00<007ooOol0A7oo0P00:7oo00L007ooOomoo`00
Ool00002Ool00`00Ool00002Ool2000@Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Ool0000J
Ool01000Ool007oo0P000Woo0P0000=oo`00Ool0;Woo000GOol01`00Oomoogoo001oo`00009oo`03
001oo`00009oo`03001oogoo041oo`80039oo`8000=oo`03001oogoo009oo`05001oogooOol00016
Ool2000XOol01`00Oomoogoo001oo`00009oo`03001oo`00009oo`03001oogoo00moo`05001oogoo
Ool00005Ool00`00Ool0000JOol00`00Oomoo`030002Ool200000goo001oo`0^Ool001Ioo`03001o
o`00009oo`03001oo`00009oo`03001oo`00009oo`03001oogoo041oo`80041oo`03001oogoo04Eo
o`03001oogoo02Eoo`03001oo`00009oo`03001oo`00009oo`03001oo`00009oo`80011oo`05001o
ogooOol00005Ool2000KOol00`00Oomoo`020003Ool200000goo001oo`0^Ool001Moo`03001oogoo
009oo`03001oogoo009oo`05001oogooOol00012Ool20010Ool00`00Oomoo`15Ool00`00Oomoo`0V
Ool00`00Oomoo`02Ool00`00Oomoo`02Ool01000Oomoogoo0P0047oo00D007ooOomoo`0000Eoo`80
01]oo`03001oogoo008000=oo`800003Ool007oo02ioo`009Goo00<007ooOol0@7oo0P00@7oo00<0
07ooOol0AGoo00<007ooOol0=7oo00<007ooOol03goo00D007ooOomoo`0000Eoo`8001ioo`8000=o
o`800003Ool007oo02ioo`009Goo00<007ooOol0@7oo0P00@7oo00<007ooOol0AGoo00<007ooOol0
=7oo0P004Goo00@007ooOol000Eoo`8001ioo`8000=oo`800003Ool007oo02ioo`0047oo1@000Woo
00<007ooOol00Woo00<007ooOol00Woo00D007ooOomoo`00049oo`80039oo`03001oogoo009oo`03
001oogoo009oo`05001oogooOol00017Ool00`00Oomoo`0UOol30003Ool00`00Oomoo`02Ool01000
Oomoogoo0P004Goo00@007ooOol000Eoo`8001ioo`8000=oo`@002moo`004Woo00L007ooOomoo`00
Ool00002Ool00`00Ool00002Ool00`00Ool00002Ool00`00Oomoo`10Ool2000aOol00`00Ool00002
Ool00`00Ool00002Ool00`00Ool00002Ool00`00Oomoo`15Ool00`00Oomoo`0UOol00`00Oomoo`02
Ool00`00Ool00002Ool00`00Ool00002Ool00`00Oomoo`0@Ool01000Oomoo`001Goo0P007Woo00<0
07ooOol00goo0`00;goo000BOol01`00Oomoogoo001oo`00009oo`03001oo`00009oo`03001oo`00
009oo`03001oogoo041oo`80035oo`03001oo`00009oo`03001oo`00009oo`03001oo`00009oo`80
04Ioo`03001oogoo02Ioo`03001oogoo00=oo`06001oogoo001oo`000Woo0P004Goo00@007ooOol0
00Ioo`03001oogoo01aoo`03001oogoo00=oo`<002moo`004Woo00L007ooOomoo`00Ool00002Ool0
0`00Ool00002Ool00`00Ool00002Ool00`00Oomoo`10Ool2000bOol01`00Oomoogoo001oo`00009o
o`03001oo`00009oo`03001oogoo04Eoo`03001oogoo02Ioo`04001oogooOol20003Ool00`00Ool0
0002Ool00`00Oomoo`0@Ool01000Oomoo`001Woo00<007ooOol08Woo0`00;goo000BOol01`00Oomo
ogoo001oo`00009oo`03001oo`00009oo`03001oo`00009oo`03001oogoo041oo`80035oo`03001o
o`00009oo`03001oo`00009oo`03001oo`00009oo`03001oogoo04Eoo`03001oogoo02Eoo`03001o
o`00009oo`03001oogoo009oo`03001oo`00009oo`80015oo`04001oogoo0006Ool00`00Oomoo`0R
Ool3000_Ool0015oo`8000Aoo`03001oogoo009oo`03001oogoo009oo`05001oogooOol00012Ool2
000bOol00`00Oomoo`02Ool00`00Oomoo`02Ool01@00Oomoogoo0000Agoo00<007ooOol09Woo00@0
07ooOomoo`<000=oo`04001oogooOol2000AOol01000Oomoo`001Woo00<007ooOol08Woo0`00;goo
000UOol00`00Oomoo`10Ool20010Ool00`00Oomoo`15Ool00`00Oomoo`0dOol00`00Oomoo`0@Ool0
1000Oomoo`001Woo00<007ooOol08Woo0P00<7oo000UOol00`00Oomoo`10Ool20010Ool00`00Oomo
o`15Ool00`00Oomoo`0dOol2000AOol01000Oomoo`001Woo00<007ooOol08Woo0P00<7oo000@Ool5
000017oo000000000goo00<007ooOol00Woo00D007ooOomoo`00049oo`80041oo`03001oogoo04Eo
o`03001oogoo02Eoo`8000Aoo`03001oogoo009oo`04001oogooOol2000AOol01000Oomoo`00:goo
0P00<7oo000BOol01@00Oomoogoo000017oo00<007oo00000Woo00<007oo00000Woo00<007ooOol0
@Goo00<007ooOol0:Goo1@000Woo00<007ooOol00Woo00<007ooOol00Woo00D007ooOomoo`0004Mo
o`03001oogoo02Moo`06001oogoo001oo`000Woo00<007oo00000Woo00<007ooOol04Goo00<007oo
0000:goo0P00<7oo000BOol00`00Oomoo`02Ool01`00Oomoogoo001oo`00009oo`03001oo`00009o
o`03001oogoo045oo`03001oogoo02]oo`07001oogooOol007oo00000Woo00<007oo00000Woo00<0
07oo00000Woo00<007ooOol0AGoo00<007ooOol09Woo00L007ooOomoo`00Ool00002Ool00`00Ool0
0002Ool2000BOol00`00Ool0000[Ool2000`Ool0019oo`03001oogoo009oo`07001oogooOol007oo
00000Woo00<007oo00000Woo00<007ooOol0@Goo00<007ooOol0:goo00L007ooOomoo`00Ool00002
Ool00`00Ool00002Ool00`00Ool00002Ool20016Ool00`00Oomoo`0WOol01P00Oomoo`00Ool0009o
o`03001oo`00009oo`80019oo`03001oo`0005eoo`004Woo00L007ooOomoo`00Ool00002Ool00`00
Ool00002Ool00`00Ool00002Ool00`00Oomoo`11Ool00`00Oomoo`0[Ool01`00Oomoogoo001oo`00
009oo`03001oo`00009oo`03001oo`00009oo`03001oogoo04Eoo`03001oogoo02Eoo`03001oo`00
009oo`03001oo`00009oo`03001oo`00009oo`03001oogoo015oo`03001oo`0005eoo`004Goo0P00
17oo00<007ooOol00Woo00<007ooOol00Woo00D007ooOomoo`0004=oo`03001oogoo02]oo`07001o
ogooOol007oo00000Woo00<007oo00000Woo00<007oo00000Woo00<007ooOol0AGoo00<007ooOol0
9Woo00<007ooOol00Woo00<007ooOol00Woo00@007ooOomoo`80019oo`<005eoo`009Goo00<007oo
Ool0@Goo00<007ooOol0:Woo0P0017oo00<007ooOol00Woo00<007ooOol00Woo00D007ooOomoo`00
04Moo`03001oogoo03Aoo`03001oogoo015oo`<005eoo`009Goo00<007ooOol0@Goo00<007ooOol0
?Woo00<007ooOol0AGoo00<007ooOol0=7oo0P004goo0P00GGoo000@Ool50002Ool30002Ool00`00
Oomoo`02Ool01@00Oomoogoo0000@goo00<007ooOol0?Woo00<007ooOol0AGoo00<007ooOol09Goo
0P0017oo00<007ooOol00Woo00@007ooOomoo`8001=oo`8005eoo`004Woo00<007ooOol00goo00H0
07ooOol007oo0002Ool00`00Ool00002Ool00`00Oomoo`11Ool00`00Oomoo`0nOol00`00Oomoo`15
Ool00`00Oomoo`0WOol01P00Oomoo`00Ool0009oo`03001oo`00009oo`03001oogoo019oo`8005eo
o`004Woo00@007ooOomoo`@00004Ool007oo0002Ool00`00Ool00002Ool00`00Oomoo`22Ool00`00
Oomoo`15Ool00`00Oomoo`0VOol00`00Oomoo`03Ool01P00Oomoo`00Ool0009oo`8001Aoo`03001o
ogoo05]oo`004Woo00L007ooOomoo`00Ool00002Ool00`00Ool00002Ool00`00Ool00027Ool00`00
Oomoo`15Ool00`00Oomoo`0WOol00`00Oomoo`020003Ool00`00Ool00002Ool2000DOol00`00Oomo
o`1KOol0019oo`03001oogoo009oo`80009oo`03001oo`00009oo`03001oo`0008Moo`03001oogoo
06eoo`03001oo`00009oo`03001oogoo009oo`03001oo`00009oo`03001oogoo01=oo`03001oogoo
05]oo`004Goo0P001Goo00D007ooOomoo`0000Aoo`03001oogoo0?Moo`04001oogooOol30003Ool0
1000Oomoogoo0P0057oo00<007ooOol0Fgoo003oOolZOol00`00Oomoo`1aOol00?mooiioo`00ogoo
WWoo003oOonNOol00?mooiioo`00\
\>"],
  ImageRangeCache->{{{0, 412}, {78.625, 0}} -> {-0.0940197, -0.0144882, 
  0.00773797, 0.00773797}, {{12.125, 133.25}, {76.75, 
  1.875}} -> {-107.205, -361.699, 2.87489, 25.192}, {{145.375, 266.563}, {
  76.75, 1.875}} -> {-489.94, -346.631, 2.87286, 21.2914}, {{278.688, 
  399.813}, {76.75, 1.875}} -> {-801.924, -90.8512, 2.69163, 6.30218}}]
}, Open  ]]
},
FrontEndVersion->"Microsoft Windows 3.0",
ScreenRectangle->{{0, 1280}, {0, 968}},
WindowToolbars->"EditBar",
CellGrouping->Manual,
WindowSize->{648, 643},
WindowMargins->{{83, Automatic}, {Automatic, 93}},
StyleDefinitions -> "ArticleClassic.nb"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1709, 49, 57, 0, 111, "Title"],
Cell[1769, 51, 35, 0, 41, "Author"],
Cell[1807, 53, 112, 4, 55, "Address"],
Cell[1922, 59, 76, 2, 31, "Input"],
Cell[2001, 63, 93, 2, 31, "Input"],

Cell[CellGroupData[{
Cell[2119, 69, 31, 0, 56, "Section"],
Cell[2153, 71, 601, 9, 95, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2791, 85, 39, 0, 56, "Section"],
Cell[2833, 87, 1730, 41, 246, "Text"],
Cell[4566, 130, 63, 0, 27, "Text"],

Cell[CellGroupData[{
Cell[4654, 134, 224, 5, 51, "Input"],
Cell[4881, 141, 678, 13, 137, "Output"]
}, Open  ]],
Cell[5574, 157, 330, 7, 44, "Text"],
Cell[5907, 166, 66, 0, 27, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[6010, 171, 32, 0, 56, "Section"],
Cell[6045, 173, 246, 6, 44, "Text"],
Cell[6294, 181, 69, 0, 24, "Caption"],

Cell[CellGroupData[{
Cell[6388, 185, 362, 7, 111, "Input"],
Cell[6753, 194, 216795, 8541, 147, 157244, 7801, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],
Cell[223563, 8738, 290, 7, 44, "Text"],
Cell[223856, 8747, 167, 4, 51, "Input"],
Cell[224026, 8753, 887, 19, 112, "Text"],

Cell[CellGroupData[{
Cell[224938, 8776, 395, 8, 111, "Input"],
Cell[225336, 8786, 141928, 2662, 164, 71755, 1790, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[367313, 11454, 34, 0, 56, "Section"],
Cell[367350, 11456, 739, 18, 95, "Text"],
Cell[368092, 11476, 73, 0, 24, "Caption"],

Cell[CellGroupData[{
Cell[368190, 11480, 145, 3, 31, "Input"],
Cell[368338, 11485, 15775, 615, 142, 7613, 509, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],
Cell[384140, 12104, 141, 3, 27, "Text"],
Cell[384284, 12109, 161, 4, 31, "Input"],
Cell[384448, 12115, 89, 2, 24, "Caption"],

Cell[CellGroupData[{
Cell[384562, 12121, 104, 2, 31, "Input"],
Cell[384669, 12125, 371563, 5225, 136, 303528, 4380, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],
Cell[756247, 17353, 73, 0, 24, "Caption"],

Cell[CellGroupData[{
Cell[756345, 17357, 237, 6, 71, "Input"],
Cell[756585, 17365, 41116, 1769, 88, 22909, 1539, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

