(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     22368,        761]*)
(*NotebookOutlinePosition[     23342,        794]*)
(*  CellTagsIndexPosition[     23298,        790]*)
(*WindowFrame->Normal*)



Notebook[{
Cell["ELEMENTS OF MATRIX THEORY", "Title"],

Cell["Mariusz Jankowski", "Author"],

Cell["\<\
Department of Electrical Engineering
University of Southern Maine
mjkcc@usm.maine.edu\
\>", "Address"],

Cell[BoxData[
    \(<< ImageProcessing`\)], "Input"],

Cell[CellGroupData[{

Cell["INTRODUCTION", "Section"],

Cell[TextData[{
  "This notebook introduces basic facts and rules of matrix theory and \
operations. We begin with a short introduction to vectors and matrices in ",
  StyleBox["Mathematica.",
    FontSlant->"Italic"]
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "VECTORS AND MATRICES IN ",
  StyleBox["MATHEMATICA",
    FontSlant->"Italic"]
}], "Section"],

Cell[TextData[{
  "In ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " a list is the fundamental data structure used to group objects together. \
Lists can group any types of objects together and can be nested to any level. \
A simple list of numeric objects is the equivalent of a vector and a list of \
lists with all the sublists of the same length is the equivalent of a matrix. \
A very extensive set of built-in functions is available to form and \
manipulate lists."
}], "Text"],

Cell[TextData[
"Here we form a vector of integers \[ScriptV] and a matrix \[ScriptCapitalM] \
of size 4x4."], "Text"],

Cell[BoxData[
    \(SeedRandom[54321]; \n\[ScriptV] = Table[Random[Integer, {0, 7}], {16}]; 
    \n\[ScriptCapitalM]\  = \ Partition[\[ScriptV], 4]; \)], "Input",
  CellLabel->"In[15]:="],

Cell[TextData[
"Here we test if \[ScriptCapitalM] is indeed a matrix and determine its \
dimensions."], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(MatrixQ[\[ScriptCapitalM]]\)], "Input"],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Dimensions[\[ScriptCapitalM]]\)], "Input"],

Cell[BoxData[
    \({4, 4}\)], "Output"]
}, Open  ]],

Cell["Here we display the matrix in a convenient form.", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[ScriptCapitalM]\  // \ MatrixForm\)], "Input"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", GridBox[{
            {"7", "4", "5", "6"},
            {"3", "2", "7", "4"},
            {"3", "4", "4", "1"},
            {"1", "1", "0", "7"}
            }], ")"}],
      (MatrixForm[ #]&)]], "Output"]
}, Open  ]],

Cell[TextData[{
  "Examples of arithmetic operations (the simple formulations are a \
consequence of the so-called ",
  StyleBox["listable",
    FontSlant->"Italic"],
  " property of the arithmetic operators used here; consult The ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " Book) :"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\({\[ScriptV] - 1, \ \(1\/2\) \[ScriptV], \ \[ScriptV]\^2}\ \)\)], 
  "Input",
  CellLabel->"In[18]:="],

Cell[BoxData[
    \({{6, 3, 4, 5, 2, 1, 6, 3, 2, 3, 3, 0, 0, 0, \(-1\), 6}, {7\/2, 2, 5\/2, 
        3, 3\/2, 1, 7\/2, 2, 3\/2, 2, 2, 1\/2, 1\/2, 1\/2, 0, 7\/2}, {49, 16, 
        25, 36, 9, 4, 49, 16, 9, 16, 16, 1, 1, 1, 0, 49}}\)], "Output",
  CellLabel->"Out[18]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(MatrixForm\ /@
      \ {3*\[ScriptCapitalM]\ , \ Log[N[\[ScriptCapitalM]]]}\)], "Input",
  CellLabel->"In[19]:="],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        TagBox[
          RowBox[{"(", GridBox[{
                {"21", "12", "15", "18"},
                {"9", "6", "21", "12"},
                {"9", "12", "12", "3"},
                {"3", "3", "0", "21"}
                }], ")"}],
          (MatrixForm[ #]&)], ",", 
        TagBox[
          RowBox[{"(", GridBox[{
                {"1.94591014905531327`", "1.38629436111989058`", 
                  "1.60943791243410032`", "1.79175946922805495`"},
                {"1.09861228866810979`", "0.693147180559945308`", 
                  "1.94591014905531327`", "1.38629436111989058`"},
                {"1.09861228866810979`", "1.38629436111989058`", 
                  "1.38629436111989058`", "0.`"},
                {"0.`", "0.`", 
                  InterpretationBox[\(-\[Infinity]\),
                    DirectedInfinity[ -1]], "1.94591014905531327`"}
                }], ")"}],
          (MatrixForm[ #]&)]}], "}"}]], "Output",
  CellLabel->"Out[19]="]
}, Open  ]],

Cell["\<\
Listability extends the use of standard \"scalar\" arithmetic operators to \
vectors, matrices and in general lists. The operands must however have same \
dimensions. Here is an example. \
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(3*\[ScriptCapitalM]\  - \ 
          \[ScriptCapitalM]\)\/\(\[ScriptCapitalM]\^2 + 1\) // MatrixForm\)], 
  "Input"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", GridBox[{
            {\(7\/25\), \(8\/17\), \(5\/13\), \(12\/37\)},
            {\(3\/5\), \(4\/5\), \(7\/25\), \(8\/17\)},
            {\(3\/5\), \(8\/17\), \(8\/17\), "1"},
            {"1", "1", "0", \(7\/25\)}
            }], ")"}],
      (MatrixForm[ #]&)]], "Output"]
}, Open  ]],

Cell["\<\
A huge collection of list construction, manipulation and element extraction \
functions is available. Consult the online help for examples and details.\
\>", "Text"],

Cell[TextData[{
  "A ",
  StyleBox["vector, matrix or tensor product",
    FontSlant->"Italic"],
  " is obtained by using ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "'s ",
  StyleBox["Dot", "Program"],
  " operator. The arrays must have appropriate dimensions. Given a matrix \
\[ScriptCapitalA] with dimensions ",
  Cell[BoxData[
      \(TraditionalForm\`M\ x\ K\)]],
  " and matrix \[ScriptCapitalB] with dimensions ",
  Cell[BoxData[
      \(TraditionalForm\`K\ x\ N\)]],
  ", the elements of a matrix ",
  Cell[BoxData[
      \(TraditionalForm
      \`\[ScriptCapitalC]\  = \ 
        \[ScriptCapitalA]\  . \ \[ScriptCapitalB]\)]],
  " are defined by"
}], "Text"],

Cell[TextData[{
  "\t",
  Cell[BoxData[
      \(TraditionalForm
      \`c(m, n)\  = \ \[Sum]\+\(k = 1\)\%K\( a(m, k)\)\ \(b(k, n)\)\)]]
}], "NumberedEquation"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`c(m, n)\)]],
  " is an element of matrix \[ScriptCapitalC] of dimensions ",
  Cell[BoxData[
      \(TraditionalForm\`M\ x\ N\)]],
  ". Matrix multiplication is not commutative."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \({\((\[ScriptCapitalA]\  = \ Table[a\_\(i, j\), \ {i, 3}, {j, 2}])\) // 
        MatrixForm, \n
      \((\[ScriptCapitalB]\  = \ Table[b\_\(i, j\), \ {i, 2}, {j, 3}])\) // 
        MatrixForm}\)], "Input",
  CellLabel->"In[11]:="],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        TagBox[
          RowBox[{"(", GridBox[{
                {\(a\_\(1, 1\)\), \(a\_\(1, 2\)\)},
                {\(a\_\(2, 1\)\), \(a\_\(2, 2\)\)},
                {\(a\_\(3, 1\)\), \(a\_\(3, 2\)\)}
                }], ")"}],
          (MatrixForm[ #]&)], ",", 
        TagBox[
          RowBox[{"(", GridBox[{
                {\(b\_\(1, 1\)\), \(b\_\(1, 2\)\), \(b\_\(1, 3\)\)},
                {\(b\_\(2, 1\)\), \(b\_\(2, 2\)\), \(b\_\(2, 3\)\)}
                }], ")"}],
          (MatrixForm[ #]&)]}], "}"}]], "Output",
  CellLabel->"Out[11]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[ScriptCapitalA] . \[ScriptCapitalB]\  // MatrixForm\)], "Input",
  CellLabel->"In[12]:="],

Cell[BoxData[
    TagBox[
      RowBox[{"(", GridBox[{
            {\(a\_\(1, 1\)\ b\_\(1, 1\) + a\_\(1, 2\)\ b\_\(2, 1\)\), 
              \(a\_\(1, 1\)\ b\_\(1, 2\) + a\_\(1, 2\)\ b\_\(2, 2\)\), 
              \(a\_\(1, 1\)\ b\_\(1, 3\) + a\_\(1, 2\)\ b\_\(2, 3\)\)},
            {\(a\_\(2, 1\)\ b\_\(1, 1\) + a\_\(2, 2\)\ b\_\(2, 1\)\), 
              \(a\_\(2, 1\)\ b\_\(1, 2\) + a\_\(2, 2\)\ b\_\(2, 2\)\), 
              \(a\_\(2, 1\)\ b\_\(1, 3\) + a\_\(2, 2\)\ b\_\(2, 3\)\)},
            {\(a\_\(3, 1\)\ b\_\(1, 1\) + a\_\(3, 2\)\ b\_\(2, 1\)\), 
              \(a\_\(3, 1\)\ b\_\(1, 2\) + a\_\(3, 2\)\ b\_\(2, 2\)\), 
              \(a\_\(3, 1\)\ b\_\(1, 3\) + a\_\(3, 2\)\ b\_\(2, 3\)\)}
            }], ")"}],
      (MatrixForm[ #]&)]], "Output",
  CellLabel->"Out[12]//MatrixForm="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[ScriptCapitalB] . \[ScriptCapitalA]\  // MatrixForm\)], "Input",
  CellLabel->"In[13]:="],

Cell[BoxData[
    TagBox[
      RowBox[{"(", GridBox[{
            {
              \(a\_\(1, 1\)\ b\_\(1, 1\) + a\_\(2, 1\)\ b\_\(1, 2\) + 
                a\_\(3, 1\)\ b\_\(1, 3\)\), 
              \(a\_\(1, 2\)\ b\_\(1, 1\) + a\_\(2, 2\)\ b\_\(1, 2\) + 
                a\_\(3, 2\)\ b\_\(1, 3\)\)},
            {
              \(a\_\(1, 1\)\ b\_\(2, 1\) + a\_\(2, 1\)\ b\_\(2, 2\) + 
                a\_\(3, 1\)\ b\_\(2, 3\)\), 
              \(a\_\(1, 2\)\ b\_\(2, 1\) + a\_\(2, 2\)\ b\_\(2, 2\) + 
                a\_\(3, 2\)\ b\_\(2, 3\)\)}
            }], ")"}],
      (MatrixForm[ #]&)]], "Output",
  CellLabel->"Out[13]//MatrixForm="]
}, Open  ]],

Cell[TextData[{
  "A ",
  StyleBox["vector inner product",
    FontSlant->"Italic"],
  " is defined "
}], "Text"],

Cell[TextData[{
  "\t",
  Cell[BoxData[
      \(TraditionalForm
      \`\[LeftAngleBracket]\[ScriptX]\ \[ScriptY]\ \[RightAngleBracket]\  = \ 
        \(\[ScriptX]\^T\ \[ScriptY]\  = \ \ 
          \[Sum]\+\(n = 1\)\%\[ScriptCapitalN]\( x(n)\)\ \(y(n)\)\)\)]]
}], "NumberedEquation"],

Cell[TextData[{
  "where the vectors are assumed to be column vectors. The result is a scalar \
quantity. If ",
  Cell[BoxData[
      \(TraditionalForm
      \`\[LeftAngleBracket]\[ScriptX]\ \[ScriptY]\ \[RightAngleBracket] == 0
        \)]],
  ", the vectors \[ScriptX] and \[ScriptY] are called orthogonal."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[ScriptX]\  = \ Table[a\_i, {i, 3}]; \ \ 
    \[ScriptY]\  = \ Table[b\_i, \ {i, 3}]; \n\[ScriptX]\  . \ \[ScriptY]\)], 
  "Input",
  CellLabel->"In[20]:="],

Cell[BoxData[
    \(a\_1\ b\_1 + a\_2\ b\_2 + a\_3\ b\_3\)], "Output",
  CellLabel->"Out[20]="]
}, Open  ]],

Cell[TextData[{
  "The ",
  StyleBox["vector outer product",
    FontSlant->"Italic"],
  " is defined"
}], "Text"],

Cell[TextData[{
  "\t",
  Cell[BoxData[
      \(TraditionalForm\`\(\ 
      \[ScriptX]\ \[ScriptY]\^T\  = \ {\ \(x(n)\)\ \(y(m)\)\ }\)\)]],
  ", \twith ",
  Cell[BoxData[
      \(TraditionalForm\`1 \[LessEqual] n \[LessEqual] N\)]],
  " and  ",
  Cell[BoxData[
      \(TraditionalForm\`1 \[LessEqual] m\  \[LessEqual] M\)]]
}], "NumberedEquation"],

Cell[TextData[{
  "The result is an ",
  Cell[BoxData[
      \(TraditionalForm\`N\ x\ M\)]],
  "  matrix. "
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Outer[Times, \ \[ScriptX], \ \[ScriptY], 1]\  // MatrixForm\)], "Input",\

  CellLabel->"In[21]:="],

Cell[BoxData[
    TagBox[
      RowBox[{"(", GridBox[{
            {\(a\_1\ b\_1\), \(a\_1\ b\_2\), \(a\_1\ b\_3\)},
            {\(a\_2\ b\_1\), \(a\_2\ b\_2\), \(a\_2\ b\_3\)},
            {\(a\_3\ b\_1\), \(a\_3\ b\_2\), \(a\_3\ b\_3\)}
            }], ")"}],
      (MatrixForm[ #]&)]], "Output",
  CellLabel->"Out[21]//MatrixForm="]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["SELECTED RESULTS FROM MATRIX THEORY", "Section"],

Cell[CellGroupData[{

Cell["Transposition and Conjugation Rules", "Subsection"],

Cell[TextData[
"We start with the four basic rules governing transposition and conjugation. \
Given two matrices \[ScriptCapitalA] and \[ScriptCapitalB], we have "], "Text"],

Cell[CellGroupData[{

Cell[TextData[{
  "Rule 1. \t",
  Cell[BoxData[
      \(TraditionalForm
      \`\((\(\[ScriptCapitalA]\^*\))\)\^T\  == \ 
        \(\((\[ScriptCapitalA]\^T)\)\^*\)\)]]
}], "NumberedEquation"],

Cell[TextData[{
  "Rule 2.\t\t",
  Cell[BoxData[
      \(TraditionalForm\`\((\[ScriptCapitalA]\ \[ScriptCapitalB])\)\^T\)]],
  " == ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalB]\^T\ \[ScriptCapitalA]\^T\)]]
}], "NumberedEquation"],

Cell[TextData[{
  "Rule 3.\t\t",
  Cell[BoxData[
      \(TraditionalForm
      \`\((\[ScriptCapitalA]\^\(-1\))\)\^T\  == \ 
        \((\[ScriptCapitalA]\^T)\)\^\(-1\)\)]]
}], "NumberedEquation"],

Cell[TextData[{
  "Rule 4.\t\t",
  Cell[BoxData[
      \(TraditionalForm
      \`\(\((\[ScriptCapitalA]\ \[ScriptCapitalB])\)\^*\)\  == \ 
        \(\[ScriptCapitalA]\^*\) \(\[ScriptCapitalB]\^*\)\)]]
}], "NumberedEquation"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(( . )\)\^*\)\)]],
  " denotes the complex conjugate of the elements of the matrix, ",
  Cell[BoxData[
      \(TraditionalForm\`\(( . )\)\^T\)]],
  " denotes the transpose of a matrix (an interchange of the rows and columns \
of a matrix) and ",
  Cell[BoxData[
      \(TraditionalForm\`\(( . )\)\^\(-1\)\)]],
  " denotes the inverse of a matrix. Given two example matrices \
\[ScriptCapitalA] and \[ScriptCapitalB], we verify Rules 1-4."
}], "Text"],

Cell[BoxData[
    \(\[ScriptCapitalA] = \(1\/\@2\) {{1, I}, {I, 1}}; \ 
    \[ScriptCapitalB] = {{2, 3}, {2 - I, 3 + I}}; \)], "Input",
  CellLabel->"In[22]:="]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \({Transpose[Conjugate[\[ScriptCapitalA]]]\  == \ 
        Conjugate[Transpose[\[ScriptCapitalA]]], \n\t
      Transpose[\[ScriptCapitalA]\  . \ \[ScriptCapitalB]]\  == \ 
        Transpose[\[ScriptCapitalB]] . Transpose[\[ScriptCapitalA]], \n\t
      Transpose[Inverse[\[ScriptCapitalA]]]\  == \ 
        Inverse[Transpose[\[ScriptCapitalA]]], \n\t
      Conjugate[\[ScriptCapitalA] . \[ScriptCapitalB]]\  == \ 
        Conjugate[\[ScriptCapitalA]] . Conjugate[\[ScriptCapitalB]]}\)], 
  "Input",
  CellLabel->"In[23]:="],

Cell[BoxData[
    \({True, True, True, True}\)], "Output",
  CellLabel->"Out[23]="]
}, Open  ]],

Cell[CellGroupData[{

Cell["Symmetric and Hermitian Matrices", "Subsection"],

Cell[TextData[{
  "A matrix is called ",
  StyleBox["symmetric",
    FontSlant->"Italic"],
  " if it is equal to its transpose\n\t\[ScriptCapitalA] == ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalA]\^T\)]]
}], "Theorem"],

Cell[CellGroupData[{

Cell["Problem 3.", "Exercise"],

Cell["Verify which of the given four matrices are symmetric?", "ExerciseText"],

Cell[BoxData[
    \(\[ScriptCapitalA] = \(1\/\@2\) {{1, I}, {I, 1}}; \ 
    \[ScriptCapitalB] = {{2, 3}, {2 - I, 3 + I}}; \n
    \[ScriptCapitalC] = \(1\/\@2\) {{1, 1}, {1, \(-1\)}}; \ 
    \[ScriptCapitalD] = {{\@2, I}, {\(-I\), \@2}}; \)], "Input"]
}, Open  ]],

Cell[TextData[{
  "A matrix \[ScriptCapitalA] is called ",
  StyleBox["Hermitian",
    FontSlant->"Italic"],
  " if element ",
  Cell[BoxData[
      \(TraditionalForm\`a\_\(i, j\)\)]],
  " is the complex conjugate of element ",
  Cell[BoxData[
      \(TraditionalForm\`a\_\(j, i\)\)]],
  ". \n\t\[ScriptCapitalA] == ",
  Cell[BoxData[
      \(TraditionalForm\`\((\(\[ScriptCapitalA]\^*\))\)\^T\)]]
}], "Theorem"],

Cell[CellGroupData[{

Cell["Problem 4.", "Exercise"],

Cell["\<\
Verify which of the matrices given in Problem 3 are hermitian?\
\>", "ExerciseText"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Orthogonal and Unitary Matrices", "Subsection"],

Cell[TextData[{
  "A matrix is called ",
  StyleBox["unitary",
    FontSlant->"Italic"],
  " if its inverse is equal to its conjugate transpose.\n\t",
  Cell[BoxData[
      \(TraditionalForm
      \`\[ScriptCapitalA]\^\(-1\) == \ \((\(\[ScriptCapitalA]\^*\))\)\^T\)]],
  "\nor equivalently,\n\t",
  Cell[BoxData[
      \(TraditionalForm
      \`\((\(\[ScriptCapitalA]\^*\))\)\^T\ \[ScriptCapitalA]\ \  == \ 
        \[ScriptCapitalA]\ \((\(\[ScriptCapitalA]\^*\))\)\^T\  == \ I\)]],
  ".\n",
  Cell[BoxData[
      \(TraditionalForm\`I\)]],
  " is the identity matrix."
}], "Theorem"],

Cell[TextData[{
  "A matrix \[ScriptCapitalA] is called orthogonal if its inverse is equal to \
its transpose.\n\t",
  Cell[BoxData[
      \(TraditionalForm
      \`\[ScriptCapitalA]\^\(-1\)\  == \ \[ScriptCapitalA]\^T\)]],
  "\nor equivalently,\n\t",
  Cell[BoxData[
      \(TraditionalForm
      \`\[ScriptCapitalA]\^T\ \[ScriptCapitalA]\  == 
        \[ScriptCapitalA]\ \[ScriptCapitalA]\^T\  == \ I\)]],
  ".\n ",
  Cell[BoxData[
      \(TraditionalForm\`I\)]],
  " is the identity matrix. "
}], "Theorem"],

Cell["A real orthogonal matrix is also unitary. ", "Text"],

Cell[CellGroupData[{

Cell["Problem 5.", "Exercise"],

Cell["\<\
Verify which of the matrices given in Problem 3 are orthogonal or unitary?\
\>", "ExerciseText"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Toeplitz and Circulant Matrices", "Subsection"],

Cell["\<\
A Toeplitz matrix T is a matrix that has constant elements along the diagonal \
and the sub-diagonals. \
\>", "Theorem"],

Cell[TextData[{
  " An ",
  Cell[BoxData[
      \(TraditionalForm\`N\ x\ N\)]],
  " Toeplitz matrix is completely defined by ",
  Cell[BoxData[
      \(TraditionalForm\`2  N - 1\)]],
  " elements of a list. Each row of the matrix is a right shifted copy of the \
preceding row. Here we build a short list."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[ScriptT] = Table[t\_i, {i, \(-3\), 3}]\)], "Input"],

Cell[BoxData[
    \({t\_\(-3\), t\_\(-2\), t\_\(-1\), t\_0, t\_1, t\_2, t\_3}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(ToeplitzMatrix[\[ScriptT]]\  // MatrixForm\)], "Input"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", GridBox[{
            {\(t\_0\), \(t\_\(-1\)\), \(t\_\(-2\)\), \(t\_\(-3\)\)},
            {\(t\_1\), \(t\_0\), \(t\_\(-1\)\), \(t\_\(-2\)\)},
            {\(t\_2\), \(t\_1\), \(t\_0\), \(t\_\(-1\)\)},
            {\(t\_3\), \(t\_2\), \(t\_1\), \(t\_0\)}
            }], ")"}],
      (MatrixForm[ #]&)]], "Output"]
}, Open  ]],

Cell[TextData[{
  "Toeplitz matrices are important because they describe the input-output \
transformations of one-dimensional linear, shift-invariant systems. A \
convolution operation may therefore be implemented as a matrix product of an \
input vector with a Toeplitz matrix whose diagonal elements are defined by \
the impulse response coefficients of some system (filter). Many linear \
transformations are based on casual, finite impulse response (FIR) filters. \
Such transformations are described by rectangular Toeplitz matrices ",
  Cell[BoxData[
      \(TraditionalForm\`\((N + L - 1)\)\ x\ N\)]],
  ", where ",
  Cell[BoxData[
      \(TraditionalForm\`N\)]],
  " is the length of the input sequence and ",
  Cell[BoxData[
      \(TraditionalForm\`L\)]],
  " the length of the impulse response sequence. Here is a 7 by 5 Toeplitz \
matrix formed from three impulse response coefficients ",
  Cell[BoxData[
      \(TraditionalForm\`{t\_0, \ t\_1, \ t\_2}\)]],
  ". "
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ToeplitzMatrix[Reverse[{t\_0, \ t\_1, \ t\_2}], {7, 5}]\  // MatrixForm
      \)], "Input",
  CellLabel->"In[24]:="],

Cell[BoxData[
    TagBox[
      RowBox[{"(", GridBox[{
            {\(t\_0\), "0", "0", "0", "0"},
            {\(t\_1\), \(t\_0\), "0", "0", "0"},
            {\(t\_2\), \(t\_1\), \(t\_0\), "0", "0"},
            {"0", \(t\_2\), \(t\_1\), \(t\_0\), "0"},
            {"0", "0", \(t\_2\), \(t\_1\), \(t\_0\)},
            {"0", "0", "0", \(t\_2\), \(t\_1\)},
            {"0", "0", "0", "0", \(t\_2\)}
            }], ")"}],
      (MatrixForm[ #]&)]], "Output",
  CellLabel->"Out[24]//MatrixForm="]
}, Open  ]],

Cell[TextData[{
  "A matrix ",
  Cell[BoxData[
      \(TraditionalForm\`C\)]],
  " is called circulant if each of its rows (or columns) is a circular shift \
of the previous row (or column)."
}], "Theorem"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`C\)]],
  " is also Toeplitz. Circulant matrices describe the input-output behavior \
of 1-D linear periodic systems. Therefore circular convolution may be \
formulated as a vector product with a circulant matrix. Here we form an ",
  Cell[BoxData[
      \(TraditionalForm\`N\ x\ N\)]],
  " circulant matrix, with ",
  Cell[BoxData[
      \(TraditionalForm\`N = 6\)]],
  " from elements ",
  Cell[BoxData[
      \(TraditionalForm\`{t\_0, \ t\_1, \ t\_2}\)]],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(CirculantMatrix[Reverse[{t\_0, \ t\_1, \ t\_2}], \ {6, 6}]\  // 
      MatrixForm\)], "Input",
  CellLabel->"In[25]:="],

Cell[BoxData[
    TagBox[
      RowBox[{"(", GridBox[{
            {\(t\_0\), "0", "0", "0", \(t\_2\), \(t\_1\)},
            {\(t\_1\), \(t\_0\), "0", "0", "0", \(t\_2\)},
            {\(t\_2\), \(t\_1\), \(t\_0\), "0", "0", "0"},
            {"0", \(t\_2\), \(t\_1\), \(t\_0\), "0", "0"},
            {"0", "0", \(t\_2\), \(t\_1\), \(t\_0\), "0"},
            {"0", "0", "0", \(t\_2\), \(t\_1\), \(t\_0\)}
            }], ")"}],
      (MatrixForm[ #]&)]], "Output",
  CellLabel->"Out[25]//MatrixForm="]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"Microsoft Windows 3.0",
ScreenRectangle->{{0, 1280}, {0, 968}},
WindowToolbars->"EditBar",
CellGrouping->Manual,
WindowSize->{596, 571},
WindowMargins->{{75, Automatic}, {Automatic, 30}},
PrintingCopies->1,
PrintingPageRange->{Automatic, Automatic},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, -1}},
ShowCellLabel->True,
ShowCellTags->False,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False},
StyleDefinitions -> "ArticleClassic.nb"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1709, 49, 42, 0, 111, "Title"],
Cell[1754, 51, 35, 0, 41, "Author"],
Cell[1792, 53, 112, 4, 55, "Address"],
Cell[1907, 59, 52, 1, 31, "Input"],

Cell[CellGroupData[{
Cell[1984, 64, 31, 0, 56, "Section"],
Cell[2018, 66, 229, 5, 44, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2284, 76, 111, 4, 57, "Section"],
Cell[2398, 82, 495, 10, 78, "Text"],
Cell[2896, 94, 117, 2, 27, "Text"],
Cell[3016, 98, 187, 3, 71, "Input"],
Cell[3206, 103, 111, 2, 27, "Text"],

Cell[CellGroupData[{
Cell[3342, 109, 59, 1, 31, "Input"],
Cell[3404, 112, 38, 1, 30, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3479, 118, 62, 1, 31, "Input"],
Cell[3544, 121, 40, 1, 30, "Output"]
}, Open  ]],
Cell[3599, 125, 64, 0, 27, "Text"],

Cell[CellGroupData[{
Cell[3688, 129, 68, 1, 31, "Input"],
Cell[3759, 132, 249, 8, 73, "Output"]
}, Open  ]],
Cell[4023, 143, 310, 9, 44, "Text"],

Cell[CellGroupData[{
Cell[4358, 156, 123, 3, 43, "Input"],
Cell[4484, 161, 268, 4, 93, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4789, 170, 133, 3, 31, "Input"],
Cell[4925, 175, 1006, 24, 73, "Output"]
}, Open  ]],
Cell[5946, 202, 211, 4, 44, "Text"],

Cell[CellGroupData[{
Cell[6182, 210, 138, 3, 44, "Input"],
Cell[6323, 215, 319, 8, 109, "Output"]
}, Open  ]],
Cell[6657, 226, 175, 3, 44, "Text"],
Cell[6835, 231, 681, 22, 61, "Text"],
Cell[7519, 255, 159, 5, 27, "NumberedEquation"],
Cell[7681, 262, 258, 8, 27, "Text"],

Cell[CellGroupData[{
Cell[7964, 274, 249, 5, 51, "Input"],
Cell[8216, 281, 601, 16, 60, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[8854, 302, 111, 2, 31, "Input"],
Cell[8968, 306, 795, 14, 60, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[9800, 325, 111, 2, 31, "Input"],
Cell[9914, 329, 642, 15, 43, "Output"]
}, Open  ]],
Cell[10571, 347, 113, 5, 27, "Text"],
Cell[10687, 354, 283, 7, 27, "NumberedEquation"],
Cell[10973, 363, 321, 8, 44, "Text"],

Cell[CellGroupData[{
Cell[11319, 375, 177, 4, 51, "Input"],
Cell[11499, 381, 95, 2, 30, "Output"]
}, Open  ]],
Cell[11609, 386, 114, 5, 27, "Text"],
Cell[11726, 393, 347, 11, 27, "NumberedEquation"],
Cell[12076, 406, 119, 5, 27, "Text"],

Cell[CellGroupData[{
Cell[12220, 415, 119, 3, 31, "Input"],
Cell[12342, 420, 336, 8, 57, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[12727, 434, 54, 0, 56, "Section"],

Cell[CellGroupData[{
Cell[12806, 438, 57, 0, 43, "Subsection"],
Cell[12866, 440, 173, 2, 44, "Text"],

Cell[CellGroupData[{
Cell[13064, 446, 191, 6, 27, "NumberedEquation"],
Cell[13258, 454, 246, 7, 27, "NumberedEquation"],
Cell[13507, 463, 194, 6, 27, "NumberedEquation"],
Cell[13704, 471, 224, 6, 27, "NumberedEquation"],
Cell[13931, 479, 522, 13, 61, "Text"],
Cell[14456, 494, 160, 3, 49, "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[14665, 503, 540, 10, 91, "Input"],
Cell[15208, 515, 83, 2, 30, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[15328, 522, 54, 0, 43, "Subsection"],
Cell[15385, 524, 234, 7, 42, "Theorem"],

Cell[CellGroupData[{
Cell[15644, 535, 30, 0, 25, "Exercise"],
Cell[15677, 537, 78, 0, 25, "ExerciseText"],
Cell[15758, 539, 250, 4, 91, "Input"]
}, Open  ]],
Cell[16023, 546, 412, 13, 43, "Theorem"],

Cell[CellGroupData[{
Cell[16460, 563, 30, 0, 25, "Exercise"],
Cell[16493, 565, 94, 2, 25, "ExerciseText"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[16636, 573, 53, 0, 43, "Subsection"],
Cell[16692, 575, 583, 17, 93, "Theorem"],
Cell[17278, 594, 510, 15, 93, "Theorem"],
Cell[17791, 611, 58, 0, 27, "Text"],

Cell[CellGroupData[{
Cell[17874, 615, 30, 0, 25, "Exercise"],
Cell[17907, 617, 106, 2, 25, "ExerciseText"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[18062, 625, 53, 0, 43, "Subsection"],
Cell[18118, 627, 130, 3, 25, "Theorem"],
Cell[18251, 632, 318, 9, 44, "Text"],

Cell[CellGroupData[{
Cell[18594, 645, 73, 1, 31, "Input"],
Cell[18670, 648, 91, 1, 30, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[18798, 654, 75, 1, 31, "Input"],
Cell[18876, 657, 359, 8, 73, "Output"]
}, Open  ]],
Cell[19250, 668, 989, 21, 129, "Text"],

Cell[CellGroupData[{
Cell[20264, 693, 136, 3, 31, "Input"],
Cell[20403, 698, 498, 12, 121, "Output"]
}, Open  ]],
Cell[20916, 713, 206, 6, 25, "Theorem"],
Cell[21125, 721, 532, 15, 61, "Text"],

Cell[CellGroupData[{
Cell[21682, 740, 139, 3, 31, "Input"],
Cell[21824, 745, 504, 11, 105, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

