(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    346525,       7590]*)
(*NotebookOutlinePosition[    347499,       7623]*)
(*  CellTagsIndexPosition[    347455,       7619]*)
(*WindowFrame->Normal*)



Notebook[{
Cell["INTRODUCTION TO LINEAR SYSTEMS AND CONVOLUTION", "Title"],

Cell[TextData[StyleBox[
"Mariusz Jankowski \[Copyright] \nDepartment of Electrical Engineering\n\
University of Southern Maine\nmjkcc@usm.maine.edu"]], "Address"],

Cell[BoxData[
    \(<< ImageProcessing`\)], "Input",
  CellLabel->"In[1]:="],

Cell[CellGroupData[{

Cell["\<\
DIFFERENCE EQUATION FORMULATION OF LINEAR SHIFT INVARIANT SYSTEMS\
\>", "Section"],

Cell[TextData[{
  StyleBox[
  "Differential (continuous time systems) and difference (discrete time \
systems) equations are common representational schemes used in many \
disciplines. For one-dimensional linear time invariant (LTI) systems and \
two-dimensional linear shift invariant (LSI) systems these equations take the \
particularly simple form of constant coefficient differential (and \
difference) equations. Solution methods for one-dimensional constant \
coefficient difference and differential equations are well known and \
computationally simple. The general form of an "],
  StyleBox["M",
    FontSlant->"Italic"],
  StyleBox[
  " th order difference equation representing a one-dimensional LTI system \
is"]
}], "Text"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm
    \`\(a\_0\ y[n]\  + \ \(a\_1\) y[n - 1]\  + \  ... \)\  + 
        \(a\_N\) y[n - M]\  = \ \ 
      \(\(b\_\(0\ \)\) x[n]\  + \(b\_1\) x[n - 1]\  +  ... \) + \ 
        \(b\_M\) x[n - N]\)]]], "NumberedEquation"],

Cell[TextData[{
  "Such an equation is called a recursive equation, since it specifies the \
recursive procedure for determining the outputs in terms of the inputs and \
previous outputs (an equation of this type can also be solved in a manner \
analogous to that for differential equations, giving an explicit solution for \
the output ",
  StyleBox["y[n]",
    FontSlant->"Italic"],
  "). Equation (1) can be written in a manner that explicitly expresses the \
output ",
  StyleBox["y[n]",
    FontSlant->"Italic"],
  " as a function of present and past inputs and past outputs. "
}], "Text"],

Cell[TextData[{
  "\t",
  Cell[BoxData[
      \(TraditionalForm
      \`y[n]\  = \ 
        \[Sum]\+\(i = 0\)\%N \[Beta]\_i\ x[n - i]\  - \ 
          \[Sum]\+\(i = 1\)\%M \[Alpha]\_i\ y[n - i]\)]]
}], "NumberedEquation"],

Cell[TextData[{
  "where coefficients ",
  Cell[BoxData[
      \(TraditionalForm\`\[Alpha]\_i\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`\[Beta]\_i\)]],
  " are equal to ",
  Cell[BoxData[
      \(TraditionalForm\`a\_i\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`b\_i\)]],
  ", respectively, scaled by ",
  Cell[BoxData[
      \(TraditionalForm\`a\_0\)]],
  ". Given the so-called auxiliary conditions defining past ",
  StyleBox["M",
    FontSlant->"Italic"],
  " output values ",
  StyleBox["y[n-1]",
    FontSlant->"Italic"],
  ", ",
  StyleBox["y[n-2]",
    FontSlant->"Italic"],
  ", ... , ",
  StyleBox["y[n-M]",
    FontSlant->"Italic"],
  ", the solution may be obtained by a simple recursive procedure. In the \
special case when ",
  StyleBox["M=0",
    FontSlant->"Italic"],
  ",  (1 and 2) immediately reduce to an explicit function for ",
  StyleBox["y[n]",
    FontSlant->"Italic"],
  " in terms of the present and past values of the input only."
}], "Text"],

Cell[TextData[{
  "\t",
  Cell[BoxData[
      \(TraditionalForm
      \`\(y[n]\  = \ \[Sum]\+\(i = 0\)\%N \[Beta]\_i\ x[n - i]\ \)\)]]
}], "NumberedEquation"],

Cell[TextData[{
  StyleBox[
  "Since the output no longer depends on past output values, (3) is called a \
non-recursive difference equation. A system defined by (3) is also known as a \
"],
  StyleBox["finite impulse response",
    FontSlant->"Italic"],
  StyleBox[" (FIR) system."]
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["ONE-DIMENSIONAL LINEAR CONVOLUTION"]], "Section"],

Cell["\<\
For any one-dimensional LTI system, the system response, or simply the output \
is given by the following relation,\
\>", "Text"],

Cell[TextData[{
  "\t ",
  Cell[BoxData[
      \(TraditionalForm
      \`y[n]\  = 
        \(\[Sum]\+\(i = \(-\[Infinity]\)\)\%\[Infinity] x[i]\ h[n - i]\  = \ 
          \[Sum]\+\(i = \(-\[Infinity]\)\)\%\[Infinity] h[i]\ x[n - i]\)\)]]
}], "NumberedEquation"],

Cell[TextData[{
  StyleBox["where "],
  StyleBox[Cell[BoxData[
      \(TraditionalForm\`h[n]\)]]],
  StyleBox[" is the so-called "],
  StyleBox["impulse response",
    FontSlant->"Italic"],
  StyleBox[", "],
  StyleBox[Cell[BoxData[
      \(TraditionalForm\`x[n]\)]]],
  StyleBox[" the input and "],
  StyleBox[Cell[BoxData[
      \(TraditionalForm\`y[n]\)]]],
  StyleBox[
  " the output of a discrete-time LTI system. Eq. (4) is called the "],
  StyleBox["convolution",
    FontSlant->"Italic"],
  StyleBox[
  " formulation of an LTI system. An LTI system's impulse response is a \
unique property of the system, one that completely characterizes its dynamic \
behaviour. A single output value is computed by summing over all point-wise \
products of one sequence with a time-reversed and shifted version of the \
other. Convolution satisfies the commutative, associative and distributive \
laws of algebra. An important category of discrete-time systems exhibits a \
finite impulse response (FIR), so "],
  StyleBox[Cell[BoxData[
      \(TraditionalForm\`h[n]\)]]],
  StyleBox[" has finite support. It is common to define "],
  StyleBox[Cell[BoxData[
      \(TraditionalForm\`h[n]\)]]],
  StyleBox[" on the interval "],
  StyleBox[Cell[BoxData[
      \(TraditionalForm\`0 \[LessEqual] n \[LessEqual] \ N - 1\)]]],
  StyleBox[". "],
  StyleBox[Cell[BoxData[
      \(TraditionalForm\`h[n]\)]]],
  StyleBox[" is then called a "],
  StyleBox["casual",
    FontSlant->"Italic"],
  StyleBox[" FIR filter of length "],
  StyleBox[Cell[BoxData[
      \(TraditionalForm\`N\)]]],
  StyleBox[".",
    FontSlant->"Italic"],
  StyleBox[" In practice, the sequence "],
  StyleBox[Cell[BoxData[
      \(TraditionalForm\`x[n]\)]]],
  StyleBox[" is also finite in length, so that "],
  StyleBox[Cell[BoxData[
      \(TraditionalForm\`y[n]\)]]],
  StyleBox[" can be computed in finite time. Consider two sequences "],
  StyleBox[Cell[BoxData[
      \(TraditionalForm\`x[n]\)]]],
  StyleBox[" and "],
  StyleBox[Cell[BoxData[
      \(TraditionalForm\`h[n]\)]]],
  StyleBox[", of lengths "],
  StyleBox[Cell[BoxData[
      \(TraditionalForm\`M\)]]],
  StyleBox[" and "],
  StyleBox[Cell[BoxData[
      \(TraditionalForm\`N\)]]],
  StyleBox[", respectively and defined for positive values of "],
  StyleBox["n",
    FontSlant->"Italic"],
  StyleBox[
  " only. Equation (4) then reduces to the following finite summation:"]
}], "Text"],

Cell[TextData[{
  "\t",
  Cell[BoxData[
      \(TraditionalForm
      \`y[n]\  = \ 
        \(\[Sum]\+\(i = 0\)\%\(M - 1\)x[i]\ h[n - i]\  = \ \ 
          \[Sum]\+\(i = 0\)\%\(N - 1\)h[i]\ x[n - i]\)\)]]
}], "NumberedEquation"],

Cell[TextData[{
  StyleBox["with the output sequence "],
  StyleBox[Cell[BoxData[
      \(TraditionalForm\`y[n]\)]]],
  StyleBox["  supported on the finite domain "],
  StyleBox[Cell[BoxData[
      \(TraditionalForm\`0\  \[LessEqual] \ n\  < \ M + N - 1\)]]],
  StyleBox[". Eq. (5) is called a "],
  StyleBox["linear convolution",
    FontSlant->"Italic"],
  StyleBox[
  ". Note that (3) and (5) are equivalent. It is instructive to evaluate the \
sums in (5) given some input "],
  StyleBox[Cell[BoxData[
      \(TraditionalForm\`x[n]\)]]],
  StyleBox[" and impulse response "],
  StyleBox[Cell[BoxData[
      \(TraditionalForm\`h[n]\)]]],
  StyleBox[
  " sequences.\.00\nHere we define two finite length sequences and evaluate \
(5)."]
}], "Text"],

Cell[TextData[StyleBox["Here we define the two sequences:"]], "Caption"],

Cell[BoxData[
    \(\[ScriptX] = Table[x\_i, {i, 0, 5}]; \n
    \[ScriptH] = Table[h\_i, {i, 0, 2}]; \)], "Input",
  CellLabel->"In[8]:="],

Cell[TextData[{
  StyleBox["Here we convolve the two sequences using the function "],
  StyleBox["DiscreteConvolve", "Program"],
  StyleBox[":"]
}], "Caption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(DiscreteConvolve[\[ScriptX], \[ScriptH], Circular -> False] // TableForm
      \)], "Input",
  CellLabel->"In[9]:="],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {\(h\_0\ x\_0\)},
          {\(h\_1\ x\_0 + h\_0\ x\_1\)},
          {\(h\_2\ x\_0 + h\_1\ x\_1 + h\_0\ x\_2\)},
          {\(h\_2\ x\_1 + h\_1\ x\_2 + h\_0\ x\_3\)},
          {\(h\_2\ x\_2 + h\_1\ x\_3 + h\_0\ x\_4\)},
          {\(h\_2\ x\_3 + h\_1\ x\_4 + h\_0\ x\_5\)},
          {\(h\_2\ x\_4 + h\_1\ x\_5\)},
          {\(h\_2\ x\_5\)}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      TableForm[ {
        Times[ 
          Subscript[ h, 0], 
          Subscript[ x, 0]], 
        Plus[ 
          Times[ 
            Subscript[ h, 1], 
            Subscript[ x, 0]], 
          Times[ 
            Subscript[ h, 0], 
            Subscript[ x, 1]]], 
        Plus[ 
          Times[ 
            Subscript[ h, 2], 
            Subscript[ x, 0]], 
          Times[ 
            Subscript[ h, 1], 
            Subscript[ x, 1]], 
          Times[ 
            Subscript[ h, 0], 
            Subscript[ x, 2]]], 
        Plus[ 
          Times[ 
            Subscript[ h, 2], 
            Subscript[ x, 1]], 
          Times[ 
            Subscript[ h, 1], 
            Subscript[ x, 2]], 
          Times[ 
            Subscript[ h, 0], 
            Subscript[ x, 3]]], 
        Plus[ 
          Times[ 
            Subscript[ h, 2], 
            Subscript[ x, 2]], 
          Times[ 
            Subscript[ h, 1], 
            Subscript[ x, 3]], 
          Times[ 
            Subscript[ h, 0], 
            Subscript[ x, 4]]], 
        Plus[ 
          Times[ 
            Subscript[ h, 2], 
            Subscript[ x, 3]], 
          Times[ 
            Subscript[ h, 1], 
            Subscript[ x, 4]], 
          Times[ 
            Subscript[ h, 0], 
            Subscript[ x, 5]]], 
        Plus[ 
          Times[ 
            Subscript[ h, 2], 
            Subscript[ x, 4]], 
          Times[ 
            Subscript[ h, 1], 
            Subscript[ x, 5]]], 
        Times[ 
          Subscript[ h, 2], 
          Subscript[ x, 5]]}]]], "Output",
  CellLabel->"Out[9]//TableForm="]
}, Open  ]],

Cell[TextData[{
  "Note that only the nonzero output samples are returned. The output \
sequence may be subdivided into three subranges. The first two output samples \
represent a \"transient\" portion of the output signal due to a partial \
overlap of nonzero values of the sequences ",
  Cell[BoxData[
      \(TraditionalForm\`x[n]\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`h[n]\)]],
  ". The middle four samples represent a \"steady state\" portion of the \
output sequence (nonzero values of ",
  Cell[BoxData[
      \(TraditionalForm\`x[n]\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`h[n]\)]],
  " are fully overlapped). The last two output samples represent a second \
transient portion of the output sequence, which again is due to a partial \
overlap of the two sequences. The lengths of these transients are always \
given by ",
  Cell[BoxData[
      \(TraditionalForm\`N - 1\)]],
  ", where ",
  StyleBox["N =",
    FontSlant->"Italic"],
  StyleBox["Length[", "Program"],
  StyleBox["h", "Program",
    FontSlant->"Italic"],
  StyleBox["]", "Program"],
  ". A result that excludes the transient samples is sometimes sufficient or \
desirable."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(DiscreteConvolve[\[ScriptX], \ \[ScriptH], \ TransientSamples -> False]
        \  // TableForm\)], "Input",
  CellLabel->"In[10]:="],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {\(h\_2\ x\_0 + h\_1\ x\_1 + h\_0\ x\_2\)},
          {\(h\_2\ x\_1 + h\_1\ x\_2 + h\_0\ x\_3\)},
          {\(h\_2\ x\_2 + h\_1\ x\_3 + h\_0\ x\_4\)},
          {\(h\_2\ x\_3 + h\_1\ x\_4 + h\_0\ x\_5\)}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      TableForm[ {
        Plus[ 
          Times[ 
            Subscript[ h, 2], 
            Subscript[ x, 0]], 
          Times[ 
            Subscript[ h, 1], 
            Subscript[ x, 1]], 
          Times[ 
            Subscript[ h, 0], 
            Subscript[ x, 2]]], 
        Plus[ 
          Times[ 
            Subscript[ h, 2], 
            Subscript[ x, 1]], 
          Times[ 
            Subscript[ h, 1], 
            Subscript[ x, 2]], 
          Times[ 
            Subscript[ h, 0], 
            Subscript[ x, 3]]], 
        Plus[ 
          Times[ 
            Subscript[ h, 2], 
            Subscript[ x, 2]], 
          Times[ 
            Subscript[ h, 1], 
            Subscript[ x, 3]], 
          Times[ 
            Subscript[ h, 0], 
            Subscript[ x, 4]]], 
        Plus[ 
          Times[ 
            Subscript[ h, 2], 
            Subscript[ x, 3]], 
          Times[ 
            Subscript[ h, 1], 
            Subscript[ x, 4]], 
          Times[ 
            Subscript[ h, 0], 
            Subscript[ x, 5]]]}]]], "Output",
  CellLabel->"Out[10]//TableForm="]
}, Open  ]],

Cell["\<\
The convolution summation of two finite-length sequences (5) may also be \
formulated using a matrix dot product operations: \
\>", "Text"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm
    \`\[ScriptY]\  = \ \[ScriptCapitalT]\  . \ \[ScriptX]\)]]], 
  "NumberedEquation"],

Cell[TextData[{
  "where the matrix ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalT]\)]],
  " (called a ",
  StyleBox["Toeplitz",
    FontSlant->"Italic"],
  " matrix) has a special diagonal structure. The elements on the diagonals \
of matrix \[ScriptCapitalT] come from the samples of the impulse response ",
  Cell[BoxData[
      \(TraditionalForm\`h[n]\)]],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[ScriptCapitalT] = ToeplitzMatrix[Reverse[\[ScriptH]], {8, 6}]; \n
    MatrixForm[\[ScriptCapitalT]]\)], "Input",
  CellLabel->"In[13]:="],

Cell[BoxData[
    TagBox[
      RowBox[{"(", GridBox[{
            {\(h\_0\), "0", "0", "0", "0", "0"},
            {\(h\_1\), \(h\_0\), "0", "0", "0", "0"},
            {\(h\_2\), \(h\_1\), \(h\_0\), "0", "0", "0"},
            {"0", \(h\_2\), \(h\_1\), \(h\_0\), "0", "0"},
            {"0", "0", \(h\_2\), \(h\_1\), \(h\_0\), "0"},
            {"0", "0", "0", \(h\_2\), \(h\_1\), \(h\_0\)},
            {"0", "0", "0", "0", \(h\_2\), \(h\_1\)},
            {"0", "0", "0", "0", "0", \(h\_2\)}
            }], ")"}],
      (MatrixForm[ #]&)]], "Output",
  CellLabel->"Out[13]//MatrixForm="]
}, Open  ]],

Cell["Note that Toeplitz matrices have constant diagonals. ", "Text"],

Cell[BoxData[
    \(\(\((\[ScriptY] = \[ScriptCapitalT] . \[ScriptX])\)\  // TableForm\n
    \)\)], "Input",
  CellLabel->"In[14]:="],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {\(h\_0\ x\_0\)},
          {\(h\_1\ x\_0 + h\_0\ x\_1\)},
          {\(h\_2\ x\_0 + h\_1\ x\_1 + h\_0\ x\_2\)},
          {\(h\_2\ x\_1 + h\_1\ x\_2 + h\_0\ x\_3\)},
          {\(h\_2\ x\_2 + h\_1\ x\_3 + h\_0\ x\_4\)},
          {\(h\_2\ x\_3 + h\_1\ x\_4 + h\_0\ x\_5\)},
          {\(h\_2\ x\_4 + h\_1\ x\_5\)},
          {\(h\_2\ x\_5\)}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      TableForm[ {
        Times[ 
          Subscript[ h, 0], 
          Subscript[ x, 0]], 
        Plus[ 
          Times[ 
            Subscript[ h, 1], 
            Subscript[ x, 0]], 
          Times[ 
            Subscript[ h, 0], 
            Subscript[ x, 1]]], 
        Plus[ 
          Times[ 
            Subscript[ h, 2], 
            Subscript[ x, 0]], 
          Times[ 
            Subscript[ h, 1], 
            Subscript[ x, 1]], 
          Times[ 
            Subscript[ h, 0], 
            Subscript[ x, 2]]], 
        Plus[ 
          Times[ 
            Subscript[ h, 2], 
            Subscript[ x, 1]], 
          Times[ 
            Subscript[ h, 1], 
            Subscript[ x, 2]], 
          Times[ 
            Subscript[ h, 0], 
            Subscript[ x, 3]]], 
        Plus[ 
          Times[ 
            Subscript[ h, 2], 
            Subscript[ x, 2]], 
          Times[ 
            Subscript[ h, 1], 
            Subscript[ x, 3]], 
          Times[ 
            Subscript[ h, 0], 
            Subscript[ x, 4]]], 
        Plus[ 
          Times[ 
            Subscript[ h, 2], 
            Subscript[ x, 3]], 
          Times[ 
            Subscript[ h, 1], 
            Subscript[ x, 4]], 
          Times[ 
            Subscript[ h, 0], 
            Subscript[ x, 5]]], 
        Plus[ 
          Times[ 
            Subscript[ h, 2], 
            Subscript[ x, 4]], 
          Times[ 
            Subscript[ h, 1], 
            Subscript[ x, 5]]], 
        Times[ 
          Subscript[ h, 2], 
          Subscript[ x, 5]]}]]], "Output",
  CellLabel->"Out[14]//TableForm="]
}, Open  ]],

Cell[CellGroupData[{

Cell["TWO-DIMENSIONAL LINEAR CONVOLUTION", "Section"],

Cell["\<\
FIR systems play an especially important role in two-dimensional systems \
since general solutions to (1) and (2) do not easily extend to higher \
dimensions.  In digital image processing, many useful operators (i.e. edge \
detectors) are linear with finite support. Two-dimensional FIR convolution \
sum takes the following form:\
\>", "Text"],

Cell[TextData[{
  " ",
  Cell[BoxData[
      \(TraditionalForm
      \`y[n\_1, n\_2]\  = 
        \[Sum]\+\(i = 0\)\%\(N\_1 - 1\)\ \ 
          \(\[Sum]\+\(j = 0\)\%\(N\_2 - 1\)h[i, j]\ 
              \[CenterDot]x[n\_1 - i, n\_2 - j]\)\)]],
  ", \t",
  Cell[BoxData[
      \(TraditionalForm\`0 \[LessEqual] n\_1 \[LessEqual] M\_1 - 1, \ 
      0 \[LessEqual] n\_2 \[LessEqual] M\_2 - 1\)]]
}], "NumberedEquation"],

Cell["\<\
The convolution operator in (6) has a number of properties that are \
straightforward extensions of one-dimensional results. It is commutative, \
associative and distributive. In the special, but frequent, case when the \
impulse response sequence is separable, meaning that it may defined as,\
\>", "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`h[n\_1, \ n\_2]\  = \ h\_1[n\_1]\ h\_2[n\_2]\)]],
  ",",
  "\tfor \t",
  Cell[BoxData[
      \(TraditionalForm\`0 \[LessEqual] n\_1 \[LessEqual] N\_1 - 1, \ \ 
      0 \[LessEqual] n\_2 \[LessEqual] N\_2 - 1\)]]
}], "NumberedEquation"],

Cell["\<\
Equation (7) may computed by a sequence of two one-dimensional convolutions, \
leading to a computational speed-up of about a factor of 2. It is easiest to \
visualize convolution with a separable filter as 1-D column convolutions \
followed by 1-D row convolutions. In matrix notation, this may be succintly \
expressed as,\
\>", "Text"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`\(\ 
    \[ScriptCapitalX]\ *\ \[ScriptCapitalH]\  = \ 
      \[ScriptCapitalT]\_\(h\_1\)\  . \ \[ScriptCapitalX]\  . \ 
        \[ScriptCapitalT]\_\(h\_2\)\^T\)\)]]], "NumberedEquation"],

Cell[TextData[{
  "where \[ScriptCapitalX] is the image matrix, \[ScriptCapitalH] is the 2-D \
filter, '*' denotes convolution and ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalT]\_\(h\_1\)\)]],
  ",  ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalT]\_\(h\_2\)\)]],
  " are Toeplitz matrices formed from the coefficients of the impulse \
response sequences ",
  Cell[BoxData[
      \(TraditionalForm\`h\_1[n]\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`h\_2[n]\)]],
  ". The matrix product ",
  Cell[BoxData[
      \(TraditionalForm
      \`\[ScriptCapitalX]\  . \ \[ScriptCapitalT]\_\(h\_2\)\^T\)]],
  " (",
  Cell[BoxData[
      \(TraditionalForm\`\(( . )\)\^T\)]],
  " stands for the transpose) is a row operation, while the left-sided dot \
product implements the column convolutions."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["PERIODIC AND CIRCULAR CONVOLUTION", "Section"],

Cell[TextData[{
  StyleBox[
  "It is important to realize that two additional convolution formulations \
can be found in the signal processing literature. The first is called "],
  StyleBox["periodic convolution",
    FontSlant->"Italic"],
  StyleBox[
  " and defines a convolution operation for periodic sequences. Assuming two \
sequences "],
  StyleBox[Cell[BoxData[
      \(TraditionalForm\`x\&~[n]\)]]],
  StyleBox[" and "],
  StyleBox[Cell[BoxData[
      \(TraditionalForm\`h\&~[n]\)]]],
  StyleBox["  have periods "],
  StyleBox["M",
    FontSlant->"Italic"],
  StyleBox[" and "],
  StyleBox["N,",
    FontSlant->"Italic"],
  StyleBox[" respectively, i.e. "],
  StyleBox[Cell[BoxData[
      \(TraditionalForm\`x\&~[n]\  = \ x\&~[n + M]\)]]],
  StyleBox[" and "],
  StyleBox[Cell[BoxData[
      \(TraditionalForm\`h\&~[n]\  = \ h\&~[n + N]\)]]],
  StyleBox[", we define periodic convolution of the two sequences as:"]
}], "Text"],

Cell[TextData[{
  "\t",
  Cell[BoxData[
      \(TraditionalForm
      \`y\&~[n]\  = \ 
        \(\[Sum]\+\(i = 0\)\%\(M - 1\)x\&~[i]\ \ h\&~[n - i]\  = \ \ 
          \[Sum]\+\(i = 0\)\%\(N - 1\)h\&~[i]\ \ x\&~[n - i]\)\)]],
  "\t"
}], "NumberedEquation"],

Cell[TextData[{
  StyleBox["The output sequence "],
  StyleBox[Cell[BoxData[
      \(TraditionalForm\`y\&~[n]\)]]],
  StyleBox[" is also periodic with period "],
  StyleBox[Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["Min",
            "Program"], "[", \(N, \ M\), "]"}], TraditionalForm]]]],
  StyleBox[
  ". Equation (7) looks very much like linear convolution and involves the \
summation of the products of one sequence with the time-reversed and shifted \
copy of the other. However, the sequences in (7) are all periodic and shifts \
of such sequences produce results different from shifts of finite-duration \
signals."]
}], "Text"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0147151 0.47619 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0147151 0.477324 0.295003 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.28355 0.0865801 0.0147151 0.117721 [
[.11039 .00222 -6 -9 ]
[.11039 .00222 6 0 ]
[.45671 .00222 -3 -9 ]
[.45671 .00222 3 0 ]
[.62987 .00222 -3 -9 ]
[.62987 .00222 3 0 ]
[.80303 .00222 -3 -9 ]
[.80303 .00222 3 0 ]
[.97619 .00222 -3 -9 ]
[.97619 .00222 3 0 ]
[.27105 .13244 -6 -4.5 ]
[.27105 .13244 0 4.5 ]
[.27105 .25016 -6 -4.5 ]
[.27105 .25016 0 4.5 ]
[.27105 .36788 -6 -4.5 ]
[.27105 .36788 0 4.5 ]
[.27105 .4856 -6 -4.5 ]
[.27105 .4856 0 4.5 ]
[.27105 .60332 -6 -4.5 ]
[.27105 .60332 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.11039 .01472 m
.11039 .02097 L
s
[(-2)] .11039 .00222 0 1 Mshowa
.45671 .01472 m
.45671 .02097 L
s
[(2)] .45671 .00222 0 1 Mshowa
.62987 .01472 m
.62987 .02097 L
s
[(4)] .62987 .00222 0 1 Mshowa
.80303 .01472 m
.80303 .02097 L
s
[(6)] .80303 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(8)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.15368 .01472 m
.15368 .01847 L
s
.19697 .01472 m
.19697 .01847 L
s
.24026 .01472 m
.24026 .01847 L
s
.32684 .01472 m
.32684 .01847 L
s
.37013 .01472 m
.37013 .01847 L
s
.41342 .01472 m
.41342 .01847 L
s
.5 .01472 m
.5 .01847 L
s
.54329 .01472 m
.54329 .01847 L
s
.58658 .01472 m
.58658 .01847 L
s
.67316 .01472 m
.67316 .01847 L
s
.71645 .01472 m
.71645 .01847 L
s
.75974 .01472 m
.75974 .01847 L
s
.84632 .01472 m
.84632 .01847 L
s
.88961 .01472 m
.88961 .01847 L
s
.9329 .01472 m
.9329 .01847 L
s
.0671 .01472 m
.0671 .01847 L
s
.02381 .01472 m
.02381 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.28355 .13244 m
.2898 .13244 L
s
[(1)] .27105 .13244 1 0 Mshowa
.28355 .25016 m
.2898 .25016 L
s
[(2)] .27105 .25016 1 0 Mshowa
.28355 .36788 m
.2898 .36788 L
s
[(3)] .27105 .36788 1 0 Mshowa
.28355 .4856 m
.2898 .4856 L
s
[(4)] .27105 .4856 1 0 Mshowa
.28355 .60332 m
.2898 .60332 L
s
[(5)] .27105 .60332 1 0 Mshowa
.125 Mabswid
.28355 .03826 m
.2873 .03826 L
s
.28355 .0618 m
.2873 .0618 L
s
.28355 .08535 m
.2873 .08535 L
s
.28355 .10889 m
.2873 .10889 L
s
.28355 .15598 m
.2873 .15598 L
s
.28355 .17952 m
.2873 .17952 L
s
.28355 .20307 m
.2873 .20307 L
s
.28355 .22661 m
.2873 .22661 L
s
.28355 .2737 m
.2873 .2737 L
s
.28355 .29724 m
.2873 .29724 L
s
.28355 .32079 m
.2873 .32079 L
s
.28355 .34433 m
.2873 .34433 L
s
.28355 .39142 m
.2873 .39142 L
s
.28355 .41497 m
.2873 .41497 L
s
.28355 .43851 m
.2873 .43851 L
s
.28355 .46205 m
.2873 .46205 L
s
.28355 .50914 m
.2873 .50914 L
s
.28355 .53269 m
.2873 .53269 L
s
.28355 .55623 m
.2873 .55623 L
s
.28355 .57977 m
.2873 .57977 L
s
.25 Mabswid
.28355 0 m
.28355 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.0068 w
.02381 .01472 m
.02381 .01472 L
s
.11039 .01472 m
.11039 .01472 L
s
.19697 .01472 m
.19697 .01472 L
s
.28355 .01472 m
.28355 .01472 L
s
.37013 .01472 m
.37013 .01472 L
s
.45671 .01472 m
.45671 .01472 L
s
.54329 .01472 m
.54329 .13244 L
s
.62987 .01472 m
.62987 .25016 L
s
.71645 .01472 m
.71645 .36788 L
s
.80303 .01472 m
.80303 .4856 L
s
.88961 .01472 m
.88961 .60332 L
s
.97619 .01472 m
.97619 .01472 L
s
.05 w
.02381 .01472 Mdot
.11039 .01472 Mdot
.19697 .01472 Mdot
.28355 .01472 Mdot
.37013 .01472 Mdot
.45671 .01472 Mdot
.54329 .13244 Mdot
.62987 .25016 Mdot
.71645 .36788 Mdot
.80303 .4856 Mdot
.88961 .60332 Mdot
.97619 .01472 Mdot
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0147151 0.97619 0.295003 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.28355 0.0865801 0.0147151 0.117721 [
[.11039 .00222 -6 -9 ]
[.11039 .00222 6 0 ]
[.45671 .00222 -3 -9 ]
[.45671 .00222 3 0 ]
[.62987 .00222 -3 -9 ]
[.62987 .00222 3 0 ]
[.80303 .00222 -3 -9 ]
[.80303 .00222 3 0 ]
[.97619 .00222 -3 -9 ]
[.97619 .00222 3 0 ]
[.27105 .13244 -6 -4.5 ]
[.27105 .13244 0 4.5 ]
[.27105 .25016 -6 -4.5 ]
[.27105 .25016 0 4.5 ]
[.27105 .36788 -6 -4.5 ]
[.27105 .36788 0 4.5 ]
[.27105 .4856 -6 -4.5 ]
[.27105 .4856 0 4.5 ]
[.27105 .60332 -6 -4.5 ]
[.27105 .60332 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.11039 .01472 m
.11039 .02097 L
s
[(-2)] .11039 .00222 0 1 Mshowa
.45671 .01472 m
.45671 .02097 L
s
[(2)] .45671 .00222 0 1 Mshowa
.62987 .01472 m
.62987 .02097 L
s
[(4)] .62987 .00222 0 1 Mshowa
.80303 .01472 m
.80303 .02097 L
s
[(6)] .80303 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(8)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.15368 .01472 m
.15368 .01847 L
s
.19697 .01472 m
.19697 .01847 L
s
.24026 .01472 m
.24026 .01847 L
s
.32684 .01472 m
.32684 .01847 L
s
.37013 .01472 m
.37013 .01847 L
s
.41342 .01472 m
.41342 .01847 L
s
.5 .01472 m
.5 .01847 L
s
.54329 .01472 m
.54329 .01847 L
s
.58658 .01472 m
.58658 .01847 L
s
.67316 .01472 m
.67316 .01847 L
s
.71645 .01472 m
.71645 .01847 L
s
.75974 .01472 m
.75974 .01847 L
s
.84632 .01472 m
.84632 .01847 L
s
.88961 .01472 m
.88961 .01847 L
s
.9329 .01472 m
.9329 .01847 L
s
.0671 .01472 m
.0671 .01847 L
s
.02381 .01472 m
.02381 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.28355 .13244 m
.2898 .13244 L
s
[(1)] .27105 .13244 1 0 Mshowa
.28355 .25016 m
.2898 .25016 L
s
[(2)] .27105 .25016 1 0 Mshowa
.28355 .36788 m
.2898 .36788 L
s
[(3)] .27105 .36788 1 0 Mshowa
.28355 .4856 m
.2898 .4856 L
s
[(4)] .27105 .4856 1 0 Mshowa
.28355 .60332 m
.2898 .60332 L
s
[(5)] .27105 .60332 1 0 Mshowa
.125 Mabswid
.28355 .03826 m
.2873 .03826 L
s
.28355 .0618 m
.2873 .0618 L
s
.28355 .08535 m
.2873 .08535 L
s
.28355 .10889 m
.2873 .10889 L
s
.28355 .15598 m
.2873 .15598 L
s
.28355 .17952 m
.2873 .17952 L
s
.28355 .20307 m
.2873 .20307 L
s
.28355 .22661 m
.2873 .22661 L
s
.28355 .2737 m
.2873 .2737 L
s
.28355 .29724 m
.2873 .29724 L
s
.28355 .32079 m
.2873 .32079 L
s
.28355 .34433 m
.2873 .34433 L
s
.28355 .39142 m
.2873 .39142 L
s
.28355 .41497 m
.2873 .41497 L
s
.28355 .43851 m
.2873 .43851 L
s
.28355 .46205 m
.2873 .46205 L
s
.28355 .50914 m
.2873 .50914 L
s
.28355 .53269 m
.2873 .53269 L
s
.28355 .55623 m
.2873 .55623 L
s
.28355 .57977 m
.2873 .57977 L
s
.25 Mabswid
.28355 0 m
.28355 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.0068 w
.02381 .01472 m
.02381 .13244 L
s
.11039 .01472 m
.11039 .25016 L
s
.19697 .01472 m
.19697 .36788 L
s
.28355 .01472 m
.28355 .4856 L
s
.37013 .01472 m
.37013 .60332 L
s
.45671 .01472 m
.45671 .01472 L
s
.54329 .01472 m
.54329 .13244 L
s
.62987 .01472 m
.62987 .25016 L
s
.71645 .01472 m
.71645 .36788 L
s
.80303 .01472 m
.80303 .4856 L
s
.88961 .01472 m
.88961 .60332 L
s
.97619 .01472 m
.97619 .01472 L
s
.05 w
.02381 .13244 Mdot
.11039 .25016 Mdot
.19697 .36788 Mdot
.28355 .4856 Mdot
.37013 .60332 Mdot
.45671 .01472 Mdot
.54329 .13244 Mdot
.62987 .25016 Mdot
.71645 .36788 Mdot
.80303 .4856 Mdot
.88961 .60332 Mdot
.97619 .01472 Mdot
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.323031 0.477324 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.28355 0.0865801 0.0147151 0.117721 [
[.11039 .00222 -6 -9 ]
[.11039 .00222 6 0 ]
[.45671 .00222 -3 -9 ]
[.45671 .00222 3 0 ]
[.62987 .00222 -3 -9 ]
[.62987 .00222 3 0 ]
[.80303 .00222 -3 -9 ]
[.80303 .00222 3 0 ]
[.97619 .00222 -3 -9 ]
[.97619 .00222 3 0 ]
[.27105 .13244 -6 -4.5 ]
[.27105 .13244 0 4.5 ]
[.27105 .25016 -6 -4.5 ]
[.27105 .25016 0 4.5 ]
[.27105 .36788 -6 -4.5 ]
[.27105 .36788 0 4.5 ]
[.27105 .4856 -6 -4.5 ]
[.27105 .4856 0 4.5 ]
[.27105 .60332 -6 -4.5 ]
[.27105 .60332 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.11039 .01472 m
.11039 .02097 L
s
[(-2)] .11039 .00222 0 1 Mshowa
.45671 .01472 m
.45671 .02097 L
s
[(2)] .45671 .00222 0 1 Mshowa
.62987 .01472 m
.62987 .02097 L
s
[(4)] .62987 .00222 0 1 Mshowa
.80303 .01472 m
.80303 .02097 L
s
[(6)] .80303 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(8)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.15368 .01472 m
.15368 .01847 L
s
.19697 .01472 m
.19697 .01847 L
s
.24026 .01472 m
.24026 .01847 L
s
.32684 .01472 m
.32684 .01847 L
s
.37013 .01472 m
.37013 .01847 L
s
.41342 .01472 m
.41342 .01847 L
s
.5 .01472 m
.5 .01847 L
s
.54329 .01472 m
.54329 .01847 L
s
.58658 .01472 m
.58658 .01847 L
s
.67316 .01472 m
.67316 .01847 L
s
.71645 .01472 m
.71645 .01847 L
s
.75974 .01472 m
.75974 .01847 L
s
.84632 .01472 m
.84632 .01847 L
s
.88961 .01472 m
.88961 .01847 L
s
.9329 .01472 m
.9329 .01847 L
s
.0671 .01472 m
.0671 .01847 L
s
.02381 .01472 m
.02381 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.28355 .13244 m
.2898 .13244 L
s
[(1)] .27105 .13244 1 0 Mshowa
.28355 .25016 m
.2898 .25016 L
s
[(2)] .27105 .25016 1 0 Mshowa
.28355 .36788 m
.2898 .36788 L
s
[(3)] .27105 .36788 1 0 Mshowa
.28355 .4856 m
.2898 .4856 L
s
[(4)] .27105 .4856 1 0 Mshowa
.28355 .60332 m
.2898 .60332 L
s
[(5)] .27105 .60332 1 0 Mshowa
.125 Mabswid
.28355 .03826 m
.2873 .03826 L
s
.28355 .0618 m
.2873 .0618 L
s
.28355 .08535 m
.2873 .08535 L
s
.28355 .10889 m
.2873 .10889 L
s
.28355 .15598 m
.2873 .15598 L
s
.28355 .17952 m
.2873 .17952 L
s
.28355 .20307 m
.2873 .20307 L
s
.28355 .22661 m
.2873 .22661 L
s
.28355 .2737 m
.2873 .2737 L
s
.28355 .29724 m
.2873 .29724 L
s
.28355 .32079 m
.2873 .32079 L
s
.28355 .34433 m
.2873 .34433 L
s
.28355 .39142 m
.2873 .39142 L
s
.28355 .41497 m
.2873 .41497 L
s
.28355 .43851 m
.2873 .43851 L
s
.28355 .46205 m
.2873 .46205 L
s
.28355 .50914 m
.2873 .50914 L
s
.28355 .53269 m
.2873 .53269 L
s
.28355 .55623 m
.2873 .55623 L
s
.28355 .57977 m
.2873 .57977 L
s
.25 Mabswid
.28355 0 m
.28355 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.0068 w
.02381 .01472 m
.02381 .01472 L
s
.11039 .01472 m
.11039 .01472 L
s
.19697 .01472 m
.19697 .01472 L
s
.28355 .01472 m
.28355 .01472 L
s
.37013 .01472 m
.37013 .13244 L
s
.45671 .01472 m
.45671 .25016 L
s
.54329 .01472 m
.54329 .36788 L
s
.62987 .01472 m
.62987 .4856 L
s
.71645 .01472 m
.71645 .60332 L
s
.80303 .01472 m
.80303 .01472 L
s
.88961 .01472 m
.88961 .01472 L
s
.97619 .01472 m
.97619 .01472 L
s
.05 w
.02381 .01472 Mdot
.11039 .01472 Mdot
.19697 .01472 Mdot
.28355 .01472 Mdot
.37013 .13244 Mdot
.45671 .25016 Mdot
.54329 .36788 Mdot
.62987 .4856 Mdot
.71645 .60332 Mdot
.80303 .01472 Mdot
.88961 .01472 Mdot
.97619 .01472 Mdot
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.323031 0.97619 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.28355 0.0865801 0.0147151 0.117721 [
[.11039 .00222 -6 -9 ]
[.11039 .00222 6 0 ]
[.45671 .00222 -3 -9 ]
[.45671 .00222 3 0 ]
[.62987 .00222 -3 -9 ]
[.62987 .00222 3 0 ]
[.80303 .00222 -3 -9 ]
[.80303 .00222 3 0 ]
[.97619 .00222 -3 -9 ]
[.97619 .00222 3 0 ]
[.27105 .13244 -6 -4.5 ]
[.27105 .13244 0 4.5 ]
[.27105 .25016 -6 -4.5 ]
[.27105 .25016 0 4.5 ]
[.27105 .36788 -6 -4.5 ]
[.27105 .36788 0 4.5 ]
[.27105 .4856 -6 -4.5 ]
[.27105 .4856 0 4.5 ]
[.27105 .60332 -6 -4.5 ]
[.27105 .60332 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.11039 .01472 m
.11039 .02097 L
s
[(-2)] .11039 .00222 0 1 Mshowa
.45671 .01472 m
.45671 .02097 L
s
[(2)] .45671 .00222 0 1 Mshowa
.62987 .01472 m
.62987 .02097 L
s
[(4)] .62987 .00222 0 1 Mshowa
.80303 .01472 m
.80303 .02097 L
s
[(6)] .80303 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(8)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.15368 .01472 m
.15368 .01847 L
s
.19697 .01472 m
.19697 .01847 L
s
.24026 .01472 m
.24026 .01847 L
s
.32684 .01472 m
.32684 .01847 L
s
.37013 .01472 m
.37013 .01847 L
s
.41342 .01472 m
.41342 .01847 L
s
.5 .01472 m
.5 .01847 L
s
.54329 .01472 m
.54329 .01847 L
s
.58658 .01472 m
.58658 .01847 L
s
.67316 .01472 m
.67316 .01847 L
s
.71645 .01472 m
.71645 .01847 L
s
.75974 .01472 m
.75974 .01847 L
s
.84632 .01472 m
.84632 .01847 L
s
.88961 .01472 m
.88961 .01847 L
s
.9329 .01472 m
.9329 .01847 L
s
.0671 .01472 m
.0671 .01847 L
s
.02381 .01472 m
.02381 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.28355 .13244 m
.2898 .13244 L
s
[(1)] .27105 .13244 1 0 Mshowa
.28355 .25016 m
.2898 .25016 L
s
[(2)] .27105 .25016 1 0 Mshowa
.28355 .36788 m
.2898 .36788 L
s
[(3)] .27105 .36788 1 0 Mshowa
.28355 .4856 m
.2898 .4856 L
s
[(4)] .27105 .4856 1 0 Mshowa
.28355 .60332 m
.2898 .60332 L
s
[(5)] .27105 .60332 1 0 Mshowa
.125 Mabswid
.28355 .03826 m
.2873 .03826 L
s
.28355 .0618 m
.2873 .0618 L
s
.28355 .08535 m
.2873 .08535 L
s
.28355 .10889 m
.2873 .10889 L
s
.28355 .15598 m
.2873 .15598 L
s
.28355 .17952 m
.2873 .17952 L
s
.28355 .20307 m
.2873 .20307 L
s
.28355 .22661 m
.2873 .22661 L
s
.28355 .2737 m
.2873 .2737 L
s
.28355 .29724 m
.2873 .29724 L
s
.28355 .32079 m
.2873 .32079 L
s
.28355 .34433 m
.2873 .34433 L
s
.28355 .39142 m
.2873 .39142 L
s
.28355 .41497 m
.2873 .41497 L
s
.28355 .43851 m
.2873 .43851 L
s
.28355 .46205 m
.2873 .46205 L
s
.28355 .50914 m
.2873 .50914 L
s
.28355 .53269 m
.2873 .53269 L
s
.28355 .55623 m
.2873 .55623 L
s
.28355 .57977 m
.2873 .57977 L
s
.25 Mabswid
.28355 0 m
.28355 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.0068 w
.02381 .01472 m
.02381 .36788 L
s
.11039 .01472 m
.11039 .4856 L
s
.19697 .01472 m
.19697 .60332 L
s
.28355 .01472 m
.28355 .01472 L
s
.37013 .01472 m
.37013 .13244 L
s
.45671 .01472 m
.45671 .25016 L
s
.54329 .01472 m
.54329 .36788 L
s
.62987 .01472 m
.62987 .4856 L
s
.71645 .01472 m
.71645 .60332 L
s
.80303 .01472 m
.80303 .01472 L
s
.88961 .01472 m
.88961 .13244 L
s
.97619 .01472 m
.97619 .25016 L
s
.05 w
.02381 .36788 Mdot
.11039 .4856 Mdot
.19697 .60332 Mdot
.28355 .01472 Mdot
.37013 .13244 Mdot
.45671 .25016 Mdot
.54329 .36788 Mdot
.62987 .4856 Mdot
.71645 .60332 Mdot
.80303 .01472 Mdot
.88961 .13244 Mdot
.97619 .25016 Mdot
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{274.688, 169.563},
  ImageMargins->{{0, 0}, {0, 18.625}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004B0000ZA000`40O003h00Oogoo4goo003oOolC
Ool00?mooa=oo`00ogoo4goo003oOolCOol001aoo`<001moo`<0011oo`<000ioo`80015oo`03001o
ogoo02aoo`<001moo`<0011oo`<000ioo`80015oo`03001oogoo019oo`0077oo00<007ooOol07goo
00<007ooOol04Goo00<007ooOol03Goo00<007oo00003goo00<007oo0000;Goo00<007ooOol07goo
00<007ooOol04Goo00<007ooOol03Goo00<007oo00003goo00<007oo00004goo000GOol30003Ool0
0`00Oomoo`0OOol00`00Oomoo`0>Ool4000>Ool00`00Ool0000?Ool00`00Ool0000XOol30003Ool0
0`00Oomoo`0OOol00`00Oomoo`0>Ool4000>Ool00`00Ool0000?Ool00`00Ool0000COol001eoo`03
001oogoo01moo`03001oogoo00ioo`03001oo`0000moo`80015oo`03001oogoo02eoo`03001oogoo
01moo`03001oogoo00ioo`03001oo`0000moo`80015oo`03001oogoo019oo`0077oo00<007oo0000
7goo00<007oo000047oo0P003goo00<007ooOol03goo00<007oo0000;Goo00<007oo00007goo00<0
07oo000047oo0P003goo00<007ooOol03goo00<007oo00004goo000MOol00`00Oomoo`0OOol00`00
Oomoo`0@Ool00`00Oomoo`0>Ool2000@Ool00`00Oomoo`0]Ool00`00Oomoo`0OOol00`00Oomoo`0@
Ool00`00Oomoo`0>Ool2000@Ool00`00Oomoo`0BOol00?mooa=oo`004Goo0`001Woo0`001Woo0`00
1Woo0`001Woo0`001Woo0`00=7oo0`00CWoo0`00=7oo0`004Woo000@Ool50004Ool50004Ool50004
Ool50004Ool50004Ool5000bOol5000lOol00`00Oomoo`0=Ool5000bOol5000AOol0011oofT001mo
ofT0015oo`0047oo1@000Woo00<007oo000010000Woo00<007oo000010000Woo00<007oo00001000
0Woo00<007oo000010000Woo00<007oo000010000Woo00<007ooOol00Woo00D007ooOomoo`0000Ao
o`05001oogooOol00004Ool01@00Oomoogoo000017oo00D007ooOomoo`0000Aoo`05001oogooOol0
0002Ool5000QOol00`00Oomoo`02Ool01@00Oomoogoo000017oo00D007ooOomoo`0000Aoo`05001o
ogooOol00004Ool01@00Oomoogoo000017oo00<007oo000010000Woo00<007ooOol00Woo00D007oo
Oomoo`0000Aoo`05001oogooOol00004Ool01@00Oomoogoo000017oo00D007ooOomoo`0000Aoo`05
001oogooOol00002Ool5000AOol0015oo`<000Ioo`<000Ioo`<000Ioo`<000Ioo`<000Ioo`<000Qo
o`03001oogoo00Ioo`03001oogoo00Ioo`03001oogoo00Ioo`03001oogoo00Ioo`03001oogoo00Eo
o`<0029oo`03001oogoo00Ioo`03001oogoo00Ioo`03001oogoo00Ioo`03001oogoo00Ioo`03001o
ogoo00Eoo`<000Qoo`03001oogoo00Ioo`03001oogoo00Ioo`03001oogoo00Ioo`03001oogoo00Io
o`03001oogoo00Eoo`<0019oo`00;Goo0P006Woo00<007ooOol01Woo00<007ooOol01Woo00<007oo
Ool01Woo00<007ooOol01Woo00<007ooOol0:Woo00<007ooOol01Woo00<007ooOol01Woo00<007oo
Ool01Woo0P001goo00<007ooOol047oo00<007ooOol01Woo00<007ooOol01Woo00<007ooOol01Woo
00<007ooOol01Woo00<007ooOol06Woo000]Ool00`00Oomoo`0IOol00`00Oomoo`06Ool00`00Oomo
o`06Ool00`00Oomoo`06Ool00`00Oomoo`06Ool00`00Oomoo`0ZOol00`00Oomoo`06Ool00`00Oomo
o`06Ool00`00Oomoo`06Ool00`00Oomoo`06Ool00`00Oomoo`0@Ool00`00Oomoo`06Ool00`00Oomo
o`06Ool00`00Oomoo`06Ool00`00Oomoo`06Ool00`00Oomoo`0JOol002eoo`8001Yoo`03001oogoo
00Ioo`03001oogoo00Ioo`03001oogoo00Ioo`03001oogoo00Ioo`03001oogoo02Yoo`03001oogoo
00Ioo`03001oogoo00Ioo`03001oogoo00Ioo`8000Moo`03001oogoo011oo`03001oogoo00Ioo`03
001oogoo00Ioo`03001oogoo00Ioo`03001oogoo00Ioo`03001oogoo01Yoo`00;Goo00<007ooOol0
6Goo00<007ooOol01Woo00<007ooOol01Woo00<007ooOol01Woo00<007ooOol01Woo00<007ooOol0
:Woo00<007ooOol01Woo00<007ooOol01Woo00<007ooOol01Woo00<007ooOol01Woo00<007ooOol0
47oo00<007ooOol01Woo00<007ooOol01Woo00<007ooOol01Woo00<007ooOol01Woo00<007ooOol0
6Woo000]Ool00`00Oomoo`0IOol00`00Oomoo`06Ool00`00Oomoo`06Ool00`00Oomoo`06Ool00`00
Oomoo`06Ool00`00Oomoo`0ZOol00`00Oomoo`06Ool00`00Oomoo`06Ool00`00Oomoo`06Ool00`00
Oomoo`06Ool00`00Oomoo`0@Ool00`00Oomoo`06Ool00`00Oomoo`06Ool00`00Oomoo`06Ool00`00
Oomoo`06Ool00`00Oomoo`0JOol002eoo`8001Yoo`03001oogoo00Ioo`03001oogoo00Ioo`03001o
ogoo00Ioo`03001oogoo00Ioo`03001oogoo02Yoo`03001oogoo00Ioo`03001oogoo00Ioo`03001o
ogoo00Ioo`8000Moo`03001oogoo011oo`03001oogoo00Ioo`03001oogoo00Ioo`03001oogoo00Io
o`03001oogoo00Ioo`03001oogoo01Yoo`00;Goo00<007ooOol06Goo00<007ooOol01Woo00<007oo
Ool01Woo00<007ooOol01Woo00<007ooOol01Woo00<007ooOol0:Woo00<007ooOol01Woo00<007oo
Ool01Woo00<007ooOol01Woo00<007ooOol01Woo00<007ooOol047oo00<007ooOol01Woo00<007oo
Ool01Woo00<007ooOol01Woo00<007ooOol01Woo00<007ooOol06Woo000]Ool2000JOol00`00Oomo
o`06Ool00`00Oomoo`06Ool00`00Oomoo`06Ool00`00Oomoo`06Ool00`00Oomoo`0ZOol00`00Oomo
o`06Ool00`00Oomoo`06Ool00`00Oomoo`06Ool20007Ool00`00Oomoo`0@Ool00`00Oomoo`06Ool0
0`00Oomoo`06Ool00`00Oomoo`06Ool00`00Oomoo`06Ool00`00Oomoo`0JOol002Moo`D00003Ool0
07oo01Qoo`<000Qoo`03001oogoo00Ioo`03001oogoo00Ioo`03001oogoo00Ioo`03001oogoo02Uo
o`<000Moo`03001oogoo00Ioo`03001oogoo00D00003Ool007oo00Moo`03001oogoo00moo`<000Mo
o`03001oogoo00Ioo`03001oogoo00Ioo`03001oogoo00Ioo`03001oogoo01Yoo`00:Goo00D007oo
Oomoo`0001Qoo`D000Moo`03001oogoo00Ioo`03001oogoo00Ioo`03001oogoo00Ioo`03001oogoo
02Qoo`D000Ioo`03001oogoo00Ioo`03001oogoo009oo`05001oogooOol00008Ool00`00Oomoo`0>
Ool50006Ool00`00Oomoo`06Ool00`00Oomoo`06Ool00`00Oomoo`06Ool00`00Oomoo`0JOol002Uo
o`04001oogooOol2000GOol50007Ool00`00Oomoo`06Ool00`00Oomoo`06Ool00`00Oomoo`06Ool0
0`00Oomoo`0XOol50006Ool00`00Oomoo`06Ool00`00Oomoo`02Ool01000Oomoogoo0P001goo00<0
07ooOol03Woo1@001Woo00<007ooOol01Woo00<007ooOol01Woo00<007ooOol01Woo00<007ooOol0
6Woo000YOol01@00Oomoogoo000067oo1@001goo00<007ooOol01Woo00<007ooOol01Woo00<007oo
Ool01Woo00<007ooOol0:7oo1@001Woo00<007ooOol01Woo00<007ooOol00Woo00D007ooOomoo`00
00Qoo`03001oogoo00ioo`D000Ioo`03001oogoo00Ioo`03001oogoo00Ioo`03001oogoo00Ioo`03
001oogoo01Yoo`00:Goo00@007ooOomoo`8001Qoo`<000Qoo`03001oogoo00Ioo`03001oogoo00Io
o`03001oogoo00Ioo`03001oogoo02Uoo`<000Moo`03001oogoo00Ioo`03001oogoo009oo`04001o
ogooOol20007Ool00`00Oomoo`0?Ool30007Ool00`00Oomoo`06Ool00`00Oomoo`06Ool00`00Oomo
o`06Ool00`00Oomoo`0JOol002Qoo`8000=oo`03001oogoo029oo`03001oogoo00Ioo`03001oogoo
00Ioo`03001oogoo00Ioo`03001oogoo03=oo`03001oogoo00Ioo`04001oogooOol20003Ool00`00
Oomoo`06Ool00`00Oomoo`0IOol00`00Oomoo`06Ool00`00Oomoo`06Ool00`00Oomoo`06Ool00`00
Oomoo`0JOol002eoo`03001oogoo029oo`03001oogoo00Ioo`03001oogoo00Ioo`03001oogoo00Io
o`03001oogoo03=oo`03001oogoo00Ioo`03001oogoo00Ioo`03001oogoo00Ioo`03001oogoo01Uo
o`03001oogoo00Ioo`03001oogoo00Ioo`03001oogoo00Ioo`03001oogoo01Yoo`00;Goo0P008goo
00<007ooOol01Woo00<007ooOol01Woo00<007ooOol01Woo00<007ooOol0<goo00<007ooOol01Woo
00<007ooOol01Woo0P001goo00<007ooOol06Goo00<007ooOol01Woo00<007ooOol01Woo00<007oo
Ool01Woo00<007ooOol06Woo000]Ool00`00Oomoo`0ROol00`00Oomoo`06Ool00`00Oomoo`06Ool0
0`00Oomoo`06Ool00`00Oomoo`0cOol00`00Oomoo`06Ool00`00Oomoo`06Ool00`00Oomoo`06Ool0
0`00Oomoo`0IOol00`00Oomoo`06Ool00`00Oomoo`06Ool00`00Oomoo`06Ool00`00Oomoo`0JOol0
02eoo`8002=oo`03001oogoo00Ioo`03001oogoo00Ioo`03001oogoo00Ioo`03001oogoo03=oo`03
001oogoo00Ioo`03001oogoo00Ioo`8000Moo`03001oogoo01Uoo`03001oogoo00Ioo`03001oogoo
00Ioo`03001oogoo00Ioo`03001oogoo01Yoo`00;Goo00<007ooOol08Woo00<007ooOol01Woo00<0
07ooOol01Woo00<007ooOol01Woo00<007ooOol0<goo00<007ooOol01Woo00<007ooOol01Woo00<0
07ooOol01Woo00<007ooOol06Goo00<007ooOol01Woo00<007ooOol01Woo00<007ooOol01Woo00<0
07ooOol06Woo000]Ool2000SOol00`00Oomoo`06Ool00`00Oomoo`06Ool00`00Oomoo`06Ool00`00
Oomoo`0cOol00`00Oomoo`06Ool00`00Oomoo`06Ool20007Ool00`00Oomoo`0IOol00`00Oomoo`06
Ool00`00Oomoo`06Ool00`00Oomoo`06Ool00`00Oomoo`0JOol002Qoo`<0009oo`03001oogoo025o
o`<000Moo`03001oogoo00Ioo`03001oogoo00Ioo`03001oogoo039oo`<000Moo`04001oogooOol3
0002Ool00`00Oomoo`06Ool00`00Oomoo`0HOol30007Ool00`00Oomoo`06Ool00`00Oomoo`06Ool0
0`00Oomoo`0JOol002Qoo`03001oogoo009oo`03001oogoo021oo`D000Ioo`03001oogoo00Ioo`03
001oogoo00Ioo`03001oogoo035oo`D000Ioo`05001oogooOol00004Ool00`00Oomoo`06Ool00`00
Oomoo`0GOol50006Ool00`00Oomoo`06Ool00`00Oomoo`06Ool00`00Oomoo`0JOol002Uoo`04001o
ogooOol2000QOol50006Ool00`00Oomoo`06Ool00`00Oomoo`06Ool00`00Oomoo`0aOol50006Ool0
0`00Oomoo`02Ool01000Oomoogoo0P001goo00<007ooOol05goo1@001Woo00<007ooOol01Woo00<0
07ooOol01Woo00<007ooOol06Woo000YOol01@00Oomoogoo00008Woo1@001Woo00<007ooOol01Woo
00<007ooOol01Woo00<007ooOol0<Goo1@001Woo00<007ooOol00Woo00D007ooOomoo`0000Qoo`03
001oogoo01Moo`D000Ioo`03001oogoo00Ioo`03001oogoo00Ioo`03001oogoo01Yoo`00:7oo00<0
07oo00000Woo0P008Woo0`001goo00<007ooOol01Woo00<007ooOol01Woo00<007ooOol0<Woo0`00
1goo00L007ooOomoo`00Ool00002Ool20007Ool00`00Oomoo`0HOol30007Ool00`00Oomoo`06Ool0
0`00Oomoo`06Ool00`00Oomoo`0JOol002Uoo`05001oogooOol0000]Ool00`00Oomoo`06Ool00`00
Oomoo`06Ool00`00Oomoo`0lOol00`00Oomoo`02Ool01@00Oomoogoo000027oo00<007ooOol08Woo
00<007ooOol01Woo00<007ooOol01Woo00<007ooOol06Woo000]Ool00`00Oomoo`0[Ool00`00Oomo
o`06Ool00`00Oomoo`06Ool00`00Oomoo`0lOol00`00Oomoo`06Ool00`00Oomoo`06Ool00`00Oomo
o`0ROol00`00Oomoo`06Ool00`00Oomoo`06Ool00`00Oomoo`0JOol002eoo`8002aoo`03001oogoo
00Ioo`03001oogoo00Ioo`03001oogoo03aoo`03001oogoo00Ioo`8000Moo`03001oogoo029oo`03
001oogoo00Ioo`03001oogoo00Ioo`03001oogoo01Yoo`00;Goo00<007ooOol0:goo00<007ooOol0
1Woo00<007ooOol01Woo00<007ooOol0?7oo00<007ooOol01Woo00<007ooOol01Woo00<007ooOol0
8Woo00<007ooOol01Woo00<007ooOol01Woo00<007ooOol06Woo000]Ool2000/Ool00`00Oomoo`06
Ool00`00Oomoo`06Ool00`00Oomoo`0lOol00`00Oomoo`06Ool20007Ool00`00Oomoo`0ROol00`00
Oomoo`06Ool00`00Oomoo`06Ool00`00Oomoo`0JOol002eoo`03001oogoo02]oo`03001oogoo00Io
o`03001oogoo00Ioo`03001oogoo03aoo`03001oogoo00Ioo`03001oogoo00Ioo`03001oogoo029o
o`03001oogoo00Ioo`03001oogoo00Ioo`03001oogoo01Yoo`00;Goo00<007ooOol0:goo00<007oo
Ool01Woo00<007ooOol01Woo00<007ooOol0?7oo00<007ooOol01Woo00<007ooOol01Woo00<007oo
Ool08Woo00<007ooOol01Woo00<007ooOol01Woo00<007ooOol06Woo000XOol20003Ool2000[Ool3
0007Ool00`00Oomoo`06Ool00`00Oomoo`0kOol30002Ool20003Ool20007Ool00`00Oomoo`0QOol3
0007Ool00`00Oomoo`06Ool00`00Oomoo`0JOol002Yoo`04001oogoo000[Ool50006Ool00`00Oomo
o`06Ool00`00Oomoo`0jOol50003Ool01000Oomoo`0027oo00<007ooOol087oo1@001Woo00<007oo
Ool01Woo00<007ooOol06Woo000YOol01000Oomoogoo0P00:Woo1@001Woo00<007ooOol01Woo00<0
07ooOol0>Woo1@000Woo00@007ooOomoo`8000Moo`03001oogoo021oo`D000Ioo`03001oogoo00Io
o`03001oogoo01Yoo`00:Woo00@007ooOol002]oo`D000Ioo`03001oogoo00Ioo`03001oogoo03Yo
o`D000=oo`04001oogoo0008Ool00`00Oomoo`0POol50006Ool00`00Oomoo`06Ool00`00Oomoo`0J
Ool002Qoo`03001oo`00009oo`03001oogoo02Yoo`<000Moo`03001oogoo00Ioo`03001oogoo03]o
o`<0009oo`03001oo`00009oo`03001oogoo00Ioo`03001oogoo025oo`<000Moo`03001oogoo00Io
o`03001oogoo01Yoo`00:Goo00@007ooOomoo`8003Eoo`03001oogoo00Ioo`03001oogoo045oo`04
001oogooOol20007Ool00`00Oomoo`0[Ool00`00Oomoo`06Ool00`00Oomoo`0JOol002eoo`03001o
ogoo03Aoo`03001oogoo00Ioo`03001oogoo04Eoo`03001oogoo00Ioo`03001oogoo02]oo`03001o
ogoo00Ioo`03001oogoo01Yoo`00;Goo0P00=Goo00<007ooOol01Woo00<007ooOol0AGoo0P001goo
00<007ooOol0:goo00<007ooOol01Woo00<007ooOol06Woo000]Ool00`00Oomoo`0dOol00`00Oomo
o`06Ool00`00Oomoo`15Ool00`00Oomoo`06Ool00`00Oomoo`0[Ool00`00Oomoo`06Ool00`00Oomo
o`0JOol002eoo`03001oogoo03Aoo`03001oogoo00Ioo`03001oogoo04Eoo`03001oogoo00Ioo`03
001oogoo02]oo`03001oogoo00Ioo`03001oogoo01Yoo`00;Goo0P00=Goo00<007ooOol01Woo00<0
07ooOol0AGoo0P001goo00<007ooOol0:goo00<007ooOol01Woo00<007ooOol06Woo000]Ool00`00
Oomoo`0dOol00`00Oomoo`06Ool00`00Oomoo`15Ool00`00Oomoo`06Ool00`00Oomoo`0[Ool00`00
Oomoo`06Ool00`00Oomoo`0JOol002eoo`8003Eoo`03001oogoo00Ioo`03001oogoo04Eoo`8000Mo
o`03001oogoo02]oo`03001oogoo00Ioo`03001oogoo01Yoo`00:Goo0`0000=oo`00Ool0=7oo0`00
1goo00<007ooOol0@Goo1P001goo00<007ooOol0:Woo0`001goo00<007ooOol06Woo000ZOol01000
Oomoo`00=7oo1@001Woo00<007ooOol0@Woo1P001Woo00<007ooOol0:Goo1@001Woo00<007ooOol0
6Woo000XOol400000goo0000000cOol50006Ool00`00Oomoo`10Ool80006Ool00`00Oomoo`0YOol5
0006Ool00`00Oomoo`0JOol002Qoo`03001oo`00009oo`03001oogoo039oo`D000Ioo`03001oogoo
041oo`03001oo`0000D000Ioo`03001oogoo02Uoo`D000Ioo`03001oogoo01Yoo`00:Goo0P000Woo
0P00=7oo0`001goo00<007ooOol0@Goo0P0000Aoo`00000000Moo`03001oogoo02Yoo`<000Moo`03
001oogoo01Yoo`00:Woo00@007ooOol003moo`03001oogoo049oo`04001oogoo0008Ool00`00Oomo
o`0dOol00`00Oomoo`0JOol002eoo`03001oogoo03eoo`03001oogoo04Eoo`03001oogoo00Ioo`03
001oogoo03Aoo`03001oogoo01Yoo`00;Goo0P00?Woo00<007ooOol0AGoo0P001goo00<007ooOol0
=7oo00<007ooOol06Woo000]Ool00`00Oomoo`0mOol00`00Oomoo`15Ool00`00Oomoo`06Ool00`00
Oomoo`0dOol00`00Oomoo`0JOol002eoo`8003ioo`03001oogoo04Eoo`8000Moo`03001oogoo03Ao
o`03001oogoo01Yoo`00;Goo00<007ooOol0?Goo00<007ooOol0AGoo00<007ooOol01Woo00<007oo
Ool0=7oo00<007ooOol06Woo000]Ool2000nOol00`00Oomoo`15Ool20007Ool00`00Oomoo`0dOol0
0`00Oomoo`0JOol002Uoo`05001oogooOol0000nOol30012Ool01@00Oomoogoo00001goo0`00=7oo
0`006goo000XOol00`00Ool00002Ool00`00Oomoo`0kOol50010Ool00`00Ool00002Ool00`00Oomo
o`04Ool5000bOol5000JOol002Yoo`03001oogoo008003aoo`D0049oo`03001oogoo008000Eoo`D0
039oo`D001Yoo`00:7oo0P000goo00<007ooOol0>goo1@00@7oo0P000goo00<007ooOol017oo1@00
<Woo1@006Woo000XOol00`00Oomoo`11Ool30011Ool00`00Oomoo`0:Ool3000dOol3000KOol002Qo
o`<008Eoo`<005moo`00ogoo4goo003oOolCOol00?mooa=oo`00ogoo4goo003oOolCOol00?mooa=o
o`00ogoo4goo003oOolCOol00?mooa=oo`0077oo0`007goo0`0047oo0`003Woo0P004Goo00<007oo
Ool0;7oo0`007goo0`0047oo0`003Woo0P004Goo00<007ooOol04Woo000LOol00`00Oomoo`0OOol0
0`00Oomoo`0AOol00`00Oomoo`0=Ool00`00Ool0000?Ool00`00Ool0000]Ool00`00Oomoo`0OOol0
0`00Oomoo`0AOol00`00Oomoo`0=Ool00`00Ool0000?Ool00`00Ool0000COol001Moo`<000=oo`03
001oogoo01moo`03001oogoo00ioo`@000ioo`03001oo`0000moo`03001oo`0002Qoo`<000=oo`03
001oogoo01moo`03001oogoo00ioo`@000ioo`03001oo`0000moo`03001oo`0001=oo`007Goo00<0
07ooOol07goo00<007ooOol03Woo00<007oo00003goo0P004Goo00<007ooOol0;Goo00<007ooOol0
7goo00<007ooOol03Woo00<007oo00003goo0P004Goo00<007ooOol04Woo000LOol00`00Ool0000O
Ool00`00Ool0000@Ool2000?Ool00`00Oomoo`0?Ool00`00Ool0000]Ool00`00Ool0000OOol00`00
Ool0000@Ool2000?Ool00`00Oomoo`0?Ool00`00Ool0000COol001eoo`03001oogoo01moo`03001o
ogoo011oo`03001oogoo00ioo`80011oo`03001oogoo02eoo`03001oogoo01moo`03001oogoo011o
o`03001oogoo00ioo`80011oo`03001oogoo019oo`00ogoo4goo000AOol30006Ool30006Ool30006
Ool3000dOol30006Ool30006Ool3000lOol3000dOol3000TOol0011oo`D000Aoo`D000Aoo`D000Ao
o`D0039oo`D000Aoo`D000Aoo`D003Yoo`D0039oo`D002=oo`0047ooJ@007gooJ@004Goo000@Ool5
0002Ool00`00Ool000040002Ool00`00Ool000040002Ool00`00Ool000040002Ool01@00Oomoogoo
000017oo00D007ooOomoo`0000Aoo`03001oogoo009oo`05001oogooOol00004Ool01@00Oomoogoo
000017oo00D007ooOomoo`00009oo`D00004Ool007ooOol5000017oo001oogoo1@008Goo00<007oo
Ool00Woo00D007ooOomoo`0000Aoo`05001oogooOol00004Ool00`00Ool000040002Ool01@00Oomo
ogoo000017oo00<007ooOol00Woo00D007ooOomoo`0000Aoo`05001oogooOol00004Ool01@00Oomo
ogoo000017oo00D007ooOomoo`00009oo`D00003Ool007oo00=oo`05001oogooOol00004Ool00`00
Oomoo`0AOol0015oo`<000Ioo`<000Ioo`<000Ioo`<000Moo`03001oogoo00Ioo`03001oogoo00Mo
o`03001oogoo00Ioo`03001oogoo00Ioo`03001oogoo00Eoo`<000Ioo`<000Ioo`<0029oo`03001o
ogoo00Ioo`03001oogoo00Ioo`03001oogoo00Eoo`<000Moo`03001oogoo00Moo`03001oogoo00Io
o`03001oogoo00Ioo`03001oogoo00Ioo`03001oogoo00Eoo`<000Moo`03001oogoo00Ioo`03001o
ogoo015oo`00;Goo0P001goo00<007ooOol01Woo00<007ooOol01goo00<007ooOol01Woo00<007oo
Ool01Woo00<007ooOol0?7oo00<007ooOol01Woo00<007ooOol01Woo00<007ooOol01Woo0P001goo
00<007ooOol01goo00<007ooOol01Woo00<007ooOol01Woo00<007ooOol01Woo00<007ooOol03goo
00<007ooOol01Woo00<007ooOol04Goo000]Ool00`00Oomoo`06Ool00`00Oomoo`06Ool00`00Oomo
o`07Ool00`00Oomoo`06Ool00`00Oomoo`06Ool00`00Oomoo`0lOol00`00Oomoo`06Ool00`00Oomo
o`06Ool00`00Oomoo`06Ool00`00Oomoo`06Ool00`00Oomoo`07Ool00`00Oomoo`06Ool00`00Oomo
o`06Ool00`00Oomoo`06Ool00`00Oomoo`0?Ool00`00Oomoo`06Ool00`00Oomoo`0AOol002eoo`80
00Moo`03001oogoo00Ioo`03001oogoo00Moo`03001oogoo00Ioo`03001oogoo00Ioo`03001oogoo
03aoo`03001oogoo00Ioo`03001oogoo00Ioo`03001oogoo00Ioo`8000Moo`03001oogoo00Moo`03
001oogoo00Ioo`03001oogoo00Ioo`03001oogoo00Ioo`03001oogoo00moo`03001oogoo00Ioo`03
001oogoo015oo`00;Goo00<007ooOol01Woo00<007ooOol01Woo00<007ooOol01goo00<007ooOol0
1Woo00<007ooOol01Woo00<007ooOol0?7oo00<007ooOol01Woo00<007ooOol01Woo00<007ooOol0
1Woo00<007ooOol01Woo00<007ooOol01goo00<007ooOol01Woo00<007ooOol01Woo00<007ooOol0
1Woo00<007ooOol03goo00<007ooOol01Woo00<007ooOol04Goo000]Ool00`00Oomoo`06Ool00`00
Oomoo`06Ool00`00Oomoo`07Ool00`00Oomoo`06Ool00`00Oomoo`06Ool00`00Oomoo`0lOol00`00
Oomoo`06Ool00`00Oomoo`06Ool00`00Oomoo`06Ool00`00Oomoo`06Ool00`00Oomoo`07Ool00`00
Oomoo`06Ool00`00Oomoo`06Ool00`00Oomoo`06Ool00`00Oomoo`0?Ool00`00Oomoo`06Ool00`00
Oomoo`0AOol002eoo`8000Moo`03001oogoo00Ioo`03001oogoo00Moo`03001oogoo00Ioo`03001o
ogoo00Ioo`03001oogoo03aoo`03001oogoo00Ioo`03001oogoo00Ioo`03001oogoo00Ioo`8000Mo
o`03001oogoo00Moo`03001oogoo00Ioo`03001oogoo00Ioo`03001oogoo00Ioo`03001oogoo00mo
o`03001oogoo00Ioo`03001oogoo015oo`00;Goo00<007ooOol01Woo00<007ooOol01Woo00<007oo
Ool01goo00<007ooOol01Woo00<007ooOol01Woo00<007ooOol0?7oo00<007ooOol01Woo00<007oo
Ool01Woo00<007ooOol01Woo00<007ooOol01Woo00<007ooOol01goo00<007ooOol01Woo00<007oo
Ool01Woo00<007ooOol01Woo00<007ooOol03goo00<007ooOol01Woo00<007ooOol04Goo000]Ool2
0007Ool00`00Oomoo`06Ool00`00Oomoo`07Ool00`00Oomoo`06Ool00`00Oomoo`06Ool00`00Oomo
o`0lOol00`00Oomoo`06Ool00`00Oomoo`06Ool00`00Oomoo`06Ool20007Ool00`00Oomoo`07Ool0
0`00Oomoo`06Ool00`00Oomoo`06Ool00`00Oomoo`06Ool00`00Oomoo`0?Ool00`00Oomoo`06Ool0
0`00Oomoo`0AOol002Moo`D00003Ool007oo00Ioo`<000Moo`03001oogoo00Moo`03001oogoo00Io
o`03001oogoo00Ioo`03001oogoo03aoo`03001oogoo00Ioo`03001oogoo00Ioo`03001oogoo00D0
0003Ool007oo00Ioo`<000Qoo`03001oogoo00Ioo`03001oogoo00Ioo`03001oogoo00Ioo`03001o
ogoo00ioo`<000Moo`03001oogoo015oo`00:Goo00D007ooOomoo`0000Ioo`D000Ioo`03001oogoo
00Moo`03001oogoo00Ioo`03001oogoo00Ioo`03001oogoo03aoo`03001oogoo00Ioo`03001oogoo
00Ioo`03001oogoo009oo`05001oogooOol00006Ool50007Ool00`00Oomoo`06Ool00`00Oomoo`06
Ool00`00Oomoo`06Ool00`00Oomoo`0=Ool50006Ool00`00Oomoo`0AOol002Uoo`04001oogooOol2
0005Ool50006Ool00`00Oomoo`07Ool00`00Oomoo`06Ool00`00Oomoo`06Ool00`00Oomoo`0lOol0
0`00Oomoo`06Ool00`00Oomoo`06Ool00`00Oomoo`02Ool01000Oomoogoo0P001Goo1@001goo00<0
07ooOol01Woo00<007ooOol01Woo00<007ooOol01Woo00<007ooOol03Goo1@001Woo00<007ooOol0
4Goo000YOol01@00Oomoogoo00001Woo1@001Woo00<007ooOol01goo00<007ooOol01Woo00<007oo
Ool01Woo00<007ooOol0?7oo00<007ooOol01Woo00<007ooOol01Woo00<007ooOol00Woo00D007oo
Oomoo`0000Ioo`D000Moo`03001oogoo00Ioo`03001oogoo00Ioo`03001oogoo00Ioo`03001oogoo
00eoo`D000Ioo`03001oogoo015oo`00:Goo00@007ooOomoo`8000Ioo`<000Moo`03001oogoo00Mo
o`03001oogoo00Ioo`03001oogoo00Ioo`03001oogoo03aoo`03001oogoo00Ioo`03001oogoo00Io
o`03001oogoo009oo`04001oogooOol20006Ool30008Ool00`00Oomoo`06Ool00`00Oomoo`06Ool0
0`00Oomoo`06Ool00`00Oomoo`0>Ool30007Ool00`00Oomoo`0AOol002Qoo`8000=oo`03001oogoo
00moo`03001oogoo00Moo`03001oogoo00Ioo`03001oogoo00Ioo`03001oogoo03aoo`03001oogoo
00Ioo`03001oogoo00Ioo`04001oogooOol20003Ool00`00Oomoo`0@Ool00`00Oomoo`06Ool00`00
Oomoo`06Ool00`00Oomoo`06Ool00`00Oomoo`0HOol00`00Oomoo`0AOol002eoo`03001oogoo00mo
o`03001oogoo00Moo`03001oogoo00Ioo`03001oogoo00Ioo`03001oogoo03aoo`03001oogoo00Io
o`03001oogoo00Ioo`03001oogoo00Ioo`03001oogoo011oo`03001oogoo00Ioo`03001oogoo00Io
o`03001oogoo00Ioo`03001oogoo01Qoo`03001oogoo015oo`00;Goo0P0047oo00<007ooOol01goo
00<007ooOol01Woo00<007ooOol01Woo00<007ooOol0?7oo00<007ooOol01Woo00<007ooOol01Woo
00<007ooOol01Woo0P004Goo00<007ooOol01Woo00<007ooOol01Woo00<007ooOol01Woo00<007oo
Ool067oo00<007ooOol04Goo000]Ool00`00Oomoo`0?Ool00`00Oomoo`07Ool00`00Oomoo`06Ool0
0`00Oomoo`06Ool00`00Oomoo`0lOol00`00Oomoo`06Ool00`00Oomoo`06Ool00`00Oomoo`06Ool0
0`00Oomoo`0@Ool00`00Oomoo`06Ool00`00Oomoo`06Ool00`00Oomoo`06Ool00`00Oomoo`0HOol0
0`00Oomoo`0AOol002eoo`80011oo`03001oogoo00Moo`03001oogoo00Ioo`03001oogoo00Ioo`03
001oogoo03aoo`03001oogoo00Ioo`03001oogoo00Ioo`03001oogoo00Ioo`80015oo`03001oogoo
00Ioo`03001oogoo00Ioo`03001oogoo00Ioo`03001oogoo01Qoo`03001oogoo015oo`00;Goo00<0
07ooOol03goo00<007ooOol01goo00<007ooOol01Woo00<007ooOol01Woo00<007ooOol0?7oo00<0
07ooOol01Woo00<007ooOol01Woo00<007ooOol01Woo00<007ooOol047oo00<007ooOol01Woo00<0
07ooOol01Woo00<007ooOol01Woo00<007ooOol067oo00<007ooOol04Goo000]Ool00`00Oomoo`0?
Ool00`00Oomoo`07Ool00`00Oomoo`06Ool00`00Oomoo`06Ool00`00Oomoo`0lOol00`00Oomoo`06
Ool00`00Oomoo`06Ool00`00Oomoo`06Ool00`00Oomoo`0@Ool00`00Oomoo`06Ool00`00Oomoo`06
Ool00`00Oomoo`06Ool00`00Oomoo`0HOol00`00Oomoo`0AOol002Qoo`<0009oo`8000moo`<000Qo
o`03001oogoo00Ioo`03001oogoo00Ioo`03001oogoo03aoo`03001oogoo00Ioo`03001oogoo00Io
o`04001oogooOol30002Ool2000?Ool30008Ool00`00Oomoo`06Ool00`00Oomoo`06Ool00`00Oomo
o`0GOol3000BOol002Qoo`03001oogoo009oo`03001oogoo00eoo`D000Moo`03001oogoo00Ioo`03
001oogoo00Ioo`03001oogoo03aoo`03001oogoo00Ioo`03001oogoo00Ioo`05001oogooOol00004
Ool00`00Oomoo`0=Ool50007Ool00`00Oomoo`06Ool00`00Oomoo`06Ool00`00Oomoo`0FOol5000A
Ool002Uoo`04001oogooOol2000>Ool50007Ool00`00Oomoo`06Ool00`00Oomoo`06Ool00`00Oomo
o`0lOol00`00Oomoo`06Ool00`00Oomoo`06Ool00`00Oomoo`02Ool01000Oomoogoo0P003Woo1@00
1goo00<007ooOol01Woo00<007ooOol01Woo00<007ooOol05Woo1@004Goo000YOol01@00Oomoogoo
00003goo1@001goo00<007ooOol01Woo00<007ooOol01Woo00<007ooOol0?7oo00<007ooOol01Woo
00<007ooOol01Woo00<007ooOol00Woo00D007ooOomoo`0000moo`D000Moo`03001oogoo00Ioo`03
001oogoo00Ioo`03001oogoo01Ioo`D0015oo`00:7oo00<007oo00000Woo0P003goo0`0027oo00<0
07ooOol01Woo00<007ooOol01Woo00<007ooOol0?7oo00<007ooOol01Woo00<007ooOol01Woo00L0
07ooOomoo`00Ool00002Ool2000?Ool30008Ool00`00Oomoo`06Ool00`00Oomoo`06Ool00`00Oomo
o`0GOol3000BOol002Uoo`05001oogooOol0000KOol00`00Oomoo`06Ool00`00Oomoo`06Ool00`00
Oomoo`0lOol00`00Oomoo`06Ool00`00Oomoo`06Ool00`00Oomoo`02Ool01@00Oomoogoo00006goo
00<007ooOol01Woo00<007ooOol01Woo00<007ooOol0;7oo000]Ool00`00Oomoo`0IOol00`00Oomo
o`06Ool00`00Oomoo`06Ool00`00Oomoo`0lOol00`00Oomoo`06Ool00`00Oomoo`06Ool00`00Oomo
o`06Ool00`00Oomoo`0IOol00`00Oomoo`06Ool00`00Oomoo`06Ool00`00Oomoo`0/Ool002eoo`80
01Yoo`03001oogoo00Ioo`03001oogoo00Ioo`03001oogoo03aoo`03001oogoo00Ioo`03001oogoo
00Ioo`03001oogoo00Ioo`8001Yoo`03001oogoo00Ioo`03001oogoo00Ioo`03001oogoo02aoo`00
;Goo00<007ooOol06Goo00<007ooOol01Woo00<007ooOol01Woo00<007ooOol0?7oo00<007ooOol0
1Woo00<007ooOol01Woo00<007ooOol01Woo00<007ooOol06Goo00<007ooOol01Woo00<007ooOol0
1Woo00<007ooOol0;7oo000]Ool2000JOol00`00Oomoo`06Ool00`00Oomoo`06Ool00`00Oomoo`0l
Ool00`00Oomoo`06Ool00`00Oomoo`06Ool00`00Oomoo`06Ool2000JOol00`00Oomoo`06Ool00`00
Oomoo`06Ool00`00Oomoo`0/Ool002eoo`03001oogoo01Uoo`03001oogoo00Ioo`03001oogoo00Io
o`03001oogoo03aoo`03001oogoo00Ioo`03001oogoo00Ioo`03001oogoo00Ioo`03001oogoo01Uo
o`03001oogoo00Ioo`03001oogoo00Ioo`03001oogoo02aoo`00;Goo00<007ooOol06Goo00<007oo
Ool01Woo00<007ooOol01Woo00<007ooOol0?7oo00<007ooOol01Woo00<007ooOol01Woo00<007oo
Ool01Woo00<007ooOol06Goo00<007ooOol01Woo00<007ooOol01Woo00<007ooOol0;7oo000XOol2
0003Ool2000HOol30008Ool00`00Oomoo`06Ool00`00Oomoo`0kOol30007Ool00`00Oomoo`06Ool0
1000Oomoogoo0P000goo0P006Goo0`001goo00<007ooOol01Woo00<007ooOol0;7oo000ZOol01000
Oomoo`0067oo1@001goo00<007ooOol01Woo00<007ooOol0>Woo1@001Woo00<007ooOol01Woo00<0
07ooOol00goo00@007ooOol001Uoo`D000Ioo`03001oogoo00Ioo`03001oogoo02aoo`00:Goo00@0
07ooOomoo`8001Moo`D000Moo`03001oogoo00Ioo`03001oogoo03Yoo`D000Ioo`03001oogoo00Io
o`03001oogoo009oo`04001oogooOol2000HOol50006Ool00`00Oomoo`06Ool00`00Oomoo`0/Ool0
02Yoo`04001oogoo000HOol50007Ool00`00Oomoo`06Ool00`00Oomoo`0jOol50006Ool00`00Oomo
o`06Ool00`00Oomoo`03Ool01000Oomoo`006Goo1@001Woo00<007ooOol01Woo00<007ooOol0;7oo
000XOol00`00Ool00002Ool00`00Oomoo`0GOol30008Ool00`00Oomoo`06Ool00`00Oomoo`0kOol3
0007Ool00`00Oomoo`06Ool01`00Oomoogoo001oo`00009oo`03001oogoo01Qoo`<000Moo`03001o
ogoo00Ioo`03001oogoo02aoo`00:Goo00@007ooOomoo`8002=oo`03001oogoo00Ioo`03001oogoo
04Eoo`03001oogoo00Ioo`03001oogoo009oo`04001oogooOol2000SOol00`00Oomoo`06Ool00`00
Oomoo`0/Ool002eoo`03001oogoo029oo`03001oogoo00Ioo`03001oogoo04Eoo`03001oogoo00Io
o`03001oogoo00Ioo`03001oogoo029oo`03001oogoo00Ioo`03001oogoo02aoo`00;Goo0P008goo
00<007ooOol01Woo00<007ooOol0AGoo00<007ooOol01Woo00<007ooOol01Woo0P008goo00<007oo
Ool01Woo00<007ooOol0;7oo000]Ool00`00Oomoo`0ROol00`00Oomoo`06Ool00`00Oomoo`15Ool0
0`00Oomoo`06Ool00`00Oomoo`06Ool00`00Oomoo`0ROol00`00Oomoo`06Ool00`00Oomoo`0/Ool0
02eoo`03001oogoo029oo`03001oogoo00Ioo`03001oogoo04Eoo`03001oogoo00Ioo`03001oogoo
00Ioo`03001oogoo029oo`03001oogoo00Ioo`03001oogoo02aoo`00;Goo0P008goo00<007ooOol0
1Woo00<007ooOol0AGoo00<007ooOol01Woo00<007ooOol01Woo0P008goo00<007ooOol01Woo00<0
07ooOol0;7oo000]Ool00`00Oomoo`0ROol00`00Oomoo`06Ool00`00Oomoo`15Ool00`00Oomoo`06
Ool00`00Oomoo`06Ool00`00Oomoo`0ROol00`00Oomoo`06Ool00`00Oomoo`0/Ool002eoo`8002=o
o`03001oogoo00Ioo`03001oogoo04Eoo`03001oogoo00Ioo`03001oogoo00Ioo`8002=oo`03001o
ogoo00Ioo`03001oogoo02aoo`00:Goo0`0000=oo`00Ool08Woo0`001goo00<007ooOol0A7oo0`00
1goo00<007ooOol00Woo0`0000=oo`00Ool08Woo0`001goo00<007ooOol0;7oo000ZOol01000Oomo
o`008Woo1@001Woo00<007ooOol0@goo1@001Woo00<007ooOol00goo00@007ooOol0029oo`D000Io
o`03001oogoo02aoo`00:7oo100000=oo`0000008Goo1@001Woo00<007ooOol0@goo1@001Woo00@0
07ooOomoo`@00003Ool00000025oo`D000Ioo`03001oogoo02aoo`00:7oo00<007oo00000Woo00<0
07ooOol087oo1@001Woo00<007ooOol0@goo1@001Woo00L007ooOomoo`00Ool00002Ool00`00Oomo
o`0POol50006Ool00`00Oomoo`0/Ool002Uoo`80009oo`80029oo`<000Moo`03001oogoo04Aoo`<0
00Moo`03001oogoo009oo`80009oo`80029oo`<000Moo`03001oogoo02aoo`00:Woo00@007ooOol0
02eoo`03001oogoo04ioo`03001oogoo00=oo`04001oogoo000]Ool00`00Oomoo`0/Ool002eoo`03
001oogoo02]oo`03001oogoo04ioo`03001oogoo00Ioo`03001oogoo02]oo`03001oogoo02aoo`00
;Goo0P00;7oo00<007ooOol0CWoo00<007ooOol01Woo0P00;7oo00<007ooOol0;7oo000]Ool00`00
Oomoo`0[Ool00`00Oomoo`1>Ool00`00Oomoo`06Ool00`00Oomoo`0[Ool00`00Oomoo`0/Ool002eo
o`8002aoo`03001oogoo04ioo`03001oogoo00Ioo`8002aoo`03001oogoo02aoo`00;Goo00<007oo
Ool0:goo00<007ooOol0CWoo00<007ooOol01Woo00<007ooOol0:goo00<007ooOol0;7oo000]Ool0
0`00Oomoo`0[Ool00`00Oomoo`1>Ool00`00Oomoo`06Ool00`00Oomoo`0[Ool00`00Oomoo`0/Ool0
02Uoo`04001oogooOol2000[Ool3001>Ool30003Ool01000Oomoogoo0P00:goo0`00;Goo000XOol0
0`00Ool00002Ool00`00Oomoo`0YOol5001<Ool5000017oo001oo`000Woo00<007ooOol0:Goo1@00
;7oo000ZOol00`00Oomoo`02000ZOol5001<Ool50003Ool00`00Oomoo`02000ZOol5000/Ool002Qo
o`8000=oo`03001oogoo02Uoo`D004aoo`D00003Ool0000000=oo`03001oogoo02Uoo`D002aoo`00
:7oo00<007ooOol00Woo00<007ooOol0:Woo0`00CWoo0`000Woo00<007ooOol00Woo00<007ooOol0
:Woo0`00;Goo000XOol30025Ool3001OOol00?mooa=oo`00ogoo4goo003oOolCOol00?mooa=oo`00
ogoo4goo0000\
\>"],
  ImageRangeCache->{{{0, 273.688}, {168.563, 0}} -> {-0.053652, -0.0309082, 
  0.00769968, 0.00769968}, {{6.9375, 130.625}, {164.5, 
  88.0625}} -> {-5.05945, -1.16594, 0.110312, 0.0811312}, {{143, 266.688}, {
  164.5, 88.0625}} -> {-20.0688, -1.16594, 0.110312, 0.0811312}, {{6.9375, 
  130.625}, {80.4375, 4}} -> {-5.05945, -7.98603, 0.110312, 0.0811312}, {{
  143, 266.688}, {80.4375, 4}} -> {-20.0688, -7.98603, 0.110312, 0.0811312}}],

Cell[TextData[StyleBox[
"\t\tFigure 1. Demonstration of shifts of aperiodic (left) and periodic \
signals (right)."]], "SmallText"],

Cell[TextData[{
  "The third form of convolution frequently encountered in signal processing \
is the so-called ",
  StyleBox["circular convolution",
    FontSlant->"Italic"],
  ". Circular convolution defines an operation between two finite length \
sequences (like linear convolution), but where the time-reversed signal is \
circularly shifted (like in the case of periodic convolution)."
}], "Text"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .2943 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.00700719 0.47619 [
[ 0 0 0 0 ]
[ 1 .2943 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .2943 L
0 .2943 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.00700719 0.477324 0.287295 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.28355 0.0865801 0.0147151 0.117721 [
[.11039 .00222 -6 -9 ]
[.11039 .00222 6 0 ]
[.45671 .00222 -3 -9 ]
[.45671 .00222 3 0 ]
[.62987 .00222 -3 -9 ]
[.62987 .00222 3 0 ]
[.80303 .00222 -3 -9 ]
[.80303 .00222 3 0 ]
[.97619 .00222 -3 -9 ]
[.97619 .00222 3 0 ]
[.27105 .13244 -6 -4.5 ]
[.27105 .13244 0 4.5 ]
[.27105 .25016 -6 -4.5 ]
[.27105 .25016 0 4.5 ]
[.27105 .36788 -6 -4.5 ]
[.27105 .36788 0 4.5 ]
[.27105 .4856 -6 -4.5 ]
[.27105 .4856 0 4.5 ]
[.27105 .60332 -6 -4.5 ]
[.27105 .60332 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.11039 .01472 m
.11039 .02097 L
s
[(-2)] .11039 .00222 0 1 Mshowa
.45671 .01472 m
.45671 .02097 L
s
[(2)] .45671 .00222 0 1 Mshowa
.62987 .01472 m
.62987 .02097 L
s
[(4)] .62987 .00222 0 1 Mshowa
.80303 .01472 m
.80303 .02097 L
s
[(6)] .80303 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(8)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.15368 .01472 m
.15368 .01847 L
s
.19697 .01472 m
.19697 .01847 L
s
.24026 .01472 m
.24026 .01847 L
s
.32684 .01472 m
.32684 .01847 L
s
.37013 .01472 m
.37013 .01847 L
s
.41342 .01472 m
.41342 .01847 L
s
.5 .01472 m
.5 .01847 L
s
.54329 .01472 m
.54329 .01847 L
s
.58658 .01472 m
.58658 .01847 L
s
.67316 .01472 m
.67316 .01847 L
s
.71645 .01472 m
.71645 .01847 L
s
.75974 .01472 m
.75974 .01847 L
s
.84632 .01472 m
.84632 .01847 L
s
.88961 .01472 m
.88961 .01847 L
s
.9329 .01472 m
.9329 .01847 L
s
.0671 .01472 m
.0671 .01847 L
s
.02381 .01472 m
.02381 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.28355 .13244 m
.2898 .13244 L
s
[(1)] .27105 .13244 1 0 Mshowa
.28355 .25016 m
.2898 .25016 L
s
[(2)] .27105 .25016 1 0 Mshowa
.28355 .36788 m
.2898 .36788 L
s
[(3)] .27105 .36788 1 0 Mshowa
.28355 .4856 m
.2898 .4856 L
s
[(4)] .27105 .4856 1 0 Mshowa
.28355 .60332 m
.2898 .60332 L
s
[(5)] .27105 .60332 1 0 Mshowa
.125 Mabswid
.28355 .03826 m
.2873 .03826 L
s
.28355 .0618 m
.2873 .0618 L
s
.28355 .08535 m
.2873 .08535 L
s
.28355 .10889 m
.2873 .10889 L
s
.28355 .15598 m
.2873 .15598 L
s
.28355 .17952 m
.2873 .17952 L
s
.28355 .20307 m
.2873 .20307 L
s
.28355 .22661 m
.2873 .22661 L
s
.28355 .2737 m
.2873 .2737 L
s
.28355 .29724 m
.2873 .29724 L
s
.28355 .32079 m
.2873 .32079 L
s
.28355 .34433 m
.2873 .34433 L
s
.28355 .39142 m
.2873 .39142 L
s
.28355 .41497 m
.2873 .41497 L
s
.28355 .43851 m
.2873 .43851 L
s
.28355 .46205 m
.2873 .46205 L
s
.28355 .50914 m
.2873 .50914 L
s
.28355 .53269 m
.2873 .53269 L
s
.28355 .55623 m
.2873 .55623 L
s
.28355 .57977 m
.2873 .57977 L
s
.25 Mabswid
.28355 0 m
.28355 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.0068 w
.02381 .01472 m
.02381 .01472 L
s
.11039 .01472 m
.11039 .01472 L
s
.19697 .01472 m
.19697 .01472 L
s
.28355 .01472 m
.28355 .01472 L
s
.37013 .01472 m
.37013 .13244 L
s
.45671 .01472 m
.45671 .25016 L
s
.54329 .01472 m
.54329 .36788 L
s
.62987 .01472 m
.62987 .4856 L
s
.71645 .01472 m
.71645 .60332 L
s
.80303 .01472 m
.80303 .01472 L
s
.88961 .01472 m
.88961 .01472 L
s
.97619 .01472 m
.97619 .01472 L
s
.05 w
.02381 .01472 Mdot
.11039 .01472 Mdot
.19697 .01472 Mdot
.28355 .01472 Mdot
.37013 .13244 Mdot
.45671 .25016 Mdot
.54329 .36788 Mdot
.62987 .4856 Mdot
.71645 .60332 Mdot
.80303 .01472 Mdot
.88961 .01472 Mdot
.97619 .01472 Mdot
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.00700719 0.97619 0.287295 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.28355 0.0865801 0.0147151 0.117721 [
[.11039 .00222 -6 -9 ]
[.11039 .00222 6 0 ]
[.45671 .00222 -3 -9 ]
[.45671 .00222 3 0 ]
[.62987 .00222 -3 -9 ]
[.62987 .00222 3 0 ]
[.80303 .00222 -3 -9 ]
[.80303 .00222 3 0 ]
[.97619 .00222 -3 -9 ]
[.97619 .00222 3 0 ]
[.27105 .13244 -6 -4.5 ]
[.27105 .13244 0 4.5 ]
[.27105 .25016 -6 -4.5 ]
[.27105 .25016 0 4.5 ]
[.27105 .36788 -6 -4.5 ]
[.27105 .36788 0 4.5 ]
[.27105 .4856 -6 -4.5 ]
[.27105 .4856 0 4.5 ]
[.27105 .60332 -6 -4.5 ]
[.27105 .60332 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.11039 .01472 m
.11039 .02097 L
s
[(-2)] .11039 .00222 0 1 Mshowa
.45671 .01472 m
.45671 .02097 L
s
[(2)] .45671 .00222 0 1 Mshowa
.62987 .01472 m
.62987 .02097 L
s
[(4)] .62987 .00222 0 1 Mshowa
.80303 .01472 m
.80303 .02097 L
s
[(6)] .80303 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(8)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.15368 .01472 m
.15368 .01847 L
s
.19697 .01472 m
.19697 .01847 L
s
.24026 .01472 m
.24026 .01847 L
s
.32684 .01472 m
.32684 .01847 L
s
.37013 .01472 m
.37013 .01847 L
s
.41342 .01472 m
.41342 .01847 L
s
.5 .01472 m
.5 .01847 L
s
.54329 .01472 m
.54329 .01847 L
s
.58658 .01472 m
.58658 .01847 L
s
.67316 .01472 m
.67316 .01847 L
s
.71645 .01472 m
.71645 .01847 L
s
.75974 .01472 m
.75974 .01847 L
s
.84632 .01472 m
.84632 .01847 L
s
.88961 .01472 m
.88961 .01847 L
s
.9329 .01472 m
.9329 .01847 L
s
.0671 .01472 m
.0671 .01847 L
s
.02381 .01472 m
.02381 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.28355 .13244 m
.2898 .13244 L
s
[(1)] .27105 .13244 1 0 Mshowa
.28355 .25016 m
.2898 .25016 L
s
[(2)] .27105 .25016 1 0 Mshowa
.28355 .36788 m
.2898 .36788 L
s
[(3)] .27105 .36788 1 0 Mshowa
.28355 .4856 m
.2898 .4856 L
s
[(4)] .27105 .4856 1 0 Mshowa
.28355 .60332 m
.2898 .60332 L
s
[(5)] .27105 .60332 1 0 Mshowa
.125 Mabswid
.28355 .03826 m
.2873 .03826 L
s
.28355 .0618 m
.2873 .0618 L
s
.28355 .08535 m
.2873 .08535 L
s
.28355 .10889 m
.2873 .10889 L
s
.28355 .15598 m
.2873 .15598 L
s
.28355 .17952 m
.2873 .17952 L
s
.28355 .20307 m
.2873 .20307 L
s
.28355 .22661 m
.2873 .22661 L
s
.28355 .2737 m
.2873 .2737 L
s
.28355 .29724 m
.2873 .29724 L
s
.28355 .32079 m
.2873 .32079 L
s
.28355 .34433 m
.2873 .34433 L
s
.28355 .39142 m
.2873 .39142 L
s
.28355 .41497 m
.2873 .41497 L
s
.28355 .43851 m
.2873 .43851 L
s
.28355 .46205 m
.2873 .46205 L
s
.28355 .50914 m
.2873 .50914 L
s
.28355 .53269 m
.2873 .53269 L
s
.28355 .55623 m
.2873 .55623 L
s
.28355 .57977 m
.2873 .57977 L
s
.25 Mabswid
.28355 0 m
.28355 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.0068 w
.02381 .01472 m
.02381 .01472 L
s
.11039 .01472 m
.11039 .01472 L
s
.19697 .01472 m
.19697 .01472 L
s
.28355 .01472 m
.28355 .36788 L
s
.37013 .01472 m
.37013 .4856 L
s
.45671 .01472 m
.45671 .60332 L
s
.54329 .01472 m
.54329 .01472 L
s
.62987 .01472 m
.62987 .13244 L
s
.71645 .01472 m
.71645 .25016 L
s
.80303 .01472 m
.80303 .01472 L
s
.88961 .01472 m
.88961 .01472 L
s
.97619 .01472 m
.97619 .01472 L
s
.05 w
.02381 .01472 Mdot
.11039 .01472 Mdot
.19697 .01472 Mdot
.28355 .36788 Mdot
.37013 .4856 Mdot
.45671 .60332 Mdot
.54329 .01472 Mdot
.62987 .13244 Mdot
.71645 .25016 Mdot
.80303 .01472 Mdot
.88961 .01472 Mdot
.97619 .01472 Mdot
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 84.75},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000E1000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`007Woo0`008Goo0`004Goo0`003goo0P004Woo00<007ooOol0;Goo0`008Goo0`00
4Goo0`003goo0P004Woo00<007ooOol04goo000NOol00`00Oomoo`0QOol00`00Oomoo`0BOol00`00
Oomoo`0>Ool00`00Ool0000@Ool00`00Ool0000^Ool00`00Oomoo`0QOol00`00Oomoo`0BOol00`00
Oomoo`0>Ool00`00Ool0000@Ool00`00Ool0000DOol001Uoo`<000=oo`03001oogoo025oo`03001o
ogoo00moo`@000moo`03001oo`00011oo`03001oo`0002Uoo`<000=oo`03001oogoo025oo`03001o
ogoo00moo`@000moo`03001oo`00011oo`03001oo`0001Aoo`007goo00<007ooOol08Goo00<007oo
Ool03goo00<007oo000047oo0P004Woo00<007ooOol0;Woo00<007ooOol08Goo00<007ooOol03goo
00<007oo000047oo0P004Woo00<007ooOol04goo000NOol00`00Ool0000QOol00`00Ool0000AOol2
000@Ool00`00Oomoo`0@Ool00`00Ool0000^Ool00`00Ool0000QOol00`00Ool0000AOol2000@Ool0
0`00Oomoo`0@Ool00`00Ool0000DOol001moo`03001oogoo025oo`03001oogoo015oo`03001oogoo
00moo`80015oo`03001oogoo02ioo`03001oogoo025oo`03001oogoo015oo`03001oogoo00moo`80
015oo`03001oogoo01=oo`00ogoo8Goo000BOol30007Ool30006Ool30007Ool3000fOol30007Ool3
0006Ool3000ROol30007Ool30006Ool3000SOol3000JOol30007Ool30006Ool3000DOol0015oo`D0
00Eoo`D000Aoo`D000Eoo`D003Aoo`D000Eoo`D000Aoo`D0021oo`D000Eoo`D000Aoo`D000Moo`03
001oogoo01Moo`D001Qoo`D000Eoo`D000Aoo`D001=oo`004GooK`007gooK`004Woo000AOol50002
Ool00`00Oomoo`050002Ool00`00Ool000040002Ool00`00Oomoo`050002Ool01@00Oomoogoo0000
17oo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol00Woo00D007ooOomoo`0000Aoo`03001o
ogoo009oo`03001oogoo009oo`05001oogooOol00002Ool50002Ool00`00Oomoo`050002Ool00`00
Ool00004000POol50002Ool00`00Oomoo`050002Ool00`00Ool000040002Ool00`00Oomoo`02Ool0
0`00Oomoo`02Ool01@00Oomoogoo000017oo00<007ooOol00Woo00<007ooOol00Woo00<007oo0000
10000Woo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol00Woo00D007ooOomoo`00009oo`D0
009oo`03001oogoo00D0009oo`03001oo`0000@001=oo`004Woo0`001goo0`001Woo0`001goo0`00
1goo00<007ooOol01goo00<007ooOol01goo00<007ooOol01Woo00<007ooOol01goo00<007ooOol0
1Goo0`001goo0`001Woo0`008Woo0`001goo0`001Woo0`0027oo00<007ooOol01Woo00<007ooOol0
1goo00<007ooOol01Goo0`0027oo00<007ooOol01goo00<007ooOol01Goo0`001goo0`001Woo0`00
57oo000`Ool00`00Oomoo`06Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`06Ool00`00
Oomoo`07Ool00`00Oomoo`1KOol00`00Oomoo`06Ool00`00Oomoo`07Ool00`00Oomoo`0@Ool00`00
Oomoo`07Ool00`00Oomoo`0_Ool0031oo`03001oogoo00Ioo`03001oogoo00Moo`03001oogoo00Mo
o`03001oogoo00Ioo`03001oogoo00Moo`03001oogoo05]oo`03001oogoo00Ioo`03001oogoo00Mo
o`03001oogoo011oo`03001oogoo00Moo`03001oogoo02moo`00<7oo00<007ooOol01Woo00<007oo
Ool01goo00<007ooOol01goo00<007ooOol01Woo00<007ooOol01goo00<007ooOol0Fgoo00<007oo
Ool01Woo00<007ooOol01goo00<007ooOol047oo00<007ooOol01goo00<007ooOol0;goo000`Ool0
0`00Oomoo`06Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`06Ool00`00Oomoo`07Ool0
0`00Oomoo`1KOol00`00Oomoo`06Ool00`00Oomoo`07Ool00`00Oomoo`0@Ool00`00Oomoo`07Ool0
0`00Oomoo`0_Ool0031oo`03001oogoo00Ioo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo
00Ioo`03001oogoo00Moo`03001oogoo05]oo`03001oogoo00Ioo`03001oogoo00Moo`03001oogoo
011oo`03001oogoo00Moo`03001oogoo02moo`00<7oo00<007ooOol01Woo00<007ooOol01goo00<0
07ooOol01goo00<007ooOol01Woo00<007ooOol01goo00<007ooOol0Fgoo00<007ooOol01Woo00<0
07ooOol01goo00<007ooOol047oo00<007ooOol01goo00<007ooOol0;goo000`Ool00`00Oomoo`06
Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`06Ool00`00Oomoo`07Ool00`00Oomoo`1K
Ool00`00Oomoo`06Ool00`00Oomoo`07Ool00`00Oomoo`0@Ool00`00Oomoo`07Ool00`00Oomoo`0_
Ool0031oo`03001oogoo00Ioo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Ioo`03001o
ogoo00Moo`03001oogoo05]oo`03001oogoo00Ioo`03001oogoo00Moo`03001oogoo011oo`03001o
ogoo00Moo`03001oogoo02moo`00:Woo1@0000=oo`00Ool01Woo0`0027oo00<007ooOol01goo00<0
07ooOol01Woo00<007ooOol01goo00<007ooOol0EGoo1@0000=oo`00Ool01goo00<007ooOol01goo
00<007ooOol03goo0`0027oo00<007ooOol0;goo000/Ool01@00Oomoogoo00001Woo1@001goo00<0
07ooOol01goo00<007ooOol01Woo00<007ooOol01goo00<007ooOol0Egoo00D007ooOomoo`0000Qo
o`03001oogoo00Moo`03001oogoo00ioo`D000Moo`03001oogoo02moo`00;7oo00@007ooOomoo`80
00Eoo`D000Moo`03001oogoo00Moo`03001oogoo00Ioo`03001oogoo00Moo`03001oogoo05Moo`04
001oogooOol20007Ool00`00Oomoo`07Ool00`00Oomoo`0>Ool50007Ool00`00Oomoo`0_Ool002ao
o`05001oogooOol00006Ool50007Ool00`00Oomoo`07Ool00`00Oomoo`06Ool00`00Oomoo`07Ool0
0`00Oomoo`1GOol01@00Oomoogoo000027oo00<007ooOol01goo00<007ooOol03Woo1@001goo00<0
07ooOol0;goo000/Ool01@00Oomoogoo00001goo0`0027oo00<007ooOol01goo00<007ooOol01Woo
00<007ooOol01goo00<007ooOol0Egoo00D007ooOomoo`0000Qoo`03001oogoo00Moo`03001oogoo
00moo`<000Qoo`03001oogoo02moo`00:goo0P000goo00<007ooOol047oo00<007ooOol01goo00<0
07ooOol01Woo00<007ooOol01goo00<007ooOol0EWoo0P000goo00<007ooOol01Woo00<007ooOol0
1goo00<007ooOol06Woo00<007ooOol0;goo000`Ool00`00Oomoo`0@Ool00`00Oomoo`07Ool00`00
Oomoo`06Ool00`00Oomoo`07Ool00`00Oomoo`1KOol00`00Oomoo`06Ool00`00Oomoo`07Ool00`00
Oomoo`0JOol00`00Oomoo`0_Ool0031oo`03001oogoo011oo`03001oogoo00Moo`03001oogoo00Io
o`03001oogoo00Moo`03001oogoo05]oo`03001oogoo00Ioo`03001oogoo00Moo`03001oogoo01Yo
o`03001oogoo02moo`00<7oo00<007ooOol047oo00<007ooOol01goo00<007ooOol01Woo00<007oo
Ool01goo00<007ooOol0Fgoo00<007ooOol01Woo00<007ooOol01goo00<007ooOol06Woo00<007oo
Ool0;goo000`Ool00`00Oomoo`0@Ool00`00Oomoo`07Ool00`00Oomoo`06Ool00`00Oomoo`07Ool0
0`00Oomoo`1KOol00`00Oomoo`06Ool00`00Oomoo`07Ool00`00Oomoo`0JOol00`00Oomoo`0_Ool0
031oo`03001oogoo011oo`03001oogoo00Moo`03001oogoo00Ioo`03001oogoo00Moo`03001oogoo
05]oo`03001oogoo00Ioo`03001oogoo00Moo`03001oogoo01Yoo`03001oogoo02moo`00<7oo00<0
07ooOol047oo00<007ooOol01goo00<007ooOol01Woo00<007ooOol01goo00<007ooOol0Fgoo00<0
07ooOol01Woo00<007ooOol01goo00<007ooOol06Woo00<007ooOol0;goo000`Ool00`00Oomoo`0@
Ool00`00Oomoo`07Ool00`00Oomoo`06Ool00`00Oomoo`07Ool00`00Oomoo`1KOol00`00Oomoo`06
Ool00`00Oomoo`07Ool00`00Oomoo`0JOol00`00Oomoo`0_Ool002]oo`<0009oo`03001oogoo00mo
o`<000Qoo`03001oogoo00Ioo`03001oogoo00Moo`03001oogoo05Ioo`<0009oo`03001oogoo00Io
o`03001oogoo00Moo`03001oogoo01Qoo`<0035oo`00:goo00<007ooOol00Woo00<007ooOol03Woo
1@001goo00<007ooOol01Woo00<007ooOol01goo00<007ooOol0EWoo00<007ooOol00Woo00<007oo
Ool01Woo00<007ooOol01goo00<007ooOol05goo1@00<7oo000/Ool01000Oomoogoo0P003goo1@00
1goo00<007ooOol01Woo00<007ooOol01goo00<007ooOol0Egoo00@007ooOomoo`8000Moo`03001o
ogoo00Moo`03001oogoo01Moo`D0031oo`00;7oo00D007ooOomoo`00011oo`D000Moo`03001oogoo
00Ioo`03001oogoo00Moo`03001oogoo05Moo`05001oogooOol00008Ool00`00Oomoo`07Ool00`00
Oomoo`0GOol5000`Ool002]oo`03001oo`00009oo`03001oogoo00moo`<000Qoo`03001oogoo00Io
o`03001oogoo00Moo`03001oogoo05Ioo`03001oo`00009oo`03001oogoo00Ioo`03001oogoo00Mo
o`03001oogoo01Qoo`<0035oo`00;7oo00D007ooOomoo`0001aoo`03001oogoo00Ioo`03001oogoo
00Moo`03001oogoo05Moo`05001oogooOol00008Ool00`00Oomoo`07Ool00`00Oomoo`1<Ool0031o
o`03001oogoo01Yoo`03001oogoo00Ioo`03001oogoo00Moo`03001oogoo05]oo`03001oogoo00Io
o`03001oogoo00Moo`03001oogoo04aoo`00<7oo00<007ooOol06Woo00<007ooOol01Woo00<007oo
Ool01goo00<007ooOol0Fgoo00<007ooOol01Woo00<007ooOol01goo00<007ooOol0C7oo000`Ool0
0`00Oomoo`0JOol00`00Oomoo`06Ool00`00Oomoo`07Ool00`00Oomoo`1KOol00`00Oomoo`06Ool0
0`00Oomoo`07Ool00`00Oomoo`1<Ool0031oo`03001oogoo01Yoo`03001oogoo00Ioo`03001oogoo
00Moo`03001oogoo05]oo`03001oogoo00Ioo`03001oogoo00Moo`03001oogoo04aoo`00<7oo00<0
07ooOol06Woo00<007ooOol01Woo00<007ooOol01goo00<007ooOol0Fgoo00<007ooOol01Woo00<0
07ooOol01goo00<007ooOol0C7oo000`Ool00`00Oomoo`0JOol00`00Oomoo`06Ool00`00Oomoo`07
Ool00`00Oomoo`1KOol00`00Oomoo`06Ool00`00Oomoo`07Ool00`00Oomoo`1<Ool0031oo`03001o
ogoo01Yoo`03001oogoo00Ioo`03001oogoo00Moo`03001oogoo05]oo`03001oogoo00Ioo`03001o
ogoo00Moo`03001oogoo04aoo`00:goo0P000goo00<007ooOol067oo0`0027oo00<007ooOol01goo
00<007ooOol0EWoo0P000Woo0`001goo00<007ooOol01goo00<007ooOol0C7oo000]Ool01000Oomo
o`006Goo1@001goo00<007ooOol01goo00<007ooOol0F7oo1P001Woo00<007ooOol01goo00<007oo
Ool0C7oo000/Ool01000Oomoogoo0P0067oo1@001goo00<007ooOol01goo00<007ooOol0Egoo00<0
07oo000010001Woo00<007ooOol01goo00<007ooOol0C7oo000]Ool01000Oomoo`006Goo1@001goo
00<007ooOol01goo00<007ooOol0F7oo1P001Woo00<007ooOol01goo00<007ooOol0C7oo000[Ool0
0`00Ool00002Ool00`00Oomoo`0HOol30008Ool00`00Oomoo`07Ool00`00Oomoo`1FOol01000Ool0
07oo0`001goo00<007ooOol01goo00<007ooOol0C7oo000/Ool01@00Oomoogoo00009Goo00<007oo
Ool01goo00<007ooOol0Egoo00D007ooOomoo`0000Qoo`03001oogoo00Moo`03001oogoo04aoo`00
<7oo00<007ooOol08goo00<007ooOol01goo00<007ooOol0Fgoo00<007ooOol01Woo00<007ooOol0
1goo00<007ooOol0C7oo000`Ool00`00Oomoo`0SOol00`00Oomoo`07Ool00`00Oomoo`1KOol00`00
Oomoo`06Ool00`00Oomoo`07Ool00`00Oomoo`1<Ool0031oo`03001oogoo02=oo`03001oogoo00Mo
o`03001oogoo05]oo`03001oogoo00Ioo`03001oogoo00Moo`03001oogoo04aoo`00<7oo00<007oo
Ool08goo00<007ooOol01goo00<007ooOol0Fgoo00<007ooOol01Woo00<007ooOol01goo00<007oo
Ool0C7oo000`Ool00`00Oomoo`0SOol00`00Oomoo`07Ool00`00Oomoo`1KOol00`00Oomoo`06Ool0
0`00Oomoo`07Ool00`00Oomoo`1<Ool0031oo`03001oogoo02=oo`03001oogoo00Moo`03001oogoo
05]oo`03001oogoo00Ioo`03001oogoo00Moo`03001oogoo04aoo`00<7oo00<007ooOol08goo00<0
07ooOol01goo00<007ooOol0Fgoo00<007ooOol01Woo00<007ooOol01goo00<007ooOol0C7oo000/
Ool300000goo001oo`0SOol30008Ool00`00Oomoo`1GOol300000goo001oo`06Ool30008Ool00`00
Oomoo`1<Ool002eoo`04001oogoo000SOol50007Ool00`00Oomoo`1HOol01000Oomoo`001Woo1@00
1goo00<007ooOol0C7oo000[Ool400000goo0000000ROol50007Ool00`00Oomoo`1FOol400000goo
00000005Ool50007Ool00`00Oomoo`1<Ool002]oo`03001oo`00009oo`03001oogoo025oo`D000Mo
o`03001oogoo05Ioo`03001oo`00009oo`03001oogoo00Aoo`D000Moo`03001oogoo04aoo`00;7oo
0P000Woo00<007ooOol08Woo0`0027oo00<007ooOol0Egoo0P000Woo00<007ooOol01Goo0`0027oo
00<007ooOol0C7oo000]Ool01000Oomoo`00;goo00<007ooOol0F7oo00@007ooOol0019oo`03001o
ogoo04aoo`00<7oo00<007ooOol0;Goo00<007ooOol0Fgoo00<007ooOol047oo00<007ooOol0C7oo
000`Ool00`00Oomoo`0]Ool00`00Oomoo`1KOol00`00Oomoo`0@Ool00`00Oomoo`1<Ool0031oo`03
001oogoo02eoo`03001oogoo05]oo`03001oogoo011oo`03001oogoo04aoo`00<7oo00<007ooOol0
;Goo00<007ooOol0Fgoo00<007ooOol047oo00<007ooOol0C7oo000`Ool00`00Oomoo`0]Ool00`00
Oomoo`1KOol00`00Oomoo`0@Ool00`00Oomoo`1<Ool0031oo`03001oogoo02eoo`03001oogoo05]o
o`03001oogoo011oo`03001oogoo04aoo`00<7oo00<007ooOol0;Goo00<007ooOol0Fgoo00<007oo
Ool047oo00<007ooOol0C7oo000/Ool01@00Oomoogoo0000;Goo0`00FGoo00D007ooOomoo`00015o
o`<004eoo`00:goo00<007oo00000Woo00<007ooOol0:Woo1@00Egoo00<007oo00000Woo00<007oo
Ool03Woo1@00C7oo000]Ool00`00Oomoo`02000[Ool5001IOol00`00Oomoo`02000?Ool5001<Ool0
02]oo`8000=oo`03001oogoo02Yoo`D005Moo`8000=oo`03001oogoo00ioo`D004aoo`00:goo00<0
07ooOol00Woo00<007ooOol0:goo0`00F7oo00<007ooOol00Woo00<007ooOol03goo0`00CGoo000[
Ool3002;Ool3001TOol00?moob5oo`00ogoo8Goo003oOolQOol00001\
\>"],
  ImageRangeCache->{{{0, 287}, {83.75, 0}} -> {-0.0589635, -0.0147182, 
  0.00737954, 0.00737954}, {{7.9375, 137}, {81.75, 
  1.9375}} -> {-5.06778, -0.953189, 0.104698, 0.077002}, {{149.938, 279}, {
  81.75, 1.9375}} -> {-19.9349, -0.953189, 0.104698, 0.077002}}],

Cell[TextData[StyleBox[
"\t\tFigure 2. Example of circular shift."]], "SmallText"],

Cell[TextData[{
  "Circular convolution of finite length sequences ",
  Cell[BoxData[
      \(TraditionalForm\`x[n]\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`h[n]\)]],
  " both of length ",
  StyleBox["N ",
    FontSlant->"Italic"],
  "(the assumption of equal length is typical), is defined"
}], "Text"],

Cell[TextData[{
  "\t",
  Cell[BoxData[
      \(TraditionalForm
      \`y[n]\  = \ 
        \(\[Sum]\+\(i = 0\)\%\(N - 1\)x[i]\ \ h[\((n - i)\)\_N]\  = \ \ 
          \[Sum]\+\(i = 0\)\%\(N - 1\)h[i]\ \ x[\((n - i)\)\_N]\)\)]],
  " , \t",
  Cell[BoxData[
      \(TraditionalForm\`0 \[LessEqual] \ n\  \[LessEqual] \ N - 1\)]]
}], "NumberedEquation"],

Cell[TextData[{
  "where the operation ",
  Cell[BoxData[
      \(TraditionalForm\`\(( . )\)\_N\)]],
  " stands for ",
  StyleBox["Mod", "Program"],
  "[. , ",
  StyleBox["N",
    FontSlant->"Italic"],
  "]. Circular convolution is the same as periodic convolution if we consider \
the sequences ",
  Cell[BoxData[
      \(TraditionalForm\`x[n]\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`h[n]\)]],
  " to correspond to a single period of their respective infinite periodic \
extensions ",
  Cell[BoxData[
      \(TraditionalForm\`x\&~[n]\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`h\&~[n]\)]],
  ", i.e."
}], "Text"],

Cell[TextData[{
  "\t",
  Cell[BoxData[
      FormBox[GridBox[{
            {\(x[n]\  = \ \(x\&~\)[n], \), \(\ 
              0 \[LessEqual] n \[LessEqual] N - 1\)},
            {\(h[n]\  = \ \(h\&~\)[n], \), 
              \(0 \[LessEqual] n \[LessEqual] N - 1\)}
            }], TraditionalForm]]]
}], "Text"],

Cell["\<\
Circular convolution is important in the theory of signals since it arises as \
a consequence of a Discrete Fourier Transform (DFT) implementations of the \
convolution operation (which in turn leads to a fast algorithm). By \
comparison with linear convolution discussed in an earlier section, we \
calculate the circular convolution of the two example sequences.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(DiscreteConvolve[\[ScriptX], \ \[ScriptH]] // TableForm\)], "Input"],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {\(h\_0\ x\_0 + h\_2\ x\_4 + h\_1\ x\_5\)},
          {\(h\_1\ x\_0 + h\_0\ x\_1 + h\_2\ x\_5\)},
          {\(h\_2\ x\_0 + h\_1\ x\_1 + h\_0\ x\_2\)},
          {\(h\_2\ x\_1 + h\_1\ x\_2 + h\_0\ x\_3\)},
          {\(h\_2\ x\_2 + h\_1\ x\_3 + h\_0\ x\_4\)},
          {\(h\_2\ x\_3 + h\_1\ x\_4 + h\_0\ x\_5\)}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      TableForm[ {
        Plus[ 
          Times[ 
            Subscript[ h, 0], 
            Subscript[ x, 0]], 
          Times[ 
            Subscript[ h, 2], 
            Subscript[ x, 4]], 
          Times[ 
            Subscript[ h, 1], 
            Subscript[ x, 5]]], 
        Plus[ 
          Times[ 
            Subscript[ h, 1], 
            Subscript[ x, 0]], 
          Times[ 
            Subscript[ h, 0], 
            Subscript[ x, 1]], 
          Times[ 
            Subscript[ h, 2], 
            Subscript[ x, 5]]], 
        Plus[ 
          Times[ 
            Subscript[ h, 2], 
            Subscript[ x, 0]], 
          Times[ 
            Subscript[ h, 1], 
            Subscript[ x, 1]], 
          Times[ 
            Subscript[ h, 0], 
            Subscript[ x, 2]]], 
        Plus[ 
          Times[ 
            Subscript[ h, 2], 
            Subscript[ x, 1]], 
          Times[ 
            Subscript[ h, 1], 
            Subscript[ x, 2]], 
          Times[ 
            Subscript[ h, 0], 
            Subscript[ x, 3]]], 
        Plus[ 
          Times[ 
            Subscript[ h, 2], 
            Subscript[ x, 2]], 
          Times[ 
            Subscript[ h, 1], 
            Subscript[ x, 3]], 
          Times[ 
            Subscript[ h, 0], 
            Subscript[ x, 4]]], 
        Plus[ 
          Times[ 
            Subscript[ h, 2], 
            Subscript[ x, 3]], 
          Times[ 
            Subscript[ h, 1], 
            Subscript[ x, 4]], 
          Times[ 
            Subscript[ h, 0], 
            Subscript[ x, 5]]]}]]], "Output"]
}, Open  ]],

Cell[TextData[StyleBox[
"Note that the last five output samples are the same as the steady state \
outputs resulting from linear convolution of the two sequences. "]], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Drop[%, Length[\[ScriptH]] - 1]\  == \ 
      DiscreteConvolve[\[ScriptX], \ \[ScriptH], \ TransientSamples -> False]
        \)], "Input"],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "A matrix formulation of circular convolution leads to special matrices \
called ",
  StyleBox["circulant matrices",
    FontSlant->"Italic"],
  ". These matrices also have constant diagonals, but additionaly, each row \
and column is a rotated copy of the previous. Consider a circulant matrix \
\[ScriptCapitalC] formed from the elements of the impulse response sequence ",
  
  Cell[BoxData[
      \(TraditionalForm\`h[n]\)]],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(CirculantMatrix[Reverse[\[ScriptH]], {6, 6}]\  // MatrixForm\)], "Input",\

  CellLabel->"In[17]:="],

Cell[BoxData[
    TagBox[
      RowBox[{"(", GridBox[{
            {\(h\_0\), "0", "0", "0", \(h\_2\), \(h\_1\)},
            {\(h\_1\), \(h\_0\), "0", "0", "0", \(h\_2\)},
            {\(h\_2\), \(h\_1\), \(h\_0\), "0", "0", "0"},
            {"0", \(h\_2\), \(h\_1\), \(h\_0\), "0", "0"},
            {"0", "0", \(h\_2\), \(h\_1\), \(h\_0\), "0"},
            {"0", "0", "0", \(h\_2\), \(h\_1\), \(h\_0\)}
            }], ")"}],
      (MatrixForm[ #]&)]], "Output",
  CellLabel->"Out[17]//MatrixForm="]
}, Open  ]],

Cell[TextData[{
  StyleBox["A matrix product of \[ScriptCapitalC] with the "],
  StyleBox[Cell[BoxData[
      \(TraditionalForm\`N\)]]],
  StyleBox[" samples of the sequence "],
  StyleBox[Cell[BoxData[
      \(TraditionalForm\`x[n]\)]]],
  StyleBox[", will yield a result equivalent to that of (9)."]
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[ScriptY] = \[ScriptCapitalC] . \[ScriptX]; \n
    TableForm[\[ScriptY]]\)], "Input"],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {\(h\_0\ x\_0 + h\_2\ x\_4 + h\_1\ x\_5\)},
          {\(h\_1\ x\_0 + h\_0\ x\_1 + h\_2\ x\_5\)},
          {\(h\_2\ x\_0 + h\_1\ x\_1 + h\_0\ x\_2\)},
          {\(h\_2\ x\_1 + h\_1\ x\_2 + h\_0\ x\_3\)},
          {\(h\_2\ x\_2 + h\_1\ x\_3 + h\_0\ x\_4\)},
          {\(h\_2\ x\_3 + h\_1\ x\_4 + h\_0\ x\_5\)}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      TableForm[ {
        Plus[ 
          Times[ 
            Subscript[ h, 0], 
            Subscript[ x, 0]], 
          Times[ 
            Subscript[ h, 2], 
            Subscript[ x, 4]], 
          Times[ 
            Subscript[ h, 1], 
            Subscript[ x, 5]]], 
        Plus[ 
          Times[ 
            Subscript[ h, 1], 
            Subscript[ x, 0]], 
          Times[ 
            Subscript[ h, 0], 
            Subscript[ x, 1]], 
          Times[ 
            Subscript[ h, 2], 
            Subscript[ x, 5]]], 
        Plus[ 
          Times[ 
            Subscript[ h, 2], 
            Subscript[ x, 0]], 
          Times[ 
            Subscript[ h, 1], 
            Subscript[ x, 1]], 
          Times[ 
            Subscript[ h, 0], 
            Subscript[ x, 2]]], 
        Plus[ 
          Times[ 
            Subscript[ h, 2], 
            Subscript[ x, 1]], 
          Times[ 
            Subscript[ h, 1], 
            Subscript[ x, 2]], 
          Times[ 
            Subscript[ h, 0], 
            Subscript[ x, 3]]], 
        Plus[ 
          Times[ 
            Subscript[ h, 2], 
            Subscript[ x, 2]], 
          Times[ 
            Subscript[ h, 1], 
            Subscript[ x, 3]], 
          Times[ 
            Subscript[ h, 0], 
            Subscript[ x, 4]]], 
        Plus[ 
          Times[ 
            Subscript[ h, 2], 
            Subscript[ x, 3]], 
          Times[ 
            Subscript[ h, 1], 
            Subscript[ x, 4]], 
          Times[ 
            Subscript[ h, 0], 
            Subscript[ x, 5]]]}]]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["EXAMPLES", "Section"],

Cell["\<\
We now demonstrate convolution in action, by performing three typical image \
operations on one of the example images. A smoothing operation is frequently \
a first step in operations such as noise reduction, edge detection, \
interpolation, etc.  A  smoothing filter that is commonly used has constant \
impulse response coefficients. A differentiating filter is used to highlight \
edges in an image. Edge detection is an important step in many shape-based \
recognition tasks. The third example will demonstrate the use of convolution \
to \"sharpen\" an image by a method called unsharp masking. The simplest form \
of unsharp masking may be implemented by subtracting a scaled smoothed image \
from the original.\
\>", "Text"],

Cell[BoxData[
    \(\(A = Partition[ReadImage["\<lena128.bin\>", "\<RAW\>"], 128]; \)\)], 
  "Input",
  CellLabel->"In[28]:="],

Cell[TextData[{
  "Here we smooth (using separable convolution) and differentiate image ",
  Cell[BoxData[
      \(TraditionalForm\`A\)]],
  ","
}], "Caption"],

Cell[BoxData[
    \(A\_S = 
      DiscreteConvolve[A, \ \(1\/3. \) {1, 1, 1}, \ \(1\/3. \) {1, 1, 1}]; \n
    A\_D = DiscreteConvolve[A, 
        \ {{2. , \(-1. \), 2. }, {\(-1. \), \(-4. \), \(-1. \)}, {2. , 
            \(-1. \), 2. }}]; \)], "Input",
  CellLabel->"In[30]:="],

Cell["Here we compute a sharpened copy of the example image.", "Caption"],

Cell[BoxData[
    \(\(A\_U = \ 5\/4\ A\  - \ 1\/4\ A\_S; \)\)], "Input",
  CellLabel->"In[35]:="],

Cell["Here we display the three results.", "Caption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[
      GraphicsArray[
        \(ListDensityPlot[#, PlotRange -> All, Mesh -> False, 
              FrameTicks -> None, \ DisplayFunction \[Rule] Identity]\ &\)\ /@
          \ \ {A\_S, A\_D, A\_U}]]; \)\)], "Input",
  CellLabel->"In[36]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .3125 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.31746 0.00744048 0.31746 [
[ 0 0 0 0 ]
[ 1 .3125 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .3125 L
0 .3125 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.00744048 0.321429 0.30506 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00751202 0.0192308 0.00751202 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
128 string
128 128 8 [128 0 0 128 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
6D7279788597ADB2A49C9DADB8BAB39E77513B3E454C494C
4C4C50565D5C636264696C6F6362616464686B7774716C6F
74787B7C7F8284827F7F8081828384838484868585848383
8485868685817F7C797B84949FA7AAAAA9ADB1B5B6B8B9BA
AB9A89888993A8BFCCC9AD8C726C6A656161636665676E75
7770655B55565D66
5A55494A678FBBC5A99791A9B9BFBBA3794B2E2B2F38363D
3F3D3E4B514E4E4F5A57565B4C4B3F414447585D584D515D
676E73767A7D7E7E7D7F81818384878586878A8A8B8B8B8B
8C8D8F908F8D8B8B8B8D949DA6ADAFB3B5BDC3C9CBCFD1D4
AF8C67696D7B8C9DA19D8B7E7470665B5451525352566272
776C584336354157
2A23171B4686C7D7AD8F86A6BBC3C2AC7E4521181A1F1E26
282D2A42413B373A50433E362627282D3431413C2E242E43
5460696E7378797B7A7C80808283868787898C8E8F919394
95969998989798999D9FA3A6ACB2B6BDC4CED6DDE2E8ECE9
B17B4B5056616D7574726F7477716252484645423D405067
73684F311F1B2331
1C1E1C214A87C5D0A68985A7BDC5C5B18049231816171820
2227203832312F3F5B403A2D272926333A393D23160F1F34
475A676E7376797A7B7C7E8082858587888A8D8F8F909193
95979996959597989B9DA2A6ACB3B8BFC6D0D8E0E5EAEDD8
9B6548535B646B6F6E6C6868696961564B49464039384357
676B5D452E211C20
14171E294F86BABF977E84A7BDC5C4B8834B1D1A1716151A
1D201C2A25232A3F513A3B2A28252F3E3D4634220E0F1420
33495A666D7376797A7B7D8081838487898B8E8F90919294
95979694929395989A9DA1A7ADB4BCC3CBD3DBE4E9EDEFC4
88544E5960656B6D6D6A66615D5C5952484648453E373845
586867553E2B1E1A
171A25385C8BB2AF887582A7BDC4C5BB87511D1A13141417
201B191B22202F4448312A2A3937353C444F351C0F0E0E14
1E2D3B4B5A677076797B7C80828585888A8C8E8F91939394
939492918F919296999EA3A8AFB6BFC6CFD6DEE6ECEFEFB5
7B474F585E5F626465666C6E645449463F3D444B4A3F3437
485E69624C35251D
1E22314A6D93B0A57F7083A8BBC1C3BD8E5F281E12121415
231B1A1A2A2A363B382C2828312D35424E55331C0E0C0B0B
1423333A4148596974787C7F8284888A8C8D8F9092949596
94928F8E8F909195999FA5AAB1B9C2CBD3DAE2E9EEF1E8AC
744955595A56575759627D918966453833333C4A514A3A33
3D52646456402F25
262F405B7C9FB6A57F6F84A9BBC1C2BC956D361F0D0C1212
1F181919292B36322C231B272834344B5C623B1B0B090908
111D2E38413C404A61717B808386888C8C8C8D9093939494
92908C8C8E9092959BA1A7ADB3BBC5CDD6DEE6EBEFF1D79E
68505A5A564F4B47465887B3B6905F3E2C28303E4B4F4539
38455A625B47362B
2C394C6282A4BAA37D6F86AABBC1C2BB97723B220C0E1212
1914151524282E20191A222C1E2328545F6B40270D0A0805
0F20364248423C38485F76818587898C8C8C8E9193929192
908E8C8D8E9194989EA4A9AFB4BEC8D2DBE1E8EDF0F2C48D
59575D59514941352E4A8AC4D2B993633A2428323F4B4E45
3C3D4D5A5C4E3A2D
2A3544577BA4BCA0786A85AABAC0C1BA98743F2610141514
131112121D202318111317231B2D3C6468744C330D0A0706
0912253F575C50393546677E8588898B8B8B8E9193918F8D
8C8B8B8C8F92969CA1A7ACB2B9C3CED7DFE4EAEEF2F1B883
535C5C544B423624193B82C2D3CDC19F6637292E38434F4F
453D455359513D2C
21242C406C9FBA976E6385ABBAC0C1BA916D402E16131213
111413181F252114101117161D315371707049310D0D0B07
060917304B6164543938507384898A8B8B8C8E9293928F8C
8B8A8B8D9093989FA4AAB0B6BEC8D3DCE3E7EBEFF3E2A772
5259554B4034261610357DB9CACDD6CD995A3630353E4A50
4D4444505754402B
1A13112C619CB48A605984ABBAC0C0B8936F4B331E121212
1017171F222620151112111827526A725E5C412E11110E09
0807122741596867503B42617D87888B8D8F8F9191908C8A
8A8A8C8E92969BA1A6ADB3BAC3CDD6DEE5E9EDF1F5CD935B
4C4F494139312A252C4D82AEB8C3D4E4C1844C37383E454C
4F4C484E5657472F
1B0B01215D9CAE7F575685ADBBC0C0B7956E4D311F0E1010
121B1A2024252013120F131D3B596352413C37302219100B
0B070F1D334E606E654D43527385898B8E908F918F8E8C8A
8B8C909396999DA3A8AFB5BDC7D0D9E0E8ECEFF2F5BB7C3E
3D4344444343454B586E8A9EA2B0CAE6D8A66B473E424246
4B504F4F56574B36
240D00245F9BA677515486ADBBBFBEB6A0744F271B0F110F
10171B1E211F1D110D1215283F574E333331383C352B0F10
100F0F15243E576B72604B48617C878B8E9190908E8C8B89
8A8C9195989B9FA5ABB2B9C2CBD3DBE3E9EDF0F3EEB87942
3E48515960686F767E8B9497919CBCE0E6C08B5F4C494644
474E535255565041
2D16032A649DA2724F5588AEBBBEBDB5A5764B1B100D1616
12131A1B1D1B1B110D171D2733383E304136404B59452113
16161212192F4A64726E53495576868B8D8F90908E8C8B89
8A8D92969A9DA2A8AEB4BCC5CFD6DDE4EAEEF1F3DCB17759
53626E78808588898A8E92928B92B2DAEDD4A37559504B47
474A545554504E48
341A052F69A09E6B4B548AAFBCBFBFB6AC7749140B0D151A
1413191C1A181A1511172030323A38425153555B5F462515
1918151112233E5D6F755B4C4C6C80888B8D90918E8B8A89
8B8D92969CA0A5ABB0B8C0C9D2D9E0E5EAEEF1F3C6A4757A
757F868B8F8F908D89888B8F96A2BEDCEEE0B3866659524E
49494F5755514F4E
351A063371A69F6747548EB2BEC0C0B6AD7949140B0E1519
18141B1A1C161B14120F212A2928395A625D5057543B2514
20272A22131E33556A78665149617A86898C8E8F8B888789
8C8F94989EA2A8AEB4BBC3CCD4DCE2E7EBEFF2F0B08F6C8B
8B9191918F8E8E8C8783848DA2BAD2E4EEE7BF926E5E5653
4E4C4B5355524F4E
3316073979A99E63445490B3BEBFBEB4A77445160E0F0F1C
1C1B1B1A1E141B16140D1E2828253A5F6B69505046453B2F
2E2F2F261418274762756F5346527282868A8E8F8A86868A
8E91959BA0A5AAAFB6BEC7CFD7DEE4E9EDF1F4DD93706591
9395918F8D8C8D8B85807E8BAED0E5EAEEECCCA078635856
55544F505556534F
3114093F80AC9C5F415592B5BFC0BEB4A26F421B140F0C16
23242B1D22171B160F121B1F222C4F6C7B70596159533A31
323531281616203A5970745143496F80858A8C8C8988898D
8F92979CA2A6ABB0B8C1CAD1D9E0E6EBEEF2F5C2734E6091
959692908D8B8C8A86807B88AFD6EBEDEFF0DCB285665956
5B5C57515457554F
35150C4385AB96583E5594B6BEBFBDB49F6A3F1B170F0B15
202F3F34271214120D111720313D4F627B7F76757A7E6049
2D2A231C17131A2B4D69755142446A7E84888A8A88888B8F
9295999FA4A9ADB2BAC2CCD3DCE3E8ECEFF4F6A956315C91
959794918F8B8A8885807B82A7D1EDEEF0F2E9C6956A5552
5A5F5D5352575A56
3718104889AB90513A5796B7C0C3C0B6A4764A2219110D0B
1727493D2F0F13140F111A2B4853525D6F887F7A796B4A30
20251C1718171A213C5A6E504343697D8688898888898C90
92969BA0A6AAB0B5BCC4CDD5DDE4E9EDF0F5E6913C2A5C91
94969592918C8A8885827C7C9DC7E9EDEEF2F1D9A875544F
565F615853555858
3B1C164F8FAC8B4D375797B6C0C3C0B5A083532D15110F0D
0D1B4542390D15121817202E4C4E44536B907359646A5A30
1D2518141617181A304E654E4142677B8486888787888C91
94989DA2A8AEB5B9BFC5CED6DFE5EAEEF3F7CC78212E5D94
93969492928E8A8684837D798FB2D6E4EBF1F4E6BE865A4B
535D625C5452565B
391E1F5995AD8B4D395897B6C1C3C0B49A82502E10131412
0F0F35333C13181A26272C39555348556D94714B48443E19
191F15121719191827425B493C3F6579828388888A8B8D90
94979DA4ABB1B7BCC1C8D0D8E0E6EBF0F5EFAA580D315D92
93979492918E8A888686817B839AB9D0E1EDF4EED59E6B4C
4F59616057505156
3A272D689BAB884E3D5B97B5C0C1BFB2A28352260A101417
1612302D3B18241E34323639464A475771906D5544422D12
151A161316171818223D5447373A5F757F82868A8C8D8E91
94989EA5ACB3B9BFC4CAD2D9E1E6ECF1F6D586360B305A8A
92969393918F8C8A8987847F7D879AB3CFE5F2F1E4B57C50
4A535C605C555254
413B497A9EA47F493D5E98B4BFC0BEB1AD804E16090E151C
1A1424272F1723203A333A37484B5460747F676053472811
15191814181818161C374F4535375A737C82878B8E8F9091
959BA2A9B0B5BBC2C7CED5DCE3E8EDF2E0A35620162B527B
93969493918F8C8C8A88847F7B7F8897B7D7F0F2EBCA915A
454A545A5C595453
4B54698A9B946D403B6097B3BDBFBCB0BD97671E0C0E171E
201B222126182421363134303A485D708072686875562F0F
15181815191819171B33453E313859707880868C8F8F9092
969EA5ACB3B9C0C5CBD1D8DEE5E9EEE4B96E3119212A4E70
9394959493918D8C8986827C78797C7FA0C7EDF2EEDAAA6A
453D4B51575A5552
56688391907D5633355F95B0BBBDBBAEB4916827150F1420
303C372D262025243936352C41536C7C836256546B4E2E14
171A18171A1B1A191F333B322B3C5C70757E848B8F909091
949EA6AEB7BEC5CAD0D5DCE2E7EBE2BD7F4323232A2B4A6A
9494979593908D8B87827C756F7275728CB4E4EFEEE5C481
4A313F474E53534F
5B708B8878603F2A346194AFB8BBB9ADA893824E2D11121E
2D3A3E3638292C293F4D463E41516A7B83635659624B2619
171B19191A1A19191F2E3028283F5D6F747A80878B8E8D8E
9099A2AEBAC3CACFD4DADFE4E9DCB77950342F2D2F2E4E6D
95929694918E8A868179726962676D667AA2D9EDEDEAD8A4
6638343C43494C4A
5B6E7E6F57422C24356494AEB7BABDB29D7B79573C0E0C1E
2C374040482C3C3650504B4444586C777E69574C3F381E20
171B181A191916181B2726232943617176797F848A8C8C8D
8E959EABBAC7D1D5DADEE3E2CEA66B3F37383C3332315677
9A9193908D86837D756C655D585F67606F99D1EAEAEAE3C6
955C3A2F353C4346
515A5B49352B23293F6C97AFB7B9BCB39D7970624A20151F
23193038472D414C5A5957545152656B80776E523D372625
181C1A1B1717131619201F222C476373787A7F83888B8E8F
90929AA8BACAD5DADFDECCB38B5F2F213545433733345F81
9D8B8886817B767069625F5D5D636963739DD0E9E8E9E9E0
C4925E372A29343F
3D3F36281B1C21324E769DB1B8BABCB19C806D6243251B22
2C202D2B322F53635A424555596269687A76733B25252624
1618161815141317191C1A202C4762757C7D8285898C9194
96989CA7B7C9D6D6C4AA886C4326111C384A4A3C34355E84
99867A7A75726D6A68696A6D6F72726D7CA6D4EAE9EAEBE9
DFC0935A331E212F
23231A141018263F5D80A1B2B9BBB9AC957E7772532B2326
3220261C1E345A6E55474A5C626E746F6E64512B19222120
141717161413161A1D1E1B232B3F526671777C8183899098
9EA0A2A6ACB3AD9E8167452C1B17141C3649493D3331557E
9382707171737274767D808383837E7780A7D3EDEDECEDEB
E6DCC3935B2C191D
2018120E0D182D4B6A88A4B3BBBCBBAD8D7571674A242527
2D201D151738555F45444C696B887D7A5D4D321B141E1E1D
141618171615191C1F1F1F26282F38495A66707A7F87919C
A5A8A9A8A4A287693F291B191B1814183143493D322D4B75
918777787C8183878B9192918D89857E7DA0CCF0F2EFEEEE
EBE7DCC29B6C462E
4727110F12203655708BA3B3BCBFBDB08F6155514B2D2E2E
2E1B1A161B3B484C3D5362717681746848351C16171C1D1B
1416181818181C1D1E1F22252221293D51616E7A8189939F
A9ADAFACA397643E1B1D1B1C1E1D16192F3F463B2F28426F
9391888A8E919396979A9A97918C88807996C3EFF5F1EFEF
EFEEEAE0CCAF8E6F
793F111014263F5D748DA4B3BDC0BEB19161423F413A3A31
2C1C1B1B213D4347496272777677636444351715161C1D1D
1516161616191B1D1D1D23232324314659697681888E98A2
ABAEB1B1A9A172481E18171C1F2019192F3C44382D243E6D
949995999A9A999B9A9B9B98928D8A847A92BDEBF7F3F0F0
F1F0EFEBE8E0D2BA
9D561111142A4260728BA3B3BEC2BFB1916244454C443E30
2A19171A24414F5B5F6D6D6A656259706A55271314191C1B
13131416171C1B1C1E2023232C384B5F6F7B83898D90979E
A7ADB1B1AAA38354271313181C1D16152A3741362D25406F
969E9BA1A09F9C9B999A9B99948F8B857A8CB6E5F6F4F1F0
F2F2F1EEECEAE9E6
A35A121213283F5E728BA4B5BFC2BFB29161464454493D2D
251D181B27445368697365665C625C91937B341613191A19
131215171A1D1B1B1F232A2F404F5F6C7881878A8A8C9195
9A9DA0A2A2A09263361211141A1B161328333C312D26426D
979E9DA0A1A09F9D9C9D9C9994908D877C88B0DEF5F4F2F1
F2F2F1EEEDECECEC
A35B1414152438556F8BA6B6C1C4C1B39262454758503936
2C271D2131495B69605C5760606D68A0A7A55F3117191D1B
18151A1E2022201F2329323E505F6B747C84898B89898989
898B8F92929594784F25151216181712252F3A2E2D25446A
98A0A2A2A3A2A19F9D9D9C9995908E877E87ADDAF3F4F2F1
F3F3F2EEECEBEAEB
A35C17191A23324F6F8EA9B8C2C5C0B69A6A4A495C5A414A
3A3222283B5260664F4F4F58617577A098A1704E26171B19
1714191B20222223252E3C505F6971777F868C8D8985817F
7D80868C909293876C401F1114171A152B303B2A251E4168
989EA3A1A3A3A2A19E9E9C99979291898188ACD8F1F3F1F1
F2F3F1EEECEBEAEA
A45F1B1E1F25324F7393ACBAC3C5C1B6997855525D674F50
383123283553646D4E49454E5979809C96A0856F422B1A18
18141A1C242427292F38485D6A71757B838A908F88827C7C
7B86929DA2A09B95855C3013141518152C313B2821184068
999BA2A2A3A3A1A09D9B99979794918B848AAAD4EEF2F0EF
F0F1F1F0EFEDEBEA
A8621E212326314E7496ADBAC3C5C1B599785E54626C5B50
2F2A1F252A516171504D4A4A4F627392A0A28F795A381A11
151218172320282B3540506973797B80868D91897C6F676C
707C838E98968F8887714520121114162D3337261C15406A
9B99A0A2A5A3A09F9C9A98979694928E868BA6CDE9F0EFEE
EEEEEFF0F1F0EFEE
AB65222326272F4B7297ADB9C0C4C1B392705B53606E5D44
2A29271D20475A6A504B44484D565F7CACBBA17F664C250D
1312161928222D314149596F787D7F858A8F8F86796E6B71
757C7F8892948D84817B552F13111217273231271B12406A
99949DA1A4A29E9D9A9896979593918F888AA0C5E3ECEEED
ECECEEF0F1F1F0F0
AD68252527272D486E96ACB7BEC2C0B392634E4D606F5644
2F312D1E20384855473F4A506049486195B9AA886C593F22
1212131827212D374B535D737B7F84888B8C8B867E767478
7C7E7E89959F9C988E8B6C441D111219252F2E281B14426B
9890999FA3A29D9A989897989593918F89899EBEDCE8ECEC
EBEBECEEEEF0F0F0
AE6D2B2A2A292D496F97ACB6BABFBFB3936346465D70573D
3834391F29353F453A3B485C7255433B67919F99826E5232
1911111B241F2C41585D63747B81868B8E8D8F8E8F8F9192
929398AABAC5C1B9A4947D552B111219222E2E291B154468
8D84929B9F9F9C9998989897959392908B889CBAD7E3E9EC
EBEBEBECEDEFEFEF
AF6F2F2F2D2A2F4B7197ABB5B9BEBFB3926447455B705F45
343539282729333D424C646F77523F303C6289A68F786650
2F13151F241F2E455E6268767C82898D8F8F9396999A9B9B
9A999FB7CAD9D6D0B9A28F6E431C10161D272A291E1B4965
80798D9D9FA19D9B99999897949494918D889BB7D3DFE5EA
EBEAEAEAEBEDEEEF
B0723434312C304A7297ABB3B7BCBDB191644842586A6040
2E2D4134342937424A5E716D5B4B4332223C648D917B7166
5129131E201C2F445F626D777B80868D9194989C9FA0A0A0
9C9898A8B5C7CCCEBCA6947F52280F131A2429281E265066
6B68829D9FA09E9C9A9A9998969495938E8899B3CFDBE1E8
EAE9E9EAEBECEDED
B0733736342F30466C93A9B3B8BDBDB09064494554665E46
2C2E3A3E38353642526474583C3D403B1A29415C6968747F
774920181A18303F5A5C6F777B7F868E93969B9FA2A3A3A0
98908C949AA6B0BEB8AA978B663E191217222B2A1C2F5A6E
5C5A769CA0A19F9D9B9C9B9A98979794908B97B0CBD9DEE4
E8E9E9EBECEDECEB
AF743A38342F2B3D608CA7B3B9BDBDAF8F62484453615740
2F334143403F3D44595C5D34252C2E291129343B3C456489
9F7B3B170F0F2C3854556B747A7F8690979B9EA1A4A5A39D
91887773718297B2B7AF9A8E744B251116232E2B1B375F76
504E69959EA0A19E9B9C9B9A98979593918D94AAC5D7DBE0
E5E8E9EBECEDEBEB
AF763C3A352F25305284A6B5BDBFBDAE8E63514D5B625C49
38424346424747415F524C201D1E1A2019332F2C17174A7E
B09B692E0F0929344E5068747C838A92979CA0A2A4A5A39A
8A8274736C7588ACBFB8A09183613917111F2D2A193C677C
4B3F5A889C9FA29E9B9C9B9998989694939090A2BED5DBDD
E1E5E8EAEAEAEAEA
B0773D3B352C1D25467CA3B6BEC0BEAE8E63504C5C63614F
414C4D473B374542665D4B2116100C101C403E3E180D295E
94A88B551D0526314A4E66757D848B93999EA1A4A7A7A397
878073736D7990BBD0C5A7948A6F45200D1927251B41707D
462E4E7D9B9FA4A09D9B99989999969593918D99B3CFD9DA
DCE1E6E9E8E8E8EA
AF763C3A34291A21447AA3B7BEC0BDAD8C634F5263696852
4D494B3D3B3D4D4B5E574123100D0A18253D3F543C2D1D3B
5E8C9E763804222F494D66757E868D94999EA2A5A8A9A599
89817F847F8499C6DACCAA968D7D572F111525201E477B79
3D183F6E969EA4A09D9C9B9B9B9B989692918C92A8C4D7D8
D9DCE3E7E8E8E8E9
AD743A3833291B25477CA3B5BDBFBBAC8A5F45485D707559
4B46544633323C4E515135220F0B09152840476B55561D25
366DA295621D1D2A464D677780888F989FA3A6AAAEAEA99C
8C837F7E7C84A0CEDCCBA8968E81643B1C152620264C7F6E
380F37628D9CA3A4A19F9D9C9B9A979591908C8C9BB5CFD7
D7D8DEE3E7E9E8E8
AC713936322A1E284B7EA3B4BBBEBAAB885E45495A6C7064
584F564C3E3A364E504C2D1D140E061F283434616B743A20
224A91A2964E2F21404E6A79828A929AA3AAAFB2B4B3ADA1
948A837E7B86A7D1D8C6A4998F8571492817282131528266
350C2C547D97A0A5A19F9F9E9B99969491908F8A8FA5C2D4
D7D6D9DDE3E7E8E7
AC713936342D232C4E80A5B5BDC0BBAC896046445466716A
55525D5D49332B424C4B2B1C15120B1C2528294A6A71411C
173E77A9B37C411D394F6E7B848B949FA8B2B7BABAB8B1A5
978F88817E8BB0D8DAC5A59B908676522E1727233E587F5B
320F21456E939EA7A4A2A09D9A9897959392908C8998B3CC
D7D7D7DADEE2E4E5
AA723B38352F252D4F80A5B6BEC1BDAD8A61474758626C70
6759514E483831445353341C14130F1A231E223D67603712
0A2C5393B7A96B2F31506E7B848D96A1ACB7BCBDBBBAB3A9
9D958B85808EB5DADCC4A89D9086795833192522455E794E
261118395F8C9AA4A4A2A09D9B9999979594928F898FA2BE
D1D7D7D8DADBDEE1
A978434039342A325181A6B9C1C4BFAF8B63494858637277
76685C463A2C37455052362010111B2638393649574A220B
091F437BA4B0935A424C6C79848E99A5B0BABEBFBCBBB6AD
9F968D858090B9DCDDC5AB9D8F84795B351B212048677341
170F122F578397A0A5A3A09E9C9B9B99979594918C8B94AB
C3D4D9DAD8D7D8DA
A77B4A453D372C335282A7BAC2C5C0AF8B634A4958626F7B
7E715B49352A2D41534F42271A1322364B4D504F4A32180D
0C13335A92B6BC926357667986929DA6B1B8BCBCBBBAB6AE
A1978C868194BCDCDCC3AC9C8D817759381E1D19456D753F
0E0C10254C75939CA4A3A19E9B9B9A9A97969592908C8D97
AEC6D6DAD8D4D3D4
A77E514B433C31365483A8BBC4C7C1AF8B634B48545D677C
8B8B6E513828282F3E474C3D241927424F5A574E3C24140E
0E0E224478A1C0B88E68617688949EA5ACAEAFAFB0B3B3B0
A09588848399C2DDD9BEA99788796E54351D1A17456F7440
0F0E101B41678F98A2A2A19E9C9B9A9999999895928F8B8D
99B1C7D4D6D3D1D1
A77D534D473E33395885A9BBC4C8C1AF8A624C4A575E6166
717B76664E37251E353D573F301A2637474E614935161212
0F101028518DB2C9AF896B6F85929A9EA29E9896969DA0A6
9B908483859EC7DCD2B19C8A756457452E1A1D1A486C7746
190F1214385D8896A1A4A19D9B9B9A9B9A9A9A999794908A
8C99AEC1CBD0D1D0
A77F57534D463A405C88AABBC4C7C0AD88624D4D595F6058
5B6574746E5F3F25243E58472B111F314958634D2F171113
120F0916386E9BBDC1AA85757C8A9295938981858D9BA4A7
9A8A7E7D85A0CCD7C39F908A79614B36251C201F4A667447
221313132F527C939DA3A29E9D9C9C9C9B9D9C9D9996928E
898D97A6B3BFC8CC
9E7B57544F483D435E88A9BAC3C5BFAB87614C4D585F5F4D
4B485B6C818F7E593E3143332812212E4E6068492A161614
130D0A051E4C8AAFC9C3AF8C7E7E867F786F697185A4B0A6
917F7A7B87A4CECFB486787779694C2B19171C1C4A627446
2815161625476F919BA3A4A09E9C9D9D9C9D9D9E9C9A9692
8E8C8E929AA4B1BB
8B725653504B40465F89AABAC2C2BCA8855F4949555C5B53
4D43456490B3A9866040352E241F1F2C4B5E5D3C1E111E1D
1F0E0B0715356796B9CEC7B4907B6A5B534E515D85B6C9AB
866E717989A6CED0AB775B5F7A7A5B2711141615495A6A39
26181615193A648B989FA4A2A09D9D9C9D9E9F9F9D9C9996
93928F8C8B8F979F
7D6953504E493F465F89A9B8C0C0BAA7845D46454F56575A
5C54426092BFBD9F87533422262B312D424A472A11102524
210C0F1816254B83ADC1CFCBB3865F39312B2E3668A2AE82
5E5C707E8DA7C9D3B0713D3B667459220D0F0F104A596633
261B1714152C5880979DA4A4A29F9D9C9D9E9F9F9F9F9D9B
989795928C89888D
766654524F4B424A628BA9B8BFBFB9A7835C43404B535558
57564C6A93ADA7999C7E57322627323A45433C25130E2220
1C171C2616192C5F97BACCD4C9A7693B211A1B1E43676E54
4959748291A6C4D9C18C4834454E3E1B1416130E495C6331
251E171416224C729399A3A6A4A19D9D9D9FA0A1A0A1A09E
9B9B9997928E8A88
7A68575654504850678CA9B7BEBFB9A8845D433F49515659
57565366829196939A907C5B4834393A3C3B352820141D12
171D232215121C497DA8BDCDD2BF98613F2928223D474937
455E788598A9C1D5D0AB73534D453623221B130C485F6433
2421181416193E658B959FA6A5A3A09F9FA0A1A3A2A2A19F
9D9E9F9D9995908E
7A695A5A59544D536B8DA9B6BDBFB8A9845D43404953595A
5656565C6872828B968C785B52453E3A3633332725111717
252E27160F1314285A91B3C1CCC9B5947159534A574E5042
4B5A758DA3B2C3D1D6C9A9805B4239373624140B455B5D2C
21211B161616325A7F929BA6A7A5A3A1A1A2A4A5A5A3A2A0
A0A0A2A09B97928F
7A695A5B5C5852576E8FAAB7BDBEB7A8835D43404953595B
58595A5F6469747F918065475D6259322D2A322E291A1419
29271D10171B1519386693B1C6C1BFB0A791816F71656354
5B6D87A0AEB9C5CFD3D0C7B69F826B533D21110C45525424
1F211C161415274E728D98A5A8A7A5A4A3A4A6A7A6A3A2A2
A1A2A2A09B96928E
7968585A5B5852576D8EAAB7BDBEB7A7815C424049535A5B
58585A5F64696F7485785A4058706D4E3C342C301F1A1023
2B27191318211C112046769DB8C0B9BABCB9A68D82757772
778BA2B4BBC2CBD1D4D5D8D4C7B39B75481F0E164C555022
20221E1914141C40668896A1AAA8A7A6A6A9AAAAA7A4A2A1
A09E9D9B96928F8D
7D6A5759585650576E90AAB7BDBEB8A6835B43404C555A5C
5B5A5B5E656A6D6E7A79685A677C7A674F43272F1E1F0D17
22201A1413211E281B2E4A79A1B3B4B8C0C7BA9E8B7F848E
9FB1BCC0C1C8D0D5D7D9DFE5E9E3C78D4C1C0E26585C491F
2023211C14121330597F939DA8A9A8A8A8ACACAAA6A3A09E
9C9A979693939192
816D585957534C566E91A9B6BCBEB8A7835C44414C54595B
5B5A5A5D63686D6F7179757A737C797C674F29271A1B0F1B
25221B11131D1F2D1B25285A81A4AAB7C1C4C0B1ABA0A3A8
AFB6BBBEC4CCD5DADDDFE4E9EEECD39B531F123D64613B1C
1E22221D161311214972909AA6ABAAAAAAACABA8A49F9D9A
9996949596999799
85715A5A56524E597192A9B6BBBCB7A7845D45444E555859
5A5A5B5D63696D6E6E6E7A7C7D74777B745A3A281F191317
211F1D161919232F2F342A435E849EB1C1BEB9B8BEB8AEA7
A9AFB6BCC5CED7DCDFE4E7EBEFEACA914A1D164A6A5F2D14
1C22251F181310163A648A98A2ACABA9A6A5A3A19E9C9A9B
9C9B9A9A9C9E9E9E
87715A5A585350597191A8B5BABCB6A6825C42414B535658
595A5B5C686E736D6D698A8A8C6D70787A695038281B1E20
211714181A1822292E41303D3C698EAABBB4B2B5C6C2B7AB
A9ACB0B8C2CDD6DCE0E5E8ECEEE6BF803B16144D675E2712
181E231F1A14111029537D949DA9A9A5A19E9D9D9D9F9EA1
A2A2A2A1A2A2A19F
88715B5A5A56535A7190A8B5BABBB5A5835C413F49525557
5858595B676C716A6770A0A299686A6E7574654F3B262821
221213181A1C272A304639311D47739AABABADAFC4C3BEAF
ABACAEB5C0CCD6DCE0E4E7EBEBDDB06D2E15215A6D5C2511
151B21201A13100E1D436E8B97A2A5A09D9D9EA0A1A4A4A7
A7A8A7A5A4A3A2A1
89715B5B5A5750586E90A8B5BABAB3A3815A403D47515355
5556585A676C7068627CADBA9D6E676E72766F67583A2E21
21140E191E272827283A32240D26517B9596A6ADC6C5C2B6
AFB1B2B5BCC8D3DBDFE2E4E7E6D19F592316336974592510
12181E1F1B15100E13335D7F9097A1A0A1A3A5A7A8A9AAAA
AAAAA9A7A5A4A3A2
8A735D5C59564F5A6F91A9B6BBBBB4A280583E3B464E5154
5555575A5F6467665D8ABAD7A97D696F6F74757872543E2A
2519111D262F2C222E31321A09132A526D7B91A3BEC4C3B9
B2B5B9B7BAC1CFD8DEE0E0E2DEC38E4B2723507B8359240D
0F151B201D19100D0F264D70858F9DA4A7AAACACACABABA9
AAAAAAA9A8A6A5A2
8A75605E5956505B7192A9B6BBBBB3A27E573D3C464E5052
535456595F646664598BBAE7B89272727072767A7B67553E
34251D2A2E30272433342F190E0C172C44567493B4C2C6BE
B8B9BCBBBABDC7D1D9DDDDDED7B5804C373E5F82875B280A
0C12191E1D1A120F0E1C3C617B8B9BABAFAFAEAEACACAAA9
AAAAABA9A8A6A4A1
8B77625F5A57525D7394ABB7BCBBB4A37D553B3A444C5053
555557595E62635F598CB9E6B89673747173787B7D756F5D
4B342B33322A1D28323022191917131F2B496284A6BACAC7
C3C0C0BFBDBEC3CBD1D6D7DACDA575544E586B8593774214
0A0F151B1B19120F0E152C52708897A9B0AFAEADADADACA9
A9A9AAA9A8A6A4A1
8C78635F5C58545F7696ABB6BBBBB4A37E563D3D474D5051
535357585D5F5F59699CC4D9B0957875737376787978796D
5D433A3935291929272A1C20211B1722244551738BAEC8CF
CCC7C4C3C2C1C0C6CBD0D1D3BA9162575C6E778B98917640
210C1214171915120E122144678394A5B0B0AFADADACACAA
A8A8A8A7A5A4A2A0
8D77615E5B5856637997ACB6B9BAB4A37E553D3F494F5153
535356585D5C595D83B7D1CEA58C7477787577787A777B7B
715B4B3D35281D2724241B252D252034364D436577A0BBCB
D3CCC8C5C4C2C0C3C7CCCFD1B5835951626C7888A3AEAA83
51271413141716120D0F18355B7D92A0ADAFB0AEAEACACAA
A8A6A6A6A5A3A2A0
8C75605D5A5859677D98ABB5B8B9B4A37E563F414C515354
555455555858526C9FD7DDC9AD927D767C7A767678797A7B
796E6753432E2B2826191927342F253A3D472A4C5A8F9FBF
CBD0CBC7C5C4C2C4CACFD1D1BE9C6A5858697A8BA4B0BDB0
91542A10111617130F1114244B73919DA8AFB1AFAFACABAA
A7A6A6A5A4A2A2A0
8A735D5B59585B697F99ADB6B8B7B3A27E5640414C515355
5655555456544D7AACE3D7C1A58B7770797D7A75777A7C7E
817F7E6D5C433A2D2E221E243A423737383E273A3E5F799D
BFC7CCC7C6C7C7C8CCD0D3D5D2BC9B8773707383929AAAB9
B39456270F1214120F11141B3C678E9CA5ADB0B0AFACAAA9
A7A6A6A4A3A1A1A0
89705B5959575D6B829BAEB7B9B6B2A17E563F3F49515557
58565453534F5387BAE5D1B49E8C8070727B807D7B7C7D7B
7D828980745E53474131242035423C332E3E343A29364678
9CBCC4CACACCCFCFD0D1D3D4D7D9C6B79B99877E73768193
AAAD9152230E11101010141329537F98A1A9AEADACAAA9A7
A5A5A4A3A2A1A2A0
866E595858575D6C829CB0B9BAB7B2A07D553F3F49505255
55555555544C6293C9DEC7A38A807A6D6B757F81817E7F7C
7F8189857E746660575143343D494A3C2B40403D1D122040
729AB7C6CDD4D6D4D3D4D5D5D6D7DADBCEC4AC936E5C5E6E
829DA48D57291611101114151C3F6C919EA5ABAAAAAAA8A7
A4A4A3A2A2A2A09F
866E575657575E6D829CB0B9BAB8B2A17E563F3F48505255
54535455524974A2D7D6C09E8D85806E6D727C8487837F7D
7E808786837877746C5C4E3E4453625C484747422D1A0F20
3A7098BBC9D3D9D9D6D6D6D6D5D8DBDDDFE0D2BB9A816D62
6272909D91572C0E11101113122C5785999FA6A8A7A9A8A7
A3A3A2A2A2A2A0A0
866E555557585D6B819BAEB8BBBAB4A17C543F404B505252
5353555452487CA7D8C9B7A094867A6E7074777F8688857F
7F7F868A8A837A7A757064525B6E857A6252575957463E3B
3A5B80B0BDCED3D9D9D8D7D6D6D8DCDEDEE0E3DECCB7A38C
73606787A6975C240E11111312204673929BA2A8A9A9A6A5
A3A4A2A2A1A1A0A0
876E555455575C6A7F99ACB6BAB9B3A17D5540404C515454
5453545351487CA5D0BBAC9E99897C6E767A7B7E868A8983
8080868B918D8A867E72655D6F86948D7D73787C82777071
617081A9B4C1CBD2D5D8D7D5D5D7DBDDDFE1E3E5E5E2D9C2
A17F666C8FA97D3B0B0E1111131D3763869A9EA5A8A9A6A5
A3A3A2A2A2A2A1A1
886F5453525357677E98AAB5BAB9B29F7B5440404C515453
5353535352497BA3CCB3A3969180726D76807F7E80848B89
8582858B90969194898B82818694999891939AA2A7A5A4A7
999996AAAEB6BFC8D0D3D6D7D4D3D6DADCDFE2E4E4E4E8E5
CBA7807884B09B621D0E15141619294E78969EA3A8A8A5A4
A3A4A4A3A3A3A2A2
896F5251505054637C97ABB6BAB9B09E7A5541414D515454
53535555544C7FA7CDB19D8F8474686774818782817F868B
8B88888C93979E9F9994919B9CA39B9EA2A8ACAAACAEAFB0
B1B1B1AEB0B0B7BDC6CDD1D5D6D7D7D8D9DBDFE1E2E2E4E8
DDC6A6928BA4A979380D151415151C39648B9A9EA4A8A8A6
A4A5A5A5A5A5A5A4
8B7051504E5052617C98ACB6BAB8B09C795442434F535654
54535657575084ACD1B5A192816D5C5D677B84868180838B
8D8E8E909496999EA2A7A9AAA7A9ACAEB0ADB1AAADADB5B6
B9B8B8B5B2B0B5B7B9C0C8D4D4D9DADAD8D7DADDE0E0E2E5
E1D0B9AB9EA6B68B4F0E1617140F1427507A949CA0A6A8A7
A6A6A7A7A7A6A5A5
896E5152515353607997ADB6BBB8B09B7755444651555755
55555759595389B0D3B5A2927F6B5B5963717E8386868689
8C8F959497979DA2A6A8ADAFB2B1B1B4B4AFAFABB1AFB8BA
C0BEC1BDBCB9B9B9B8BCBECCD1DCDADCDBDADADCDFDFE0E2
E6DBCAB3A8ACC3A76B2411120F0E101A345F83989EA4A8A9
A8A7A8A8A7A5A4A4
8A6F5453535354607896ABB6BAB8AF997554434650565656
55545658595488AFCEB09C8C7A6A5C585F69767C848B898C
8B93979B96969CA8ADADB2B3B6B2B4B7B6B5B4B1B4B5BEC1
C5C4C6C4C3C1C0BDB9B9B9C0C4D2D6DCDADDDEDEDFDEDFDF
E2E1D5C4B9BECFC7863F1011100F10151F446D909CA0A7A9
A8A8A8A9A6A5A3A3
89705655565557627894AAB6BBB9AF99755343454D535356
53535456595584AAC8AA8F7E6E66605E6468747580868E90
919093969D9DA5ABB3B3B6B6B8B7B8BABAB7BABABFBEC3C4
C8C9CCCCCBCAC6C6C5C3BFBDC1CAD0DADADFDFE0E1E0DFDE
DFE2DFD2CFD2E4EBA6590E0D10100F10132C5681979DA4A8
A8A8A7A8A4A4A3A4
89705855575557637995A9B5BABAB09A765443444C525355
535353565A57769EB8A784706563625F6369727479838B93
949892979BA4A7ACB4B6B8B7B6B8B8BBBDBEC2BFC3C5C7C7
C7CACCCECECFCCC9C9C8C8C1C3C9CACBCCD6DDDDE1E1E2E0
DFE1E4DEDDDFEBF5BA6C1E0F1311100F1120406C8B9A9FA5
A8A8A8A7A4A4A3A3
88715957595759647A94A7B3B8B9B09B765443444C515455
545454575B5B6994ABA77D6961606163646B717374788690
9A9997909BA2ABADB6B9B9BBBABAB6BAC0C2C3C2C4C8C9CC
CCCFCED0D1D4D4D2D1D2D3D0D0D3CAC0B8C2D3DADFDEE4E4
E3E2E3E2E2E5EDF6D38538121612100D1117295078949CA2
A7AAA9A7A5A4A3A2
88705757575555617893A6B0B4B6AE9A765544444E535556
5757585A5F60608CA1A879625C5D6363646A707673757984
919D9C9696A1ACB4B7B8B8BBBBBAB7BCC1C5C6C6C7CDCFD3
D2D4CECDCFD6DAD9D9D9D8D8DBDAC5B0A3ADBAC5D4DDE3E4
E5E6E5E4E4E6EDF5ED9F51131615120E0E1217305A84989E
A3A9A9A7A5A4A4A2
876E55565655535F7692A5AFB3B3AB97745341444D545659
5A5A5A5D6265618EA3AB7A625C5D6467696D73777676787B
86929E999CA1AFB9BBBDBEC1C4C0BDBDC2C6C7CBCBD2D5DB
DADBD4CDCED5DDDEDFE0E0E3E3D5BDA69C9FA2A6A9BDD1DE
E1E5E9E7E6E6EBF3F8AA5C111516110D0C0F0F173B6B8F9B
9FA6A8A7A6A5A4A2
876B50525353505D7492A6AFB2B0A893725140434D545659
5B5C5C5F6366628FABAF7E5D5B6065666A6F7677787C7A79
7883949EA6ACB0B8B9BFC2C2C3C3C5C5C5C4C6CDD4D9DADA
DBDDDAD3D4D9E0E1E2E4E6E3D6BAA79EA09F968D80859EC2
D7E0E5EBEAE8EAF1FAAD5D0D1215120F0D11100F224F7E97
9CA2A6A7A6A5A5A3
886A4E5051514F5C7392A6B0B2AFA691704E3D3F48515559
5A5A5A5D61646383A4A8835F5D62636669717977797A7F7B
78778293A8B5B5B5B8BEC3C2C6C8CCCCC9C7C8CED5DADDDD
DCDEDED9DBDCE2E3E5EAEED6B795969BA2A29C87614B5986
B3D0E2EAEEEEEDF2FAAC5C0C141715110F1111111636648A
989DA3A7A6A6A6A4
886A4D4C4D4C4B597292A5AEAFAEA48F6D4C3A3C46505356
56575A5C606262739A9E885F5C62636568717A7B7C7B7C7C
7C7877819AACB7B9BEBFC1C1C6CCD0D1D0CDCED1D8DADDDD
E0E2E2E2E3E4E5E6E8EFE4B78B7A909EA3A29F8E65342643
72A5CAE7EEF1F5FAF9A9570C131717141213131516244875
919A9DA5A7A7A7A6
896A4C4A494747577294A7AFAFADA4916F4E3A3B444E5154
5356585C5F616265909790635C616468696D757B817E8080
847F7879859AAAB8C1C4C5C6C8CBCDD4D5D8D8D7D9D9DDDE
E1E3E3E2E4E6E7E9EEF6D2956970919EA1A09D8E6C3C1715
3161A0D0EDF0F4FBE1903E0B131719141413141616162B55
809499A0A5A8A8A7
8A6A4C4A494646577393A6AEAFAEA593704F3D3D474E5255
5557595E61626463838F8B695B616468696D737A7F838587
8786837E7D818FAABCCDCCCECBCBC9D2D7DCDCDBDEDCDDDD
E3E4E4E4E6E9EAEEF4F2B5795776929EA09F9C8E6E411D0B
0A2762A2CDDDE1E2BF7A310A101518151515161516121935
638694989FA7A9A8
8A6A4B4A4A47495A7593A5ADAEADA49271514040494E5356
5657595D62666867768A87735C626468686C70767C82888E
8988898D827B7B91A9C2CDD1CCCCCBD3D4D9DADFE2E2E0E0
E3E5E5E5E6E9ECF1F7DA965C5378929EA0A09D8F6F421E0C
0913407BAEBEBDBBA07134120D121618161616151312111D
406C899297A1A8AA
8C6A4A4B4C494B5B7692A4ACAFADA491725242404B505558
5958585D63696C6C6B7F7B7760646567696C6E72777F878E
8A8A8C90877D798696ABBCCAD2D4D2D4D1D7DAE1E5E4E2E3
E6E8E6E7E8EBEEF5E3AD6C4B5A7B939EA1A29D8F6D421D0C
10274A7190A19F9B978353230B0E14181815161412141215
264D758A939BA6AB
8C6948494A484A5B7793A5ADAFACA28F725242414C525557
5656585D62686C6F6E7A7B786866676A6A6B6D70757D8388
868A8D8F8984858B8F9AA8BECDD9DADBD7DADBE0E2E2E2E2
E4E9E9EBEBEEF2E4B9754A43607E939EA1A19D8F6E411B0C
1B3F67849191909196937442170A11171B18151313151314
1932587A8E97A2A9
8C6C4B484946485A7895A8AFB1ADA38E7152424250565856
5656585C61666B70717277736C66666A6B6C6B696D737A7D
81888D8C8A8A8E939398A4B6C2CED5DEDEE1DFDFE0DFE1E3
E7EAEAECEFF0DEB97C513C4C6681949EA1A29C8E6C3E1A14
315C7F919591909296988A6231110F151A19161211121213
15223E6283939BA2
8C72554A494749597795A8AFB0ACA28E7051424450575856
55575A5D61656A6F717276746F6664686A6E6F6E6C6E7276
7A848C8D8B8D919798A1A9B3B8BECAD8E1E4E1E0E0E0E1E4
E7EBECF1F5E0B77B554144516982969FA1A19C8F6D3D1D22
486F8A959692919395979781522915191818161111111212
131A2C496C86959A
917F645047464A5B7996A9B0B1ADA38F7052444651575958
5758595C61666A6D71717473716A6565676C6E6C6B696E72
79848A8C8A8F94999BA2B0B6B9B7C3CDD8DEE5E4E4E3E4E7
E9EDF0F5E8BC7E52464A4D576A83959FA1A09B8E6A3B2538
62839296949292949394969273482114111517130F101213
121622364F6D8694
97907A5D4A43485B7997A9B1B2AFA48F6F5243464E555759
5758595E63686A6C7173757576726966656B707474717070
757F8485838A90989CA3AFB9C3C1C5C7D0D4DBE0E7E9E9E8
E9EEF5F3CF915D494F5151586983969E9F9F9B8D6942364F
778E969694949394929394988A693B1A0D0F141713111114
11131A28364D6E87
909E8D6E5445475A7998AAB2B3B0A4906E51424650545758
5858595F666C6D6E717477777977706A65676C7073717073
777E818182878E969DA3B1BBC8CACDCACCD1D8DCDEE3E7EC
EFF4F9DFA66C51525556555A6B83969E9F9F998A694F4E69
889597959393929291929497998456260D0D121615120F11
1011131E29344A6C
789C9F83634844587999ABB3B3B1A4906D4E3F444F545757
58595A60676D6C6D707577777878807B73676B7072737374
777B818386898D939AA0AFBAC9CCCFD0D0D2D1D7D9E0E1E6
E9EADDAF7F5E585A5958565A6C84979FA09F98897163687E
9197979695949293929395979B967A481C0B0D1214130E0E
0E10111621242C46
5B8DAB95755447577899ABB3B1AFA4916E4E3E424F545655
58585B5F666B6B6D707476767877827C76686A6F7073757C
7D81838689898D909AA5B2BBC5C6CCCCD2D6D7D8D5D9DCE1
D5C4A6836A5E62605D5B595D6D83969FA09E968A7C777E8C
959695969594919392949697999B8F72401E0C0F1012110F
10121313191C1D27
4A80B3A488634D58789BABB1B1AFA49270503D404C515353
55565A5D6467696A6F737676787782837D716E757677797C
7C7F81878E9091949FACB6BCC1C5CBCCD1D2D7D9DADAD4C5
AC90746661676865615E5B606F85959D9E9B958F88888E94
96949494949392929292959799999F9D844F200C0D121314
1313131212161816
477BB5AC97775C5E789BABB0B0AEA69572533F424B505253
55575A5F64676A6C717577777879777A797B797B7B7A797E
7E80818790929699A4B1BBBFC2C5C9CACFD2D8D9DCCFBEA3
867064686B6C6C6863615E63718493999A98969392939797
9591929393939191909194949596A8C3C6994F1E0C101316
1614121111131612
467AB4B0A3896F6B7E9CABB0B0AEA796755543454E515355
55575A60666B6F7073767778787B777D7D807F83847E7A7C
7E80828A93999CA3A9B3B7BCC1C9CBCECED3D6D6CBB3997F
726B6E70706F6C6965626065738391959696969697999C99
969293949392918F8E8F9293929CB8DEF5D784360C0E1013
1515111111111211
4477AFB1AB9A837A839AA9AFAFAEA8967556464951545658
595B5E646A6F7273767778797A7D7B7B7E818383837F7B7F
8388898D959AA1A7ACB6BAC0C2C5C6CACED5CBC0A8927C73
717375767674716D6964626573818F939494979A9C9B9C9A
979595959492918F8E90919093A8CCEEFFEFA451140E1012
1515131110101110
4274ADB1B1A6958A8B9AA7ADAEADA6967657474A53565759
5B5D60646C7073747778797A7C7E7D7C7C7E7F8284817E7F
84898D8E939AA2AAAEB9B9BEBFC4C7CBC6BFAA9C857B7478
78777878797573706C67636672818E929495999C9E9E9D9D
9B9A98979793908D8D8E8F909DBCE1FAFCE1A25C26140D10
131515121110110F
4276ABAFB1ADA095929BA5ABADABA596775A494B53585A5B
5D5D62656C70727477797A7A7C7E7E7D7E7E7D7C7E808181
82878A8C9299A3A9B2BEC2C5C3BAB0ACA69E8B7F75777A7D
7C7A7A7A7A7775726E68646672818D9295979CA0A09F9E9F
9E9D9B999895928F8F909096AFD2EFFBEABF8E634226140F
1114171615110F0D
4277ABADB0B0AAA19CA0A7ABACAAA495775C4C4D54595B5A
5A5B6062686D70737678797A7B7C7B7C7E7D7C7B7D80807E
7E8083858A8F92979EA4A6A7A7A199938A807675777A7C7E
7D7B7A7B7B77736F6C68656772808C92979BA0A2A19F9FA0
A09F9E9D9C989491909091A2C3E5F9F5D09D74675C442713
0E12171A19140F0E
4278ABABADB0AEA9A5A5A9A9ABA8A394755A4C4F56595A59
58585D61676D70737477797B7C7B797B7E7F7D7B7B7F7F7E
7C7D7C7D818384858B8F8F8F8F877D77787B7B7A797B7C7E
7D7B7A7A7B7975706C69666974838E959A9EA2A3A3A1A0A1
A1A1A1A09E9A9795939198B4D8F3FAE3B180686B6E634927
130F171D1D18120F
4477AAABACB0B0B0ADACABA9A8A8A293745A4C5056595A5A
59595B60666D71747577797B7C7B797A7E807E7C7C7E7E7D
7D7C7C7B7C7A7875757472717377797B7E7F7E7D7C7D7B7C
7B79797A7C7A76716C6A676A758490989EA2A5A5A5A3A3A2
A3A2A3A3A19D9B989593A5C7E9FAF3CB976F676D75756849
291514181B191513
4577A8ABABADADB0B1B1AEA9A7A8A39474594C50585B5C5C
5A595B5F676E727576787A7B7D7C7A7A7E81807F7E7F7E7E
7E7E7E7B7A78767475757675787A7C7E808281807D7C7B7B
7B797A7A7C7A76726D6B686D7787949DA2A5A6A7A6A5A4A5
A4A4A4A3A29E9D9A969DB8DCF5F9DDAA7D686D7176787868
4A28171418181614
4476A7AAABABABAEB2B3AFAAA6A8A495755A4E4F585C5E5D
5C5B5D61676E737577797B7C7E7D7C7D7E80807F7E7E7D7D
7F80807D7A78777677777979797A7E80828381807D7C7B7A
79797A7B7C7A76726E69676C788897A1A5A7A7A8A7A7A5A5
A4A3A3A2A29F9D9A9BADCCEBF8ECBF8E6F6C737575757979
6A4A291611121214
4274A5A7A9A8A7A9AEB1B0ACA9A9A596785B4E4F585C5E5C
5B5B5D61666C7175777A7C7D7F7F7F7E7E7F7F807F7E7E7F
8182817E7D7A7978797A7C7C7D7E80828281807F7D7C7A7A
7A7A7B7D7D7A76716D67656B798B9BA4A7A8A8A8A7A8A5A4
A3A2A1A0A09E9C99A3BEDEF5F2D39F75676E74757474767C
7B6B4C2D1B151312
4171A4A6A8A7A6A6AAAEAFAEACABA496795D4D50585C5D5C
5C5C5E62696D7275797B7E7E7F8182807F7E7F7F807F7F7F
81818180807E7E7D7E7E7E7E7E7F818283818280807D7C7B
7B7C7D7F7E7A76716C6563697A8D9DA5A8AAA9A9A9A8A5A4
A2A1A09E9E9D9C9FB2D0ECF5E0B281696A71757674737579
7F7E6D4F2D181010
4271A3A4A6A6A4A2A6ACB0B1B1ACA494795E4E51595D5D5C
5C5C5F62696D73767A7C7D7F7F8181807F7F808081818181
81808181828080808181807F8081838483818282827E7C7D
7C7D7D7F7E7C76706A64636C7F92A0A6A8A9AAABAAA8A5A3
A2A09E9D9D9D9DA8C2E0F3EDC7956F666B70737575757678
7C807E6F51301A11
4372A5A5A6A5A3A2A3A9AEB3B4B1A693765D4E50585C5D5D
5D5C60626A6F75787A7C7D7E7E8081807F7F808182828281
8180828282818182818281817F81828382818382827E7E7E
7D7E7F7F7D79756E686365728597A2A6A6A7A9AAA9A7A5A3
A2A09E9E9E9DA2B7D4EDF2D8A679676A6F71747474737576
797C7F7D6B4E2E1A
5077A6A5A4A2A2A0A1A6ADB3B6B4A993755B4D50575B5B5B
5C5C5F62696F757A7B7D7D7D7E7F80807F80818283828281
808082818283848380807F807F818283818181817F7D7C7C
7C7E7E7D7C78746D6663697A8E9DA4A4A2A1A4A6A6A4A3A2
A1A0A0A0A1A0ADC6E2F2E6BC8B6C696F7172737474747575
76787A7E7B6D5033
708BA9A7A5A2A2A1A1A4AAB2B7B7AC97765B4E515A5B5D5D
5E5E5F63686F75797B7D7F7E808081818081818484848382
8283848384858683808180808182828181828382807E7C7C
7C7E7F7E7B76726C65646F8495A1A4A29E9FA1A4A4A2A1A1
A0A0A1A3A3A8BDD8EFF1D29E73666E727473747474747676
7778787A7A776A5D
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.35119 0.00744048 0.64881 0.30506 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00751202 0.0192308 0.00751202 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
128 string
128 128 8 [128 0 0 128 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
513E4D4A797894A1889B84878E91928C878F7D77657A6E7B
6E728876817B875E867F588D596C6B65667D6A836C807176
7A7B807F878588908C8D8B8B908B9090938C909091959797
999999999D9EA49EA5AFA2989091919D9EA29EA3A9ACAFB0
8898716A70716351565D68ADA98E8778767C777B7E7F8685
897E766B66766F53
97DCD0C5E48A757471C49D8C8A89827592ABB9B1A0A99FB3
A4A5B1A67BBEB78ED7A291C194D5BDA2B5ADB6769C9CA4A6
A09E9C989B9490949191928A968F8D8B938B918A8A878585
8985878382817E7A76777B80868E828C7C817A7A77756D6F
4BBEA5B4B2BBADB5B6B99A9979859DA8AEB0A59D9FA89788
8998B2BFC1BEACA7
6F9F8B8EBF71728468CA8E858B8A8B7E8A9E9E9490977F97
758B96AB499FAD49AD6892A14D9AA586C49F848096B18D86
8888918C90908A938D8E928B918A898C928D8A8D90918D8F
918D8E898E8D9091938C969091938D9590918E8F8E918D81
58D99A98969290928B9A949487848E928D918F8E91959280
8081948F9C988F95
8AA09197C27972756BC48D878B8D927A78A68D8785958E9B
898B7CA844ABB96CA460B8A78FD05C71886A9A7EB99B8F8F
888A8889908C8C93918E8F8D90998E918F8F928C8F8F8B8E
8D8B8C8C938F8D8E8F8D948E8B8C8A908C8D8C8C8C918B68
72BB838B8E8C888E87918D948D8A8193888783909699978F
7F84868E9697879C
9293888AB383727B84C48E83878688836FBA9C94929D9094
989C91BD6DB0B95E8B88BE52A89E89A8868A79BA94919898
8F8882868D8D898D8A8C938C878E8E90928E928E91948F96
8F918D9295928D938E908E8E91919591929490908D918E63
BDB7888E8E89919091938F93988E888C94998E909E94979D
8E868782929B919E
8FA29494A78B818698BF8B838C918F8665CC96A07D8A9380
95799D9E808EC16D7AA88853B1887DC1948D91878384939C
8E8E838184828D8F8F9292948D978B8F8E8A8B8C908F8B8F
8E8B8C8E8C8F8C908F909291958D918A8E8E8F8C8D8E8A4D
DF9A8D8A8E878C84838F9C929BAA8A8A8C968D7D8791939C
8F83858A8894908D
8AA6938AA6837C7794B78D838B8F8B8565BA7CA582969A85
9D69A4957F81B1616EBDA893A63E76B2488775B3988B928E
9DB0BFA89D82818187898F898D918E8D9290938E8E8B8B92
8F9392938D9291918E8E8D8D8E898E8D8E8F8F8D8D917A52
CD8F928D948F978D8D9E9C778FAEAA948A9190817B8B95A5
9A8A82808991998B
8D9F828796847F7D9EB886818B928A8972AA73A694899C82
9F76A58F7E6CAD729BAE56A0A6B7AFB6628CA2AA9989959A
8B747180BCAFAF847E8393908D938C8D8B8E908D908F8E8B
888B92928E92909293908E9092909390908E908C8E906887
B98A8886928F9890949B8B4B6099A2B3A692979683838999
9F928E818B8C9290
928E888B98777D739EB387858A918A8871AC71BA918E9786
997E9D939C87A36E979F7F8D7C8871B15EAD60A49085928E
968E9071717FAEBAA980868C8D938F8F8E91928C908E9391
8D9190908C8F8E8E908D8D9192918F908F8D908A8E8F5DC6
AB8A8987908A888891B69066787C8391B79E949797898089
9A969286868F9294
92837B94997C826FA7AB8086889089877BB079AC8B918F93
938A9394977B9D8E9FA7759D71C68DAA63A853BA8E918E95
959599918F71868DAF977B818B9288918F90918A8C8F8D90
8C928F8B8F90908F8D918F9093918C8B8D8C928D8F8A4FDD
948B8892938A8E8DA4C6806792996075A1B49A8A9396867E
979B998B818B8E96
9E8E8AA39E75796CBBAD838989948F8766B16B9E95887E8A
909D8A9D918399929B8F9A8FB4A3867D6BAA49B69291978B
96939590818774849CC08D81899190908D9191918D919490
9390949193928D908B928F8C918C8C8E908C918E8F6564B5
7F82868B8B878F97A8BC83548FAC755F7E9EA4908A95927C
8C989696848A8998
98A095BC9B737A6CC6A47D85898E8A8488C59486A6999697
8A927E9C86808A868A8678AF8CA65580839B5EC288898C89
94959F948E8F8B7F8BA8B380818C8A918C908E8F858D8B8E
8E908E8F908E8E928E908E8F928F8F8F8E8C918E8F63B7B3
878E8B92989DACAFACC2987B79AC7A777099A6A39390978C
818F8D958B898E9B
8A9F95B48B737B77D0A77E868E908A8A709A8372A0858D95
9094799C8A7BA08C9B8F9E8794476C84AB8888A3939B938B
9586968D8C947C8A708BB297828D94918B8F8C958E92958D
948F8F8E918F8D908E8E8F918D8B908C8F8E908E8E4BDA9D
8B9999A2A39D938C847B88818FAB7F76768BA0A0908C8A9A
8B8598918E7D8190
86A490BD7E767571CC9E7A828D8E8C898C7FAD79AB878B8D
8B9087999281999191AB7AB7859696BCC484AD9F4CBB9195
8E9699938D92848A8C73A4A37C808C8D8D928A938E8F918D
8E8E8C8C8D918D8F8E9091938C90908D8B8E8F8C7F59CCB6
A59F95918E84848183877B9798B19578767D969A99948B9D
9A868D91948C8B91
7CA793BC7A7D8179CC9A7E8291908A8A8D76C08B9E96918F
A795898A9D8194849592718F9A58AA96AA4FC08C728CBA8D
888499989AA1898B8B7C87C5918B8E8E8E91888F8D8B8F8F
958E938E8F919191908D908C8D8E928D8E8F908E6D8687A4
90938C85838180868E9689888DA7A3827C7A8F9C8C928A8A
998F8983948D878A
6FA38FBC6D7A7A74D0977F838E908D89954EBD889D9A7A7F
8D9B8889958F908AA09578AB9EAC83817880B5984066818B
8B83898A939F8A88898873C08D81868891908C928F90908E
938B928E90918D918D9390908E8D8E8E8C918D8D5FDB739E
8082847F898D8F8F8F938B8EA0A1A88A7F7D86A38F919789
899F8D84939C8F8E
6FAC9CB9727D7A80D7937D83918F88889856C492919A8A83
9183A07C9B8E9977979B986A6C82A19B848E6678819EC47E
AEA599AD91A5878F868B73A49A8D849193908B8B8894918C
918E918B908B8E8C8E8E8F8C8F8D8E9190918D8349FF6199
7E8A8D8D91938D8C91949198947B848B82847EA992879691
87A3948B898E8C8C
72AEA4AF7076747EDC8D79818C8B8884945EC0918E9388B5
81A19C7A958B947AA49298809DBE937469AFA0BE9DB5CEA4
A36B557B8A9D8D8F82857D8AC08D82888E8D8E928D96918E
8F918E8E9190918F8F8F8E918F908D928B928F6260F05B99
8594909092918B8A8D959497956A879888837F9DA08D9395
828E98918A8A9396
6BB0A3A56D7E7482D88D7C869296938E926EB78C98948A86
8471CE67AC92908A8F968689ABA2B2827F9599E15564393D
849182A4909D9C9B8E838573C88C8191948E8A8E8F969390
8E92928D908A9191928E8F8F8F8D8C8F8A8C8F53BCF1608F
8292908E8F909090919191A099718A9C8B867D8F9D969094
8B809199938A8D8D
73B7A8A06F787885DC897C858C8D86848D73B882899292A8
6B8F8B72B2897B89978F889996527F7C7281826072D0CCF0
93A29293958793928D7B8C6AD383808A8D918B8F8A8B898C
8D928F8E8E8F918E92888E8D8E8E8D938F928A39EFDB5694
84928D8A93918E8B888E8F9CA86A85958F87847D969D8F8F
937F8A9292858F95
60B6AEA0737A7893DA847B868E928A8B9184C49E94859B94
A87F8E1EBF99939C97A39198A579B0D15C917E8881274484
7A8E8887988B9A9E97718365D18C8B88928A938E9592918D
8B8F8D8C938E8F8E9191918F908D8E8D918F6241D8CE5696
87929288938C8F928E938F99AF6C7B928F88897A8CAFA098
98888C949A8D8389
68B9AC94727D739AD47F7D848C90858A7F786DAE8D86938E
8FB2AE40D9809E7C908F9A777F549AC46AAE6CB9DF51AAE3
66999493937E8C9DAC8F8B6CC08B84878D8A8D8F91919391
94938F8E8F908E8F938C928B908D8F8F90905A9DC3D1459D
878F918C908B90948D8F8B94AA78798F92888C7E7C9BA78E
9189878698969091
67BAAE8E737C759CD9828584908E888B8F8C569F95928F92
878EB42BC56D9C9D8386AD9CAC7CA4B3599D57CAD513B1B1
73949792968C928E9785826FC58983839B8A928C908E8D89
8B8E908D928B898F8F928F8C918D908F8D754ED0ABCC4595
8291918F8F8D8F938D8F8E93AA9687898A858E877A82B299
8D90898691958C89
6DC8AA90767D7197CD7F84818E8E8A89ADA4AEC38A8C848B
9F93C438CD66C774A26E988F5F7B9BA6708D32D7A066B09A
858B938A8E89928E97987175C69384839192918D8E8E918E
9191918A8C938E928D8C9289908D8F908B577FB892BF6991
848E8E928B92908D8E8D8A8C96A0908E8F7D8E8D7F70A8A3
928E8D878C9A998E
79C0A0887B7D7796C27B8384908E8B88893295A28E9D9187
828DA360A97D9764A8619D8AA58ABF8E959B6EB68474BEA9
8C86978D968A90939FA8756BC197889087908F8C8F909394
93919492949091918E9592909390918F5573A8B78EA08D7E
8C90929089928C8E8C908B8A8E95939EA778898D887498AB
9D858F8B8189938E
829C87807D7F7FA4C38484858E8E8986C53FD4B891949A81
8C98A875AB82B580AA789BAC7C838B7A8E8CC29A8758B58F
8685988B978791938FA06B75B98A818D8A94888B9289898F
898A8A8C8F8B8E8D8E8E8F888D8C8D688099D8998E94B86C
8F858F918C948F8E8E8E8F9094908690B66C888E8A7D809D
B68191958C868792
9F84897F838D80A3B58283838D8F8A89A31F9D8E997F8E96
9DAF9DA4A383AF84B969B6989F8DB0755D6A8F584B529A9D
8994938A918B8D988F99778AB6937D958C998D8C928E8C96
8D928B8C8F88958F8E908F91908F70718FA8A1927E8BC65E
988B948D8A8F8B8F8E8B8C898E99848DC66B7F8E8B857680
C895868D958E8997
AC768878839086A7AD89828A908E8B8AA482BF98C0939E94
543E5967B46A9486858783B48A6B98789C9AFCB0B5B9B0A0
838F8F9093858D908D937999AE8A818D89928B8A8B8A8F97
8E918B91948D8E8F908F908E8E647186C18C9799798ECD56
9F868E8A8D918C898B8A8D8B929A8081D27C79918C8C7E7C
C6B59680918E858C
A86A81858E9D86A5AA89838A908F9680A47A7D0BA18F91A5
8ACAB86F9A63DA72B45F559A8A9BA1899078A9694C9173A4
819088928C928B978B957C95A38A8792918F978F96908D92
9198928E8E859090918D8F84567687C4BC669F998698C550
9D8C90888F8F8B87908E929399A18080D18D76918C8E856D
8EA1B4968A8D8D8A
946F808B98A18CA7A39082868D9085708EA8C98098BDAC80
8F97BD46AB81B16F89C3A9A5B77797708F57859D8FC269A7
8D998F94879392978D98879B9C8E82898F92948C8D908F90
91908F918D8A8A8D8B7F616673A8CABB8D6997928199C03E
97928B87888E8E8E959C999B9EA0928EC3927092928F8C81
6A85B0AFA58D8D8A
88959F9F929E8495968487898F919880829BB5A267879E6A
8F899962AA92AF497A896A627AC07A9AD838AB80A49068A4
818B83908A938E918B938A978E9085878D8E9286918F8E8C
939698978F8A8C7960626DB3ACB6879784689D998598B94A
87A48B9593959A999B9C96938B8B8889AB8B6D8F95908C8F
8670868BB3A69587
8090959596A38B95988689868E90888C996B726190C1B060
A875A783A6A7617D93E59C8A9C8B769CAE6077A1A29D76A0
909494949295908E8D958FA5859282757E82828987918A88
8E8B8F9084784D6081C1C0BAA09393A59A708A97809ABD59
82A6909B9598989A8E8E85878887878B9C976787948E8A8D
8A877D84A5AEAC98
AC9C948D909D8E8E948D8F85918E89848EC8844F6DA0A56A
A68E9A999FAE5E738DA17EBC87BB459A7682ADA78D987DA1
92998E8B948F928A8C888D96809B968A8F9690959699968C
8F87899399AFA6E8B3AD928A898B8E9AA06E9399879DC16E
78A69F9C928C8B8D8789838A8C8F8C91A1B6708392928C93
8E8B85768EADC8C5
95BE9094959E8C8A84878A84939088858091E086A7AAAA60
B687808A9DA268B49B99667B7B666B9D74A4A58A938F7C92
878A8384928A8E8D8E908C8480A5AFAEAEAC9B999197908B
928E9193899560C68789968F85918C979D6D98957D98B371
75929189858E858A878E8A8F95908F8892BD737D8E908D8F
8D8C8B806E647197
3FB090899195829991949385908A868A818AAF896FA5A055
9F9783A0958A66CEAB9786967EAC81FC74CB86858F9D8199
93958F93948B8B9191919F88A5A4908580808685858C9084
91878C8A80916BC09488909388949196A667998E81A0BE73
7991898187918B8D91908B8A8C8E8D8C8FBE78798D938F8F
8B8D8D8C8F837560
38E7908E94A075958A8E8F849291888D878CB595678FA25F
AF937D999D9775A67170899893918DA251A5CA8998917C90
92948E9B95938D998B8B99869894868E868C8E8D8D8F8E84
8D8C868D868D6D95AA9593917F868694A162A0908BA2C073
7AA493918C978E9190908B8E92908E8A8CB584768C909190
938C918E908E8C88
35E7918E96A773938C8A93858E90848A828AB8888480AF87
95A78893A48E5F9B5E8E94A27AB87CBE00809F968F9D828E
968B87888A878A998A819F8F9581898D908A8F8B8F929289
91817D878A8E806FB994919890939899AD679C8F8088B766
76928A888B8D8D9295928F8E92908F8B92B392778A8D8E8E
908B8E8D8E8C8E90
31E48F8E8FA48299958B94858E90868B848CB295778E9EAC
65AE9D84AB8E79C0888499876BC571DC3AADA2C18F97938D
A296909695938D9C988D988D8A8A8E908C8D8C9091948F8F
959D9D9C8E8C8278B0A29A929186948DAA66A28E9386C671
8A8F949093928A8C878A888B8F8E8E8790AF97778A92908E
908B9191908E8A8A
3CEA968D8BA08F9B928691868C90848E8D8EC294747E9DBA
3BB59E5EABA551B37CABA3927F9363BF2E8A4A7AAF8E7F76
8D8286848A7E8C9284998F8B90908E8A918B908D8C8D8C91
959D9596A29E95728882A59584889280BE669C8B8E8DC565
928391888E8E8D939294918F928E968992A49675888F8F91
8D8C8D8F94959595
36E78F908A9895938D8691888E928989709195B97D8386B0
31ADA95998A731A69C8A8BA082B15CB57FBE88A380CE928D
A8889D989A88A48A909D928487908C95968F8E878D968F9B
8B9B8B8C9B95989A7273B39A9291987CA85F968A9B8EC854
9681978B8E908C928D8E8B8D8E888F8A8DA6957A84908F90
8D8E8F8C8E8B8E90
37E18F8A8B92919085848F888C8D868F8F7B8D83A2746AD6
62C09B82AEC637BB888C9A8E99846BB57498A98162879A8A
A17E9A838E75A97E7FA3838B89938F8E8E86848186837983
7479615A554469827B76A0B1838B9E88AD6E98928C92CC52
9E88998B90948E8D8A928E938F8D8E8D8BA49C7C858C9190
8E908E8C8E8E8C8F
3AE7978F8E919CA187878C8A8B8E858A86B0968995825DB7
9785AD7D9AC23EA37B937F998EAFA3867E3883B76E8CAC8C
8D7A9A95957CBD7D95A7898A87908B918C8F9292AFBABCC1
ABC0C1CECBB7BFBA977769A7958A95978E7F90938B96CD41
9B819383868C8D908D948E8F9092918E889E9E81888B8C90
8F938F8F918F8D8F
39DE918E8C8F96A685868D8E92958A86868CC1849CA154D1
8869948C909D538E9482C17BAC66B9A85A6C70AAB68892D1
9389A38B876FBB6E80A4828A8991918C8E8E8F898D857F80
7984889C939F9EA89DAB77AAB3898D938A858C9189A1D33B
A88C93908E9293938E938C8F8C908E8E8A9CA3818C8D8E8E
90908B8F8B8E8D92
3DDD948E919393A1868B8F8B8D8E8484868EB288838968B3
B040D082A5B293B48EAB87837C5AE5938E9F6D84A27A677C
A288989A7A8BBF7280A68A908D948D8D909395898E8A8B8B
8E8A86875D6A67666F996D77AB9189A08A8F8F8F7E9FC732
A989888F8A8B8D928E908C8E8D8E908D9195A67B89908A8E
90908F92918E8C90
40DC91898A95999C8384868D909388888591AF9D858E60C2
9B769687857B7E86A0A9BA6A9C54B0AD90C4706365AA8088
B28D959A8298C26A82998A908B918E87908C8F8A91908A8D
8E8F909769938B8887A18975ADA88E988483898F8AABBF37
BE9984978C938F928E908B91929390888E92AA7F88938B8A
8F8F8D8F90908E91
40D9948F86949B9988878A8E918D87868790A989A07E6088
B366AD67C8999A8674895557AB9573969A9975747CA3BC6E
87C88A8C6C8AAF599B90878A8A8E8A8B8F9391898F908C8B
8D8B93996E9C86858A9A8C757AA28E969198928987B3A34B
AEA0698D898F8A8F8E918F91918F8E8A918DA68083948E8C
8D91928E91918C8F
46D3918D8E90979A86848A8F949187878392AA8D8CA074AF
B19F759079AB9498908C8757D0B836AEAAAA93A16162A458
6F8FC1938499BA5BB0878A8E949897918E8F8F878E8C8B8F
868E939B8596746F7B998B8F7CB1A89391958B898DB67758
B2CB6D8E8A8F8E9290928A8E8E8F8E8F9393A78B8292938E
8A918F8E8C8E8E90
47DA8E8E8B8E89A78781878A8E8D89868B8DAC8A878D6B8E
A188A48A876D8C9EA872BF6BBDA131A194A57BCFA471B67B
5797A5AE8E8FBA4FB3858C8C8F8E8B8E8B93938F948C8A90
8F9C7A9675A6ADA5809E8D9078809E8C928E7A839CCE5669
98D46C85938A8E90908B888E8E8D888E8A899D927B8B8F8F
8A8E8F8E8C8F8D91
47DA8E8C94908DB490858E8B928E87868992C08EA3987C9E
A98D59B39C8A9D7F9C2DC78A9BAA80D2958F498BABACD756
73598EB2A686B356B789908B90918F8C89898C8C918B8B8E
8D999CDABAAFA891719C998F8884A7A292967F789AD4537C
8FC46B7697858C8F8F958E94958F949A8D8A99A081859391
8E8E8E908D8F8C8D
44D58B8B8C8E87B5958384858E8E8A848E889864818D828B
A79B5FA8886BA085B962ABA58E7EA2806FC165D387B2B25A
63884E8FBB8ABB56B38D888D8E8F8D9591928E8E918F8C8A
929D62866788988B5E8D9E878D7787A499A0887BA4C8436B
A5CC9C75A084929392908D8F8F8989938A8F94A489808B92
938E8D8D8F958E90
47D78E8A8A8C91B49689878A8E8E85868495BA9D958F846F
B773838DAB89CB7CA5506FA08A8C95AF779F60A464BCB5A2
9B935E57CF91B652B08C898C8E918D8E8B8E94908C8B8E8C
98A58A93879B989055889E8A8C8C7FA89E958D77B7C1445D
B6AD9E609280888D8B8D9092908E8D8F888F8C9D987B888E
928E8E8A8F948D90
48D5929192938EB090848888918E88898792AA8A7991957D
B98984BA9B73587C719F84B18F909B95879B839F0CD35BDA
B392955CABC6B555AE878D8F8E918D958F8F929291908E86
8C9489959A9CA193609CA18A8E897690A392926CBFA9545D
D49AB3708F8E8A9397928F8D8B8D8D9391958895A285838D
9292938A8C8E8991
4AD391898E8988A98D7E868A8E91878B8698A69986856680
D0987765A6C593CE7BA0AF9A7C9C93AA519D829D55BB5BB3
A555A1318092ED67B1868A8B8E908C8C8C8A918E898C898F
96978891939897805EAD9292938F8688AF939863C992665F
D887AD847A997E8A8C8A8B8F90948D8F91928D93A1957F89
8F8F948B8D8B8B90
49D69589908F91B39783898E9290878C8399A88A94A0976C
6C8F8E76957898B0457588937D92929D7297C6AF5A7551B1
B098A08F3357BC81AD7D8C8A90918D958D8F8A8E8B8E8B8D
908E8D8F96999F7E6DAE8B8F8D8B8276A18F9F60DA74675D
C67DA29D729C868D9394908C918E908E908F888E9AA08C80
8A90959293908B8E
48D1938F918E88A5947F89898A8B86887E96A694978897A1
96B3886A8A937AB3768AB19E8F908AA88788BA906C76AFAC
96A4749C7D73C1C69E7C8A8A918D90928B8B878F8D8D8891
90948895929D966D70A489908D918B79A9A49A60D65F7688
B78297BD6A8F858A8A908C8F91908E8E908E8C918DA09284
818C908D908F8E8A
4FD68F9690908FAC9581868D8E90878E859BA089827A9380
95A8AE93B882A595769773AD8E8BA89A9E9CA6B75E8ABB8E
84B68F908A41809BDF7E8A8D938D8E918C8D8D8F91928990
8E8F868E92A097717CA48E8F91928C76A2A18E70E2516EAE
AE868CBA788699848F8F8F8D938C8D8C91908E8D8D959C90
828B8F8C90929191
56C17E878B8989A79882888B8D8E868A8399A38E9B8F8F74
515E799695AA927A8771977AB5938B776E4DA67385819191
8EA69776998C5189A2B18591938E918E8A898A8A8A8E878A
8D9B889997A8926F87958C8B928F89729E988E7CDF4558BE
A69185AA85709B848F918E8E8B9189908E8E8F8E92919B9B
8F7E86888F93918E
5BC88C9A94928DAE9684888B8C8C858A8399A78C929193B4
A7B1A1907189B27277A67E90A093879A749E6B8484A89996
8A88AB939284705B87AA91898988908D8B858982848B8991
869C848E94A1896D8D928C888D888E7A9D9E8E8CDE4753B7
99958DA1B0689A838C8B8F8D939290929090908F908A8D9F
98907E848A909190
5FBE8E8A8F878BA8948089898D90878C8597A485908E8C7B
664A7AB99DA1A89DD070B02BB3958C8CA882D05EC2928C98
8B8DA1997B8D8B8C74AABB8C85868C868F899797828E7C7C
7B9C8A91949F8764938D8D897F9381769A99997ADA4D78B9
9B8A928EBF7092918B8F92918E8E8D918D8D8A8D9290908F
A0988E83848A8C8E
5CBF8E8D91958EB092848C8A8F8A83878799A38A8D8A8A98
AF856D7A9A929EC07F897F7CA99B888BA08A7B7BA09C7D8D
928C91BAA291797B678A9DBA8A8A978D878C9EA8ABBFB5A1
95A0928C9D9E8B5F989E9CA5AFB9B28B9A9E817ED23D7696
9199987CAD787C9483888E8F928C918D8D958D908A8C8B8F
91A196928C818287
59B28E878B8680A38F838A868E8D868C8A97A18E888C8D8B
E3A89D72536C8BA3D2699A45BDA7A97F9B5D717095959B8C
94848B99A0888B8E935B9396AF898B7293847D9569777375
878E90969C9C8953B2917F67616D9A9B8E8C8380DC379C8B
99909F81AB9E6F968F8B918B928D928C8F92888F8F919090
9093959A9E928982
69AC938F8F908DB091898C87948A898A87959F8E878E8D7D
7B77B0E99677436099C8BE99809F8087AF6292A3968AAB6A
B3948C96B393887B769363928BAE7282AB7D93AB9D676E7F
A98B8A89929187699BB68DAF9A448EA594A19593D51CB185
91908D80A0B6738991838F8F90928F8D91928B8F8F8D8C90
8B8E8C8E9A9D9C92
82AD938D918D8BAC8E858986928B868C869AA69089908A93
927895C7567BB572865AAA918682A883C16A73B295A09B45
94938F9D8EACAE8397878F638E96C59CBF8188AC9B554672
A2959C9A95998E6083A7ACBEAA3D93AB8D8F898CDC17C89D
9897988B94A87E749D86908D8C90918F8F908C91908E8B95
8D938D91909498A1
77A19291908F88AC918B8B87948A888D8398A38E92918D96
8A8E88AB484CA48E9170BBAB8F9D7388A5908C92A0899F59
AAB26F9263A490896C8EA18C5F9D86C5A38FB0A7A35972C6
D5918C889498947C6BBCB0BB7A3D98A5968C9591D80EB49C
80899C8E8EA2A765998989918B918F908F908C8F908F8B90
8C8D8D8C8A928A8F
78A68E8B92918CA78F858C88908E8690829DA28C908D8A96
8C938FBE9281A78281888692D69DBB606B8C8E7EAE84A889
BE7570908CA4ABB0767A728D85609383CE99AD9EEC9ADDC3
95688C818F938E84697386CACBB2D19E8D858E92DB0FA3AA
8085968D879ABA668E95828E8D8E93938F918E8E8F8E8B90
90928E8E91938B92
7AA58D8B8B8B8AA18E868D8A908E84887B9F9D8E928D888C
8991898E9D8FA68786635D34585C9CBE889D9E5BA5768E9C
9D9288B4A4809F9D9972A9878588748582A48B81B0629387
748BA28D9A968E8A8D7D838B75718D7F8D909C93D215A1AF
8F889D938E8FB17680A2868E948D8F8D8D92908E8F91918E
948F8A888A8E868F
7AA38D8E8E8A90A396888D898E8E878D81A0988F928E8792
94988F91928C98889F78D8CECC58A4979B8BA18E97AB986D
75538EA1877F87C08A7E79868E7DA86A858189668033828A
BFCCAD8A87928A8A93877C8FA7C0C1837B809A8ED51EBCA3
8C858D94888EA4926F9C89858D8C8D8F8D918C8B8B928F8B
8D8E8C8B928D8D92
7AA890918C8A8C99918389898E91898F81A09C8E918D8D8F
8B8D87908B8B90958E67B3EFA96483A59E9786955A9B98AA
9FA39E8D8585899FBB978D9974859E9E69869693D4A6CCB6
8F7C677891958F8C96918F786A66798CAFA89AA1BB35BF9B
8E8C879892909DAB6C90957F918E92929293919090908E8C
8B8C888D8E958E93
79AD8F8F8C908EA6948E8B8C8F8A8588859CA491928D8D8E
91929890928F9390A25F6673726594837E9378BF5FB5877B
847CA5958FA36BB095A790718C668EA583857E849F8F7771
74808192909087888F8F8F8E8A7C696C979C9DA48A33B884
93948697908B92AF787C9F878E908C91898C868B8C8D8E91
919494928E969096
6CA98A918B908EA38C87878B8F8E878B83979F898C888A8C
8D8C928E8D8A8B8F9A9B86BA839680956FAA8BBA6BA797A8
7C7C8E889CA1698E47BB8CC76D9F839E8381976C97848C8C
8F918E8F928A8C9092908E8E8E8A797F959E9FB2586CB595
8E8C838C949290A9966D998D888E8D928E8D8A8D908F9290
918E96959195868E
71AE8D908E9099A08E8B888C8E8F888B849CA09190929390
8E8B908E95928C8B8791AB81AF988C837E8CA7A47B8E9E84
9986A48E8E87A5A594D39BB6886F99877D87AB8B82889B95
93898A8F938C8D8D898D8E8C8B82728E94A59DA33F8EBE92
8F88938D90908A9DB46D8694818F8A8F8C8A8D908B929092
9093948E898E8793
72AB8B908E8D8F97898D888D8F8E868A80999D8D848D8B90
9290928EA17FA2908F8EB028A3968F988A739397909E9D7A
9497858A8A869C7D699616CA8D90908E837DAB8A8C799697
969C8D928E8A8C918B908D918E8376989AA59AB12E96A997
928691868E988C8BB27D759F888989909593969792999593
8A8A8F8A918E8C93
73AA8F8C8D8894A0968A8B8B8E8C868E869AA6968A8F898D
8B8E8E908B67828E8BAEBC2ECD88908B867F89969094B55A
98978A999693AA6898AE3CCB9B92718B7A83AA7692769289
8C909594928D90948D938D8C8D7E7599A2A8B6C84B9A9D91
948A8F8B88988F85B09D749490838D9093919397898C8790
888F898D928E8C8F
74AD928F8F8E8AA18D87888A8E8E868B80939F938D929091
8C8E8F8DA688A38D8CB67549BEAB92A190928A8F8A78BB71
98A28BA082988793A9B564BAA99E8E768E70B878AA879599
9090879792868A8A87928D8B887A8298A89C857B40A6AC94
948B928E8A95948F9BA6737D9D8293979591898C8D8B8F8E
8C94908F928E8D8F
75A9908E8D938AA98E8D8C8A92908B8E8696A18E868B8C95
9294968D8C8C888E8AD54E6098AC8D8E86958587807AC594
8F97979579858E85B65C7F9095B8889F7188A265867F7E93
9F8C8B8F9C89928D8A94918F887D8D9EC198B171629EA38E
93898A9682968D8E91A98A799A8F868E888C898F908E958C
8E8D8C8E918F908E
77A789908D938DA58A898A888C8A838B849FA89390918B8B
898A918F8F908B8E86E2358469B38A8E8C938C848371A67F
8F9797A9749F8C86987092A18891AB959989A979918A8C8A
989180939993958C838F8D918A7599AC979F9C876A83A995
958D918B838D8F978FA39B7C919C898A8E928D918C8C8F8F
93908E8B8C8A8A8E
7BA98B91908D8CA28A8C8D8A928C888C7F969B8886938E92
948D948F928C8B8C96DA489357B4799C96919A999984927E
989B8A9071969C9D7F8C9B8BA18A90B689C4A595A37F958E
9794928E928A979687908889767CA5918B7E8D82868FCAB1
93908D90889489958C909E87759B86818A8C8E8E918D918D
8F8C8E8E94918F92
78A290928D908FA48D8A8687908E888D859EAB9192938B8E
8F8B92898D8C8B8DBCB0619E76C19D8A90898187858A8F6A
8E869E8A8294A3AA50AB997F8F8383AB60AE4D937B7C7783
8E8E8A93898E8E908E9C938D6C98919D7C9F8FA071569E93
CD8C91899594889D8F92A29E769599868F8F938F908E8D90
90918E8B8F8E8F8C
76A38D8B8890929C8C8A8B8C908C85877F9DA18A868E8B93
908F948A958C90ABA37154B168A483878E989A889492998F
94A1A093938A88AD66A79E83889EA4A676C763C29590936D
908B8F8C8E919294868D92978BA3C991937886919F756C6F
95CC9591938A7E8E948E95A182849D898A8A9389938D8E8F
8E92908F918E8E90
7BA2979090968E988E8E8B8A908F888B839D9F888990908E
928F948B8C8889BA826A80A69399B995839398938E938E7F
7E7C9C87B1969B929085A089788E92903BBB71D749B3799E
768E94978D8C9697938D8C8771B8A3C57190AB858A878D49
8A78BF8C8F918A9495928C9C96698D90858E9288928F8E8E
8D928E8C908E938E
74A7918C8E9192968E8B8A8B938F8886869CA58C908E8C8A
8B8A9092968A90CA48817487717189908079938D8A899191
9982876898999D819F90B0A0797FAEA364A481CF507D955B
A76E8A928F8A91928A8E938D7F5893C0AEC1966B7C768792
5B8888D1928E8C8E908D8DA6B77687988E8C928A918F8E90
908E8D8B938E8E8C
78A794898F8F9496908B8887908C8A84869C9D8D858F9192
928C8F908B8BA8D05B948298B98CA5A49F848E9D96968E8E
928A8B7D8D759FA09B78959E8C5D77B99BAF6EBE95E486A2
5BA47594998B8E8E8E908F8D908F578761B096ABA79D8678
834E838BCC8E888A978E8B86A5876D8F8C888C8B8E8C8C91
8D908E91928E8E8E
6FAB938B979191918C8E8B8B91908D868599A091908F868D
878F958D8F8DB6876E887A9AA576769B969187808D8B9586
9E8E9287988973927B92AEA6C99889A082A04E908299CA77
9E6F898A878E8E909092908F9391908B6A8373B0C0B7ADA5
92863B75A2C9A1919395928CA2AC738099898C9396918E94
8D91908F8D908B90
75B18F8790909297928D8687918C8C858A9FA18F89949094
90928E898A8DCB4A84847AA4B87CA6929289998A898F918E
8A8F917B9D8F9D80877C6A5599818CA8A0A6888C9F958FCD
7EA963878D7C86938F8E8A8D908F8D8F9390667E8BBCC3B3
AEAA92477064C88888898F8C90BF88789790858E908C8996
8E8E8F8E8C939095
6BAE8F8F958C91968B8E878A908C87878098A0898C8D8D8D
8F8E938A918BDF369B87839A966B999A8694948E878C988F
99889490819C8A9B7AAFAEA3CD70668182A0B294B3C1BFC1
D4E37CA87E9F81858E918C8F948C8C8C8A9389796B677492
BBB4B7995E649FD18C91949285A69B6C86988D8E938D8991
8A908F928B8F888C
70AF8F90908B91998B8E8D8B918A868A889DA7898D8C8E90
8F8E908D8D88E2379B9389898D6FA996918D9C929586888C
94968F8B9073A99989807E8BB97C61947F9AAA576475605C
69CF8A90918F968886908E91918E8E8F8F928F9290867367
78A4A8C7993D36BA97849095879C9D9175978A898B939097
8F8C909093929192
71B18A908C8D949A8B8F8B8B90908A888396A685948B8E8D
8F8B928D8F89E23798929E92907C96947A88868C8D838D88
95908D8D8C956D937BBC9D8B8E7E99B89870957F8A8E8E88
69985AA67B8E98899690859090908B8C8B8E8B8D8E92927C
6B837CB8BCAE4ACCC88693919A87A09C7685958E8E8B8A90
8E928F8F8C8D9091
6AAF8D9493939599888A8E8A8E8C898B869CA388908D8E8F
9093928E9187E53B948F9594948E9F968D88918FA6929589
839A9A8A9D92998A8982768E8CA37294838392848E91888D
928B9591A090978788968888929C999491908E898E90908D
839D937B849A4F62C3888B808C8E90AA79788E90898F8E94
8F8D8F8D8F8D8D8E
6DB28C968991939C90898D898D8A8989879CA289918C938F
918E8B8A8D89DE349296978E939893A383927D8492998D97
8290968B848D7B8E8C959293828D898E8F8B998097898D87
9A8F8D8C8B8FA4868B967E9B818787919391948E91909290
7A8889A07BBA7120DD96928D9D8F97A9998085978F8D8B8F
8F8F8F8E918E8E8D
6BB08D958D90939C8B858A8A948C8B8A869C9F878F868C8D
8D90928B8E87DD2D928C8981818E979F9F84957F8D8A8D95
9481937C9F93A095928587888E9190908C839F83A9909684
967F938E968E8D9AA5AA88978296818C8D94978F8F8D9290
8D7E9F8CA1A2B25FD5CA8282939290969281758A928C8E8E
90918E8C8D8E9091
70B1918F8B8C8D9B928C8A888E8A878B899B98888B8F8A93
8C8D92898E8DD9348E95898E8C958B928D8999968B927BA2
859F8A95859C888791949E7F9A8E8E90899A9B87938C9490
918C908B8C8E8980808E8A9584928799828A8D8C938A8F90
8D85889C94958B4C55BD8E91968E8B9E96B27E7C908E8C88
8D908C908F918E90
6BAE8E8D988F979C8F8E8D8B908C888B8C9FA18F8C928898
8A91948C8F8CD445949A959591978E95A4879B839D82928E
957D9A79998CA07B8595978B8F918E928C8793809B868E80
958F958A8E95909D93909BA59F9A859C8C93878995909393
938E80869D808F7E2FEB928D92878D9493B194788C958D8C
9195898F8C928D90
71AC908A8F8590978A8A8A8A8B8E878A8C9B9D8C91938B93
8A9295908E88B46460998D9C8D8E8F839183839292947D98
7EA18EAE768C8B998E7D8887878F838F948A9588928C8B97
8787868B8B8C899091848C809B9078907887998394858E93
908F90839B8B8E894BD9B88C978E9594869B91837A929087
8F908D9490928C90
71AF90909889999B8E8A8A8B8C8E8188879796898B8C8B95
8C908E8D908BB3AA569A939E958C90938F9E8C89A0838E83
97779885A5739C91998D9B9D8EA2928B938690908D8C8D9F
98989398908E8A9193918F8F979189B6928B86819A86878E
928F908991928F8E5588C0868C898E8E9192989974879390
8B8F8B8E8F8F8C92
70AB888D8C888F98888C8E8F8E8D818B8E9FA192948B8F91
8A919790928A94CD41A49991938B99889596869394A48C92
808780A6959A86917E8E9888789590988D8A91979796898C
838E8893898B918D90888D8F8F7B729FA49882789090948B
8792958C908F8D8E7247DA8B898E9393959697AC876F8C94
8A8B8D8D938D8C90
6EB09091918F96A38C8A8B8C9093898A8A98958D898A8F94
8A8D8F8A8A8A86D22E96A09E958E908891998583918C9EA1
9E7D927CAA898895889394909391938B908D849481958791
868D8999A07F8D8B8B929294857990978A9FA092756E6690
8F7D8F909392908D8528F191918D8A8E908A8CAAAA797B96
908C8E90938D8E91
6EB1908D8A8F8DA4898C8A898D8C87838A9B9B918B8D8E8C
898A958E8E8D8BCB3D7BA6918E8A90858D8A918C9489709B
93938A7D919783918E888B858D8C8F92928F948B8D918E8E
968C899CA59094928C8F8C797582A0988E8F89B1B2A68168
88A07988939494938C27F992888C8A9A9293889AB0976F8C
948F878D918C8F93
6BB39591908E8A9F89898C8B8D8E8B8A909C9892858E8C91
8C918F8E8E8F8BB6575EB3A38F8D8E9A948F8C89A6868B8D
99919F827990879E9183978A938D8F8A8A9D98958A868E94
939283818E7893908F998E62B493A784908B847895DBAB78
6B80A283889295968E22F992948E93908C8E8C899CA57E70
90948590928C918D
69B3908A8C8D8EA5888B878B8E8F878B8A989C9591948E90
8E909191908D8AAEA04FAF9B8C8E8E948F9289839A92909C
838EAF9A886D8D939D8E9394948F8A8C8E8A9388998B8D86
8F8D959896908F8F8B935F78C1AA87888A908A807F9DD3AB
73865C8E8E858C948230EC908A818A908E9192908DAA9F7A
809A8B8B8F908E8F
6AB3908C938F94A48A8B8D8F9091848D8C9D9D95868E8792
8D948D8D908F9199C030B2A08B91888E8B8E8B8491809D8D
92878FAA9A977A808087A18C899282948A938B8C958C9A92
8B88878E8F89919393905CAECA7D87898F8E908186959DB3
BB978D56929781804E5CBE90958595918E8E8E928590AA84
6F8F9190878C9190
69B49590979395A1838784878D92838C85979D8C8F909193
9194918F9192938DA74581AD8E928A8E909A98948A8C8C89
898F8B85A29592956F9588888BA18D9781878E8F9287948E
98908E9189908D958E7355DEAC85878F8E928E8184939C91
96D4A26A65797E8670A6E69196878C90918C91899290AF9F
84728F938C8A8C8F
67B38E858B8892A2898D8D8B8C8E818989979C8C8E8F8C8B
87908A8D8B8B8C8BB68D77B090948A9A8E868E8D8C968E86
87A0848989A5A4AB83787E8B899C8A9F89908B928A8F9191
8A8C95958F8E8E898A5380C29085878E8D8D8D8586929D90
90A1CC9FA58888AA759AA4A5928C8A918F919191908F8EAC
9E7D7896968A8B8F
67B9958E908D9299868A928C95938A8F8F96A284928B918F
8E9294908F8B8D8F959A4FA28F9086958C8C908D87938F85
8EA18A80839490A48F988A80969283948AA0958B8B88948D
8D8A8D918E988F945C80ADBF938A878A8E8F898781969B96
9DA2918F93989BA8877187A795928B8B8D88928A8E94819B
AB917D859A8F8C8B
61B6928C8E91979A89878E87898B868B8991A28F8E8D8B8C
8A9092918E908C8D8AA97C9D9992879490909D999198848C
8591869096948E8794B2989476878A9C8C99838F8D898D95
86948C8D8E90915E8390CC91908A8A8E8D8F888887949C9C
9B887B7C878A9491917B7DA6B593908A9494918D8E958B91
99A18A79898E9286
66B19E8E898E999E8D888D89928C8A8A8D8FA08E908C9594
95908F898E928C8B8B93877C929488908C8B89838783898C
988E888E948F928E85929D8E93877690848C8E9898889A93
90958E8D92835C8481CB9C949188898F8C9289888090A3A6
9E8C878A8A90938C8E8C6D7FA1A894888988929191888895
8A9D9F898185908E
7B989C988C8F999987878A8B8D8E898C91989F8D86848990
8E90929192918F919090988497958F918792909DA49F9298
97938B8A908B8994869B7A8B9FA1958483928C8E8F92948E
80908E9A915E9F9BC0958E938D868B8D8B908A898797B29C
877E8585919293908B94876E88B8919792898A91988D8F98
8F91A0928A7D9191
8B8D8F9D8E8A96998C8D8C8C938C8A898B999C91948D8F8E
8E8D8D8D908B928D8E899688919295958E92887C9489918E
928F868E959589918D96997D959C9F8F8F83908C91898E91
94938D895C7DA3BF928C9399948D888A8B9087837996B396
858F898B8B8E8E8E8C90927A7F9E8F8391928B8D94908D8D
92969093948F798B
8E808BA09B899698878A878A8E8C898A859894888B928A93
8B948D94918B8F8F8E8D968D8A8D8F9C8998918F958F908E
8A84828C8E8D81918B8D957E988195919D8D848192928E92
90908F7A77A3C2918C878B978F8C8B8D90928A8A86A8B68A
7F828E8F94928C918E95918D6A93A0B39B898A908F978A8B
879C898E9B968E71
717C80939D98A09B86898B8D8C8C888E8CA29D8B918C928E
909490918E8C959792889288908687988A8D8D7D8788879F
9D9D979A999C91968F8C9B8190818F85969BA29780838491
90938C6294B093898B8C969A9688888E9092868988A5A68B
83878B908C928A8F8D8E90918A7187A89A958C8C808E968D
889893949493A288
81688A87969196968A8C8B8E8B90888A849E988E8A8A8E8E
88918B918985838F898B8E8B918DA583AF9C9691979A928A
8A848E8E91958D8D8D89998292879594848A839799A58885
82706065A4B18996928C8C9794898A8C898F878E919E9284
868A968E8C948E9491908F8C927A7D97B18F8D928A929397
8B948D978B80ADA7
B85D8B848F9EA89D8686828E8A8E878D85A09D8C9186948D
8F8C9690908E8F978D8E938F968F80517F938C928B92869B
88988B7F8A7C8C8E9A989A8D957E957E939288948790919E
778A8DA2C78788908F8F91999486898E898E8A8E91978F85
868E908C8A93898F8B90908A8F8E6C9597C190998C8C8E91
97908C919B819CAF
DC5389838994A7A2888D8A909091888F84A19C8D8A8A8F93
8E8E938A918F92958F8C938B8E8AA9919FA6878E928D918A
83918E949C9B9CA39285878F8F999A90988B8B8F8D8E816D
87A8AFA98D86888D8D8C8D9B958C8D8E8C928E9090929389
918E928D8D938C908D8D918D91919A758E9EBF918994878D
8B8C8B8D97907D95
E143858586899FA7838D878E918A888E81A09E93928F9491
9191948E928E8D91928B8C8F8F8C8F8C80949A878E8E8E99
87A09987967B8F8888838A8E948B8E87938E938B92748A8C
99B98C8F918E909190928E968F858A8B8C8F8F8E8F8A8985
9192928E90938C949190918A8C8FA47D497EA1C38D90908A
8D8E938F8D969086
D748938A8E879AAD8E89858D928A878983999C8A8C908B8D
8A8F908A928C908C91888C958E928AA47391848F9192958F
85908E89868C86998F9D878E858B889B8D8E8F826E839BA0
A78B8A8A8D8A8C8E8F8E919193898F8A91918B8C908C908C
9594918A8F8F8B8D938C8C9091A69D8773546DBB908E8B94
8B8F939188909883
D4518E85888B8EA08B8B848B938A8C8A85A19986878F9192
949395948D8E8E8D919290938C8D8E96958A97827C89969B
879796909C909A918A978FA29B858B908194758687A0AA97
8C8F8F8E8F9295928F909494948A928C94929290958D908D
8C8F908A928F8E9291918E8D9E9C8979886159C2A3919393
91878F92918D8F89
D94F95898A878F9996968992918B888B869F9F8B918F8B8E
8C858F878A888E8D8F8B8C908A8C8A8E8D8E9099928F9586
86898A8894888192818C748A87949D9C757E719D9EA98A8E
8E8E928B8C8A8A888A8D949293878C888F928E898B8E8E94
8D92918E938D928D8E8B8E929F987E8A817575AD989F888A
8E8A9091918E938A
CD4E919188848D9590928989948A8A8D849F9B8C928E8E91
8F88978F938F8E918E89919291918E91938D8D928D8A8F96
8D967F8898818D98929D999E8F7B746471A7A5AD928F898F
8C8E918A908F918F8F8D9094928A8F8B91918E8A918F8C8D
8D8F8E8B8D8B92979292929F9D8681866F89A08C8EA19F95
938A918E908E948B
CE4E8D919289909692958D8C938F878E819D96898E8C8890
948F938A8F8D8B968E8C918F87908E8D90898E9390898D8B
95909494948485846B62645F6382A5BEA5A3928B8E92898E
8A8F928C8F8F908F8D8E9295948C8F8F9191918B91928F8E
8C8C9290948E8F8D8B8A909D8A7D8A8078A9A6837E909CA2
948E8B8C88909494
D04E8D928D8A838F8E908E86938A898C839D988992908A8F
918C8F8C93908B908F8D91928B92928E908D94948F928F92
91918F92958DA0A5A4ABBAB7B3A29C938D8D91918E918F91
8E91948A8D8D9093918F91978F8E8D918E8C8B8A8D919190
8F92918B8B8E90918E93A39F8484876D8AB19F9287788A9A
A58C908B8E8F9090
CD508E9390938D908F90938F938E869089A69C8B8D908F94
92949690908F8C948F8F8F908D8F94958D8A8C938D918B8D
928990938D8F9095938E918F8B8C8D918C8A8D948B938C8F
898D918C918E8B8F8D8E8E9490898A8E8D8E928E918D918E
908D8D8A8E93928D8F99A08A7C897B7BA5A98D90907C7D8F
A5A48F84848B8A95
CD4E8F9287938B8D8A8B8C8E9590858E879B9787928D8F8D
8B8C938F8E8E8B8D8E8F8E8E8D8992918B8E90918C908B92
948D938D938C908D9089949195928D908F8B8C9089908E8F
9491978F8F8B8C938D90909892928E938E8F8E8E8E938C8F
8C8D928C8E8B8B888DA1998084846E8CAC8E9287908D8075
8A9DAC8E96928D8E
C85490908A8F928F8D8C8C8F91927E8A89989B8A9089888F
8F8D928E928D8C8E9090908E928A91928C8E8B8B8C8F8E8E
8D8A8D8D90929293918D8F888B8C8B8C938F8C908C958E8C
908A8D8D8D8D938E8F908E908C8A898B8B908C8C8B8F8C90
8E8B928C8F90938D9B9F887F84777FB1AB8F938C8F94917E
798FA49E8B8D8790
CA4F8F8E8D9092928D8A92929391858C8F9D9E8A928A8E92
8F918E8E8D8E8D908E8F8D8F928E91908E90909592909295
8D8E928B938D8F8F8F8D948D9395958D8A8D8E948F928E8E
928E8E928C92918A8C909196958D8D8B8B8F8F9290918B95
8E8D928A8D8E8F90A1957F89807C96AE8984898891949393
807A90A0A99A9895
D1539393908E90948F8A8B908C918A888298988D8D909091
928F96909492968D918C8F8E8D8E8B8F928F8D8F8D8A928C
8B8D928B918C929190908F908E8A8E8B92909789928E9293
91939190898C928994929599928A8D908E9290918F8F8D93
8E8E949090918C99A28783866E8AA59E9192948F8E918A8F
8F7C7C8C8C95858B
CE53918A8C8B8B91928D928F8C8A8F89859B9A8F8A8C8C91
8A8C928A89888C8C8F8F8D8F8E8E898B918E8E8E8F8B928E
8D9090898F8C8F898B8C8A8F918D918F8D8F8C848E8D8D8B
888F878C8B918F8F8E8D9395908A8E8C8A8E8B898C8C8E8F
8E8F8D908E90909A917E877D7CAAAE909090868E8F90928E
8E8C7E8093ABA78E
CF4F909092919096928F878F8F8C8E938A9B968E8B8A8D91
9389988B9491908D8F8F8E9190919292908F8F90928F918D
9390938D908F908D8E9489938E8E8C8F88919789968F9091
8D96919191898F8C8E8D99958C8A8A8B8E8E8D8B8F908F8F
8D8F91908F8E9DA0888583718BAA948891918E8D8F8A9090
92908E80718E9C9E
E1598F89918E8C8D918F908C8C87868B8C9996918F928F8F
8D8F958B92908E918F918C90928C8E8F8F92908C908C8D8E
8E8D8C8B9390929193928990928E90928F928E8B8D8D8E8F
8F908A8D928B9290919B97918C8E8C8E93938E8F8F8D918E
8D91938F91929F8E7F877684ADA891898B938D939490938E
91928F967B7B8B9D
BF7C928D96908F928F95908E8B8C868F8A9EA08C918A9792
928F948B8E8F848D8D8D908E958D8F9089938B8D8F909192
93919291958A888A8D958D92938C8C928E8F919193929290
8F8F8C8E8F8B918C8E9B8F878B8E869191979190918E8F90
8C928D898D9998848685759CAD8D8E8D928F8D898E8C908C
939091948C887C97
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.678571 0.00744048 0.97619 0.30506 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00751202 0.0192308 0.00751202 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
128 string
128 128 8 [128 0 0 128 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
232F332C9AD4D4C06389ADB6BBBAB67F402D274B364F3849
473469624D38792A42962E5E2C2A50463063617F48515C67
72747A7D7F89818485888C88898E928B8C919593979B9796
9B9B9D9E9D9EA3A1ADA9ACADABB0B4BCC2CBCED2D8DEE0E1
67585A5B6779817F7076839283675C4E47586055556B8989
754836262A446368
33323938B0D4D3C4638BADBABCBBB77555372E3E3D493E5B
5639409E3E3F7E5B7A433A8A323945265141921C2B4E6070
72777D7E8385818687848D868F968C8A9494969195989896
9D9AA19C9D9A9B9DA3A0A7A9AAB6AFBCC3CBCFD4D3DEDCDA
39525A646E77797E6F6D798784745C645C575A584E68808C
7B614336393E475F
353F4046A5DDD3B96289B0BCBDB7B2994A325A373C3D3B4C
3F663394313079509929412F295A94426F6C322228415863
757A817F8387818287898C878789908F8C93939593979899
9A9E9B91979B989D9F9BA5ADB1B3B6BEC5CCD0D4D4D8DBAD
40646D6F7A807E7F777A7073807667636D69564D51536F82
826F6441414E3540
3D4E4C559FCEC7925B8BB2BDC2BFB79931422F3C3639403C
373E3650312A8175512F7151207027737A45293135383B53
67797D7A8184868887848597888D888F928F969392959198
999A929093989A999EA3A5A8ADAEBABDC2C9D2D4D7D9D750
496173757A7C777977766D696778665857655A4D5350546E
7A80705B3D433631
373D5D669EBCAD7C5B8DB4BAB7B9B7A5352C3056323F4541
572B3A4F4130777B2257941D616C3469387E324044303143
4C6069767C817F82848289878890908C99959793969B9599
979994949598959F9BA2A3A7B1B7C0C4C6D0D3D9D8DCD836
4E6C6E727971807B777476665E5A655D495F7A6357544563
7D7E74665242433E
3455677AA4C1B07F5B8EB3BAB8BAB7AC484E3C383C2D493B
5D333B54603778772C2D2E48AC4A4E80A637312D33363839
2B293C566F72808683888B8C8A8D93928E9392989B999992
968D90959095959BA2A2AAADB9B9C1C6CBCFD7D9D9D9D345
5967716B6A626B6F687BB49851514D51554F6E7F614D464E
6F80806E55454E46
3F6C8482B2BFAF735D96B8B5B5BDB7A35E6D28303B314439
512B3D616049662E336F4A2F2D3551AA6349292A3D2D2B31
606E6D2C2E4C717E8481898C8D909395929195959697989D
948F8D9393939A97A1A7AAACB2BAC0C7CDD2D9D8D9DC9A4A
66727966615F565B609AE6DE96513E3E464D4E6D72614C4C
5C727B6F614D4B4E
5E6D7592B8C2B2775F95B4BAB6BAB5A3705A273038373F3B
443339404E3765372166326C337D468E6D7B34333C2F2F3C
425076807E2A2A5783848D9188929092918E999595939196
9090919397989A9FA5AAA6B0B4BDC5CCD0D4DADBD8DB5154
6A7A6E6764595A464E8DDFDDC0AB65383F4A48526A736251
53617B6E6357434C
65686F80B2C2B06C629BB2BAB7BAB7A35C652D3D3C393C38
3B393A325C432C2D38325C43354D68AB6B8833313334302B
384853727C86512A628D8E8E9092918F8D95989797909590
8D8F9596919A9EA3A4A9AFAFB8C6CDD0D3D2D9DADBDA3F5E
7275685B5A5843282DA9DEB8BFD7C65738455C4C57717456
5356697F64544942
41564A6FBBC2AE525999B3B8B3B6B6A6636E37373F503938
34363B4A4841393032472B353874A68D69942A352C363231
2E38566C7D8183442B6E918F8B928E92928F959A91928C8F
8D8D918E989AA0A6A5AAB4B5C1C9CCCFD6D4D9DBDFCB4B6B
7A6E5E5D5741322827AAE4BFA2DDDFB4573F525E505F7A65
555D60736E5B4338
302E2B6FBAC2A03E5D9DB3BBB7B9B7A138605E312D33383E
375630535742443A45433D297D9F96795F75253149343B2E
2F2F46636E7B79832C4D7E93928E91949195959B9692928C
928F95969A9E9DA6A9B0B4B8C2C7CED2D6D7D9DEE05A4F65
63605C4C42352F395B75D0C39ED5E1C986513D5B5C546972
6262666B6F623F39
25282B7FB9BA913257A0B7B5B7B8B59B7D5D672C4535333C
3D50414B514033323A38278A7BC34D3C59632D413F323A30
38384652648283807E2D6E8E8A8E8E9696978E958F8B908F
8E9995999BA1A0A7ADB1B2BFC5CBCED5D6D8DCDCDF324D56
52574E4D565D6C7E96AD99A496C8E8D99C6C56516960506D
6B6160707969543F
27273182BBBB8A365BA6BAB4B7B8ACA37D524E293A403939
47403942592A3E332F30594593314329492A7D6C2B3C3633
3C2A3E4D55797C8288505483948F929592969393908C928F
92979C9B9BA0A6A8AEAFB6C2C6C8D5D6D8D9DDDCDC42334A
57666C7A838F919AA0AC9A8283B6DEE1C483695E586E4E52
76656B637067574A
282E2E95B1AA863364A5B6B7B3B6B4A18F313D2C313C3830
3147483942443E362B7B2E567D4F313BA73B36C638343353
3B3B2F3648637D82857730698C8B9591919A949195928B8D
94919A9D9CA0A3ABAFB6BDC4C7CBD2D8D7D8DBDAA9845468
78829396A09D9C948D9A9C94859ADAE5D29A757062666952
63737266646C6357
2F2E369BBAAB852E64A2BCB4B7B7AEA1AC3B3329294C5D2D
364947344445342D3F5B41413C5583796F487F84B82A423E
4A433D363C6178828683396A86959090929591938F8E8F8D
9596989BA1A5A8ADB1B3C0C5CBCFD3D6D6DBDBDA56927694
979CA29B9795928D8E92929290A7D9E7D5B176746E597267
506C74665D616768
26263D9EBCAD782568A9BAB6B7BAB69CA82E333231443B50
393847493138562D3C286A7C445C4694648A9C5C322F432F
44313F3B355B6E828588565C778B8F8A90969895898A9390
95969DA0A2AAABB1B1BDC0C8CDD0D1D5D5DDDCD83290909F
9E9897938E94938D83899094D0D7D3E3D9BB7B7477685F74
525B736E646B6664
222046A7C0B66F226DB0BCB8B9BBB19F9A312F3C373B3230
4E2D553649364F2E29476722314E989C5B612187251F4D3E
6699443F2F525F808A88683A66908E8E93928F90868C9291
95999F9CA6A3AEB0B7BCC4C6CCD3D3D7DADADCBD2293979B
9795918F8E95948B858286B3E2DED0DFDBCA8C756E6C6573
6D615F7271625E64
1F2257ACBEA8771F6EADBDB4B1B0AE9B863E3834333B367C
30355A343B3E3F393B4343442F4AA387806D375FBAA6785E
50503E3B3736537485847F276C88898A8E96928E868D9197
929A9DA3A8A7AAADBCBFC2CBD0D4D3DFDBDCE043139399A7
93939492928D8E8B858385A7E4DCCED9E3D1A97975636A71
7E6862656F6B6963
1C2459B0BFA7651E71AFBBB9B7B9B59E7B364C3939332E3E
933370363458343134532E498D8A7B959A79AFD837194743
423C3E36403E4F648D82782D648C8E8B90918F8F95949598
9698A2A4A5A9ABB5BBC3C7CBD1D4D5D5DCDFE1001C939E9D
9799988F8D91918F8B837D9DE1E1D4DADDDAC789696B6668
80736566746F6460
1C215EB0BE9F571C77B4BBB9B5BBAFA08B21394B352D3835
24A299282C37352B333C4D50903F40AC98829980A9DE1B52
444841344338375888857E2B5E838B928C8F8C8B89909896
9B9FA1A3A6ADB3B0BCBEC7CCD2D5D7D8DBE2D40414A19A9A
99949994908F8C8C84868284DFE6D3D6DFDCD5A55E5D5D66
777765606D727372
1D296FB2BC9C511E7DB0BCBAB8BBB09EA477362D4D31323D
3138A02236324A4A2F3872778662379F6FA94920C82D1F61
4235363B4B46343C65787F31657E9289978A908A8E8F9196
959FA4A2AFACB3B6BAC1C8CED3D4DADADDE459121FAC959F
97949B8F998F858E8B87827DC6DACCD1DFDBDCC2775A626A
707C77615E6F6A70
202C7AB9B9A249207CA9BDB9B7BBAF996AB1293137383F37
4432A2215D2F3E4164433D63735454A498AB182DCA261E54
3B36363A403C41456B7A69395A878E838A918F8E9294999A
9A9DA3A8ACBAB4B5BFC1CDCBD4D6D8DEE2E00F1920B9969E
99959297948D8D8D8E8B7F7E8FB9C9D0DCDCD9D1A6545E63
7374796863686F6D
213984BBB79C59257FAEBDB6BAB7AC9B6046203934503936
2F3A803B4A3232725E3D6F78843F609BA3A55438694A263E
45383E3F42394140597E752550848C838C8A909690919894
999CAAACABB0B4C0BDC4CCCFD4D5D9E0E1921B2B2E9394A0
989792988E9290908E8E8A838096AFC6D9DCD8D7C7665563
63737A6F5E607065
276096B7B18E543284ACBBB7B6B6B095ED412C2B2D3A4C46
4435722D532C8A2A6F69436A416773767FA328A157252838
4D373C3942403B3A3B84742B566B8790878D969293919196
9C9FA5A8AEB4B7BBC0C1CCCED1D7DBDFDC1128314D6D979A
96959698919293908E8C8C86858B8A9FDBDDDBD9CB8B4A5A
67696B7E70636872
6289A7AAA2813B3082AAB7B7B6B7AE98C73C21313B2F504F
3634514734315A2C81314254885BA0956B60628B9C2C2F4B
4337403A434137414D776C2F54877A88869493909999949D
A3A9AAAEB8B5BFC0C1CDD0D3D8D8DCE030172F4451479C9A
A1959796919290918B8A837C848E8385D7DDDBD9D0B2613E
685F606C786E626D
8E95A6A082663C397CABB9B4B3B6AA97E378253D3F414B3F
3F5344364F44257245454C555F7198AAB31DD878AD2A333F
3B3E423D483B3D454E6A522D578082817D91939095959098
9DA7AEB3B9B8BCC5CAC7D0D2D6D8DA682F353C604F3EA692
9B96979C93938F8C8B87827B79838069CFDFD8D9D5C79327
505D665C67715D59
9599A28A6357323A83A6B1B1B4B4A892AC4D5B303A302E7C
A39A4B4464456B468B563F697F868D8B533A326F2B372D49
443D3D4142483B455160393463807F878587929694938995
9AA6A8ADBDBFC5C5C6CFD2D4D6DA75145A3F4A63503FA598
999A9B948F938E8A887A7971688B7D52B5DED6D7D4D1B63D
2C5E605A5F6B6658
9897815C4E492F467DABB2AFB2B2AF9569A9D63132343E52
272395506F2E525789A8475A7E4F9D8F696C5FB532533247
41453E3D433A3C4346553F3E667D80808388878B92929192
8F9CAAB7C2C6C4C8D1D1D0D7D9520E356D5249574E4AB994
9996968F8C898B7F75716A5E64827D4F9ADFD6D6D3D4CBAA
50354F58595B6260
8D78544732433C4D83ADB5B4AFB1D39A6443993D2A303F5D
25368052621EA86D445A4C64618F817ECB5F892841623741
363F3E47383835433E46414068848682867E938F91929292
979BA6B3C7C8CDD0D3D0D6B319171F567A575859475ACB9E
8C8A968A827F7E6D686764666A76765BA5E2D2D2D3D4D3D3
B44535434D535C5E
4E3C3A36344B4C6B92AAB5B1B0B3A69FAB363ABD2C2C793A
544279383679829F5667B350786D7466A37F4F354262383F
49453843353D3C4240423C54637F8A89868A92928D979B95
9596A1B5C1CBCDD1D1AD3321312E356881554B5F4C57CC9E
7C857B7D76736C706D747B8388857C7AB1E4D9CED4D5D5D0
C4B16C2A30415863
3C392F2E304F5B6F9BABB5B4B4B3AC896FED7D4C362F6641
5D3C37354889AB4B2B4975914FBD7E28C77021313B57353F
343B3C36393A4543413F38545A76898B88908F8A93979FA2
A3A3A1AEBCCBCF9121222A282E3937497B6954534C52ACAB
6B8170777A7679848B95959492918581ABE6E0D1D7DBD4D4
D0C2A85A312A3857
3534373931526F7997A9B7B3B3B8AD905C47ED5B2F336843
3D363A2F3C9885613A953F70A39681AB442F31373E4E3732
3A3C43393E3D4648474B3E5A484B6768737A7C898192A1A5
ADACA79A897A1F233A2D3C41433C344B75614C5A40429DAC
7C707A878E90929A9DA29C94918E867B85DFE5D8D6D8D5D4
D5D2C9AA64302734
3F3237343F58759099A9BAB0B4B9B1986B394954384C5E3B
40523A3E4A883C4F658F95A881C5487E2E303540424D3F40
4049463D4044454146415555332E44505C7782868C99A5A3
ADA9A4A4938C223C3C3A424A433B3E4875595059454699A8
99879C999AA09FA29FA097928D8E8D8278D4E9DED7D9D6DB
D7D6D5D5D4B9803E
2F3B383B4D686C8592A5B5B6BBBAAB98713F5480383E9732
3D45363B717D2D4183799C70915749314C364C343C4A3B3B
34403A37454640413D414B3235566783868C91989A9AA7AD
ADAEAEB49A992845403E3D4C3B42394277565853374092AD
9BA0A4A898A09E9B999F9E94958F8D8278C9EDDFD6D6DADA
DAD8D8D2D4D8DDD3
222E3E393F77758297A5B7B4B6BAAA9768405E7868526538
364C393F5B73668B9C8A5D7B676F62D22D30393D39543E35
3D38343B403E3D49453C573F56727D84948B9498929AADA2
ADB0AFAAA29F612B37353C504A3F384178504E5335399FB1
899CA1A19B9C9C979E9C9A9590928E8677BFE8E0DAD7D7D8
DAD9D7D3D7D5D8DB
243038363A75708797A2BAB7B7BEAC96713B5D7F61445539
32483647598A82A17577667D50797FFDAA2F3B343A484034
3A4540494549334959414465787B7F898B93948E9094979A
A4AFA49E9F97932633393A384037303A6E4F51534E489CB3
9CA0A4A4A1A09A99989F999492948C8278ADE3E2DDD9DAD6
DFD7D8D8D5D8D4D4
262D3E3D3964667B98A5B8BBB8BBAF966D3E696B7D384668
353B4B3A748D3886765E778A5C8675E5A33D384537414032
3740443C47463D3F4C4F616D7C7C84899093918B8C8D8E89
868284989E97983E3938344342393C386D4D44504E3A96A4
A29CA39CA1A3A1A4A0A09D96949097817AA5E4E1D8D8DADB
DBD9D4D2D6D8D6D8
1E2F4044404E657BA0ABB9BABABCB09A694057936C5E32A0
38307B43628E7A5C6137778D66BE7BD398E13C3C3F48583B
4346474C4F474949505970747A84868A909190958A8B877E
7A8990847CA093915237393B4B4042336A4E573D47389B9D
A8A1A4A3A0A39D9B9A9A9A97958E92887FADDFE3DAD8D6DA
DCDBD6D2CFCED1D0
2B304549434F678AA2A9BBBBB7BBACAA96425091746752AD
262E794F58C16C5C478257539C9487CC458CAD2736403A2F
403A383F4F3F446141677D857F84868293979990857F7D87
8799A39DA08B969F892A2F45313658307E554440363DA79F
A79BA2A3A2A09D9D9C9C9A979B96938983A7DBE1DAD7D5DA
D9D7DAD8D8D6D1D3
283D484946536B8DA4AFB8BBBDBDAC966DA9505CA97D404E
3B3849393CC84F64785B408662A88D7CDE5670D32C3F3D2C
46344A4C503863545A6F8087848786939B9A9B847F897A8F
8FB0B9BCD7AD8C989838353F3F323B41684F463F3A35AE97
A099A5A09DA29FA1999895979A939490809FD2E1D8D5D7D7
D5D6DBD9DAD8D7D9
2B31484B49465B8AA6AEB7BABBBAB0936B3D975B8797315B
2B474D3C3FA370746541944942767DD0E7AB727B66313836
54323D405E2A5E5D5078868C878B8F929397856E58535C71
6A606070746D6B829196293741313A4D5E4F41413833B79E
9E99A8ABA19E9D9B939B979790969293859AC7D5DDD7D5D3
D2D7D7D8D8DBD8D8
38384A494F47518CA4ADB3B2B1BBB0976D415F75669A312F
96354741508F6F5546783A7098256DB1DED34A58A9192942
33333D5656326E725C7D878B878C8E96918E90848B8C9395
908F889296938C877998382C394239534F5548432839BC8E
9697A0A19F99979997989B99959494928691C5D1D3D7D3D5
D2D7D7D9D9D9D6D7
34414B4C4450588BA1ABB2B6B5BCB3966B435890728A314F
773B3D44444C46486730A8898D174A9966ABD25666D8273E
3D2E41534929747E627A8387898C998F908D98969B9D9A9D
9BA4B3DEDDDED0C28E8F8A273B3D3647544A48503237C586
8B9A9BA2A19D98989A9C99999894948E8991C3CED0D6D6D2
D5D6D0D6D8D9D6DA
3A435553444A5F8CA9B1B2AEB4B8B0956E415962A8753D3A
8A25654F526B555E3A72878B943B3E386C95B7CD6E697829
4738365B362B7C866C7B858A8993969597979B9B9AA1A298
9E9DAEE2CAC6CEB393969635333B354C55504A3F2F49BB6A
799B9AA09D9C999C999C999492959D918C89C2CDC9D5D8D4
D4D4D6D1D6D8D4D8
414056544E43628CA3AFADB1B3BBAE96694C61686FA7593A
3E86473148466D7180B2A7505D61504E2EA0A0B1574EC838
2D424B584441836C7285868C88919992939DA2A09EA3A2A0
9B969DC8B3C1C4B29B968D832F3637433C485149315BB25B
72A59EA59FA19C9A9A9C969698999790918CBBCDC7CDD5D5
D1D2D4D4D4D6D8D6
444C51584A4B5F86A2AFACADB4B8B0956A4A5E6F7379462A
563E973D4E4466667098921926B13A233D506875C4657BF0
252E3B4B372F89547684848084878E9D999AA7A3A5A3A09D
948E8B9C93C8C9B7999A8F872E32393C454F4B44378BA459
389DA5A39FA09B9A9C9C9E9B989998908A8AB3CCC5C9D1D6
D2D2D5D8D6D7D1D3
414D57535250497BA3AAB5B1B7B9AA936B47607274825A3F
595A2DA05570426C7E446E1A28B12B22663732505377A0AC
AC22333831368550747A8683899298999C9CA09DA8A69996
7F7E8C8876759DB9A19B8B8973343B384B62572F29A7A25C
299D9E9DA59F9B9C9DA49A979C9C9697958FA7CBCDC7CED5
D1D4D4D7D6D5D4D1
404F5C4F4A4B336D99A8B2B6B6B9AF8C71425A6A717D4F43
5B90563767685A6DC22938334B26213338C8252A251DC1C3
CB78212A42337A50677B8289899098A2A0A3A2A2A5A5988D
84882859767DA7D4A0969789822F37383C5C5B372BAB8F5F
3689A695A5A39F999A9A949997958C989B8B96C6CCC9C7CD
D4D1D3D5D4D5D5D4
4853595250432C5E94B1BAB5B6B8AD906A589A6E7381624C
5D865546932C8143A53A304E3326377D31545B202A20BAAC
A2CB5F202F317B4A678084878E9594969DA3A3A3A4A29E85
7A95949C8094C2E5BD989791836E262E364E543237C0A14C
185CA193A8A19A9C989E9A96A19B959893908AB5D0C9C8C5
CDD5D4D0CED3D3D4
434D5A5A453C2E5995ADB6B5BAB7AE916D435573827A804F
638041653E3E727179982229482B3436718646822D382A89
71D7A01D2E2D7D4F657F878A8C9498A29E9BA3A9ABA29A88
748C8D8D8A98C1F7CC8D9C9384773033374E532444C3AF2E
1F53A796ADA5A0A29E989B9B9D9A969D92928AA2CACDC6C6
CAD1D5D3CDD3D3D4
434C514C4A3B326894AFB5B6B3B8A890644B55947D707B35
94434E376E906C77604A293E2C2C3863407173D83F581D30
7C97DF30292A774F6A7D838B9196979EA6A2A5A8A8A89F92
898A817D829BC0F4AF9398928D7E592C3B4A5E2558BF9C15
2C3D93969EA79F979F9D9DA2989C948F90969089BBCBC8C4
C5C7D4D3D4D7D1D0
434958504D49376E9BAEB7B0B5B7A48F634665697DB28921
42B08531374B3D81453141432D30356C614D6DBB30A41F1F
B576D6E11E2466436E808B8D8D9A9FA7A9ABADB4B1AAA28A
8B8F897C8AA3D9EB9D9A978E898364284144632D6CB09313
3A357A9A92AAA9A1A1A39C989898969391948D84A3C5C9C6
C5C4CED0D4D7CECE
414659544B443661A1ACB0B4B4B6AB8F6449616B6D7075B5
6654748E3C56339A8E383B503430317E262B557AC0741F27
596DB9D7D91D4A4574868A8C93979FA5B1B2B5B7B1ADA199
919183878BA4DDE29DA596958F8673413842652984AB951A
3A4156998AACA3A19C9DA09B979899949699928B83B9CAC9
C6C3C5C8CED1D3CD
444C564F5149436A98B0B6BABBBAA899674B5B6B78768551
537C8B3A78415982524E2B353F40353A56225A94931A2539
23AA78C6C732364A7A818D8D929B9EB0B3BCB5B2B5B2A19A
95928C818CB3E5E1A7A29C938985753D2A3C702DA0936025
4138349499A1A7A3A29F9D969D9A9A97989890908B99C4CD
C6C6C9C7C8CDCED1
49525857514A3C6A9EAFB7B8BAB9A991625364749079888B
624C603D415C4D7382403D38353742446C2064A044283236
2D6972BFC6E11A4073838888979EA4B0B3BBB2B3B2B0A69F
9698898A88B0EAD7A7A09D9084837E3A3249572DAA9B3621
384230849595A7A69EA29C9B9AA09C97959796948B8CA8C5
C7C6CBC7C3C3C7CA
556E605E545341679AB1B7BBBBBCAB91674F616A6B7E9EB1
AC834D443C457874588E292E42327D8E6AA634835E2C3039
332CBA73B7CADA2F6982838C989DA8B0B9B2BCB4ADB8AD9B
919485808BB8E5D2ACAB9A8A89837C47324B4330B6AF291F
343F38739C8CA8A1A09EA19B9E9C9A9A99979790918B88B0
C6CECDC5C1C2C3C3
5C5D5E565A4C43689CB1B8BDBEBCAB93664D646671796F7F
6F6A6885362D6A686F3286263D624B758A45BC2C32363134
413E596EC8C5CBAE527A86979EA0A5A9B2AEAEB3B1AAAAA3
8B958A878FC6E7C5B29F9B8D837C6E4339394527B6B53424
333F34469B8FA3A3A59F9D9C939E97989B98989399928A86
B5C6CBC9C0C0C2BE
5D6365605E5543719DB1BBBABCBBA89265516B6C73756EB6
B88B5044612F382F3B9383432B5A486B4E64594B2C343343
382E26B273B4BBD85C6285959D9FA5A597939193A0ADA8AD
8489898996CAEBBEA695927F756A6C40313E473FB28B333B
373A412E938D9AA5A09E9C9A9F9C999C9CA19B979394908B
86B0BFC3C4C3C0C0
5F636D625B544872A0ADB9BCBCC1A98C6651687175767334
8AA08A7D654F2D31AA39852F343C7035867C832634503736
3935293778CBB7C2D655748B9590979599756F8C69889C95
808784849AC6EEAD8E8678733B50543737485E32AF9C5831
3B2E4D3F7F9891AAA8A09C9B9F999F9F989C9D9E9B97938B
8A8BA0B1BCC5C4BF
62686B6964664F759DB0BBBABCB7A7896555637377716C29
2965AAAEB6A32D60398B7020242F5C6B978C77482D313D39
43312E239771BABCD1D160828E89968C71738CA1B9BCBB97
8679867EA1CFE9966E8FA1A78E4C3F3D3A564136B6775747
33344539559F8F9EA3A1A39B9B9D9F9B9AA59D9B9A989393
8E918D87A0AFB9BD
605F6A6661594A759CAEBAB6BAB6A38C665161736D706C70
90312893C3DEEB402F275B3C43554563837D303B3F35512F
34352F2D3C8ABDAFC2D2D16D7A8B803A647F3B87E0DBA875
7B818194A5CEE9777E575778C26F2F342D313B3BC15F583C
3C404A3435949999AAA0A19C9E9B9F9B9BA19E9D9D9C9998
9598918A85879BA8
6461656364594B799DB0BBB2BAB5A38C60495D6C6A6D6976
6C6547CFC9999E9EAA2827812E5A4E2D995F312B2C2CA136
2A41313D346F63CEAFC2D4D558612F2866334A74C0DBAD4E
57758291A3C2E3C343522955C36D202E3D3C3A32CB48423A
3C3A3B393F819F8FA5A3A1A69B9C9D9BA09F9F9BA1A09799
9B9695908A8C8080
63626863626350749DAFB7B5B6B6A18C624A5C61666E666E
69685DE8E08693A38C61322E713A8B305F683034314C5F30
2D3E586F2E21B59BB3B2CACECA3C4B30332E2A43B399151D
768A9195A2B8D4DC6A2B3280A53A263D373B3735D2563D59
41333C3F3A55A48FA1A5A2A49F9D9B9E9EA2A0A0A0A29BA2
999F9A9892908E92
646C6A6B6263557E9DAEB6B2BAB4A18F60495C626C6D696B
6B65676FAC8798A2A37C852D236359A13F4B5B2D3F393327
3094332F333B3E8CDDB9C0CBBCD43D493C3A393439242364
92899A9AA7BECDD1C5884036332B3D3F543A2D38CB703050
4E353D443C34A09295A8A5A5A19C9B9F9EA3A0A2A1A49E9A
9E9F9D9B9298938F
646C746E6E655F80A0A9B8B5B3B8A9935D4D5B626A727071
676C74757073A09D94B8AD90923B345A404E6F2565313B28
7A2D2933304521A86DB9B8CABCA9D457796D7946A6477179
7C6C93A4ABBBCBC5C5B383867B505F58462F3436C8682940
4A3836403C3D889584A9A3A0A5A2A2A29FA0A7A2A09FA19A
A0A4A79B9B9D9192
6A6A6F6F71675F78A1AEB4B8B5B5A38E5B56595E6C766D67
63756E747980839695371854966451375A2B6D34213C5275
6A412E28722C3526BC95ACB9CE93BAD68494AC89B795694D
4084B7AFB6C2C3BFC8C4C48F5C577C78442E3438BB462F46
4E3D3F3C3D4061A1879EADA6A8A2A3A2A2A4AAA5A19DA5A2
A1A39F9B97968F8E
64696B706F6865819EAFB9B5B4B0A38C5C4E5A656A716D6E
71717374807B7D7CC52B1F39C485523569522C922334373C
383C2B5E473A362C5372BDB0BDAC9FC8CFA7707E6254608A
B2CEBBBCB0C1C8C1C0C9D0DBD9B67A3C352B3A3FBB393B41
494B343C39394A959194ADA8A1A4A1A3A1A9A3A79DA4A0A2
9EA39D92938E918D
5F696D6F686560779EAEB4B5B8B9A38C5F485B626F6F716E
6A686E7879767D7D8AAC78B188867B902E792B512F3A4C5C
40303C39277B283433945DD1B6B29EBEC1BBBF6192A0B2BA
C0C2BAB5BFC9CCC6C9CDD2D9DFDAB3542A2D3882AB4E3E41
3F4F373B40373A859A89A6A3A9A4A4A9ACAEAAA4A2A09A9B
969394988D958F94
676A6D6B67655984A0B1B4B4B6B3A68A654D5F68726F716F
706973747C82797875925D86938982895D3F2A5A35273840
762F442F315E4D8C2720836CB8A5A5C5BBB8BDABA5AEADAF
B1B5B7B6C5CAC8C8CED2D7D7D9CF9D5D322F40A8982A3C42
47504834383C2F659E8C9FAAA8A9A4A8A8ACA79DA1989A98
9992909895A39AA0
646C6B6E645D5E889CAEB4B3B4B3A48D5E4D5F66666D6B6D
726E7070757D82807D72847D6C8A8E8B74313F5B323F3457
333B3E3859353358273936A57EA2B2C2C290B0CDB2A29DA7
AEB1B3B7C4C8CDD3D0D3D7DDDBCC8950282D64C261283045
4D3F453F393E3538989A95AFA7AAA4A6A6A09E9F99969E99
9A959FA0A3A29E9D
656E6D6B6B60747F9CAEB1B3B2B6A3905E505A6D6E6A6B6D
696C6F757C7A787B7A6DF57A7577817F8C6D4F3448325B3B
39463A4D442B7A426AC11D4A8F86ADBBBB99ABBDCCABA396
A5ACADBAC6C8C9D0D2D4D4D7D9C17145222D5EBF65322F39
4C4647413438422D819D88A6A9ACA1989B96949F919D9BA9
A4A3A2A2A3A19C9E
67696F6E71665E7F9DACB2B5B6B2A18B5F47556667716F6A
706F6C6DB47979767375F56D7879788D8D6F675C382F7A37
363A3A3E34425A69309C29276D8BAAB6A397BEB5CEA9AFB6
99A8ADB6BFC8C8CDCDD6D6D5D4B46631253835B7722E333C
42434C40333A3D314E9A8E99ABA09E9A99999BA1AAA9A2A9
A8A8A89DA2A59D9E
6566706C6B6B60809EADB8AFB3B2A18A6B4655646468686F
6A6B726E6F78767667CFED666F6E737A7F896A7C60335C38
2B3C3C3B5450483142632E24209675A8AA85B7A9BEB8A2A5
B7ABA9B3C4C8CDD4CACFD8D4CAA05525315A9FC24B2A3636
41443F4836333634418E9687A69D969AA3AAA7A9A9A5ABA9
A1A7A3A2A3A1A39D
686B6E7066675E7E9EADB1B4B0AE9F8B5B4B57656E696368
65666F75777A786F5EF8DFAE5B7F7F85758A8F7F8D26385C
313733704B58482D7867312C292B8C6B9B77C8BEC2C5AC9E
AEBDABA9BDBFC9CECBCBCBD1C2814D232E60B3A659393032
444342443E3837383967997D98A0A6ACA9AEAAA7A8A3A6A8
A8A9A5A4A3A1A09F
6C72716D66695D899DADB6B4B7B4A18858435463626A6D6C
6E696C72767973725FF4E9C673837C857A79998F83616254
4537455B4E44563D8B293F373A312B765576A6B1B5C1B7A9
B2BAB9A3B2B6C9CFCACCCAC7B57F472E7B589CA979282B34
3A4040543B3B33373652858781AAA9ADA9AAA8AAABA5A7A0
A8A6AAA5A8A69F9C
6D746D6C6D696587A0ABB6B3B4B29F8B60475F6462676667
6C696C70737A716B59F7CDCC8C7B7C6F87816F8882808849
5551556B4333445E454F31383945313C48657DA5BFB3C0B4
B0BBADBAB8B3B5CAC5CACBCAB35F4E8C5C9699A974232C31
383D443F403C313F3946709584A2B5ADACABA6ABA6A8A5A6
A9A6A5A0A1A29E98
6E706F6D6F666784A3B3B7B0B3B1A18956455462626B6A67
6B697171766E6F657DE7C8C24B89807F838C8D848A7F9086
4E5753693F2E2E8F243E4944593A366657879B83CDC8C9C1
BDB8BCB7B6BBB9BFB4BDC6C687577372758C81AAD6832C31
373C3E3A3A3F333340345393898EADABABA5AAA6ABA7A6A5
A0A7A6A3A1A0A0A2
766B7476676B698EA0AFB1B1B3B4A38A5A44606A69696567
6966716C6C6F675BFFE8A8A68F7C8886727E8A7F7F82876E
704B5F465644306E2D2871403A48357B289C48818BD1CBC2
C3BCB9BEB4AEBBBFC2C2B9B55166466CA28A8B9BB1C3DC26
34343D3740513535393B4A7D908DA5ADAFA8ADA6A9A8A6A4
A3A2A2A1A3A09F9C
6B6D6C6B676E748B9FADB2B2B0B0A289584C6269666A676C
66666E6D74675CBAEAE39FAD835F858D877184857C849393
87736D3E485341385C2E3E7F413A758A495C1CAF9578D3C7
BFB9B8B7BCB7ABBDC6C2C9C9981D78846F69A7A6B5B7C7DB
3A3F3C383D3D3B3234453C63A296A0ADABA8B0A9A6A7A7A5
A1A1A7A29F9E9E9E
6D66726E696B798AA3B0B5ACB0B2A288584A596867697369
706C63676A6752FDD8D4C2A8AE7979919388788A8C867D8C
89919F74473D8034383537736C383C8A552E35905EC079C8
CBC0B6BEBDB6BFC3C1C2C6C6D3D831706A78A4ADAEA9A9B9
E331273A3E3A39383F3E2F36999D90ABA7ACAEA7A8A7A2A4
A2A8A29DA19FA29D
666A6F6A6E6C748FA4B1B7B2B0AEA6855D4663656C67676B
6F6869696A5D58E9D9C7A27D82865E799185837A82898A78
9B908D83955F3E6069433C4198712E3047793C2F272ECC77
C8C7B4B6C4C2C3C4C1C3C7C6C9CFD9CD6A8F845E6B93A9AF
B9DC2F2D34443C31383E463975A49E9FAEA9AAA9A8A6A4A2
A4A1A19BA2A29F9B
66636E6866707D919FB1B5B0B1A9A4865D4D526665706D70
6765696C6258ADDCD6C691709E8F805E8594919084858C82
809595708B926A836C3F453E526556544D8D585128232FCE
72C0CCBAC5CBC4C3C3C5C5C4C3CACDD1E1D05A5D5A506286
A5CEE0212E353A343A3642383E9F9E95AAA9A3A0A4A6A0A3
A19FA0A39FA19E9E
5D6774666C70768BA3B6B8B2AEB0A387524C5C67636B626A
6768726A6156E8D2D4C08476907C6F8B7782928F927F8B8B
89899A93618F8881718D875D6B81555E4A7A503F41382A23
ADA8A3D3D1CBC5C6C7C9C8C3C8CACBCDC8D7E09E5A555F5E
6387CADD5D2E3B4237403B392A77A2949FACA4A1AAA99CA4
9FA3A0A49CA2989C
606767696E70788DA4B0B6B0B4B1A48761475E6969666E66
666A6A676155EFC6BDB88F89B176707F88758E958D8B7C89
8F86938F9D5BA4816B5C5443A5AE987A6A3D834646433035
2699BCA0C0D4CBC7C7C9C4C2C9CECECCCCD3D3DCE0C2895B
576072CDEB222F3B3831384A3056A89D90A6A5A4A4AAA1A2
A49E9FA2A0A2A3A2
6366656A706C72929DAEB2B0B6B2A085584563636E676966
6E656A676652EABEADA0A2A39C6F7B7F81877C9091979774
8B918B9C9F9C56A28E7F7A4FABB7A6847A68BFBB8F9FBDA5
2FAE8ED39FB6D1CBC2C6C5C2C9C9CCCCCAD1CED0D4E0E8B1
81515D7DE1E8182A413B343C4841809F989FABA7A49E9EA1
A3A39E9D9E9E9E9E
60646D67696B6F8D9EACB3B2AEAE9F8A5B495E65676F666D
68676A686253E9C2A095918E9772778F958A8A859F8A8F94
7D93998E96A5AE936D7B8EAAA1A452ADA9AF9EB6AAB2A4B5
BDB1A9A0C5B1AFC0C9CAC3C3C4C8C9CCCFCED3D0CED0D9DD
ADA7626193EE1D24413A38383E524AA89D9BA1A6A7A9A0A1
A09FA4A3A3A19D9F
61685E666362728EA1ABB2B5B2AD9E815D476364696A6A66
6669686B6856E2C5AC908E82796F6392878E90757E909595
8D83909B8D9E9DA598BC9B9B96AEB299B4AEB2A4AFACB0AD
AFAEA8A6A49FD1B4B1D0CDC3B6C2C5C5C8CFD1CFCECED4DA
9DAC97BD8BC4B91D36404B3A44364B87A6999FA6A6A49FA4
A4A5A1A5A4A3A5A4
5D63636766656A8AA2ACB7B2B4AD9D83594C62666E656C67
686E73696C5BF6C5A499908A6A62726C8F9893898282939C
8F8DA08EADA0A29DAE98A6BEA5A6B5A6B994BCA4A6B4BAA5
B1B0B8ACABA89FC1BCB3BFCFD5CAC5C6C4C4CCCBCACECFD4
D69ABD89A2B7ED1B30393E3437383B579F9C95A1A5A8A6A1
A4A5A6A1A3A5A4A5
6362616C65676A89A8AEB2B0B2AB9C835852636B716E6B6A
6C686E716C60F8CBA4A69F8A7C68527978928D918E9A7A97
9C9A9D9F859B9A9FB3B1B5A2B2B1A0BDA8ADA597ACB0B6B4
C2BAAEB3B2B3B8948FD2B6C3C8D6D0C7C6C0CBCCCDCACDD2
D6B59ABB7EAFD12223494633313B38567CA5979DA6A6A6A4
A5A2A9A4A4A0A0A2
5C66676B6D696C859CB0B7B1B4AD997D5A526A676C6F676D
686A716C6965F1C0AA939182706C6A748864908A9097997F
9C93A48E9D9CABB298ADB4ABACACB4B7A39EB8ACB7A8BDB7
C1B5C1BAB9B9BDC1B8A9A9D7B4C7C6D2D1CDCBCCD0C9CDCE
D0D2AAA2C7BEDCD2203636343A3A393A438EA699A2A5AAA8
A3A8A3A4A0A1A2A1
64646E6567686D879DACB2B3B3AF987B5A4C5B6C676C636C
69626F6F6962E7BA8F937B75697673578485788A949780AD
85A499AA8A9FBCB5AD9BC0AEADB0B8AABAB4B9B1B3C9BFBE
B4BEC7BEBABDADB8BEAAAD97C0D3B3CCC8D6D4C4CCCCC5CB
CED2D4AED3DBE1E4222D3637403A33412B6BA59998A4ABA0
9FACA3A49EA2A0A4
626770687569708CA1AAB5B6B2AC9C7F575360665F6F676B
6666686E7364CFCC9F7F6D76736D787E7A848E6E94949E93
A777999BC098A7A6C2BFACB1B7BAAAB7B9AEBFB8C1B6BDBB
C8C6BFC7C0C6BABDC0C1C2B2BDBECCD3BFC4D0D2D1CECCC9
CFCFD0C8CFD9E2E723263E343A36343C48538BA396A1A5A8
A4A4A2A1A0A49FA1
6668676A6E686D8A9EADB0B2B2B39D7F615364637168666B
676C6D6F6F697ADA987F676578747070788276857B9B969B
9DB07AA79FB49AB1AEABA9B699B6B5B4B9BDB8B2C7C2ABB9
BEBEBAC2C9C4C8BBC5C4C3BFC3C98E9ED3BFCFC0D9D4CDCF
CFCDD3D0CDD8E0E38E263F3F42363B363C485EA09A97A6A2
A9A8A4A2A2A3A09B
626D6E6A7069718A9DA6AAB0AFB3987C584D5C646C6B6C6E
6A676D71767364E08E756F6E6C6E757B6789886D7D77939F
AA95A277AEA2B6BCB6A0B6CEB19FB8B2C6B9ACC4AFC8CAD3
BDC2C5C2C9C9C7CBCCCDC5CBD3D8979388C2E1B5BCD2D9D3
CDCED2CFD3DADDE2D71F39463A3635343637337EA79899A9
A6A9A4A0A4A49FA0
6065666B6A6362899EA8AEABA9A9987E5B565F6A6E6C6871
726A787579796CE8A86F64647672826D7D85878B7D7E6B87
A3A6939D9DB0B6B5AEB5BFABB5BDACBDBCBFC3C1C4CCC9CB
D5CAA8C0CDCFCED1CDC8CDD6DAA99A9C9A917ACCE4C2C2DC
D8D1D2CCD0D5DDE3E620283A3C4133353A3E2A389BA290A4
A5A3A59EA4A49EA0
5C606A6C666862879DA9B1AEABA79E7A57515A6B6A6C6F77
6E6E6F7776786BEFB47168737172817F7E82837E8E978871
869CB995A2C69FBBB7BEBCBCBEB5BBBBAEC4BBC9CAC8CAC9
C5D1C3A5D2C9CED0D0D6D9DAC27E969EA29A865159DEC6A8
DADCD7D3CDCFD9E2E5132A3C443A32313B3B392564A89D91
A7A8A3A3A6A0A09F
5C5A6467676B648A9DAAAEADACA39375584B5C666A6A6E6B
706D6E77747273D8C7645E6C797A657684868770869B7589
7A77A8B9B1A8AFABBDB6B7BDBABFC8BABFA4C1CFCECDC8C0
D2CED3D2D8CDCCD2CFD6DDA66C8EA0A2A0A79A712719C3E6
95D3E1D9D5D4D2E1EB13253D3A3E363F373D3C3F3492A797
98AAA3A1A5A5A1A3
565F696466616084A2ABAEABA6A59477574D4F61626B6A6D
686C726B787A6F88CF716472707773777B8A927B8B728D87
8A6D69B6BEB8A8A3C6A9BBB1C0C9C5C5BAC9C8B9CECFCED3
CACEC5CBD2CFD4D6D2E6E1347694AAA2A39F9A7C42221D86
E9B7D2E2DEDDE0E2E316263F4B403B3B393A3B43364E9F9D
8EA6A4A3A6A1A7A5
5C5E61615E5B5C899DAAAAA8A8AB8F7C54475664686F6669
696C717471707271DD7D5B717A727C7C7A88898C8E897D8E
937F7E6AA7ACC6C8B0BAB4BEC8C5BDCCC8C6CEC6CBBDCBD1
D6D4CED2D0D7CED4DEEA644984A1A1A39D9D9A784E302B26
3BE3DBC1DCE9EAEDBC1A273848393B3A42383E40462F75A8
9690A5AAA4A7A1A3
5859635A5A5C628CA2AEB1ACA5A9967E5B4D586664686769
66706E7372717671E87D676E697F7A777673838E8F899A92
86968B837199A1C9C3B9CDCE9CC1C7CAD0D1C5C9D1CCCAC5
D0D0D2D0DAD0D4DDE9E322538CA19FA09D9A9C7D51313432
252DE1EDC5CFDCE1261C2A32443F3D3B39423E3F362A3D8B
A19792A6A7A5A7A6
5B5D6965665E63899EA7ACAAAAAA957C5D4D625F6A687070
6D6C7675797A7C717AAF5E6B74786C798083828685939B91
8793998F7B716DC1C4D3C2B8C1C2ADCDD1C3CAD7D0C5D0D4
D4CAC8D6D1D9DBE4EA9B35638F9FA2A0A1A0957D52362F35
31436397C7BF879D84202E353B46383E3F393E363B3D303F
9C9E8C91A7A8A5A5
535A626164626A8E9EA3AAA8A2A5937859506264676B6D6E
696C6C757E7E777973C8646F797A727C7E77838C7E929799
7797A4977F7E9080A9C0BEC0C1C8CCC7ACCAD6D5CDD4C8D7
D5D4D2D1CDD8DED9DA2343698FA2A2A2A19E9881512E3232
396B8F9395898C90A26B2C34333E4142403C3E3A38463634
5D9996899CA8A9A9
565862655C5B6B8CA0A6B2ACAEA3907E65485E646C6E6D70
6B667076777D7E817B857C736F7F78777975727C8A8C958E
929B8F88879297998283CCCCCDD1BDC3CAD1CDCDD9C7D2D2
D2D4D6D7D8D9DAE9353556768E9FA2A09FA4947B4E362A33
6C969EA3968D90979E9F3127323B45383D38403F2E433B3F
3B739C9696A1ADAC
56546365605C6485A6AAADADA8A3927B614E5D6A6B6C6864
68707574737D82807E7E9A6C737D777C7F7885847F91827F
9395938A909295A590B48CC2CFD0C8D8D0CFC2C6D2C9C6D7
CBD8D9D5DCE1E44C334A5F7B969D9FA29E9E957E522C264B
7F95A49C9491969A9AA1902B302F4548423D323947383940
43457B9E9D95A9A9
75545F655F576A90A1AAB0AAA9A293735A505D6F7C6B6B6A
6D696E7175797C7C7E8083777372767F7E7C706777777D7E
8993969099959D999FADC89B92CAD0D3CFCED0CDCAC5D4DE
D8D3D2D7E5C6384451596B7E959F9FA59F9F947B4B223D73
93A1A197928F9A989897A7692B38394043423A2B423B303C
44435984A0988BA6
8D745B5F635F6A899EAEACAAA9A5927B5D5060666A726B6E
6D6F7171797A7A81827B7F846F7076786E8D8478787C7E85
879B93888D9F97A09DA5BBADB795C0D5CFCBD2D2D0D6D1CE
D2DDDEEDDE3B43516366657B909FA6A29D9F9A7F4E275784
969DA0979897949C93999B9F315D43323B3C413730423B38
36495858819DA287
9D8B5A5C615D6B8CA3ADB1ABACA3937E5C5766686A6C6C6C
6A6D6D737D777F7C8279878086766A7A7D70887A817C7D87
9394898F8EA097A1A0ADBCB5BAC2C19FCCDBD6C8D5D5D0D3
D8DCE4E35C4158686F6A6A7C8EA0A09C9E9D917D4035719F
9EA09595919A979491949AA2912A2B2F3B46363C363A4638
33464C4F4F8CA198
AB9C7C575A516892A3AAAFB0ADA592785152606A686E6A6E
65706E7B7D77757D8583848489866F787780868687807970
8285837F8890949DA9A1BEBECAC2BCCAB5AAC9DBDBD5D3D7
DBDFE89D41606B6F6D67627B969FA09D9BA092774D59849B
A99A9895969895969796989AA66D322C3339434A39313746
2D393D4E4C4690A6
B2A18E6C5D5B6A8B9FAEAFB1A7A6947C574D61677467706D
6F6D737B82877A808483858381867C7669777E7B6F857C92
89898E8A8B929C9CA5A1C0BAC8B9C0C6C8D5BBBFB5D4DDDF
DDE9E03D596D696B6F6B6F7494A1A1A49F9F8C746A7A97A3
9D94989B9395929396989C9A9EA73E313538393E3B333038
3A373942622A3FA5
BAAAA180574F648DABB2ACB1AAA5937D544E5C6A6E686A6F
6B6C6F777A7B7281807F817C8281DB7677787B7E82828781
8C8E949D969A94939BA7B6B8C2C1C5C5BECEC3CEC6CDBAC2
D69D4656707B706F716B667E979DA0A59D9A8E827C8D9DA3
99959C9A9299979795989D9A9EA19A2D2E3531393D3F342F
3D40373A47442359
C5B9A6946D4D658E9FB1ACA8A9A49380504D60656E686468
716774777770777E7F7E8583887F7F7477847F8383868499
808A927C97848C9EB2C0B1B3BDA9C6B7CAC8C9C7CEC4CEC9
51585F717E7A7A746F736B7A909F9E9F9B95908F8D959D99
959695989497919B96949B99969CA6B32E3A323C3939473C
3A423E3038504519
C2C0B09987606193A4ADADAAABA893845B495A656566676B
676B786C7A7E79778A828384848576AD62868E8587828689
7B868C999EA099AFBCB2B5C0ACC8C6B6C7C1CFC6C8C1A859
636E78767D7C7472736F6F8397999E9E989894959E9DA592
949197979196958D9695989C9A93C5F4D126313833433845
3D323C3D3637432D
BCB5AAA294766091A5B3ADA6AEA99A825B575F686B696D6E
6A70707B787D808284887E8283867E86A482918784848290
8A869D99A29EA99DA6B4BEB5C8C3AFCAC2C6CCCCCA776570
768181807F7E77757073767D91979B96969A9E979CA09C93
91959C93969991909597978F949EE6F1F3AF25313C373D3B
3E37354238333A40
B9B1B7AA998A7E8DA6B0ABA9ABA39B825A4E706F656D696A
6A6E7479827F838081837E8C86848186848B91A08C79838F
8F898F9993A09BBAA5B7A2B0C3BFBACDBFC8C2B26171767C
818282847F777A79766D747D8F9399929699969B9E9C9A9E
959899969692948F919892928FDBEBEDEAE01F2C3C33353F
403E35373A3A422F
B5AFAEB1A698898E9AA9AAA4ADA897815A5761696D6E6E70
79727A8281808282858587858D8A848A8787838885878B99
8B9E968DA9A8A9B0B5C9B8BDB5A6BCC3C4CA776D73808086
848188858483847C7871728092949E97939AA49FA29A9B9C
9A999A95979390959493948FB7E3EAE9E19E5C2C2F413D39
413A3D323C393833
B9ADA8B0B29D94979AADA8A9A7A795865D5665676F6E6D70
786C76777E807D838A828284858788808A89828591848884
91949D8E9FA9A3A6B0B0B1B5B8C6C2C07D65757882878987
86828883827F7C7D7774757C8F979598979EA49E9BA59E9F
9E9B9F9C9B908F8E968F929CDAE8E9E6BD6275622F333436
423B3C4038333A3A
BBB3A5A9AFA59B9B9EA6ADA1A9A49687625A6C6A6F756D6A
6C6E7A777D7F7B818682838C858586868C8581858B8D8687
818D828AA29699BDC0BBC6C1AA7A6B73787D8080838B8A89
84838784827E7C7B7872727F8C9398969CA0A2A19C9DA1A2
A09F9A989A989499959894C7E6E9E4D37167777F61343235
3A4343453B323438
B6B1A9A6AFB3A6A2A5A6AEA5A5A695835E5E676C6C736C69
6D7473747A837B848281838A7F8387898683828784878683
8782838C83817C7D7C736E73767C7B7F838381888289828A
81818789847E7B78777473809193999CA2A3A8A0A19CA1A0
9E9CA5A19A97969791909FE0EBE5E4AF526A717F8E683532
384342433E3C343D
BCB0A1AAA5AFA7ABA8A5A4A3A7A3938056566C6F6C6C6C69
6B6870797C7F807D84868287887E808890888187878A8784
8A8485808A7B7B797F76797D8181838B8E87858786848986
8581888284867D7A797875858F9E99A3A2A2A2A3A2A3A0A1
A2A5A5A09A999B979290D0E6E8E6D1676B6F7E7F8D90642A
39354C48413D3B35
B7AEA5ACA7A8AFAFADADA59FA3A99380605D6C6B70706E74
6E6974777E828284838189888982838C8A88868A888A8681
898883848082808283817E7F838988898C8E868B86868382
827D83878982797E7876778091989BA3A5A4A5A4A2A0A6A4
A3A2A0A3A19FA29794ACE0ECE6E09E606E7A84848386966A
2F333A383A413A3E
B5ABA7ACA5A5A9ADB0ABA7A0A3AD9980625A6A6A7775706D
6F7172777D848182818784858B84838C888A8D888588858B
8C878B837E817F7F85838A86878D89878B8B88897E868882
85878787847F7B7C76777A88939EA8A5A4A6A8A7A1A89FA4
A59CA59F9E9A9A9995D5E6E9E3C55A62787E85807F808A96
622E3A3A3D3D3B3E
B3ADA4A5A6A0A3ADAFA8A3A4A2AD967B6257686F70736D6A
706F75787D7E81828687888588878688888783858882858A
8B89878488828386858188878182908D8D86848584858480
87868488847B86797673748292A3A6A9A5A6A1A4A3A69FA0
A29DA39F9E9C9995B8E0E7E3D1855D758684868078828188
966634372F36363D
B3A5A1A3A5A39EA5AFABAAA8A7A29C88645B6A6B726E6B73
696F7277787C80858687898A8B8C8B84868B868B8C868791
89858D868A868586898785868F8B8B8C8488888989808286
8284878F84827E77716E74819DA1A2A7A4A5A4A4A8A29DA4
9F9C9B9E9B9E9E98D6E6E3DFAF5F6779797F827F7F838686
8F936940493F3637
B0ACA4A7A6A3A0A2A6AAA9B1AC9E968C5F5A67757170716F
756D777E847F87808888878A88908A8688888A8B8B878D87
89888E8B89898F8E898F87878A8C8C898C879A84878A888A
858E8C88847F7E767572758C9DA2A9A8A7A8AEA9A4A4A1A0
9F9E9D9C9A9F9BBFE1E5E1CC67607276808583807E7F8389
8A8F936A27334631
B5A9A4A0A2A19A9CABAEAFABAEA3927A666062727374696F
746B77767B81868684888587878685878A8789868C888A88
85888A8A89888C89888A87898B898E8F8986898A85848889
8286858687807979756E7A94A2A7A7A5A4A8A9A5A3A1A39F
9F9E9A9EA0999FD7E4E3DA9E5D6B807A7B867D80847F8081
85888B976C36343E
B3AEA6A1A0A2A0A29EADAEB1B4AC928061596D676C6E726E
6F6B79767B868086868A84848B888987858B8B8A8B8D8987
8C8C8B88888A8887848F8686888D848E828C8E8588888484
888B8881867C79716D6F8B98A1A8A29C9DA2A3A3A3A09FA4
9D9AA19F9F9AC6E2E2E0BF5D627681847F7B827A7E7E837F
8282828C92733937
B4ACA59EA0A09F9DA2A2AEB6B0AB997D5E59647272696B72
6E71757981868888858789848B8A898D878B8F8B898A8788
88898C8490949088868887868D8C88888C89878785838486
88898984847B7D756784959FA4A7A499979FA0A1A19EA0A0
9DA1A8A2A1ADDBE3E1D4835D737D7F807C86828183818382
7F858086818A7D49
B2ADADA0A29F9EA29FA4ACB1B1AC9584625C7172776F7476
756F7479778582808C868E8A8D8C858E868C8A8C8F8A8B8C
8E8F8F8E948C888A898C8C888F8A8987928A8B8D87848885
848A86857E7D7B796D8397A3A8A9989F9CA3A59F9E9F9D9F
9EA4A2A3A0CCE0E3E2BF5E63797F887E827F7F8181838583
87858584767B95C0
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[36]:=",
  ImageSize->{452.062, 141.25},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000740000SA000`40n007h00OooooaOoo003oooo5
ool00?ooolGoo`00ooooaOoo000;oon7000<oon7000<oon7000<ool000_oo`03003ooooo08?oo`03
003ooooo00[oo`03003ooooo08?oo`03003ooooo00[oo`03003ooooo08?oo`03003ooooo00[oo`00
2ooo00<00?ooool0Pooo00<00?ooool02_oo00<00?ooool0Pooo00<00?ooool02_oo00<00?ooool0
Pooo00<00?ooool02_oo000;ool07000ooooof]]LhiccW_?Q12L/jeE]IJU59ccW=>]MKFf_MN]UIcc
LjiBRSW7@NQ2:4YY@TQ:JDY90TYY00=JZe[[F^/00f<<0V]=00IcSV<<H`aK2f</H``2Jdd017_?Lhic
SV]=0W>>0W_?0W__00R447`?Q31l3h@@Nnn447__0X@@00N4<8@@Q32448@`Q124<003Q1000h@`Q124
<002Q3000g__Q11kc`02Nll01X@`U9:LljDd[EFUE0:]E@:eUP:e]P0?_MNeeZeEU=:<DH@`S56DTZeE
_OO>NLHh[GF<DG>>009[C@03HbaS35/;00AS;006Jfec[W_?JfeS;5[;0U:Z00EJjf</ooooo`0000co
o`0=003oooooDXXiidYYBTUkcg>^U;:LlhaAU=800X@`0Xaa02:DTXaAS36<LG__LjiS;7?>Jfekcf]]
Jhf<DG>^Q11kch`aF^^4<7__F/^<DE[;Jde[KF</Jbekkf]=Q11[KG__Lhic[P9kc`05Q11kkh`aQ12<
D@02S743S5402YBBS56DTXaaU9:<DIBBS76DTXaa0YBb00BL/iBbW=>D/P:Ld`0:W?>U59ccYAB]MIdC
W=><LIBBS742W?<01:DDW?>U5:Dd0Zee01BeUX@`W==[SF]=JfecSV<<DXYBZU[[Hbb]MJDdS764<7_?
Ljikkg>^0W__00^448@`Q324<7__Lji[KF</Lji[KE:Z00;oo`03003ooooo00[oo`04003ooooo8@@2
<HH08BUUU=;F^/jIaQQS38aA[EFe][GF_MNe]X@@>NLaIR4TBVTaYU::<JI:BD8X<JISC6<<BVTiag?>
:DE229Bb:FERk002:DD03DYYBRTYIF</F`^4448XDXYJbf]=Jhec[W?>009kk`04S55kkh@`Q103S540
0h@`S76<T@02S543U9801IBbW=>D/YBbU=800YcC19cc00FU59cc[GFU=:ee00:]E@0=[GFe][gGaQS6
F<iicYWFf]kkga_Nnf]=DZX00U[;00m[CG?>Q11kkg>>Ljj448bAQ11S;5[[BVU:BE:ZH``00U:Z00U[
CHaAQ31c[T8X>JLQ92U5@PP00V</0_oo00<00?ooool02_oo000;ool01@00oooooe[[DZX00TY900U[
CHaa_OO6>:eEU;:DTZED_ML00[gg00JU57_?BTTaQRU5<HH2>LL02cWW@PPiid88BTUBRTYYDXY:JE[[
DZX00U[;00iBJTY9@PQ224XY@RQJbe[[F/]:JE::F^][CF]]0W>^0W__00B3l7__Q11kk`B440:4<003
S364<8aA00><D@0@S76<DHaaS56DLXaaU9:<LIAbS56<LHaAU7:DTYccYC@2[GD2]KH06;ggaQS>FLiI
eY[>VMJj[GF<LF</Jde[KG__S56LlidCW?><DH@@LjicSV</F^]BZP9BRP04DZYBRU[;H``2Ljh01f]]
F/]2:36V>JM225[;00;oo`03003ooooo00[oo`09003oooooU;;NnliiaSSW78aA009c[P04Lhk6>9cc
S742S54098@@NjnDTZee]MJeUYcc[EFLlkFfYABU=:fE[CEkclGh]KJDL]JjYABDT/HHU9;F^[ggYABe
]Zee]KIkcicCW?>U5:deW?>Tm0>Ld`03U;:<LIBb00>DTP03S56D/YBB00:<L@03U9:<LIBB00><D@06
Q32<<H@`S564<8aA18@@0W_?00Yc[W__Nnn<<HaaQ12<DG__Q11kk`9kc`06LjicKV]]BVVmmjDd0[FF
01^mejee]KJm]kGFW=>DdW_?Q32LljDd]GJ]MJDdW?>U5:DdW=>4<8aAU;:eU[ggaQRmmjeeYC@00_oo
00<00?ooool02_oo00D00?ooooliYc66008ia`09]IKFV]JjaQQS;8aA[GFmekgg00:me`08LjiJZc6V
<HHiid7XBTU2209Jb`0G>LM229cc@PPiih@@F/]kkd88>NN<DC6V>LM::B4TDXY229BB6><aITYYH`a[
S@02Ljh06X?`Nnn4<8@`Q124<8aAQ12DLX@`U9:D/XaaS56D/YBBW;>DTYbcU;:LdiBbW?>LdjDDWA<2
W?<2W=<019ccYABU5:Dd0ZeE00Bm]jee_OO660;>N@03e[[FV]kk00;Nf`05>LMBZU[;Jbe[K@02Nll0
2X@@JfecKW_?S56447>^F^][;E[[0e[;00M:JF]=Nnn<LG_?H`a22002>LL00d88@RQS3002ool00`00
ooooo`0:ool000_oo`0F003ooooo:DDQ912R6>=2:8@`aSSF^ZeEU7:4<:Dd]MK66;hG[GEkkd8X8@@2
6<<04b446><Y9B4T<FHYAD88>PLiic6V>LM:JD8X>NLiYb4T:DDQ935V008aQP0=>PLiibUU8B@YID8X
DXYS36=<JfecSW_?Ljh017_?00B447__Q12440:4<006S364<8aaS76DLXaa0YBB0YBb00JLdiBbW=>D
/YcCU;82W?<04:DDYCB]MJfE]KJmelHhcWWF^]kKiacW?>mmicbeUW_?0TYY00=JZe/;Jfd00W>^00Q[
SG>>Lhikcf^=H`aBRTY90T8X00e223WW>NMBRV</LjiS;5::<HHQ11S38B@aQP02ool00`00ooooo`0:
ool05000ooooog>>W?><DHaa_OM[SG>>Q11[CLIHS76448aAQ52<DG__S542W?<2U9808iBbQ12D/W>^
S56D/ZEDBTVLljee@TR]MF</U9:LldYYU=:U=8@`aSRLlh@`NnnD/ZeeS764<8aAQ32DTXaAU9:<LHaA
U9800Xaa00BDTXaAU9:4D0:<D@04U9:<DHaAS542S7400iBBS56DLP03S74018aAS76<LHaa0YBB01^<
LIBbU9:<LIBBS56D/XaaU9:<LIAbS76DTXaAQ11BZ]kKU=:LdiBbU9:<LIBBS56LdiBBU;800X@`00B<
LIBBS56DTP><L@07U;:<TH@@Nnn449BBU7800YcC00F<LIBbooooo`0000coo`0F003ooooo<JI223WW
BRVU5=kkcYVmef<<S56]MKgg_MNe]ZfEW==:BC66F//2>LL01cWW>LM:JCWWJbdaQYBb008aQP0:LliB
RYBb:DDj1c66:DEJbiBB@PP2Jfd02C668@@Q9488DZYS;7>^Nlmkk`02Q10018`aNnn448@`0XaA00J<
<H@`S56<LIAbS542U98039BbU9:L/iBbW=>DdYccU=:LdhaaW;>DdP:Ld`0:W?>DdZDd[EFeUZfE]KJm
mlHhcUT2cYT2e[X01=kK[EE226<<0V]]00Ikcg__Nnmkkg_?Llh2Lhh028@@Lji[CF<<JfeSC5Z[BVT2
DXX02W>>O0n446]]Hb`j1d88BVTaYSWW0_oo00<00?ooool02_oo000;ool04000ooooob3T6><Pi244
BVV4<<HhcWV]=HaAS36U=;gg0/Hh00B]UH@@BTTY9@8H``086:<H`b448B@Y9B44>LLaYP8aQP05>NMJ
jd88>NLYI@03:DD03C66>NLiad7X8@@H`a1R8@@aYTY9F/][CF]]009c[P9kc`04Nnmkcg__Nnl2Q100
28`aQ32<DH@`S56<LIBBS742U982U;801YcCU=:L/iBbW;>D/P:Ld`04W?>U5:de[ED2]KH04LHHaSSF
V]JjiacW?>mMkggNficCJbe:BE:ZF/][;F]=Lhh00V]]00ISC6]=Jde[CF<<F//2BTT03T8X@PPiacW7
@PQJbf</JfeJjdXY:FDQ11SS8@@2ool00`00ooooo`0:ool03P00ooooohaAYABDTYcCaQQkcg>>Njm[
CLHhS742S5409iAbU99kkg?>[CF<LHaAQ32L/haaW?><DHaaNnn]ED8X[GFeeV]]YAAS3;Ff[EF<LMJJ
F^]cSX@`JffLdh@@]MJLlhaaU9:4<8aAQ32<D@02S7402haAU;:DTYAbS76DLXaaW=><LIBBS7400YBB
00><LHaAU9800haa00^DLXaAS76<DIBbS76DLXaaU9:<LIBb00:<L@:<D@B<L@0:S56<LIBBS75SC7>^
_MN4<8aAU782S5402XaaS56DTYAbU9:DLXaAQ12DTXaA0X@`00F<LIbcU=:Ldhaa00:44006S36<LIbc
U;:<DIcC0_oo00<00?ooool02_oo01L00?oooom1j4YYDVYBZZDDcWW>FIBBF^^<DKFF_OO66;gg_MND
dS66@PPaQSWW008ia`0N@PPiicW7>NLiae::<HHYAH@@LjiBRS5VLhiBRR44JhdYAG>>Nnm2:2U5<HHi
YcW7>NMBRV]=Nln3l7_?0X@@00f<<H@`S56448`aU;:<DHaaS56<LIBBS76L/`02U9800iBbU9:D/P02
W=<4U983W=<02iccYCBU=:eE[GFeM[gG_OO66<iIcYT00]Jj01ONfmJjDXY:BF<<Lhik[g_?Nnmc[W_?
Ljikcf]]JdeS;7_?HbaJbe:ZJbeJbe9Z009BRP0:DZYcSW_?Q11[SE[[>NM2:36V<HH2ool00`00oooo
o`0:ool000_oo`0O003ooooo488H`aSS:DE:JH@`]MJmmiBbNnn44:Dd_MO6><HH_MN444YY6><H`a2R
6:<@XQS36><Q11S3:DD00R4T00<YAD88BXT00SW700XYAB4T:BDYID7X>NM::C668@@8H@8@PP0:8@@a
QTY9F/][;F]]LjicSW>^Llh2Nll2Nnl2Q102Q302S542S74019BBS76DTYBB0iBb0iBB0YBb0YcC00ZU
5:Dd[GFeU[gg_QO>FLjIg]_O6`;_G@08kgg668aADXYBJU;:H`aS;0=[K@04Hda[;E/;F^/2F//04E::
BTU2:4Y9@RQ1j36V>LM2:5[;Hba[CE:Z@NPYAB3T6<<00_oo00<00?ooool02_oo00<00?ooool00YBB
016<DHA@]IJ447>>Nln4<<HHS76448`aQ32<DH@@LhjeeYcc00:DTP03W=>DTYBB00:Ld`0KU9:mef]]
[GFmee[[S564<;ggDXZ]EIccS56U=8@`Q51kckGFU;:<LIcCU;:DLX@`Q124<8aa00F<D@03U9:<DH`a
00><L@03U9:<LIBB00><L@06U;:<LIBbS76DTXaA0iBB00B<DIBBS76DTP><L@>DTP0;S96D/XaaU9:<
DIBBS75S;;gG]KJ4<002S74048aAS76DTXaaU9:<LIBBU;:<LH@`S76DTYcCS76DTYcc0YBb00VLlhaa
Q324<8@@S96LdhaaW?<00_oo00<00?ooool02_oo01@00?oooolaYSWWF^][;Icc_ON]EG__F/^<LKFF
_MNe][gG]KJU=36V0RUU01QJZc66@PQ2:488DZXYICW7DXXj1c66Ljikkb44F/^DTR3TF`][KC66Jdda
YW__<HH2@PP2<HH0248XBTUS36=<Ljikch@@Nnl3Q10018@`S364<9BB0Xaa0iBb00ZDTYBbW=>DTYcC
U;:LdiBBU;:DTP>D/P07W?>LdidCYABU=;FF]KH00/HH00C6><iieY[F^P?FfP08<JIBJV]=Jfe[SG_?
Jhf4409kc`0?Lhic[V</H^aJbf</F^]:BE[[NlmS35[;DXY2:6<<009kk`06LjiS;5::@PQ2:3WW0_oo
00<00?ooool02_oo000;ool00`00ooooo`026<<052TU>LMRk8aA]IJ]MHaALjj44:Dd_OO66<Hh_MN<
DE::8>@H`aRS4:826:<082446<<H`aS38B@Q1366@RQ:BC66:FDYACW7<JHiYcWWBRU:JCVW6><@PPQQ
488@XR44:FDiidY9F^]S;6]=Jhd2Nll2Nnl2Q10018`aQ32<DHaA0Xaa0YBB00FD/YBBU;:DTYBb00:D
TP0IS76DTYBBW;>DdZCdYAB]EJee_KNmmlhicWWF^]kkicc_GONNkgfe]W_?BTU:JE[;F^/00V<<00M[
;F</Jde[KG>>HbaJZ`02BTT043WW@NQ2:4YYBTU2236V>LM:BF<<JdeS;4YY>JLQ923T0_oo00<00?oo
ool02_oo03D00?oooon<LJDDU9:D/ZDdS76448`aU;;668aAQ32<DIBBS76<<F</cWVD/ZDDNnn<DIBB
Q12D/W_?W?>Tm7__U7:n5g=^Nln]EH@`DZZ]UHaANno669BBU7:DTXaAQ124<9BBW?><LIAb00B44003
S76DTXaa00:DTP06U;:<LIcCS56DTXaa0XaA00><LHaAU9800haa00>DLXaAS7401Haa01jDTXaaU9:D
TYbcS76DTXaAU7:<LIBBS56DLXaaS55:JNLLW=>DLXaAU7:4<8aaQ124<8aaW?>DTYcc[ED2S5402haa
U;:DLW__S56DTYBbW=>DTX@@S3400XaA0YBB00B<LOooool000coo`0>003ooooo>JMBZV]=NlnU=;hG
]IIkke[[S76e]PBme`0O[EE:BDYY@NPiad7X:FE:BCW7H^`aQSWWDZYS336VNlmc[S5V:FDaQTY9[GE:
BE::Nnn]=C6V<HHYICVW<JH00SW700@aIRU5@NQBZP9cSP05Q124<8@`Q32<L@02S54018aaU;:DTYAb
0YBB00jD/YccU=:LdiBBW;><LIBBS76L/haaW;>D/Ycc0ZDD01Z]EJee]MJmekhGcSW>FMJJe[[NfmKJ
g]_FVTXYF/][CG>>Jfe[CF</JdecSV=<NnneUYcC0U::019:JE::DZYBRV]]Q11S359Z@RQBRV]]Q11k
kg>>DZY::DYYBTT2ool00`00ooooo`0:ool000_oo`0G003ooooo6><Q1366BTU[KIBB[GFU=7__Lhj4
4:eE]MK66;hG_ON<LF<<8B@Pi00348800aRS8@@Hh`026<<2:DD03S6V>NLaYRUU8B@YAC66<FHaYT88
BVUBZS666><226402`Q1264@PR4T<HHiacX7BTU2:5[;Hd`00W>^0W__0X@@00J<DHA@S76<DIAbS742
U983U;801HbAU7:<LIAbS7400YBB00bLdiccYCBUE;FF]KK66<IHeY[Ff^LLic`2kgd04NML[EEc[T98
DZYBbU[;DZYJbe:ZF/]S37__S76<DF</@RP00S6V00laQSWWBTUBRTY9>LLaQSWWDXYS;6<<FZ/iic66
8B@00_oo00<00?ooool02_oo03l00?oooon<DJDdU9:4D:DdQ11kkg>^U;:e]XaaQ12<DHaaS56446</
]MIkkjDDQ12D/YcCQ12Llf=<YCBDTX@@NnneUU/;JffmejeEU9:U=3WWLjj]UDY9Q31c[ZfEW=><DIBB
S76Lljee_ONU=9ccO0n447__S364<9AbQ3000haa00B<DIBBS76DTP><L@:<D@09U9:<LIBBS96DTXaA
U9:<LIBB00:<L@04S56<LHaaS543S7409iAbS76<LHaAU99ccU::cUVDLXbAS76DTYAbU;:<LHaAW?>L
dg_?S76]MJEDU;:4D9BBS76447_?S56DTZDdU=:<DG`?Q124<9BBU;:<D@02ool00`00ooooo`0:ool0
1@00ooooocWWJfd00X@@00J]UKgg[GEc[U[[U;82]KH07[FF_ONe]ZDDF^][KB4T<HHiac66@PPiadZ9
:FDiif<<F^]:BF</<FHaQW>>BTTaQRUU<JI:RJeEH`a:B@8YA@05>NLaIRU5<HIJj`02Jfd2:FD00dYY
Jhekk`02Q1000h@`S76<D@02U98019BbS96DTYBB0YBb00NL/iBbW?>DTYAbS56<L@03U98019cCU;:U
5:Dd0ZeE02VeU[GFaQS6><iicYWNfmJjg]_FfYcCBTU[;F^=NlmS;6<<F^]JZe[;H`bDd^Llg_^D/TZ9
@NPiidXYBVUBJV]]LhiK2dYYBTUJjf^=Nnm[KF<<00=:J@;oo`03003ooooo00[oo`002ooo01`00?oo
oolYAC5V@PQJbg__W?>m]jDdQ11[KH@`YEBmmkhGaQRmeibcJfdiab3T4688HA2R488Q10<H``8YA@0?
>LLaQS5V8@@Pi2TU:DDaYSVWBTURk6<<>NLH`a1R00<8@@0<488Hhc66>LM223WW@NQ224YYH`acSW_?
0X@@00B<<H@`S76<D@:<L@:DTP03U;:DTYBb00:DTP03S56<LHaa00:DTP0<W;>LdjDDYCB]MKFF_OO6
><iie[[NnnLl0^mm00WgW]JjY?ASC5::F/]Jje:ZDXX00TY900=2:5[;Q3000[Ff00ZDTU[[@PPYIBU5
<HI224Y9DXY2:08ia`07BRUJbf</F/]:BC6V<FH00_oo00<00?ooool02_oo01400?oooon<LJDDQ12<
DIBbQ31kkh?`W?>meh@`Q12<DIBB00:<D@0ZLhj]EG>>[CFDTXaAW=>449ccNlnU=9BBNnm[KJeeLjjL
dkEfDZZU5:Dd_MN]MKfgH`b<LJDD[EFDdXaAU;:LdhaALjicSX@@_MNeUZeeQ31kkh@`0YBB00b<LIBb
S56DLXaAU7:<LIAbS76DTXaaU783S542U9805IAbU9:DTYBBU;:<LIAbS76DTXaaU;:<LIBBS76DTXaA
U7:<LF]=Q32me`02S5407H@`U9:<LIcCS76D/YcCS75:BF<<U=:U5;FF[CFDTYcCU;:4<8@@S56DdZDD
U9:DLX@@S76<DIBBS7400_oo00<00?ooool02_oo04000?oooomS36]]NjnDT[gGaQReUW>^H`bD/[Ff
_MNm]kgG]KJU57>>F//YAC66>LLaYT88>LM::C66>LM225::<JI[;C6V8@AS;36VJfdiYg__BTV<LG=^
NlliYc66@NPaIS66>NM2:5::Nlmkkh@@:DDYIE:ZQ32449AbU9:<D@BDTP04S76LdiBbW;<2U9800iBb
U9:<L@02U982U;82W=<01:DDYCB]EJDd0[FF012mmlHhcWW>NMJje][NnmJjg_]BRUZ[Jdekkf]]JdeS
;09Jb`03BTU:JIAb00;Nn`0;_ON]MF</>LLiidYYBTUBZV]=LjiS3002DXX01f<<NlmcSV<<F/]2259Z
00;oo`03003ooooo00[oo`002ooo01T00?oooolYACW7BTUS37`?YCBeeZDDNnmcSX@`[EFee/HH_QNm
eiBbLhhiab44244@HP02488021S34:8@XQRS8@@YABUU8@@26<<00b44:FDHh`028B@03U:ZF^][KCWW
:DD8H@Q102088@QQ8@@aYT88@RP2@PP01SWW<JI:BE[[Ljikk`:4<0:<D@09S76<DHaaS76DTXbAU9:<
TIBB00:<L@03S56<LHaa00:D/P0<W?>U5:eE[GFe][ggcUW>VMkKg__WG>mM0^nM01[6>8aAF/]BZU[[
D/YBRT98@PPaYS5VBTV<DLHHeYZe]YBBH``iab44:DDaQT88BTUBJT8X0SWW00I:JE[;F^]:JCW7:FD2
ool00`00ooooo`0:ool01@00oooooiBBS7400XaA03^Ldg>^NnmcSYcc[IF<<H@@S56<LHaAQ31cSZeE
LhjeeYBBS76L/h@`W==kkiccU9:Llh@`YAA[KIbcW?>448aANnn4<7>>[GERk:eEH`bU59BBQ12DTXaa
U;:<LIBBJhecSW__[GFeeZeENnn4<8aAS76DTYAb00><L@03U9:<DHaa00:<L@:DTP06S56DTXaaU9:<
DIAb18aa00J<DIBBS96DTXaaU983S74088aAS76DLU[[aSRUE8aAQ32<<HaaS564<8aAS76e]XaaJbec
[W__Q12DT[FfW?>DTYbcU;:<DG__S56DdYBbS942Q3000iAbS96D/P02ool00`00ooooo`0:ool05`00
ooooof</Jde[KH@@[IG66:eeJfeS39cC[IFmekFf_MNe]ZDDF/]S;2UU>NL01cW700laQU[;@RPYAC5V
<JHaQU[;@RPaYTYYHbb]EF]=S5400c6600`aYRUU:FDaYTY9DXYcSW_?Q31:RBU5H``4S74019BBS76D
LXaA0YBb00>L/iBbU9800YBB00><DIAbU9800YBb00BDTYCBW?>M4`:U=0:]M@0?_MO6><iicWWFV/jI
g]_Ff]kKe]Y225[[Lhic[V]=009Jb`0BDZY2:24T<FJU==kk]KJmmmJjaSQBZSW7@RQJjdY9F/][SG>^
0e:Z00I[CG__HbaBRTY9@PP2ool00`00ooooo`0:ool000_oo`0S003ooooo:FDaYTXYDZYkkjDD_ONL
lg_?Jdf<<JeE_MNmmlHH_MNLdg>^@PPQ91224:8HXa2R6:<@PQ2R488Pi244:BDH``0248802aS38@@P
i2UU@NQS;6]=LjiBJS6646800PQ100l080Q1488Y9CWWF/]Jjf;/DXXiac6VBTUS;8@@Q3000XaA00B<
LHaAS76<L@>DTP05S76DLXaAS76<D@02S74019BBU;:LlidC0ZeE02feU[GFaSS>NMkKg__W?>MLkgg_
WONN]KJ4<5::H^aJjeZ[BTU2:36V:BDH`cWWQ1366=JJcWVn5jDDHb`iabU5<HHiad8XBVUBRT8X@NQ2
:5:ZF/]BRSWW<FH00_oo00<00?ooool02_oo01400?oooonDTX@`NlnD/YCBNnn447>>YCB]MG__S364
<9BB00:<D@0;NlneUW_?[GF<DIBBS76D/YBBS56DTP02U;8097__W?>DLYcc[EEc[YccLhk>>Haa[EES
3:eEDXZmehaaU9:<LIbcU;:L/iCBU9:<LG>>Q32DLZeeW==kch@@S56DTX@`U9:<L@:DTP:<D@:<L@03
U7:<LHaa00:DTP06S56DTXaaU9:<LIAb0YBB00j<LIBbU9:<LHaAU7:<DIBBS76DTXaADX[NniBb0XaA
016DTYBbS56DLXaaYCC6>8@@HbbDTYCBH`ac[ZDD]IJLdhaA00:D/P03S35kkicC00:Ld`05S56448aA
U7:D/P02ool00`00ooooo`0:ool03@00oooood88DZY:JF]]_OO66;EfDXYJbiCB00Be]P08_KNU=6</
Jfdiac6V@PQBRP8ia`03>JLaYSWW009:B@0@@PPiac66<JI2:35V<JHiag>^[CF<LF]=U98YIC6V<FH2
<JH2<HH02SW7F/][KH?`Q124<48X<FI[KIBB0Xaa00NDTYAbU9:DTXaaW;>Ld`02U982S7403YAbS76D
TYBBU7:D/YcCW?>]=JDd[EFeU[Ff_QL2cUT01=JJe[[F^]KJ0]kk013>NDY9Jfekcg>>F^]Rk5:Z@PPa
QRU5:BF]ENLLaQRU50;Nn`0A]KIBZT88DXYS35::H`akcf/]DZYRk6<<Lji[KE[[@PPia`02ool00`00
ooooo`0:ool000_oo`0G003ooooo8@@Q92U5@PQ[CIcc]MJL/f]]Hbb44:eE]MK66;gg_MN<LF]]>NLa
IP024:8061224:8@PQ2R488H`aSS:BDQ112R264@PQ2R6:<Hhc66DXYcSV]]Lhi2B366264@HP88@@0=
0208@A2R<HI:BF<<F`]S;5::>LLaYU::Lhh00X@`18aA00F<LHbAU9:<TIAb00:<D@03Q52<DHaA00:D
TP0NW=>LljDdYEBeU[Ff_OO6>=JJe][W7>Llkeg_OONNga^U=6^=DXYBbU:ZBTU22366:BD@XQ22<JIk
kkFf0/iI00WF^/iIW==JbcVW:FDaYSWWBTT00TYY00M2248XBVUJbe::@PPYA@02ool00`00ooooo`0:
ool0@P00oooooiccS76<DIdCW?=c[W_?JdfmejeEQ124<8aAU9:DLX@`Jbf]MF]]W?>D/X@`Nnn4D9BB
W=><DIcCU9:449cCS96LdhaaW=><LKFfWA>4<7__JffUE4Y9]KJDTXaaW;><DIBbU9:D/XaaQ124<7>^
Q12LlkggS75kkhaAS76DTP><L@04U9:<LIBBS549U98018aAU9:<DIBB18aa00><DHaaS74018aa00IS
;6<<]KIkkh@@Q302S5405H`aS76L/jDd_ON445:ZS76]MG>^H`akkiccYABDTXA@U;:<TG__S56Ld`02
U;8018@@S564<9cC0_oo00<00?ooool02_oo01P00?oooolYIC5V:DEcS[GFaQRLld7XF^^LljfE_MNe
][gG]KJU536VH`aJjc66:FD2<JH0147X<JIJZbUU0U:Z0T8801hiad8X@RPiibU5NnnLliBbNlmJjg>^
8B@aQT98<JHiac5V:FDaQT8XHba[KG__Llj442U5BVUkkiBBS942S74039BbS76D/YBBW=>D/YBBS96<
LHbAU7:DTP:D/P06W=>LliccYCB]EJee0[Ff00C66<HhcWW>V@;F^P05g]_NnmlKF/]BRP02Hb`2F^/0
5DY9@PPaYS66<LIJjg>^cYVn5icceY[W7<HhQ31:RCWWF/]Jje::Jde[S@02H``01V/]JdecSV<<@PPa
aP;oo`03003ooooo00[oo`002ooo00@00?oooolHh`8@PP0D:FES39cC]KJ<DF<<F/^4<:eE_MNmmlHH
]KJD/V]]BVTaQR44488@XP8@PP036:<H`b3T008Q90038@@@XQ22008@PP096<<YAE::JfecSV<<F^]2
22UU00<@PP88@@04224@XRTU@PP2F//02F=<JdeBRSWW@PQS37__S564<002S7400iBBS76DTP02U985
S540:9AbU9:L/icCYABU=:ee]IJmelHHcWWF^]kkicc_GNmmmikg_/iiU99JjdYYDXY:BD88>LLaQRU5
:BDYIE9ZQ12eM[FfaSSFV^Ll_QN4<4YY0SW700]2248XDVY:JE9ZBTUBRU:ZF/]2:36600;oo`03003o
oooo00[oo`0B003oooooU;:U59Bb_ONLdg>^Nlm[KLHhYCAkkh`aS56DLXaA0X@`01K6>9BBS36U=9cC
U;:LdhaAU99kkiccQ32448aAS36<DH`aLljeUXaA[CEBZP:44004W?=JjlHHQ303S5402iBBW;>LliBb
S76DTXaAQ12<DJeE]IH00X@@00V<LHaAU9:<DIBBS76DTXaaS3400haa01VDLXaaU7:<LIBBS76DLYBB
U7:<LIAbS76DTXaaU9:<LIAbS56DTXaaU99S3;gG]IJ<D@02S7400iBBW=>Ll`03[GD05lHHW==kcg_?
[EEkkg>^LhjDdZdeYABD/XaaW=><DH@@S76DLYBbS76<DIAbW=<00_oo00<00?ooool02_oo00L00?oo
oolY9BU5<FIkk`02_ML01iBB<HIJbicc_MNe][gG00:e]P0LW=>3l5[[JddYIDXY<JHiYcWW@NQBRT88
BTUBRT88>JLaQSWW>LLYAHaANno6659Z>NMJbf<<<FH2@PP00c66>NLaQP02>LL06TY9DXY[;H@@Q31k
kh@@:FEcSXaaS56<LIAbU;:L/iBbU7:D/YBBS56DTXaaU7:DdYbcU;82W=<01:DDW?>]EJee0[FF00C6
6<HhcWW>N@;F^P;Nf`;Nn`0L<JI:JE[;DXYJbdYYDVYBZV;/Jff449Bb[GFDdZDdU;;>FNLlg]^Ldf]]
DZYBRV]=H`aBRW=^Jdd2H``01G>>Nlm[CE:Z@PP00_oo00<00?ooool02_oo000;ool06P00oooooaS3
26400244F^^LljeeQ11BZUZ[Q12]MKGFaQRmmkFfU99[KDYY<HHHha1R264248801aSS6<<Q1244:BDH
ha2R00<@PP0;8>@iae[;H`aBRSX7>NLaYS668@@H``02264224403@QQ8>@aQU9ZBVUS36]]Hba:JD8X
DXYc[X@@00:<D@:<L@03U7:<LIAb00:<L@03Q52<DHaA00:DTP:D/P0:W?>M4jeE[GFe][gGaSS>NMkK
g_/2ie`01Nmmkigg_[GFNnl00SWW01A2248X@PQ2:488@RQ:BE[;Jff<DIccYAB]MLiIiccFfZDdJfe2
:47X0T8800U2:4YYBVUBRTYYFZ]BZTYY<JH00_oo00<00?ooool02_oo00l00?oooon<DIccU;:eUXaA
Lhikkg>^cYVU=7__Q3000Xaa00V<DHA@LhjDdX@@JhfU58@@S7400iBB02MkcicCS55kcjDDS56Ldhaa
W?>4<9Bb@RQ[KH@@[EF4<8aAWA>DTYCBU9:<DIBbQ32D/XaAS76DTW__Q51cSXaA]IJD/X@@S56D/Xaa
S5400Xaa00>DTYBbS7400YBB00><LIBBU7800haa00>DLXaAU9800haa00>DTXaAS5401haa019:JMKJ
W?><DIcCU;:U59dCW?>DTXaaQ11kkh@`Q12<LJeENnl2Ljh00haAW?>U5002S7401hA@W=><DH@`U;:D
TXaa009kk`04U9;ooooo000<ool03P00ooooob4T:DDaQX@@]MJmehA@>JMJbjDd]MH2]KH08KgG[EFU
57__DXY:JBU5>LM22376>LM2:488<LI225;::DDiic6V:FDaQU;:@RRDTS66@PPYAD98:DEkkf]]:DDi
i`02<JH01CW7:DDiidYYDZX00W_?00^448@`DXYBRX@@U9:DLXbAU;:<TIBb00:DTP:<L@09S96DLXbA
W;>LdiccU=:Ldicc00:U=0:]M@04]KJn5lHhaSP2e[X05]KJe[[NnmKJg_]2236VBTUJbf</JfeccX@@
S76DTYCBYAB]EIcCO0n44;Ff0]kk0136>8@@JdeJje[;JfeBJU::LjiS;6]]H`acSV</F/]:B@;oo`03
003ooooo00[oo`002ooo00l00?oooolY9@QQ000Q96<<W=>]=G>^DXYBZX`a[GD00[gg00o5n;FfYAAc
[U:::BDPi11R488@HQ226:<Pi1SS8@@00R3T00l@PQ1R488HXbU5@PQBZU::<HHiYc66>LLiicVW:DD0
0a2200X@HQ224:8Y9CWW@PQBZV]]LhiS309:B@03H`akkh@`00:<L@03U9:<LIBB00:<L@><D@04S76D
TYbcU;82W?<02ZDd[EFeU[GFaQS>FMJjg]_W?>ML0^mm01kg_^mm_MMkcd8X>NM:BE::F/]S36]=Jfek
cg__S76DTYcCU9:LlkgGiacW?<HHS55S34YYBTU2:4XY@RP2DXX2DZX00e[;DXY22002ool00`00oooo
o`0:ool04@00oooooh@`YCB<LKggNnmkcg>^Lhk>FJCdNln448aaU7800haA00B44:eeNln]E@:<D@08
U7:<DIBBQ32LdiBBQ12DdP:DTP0F[GEkckgGQ32L/iBb_OO668@`[GFU54YY_ONDTYbcS76L/iCBU;:<
LIBBQ102S5404G>^YABU=7__Q12<DIAbS76DTXaAU;:DTYAbS76DTXaaU7800Xaa00N<DIAbU9:DLXaa
U7:<L@02U982S7404YBBS76<LHaaU9:<DH@@F/_>NKFfYCBLlibcU9:DLX@@Q32440:4<009NnnD/YcC
[IFL/g?>Nlmkkibc00:Ld`0;U9:<LIccW=>4<9AbU9:D/XaAS76DTP02ool00`00ooooo`0:ool03P00
ooooobU5:FDaQYBb]IJ]EH`a<HI[;JDd_KL4]KH029dCU98aQT7X:FDaQSWW>LL2<HH00d8XBTTia`02
@RP02d88<JHaIW_?<HIBZX?`BVTaQSW7[ED00SW701C6>3W7<JHiYe::>NLiac66<JI:BF<<Po2448`a
LjhaQV]=S76<DIbc0YBB00FLdiBbU9:L/iBB00:<L@06U;:DTYcCW=>LlicC0ZDD0Zee00Rm]kggaSS6
><iicYWNfmJj0mkK00RUE8@`DZY[CG?>Q12DTYbc0Ycc00>LdiBbS7400YcC00ZD/X@`W=?Ff^LlcYVL
dg>^LhiS309[C@09DZYS37>^Lhi[CF</JfeS35[;00;oo`03003ooooo00[oo`002ooo01h00?oooolY
IARS000YAF<<W?>M4g>>BVUBZX@`[GFee[gg_MNe]ZDDLji:BASS264@HQ2R6:<@PQ2R6<<36><04AS3
4888HAS36><YAC66>LLiic66>PLiYcWWBVUBbT8X8@@00Q2R010HXa22488H`c66:FE:BF<<Lhi[KE:Z
@TQBZW>^Q32<D@:<L@03U9:<LHaa00:<D@05Q32<DHaAU9:D/P02W=<05ZDDYCB]MKFF_OO66<iie[[N
nmlKkeg_OONNkigNnjeeNlmBbU:ZH`a[KG>^0X@@00n<DH@`S56<LIBBS96<DHbA]IKFf^mmcYVU57>^
F//00TYY00=2:4Y9BTT00e:Z00=:JE9Z@RP00_oo00<00?ooool02_oo03800?oooomkkjDdU9:meg_?
Nnn447?>cWVDdW__O0nDTXaaS564D8aaLjk668aAW?>D/YBBS76U=9BBS564D9ccNnnD/X@@U;:<TG>>
S76Lde:Z[EFD/ZeEBVW668aALhj<DKgG0XaA00F449cCU;:Ldicc00><D@05Nln<<LHHU9:<D@04S740
0haAS76DLP02S5401HaaU7:DTXaaU9800Xaa00>DTXaaU98018aa00><DHaaS9400Xaa00BDLXaaS75[
K@:4<005YCB<LIBBS564<002Q1001G__Q32<LIBbQ3000XaA00>U=9dCQ1000W_?00j<LIccS56DTXA@
S56D/YAbQ32449BBS764<8aA0_oo00<00?ooool02_oo00h00?oooolYIC5V<JJLdkGF[EF4435VH`bU
5;gG0kFf00F]MJDD[EDiic66008YA@0_BVUJjc5V<JI:BD8X<JI2248X<HHaISWWF^/j1d88>LMBZX@@
Nlm[KDY9Nnn4<;Ff:DE2247XBTU2:3WW>JLiaf<<Ljj448@`Q10aaV]=Q32D/XaaU9:<TIBbS76DTP04
S7401IBBU;:D/YcCU=800ZDD0ZeE00NeUZfEaQS66<iIcWWFVP02e[X03=KJg]_FfUZ[S95c[YBBW;>L
djDDU=:L/`:DTP0IS56<LHbAU9:<TIBBYCCNfnLle[Z]MG>^Lhi[KE;:LhiS;5::Jdec[V</F^]K2f]=
Hb`00_oo00<00?ooool02_oo000;ool03`00ooooocVW6<<88C5VJdfLljCdJde:JE:ZS56]M@02_OL0
3LHH]KJ]MG>^BTT@XQ1R264HXaS36:<@PQS3008Hh`086<<Hha2R488HXb44<HHaYP8ia`09@PQBRU::
FZ]Jbf<<@RPY9A2R008H``0>6:<@PQ2R8@@Y9CWWH^a[KG^_F/]BJTYYJfekk`:<D@03U7:<LIBB00:<
L@><D@06U7:DTYbcW=>U5:Dd0Zee01:mekggcUW>VMkKg__W?>MLkgg_WONnaSRU=7>^Nnmc[X@@Q302
S7400iBBS76DLP03S5402iBBU;:U5;ggg___ONLL]IJ<<F</F//00U::0TY900I:JE[;DZYBRTYYDXX2
ool00`00ooooo`0:ool0:@00ooooof]]YCB<LKggJfekkg_?Ljk>NIcCNnn4<8aaU9:<LHaAU;9BR[gg
S56LlicCNln448aaW?>4<8aAU;:DTXaaS56LlibcLlj]MIcc[GD00X@@00YccX@@]KJLdd88Jdf448aa
S564<0:<D@03U9:U58aA00><D@06Lhk668aaQ124<8aA0YBB00^<DIBBU9:DTXaaU9:<LIBbS56DTXaa
00:DTP03U7:DTYAb00:DTP04S76DLXaaU782S7401iBBU7:<LF<<g]]c[Ycc00:44006Q31kkhaAS76D
TXaa0YBB0Xaa00RU59dC[EF<DH@@Nnn<<JDD0YBB00ZLdhaAS56LliAbQ12D/YcCU9:<L@;oo`03003o
oooo00[oo`0?003ooooo:DDQ947XW?>mmjeeNllQ96]=YEBmekFf00:me`05_KNLdjeE:FDiY`02<HH0
0d8X>NMBRP02>LL2BTT0:366>LMJbbUU@NPYAF]]Nnm::E[[BTVDTV/]S56Lle[[<JHaIT8X<FI::C66
@PPiacVWF/]cSX@@S364<5[;F^]kchaAU9:<DIBBU;:LdiBb0XaA00BD/XaaW;>D/P:Ll`:U50:]E@08
]IJ]UKgg_OO>FLiieY[>V@;F^P09g__NfmkK<HJDTXaaYABLlicC00:D/P0?S76D/YBBU7:448aAS76D
//iig]_FV^Lle]Zmmg_?009c[P05JdeJjg>^DXYJj`02Lhh016</JfeS;6/]0_oo00<00?ooool02_oo
000;ool06`00oooooc6V6<<0836VJhfU=9ccJde2:5:ZS76eU[ggaQRmmkFf[EEkcd984:88@A1R4:8H
``024:836<<00aRS6<<@XP0248803b44:DDYABU5<LIJbf<<F^]:JE[;DXXiib4T4:8Hh`02:DD03R44
488Pi1SS<JIBZV]=Lji[;DZ9BTUK2g_?Q302S542S74018aAQ32<<H@`0Xaa0YBb01>LlidC[EF]MKFf
]MK66<iIe[[Ff^LLicc_GNmmmik_OKFFS75[K@02S54018aaU9:<LIAb0Xaa01J<DH`aQ124<8aAYABe
e]JJga__ONLl_ON<TF]]F^]JZe::DVY:BDYYDXYBZP9BRP04BVWooooo000<ool0A@00ooooog>>[EFL
lkFfLhikkg_?NnoF^YBBNnn449BBS76<DH@`W==BZ/HhS96DTYCBS56449BBQ12U57_?W=><LIcCLjjL
/iCBW==SC6]]O0nU59CBQ32<LF/]Ljj449ccaSQkkjeeYABLdjeEU9:U58`aS764<8aALjjU59cCS564
<8aaU9:<L@03S5400h@`U;:<L@04S7400haAS76<D@09S7402YBBS76DTXaAQ112B?ooF`^Ldg__0XaA
0Xaa01^DTXaAS76<LIBbS76LdiBBNnn448aAO0n4<7__[EF<TH`aU;:DTX@`YABDTXaAQ32<LHaAS740
0_oo00<00?ooool02_oo00<00?ooool00R4400Q2::Dd_ONe]V]]8@A[KKFF0[gG00Ze][gG[GFLliCB
<HHYICWW<JHii`8aQP0JBVTaIU:Z>JM2B3VWBVTaIRU5BTUS;244<HIBJYBbW?=Jbf<<8@B<<B4T8@A:
JD7XHbbLd`92200::FEBRU[[Q124D8aAHb`iaf</U982S742U9801HaaU9:4<8aaS9400YBB00JLdicc
W?>LdjDdWA<2[GD04KFf_MO6><HhcWW>VMJJe[[NfmKJg_^meb44U9:L/iCBW;<00YBB0Xaa01^DTYBb
S564<7`?Q32]UNLLg__>VMkkg]_6F8aaLji[KF]=HbacSV]]F`]S36^=LhiS36;/H``00_oo00<00?oo
ool02_oo000;ool09P00ooooocVW4:88@CW7NlnUE:CdH`a::E:ZU9:eU/Gh_OO5n;FF[EEc[TXY4:8@
PQ1R488Hhb3T6<<Pi1S38@@@XR3T4:8HX`QQ8@@2:DD01B4T>NMJjf]]Jdd00U::00U:BD8X>NLaIS66
<FHaQR4T6:<00QS301DY9DY9H`ak[f]]DZY2:5:ZLhj448@`S56<LIBBS56<<H@`S56<LIBBU;800Ycc
00bU=:eE]IJe]/GhaSSFV]Jjg__W7>mMkgd2mih01=kkU99cSV</0YBB00>L/iBBU98018aa00R4<8@@
Nnn<LJeeeY[W?>mM0^mm00C>FJDDLliS;09Jb`06DZYJZdYYDXYBZU[;0U::0_oo00<00?ooool02_oo
01400?oooomcS[EfYABeUV^=Nlmc[X@@g]^DLW_?Q12<DHaa00:4<00cU99S3;ggU9:<LIBbQ32e]X@@
YABLdg__U;:<LIBBNnnU59BBU;:449ccaORDTW>^JdfeUYccaORLlkFfcWVU=:DDJfeBZW__S56Llhaa
U9:448`aNnn<DKggU7:448aAS76DLXaa00:DTP04U7:D/YBBS742U9802IAbS76DTXaaU9:<LIBBS76D
LP02U98018aaU7:DTXaa0YBB0V<<00C_OE[[U=:<<@:DTP06S76DTYBBS76<DIAb0iBb00FL/f]=S56D
/XaA00:44003W?>U58aa00:D/P04Q12<LIcCU982S542U;82ool00`00ooooo`0:ool00`00ooooo`02
8@@02E[;[EG5n:DdNllPi7>>[GFmm`02]IH02:ee]GJLdh`a>NLiac6V>JL2>LL01G__<HHaYU[[<JH0
0SWW00A223W7>NM22092:00<<HI:BJDdQ32446]]>LMJjkgGYCAkce[[0U::00M223W7>LLaYU:ZLjj<
<@02Q1000bTUJff4<002S5402YAbU;:DTXaaS36<LIBBU;:DTYcC0Ycc0ZDd0ZeE00B]MKgGaQS660;>
N@04e[[FV^LLg]/2g_/01d8X48:D/YCB[EFDTYBb00>DTP03U7:<LHaa00>4<00A[EGW7=kkcWWNfnLL
eYZUE7_?LjiS;6]=Lhikkf]=H`a[;@02Jfd01F]=Hbcooooo00003?oo000;ool05`00oooooc664:88
@D88Nnn]MIcCH``j1e:ZS96e][ggaQRmmkFfWA=cST886><00Q2200L8@ARS8@@Q92U58>@Q10026<<0
11RS264@PQS30R4400XYIDYYJfekcg>>D/YS35;:DZXia`8aQP0C<JHaQRU54:8HXa2R8@@iae[;Jfec
[TZ9@RQ2B7>>Nnn4<8A@S7400XaA01^4<8aAS56DLXbAW;>LdjDDYCB]EJee_MNmmliIcWWNfmkkiccW
G>mmkigg_[hGLji:JF<<S7400YBb00NDTXaaS76<DHaaQ524<002Nnl00h@`[GGF^P02ked2kgd01mkk
[IF4<6</F/]BZU[[009Jb`05BXUBZU:ZDZY:J@02ool00`00ooooo`0:ool01@00ooooof]][GD00ZDD
01=[KG__Ljil3mKJS55kkh@`U9:D/YBBS76DTV]]]KJ<DIcCU9:<D@02Q3002F^=cWUS;:eeS96DTXA@
U7:D/P02Q3007jeEWA>eUW`?Q12DTYcCg_]BZV<<>LLiih@`S7644:DDU9:LdiccU=:<LH@@Q31cS/iI
S56448aaU;:<LHaA00><L@06U;:DTYBBS76DTXbA0Xaa00B<DHaaU9:<T@:<L@06U7:<LHaaS56DLXA@
0Xaa00MBZ[gGmiiJjiAbO0nDTP03S74069BBS76DTXaaU9:<LJDDU;9cSXA@W?><DH@`NnnDLYcCU;:<
LIBbS56448aaW=>DTP:<D@04S77ooooo000<ool08@00oooooaS38BABb[FF_ONU=6</8>A[SJee]MJm
ekFf_MNeUYccNlliYdY9>LLaaS6V:FE1j9BB<JI[KCVW<HIJb`03<HH00e:Z:FE:B@02S54027_?U;:D
dW_?[GGFfS6V6<<2@RP03D88>NLiicVW>NM1j4YYHbb<DH@@LjhaIV<<00:<L@0<S56<LIBBS76DLYBB
U;:DTYcCU;:LdidC0ZDD0ZDd00Z]EKFF_MNn5lHhaUSFV/jIe[[FVP;Nn`09ia`001SSU9:LlicCW;>D
/YcC00><L@0>U9:<LHaAQ11kkicCiacNnmJje][NnmKJaSR4<09[C@04JbeS;8@@Lhh2Hb`017>^JfeS
;5[[0_oo00<00?ooool02_oo000;ool04000ooooocVW4:8@HT88S36]EIbcF/]225:ZU;:e]/Gh0[gg
00BeUZDDJde2208H``8@HP0A4:8Q135V@PPaYRU5488HXa22468@PQS38@@aQSWWDXYS3002Nnl05W_?
Ljikkg__H`a:BC5V:DDY9ASS6<<@PQRS6<<aITYYJdec[U::@PQ::F]=0X@@0haA00>4<8aAS5400YBB
00bL/iCBYABU5:eE[GFeU[gGaQS>FMJjg]/2ic`2kgd2mkh01jeEDZXaQU[[U9:D/YcC00:DTP:<L@:<
D@06Q32447_?Q12U==JJ0nmm00GgW^MLcSVD/V]]009BZP05F/]S35[[DZYBRP03F//2ool00`00oooo
o`0:ool04@00ooooog>>_MNU=:DDJfekcg?>S37NfhaANnn<<HaAU7800X@`00F<LG>^]KJ448aA00:D
TP0?[EE[CIBBS55c[[FFS55kchaAU;:DTX@`W=>D/U:Z009kk`0;Lhj448@@H`acS]JJcUWgWYBBYABD
TP02U;8048aAU9:DTXaaNnn<DF]]eYZ4<7__S56<LIBBS56DTXaa18aA00nDLYBBU9:<LIAbS76DTXaa
U9:4<9AbS76DLXaaU7800iBB00f<DCW7mikNfe[;U9:4<9BBU7:<DIBbU9:DLP02S54028aaU9:LdjeE
Jdf<<IBbU982Q30027__W;>LliBBS76D/W__S542U9800h@`U9:D/P02ool00`00ooooo`0:ool0>000
ooooob3T8@AS3:eeaORLle[;6>=kckFF_ONee[Ff_MNeUYccS74Q13W7BTTiYbUU>LLaYRTUYABLdbU5
<FHaYSVW:DDiYcWWDVYBRYBB>NM22:eEW=>449cCNnn]EMkk8>ABRTXYBTU2236V@RP2>LL02E[;S564
<8@@:DES38@@S76DTP03S742S5400haaW=>D/P02W?<01JDDWA>U=:Dd[GD00[FF00FmelGhaSS>NLjI
00;F^P;Nf`05iacFVPPQ4::U5002W=<049CBU;:DdYBbS76DTXaAS76448`aQ124<=kkiccFV]Jj0]kk
00kF^ZDdF^]Rk5[[Jdec[W_?HbaS36]]LjicSW>^0_oo00<00?ooool02_oo000;ool06@00oooooc6V
6<<8HDY9Q32]EHaaDXXiae[;U;:e][ggaQRmmkFfYAAc[TY98@@H`a220088H@054:8YAD98>NLYI@02
48804a2R264@PQS3:FE2:5:ZDXYJjf]]S55kkg_?Lli[KDY9<HHHhbTU008H``0=4:8H`a2R6<<Q13WW
F/][KDYY@RQ226]=Nnl00X@`00B<DH@`S564<0:<L@06U9:D/YcCW?>U=:ED0[FF00JmmlHHcWWFV]kk
ga/2ked02>nMmikW?8aa>NLYAE[[S743U;8018bAU9:<DHaA0X@`00El3g__NlnLllHh00;_G@0;kgg_
WONNe[Z]EG>^DZY:JEZ[F^]S3003DZX01E[;DZ[ooooo00003?oo01400?oooomS3;Ff[GFLlg>^Llik
ciBBg]^447__Q32<LHbA00:<D@0]U9:44<HhW?>D/X@@W=>DTZeENnn<LASS_OND/YBBW=>L/idCU9:D
/ZDdLljeU/iiF^^<LG__Q324424T@RR447_?S76<DH@`W=><DIcCW?>L/f^=Q11S;=JJ00:<D@04Q32D
TXA@U982S742U982S7401HaAU7:<DHaaU98018aa00>DTXaaU7801Haa00bDLV<<@PSF^/iiDZZD/X@`
U9:<THaAU982S7404YBBS76DTXaaW=>]MF]]NlnDTXaaS564<7_?S56]MIccW=>D/P:<D@05U;:DdXaa
Q12<D@02ool00`00ooooo`0:ool03@00oooooaSS:DE[KKFF_MNLldZ98>AkkkFF00:me`09]KJmejee
W?>U57_?<JHaITYY008aQP07>NLaQSW7W?<Q136V<HH00TY9014YICW7Jhekch@`H``aYYccJff]ED98
8@C6>35V6>=S3488008aYP0l>NM:BDXY<HHiif</Nlmkkc66HbakkhbAS56D/XaAS76<DHaaU7:<LIBb
U9:LljDDYCBM4jee[EFeU[Ff_MNmmliIcWWFV/jIg]_Ff]kkga]Jba228@B]EIBbW?>L/iBBW=><LIcC
S764<8aaS564<8@@Nno6>=KJ0/ii00WNnmKJg_^n5g_?F/]S36=<Lhh00W_?00EK2f;/Jfe[CF]]00;o
o`03003ooooo00[oo`002ooo00l00?ooooliiaSS6<=:JIBB[EF<LDYY>LMBZYcC]KH00lHH00Je]ZDD
Q11BZRUU6:<248807`QQ468H`dXY@PPia`QQ6:<@PQS36:<Q12UUDVY:JDXYDXY[KHaaLjiJbf/]JdeJ
jc668>@Q91S34:8H`aRS008H``0>6><aQU::HbaBRT88@RQS;7__Q12<<H@`S564<0:<D@:DTP0IW=>L
ljDDYCBeM[Ff_MNmmlHhcWWF^]kkiccWG>mmmikogliINllQ1366F^^D/YBBW;<00iBB00bDLXaAS364
48@`Nnmkchaa]IKF^^Llked2mih02NLl_ON<<E[;BVUBRV;/H`aRk003DZX015[[ooooo`003?oo04P0
0?oooomSC;gG[EFD/W>>Po1cSYcCeYZ447__Q32<DIBBQ32<DG__Nlm[KKEfS76<<IBBU7:<LKFF[GE2
2=KJQ12Llg__S76DTYcCNlmkkeZ[W=?6>6]=]GI[KKgGg_]BRZeEicaS;9cCU9:D/YBBQ12<DIcc[EFD
TXaAJffmmhaaQ12<DHaaS56<LIBBS742U9800iBbU9:D/P02U9806haaU9:<LIAbS76D/XaAU9:<DIBB
S76DTXaaU9:<LE[[W??6><jIBRVLlhaAS76DTXaAU9:<D@02U9802iAbS76<LIBB[EEccW_?S76DTX@`
S7400W__00BLdjeES76DTP:<D@03Q32LdiBb00:DTP;oo`03003ooooo00[oo`0?003ooooo8@@YIG__
]MJmejDDBTTQ17__YEBmmkGF00:me`06]IJDdV]][IDYAC660SW700Q2236VBRTaQZDD8@ARk35V0T88
019[;D88@NQS37>^DZYJZjDDW=>]EAS3:FG>FB4T8@ABZSWW<JH2>LL03D88>NM2248XJfekcf]=>LMJ
jh@`U7:448aA00:DTP03S76DTYBB00>Ld`03W?>U=:DD00:]E@05_MNeU[Ff_OO66002cWT05=JJe[[F
^]kkga_W711R6<<Q1;gGU;:Tm9CBW;>DTYcCU9:DLXaaU782S7405W__Q12<LKgGaUSFV]kKg__Ff]JJ
YCAJZe[[HbacSW>^Nlm[CF<<Jde[KG=^0_oo00<00?ooool02_oo000;ool06@00oooooc768>@Hhe[;
U9:]MHaABVTaaU[;U;:e][ggaQRmmkFfU=:444YY<FH8HA2R008@PP05264@PS6V<JHia`024:801AS3
8B@YABU5>LL00U:Z00I2:5:ZJffD/V^=BVT2@RP01cWW6<<H`b444:8@PQ2R00<H``054:8YAD88F^]2
B002>NL01V</Llj448@@S564<0:<D@:<L@:D/P0GW?>U5:eE[GFe][gGaQS6><jIe[[O6nLlkeg_OONn
kgf]EE:Z468aQU[[S96DTP02U;8018bAU9:<LHaA0h@`01J447_?Q12Dd[gGcWWW7>mMmkk_OMJjW?=[
KDY9DXYBbV<<F^]JbdYYDXYBZP;oo`03003ooooo00[oo`0A003oooooJdfeeZeeS75c[W_?LjjLdmkK
O0n4<8@@U9:<L@02S540:IAbS55JZiccU;:<TIAbS96<<Haa]KHYALHhJffLlicCQ124<:eeW=>]MG_?
YCB]UE[;W==JblIHe[X@P[FF[GEc[YBBW;><TIBbS56DTXaaW;<00X@@00=[KLHhQ3000X@@00BLdhA@
U9:<D@><L@><D@><L@06S96<DH@`U7:<LIBB1Haa00fDLXaALji:JLjIYEC>ND8XU;9l3iBBS76DLP03
S7404iBBS56DLXaaU9:UE9BbQ32<DHA@Q32<LH`aLlj44:fEW=><DIBB00:4<004S76D/XaAS542ool0
0`00ooooo`0:ool08000ooooob44>LN44;gG]KJLle;::BEkkjee_MNe][GF]KJ]EIcCF^]::ASS>LLa
QU::<LHiYbUU>LMkkcWWBTT2<HH057>>F^/iif]]Nln44488F^^LdidCYCABRSW7Hda:BB4T@NQ2:3W7
>NL2@PP02cW7>PM225;:Nnmc[RTUBVV4<8aAQ1000XaA00B<LIBbS76DTP>D/P03W?>UE:eE00:]E@05
[GFe][gg_OO66002cWT04mJjeY[Nfmkkiab<TASS:DDaIYBBU;:LlicCU;:DTYBbS76<TIBB00><L@07
S56448@@U;:]MLHhg]/00]KJ00gF^/HhHbaBZV<<HbacSW_?JfeRk5[[LhiS;002ool00`00ooooo`0:
ool000_oo`0I003ooooo>NLY9C5VHdbLljeES55:JD7XF/^LdkFfaQRn5lHH]IJU58@@DZXQ90QQ4880
0QRS00XH`a22<HHYICWW6<<Y9ASS>JLaQP8ia`=:B@0:DZYcSXaaLfiBZTXY@PPaIQ226:<26<<00a22
6<<HX`036<<02b44@NQBZTY9<JHiie[[Njmkkh@@Q3000XaA00ZDLXaaU9:DTYcCW?>U=:eE]KJeeP;6
600CcUW>VMkKga_W?>mMmikg_]JjQ30ia`Q1<HIJbhaAU9:L/iBBU;800YBB18aA0X@@01AkkhaAW=>e
]/iiicc_WONNiabe]W__DXY:BE:ZF^]S35[[FZ]BRUZ[0_oo00<00?ooool02_oo00`00?oooom[KLiI
[EFDTW>^Po1cSYcCcWT3Q100=8aaU7:<DHaA[GFU=:eeaSR<DHaaQ12<LIccU;;663W7cWU[CLHhLjjU
57>>U;:DTU[[NnnLdjdeJhfDLS66g]^Llf]=[GFLdh@`S76DTXaAS76<DIBBU7:D/YcCLhik[lHhU;:4
48@`0iBB00JDLXaaU7:<LIBBS743U98038aAS76DTYAbU9:DLXaAU9:<DIBBS76DTP:<L@0<DZZ44;Ff
U9:mmf]=U9:4<8aaU7:DTXaa0YBB00><LIAbS7400XaA016L/iccU9:<LIBBNnnDLXaaQ11[SJeEYABD
TXaaU7:4<8aa00:Ld`04S77ooooo000<ool0:@00ooooobU5H`bL/kFf]IJ<LEZ[<HJ4<:eE_ONe][fg
]KJeUYBbkge2235V:DDaISW7DVY2:4XY<JIc[RUUDZXYIHaA:DEcSV]=@RQ[CD88Hb`00W>^01f44:DD
:DFM4e[;8B@YACW7DVXaYT7X>LM2:488>NLiacWWQ11c[RU5F/][CHaAS76<DHaaW;>DTYBb00:DTP03
U;:Llicc00:U=004[EF]MKFf]KH2_OL01<HHcUW>NLjI0]kK00gW7=kK488YAC66BVUcKYBbW=>D/Ybc
U;:Ld`04U982S74028aAS364<8aaS56U5=kKg_/2g]/01LiIS75:BE[[Hb`00V]=00F446^=HbaSC7>^
00;oo`03003ooooo00[oo`002ooo02400?oooolj1cWW@TQkciccYCAkkdY9>NMRk9Bb]KJmmlHH_ONe
UZeEQ11:JARS244@HQ2R6><H`a2R8@@YABUU6<<00R44018iac6V>LLiad8XBVUBRV<<Lhj446</H`aB
RTY98B@@PQ2R6<<34:8021S34:8H`a2R6><aYU::@RP2<JH01U[;Lhikkg`?S36<D@:<L@06U9:<LIBb
U=:U5:Dd0[FF01>mekhGaSS>NMJje][W7>Llkgg_WMlKWA=JZaSS6:<YAE::NlnDTP02U;82U982S742
S542Q303Nnl018aAU;:e]]Jj0^nM00c_GLIHU99Jbd8XBTUBZU[;F^]BbU:ZDXX2ool00`00ooooo`0:
ool01`00ooooog_?_ONU58@`009kk`04NlnD//HHNll2Q100:YBBS76<DH@`S54aQYBbWA><LIcCU9:4
<8@@S56U55[[[EEkkibcH`b]EE/;W?>4D:DdQ52mmhaaU;:DdV]]]KJ4<7>>_ONU=8aaQ32L/haAU;:4
D0:DTP0<W?>U=7>^Jdg669BbS56<LH`aS76DLXaA0Xaa0YBB00>D/YBBU98019BB00F<LIBBS76D/XbA
00>DTP0DS76DLU:ZLjjU=;FfS76U58aANnn<DIBBS96DTX@`U9:<DHaaS56DTP:<D@0DS76D/YBBW?>U
=7_?Q32<LH@`LjjD/ZeEW=>4<8aaS55kkhaAU9:<L@;oo`03003ooooo00[oo`0=003oooooH`b<DJDd
[EFM4h@@>LLaQW`?[ED01;Ff00Z]MIcCaSPiib44<HHiac66BVUBRP8aYP0?BXU:BC66<HIJbbUUNnla
QT88DZZ4<5[[W?>D/V]=009S3009S56LdbUU:FE:JD88>LLiicW70092200<<JI224YYNlm[CC66DXZ<
<G?>S564<9Bb0YBB00^D/YcCU9:LlidC[EFUE:eE[GFmekFF00:mm`06aQS>FLjIcYWFf]Jj0]kk01Ha
QQ2R<HI225::@RRLliCBYABDTYbcU;:DTXbAU9:<LHaAQ52447_?Q32<L@:4400@e[[NfmkKe[[>VJfE
H``iif]=F^]S36]=Nlm[KF<<Jfd2ool00`00ooooo`0:ool000_oo`0?003oooooBVUBZV]=S56LliBB
Lfi223WWH`bLdkFF00>mm`0R[GFmmiBbJddHha1R264H`aSS8@@H`b4T8@@YAAS3:BDQ13W7<HHiYc66
>NM:BF;/Jhf447>>JdeSC7^_DZXaQQ1R6:<26<<00a2R6<<H``046<<02SVW@RQ22366>LMJbg>>Llj4
48@`0Xaa01bDTXaaU9:D/ZCdYCB]MKFF_MNmmlHhcUWFV]Jjg__W?>mMkggW?;GFLhhaQQS38@@YIDYY
LhjDTP>D/P:DTP:<L@0FS56<<H@@NnmccW_?Nnn449cccUW_OONNkggNfjeEJfe2:47XBTUBRU:ZF^/2
DZX2ool00`00ooooo`0:ool0:`00oooooh@@W?>4<8@@Nnn447__YCC668@`Q12<<HaaU7:<DH`aaSQ2
2=JJ_MNDTYBbW=>448aAW=>U=7^_[EF44;FfQ12]EG_?W=>]MG__Q32<DG__00:<L@0LaQRLdh@`F/^e
]YBBQ32<<IBbS76D/XaAU9:D/XaaYAA[CG^_]MJ<DH@@U7:<DIBbQ32<LHaAU982S5400haaS56<D@02
S5405YBBS56DLXaaU7:<LIBBQ32DLXaAU79SC8@@U=;NfiCBU7:DT[gGJffDTX@`0YBB01b<LIBBU9:<
LIAbS76DTXaaU;:<LH`aS76m]f]]S56<LHaANnn449cc_KN449BBU;:<LH@`S56DTP;oo`03003ooooo
00[oo`0?003oooooU7:D/ZdeW?>446</@NPiag__[EFmekFF00:e]P06[EFD/^LlLlhY9CWW0T8801U:
JCWW@PQBRTXY<JIBRT8X:BEcSTXY@RQBJU:ZH`acSYcC[EFe]QSSg]]ccZee:DDiY`03>NL0348X>NM:
BCW7@NQ2:5::JdeBZRUUF/]kk`:4400>Po2DTYBbS76L/iBbU9:D/YccYCBeMZee]KJeeP:me`0GaSS>
FLiIcWWFV]Jjg]_FfV]=<FHiYcWWH`a:JD88YCBDTYcCW;>D/YccU9:D/P02S742S5405X@@Nnmkch@`
Nnm[CLiiiacF^]kKe[[>FIBB:DEBRV;/HbaRk6</LhiJje[;0_oo00<00?ooool02_oo000;ool02P00
oooooe:ZJdf449BBS75kke:Z0S6V00aS39BB]IJee[gg]MJ]MKFFU99S;2U54:8248801b44:FDiic6V
<FHQ9244008Q900:<LHiYc6V:FDj1e:ZJdekkh@@H``2DZX00f]=DVXYI@024:801AS34:8H`aS36><0
0aS302@Q1366>NLaQRUU>LMJjf]]Ljikkh@`S56DLXaaU9:<LIBbW?>U=:ee]KJmmlHhaUS>VMJJg__O
6nLliecW7;gGQ112224T8@@2:DD01DY9HdbD/YBBW;<00YBB0Xaa00b<DH`aO0mkkg>^Lhi[SG>^Jhf<
LKFFic`2kgd02nLLaSQkkdY9<HI2248XDVYBRU:ZBVT00_oo00<00?ooool02_oo00d00?oooonLlh@@
S55kkh@@S56449dC]KIl3`02Q102S7403HaAQ32U51SSW?><LIcCNnn<LIBbW?>]MIcc00:U500AQ12]
MH@@_MMSC;FfU;:LlhaA]IIc[U[[HdbDLU:ZBVUBRP02W=<078aAU9:DTXA@U9:<DHaaU;:DLYBbNln4
D;FfU99kkiBBS76D/XaaS56<LHbAS76<DIBbS56DTXaA0Xaa01b<DIBBU7:<LIBBS76DTXaaU79[KG>>
S76]EIccU99kkhaAaSQRk9BbS56DTXaaQ52DLXaAU7:<L@><D@0DS76Ldh@@S776>6]]Nnn<LHaAQ31c
[X@@aSRD/X@`S76DTXaaQ32L/`;oo`03003ooooo00[oo`0>003oooooU9:LdidCS55S35[;<HHiah@@
YCB]M@:eUP0I]KJU=9BB[EE:JE[;<HHiac66:FEkkidCW==:BD8XH`a2:6]=BRV<DEZ[>NM[CG__Q300
0XaA00UBRSW7<HIcSRU5>LLYIDY9@PP00SWW0T8800m:BCW7@RQ:RF<<<LHaYV<<Q11kkh`aQ12<<HbA
U;800YBB00>4<9BbU=800ZDd0ZeE0[gg02C6><HHaSS>NMJJcYWF^]KJLjh@PU[;>NM:BF<<DXXiijDd
U;:LdiCBW=>DTYAbU9:<LHA@S55ccW_?Jhe[CHaANnmBR[Ffg_/3e[X02lii]KHiibUUF^]S35[;H`a[
CF/]DZX00_oo00<00?ooool02_oo000;ool03`00oooooe[[Jhf<LH@`NlmS3488:DDiYf<<U;:]M@03
_ML06jee[EFDTX@@BVTaIQ224:8Hhc5V>LM2236V>LLYAC5V:DE224YYBTTiid88DXY[KG_?Q31S3002
F//00f</BTTYA@056<<00aSS6<<Hh`026<<00b3T<HHaQP02:DD01488F^]cSW>^0W__0XaA00ZDLXaa
U7:<LIcCYABeM[gGaSS>F@;FVP09g]_NnnLliecNnkFfNlmBRSVW00<aIP05<HI:JG=^U;:DTP02U;80
3iBBU7:<DH`aQ11kcg>>JdeS36]=Jfe[CG_?YACFfP02kgd02NmMe[ZU=6</>LLaYT7X@PQ:B@02BVT2
ool00`00ooooo`0:ool04@00ooooojeENln4<7_?Q12DTX@`[EF]MHaAQ12<DHaaU7800XaA01RU58@@
_ONLdkggU;:LliBbDZY225[;JdfeUV]]U9:<<H@`S5644;FfS55[KIBbNll2W=<02OoO]IJe][gG[GFU
58@@U9:<L@02U9803H`aS76DTXaaU;9kcicC[GF<DH@@U7:<DIBB00><D@0ZS76<DIBBU;:DLYBBS76D
TYBbS76DLXaaU9:<LIBBS76DLV</Lhj4<<HHS56LdiCBNln<LLiiDZZU58@`U7:<DIAbU9:<LHaAS76<
DIAbS56DTYcC0X@@013FVW__NlnDTXaaS56447__cSVe]YbcNnnDTXaaS36<D@;oo`03003ooooo00[o
o`0?003oooooW=>D/X@@F^]BRTY9<HI2:8?`[EFeUZee00>eUP05U;9[CJEDe[XaQP02<JH02488DXXY
AB44W;=BRW>>:FD2DZX088aAYCA:BE[;Q11:JIccS75[CF]]H`be]S6VDXXaYT8X@PQ2:488>NM2:3W7
@NQ224Y9DZY223WWJdekkh@@Nnl2Q302S545U98059cC[EF]EKgGaQS>>LHHcUW>VMJJcWWNfmKJDZX8
HCVWJfeBZTY9F//2BVT01[GFU;:DdYbcU;:DTP><D@0;Q11c[W>>JdeS36</Q11kke::W=?W7002e[X0
1mJJe[[>FJeEDXXiYdYY009Jb`03F^]S36<<00;oo`03003ooooo00[oo`002ooo01000?oooomJbf]]
NnmcSU:Z@PPYAB4T<JIS;9BB[GFe]P:me`0T]IJLdg__LliJbcW74688@B3T:DDiacWW@PQ2:2UU>LLi
YdYYDXY:BD8X@PQJbf]=Nlmkkf]=DZY:JCWW>LLHhb444:8Hha2R11S300`HXa2R6><Q92TU8@@YAD88
H`a[SG>^Llh2Q102S54028aaS56<LIBBW?>UE;gGaSP2eYX02mkKg__W7=lKcWVU=6]]>NLiac6V>NL0
0c6600EJZg>^W=><LIBB00:<L@0IQ32447__Lji[CF</F^]Jbe[[JdeJjg>>U;;FV^MLkegWG>LLaSRD
/U[;>LLYIC6V>LL00T8X0_oo00<00?ooool02_oo00D00?oooon]EF=<00:44018S76Ldh@`YAB]EH@`
Q124D9BBS76D/W__YCAccW__246U58aaU9:U58aAaURmef]]W==S3=kKJhfe]U[[DZZDdXaAU=:U58@`
U99c[ZeEHda:JHaaLjjU58@@S76<DHbAS76<THaAU;:<DIBBNnnDTZDDQ52<<HbAU9:<LIbcS76DLYBb
U9:<DIBBS76LdhbA0Xaa00>4<8aaU9800haa00j4<5:ZLjj4<<Hh_MM[;IccW=>4<9cCaQQBRYcC0Xaa
00F<DHaaU7:<DH`a00:<L@0DS96DTYBbYAAkkh@@cWV<LG>^U9:<DHaaQ11[KHaaYABeUYBbQ52<L@:<
D@;oo`03003ooooo00[oo`0Y003oooooS55kce::BTTaQT8X>LM:JH@@[GFeU[Ff[GFeU/jIW==S348X
U;8iibU5<HHiie[[8B@iYg__DXYS323TYCA[KD88F/]:BF</F`^DLP02Nnl05LIHH`b4<2U5>PMS336V
@PPaYT88>NM:BC6V>LLaYT8X>NM::CX7@PQS;002Q3002h@@Q31kkiBBU7:<LIBBS96DTYBbW=<00ZDd
00>]ULHhaSP00/ii01GFV/iie[Z]UAS34:8Q15:ZNlmBZU[;D/Y:BE[;cUVLlhaaQ52D/XA@Q1000W__
00=[KF]=Hb`00V</019[CG>^LjiJbjDdga_FV/jIeY[>VMJJcYVe]T8X<JI224YYDXX2F^/2ool00`00
ooooo`0:ool000_oo`0T003oooooDXYJbe[[BTTiYbU5:BDYAD88JffLdjee_MNee[gg]IJLlg_?LhiS
34YY8@@HXb3T:BDH`c66>LM:BBUU@PQ:JE[[0U[;00iBZU::DXY[;F]=Q11c[W>>DXY1j36V:DDQ91S3
0QSS0QS300<HXaS348800QS300PQ123T8B@YIDY9H`ac[W?>0W__0X@`0Xaa00VDTXaaU9:LdjeE_MO>
FMJjg]/00]kk02[>FKFfS55S335V8@@aYTXY@PPiac66>JMJjh@@W?><LH@`S36447__LjicSV]=HbaJ
jf;/F^]S;6]=HbacSYcccWW_GNLlkegWG>LLaQRDTU[[>LL2:DD01C6V@PSooooo00003?oo04@00?oo
oonDTW>>Nnn<LIBbYAB<DJeEYABDTX@@S36<LIBBQ31cSXaa[EG6F8@@U;:mmjeEQ12<LIcC_OM:BJeE
Q12]UG>>S576>:EDYCBe]W_?U;9cSXaaF/^4<9ccS77666]=[EF<LIcCS76D/X@`U;:DTYcCS76Ldh@`
W?>LdiAbQ12<DHaa0YBB00R<LHaAU7:<LIBBS76DTXaa0YBB00>DLXaAS5400Xaa01Qkkf<<Hbac[ZDd
cUVmeiAbJdfLdiBBQ12Dd/HH>NNLdiBBS764<8aAS76DLXaaW;<3W=<01jCdW?>DTXaaaSRDTW>>00:D
TP:<L@09Q11[KH@`]IJ]MJDdS76DLXaA00;oo`03003ooooo00[oo`04003oooooDXX2>NL02C6V>JM:
BE9ZJdfDTZeE]KJ]U@02]IH03JdeW?>]MC6V>NNmmc5V:FEkccW7FZ]227_?008ia`0JNln449ccF/]S
;;FfDXYkcf]]LjiS;:DdNnmBRS6V@RQS33W7>NM:BD8X>LM223VW>NM1j0=22004@NQBZV</Nnl2S540
3X`aS56DTYBBU7:D/YccU;:L/iBbYABM4kFf_QL2cWT01MJJcYV]MC668@@00S6600haYV]=Q11JZdY9
H`a:JE[;cUVTm7__S35kch?`0W>^00E[KG>>Jfec[W_?00:4<008S35kkg__[IGW?=KJcWWFVP;F^P09
eY[66;FFJfdYIC66@PQJbf</00;oo`03003ooooo00[oo`002ooo01000?ooooliid88<JHYAAS36><Q
1366BVUc[YcC]IJe]P:me`0;]IJLdh@@JfeS3488:BDH`b44:DDQ1002:FD2<HH045::HbaJbd88@RQB
ZU;:H`aSC6]=Llic[W>>>NLQ92TU0R4T00@@XQS34:8H``8@XP03488@XQ2R00<H``056><YID8XH`ac
[P02Nnl2Q102S542U982U;8019ccYCBe]/Hh0]Jj00W6>:EDS55[CD8X8B@@PQS3>LL00TY902Diac6V
<JIRk8@@W=>4<7_?Llic[V^=JfeSC6]=Hda[CF]]Lhi[SG>>JfekkjDde[[WG>mMiec_GNLlg_^mmiBB
F//aYQSS8@@YI@02ool00`00ooooo`0:ool01@00ooooohaAU9800Ycc03:DTYccQ32DTYBbQ12<<H@`
U7:<LIcCNnn449CB]KJM4f]=Q32Llf=<U7:4<9cCH`b]EHbA[GE2B7_?Q31[CF<<Nlnmmg_?U=;FfS6V
[EEkkjDdS75[CJDDQ12<DH@@S76<DIBB0Xaa00B<DIBBS56D/P:<L@:4<0:<L@05U9:4<8@`S76DLP02
S7401IBBU;:D/YbcS7400XaA00]kce[[H`a[KKFF[EFe]X@`W;>446]=00:Ld`0@Q12LdkFfBTV4<:Dd
S56D/YBBU;:DdYcCU=:LliBbU982S5401X@`S56UE8aAJffDLP:DTP0:S56DLX@`Lhj4<8aA[IFU=9BB
S342ool00`00ooooo`0:ool00`00ooooo`02>LL02RUU<FHYIE::F/]cSYCB[EFeU[Ff0[FF00b]EHaA
Jfg_OG__BVTaYS66Hba225[[>NL2<JH06T8XS56UE4YY:DE:BG>^U99:JKggNnlYALHhLhhQ1366>LMJ
bc6V@PPaQSWW>LLiYc76>LL2@RP06CX7@PPaYU:ZF/]c[X@`S564<9BBS76<DIBBW;>LljDDWA>U59cc
YAB]MKggaUS>NHaa008Q100I:DDQ935V<LHiad98NnmSC5:ZDXY:JE::[GFUE6]]NnmcSW>^Nlmc[W_?
Q12<DIBBU;800YBB00Z<LH@`Nnn]ENLlga_>NMJje][F^P;>V@07_QN]EE[;<HHYACW7DZX00_oo00<0
0?ooool02_oo000;ool03`00ooooobTU8@@Hha2R488H`bU5>NMRk7__YABeUP03_ML07ZeEW;=kkg_?
LhiBZRU5:BDQ936V8@@YAASS8@@aYU[[JfeJZd8XBVUJjf</Jfec[V]]LhiS;5:::DDH``<Q108HX`06
6<<@XQRS488HXa2R0QSS00XQ11S3:BDYAD88DXY[CG>>Nlmkk`:44004S56<LIcCW?<2YA@02Jde[EFe
]ZeeY?B446]=@RPaIP026<<00a2R8>@aYP02BTT0247X<HHaQU:ZQ12DTX@@Jhd2Lhh03W>^Lhic[W>^
Po1kkh@`Q124<7__NlmkkjeEeYX5kgd02>Llg__669BbF//aIQS38>@2ool00`00ooooo`0:ool0;P00
ooooog__U9:D/YbcU;:U=8aAW;>D/X`aS56<<HaaU9:4<8aaU=9[KG>>H`b<LLHH[GES3:DdNjnU=8@`
YCB]EF<<Po2DT^LlW=><DIcCS75c[Ycc[GES37>^0ZDD01BLlg>^YAB<LIBbU9:D/YBBW;><LIAbS76L
/haaYCB4<9BBQ11k[g__0X@@0haA026DTXaAQ32DLXaAU9:<LH@`LliBJV<<Q12n5lHH_MNU59BBU;:U
=9cCJhf<DIBbQ12LdkggF/^44:DdU9:LdibcU;800YcC00JDLXaaS364<8aAQ302S5403IccU;9[CH@`
U;:<LHaAS76<DH@`Po244:Dd00:]M@04U;;ooooo000<ool01@00ooooocVW<JH00SW700PaQU::Lhik
cicCYEBmekFF0[Ff00J]MHaaH^a2:>mmF//2<HH06V]=@PQ1j36V>NLaIT7XU;:<<F<<>NND/T88JhfU
=9BbQ12]EDXY<FHaQS6V@PQ:JCW7<HH2>NL0148X>LM223WW14Y900m225[;BTU:BF]=Hdac[W_?Nnn<
DH@@U9:U5:Dd[GD00ZeE00VU=9cCS55kkb3T:BDiac5V>NL00T880111j36VBVUc[V<<BVUJjd88@RRL
ljeeNnmcSW_?S56<L@:DTP0?W=>LljDDW=>D/YBBU7:4<7__Q33W7>Llg]_F^]kK00?F^P07eY[6F:eE
Hb`aQRTU>JL00_oo00<00?ooool02_oo000;ool06000oooooaSS6<<@PQ1R264H`bUUBVUSC8aAYABe
U[GF_ONeeZeeS55c[V^=Jde:B@8Q9009:DDYIB446><HXa2R>LMBZV<<0092:00EBTU[CF]=S55kkg_?
F^]:JC666><@PR3T6><Pi1226:<@XQS34:8HXa2R008H``0@8@@Hhb448B@YABUU>LM2B5[;HbacSW?>
Q124<9BBW=<2YC@02jeEYCBU=9dCS35SC488:DDHhaS36><00a2R00`aQT88BTTiic66:FE:JG>^U9:4
<7_?Ljh2Nnl01H@@Q32<DHaaU9800Xaa0X@`0W__00BLlliikgggWP?_O@08kegW?=kk_QNLdf]=BRTY
I@;oo`03003ooooo00[oo`09003ooooo[GFLdiBbS56DTYcC00:<L@0jU;:<DIAbQ12DTXaaS56448aa
aSR4<4YYJffLljDdHdbU=8aaW=>D/Ycc[GERk7>>S76Llg___MN<<KGF@RRDdW>^O0n]MJDdS76D/W__
W?>DTYBbS76<DIBbS76DTXA@S764<8aaU;:449CBU;:4D9AbU;82U982U;807IcCU;:<LHaaS364<9BB
U;:]MJDdieb]UJeeS96<DH@`S56<LIcCW?=[KIBBW=>4<9cc_OM[KG>^YC@00Ycc00N<THaaS56<LH@`
S5644002S5404IAbS56DTYcc]KI[KH@@S96DTXaAU9:<LHaAQ11c[Xaa[GD00/Hh0_oo00<00?ooool0
2_oo00D00?ooooliic66008aYP07>NMJbg>^U9:D/ZeE]MH00[FF00ZmejeeW==[CCW7@TQBZS6VBVUJ
j`8ii`0BDXXiad7XBTV<DCW7DXYS;9AbU9:]EG__aSQ2:7__:FDaQS6V0T8800I:JCWW@PPiidY9@RP2
>NL2@RP00d88@RQ22002DZX02S66<FI225::F/]kcg`?Q32<DIcC0ZDD0ZeE01>U5:DdYABDTXaA8@@i
acWW>LM224Y9@RPiad7X@RQc[U;:DXYBbP02@RP01icCYCBLdh@`W?>D/YcC00:Ll`05WA>LliccW;><
T@03S7401G`?Nlo>VNmMg_/00mJj00WFf]Jje[[F^]JJe[Ze]X@@>NL00_oo00<00?ooool02_oo000;
ool03`00ooooodY9:BD@PQ1R4:8Q13W7DZYcSXaAYCBeUP03_OL08jeeU99S35Z[DXY:JBUU<HHYIC66
6<<Hha2R8>@iadY9BVU1j5::HbacSW_?Q11c[V=<BTTaYR3T4:8H`aSS8>@H`aRS4:801AS300<Hhb3T
6><00R4400hY9B448@@YAD7XDXYS36]]Nnn448aAU9:U5:ED0jee01BU59cCHba221S38>@H`b3T6><P
i12R6<<aIT88@RPiic5V:DE227>>0YBB00>4<8aAS7400YBB00>L/iBbW=<00YcC00bDTXaaQ32447_?
W;?66?NNmkkgW^mmmih2kgd01^MLiac>FKFFS75cSP;oo`03003ooooo00[oo`06003oooooU;;5n8aa
0YBb00BTm8aAS56440:<D@0:Q32DTYBBQ32<<G__U9;Nnh`aYC@2[ED02F<<]KJ<DG__S56LljDDHdbe
]P02W=<00f</Nnmkc`02Jdd01IccLjjU=:DdS5400YBB019kkiBBQ32<DH@@Q32DTXaAS76DLXaaU9:<
DH@`NnnU=:ee]GH2[GD2W=<01iCBU9:D/YBBS56DTXaa00:DTP04S56D/V<<aSP2S5403ibcS76<<IBB
S76D/YccJffLdiBbPo2D/[FfLhik[`02U98018aAS36<LH`a0XaA01N<LHaAS76L/haaU9:4<9BB_OMc
[W__U7:<LIAbS76DLXaAS75kkg>>HbacSYBb00;oo`03003ooooo00[oo`04003ooooo<HH3>LL01U9Z
Hda[KH@`U9:U=0:e]P0>_ONmejeeU;9cSSWWFZ]kkcW7>NNLdc66@NQ2:08ia`0JLhikkc5V@PR4<7_?
W?=[SIBBDZY:BC66DVXaYU9Z<JI1j4Y9>NLiacVW@PPiic6VBRU2:092200<@NQ224YY<HHiYe:ZJdf4
48`aS56DTYBb0YcC00N]EJee[GF]MKEf[GFe]P02W=<02bU5BRU22488>NMBJSW7@RPiad8XLjh00U[;
00IBZS6V@PRDTZeeW=<2YA@00jeEU;:U5002W?<00iCBYABLl`02U;801iBBS76447?>cUW_ONLL00;F
^P05e][NfmKJg]_F^P02eYX00mkKg__F^P02ool00`00ooooo`0:ool000_oo`05003oooooLli22003
48803BTU>NMJjg>>S76U5;FF_MO66;gg]IJ<LF<<0092200I>PLiacW7<HHYAASS6<<Hhb44>NM224Y9
@TQS36^=Nlmc[W_?H`aS;488<JH@XQRS4:800QSS00HPi12R6:<@XQRS4:826<<26><06R3T6><Q9244
8B@Q1366@RQJbf=<LjikkhaAS76LdidC[EF]MKFF[GF]EIccLhi2:23T4:826<<032446><H`aS3<HHi
ad8X<JHaIR44@NQ[K@BD/P09W=>DdYcCU=:LdiCBW=>D/YBB00:<D@06Q11kchbA_OOWG?Nn0^nM00C_
OONNkgg_O@;WG003g__FV[GF00;oo`03003ooooo00[oo`07003ooooo@PR]MIBBQ3000YBB00>449Bb
U9800YBB00Z449BBQ524<8A@Q124D:eeQ31cSP:U500IDZZLliBbQ12LliBbQ51[;Lii[EFD/X@`U;9k
kjeEQ13ggW>^aUR4<8@@U7:Ldh@@U;800YBB00>DLYBBU;800XaA00R<LIBBS76Llh@`YCBU59BB0X@@
00Ekkh@`Q124<8@@00:<L@03Q32<LH`a00:<D@0KNnnDTV]=aQRDTXaAS76DTX@`U;:<LIBbYCA[CIBb
S75kkjDD_OMc[W?>U9:4<8@@Q32DTXaA00:<L@06U9:<DHaAS56<LHaA0Xaa00Zmmg>^Nln<DIBBS76D
LXaAS76<D@:<L@03Q11c[V<<00;oo`03003ooooo00[oo`0=003ooooo8@@aISWW>LLiig_?Ljj449Bb
YC@00kFf02JmejEDW;=S;488F^]kcf</DXYS;3W7<JI:JC76@PQJbg>^Hbb<DIcCS55Jjg__HbacSV<<
eYXYIC66<LHiic76DZXiic6V>NLiac660SWW01E1j3WWBTU2:3WWDZY225:ZLhikkh@`U9:<DIBBW=><
TIcC[EFU5:eE]IH00Zee01VUE:DDW?=S32U5>LLaYSWWBVU:BCWW>LLj1g_?BVUBJU::<JHaaYcc[GF<
DIcCYABLl`02W=<00iccU;:Ll`02W=<2U98028bAS764<7_?_OOWG=kkg]/3e[X01]kKe[[F^/jIe[[F
VP;FfP;oo`03003ooooo00[oo`002ooo00D00?oooonLle:Z008@PP096:<YAD8XH`ac[XaAYCBeU/Gh
00;6600:[IFDTV<<BRU2:59Z@RQ22366:FD36<<07RTU@PQBRU[;H`a[KG=^Jde[;F<<F/][SF]]DZXY
AA226:<H`b3T6<<HXa226:<@XQS36><Pi1S38>@Hh`8Q100^:BDYICW7BTUS36]]Nnn448aAS76DTYBb
Y?BU=:ee[IFeUZeEYCB445Z[:BDHXa226<<Hhb3T4:8HXbU5>LM223W7:FDY9D88LhjD/ZCdW=>U59cc
YABLdiccU=83W=<2U9801XaAS35kchaa]KKW?0;g_P06kiggW^nMmik_WNmm0^mM00GWG>Llooooo`00
00coo`0?003ooooo>LO_GHaaU7:DTZDDLjjL/haAU7:<LH@`00:DTP0BQ32DLX@`S76e]YbcHbbDTZDD
H`b]MIBbNnnLdiccW==c[Zde0W>>00f<DIcCU9:DTXaaYAABRZDdcUV<DIBbU99kk`02U9800iBbS76L
l`02U;801XaaW=><DHaaU=:<<@:D/P03Q32DLX@`00:<L@0?U7:<LIAbS76DLX@@U7:<DH`aS76<<Haa
LfjD/ZeE00:D/P08U9:448@`S36DTZDDH`bU50:<L@0:YAC667>>NnnU59BbU9:<LIBbU782U983S740
29BBS76DLXaAS76e]X@`Ljh2S7401iBBS76D/XaAU9:<LIBB00:<L@04Q33ooooo000<ool0?`00oooo
obTU<HHiac6V>NMc[W>>Q32LdjDD_MNe][gG_ON]MIBbLhhiaf;/NnmS348XFZ/iac6VBTTiad8XF/^<
DH@@WA=k[g>^Jdekke::Nln44?oo[EDaISWW<JHiidY9@PPaYSWW@RQ224Y9BRU:BCVWBTUJbd88BRUS
;002Nll01X@@S56<LIBBU;:<L@:DTP:Ld`0:YCB]MJDdYABTm9ccW=>DTRU5<HH3>LL01D88>LLaQSWW
Jfd00U::00IBZTYYBTVLdkFfW=<2YA@00jDdWA>U5002W=<02YBbYABDdYBbU9:D/XaAQ11ccZee0^LL
00cNnmkKe][F^]kkg]_F^]kKe[[NfmJJe[X2ool00`00ooooo`0:ool000_oo`05003oooooWA=Jb`03
48803BU5>NMRk6^=S56U5;Ff_OO66;gg]IJ<LF<<0092:00CDXY:BCWW<FHQ923T4:8Hhb4T@RQBRV]=
Hdac[V</JbeJbf<<F//00YBB00Akkc666:<@PP<H``8@PP044:8H`aS38>@26><03AS38@@Q12U5:FE2
24YYH`a[CG_?Nnn<<HA@00:<D@:DTP:Ld`07YABM4jDDW?>DTV<<>JL00a220QS300/HXa22:DDaQSWW
<HHaIR4T@PQ[KIbc00>Ll`07YABLliccW=>LlicCW?<00YBb0Xaa00b4<7__Q32eU]kkmkk_WONNkggg
W^nMmih2kgd00nMLkggWG002ool00`00ooooo`0:ool03`00oooooc6VicbDTXaaU;:U=7>^U9:<LHA@
U9:44002S7401H@`Q52448A@_ML00X@`02UkkjeeQ32D/ZDdS56DTZDdS75S39CBH^b<LIBbWA=kckFf
Nnnmm`00NnnLliBbU7:Ldh@@S76D/XaAS364<8aAQ32<DIBbS55kkiccS76D/W__00:<D@03U9:4D9Ab
00:<D@0OS76DTXbAS56<LH@@Nnn<<HA@S75kkg>>]KJD/XaaW=><LIBBU;:LdjeEJdfLdiAbNnn<DKFf
Jbec[YBBQ5000XaA00><LHaAU9800YBB0Xaa00V<TIBBS76<DHbA]IJ<TG_?Q50018aa00><DHaaS740
0haa00BDT_ooool000coo`05003ooooo8B@aIP02>NL0;C76HbaS;7__U;:U=;Ff_MNe][gG[GFD/V]]
@NQSC6]]Nnliad8XJddaYSWWBTTiag>>S74aYX@`LjiRk7>^S55Jbh@`LjkW?9dC>NLaYT8X<JI223WW
<HHaYP02@PP043WW@RQ::CWW@PQ:BE::F`][KG_?Nnn448aAS76DTXaa0XaA0Xaa00^<DH@`Q12448@`
U;:LliBbW=<iicW7008aYP92200:<LHiic6VJfe:JD8XBVUBJSW7U;82YA@01IcCYABLdjDDWA<00jDD
0Ycc0YBb00b<LIbcNnmkcjDDiccNnmKJe[[NfmKJg]/2e[X00ljIe[[F^P02e[X2ool00`00ooooo`0:
ool000_oo`0?003oooooYCAJbaRS4:8HXb4T>LMBZW>>S56]=KFf00?6600D]IJDTV<<BRU2:5[;DXXi
ac6V<FHY9B3T8@@aQTY9F^][CF<<F^]Jb`9S3007Jfe[CIcc[EFU=6<<<HH00QS300@Pi1S36<<@XP8H
h`8Q100?8B@Q12448@@YAC66@PQBRV<<Jdec[W__Q32<DHaa00F<D@:<L@:DTP05W;>DTW_?BVTY9@03
4:8031S36:<@XR4T<HHiac66:FDY9D8XJffD/PFU5004WA>U59ccW?<2W=<02iBbU9:<LHaANnn<DJee
g]_gW_Nnkid00_NN00Og_^nMkgg_GNmmiec_O@02ool00`00ooooo`0:ool08`00oooooc66icb<LIAb
S76U=8@@W=>D/XaaU9:<<HaaU9:4<8aaQ12<LKFFW;=c[YAbW?>]MF</]GJLlh@`[EFDLW_?aQP00X@`
01:DdXaAJdg6>7>>g_/iajeeYAC668aaW=>DTYAbYABL/haaW;<2U;801XaaW?>D/YAbU;:DLP:<D@07
S76DTXaAU7:<DIBBS7400iBB00b<LIbcW?>LlicCU7:<DH@@LljeUZDDW=<2U9804H@`U;:<LJeEHbbU
58aaU;:4<<hiLhj<DHaaU;:<LIBbU9801XaA00VDTXaaU7:4<9BB[GFLdg>^S5400YBB00><LIBBS540
0iBB00><LHaAS5400_oo00<00?ooool02_oo00d00?oooolQ135V@PQ2:488BVU[;G_?YAB]E@04_ML0
8[FFW==[CD88F/^DTV]]F^/aYYcc>LLaQW__@PQS;8aaNnmJjf<<<JIkchaaJdfmmg__eYZLdmlK@NPi
id88BTUJbcW70T8X00A:BDYYDXY2:09:B@08DXYJbg>>Ljikkh@@S36<D@>DTP04U;:<DHaAS542Nnl0
1XaAU9:<LH@`NnnU50:DTP05DXXiacW7>NM:B@02@PP02SVWJdeBRU:Z@NQ2:3W7W=>LljDd0ZDD00>U
=9ccYC@00Ycc19cC00^D/YAbU9:<DG__[GGNnnLle][NfmJj00;Nf`03g__F^]JJ00;>N@05cYWFV_oo
ool0000<ool000_oo`06003oooooWA=Jja2R0QS300dQ9366DXY[KHaaYCBmekhGaSRmmkFfU=9[C@02
BTT2F//03cX7BTTiac668@@YACW7DXYJjf/]BVUBRTYYF/]K2`02Ljh01ZDDU;:U56]]DVXQ90<H``8@
XP036<<HhaSS00@Q100;:BDYICWWBVUS36=<Lhic[X@@Q32<L@02S542Q103Nnl02X@`S56DTXbAU9:4
<6]]>NLQ11220Q2R014H`a2R:FDYICWW:DDY9ASS@PQS;9cCW?>U59ccYABM4jDD00BLl`0@U;:L/hbA
U9:4<8@@Q32]MMJjmik_WONNkgggW^nMmih2kgd00nMLkegWG002ool00`00ooooo`0:ool01P00oooo
ocWWiebD/P:<D@07W?>DLYCBU9:4<9BBQ3000Xaa02n4<8aaS76<LLHHU99c[W__W?>eeSWW]IJLle[[
[EFU55::[IEkkjEDYAB<TH@@U99S;;gg<FJ4D4Y9Llj]MHaaQ11c[XaaO0n4<8@@S55kkhaaS964<9Bb
U7:<DIBB00:<L@09Q52DTXaAU9:<DHaaS56<LHaA00:DTP0CW?>DTYBbWA>LliBBLhj4<8@@YABD/X@@
S56<TH@@_OM[;IcCS5400Xaa00K666</S96448aaS542S7406XaAU9:<TIBbS76DLXbAS76D/XaAS96U
=9BbLjj4<9AbS76DTXaAS76<DIAbU9:D/YBBU;82ool00`00ooooo`0:ool04@00ooooobU5<HI2:4Y9
@PQBRV</S56M4jeE]MJmekFf_ML00ZeE01:D/T88BVVDTW>>JdeBRZee8B@aIW?>DXYBZ/HHJdeJjd8X
Q102DZX04IcCU;:4<<ii@RR<LJeE:DDaYT88>LLaQSWW>LLaYT88BVT00T8800IS33X7Jdekkh@`Nnl2
Q3001H@@U9:L/iBbU9800X@@021kkh`aQ32LdidCYABLdjDDS56D/YccS54YAC66@RPaQS6VF//YIG__
DZY2:3WW>JLiijDdW?>U=9CBYABM4jDD0Ycc00jLdiccW=>LdiBbW=>D/YBBQ3244:Ddg]_NnmkK0]Jj
00WFf]kKe[[NfmJje][F^]JJcYT00_oo00<00?ooool02_oo000;ool03`00ooooojDdF^/Pi1SS8@@Q
936VBVUc[YBB[GFme`02aSP02<HH]KJLdg?>FZ]BRV;/Hb`2DXX05cW7<HHY9BU5>JMBRV/]JfeBRTY9
BRU:JE[;Nln449cCW;>Llh`aJfe2:2U56><00QS300D@XQSS6><Y9B4T008Y9@0?:DDaISW7BTURk6]=
Lhic[W__Q12<DHaaU9:4<8@@009kk`04Nln<<IBBW?<2YA@059cCW;>4<6;/<HHHXa2R6:<H`aRS:FDa
QSW7:DDQ11S3@PQ[CICBW?<3YA@00jDdWA>U5002W?<04YCBW=>D/YBbU9:<LH@@S56]EMJjkgggW^mm
mik_OONNkiggWP;_O@;_G@;oo`03003ooooo00[oo`09003ooooo<JK_GHaaU9:<DIcC00:D/P06S76<
<IBBS56<LIBB0XaA00E[SIBBU;:meg__00:4<00:]IHaQZeeYEAJbiBb[EDaQZdeW=<2S5404:DDQ12e
UU[[]KIkklGhQ32U=7__cWVDTYAbYCB<DIcc0YcC00J<DJDDS56<LIccU982Q3004YBBS56L/iBbU9:<
LHaAQ32DLYBbU9:LdhaaW=><LHaAW?>D/P:Ld`04LjicS[FfW=<2U9803icCNnn]EE[[W;><DIccS77>
FE:ZW;>449cCS56DLP02S7400iBBU7:<L@02S74059AbQ32DTXaAU7:U=9bcNln4<8aaU9:<LIAbS76D
TXaAU7:<DIAbS742ool00`00ooooo`0:ool01@00ooooobU5>NL00dY900EBRV]]S76U=:ee00:me`:m
m`0T[GFD/W=^YEABRU[[[EEkkd88BVTiicW7BTTiad7XaSQBRV</NlmJbd88Q31S;:DdU79kkmkkDZYc
S]JJ<FHiid7X:FE:BC6V0TYY00MBRSW7HbaBZU[[Jff44003Q3001H`aU9:LlicCW?<00X@@02N<DG__
S76DTZee_MNee[gge[Z]MHaAW=>D/SW7<JI223WW<JHiad88HdaBRT8X@PPiacVW[GFLdiccW=>U=:DD
W?>U59ccYABDdYcCU;800YcC00ND/YBBU99kkjDDcYWW7003e[X00mkKe[[F^P02g]/01=KJg]_F^]kK
0_oo00<00?ooool02_oo000;ool01P00ooooojDdH``Hh`8Q100K:BDaQU9ZLhjD/ZeE_MNn5lHh_ONe
]YBbNlmJje:ZH`a[KE[;DXXYIBU56><Y9BU5DXYK2g>>009:J@9:B@0@BVUS37>>U9:LljDDS75kce[;
>LLH`a224:8@PQ2R6<<28@@02ASS:DDYAC6V>NMBRV=<LjiccP02Nnl01X@`S56DTX@`Nnm[K@9[C@0<
Lhikch@@S76LdiBbU7:4<8`aJhe2:1SS0Q220Q2R00laIS66>LLQ91SS4:9226=<W=>D/ZDDWA>U=9dC
YA@00Ycc00BDdYcCU;:D/P:DTP06S764<8aAYCC>FNmM1nmm00CgW^mmkgg_O@;oo`03003ooooo00[o
o`0S003ooooo>LONniAbQ52<DHbAU9:<LH@`Q12DLX@`S76<DH@`S76DLW_?S7644:DDLhi[CMJjH`bm
micCO0n]MLHh>LNeeP02S5406IcCS76Ldh@@JffeUW>^U;:]EG__H`b4<9cCQ52U57__W=>448aaLjj]
EG__Q12M4h@@00:<D@04U9:DLXaaS742Q30097__Q124<8@@Llj447>>NlmK2e[;DZY2:6=<Q11kcg>^
W?>eUX@@S56LlhaA[EE[KIBbU9:<DIBBcUUBRYccS56D/XaAS76D/P:<L@04Q52DTXaaU984S7401HaA
YCBLdg__Q1000Xaa00>DTXaaU98018aa00F<DIAbooooo`0000coo`0N003ooooo:DDaQT8XBVU2B4XY
F/^<DJDd[GFe][gG]MJmejeeU99[CCWWU;9Jjh@`W;<aQU[[:DE:BDYY0SWW01VU56]]LjiS;488U99:
BD88LjikkljIicb]EF^=NnmS;366<JHiYe::<HHiid88F^/YA@02F^/01dYYNln4<8aaQ32<DHaa00:D
TP03W;>446]]009BZP08F/]cSV=<H`aJjf<<Jfec[P9[K@0@O0nDTYBb:DDaYT88<HHiadYYH^a:JD88
>PLiac66]KH2W?<019Bb[EFUE:DD0Ycc00NDdYBBU=:L/iBbU9:D/P02U9801H@`U=;6>=JJg_/00]Jj
00?>VMJJe[X00]Jj0mKJ00CF^_ooool000coo`002ooo00l00?oooon]MF</8B@Q12U5:BDaQTY9LjjD
/Zee]MH00lHH00ZeUYBBJheJje::H`a[KF;/@RPYI@8YA@0G6><Q148XF^][CE::BTU::DY9DVYBZV<<
Nnn]MKgGYAAkkf]=BVTY9@QQ6:<@PP026<<05RU58@@Q92UU<HI224Y9F/]cSW?>Po1kkh`aS56DTXaa
S35kcg>>JdecSW>^0W__00V<DIBBU;:<LH@`Q11kke:Z<HH00a2200`H`bTU<JHaQRU56<<@XT88JffD
dYBbW?<3YA@2W?<2W=<019BbW=>D/YBb0YBB00F4<8aAW??6>>LL00?_O@08keg_ONmmmik_WONNkggg
WP;oo`03003ooooo00[oo`0<003ooooo>LO_GIBbU9:<LIBBW=>U58@`18aA02:DLX@`S564<;FFU;:<
DIBbQ11JjkgGU;:<<JeePo2LdlHH>NNU=7_?U;9kkicCS76eUZDDS35kkcW7Q12mef]]S76]E@:<L@09
NnnLdibcU;9kkkggPo2D/ZeE00:<D@05Q32DTXaAU9:<D@04U9801kFF_MNmmkhG[GFmmlHH00;>N@0=
]KK66;gGW==c[V]=YCBL/haAW;>D/YAbNnl00YBB012<LIBbcWU229ccQ12D/X@@S36<DIAbS76DLYBB
U7:<L@>DTP05S76<DIccY?B44002S542S743U9801HaaU9:<LIAbS7400_oo00<00?ooool02_oo00<0
0?ooool00SW700U:JDY9DXY2:5::S56U=:ee]KH00[FF02VmekFFU;9cKT88H`ac[V]=W=<aQS5VW;<a
YTY9@PQBRXaaLhiBZTY9Llhiif^=W=<Q97=^[IGNnmJJBVUJbjeE6<<YAD88>JLaQT7XDZYJbc66009c
SP03H^akkhaA00><D@08U7:D/YBBS76DTX@@S76<D@:D/P05U9:<LHaAQ32DTP02U;82S5406G_?W=<i
ac5V>LM2:3W7DZY:JEZ[BTU2:2U5>LNmeiAbU;:LdiccYABLlicCU;:LdiBb00>Ld`:D/P:DTP03Q32D
T/Hh00;FVP0;g]_FV]JjcYWNfmJjg]_Ff]kKe[[Nf`02ool00`00ooooo`0:ool000_oo`0E003ooooo
[EE[CB4T:BDQ92U5:FE:BF]]U;:]EKFf_OO66;gg]IJ<TF</009:J@0LF^]cSU:Z@RPYIC66:FDPi1SS
>LM2:5:Z@RQ224Y9DXYJjdY9@RQS39BB_MNUE8aAJdeJbcWW8@@348802QS38B@Q1244<FHaYTYYDXYJ
jg>>0W__0X@`0haA00>4<7__Ljh00W>^0g__00Z4<9BbW?>LliBbS76<DF]]@PPPi08@PP0D6<<Y9BUU
<FHQ91SS489226]=W=><LIcCW?>U59dCW?>DdYcCU;:L/`:D/P:DTP0;S76<DH@`W?>mmmkkicc_ONML
kegWG004kgd01NnMkggooooo00003?oo00H00?ooooliamkkU983S74019BbYCB4<8@`0Xaa0YBB00J<
DH@`Q32<DLHHQ102W?<0:U:ZcWV<DF=<U;:<DIBBW==BZXaaU;9l3lHHNln]MF</_MNU=5[;JdecSZED
]KJ4<9BBcWVDTX@`YAB<DH`aJffmef]]Q12U58@@Q52<DHaaU9:<D@:<L@08U7:4<8aAS564<7__Q11c
cP:4<00:W?>DTYccW?>]EIcC[EEc[ZeE[ID2S5402iBBQ524<8aAU9:4<:DDcYTiijDdS7400YBB00Z<
LIBBU9:DTXaaU9:<DIAbS56DTP:<L@05Q52LlidCQ12<D@04S7401iBBS56DLXaAS76<DIBB00;oo`03
003ooooo00[oo`0L003ooooo<HI224Y9BVU225::DZZ<DIcc[EF]UKFf]IJmmjfEU;9[CD8XDZZDTV^=
S54aQU::Ljh2>NL0248X@PQ:JD8XBTUS;366YC@2S5406aS3BTVLdf</[EG>VEZ[HbcFfR4T@NPiic5V
>PMBZT98:DEcSW__H`akch@@S364<8aaU;:DLP02S742U;8029CBW?>DdYccU=:U=:fE]IH3g_/01/jI
_QN<LHaaS54Q908ii`03>JM2:5:Z009:B@0:BVTaQS6VaSR4<8aAU=:LdidCYA@2W=<03YBbW=>LdicC
U;:LdiBBU;:<LHaAS7766<iicYT2e[X01/jIe[[F^/jIe[[FfP;F^P04e][ooooo000<ool000_oo`0d
003ooooo]GI[KC5V:DDYIBU5<FI:BG>>U;:]MKFf_MNmmlHH]IJD/V<<BTU2:6;/JheJbcWW>LLaYSW7
8>@YAC6V@PQ2:3WW>LM:BE[[LjiBZT8X>LM[CIBBYABDdX@@JfeBZS666<<248803AS3:BDPi244:FE2
25[;H^aS37>^Nln448@`00:<L@04U7:<LIAbS744U982U;802ZeE_MO6>;hG_MNU59BbNnmJZbU50Q22
00`H`b44<HHYIBU56<<HXd8XJdf<LH@`U982W?<01jDDW=>LdiBbW=>D/YcC00:D/P:DTP:<D@09W=>m
emJjiccWG>mmkeg_ONmM00;_O@03mik_OONN00;oo`03003ooooo00[oo`0<003ooooo>NONniBBU7:D
TYBbU9:U58@`18aa01FDLX@@Q324<9Ab]IJ<DH@@S55SC;Ff[GE22<iiQ12U=;FFU9:e]Xaa[GD00X@`
01ekke[[icbD/XaaYAA[KH@`YAAkkf</NnnU58aAU;:Ldg_?S76mmg>^Nnn]=HaAU9:<LIBbS76DLXaa
00:D/P:<D@09U7:<DHaaS56DLXaAS364<6;/009[C@0BHbacSYCBLfic[ZeeU9:<DIccS56<LIBBS764
49cccUTaQZeE0XaA00J<LHaAS56DLYBBU783S7403YAbS76DTXaaU9:D/ZdeNln<DHaaS56<LIBBS743
U983S742ool00`00ooooo`0:ool03`00ooooocWW@PQJZe::BRU:BF<<S56]EJfE]IJ]M@02]KH05;FF
U;9cST88F/]S3:eELji1j3W7S54Q96/]BVUBZV]=FZ]JjcWWLhh2S5403IBb>LM223W7JffD/[gGcWUc
SV]=NllYADY9008ia`08F//iabU5Nnn4<6]]Nln<<@:<D@06U9:L/iBbW=>D/Ycc0YcC022M4jDDU;:T
m9cc]GJ]MNLLcUW>>Lii]KJDTYbcU;8iYc66>NLaYU9ZDZYBRTY9@PPaITY9_MM[KG_?W?>LdjDD0Ycc
00ZDdYccU=:LliCBU;:DTYbcW?>DTP:<D@03aQS>NLIH00?F^P08eY[F^]JjeY[F^]kKeY[Nf`;oo`03
003ooooo00[oo`002ooo00h00?oooon]MG>>:FDaQRUU:DDYIDYYJhfL/jED0[Ff0[gg00>eUXbAHb`0
0T8X01eJbg>>F^]2:366<JHaaRU58B@YAC66>NM224YYH`acSW>^DXXiic66>LMS38@`YCB<LG_?HbaB
RRUU008@XP<Q10096><aIT8XH^aS36]=Ljikkg`?00:<D@0=U7:<LIBBU;:LdiCBW=>DdYcCU;:LlkFf
cUT00]Jj00_>NKgGWA>DLV]]@RPH`a224:8Pi24T008YA@088>@H`dY9Hbb447?>S76Ld`>Ll`04U=:L
diBbW=<2U;803iBBU;:<LHaaQ32LdkFfeY[NnnLliec_GNMLkegWG002ked2kgd2ool00`00ooooo`0:
ool02@00oooood88e]ZDTX@`S56DTP02W=<2Q1001H@`S56DTYBBS5400X@`00Z<LJeeW=>4<8aaH`bn
5icCLjjD/P:4<00PNlmkkh@`YABU=;gGHdbLle::]IJ]EIBBaQQcSV<<HbbUE8@@Q32eUXaAU;:DdX@@
U;;666=<Q12D/XaAS76<D@:<L@09Q32DTXaAU7:4D8aAS76DTXA@00:<L@05U7:<LIbcHdbDTP02S540
18@`YAB4<7>^0ZeE022<LIcCQ12448@`U7:4D:eE_OLiakggW=>449bcS56DTXaaU9:<LIBBS56DTXbA
U9:<LHaAS76DTZEDQ124<9BB0XaA00R<LIAbS56DLXaaU9:<LIBB0_oo00<00?ooool02_oo00D00?oo
oolj1d88009BZP0`BVU2:6<<S76M4jee[EFeUZfE_MN]MIBbHda:JE/;Jde[KJDdD/XiacWWQ312:366
@RQ::F]]LhikkkFFYCABRU[[H`a:JE9Z:FFU59cc]IIBZU9ZaSPiabUU@PQ:BE[;0T8800>446]]Jhd0
0X@`00B<LH@`U9:D/P:DTP0TW?>M4jDDW?>U59dCYABDdYBbW=>LllHh]IJmmlHh[IFLdiBbS7644366
<JHiad88>NM2:5::@TPaQU[;]IIJbg>>YABLljDD0icc00>DdYcCW=<00YBb00^LdiBbW;><LIBBS56m
eliIaSS>FMJj00;FVP03cYWF^/jI00;F^P05e][F^_ooool0000<ool000_oo`0?003ooooo]IIcSSVW
<JHaQRUU<HI:BG>^U;:]MKFF00:me`0^_ON]UIBBHba:BD88F/][CF<<@PPaQRUU@PPaYSVW:DDiad88
BVUJjg>>JfeJjdY9@RPaQR4T>NM[;HaaU99kcg>>HbaBRRU56:<Hhb446><Pi35VBRUJjf</Jfd2Nll0
18@@Q32DLYBB0YBb0Ycc00>U59ccYA@00YcC00>D/ZeE]KH00/iI00_>NKgG[CFDTX@@DXXYAA1R6:<H
`bTU008YA@036><YAE::00=[C@04Q12LliccYA@2W?<2W=<00iCBW=>D/P03U;802haaS56Dd[FfcWWN
nmlKkegWG>mMie`00^mM0nmm0_oo00<00?ooool02_oo00D00?oooom22=kK00:DTP05Q32D/YcCW=>4
<002S5404YAbU9:DLX@`S364<9BBYEB<DIccQ11S38aA]II[CJeeJdg6>0:Ld`09S35c[XaADZYJbjeE
W;=cSYbc00:Ld`9c[P0?NnnU=;gGLhj4<<iIS56<LF]]S56]ME[;W=>DTX@`00:<D@06U7:<DHaaS76D
/YBB0XaA01NDTXaaS76<DIAbS56D/YCBLhjLdh`aQ32<DIcCS75c[W__YABDLYBbU9:D/YBB00:<D@0<
]IJU=4Y9]GJLlf]=S76<DHaaS56<LIAb19BB00b<LIAbS56DTXaa[CEkkh@`U9:DLXaAU782U9800haa
U9:DTP02S742ool00`00ooooo`0:ool03000ooooodXYBVUBRU[;BVU:BF<<Q32U50>]M@:e]P0^]IJD
/V]]BTUS36]]LjikcdY9:DEJbcWWW=<iie::@RQ[CF</LhjD/YBB6<<YAJfE>NLQ147XDXY[CG>^aSQS
;7__kgdY9BUU>NM:BCW7<FJ<DE:ZNln448@`Nnl2Q3001iAbW?>LdicC[EFU5:Dd00:U500LW?>D/Xaa
S76<DIccU9;>FLIH_MNDdYcCS76<DBUU<JHiad7X@RQBRTY9BRTaYXaaYAAJbcW7W?<2YC@00iccYABL
d`02W=<3W?<019BbW=>D/YBB0XaA00jeU/iiaSS>FLjIe[[>VMJJe[[NfmJjg]_>VMJj0_oo00<00?oo
ool02_oo000;ool01`00ooooojeeLjhaYSVW008aQP0F:FE::F]=U9:U=;FF]KJmmkgG]IJ<LF</@TQ2
:5::JbeJjdXY:DDaISW7@NP3<JH01T88DXYS;7>>F//ia`<ii`0;6<<YACX7F^]SC6]=Lhj447>^BTTH
h`036<<00a2R<HHii`02F//03g>>Ljikkg__Q32<LIBBU;:LdiccYABM4jDDW?>Ld`02S7406YBBW=>U
=;FF_ONmejEDW;><DF/]>NLH`a226<<Q12UU:DDHhbUUF/][KE[[F/]c[YcCYA@2W?<4W=<019CBW=>D
/Ybc0YBB00n<DIbc[GG>FMJjg__O6nMLicc_GNMLkgg_GNmmie`00_oo00<00?ooool02_oo00L00?oo
oom::LjIU9:<D@02S74069bcU=:4<8@@S56<LIBbS76<<H@`Q12<TJeES56<LIccLjj]MKFFW?=c[Xaa
NlnUE0:D/P0<U9:<DH`aDZ[>VKFf>JN]MJeEYEBDTYcc0V<<00jU=5:ZLhj<LLHHU9:4<9Bb_MMJbkFF
Q32<DHaa0YBb00NL/haaS76<LIAbQ32<<@02S74028aAU7:4<8aaU9:Ldh@@U;82Lhh02W_?W=><DIAb
NlneUZDdU9:<LIBb0haA00je]W>^F/^]ULiIJff<LHA@U7:<LIBBS76DTXA@0Xaa00>DLXaaU7800YBB
00>U=8aAO0l00YBB00><LHA@U9800Xaa00B<DHaaS76DTP;oo`03003ooooo00[oo`05003ooooo>PM:
J@02DZX2DXX01498NnnM4jeE0[FF00Ne][gGYEBDTV]=BTUJj`02Lhh05X@@F/]225;:F//YIJDDDZYc
ST88Jfekkd8XJfdH`b4T]IHYAB44Hb`iac660U::019kcicc[GF]EB44<HHiac66>JN445::Lhikch@`
Q124<9BBU;82W=<3W?<2YC@2U;82Nnl00haAS764<002Ljh069cc]KJU59CBS564<7>^<HHiic6VBVUS
35[;:FDYAJDdYAAJbbU5W=>LlicCYCBLl`:Ld`06W?>U59cCU;:LlicC0iBb00J<LJDdaUS>NLHhcWT2
eYX01ljIe[[F^]JjeY[F^/ii00;oo`03003ooooo00[oo`002ooo00P00?ooooneUW>^>NLiacVW0S5V
00Hiif<<S56]EKFF_ML2_OL02JeeU99S34Y9@RQBZV<<F/]22002<HH3@PP09CWW@NQ2:5[;F^]Rk36V
:BDYIC66:DD@PRU5>JLiad7X@RQ[;HaAYAAkccWW6:<@PQ1R488YICW7DZYJZf]=Ljikch@@Q32DTYBb
00:Ll`:U5005YCBU59ccU9:<D@02Ljh057>>Q12D/[FF]KJeUYcCU79c[TYY8B@@PQ2R:BDYIC5V6<<i
ae[[Nll2DXX026]=W;>LljDDWA>Tm9cCW?<2W=<02IBbW=>D/YBbU9:DLYBB[EG6>002g]/02NLLicc_
GNMLkgg_GNmmkeg_O@02ool00`00ooooo`0:ool0?P00oooood8Xg]^<LIAbS56DLXaA[EF4<8@@Q32<
DHaaU7:<DH`aS56DLZeES564<9AbJdfDLYdCS56U58aAQ31cKXaAY?BU=7>^_OM[KKggYA@aQZDDU9:U
=7_?eYZU57>>]KIkke:ZW=>U=;EfS76DT[gGDXZeUX`aS542S7401IAbS56DLXaAU;800YBB02J<LIBb
S56<DHaaU9:Ldg__U;9k[jDd[GFU=8@@W?>DLXaaNlmkkjCdS56DTXaaNnn449cccWUJbf]=W=?FVV]]
Q32D/XaAU7:<LIBB0XaA00F<LIAbS76<DHaa00:<D@09W?>DTW__S56DTXaaS56<LIBB00><L@05U7:D
T_ooool0000<ool01P00oooood88BVURk09:J@0YBTTiYf]]W=>U=;FF]KJm]kGF]IJ<DG>>@PQJjf]=
Lhikke::@PQJjhaaF//aYV]=HdaJjf]]aQPYACW7<HI:JB4T8@@aQSW7aSPY9BU5:BDHh`02aQP02lii
LlhQ12U5@RPaQW__DXY[CG_?Q1000XaA00><LIcCYA@01:DD0ZDd00BLdhaaQ324<08YA@0IF/]c[X?`
YCCF^YccW;>D/XaAQ10aQS6V>LLiif;/F//iabU5[GF<LF<<<JJ<DJDdW;<00ZDd00VLlicCW=>LdiBB
W=>D/YbcS5400YcC00><LIBbcST00/iI00?6><iieYX00]JJ00?F^]JJe[X00]Jj0_oo00<00?ooool0
2_oo000;ool01@00ooooojeeLjh00SW701DaYS668B@aQU::Q32U=;Ff_MNmmkgG[GF<LF</BXU:JE[;
H`aJbdY9<JH00T8800m::D88BTU2:488F^]BRTY98@@Hhb3T6<<Q11S3<JH00RUU00T@XQS3BTUkkjee
W==SC35V26400PQ100lYAC66DVY:JF]=Lhikkh@@S56<TIbcW=>U59dCYC@00ZDD01fDdXaAO0mc[W>>
Jfec[XaA[EFmmkFfYAB<LH@@F`/iaa2R488Hhc5V:DDH`cW7JdekcdYY>NMJbh@`00:Ll`03YABLlicC
00:Ld`04U;:LdiBbU;82U9801HaaU9:M4kggeYX00]kK0^LL0^ML00C_GNMLkegWG0;oo`03003ooooo
00[oo`08003oooooBTWFfXaaS56D/P:<L@0U]IJDTX@@S76<DIBBS76<<H@`S56<TLHHS76U59BbNnnL
ljeES55JbjfEW?>4D9ccNnnLlbUUaSR4D9cCYEB44<jIU;:<LDY9S5400ZeE017F^U:ZLjiBbXaa[IFU
=8@`]IIBZ[FfQ32DTXaAU9:<LIAb00:<D@03Q32<LHaA00:<L@:<D@0=S76<DIcCW=?NfkGF[GFU=9BB
JhfLliBbU7800X@`01ZU=:DDS96D/W__NlnDd]JjDXYkkhaaaSQ[CG>^U;:4<8aAU7:<LIBbS76D/YBB
U7:DTYcC0XaA00BD/ZDDNnn4<0:DTP><L@05U9:<DIAbS56<L@02ool00`00ooooo`0:ool03P00oooo
od8XDZYBbU::BVU2:2U5H^bDT[FF]MH2]KH0;;gG[EFDTV=<F/^DdV]]Lhj446<<BVUJjh@`DZY::IBB
:FEkkd8XYA@iabUUDVXaQRTU<JIkkc66DZYJbb44:DDQ1;GF[GFM4liIF^/Q12UU<HIkcdY9Hb`2Q100
28`aS76D/YBBU;:LdjDDWA<3YA@08IccQ31ccYBbU9:D/YcCQ12DT/HHiabmmiBbW;><LH@@JfdY9BUU
>JM:JE:Z<HHiakggYAA:BAS3F/^U59BB[EFLl`03W=<01IccW=>D/ZDDU=800YBb00^DTXaaS56eU/jI
aSS>FLHHcWWFV]Jj00;>N@03cYWFV/jI00;oo`03003ooooo00[oo`002ooo01P00?ooooneUW>^@NPi
acVW:FDPi24TBTUkkjDd]KK5n;ggaOR]MIAbH`aBRTYYH^`2H``04TYY@PQ:JE9Z@RPiic6VBRU226]=
F^]:JB446<<@PQ1R488Pi092200I>NLH``QQ:DEJjiBbYCB<LE:Z8>@080PQ8B@aQTY9DXYS;7^_Nnn4
<8aAU;:DdZCdWA<00ZDd01F]EJDDW=>4<8@@Lhic[V]]Nln<LKggcWW6>:DdU;:<DG>>@RPQ10QQ6<<0
0RTU00TH`d88Jhf3l48X<HI:JH?`W=<00jDD0Ycc00JDdYcCU=:LdiBbW;<2U9801HaaW=>eU]JJe]X0
0]kK00OW7>LlkegW?>mMicc_G@02ool00`00ooooo`0:ool0<000oooood8Xe[Z<DHaaS56DLX@`]KJD
/X@`Q12<<HaaU7:<DH@`S76<DIBbJbf449AbQ12<LJDdW?=JjjeEQ31[KIccS36eeV</[EFU=8aaQ12U
58@@Jfg666</e[Z4<0:eUP0AF^]S38aABVVDT[gGS56mee[;]IJDLX@`U7:<LIBBS76L/`02U98018aa
U7:<LIBB0Xaa01n<DIBBW?=S;8@`Jdf4<9cCS55S38aaY?B4<9AbLjj<DJDDW=>LlhaANlnU=<Hh@RQ[
CJDdcUVLlg>^YAB44003U98018aaU7:<LIBB0XaA016DTXaAS76D/ZDDS55kkhaaU9:D/XaaU7:<LIBB
U;:DLXaa00;oo`03003ooooo00[oo`0m003ooooo@RQ:JE[[F/]::CWW<HIJbibc[GFm]kFf_MNe][Ef
U99cKT88FZ]cSX@@Nln444YYHbakkd88Hba223WWLjicSW_?U;8Q92U5BTTYACVW<JIcSX@`BTV4435V
>LLYIHaALhkF^ZDD6><aQRUUPo1:JF/]Nnl00XaA01j<LIBBW=>U5:CdW=>U=:ED[GFU59cCQ31c[XaA
U7:<LIAbS56LdkhGomo>FIAbW=>D/X@@NllaQSVW<JH2DXX03RTU@RS6>:ee<HHPi5:ZYCBL/jeeYCBL
ljDDW?<2W=<2W?<00icCU;:Ll`02U98028aAYAC>FLiiaSS>>LiIeYX2e[X01<iie[[FV]Jj0_oo00<0
0?ooool02_oo000;ool01@00ooooojeeLjh00SW701DaQRU56<<Q1488NlnM4kFf_OO66;gG[GF<DF</
BVUBRV<<JdeS;5::BVT00TY900<iicW7>NL00TYY00UJje[;>PLQ90QQ4688@AS38B@00SWW01QBZSW7
<FHHhcWWF^^<LIccLjhaYP0P000Q12UUBTU:JF/]Ljikkh@`S76DTYcCW?<2YA@01ZeEYCBU=9BbS55k
k`B4400IW=?6>=kKcUV]EIBbS75kke[;:FD@PQ2R:BDHhb3T@RQkkg?>>NL@XT88JffD/YccYC@00Ycc
0YcC00JDdYcCU=:LdiBbU982S7400hbA[EG66002e[X02=kKe][W7>LliecW?>MLic`2ool00`00oooo
o`0:ool01`00ooooodY9e[Z<LHA@00:<D@06U9:eUYBbQ32<<HA@0Xaa0h@`01>DT[gGW=>D/XaaQ31[
KKFfLhj448aA[EF4<<iINlnU=4YYLhjLl`02S5404iBb[GEkciccH`bU56</_MNe]YdCW=>DTV;/DZ[>
NHaa]KIBR[FF00><D@B<L@05S56<LIBbS76DTP02S542S7402iBbYCB4D9BBQ32LdiBbU99BZXaAW?<0
0XaA01B<LG__[EFLliBbS55kckFfaQQ225[[]KJ]MIccH`b<TH@@Q32<LHaA0Xaa00jDTXaaS76<DIAb
Q32DLXaAW?>D/W__Q32<LHbA0Xaa00F<DHaaU;:<DIBB00;oo`03003ooooo00[oo`0/003ooooo@PQ:
JDZ9BVU:BCWW<HI[CIBB[GFeU[Ff[IFmejDdU99S34YYDZZD/W__Lhikcc6VU992:4YY>LM[KIBBJdek
ce[[BTTYAD7X:DDYIC6VHb`ii`9cSP09e]Xiie[;6><aQW_?W;?Nnc66008YA@07LjiBRV=<Nnn448aA
S7400YBb02jLljDdYABU5:eEYCB]EIccU9:4<8aANnn447__Q12Dd/HHkif]MIBBW=><THaaNnmJbbU5
>NM:BF;/8BAJbkggW?<@XRUU>NNDTYBbW?>U=9ccU;:LlicCW?>M4`:Ld`0:U;:<LIBBU;:DTX@`_MO6
F<iIaQP2aSP01]JjcYWF^]JjeY[>N@;oo`03003ooooo00[oo`002ooo00l00?oooon]MG>^>NLiacVW
:DDPi24TBTUkkjDd]KH00kgg016]EHaAF^]::DY9H^a[SG^_F/]:JD8XFZ]2:3VW<HI1j4YY009BRP03
>JLQ11220088@@0K4:8YAD88BTU[CEZ[DZXPi24T>LM[KJDDU;9S;1SS8>@HhbUU@RQBJV</NlmkkhaA
S76Ldicc00:U=00W[EF]MKEfYEBLlhaAQ31kkh@@Nnn4<9cccWWNfliiYCBL/haaQ11S;3WW6><HXb4T
8@@Q959ZNnmcSSW7488aYV</S76LljDDYCBM4jDD00:Ll`:Ld`0=U;:L/iBBU9:<DHaaW=>e]/iig]_F
^]kKg_/00^Ll00?_GNLlked00_oo00<00?ooool02_oo00D00?oooom:BMJj00>DTP04U;:<LKFFS742
Q300=XaAU9:DLX@`S564<9BB[EF<DG_?U9:D/X?`]MJ<DH@@_MNLdg>^F/]kkg>>YAB44;FFS76DTYcC
W;>4<9ccQ12U50QQe[YJbmkK]IJDTYBbH^b]ELhi]KIJZjeeS56<LIBBS76DTXaaW;><L@FDTP07S76D
LX@`S76DTXaAU;800YcC00^U59BBH`bLdjDDS56DLXaANln<LJDd00:DTP0>Jfg66:EDFZ]JjmJjW=>e
]V^=U9:<LHaAU9:Ld`:DTP><L@07U7:DTYBBU;:<DIBbYA@00X@`00F<LIBBU9:D/XaA00:<L@05S56D
T_ooool0000<ool03`00oooood8XBTUJbe::DVY:BCW7JffLljee_MN]M@02]KH05:DdS75S;48XJbe[
CH?`]IJ<DB44@RR]MH`a<HHiadY9@NR444XY<HH2@PP05S5V<HHiYf]]H`a:JG=^_MLaQZDD8@@Pi;Ff
LjkF^]lK8@@Q96]=@PQcSW__0Xaa00BDLYcCYABU=0:]E@06[GFeU[FF[EFU58aA0Xaa0XaA01mkkhaA
YCCFf^mmW?>LdiBbU7:<DH@`Hb`YAD88BRUS335VJffeUYBB6:<iacVWNlnLdiBB[EFUE:DDWA>U=002
W=<039BbW=>D/YBbU9:D/XaaQ32U5<HhaUS>>@;6>004cWWFV]JJg]/2cWT2ool00`00ooooo`0:ool0
00_oo`0H003ooooo[EEcSS76>JLaQRU56><YADY9NnnM4kFf]MJmmkGF[EF4<6;/@RQ:BE[;0V]]00US
;5:ZDXYBZTYY>NLiac6VDVX00TYY00dYIB3T488@HP0P8@@Q936V<HIS36]=Ljhia`028@@06dY9S76U
59BbDVY:JC668@A224YYJdeccX@@Q52DTYCBYABUE:ee[IFe]ZfE[GFLliBbQ5244002Nnl06H@`YCC>
NMKJaSRU=9BbU7:447>>@TPYAA2R:DDQ1366DXZ446</<JH8@BUUDXYkkiBb00>U50>Ll`03W=>D/YBb
00:DTP07S76DLXA@U7:U5<HHcYT00]Jj0]kK00CW7>LliecW?0;oo`03003ooooo00[oo`0?003ooooo
BTW>VIBBQ32<LH@`S56U=8aaNnn4<8A@00:<L@0/S36<DH@`U;:U=9BbQ32446/]Nno>VIBbNlmS;:Dd
aQRDT/iiNnnLljeeU=9kkicCU9:UE5::W=>449cCDZZeeU[[[IFU=5:ZYA@aQX@@S97_OF</]IJ4<0:<
D@><L@04S56<LHA@U982S7401h@`S764<9AbU;:L/h@`00:DTP06W=>D/X@@F^^]MHbA0YBB01:DLX@`
S56]MIBBU;9S;<HhU99S;6<<e[Z<<JeEQ31ccYcCNnl4S54049AbS76D/XaAU7:<LIBBS56DTYccU;9k
khaAS76DLYBB18aA00BDT_ooool000coo`0<003ooooo>PM::E;:DZY:BD8X<JIS39cc0Zee00Re][FF
]KJUE9AbH`a:BE/;0V]]00acSW>^]KIS;5:ZLhj<LCW7FZ/aQYcCS742>LL045::<HHaQS66NnlQ92UU
DZYkckggLjhHhbU5D/Y[KKFf0]Jj00`Pi4Y9@RQcSX@`Q52<LIBBW;>LljDd[GD2]IH01kFf[GF]MIcc
W=><LIBB00:4400LQ32<DJDDg__O6iccYABD/YBBU7:4<7>^>PLiad88Hb`YAH@`YEBD/QS3>LLj1eZ[
U;:<DJeEYA@2W?<01icCYABDdYbcU;:LdiBB00:D/P05U9:<DH@@]KK>F@02aSP00khGaSS6>002cWT0
1MJJcUWooooo00003?oo000;ool03`00ooooojeeLhhiac6V>JLYIBTU:FEBRW__YCBe]P03_OL06ZeE
S55S34Y9@RQJZf</Lhi[CEZ[DXYRk5[[BTTaQS5V@PQBJTY9<FHHhaRS488@HQSS:BD2:DD02TY9Jfec
ST886><H`cWWNlnUE;Ff0W__00e2223T>LMBRV]]Nnn448aaU9:U5:Dd]IJe]P03_ML05:fEYCBD/YBB
Q32447__S76]MMkKe][6>:DdW?><LH`aLjiBZRUU6<<2:BD033WWF/]kke[[<HH@PR44BRU[KIBbW?>]
E@:U50:Ll`:Ld`04U;:L/iBBU982S7402HaAW=>eU/iie[[NfmJjg]_Nn`02ia`01>Llooooo`003?oo
00P00?oooom:BMJjU;:<DHaa0YBB00Fe]YBbQ32<DIAb00:DTP09Q32<LH@@W=>U=8aAU9:U59Bb009[
K@0<U9:<LG_?U;9kciBb]II2:7^_Q32D/W__0YBB01>Llg>>W=?6>;FFF/]k[e::]IJ]MIcCW?>DTS66
F/^meh@@[GF3l002S54028aaU9:<LIbcS76DTXaAU785S7402YBBS76DLXaaW;>DdZDDNnmcKZee0Xaa
01FDLXaAQ11c[ZDDS76U56<<g]]c[V]=F^_>>G__YABLlg>^W=><<HaaU;800YBB01:<DIBBS76DTXaa
U9:<LHaAS76LdiccS75kkhaAS76L/iBBU;83S742ool00`00ooooo`0:ool09`00ooooodXYBVUJbdYY
DXY:BD8XJdfLdjee_KNmekgg_MN]EICBJde:BE[[Jdekcg>^S35BRU:ZNnn<LCW7Nlm225[;Q11BZTYY
<FHaYP02@PP0@CVW>LMJbb44F^^DTYBb6<<Y9CW7:BF]EG_?aSS>FC66>LM:BG__Q12DLXaaU9:LdjCd
[GFe][gG]KJeU[Ff]IJU59cCW;>DTXaaS56448aA]KKW?>LLYCBU59cCU;:<DH`aLji1j2U5@NQ[SC5V
W?>D/V<<:BE223W7<JJD/YCBYA@00ZDd0ZDD00>LlibcW?<00icC00fD/YcCS76DTXaAW=?66<iiaSS>
>LIHcUW6>002cWT01=JJooooo`003?oo000;ool01@00ooooojEDLhh00SW7040aYS668B@aITYYQ12U
5;Ff_OO66;gG[GF4D6<<@RQ:BE:ZH`a[CG>>HbaJbdZ9DVY2:3W7<HI2:5::DZXaQQSS488@XPQQ6<<Q
123T8@@iif</H``aYQ22244YIE::U9:e]ZeEYCA[KBUU<HI:JF]]Nln4<8aAU;:Lljee]KJmm`:me`06
]MJeUZDdW?>DTXaA0X@@01j<LKFfe][NnlHH[EFLdiBBQ31kce:Z<JHH`bTU8@A2:5[[Nlm:JBTU488H
`c76H`b<DIcCYABU=9dCYA@2W=<019BbW=>D/YBb0YBB00J<LHaAS76U5;ggeYX3e[X01=kKe][Nnmkk
0_oo00<00?ooool02_oo00l00?oooom:BLiiU9:<LIBBS76<DJDDU;9kkhaAQ3000XaA0X@`031kkiBb
YCBDTYbcQ32L/iccU;:]UHaAHdb<DIBBNln]UG>^Q52eUYccU7:<LHaAYCB<<H@`_MN<LF]]Ljj]MJeE
U;:U57>^W==kkg>>aQS6>9ccNln<DHA@U9:<DIBBS942S5403X`aS76DLXaAS764<9BBS76D/X@`U;:<
TIccU;82Jfd01jDdQ32DTXaAU9:<DG_?00:U=00DU=9S3=JjH`ac[XaA]KJ449Bb_OMSC9AbQ12<DHA@
U9:<DIAbS76DTPB<L@07S56DTXaAYAB<TH@`Nnl018aa00>DLXaaS5400_oo00<00?ooool02_oo05D0
0?oooom2B5::DZYJbdZ9BTTiaf]=W?>]MKFf_MNee[gGYCBDTV<<DZYS37>^S75kch@`S55S34YYF^/i
icX7F^]:JG>^O0m223WW>LLaYSW7@PQ2:6]=8@AS3:DD@PPYAC66>JLYIF]=JhfmmlHhia`H`d88Lhj4
48@`S56D/YccYABeUZfE_MN]UKFF[IFeUZDdW?>D/YcCQ32<DHA@S56]MNmMe[ZU=002W?<04haaQ324
47__>LLaQT98F//YIJeEU=8iYb44>LM22366Q12D/YBB00:U=005W?>M4iccU=:Ld`02W?<4U;801IBB
S56<DJeEaQP00/Hh00K>FLHhaQRn5lHhaUP2ool00`00ooooo`0:ool000_oo`0?003ooooo[EEccT8X
@PPiac6V:FDaQU::Q12]=KGF00?66003[GF<LF<<009:B@0<F/]S37>^Ljikcf=<H^a2:3WW:FDiad8X
0U::00Hiab44488@PR3T8B@3>LL014Y9F/]:BB4T0PQ101lPi48XNlnU=:ee]IJDTU[[@PQBJV]]Nln4
49AbU=:U=:ee_MNmmlHH_MNmmkFf[GFLlibcS76<<G__U9:eeP02g_/02LHh[EFLlhaaQ31kce[[<JHP
i0028@@01DY9JdecST886:<00Q2200DaQU:ZQ32D/ZDD00:U=004W?>Tm9cCW?<2W=<049BbW;>DTYBB
S56<LIBB[GG66=Jje][NfmJjg]_F^]kK0_oo00<00?ooool02_oo01@00?oooom:JMJjS76L/haaU9:<
LJeeU;:448@`U7:<LIBBQ32DLX@`0Ycc016<DH@@NnnDTX@@U;:]EJeeU;:e]X@@YCBL/g>^W==cSZee
00:<L@0OYCBLdiccW?>U=;gGF^^<DKgGU7:44;fgS76DTXaA@PQkkiccg_^448aAU7:DTYAbS76DTXaA
U7:<LIBBS7400YBB00j<DHaaU7:<LH`aS76DTYccW==cSW__YABDLXaa0YBB02J<LG>^YABM4iAbJhgW
75::Lhj]MKEfQ32<LKgGNln4<9cCQ12DTXaaU9:<LIBbS56DLXaAU9:<LIAbS76DLYBbW?><LH@@S56D
TXaA19BB0_oo00<00?ooool02_oo00d00?oooomJZf]]H`aJjeZ[DXY226</W=>]U@02_ML0?;gg_MN]
MIBBJde:JF<<Jde[KG__Y?B]UJeeQ11BJT8X@NQ2:7_?LjiJbhaa:DDYID8X<HJ3l8aaJffU=3VWQ11S
32UU<HHiacVW:FFmeg>>_MO>FMkK<FI[CH@@Q32<DIcCW?>]EJee_MNeU[gg]IJ]MKFf[GFLd`:DTP0:
S364<8@@S56menLleYZ]EJeeW=<2S5405X@`Nnm:BC66BVU22366]KJeURU58@@aYT88>LMc[YcCS76U
=:DDW?>Tm9dC0icc0YcC00>DdYcCU;800YBB00B<LH@`]IK6>0;>N@05aSRn5lHHaQS6>002ool00`00
ooooo`0:ool000_oo`0E003oooooYCAkkdY9@RPiicW7:DDaYU::Q12U=;gG_QO6>;gg[GF<DF</009:
B@03DZYS36]]009kk`07LhiJbdY9<JHYABUU@PP00U::00M222U56<<@XR44>JM:B@02BVT02U::BTTa
QQ2R4688@A2R<HIJbhbA0[Ff00fmmhbAHbaBZV/]Llj4<8bAW?>U=;FF]KJmm`02_ML0;;GF]KJ]MJDD
U;:<LH@`Q12DT[gge][NnkhG[GFLdhaaNnmkce;:>LLHhb3T6<=2:6]]Ljhiia1R244@PR4TBVUc[YBB
W=>U=9dCYABLlicCU=:LdiCBW;<2U;8028bAU9:<DHaaU;:]MLHhe[X2e]X00ljIeY[>V@02ool00`00
ooooo`0:ool03@00oooooeZ[_OMkkh@`S564<8aAYCBLdg`?00:<D@:<L@0=Q324D8@@U;:U58aaW=><
LIAbLhiBRU[[Nll00YBb01:UE9BBLlj<<F^=W;=cc[FfU9:<DG>^Jfe:JJDdLhj4<7__U982S7405jDd
W;=c[YcCS55BRX@`YAB]MH@`S76DTXaaU9:<LHaAQ32<DHA@S564D8aaQ3000XaA00VLdh@`W=>D/ZeE
S95cSX@`U;800XaA01J<TIAbQ31cSYccW=><LG__g_]2:5:Z_ONU=9BBQ12]EH@@LhjDdX@`S76DTP:<
L@04S56DTX@`U984S7402XbAU9:DdYcCS75kkh@`S56<LIBB0Xaa0_oo00<00?ooool02_oo00@00?oo
oomJb`9Jj`08FZ]JbdYY@PQ[CIcC]IJe]P>mm`0VYEBDTV</BVUS36/]Jhekcf]]Q11[KF]=Hbb4<36V
<FISC6]=JfdaQX@`:BDiif<<BTUc[XA@@RRmebUU<HHiYc66<JHj1d7XD/Y[K@;6>007aUR]ME::Nln4
<9bcW?<00ZDD02^]EJfE[GF]MKFF[GF]EJEDYAB<DIBbQ52<DH@`U7;6>>LlaQReUYccW=><DH@@Nlm[
KD88>LLaaT8X8BBe][FF<JHQ136V>NLaYT8XW=><LJDDWA>U=002W?<05IcCU9:LlibcU;:LdiBbW=>D
TYcCS96<DH@`]KK6><iIaSS66;ggaQRmm`02ool00`00ooooo`0:ool000_oo`0?003ooooo[EEkke::
BTU2:3WW<HHaYUZ[Q12]EKgG00;6>00?aQR]MHaaH`a:JDY9FZ]Jjf]=Nnn<LHaALhiBRSW7008YA@0:
<FI2248XDVXiibTU6<<YAD88DXX2F//074YY@NPQ91RS264@PPQQ8BA2:7_?WA>U5;gg_MN<LF]=H`ak
ch@`U;:LljDd[EFeMZee]IJ]MKFf0[FF01:LlibcQ324<8@@W=?66=kke][5n:EDW=>4<7_?JfeJZc6V
8>@26<<01D8XLhic[T8846800Q2200DPi488Jdf<LIcC00:U5004WA>Tm9cCW?<2W=<019CBW=>D/Ybc
0YBB00F<DIAbU=:eU/Hh00?F^P05cYWFV_ooool0000<ool01`00oooooe[;cUV<DIcC00:DTP03S76e
MYBb00:4<009S76<DHaaQ32<DH@@W=>U=8aa00>DTP08]KJU=;FFWA>DTW>>S56eUP9c[P0?[CEkkiBB
W?>D/X@`W==c[ZCdJdf4<8@@[EFDdYbc00:<D@09[EFD/YBBQ31[SE[[Q32]EIBB00><D@05S76DLXaA
S36<D@02Q10058@`S56<DIBBS36Ldh@`S76D/YdCS55[KIAbU9:<LH@`U7:4<9AbNll2W?<04iAbS57N
nd8XDZZe]YcCU;:DLYdC]IISC9cCQ12<LHaAU9:<LIBb00BDTP09S76DTXaaU9:<DIAbW?>Ldhaa00:4
4004S56<LIBBS742ool00`00ooooo`0:ool01P00ooooof;/H`a[;@9S300=DZY2:7>>W?>]UKgg_MNm
mkgG[EFDTV/]DXX00V]]0W>^02IcS[Ff_MN<DE::@RQS335V>LLaISWWU9:4<488<FIJbdY9JdeBRV</
F/]:BC5V<JHiYd88>LLYIBU5]IIc[[FF_OOF^V;/H`b<<IBb0Ycc0ZDd00VLdiBBU9:DTZDD[GF]EJee
Q30018aA00VD//iIkeg5n:DdW;>DTX@@Ljh00V]]01=22366@PQ2:488]IJ<LC66>NLaYSWW@PPaQYBB
U7:LdjDdW?>Tm002W=<2W?<019CBW?>LdjDD0YcC00bDTYBbS76<LH@`]IJmmlHhaQS6>;ggaQP2ool0
0`00ooooo`0:ool000_oo`0E003oooooYCAkke::BVU2:47X<HHiae:ZQ32U=;gGaQS>FKgg[GF4D6<<
009:B@0JDZYRk5/;Jbe[SG__Lji[;DYY>LLQ923T<JHiie:Z@PPYIAS38B@iad8XDVYK2dY9<JHHX`8@
PP0;264@PPQQ:DE:RHaaS56eU/Hh[GF4<002Jfd01h@`S96LdiccYABLlicC00:D/P0MW=>U5:DdW=><
LH@`Q124<9ccaSSFf]JJ[GFLlhA@LjiS35[;@RPaIQS38>@H`dY9Jdekcd8X6<<8H@02488013W7F^^<
DIBb0jDD0YcC00RDdYcCU=:LdiCBW=>D/Ybc0YBB00V4D8aaU;:]MKggcUW>NMJJcWT00_oo00<00?oo
ool02_oo00l00?oooomS3;ggS764D9AbQ32<DJDdU;9kkhaAQ3000Xaa00N<<HaAQ32D/ZDdQ12DTP02
S7401G_?Jbe:BG_?]KH00Ycc01:]EIcCcYU[KKFF:DFeUYBBS76<DJeEO0o>VE[[aQR<THaaU;82S540
0jDDU;9kk`03S54017>^YEBmehaA0X@`00j<LH@`U7:4<9bcU;:L/g`?S75kcg__NlnLlhA@0YBB00FL
lh@`HbbDTXaa00:<D@0HNnnDTW__LjjDdYcCU;9kcmKJBVUc[[gGU=:<DHbAS76mmg>>S96DTXaAU7:<
TIBB0Xaa00f<DIBBS56<LHA@S76<TIBBS76DLYccW=><L@02Q102S54018aaooooo`003?oo01L00?oo
oomJjf</JfeS35[;DZY2:7>>W?>]MKFf_ONmelHHYCB<LF</DXYS;7>>009c[P0=LhhaYXA@YAB4D7__
HbaBRRUU<HJUE3W7Q1000S6601Liif]]<JJ4<7__Q10Y9C66DXXaYSVW<LHaYRU5>LMc[/iI]KK66=Jj
DZYcSXaA00:DTP>D/P0YLji[KHaaHdb<DIcCU;9kkh`aQ124<8@@W=?6>>mm[EF<LH@`NlmcSSWWBVUB
ZS6V>LM2:6;/<HJ]MIcCF//aQSWW:FE:JCWWQ12D/YBBYEB]E@02W?<00iCBW?>D/P02W?<2W=<2W?<0
0icCU;:DTP03S5401ZDD[GFmmlHHaSRmm`;oo`03003ooooo00[oo`002ooo00l00?oooon]EG__F/]B
RU9Z@RPiid88H^b4<:eE_ML00/Hh00c66:eeS55S359ZBVUJbe[[H`aJbe[[Hb`2Ljh04W>>F^]2224T
:BDiie[;@RPaIQ228@@aQTY9F/]S;4YY<HHHX`8@PP0[4:8@HPQ14:8iaf]]LhjLdkgg_QN]EH@`Njmk
khaAU9:L/iBBS56448`aS76LljDD[EFLdhaANnn3l8@`YAC>FMkKaQRU58aaS55kcf<<BTTiab4T8>@0
0R44011:BF]=Lji:BB446:<@PQRS<FIBZW__U;:LljDdYABTm0:Ll`0BW=>LlicCW?>LdiccU=:L/iBB
U7:<DIAbU;:]=KFFaQS6><ii0_oo00<00?ooool02_oo00d00?oooomJjlHHS76DLYBBW;><LKFFU9:4
<002S5402HaaS56448aAQ32LdjDDS56<L@02S5402icC[GF<<F]]NnnLdiBBW??667__S5400W__00RU
E9ccQ32<LIccS55kcg__0Ycc00ikkiAbU9:<LIBB_MNU59BBNlmkkf</S56LlkgG0XaA00nD/YAbQ32<
LIcc[EFU=:ee_ONe]YdCW;>LliBBS5400Ycc00><LE[[W=<00Ycc01FU=;FF]MJeUXaAW=>Llh@@NnoF
VSWWNlnD/YBBU=:Ldg__[GEccW__U9800X@`00ZDLXaaU9:<DIBBS76DLYBbU7:<L@:<D@:<L@05U9:M
4ibcU9:<L@02Q10018@`ooooo`003?oo01X00?oooomS;6=<Jfe[CF/]HbaBRW>^W?>]MKgg_MNmmkFf
[EF<DF/]DZYS;7>>NlmcSV]]0RU501QS;:eE[GFm]jDD<FIS33W7S55cSR44:BDaIV;/JdfLdhaANlm:
BC5V<HI1j3W7@RP2<HH00b44W==cSP02_ML02=JJcYUS38@@U7:<DIbcS542Lhh09haaWA>mekgG_OND
/X`aNln<<H@`Q12M4mJJiebL/f]]U9:M4jeES75BJSWW@NPiae[;@PPiakFfNlmBZTY9<HHiYd8X>LMB
ZZDDS76Tm003YA@00iccW=>Ll`02W?<019cCYCBLlicc0YcC00ZDTYBbS76DTXaaS56LlkFF]MJmm`;o
o`03003ooooo00[oo`002ooo00D00?oooonLlg__009BZP0DBVU:BCWW@RQJjhaAYCBmekhGaSRmmjeE
Q31S34Y9BVUBZV<<F^]:J@9:B@0DF/][KG__U79kke[;>NLaQT88<JHQ91228@@aITYYH`aS;4Y9:DDH
X`8@XP0=488@HPQ1224HhdYYBTV<DJeecUVn5jeeS5400W__00b4<7__Nlm[KF]=Jhf4<:DD]IJU=9BB
Nnl2Nll07h`aYAC>NLii]KJ4<7_?Ljikcf=<BVTYAAS34:8HhaS3BTUS37>^@RPYAA2R6:<@XRTU@RQc
SXaaW=>M4jDd00:Ll`05W=>LlicCW?>Ld`03W?<02iCBU;:<THaaS56<LHbAW=>U5;FF]MH00_oo00<0
0?ooool02_oo01800?oooomJbjfES764<8aAQ32449dCU7:448aAQ32<LHaAQ302S5400iBbYAB<L@02
S540=8aaS57W7:DdW?=[SE:ZJdf<DIdCeYYSC9cC@RRmmjDd[EEkkicCF^]cSV]]U;:DTYcCS56D/X@@
S56D/ZDDQ32<DHaaU99JbiBBU;:]MH@`S55[SIBBQ11kkiBBU;9SC7_?Lhic[X@`0Xaa00fD/YcCW?>4
<5:Z[IFDTW__JdeK2f]]U=:Ld`02S742Q1004mKJ>LNLdhaAU;:DTYccQ12UE9ccJffD/XaaS56<LHaA
S96<LHbA00:<L@08U9:4<9AbS76DTXaaU9:<L@:DTP05W=>LliBBQ3244002ool00`00ooooo`0:ool0
;P00oooooe[[H`aSC6/]F`]JbdY9LjjLdjee]MJe][GF]KJM4haaHbaBRU/;Lji[KG>>JdecSXaa<HHQ
99BB_QONnnML@PPYIBU5F//iid88DZY2:6</Q11kkbUU0SWW02XaYTZ9<HHaQS6V:FDaISW7S56mejee
_QOFV/iiJfeccXaANnliaf<<Q10iah`ag__NfjDdLjikch@@Nnn449BBYCC>NNmMLjikke:ZF/]c[/HH
Jfd2<HH0235V<HHiicW7aQQJje[;>LL2>NL03dY9<HHaYYBBW=>D/ZeEW?>U59cCW?>DdYccU=:Ld`02
W?<019cCW?>LdicC0iBb00JDTXA@Q324<9cCYC@2ool00`00ooooo`0:ool000_oo`06003oooooS75c
SU[;0U::00M:BD88@RQS38aA[EFme`02aQP01;ggYCB<<E[[0TY902eJZe[[F^]BRU9Z@PQ::F</U9:e
UZeEQ31S3488>JLYIBTU8>@Q12UUBVUJjf;/>NLQ11228@@Hhb44264@HPPQ6:<aYSVWHbbL/kGFcWW6
>;FfS75kkf]=F^/00e::00IRk8@`_KO6F:eeQ302Lhh07W_?S56]=LiieYZ]EG_?F/]S37_?NnmJbbU5
488HXa2R6:=:BE[[Jddiab4T6<<@XQRS6<<iif</S76D/P>U50FLl`03Y?BLljDD00:Ll`04U=:L/iBB
U982S74018aAU9:D/ZDD0_oo00<00?ooool02_oo00D00?oooom[CJee00:DTP05S76DTXaa]IJDTP03
S54039BBS56<DHaAQ32L/iccU7:4<9AbS763l09kc`0`[GG_GIBbNlm226<<U=;>FKggW==kkjDDNnn<
DJeeHbbDTZDdU;:<DJeEJffeUYBbS56L/kFFU;:4<7__LjjD/V<<U9:<DKEfLhj44:eEPo2DTZee[EFL
lf</LhikkjeE0haA0YBB01j<DF]=W?>e]YAb[GFLdd8XU7:U=9BbWA>L/iBBe[XHhkFFQ32DTXaaU79k
kjDD]KIc[XaAU9:449BBS743U9800haaU9:DTP02S7400iBBS76<L@05S74019cCW?>LliBB0_oo00<0
0?ooool02_oo01H00?oooom[;F<<JbeS36/]F/]:JG_?W?>]MKgg]IJmekFfYCB<DF<<BTURk0=[K@0;
Jdec[V]]Hba:BLiicUVDdZCdW?>]E@02:DD05h@@<HIJbe:::FFLde[[<HHYAC5V:FFU536V:FE22366
>NLiYf]]Hbc>NKFFaQP00]Jj00iJbf<<<HHYAF]=<HI:JG>^aQSNfjeeBVUJbg>^0X@@01BDTZDDaQSW
7<Hh@PQBZRU5FZ_667=^8@@aQSWW@NPiac6VcUU:BD880cWW0SW700@iih@@W?>DTP:U=003WA>]=IcC
00BLl`06YABLliccWA>U59Bb0YcC00NL/iBbU9:<DHaaNnn44002ool00`00ooooo`0:ool000_oo`05
003oooooNnm[C@02DXX03TYYBTTiidXYF^^<DJDd_MNmmlHH]MJU=8@@F^/2@RP00dYYFZ]BZP02F//0
4e:Z@PQS38bA_ONmeiccQ31BZS668@@Q92UU<HHaIT88BTU2:2U5008@PP8Q900b8@@8H@QQ6<<@XRTU
8BA:JH@@[GFmmliiaUReUX@`H``aaS66:DDaIS6VJdfM4jeeO0mRk5[;LhikkhaaYCC>FLjI]II[SCWW
>LM[;G>>F//Q111R264@PPQQBTUBbV/]<HHY9@8H``08488HXbU5F/]kkibcW=>U=0:U50:Ll`03W=>L
licc00FLl`07U=:LdiBbU;:<THaaQ3000XaA0_oo00<00?ooool02_oo00P00?oooon44:eEU9:<DIBB
0XaA012]EHaaQ12<DH@`U9:<DH@`S564<9CBYCB<LHaAS76<D@:DTP0bLjjD//HhFZ]kckFfJhf4<5[;
[EF<LH@`O0n]EH@@aQQSC7>^[IFD/YccW==2:9BbU9:DLYcCS76]EJeeQ12L/h@`U79S38aaU;;6>9cC
_OMkkhaA[EF]MICBDZY2:7>>WA>D/P:Ld`0NU9:LdhaaH`b44:Dd[EFmmjED>NNDTZeES56DLX@`S77F
fQS3aSRLliBbW;>D/XaAU9:]EG__LjjLdh@`0Xaa00R<DIBBS76DLXaaU9:<DIBB0Xaa00N<DIBbS56D
TXaAU9:<L@02U;801:DDooooo`003?oo00<00?ooool00V<<0V</00IS36</BVUc[YcC[GD4]KH0<Icc
S75S34Y9F/]S36</JfeS;6]]Hda[CE[[iecNnh@`U9:U58aAH``aQS5VJhdiahaA<HIJjf]=:FDaYS66
BVUJjc66:FE1j5:ZLhhYIB44]IJLdjfE]IK6F<iiaUPiidY9008aQP0:<FHYAD8X[IFLda2R8>Ac[XaA
S742U9803:DD]KKF^]KJJddYAC66NnnU=3W7:BDii`<ia`07<JKFVU:Z>NMBbT88<HH00SWW00@iae:Z
YCB<L@BU5003W?>LdicC00:Ll`0<WA>U59ccYABM4icCWA>LdiccW=>D/YBB0Xaa00B<TOooool000co
o`002ooo00H00?oooomkcf</FZ/2DXX04TY9@RQ:BF</S56]EKFfaQRmmkgGYCB4<5[[@RQ224YYDXYJ
Z`9Jb`0KDZYBJV]=U;:]MJeEU=:Llg__F//aQRU5:BDaYSW7BRU2247X8B@HX`QQ8B@Q123T6:<Pi24T
00<H``0T:FES39Bb_MO>FMJjaUR]EF]=>NLQ11SS6<<Q1488Jde[KEZ[BTUJbg>^Q12DTZdeaQSNfkhG
S75:BCVW@RQBRSWW8>@@XQS30Q2200I:BF;/H``aQR4T8@@26:<0212R8BA:JG>^U9:LdjDD[CD2YA@3
W?<03JDDW?>U59ccYABLljCdW=>LliCBW=>DTYAb00:<D@;oo`03003ooooo00[oo`05003oooooLjjU
5002U9801XaaU9:4<:eeU9:<L@:<D@08U9:<DH@`U7:449cCYABDLP:DTP0^S76L/haAU7:4<:eeBTUB
JZDDU7:DTW>>_MN]MHaaW?=cSXaAYCBDTXaAU9:LlhaAW?=JbjeE]II[KIBBH`bU=8aaS55[KIAbWA><
LE[[W?>4<<HhYABDTZee[ED2YC@01e[;Ljk6>=JjU9:<LH@`00>D/P0JNnm[KKgG]IJmeg__>NNLdjDd
W;><DIbcU9;Nf`QQ]KJLdh@@S56LlhaaU7:U5:eEHbbLd`:<D@06U9:<LIBBU9:<LIBB0haa00>DTXaa
S7400haa00JDLXaAS56DTXaAS742ool00`00ooooo`0:ool01000ooooof/]0V]]015[CF</H`aJZg__
W?>]MKfg]IJmekFFYAB<LF<<BTURk6<<009[K@9[C@0YJfeS;6]=Jff]MH@`W=>U5:DdNnn<<BUU:BES
35[;WA=224Y9F^/YID88>LLiYbTU<HJDTSVW<FHiYcW7@PR<DMkk]MK66<iI_OOFVT7XBTU1j002>LL0
1c6V>LLQ92TUHbbDTXaA00>Ld`0NYCC5n<iieY[6>8aA@PPiac66<FHiid88DZXiibUU>LO>FG>><HIB
RTYY>JLiidXY>NLiYiccU9:D/ZeE0ZDd00jM4iccW=>U59ccYCBLljDDWA>U=9ccW=>LljDD0Ycc00BD
TYcCU9:DTP;oo`03003ooooo00[oo`002ooo00L00?oooomccV]=DZYJZ`02DXX01T8XDXYS;8aaYCBe
]P:mm`04]KJ]EH@@F^/2@PP04d98DXYBZU[;DZYJZe::Jbel3iBBU;:DTYCBU99kce[[@RPaYS76008i
a`09>NLaYRU56><@XQSS488@XR3T008Q100>4:8@PQ226>=2B7__YCBmmliIeYZmmicCF`]2208YA@0D
8@@iid8XBTTaYT8XF^]kch@@W=>U=<HHeY[>VJEDLjiBRTYY@RPiY`8Q100B6<<@XPQ1BTUJjf</<HHQ
92446<<@PQRS6<=1j6</S56DTYcc0ZDd00>M4jDDW?<00Ycc00FU59dCYABM4jDD00BLl`:Ld`:DTP04
S77ooooo000<ool02000ooooog_?YCB<LHaAU982S7403ZDdU7:448aaQ32DTXaaQ32<LH@@W=>U58aA
U982S5402YBbS76DTYAb_ONDTW__YCAl3h@@0X@`012<TMJjW=>mee[[Jff<DHaaNnn]MH@@[EF4<;gg
LjicSP:<L@0>YAB]EJeeLjiccW>>S564<5[[U9:44<iiU;:]M@:Ll`0ZiebLdmkKaQRDTV]=S56448aa
U9:<LH@`Hdac[X@`cUW6F;FFcWVLlhaAQ32<LIBBe]X@PYdC[EEkkh@`U;:<LH@`W=>eeV/]S76D/W`?
S76<DHaa0YBB00><LIBBS7400haa00B<DIBBS76DTP><L@03U9:<DIBB00;oo`03003ooooo00[oo`06
003oooooH`a[KG>>0V]]00ES;5[[Q12LljeE00:e]P0B[IFmejDdU99JjdYYF/]S36=<Lhi[KG>>Hba[
KG>>Lji[KG>^0Ycc02NDT[gG[EFDTXbA>NLaQU[;>NMBJV]]:BES;366>LLYAG?><FHYAC6V:FE2:244
[EE[KKgG]KK>FKgG[EG>VE[;Lli[KG?>BRVU=4Y9Jhd00W_?019[KIBBU9:U5:eE]MK>FLHHaSR]UH@@
Q31kkdYYH`aBZTXY:FD2<JH01liIHb`YACWWBTTaYSVW00<ii`0:S56DTX@`YCBU59ccYCBM4jDDWA<2
W?<01ZDdWA>U59ccYABDdP:U5006YCBDdYcCW=>DTXbA0_oo00<00?ooool02_oo000;ool01P00oooo
og__JdeJj`9Jb`07DZYBJU::Jff<LJeE]KH00[gg00RmejEDQ31Jjd8X@PQ:BE::0e[;00iBZU[;F^][
CG>>Q12<DIbcS55kce[;DZY2:4880SW700/aQSVW:BDY9A226<<HXbTU:FDYAA2R008@PP076:<@XRU5
F/^DT[FFaQP00/iI00Ne]YBbLhiJbe::BVUBZP02DXX03d8XBTUJjg>^U7:U5;FFaQSFV]JjcUVUE8@@
F/]2:002>LL01C6V:BD@XQ1R@RP00U[[00<aIR448@@00QS300P@XQS3<HIJjg__U9:Ldjde0ZDd0ZDD
00>M4jDDYA@00jDd0ZDD00BLljDDYABU50:Ld`:DTP;oo`03003ooooo00[oo`05003oooooNlnU=002
S7409HaAS76<DJDDS76<<HaaS56<LIAbQ12<DG_?YABLliAbU9:DLX@`S76<DIBBS56DLYccU9:U=8aA
Q31S;5[[>JMJbf;/W=?5n8@`00:Ll`04F^^U=7_?S742W?<01IBBQ32e]ZDDQ1000Ycc00^DdW>^YEB<
DH@`S55c[X`aQ12U=8aA00:4400]]IIS39BbQ31c[XaAYAB<LIcCU;:DLXaAU79kkh@`S55k[g>>U79k
kiAbS76LliBBeYX@XZDD[GFDTX@`W?>DTYAbS76eUW>^Q12U58`aS76D/XaaU9:<LIAb00:DTP0=S76D
TYBBU9:<LIBbS76<DH@`S56<LH`aS7400_oo00<00?ooool02_oo00d00?oooom[KF]=Lhi[KG>>HbaS
37?>YAB]M@04]KH02JDdS75Jje:ZF/]Jjf]]LjicKP02Hb`0=G>^Lhic[W_?Nnn4<9BbW;<aYQS3DZZL
/f</DXXaYU[[:DEcKS6V8@@iie:ZLji[KD88<HHYAG>^:FDiYb4T_OND/Zee]MK>NIBB_MOF^X@`U9:]
MHaA_MND/V]=BVU228@@_MNe][FF]KH00lHH0/Hh01_669BBF^]Jbg__Nlm2:366<JHiakgGBTTaITY9
BVU1j3WW@NPiid88H`bU58@`Y?B]MJdeYC@01:DD00VU=:eEYCBM4iccYCBU59dCYC@00Ycc00BD/Ybc
S76DLP;oo`03003ooooo00[oo`002ooo00L00?oooomccV]=F/]Jj`02F//035::F/][KIAbYEBe][gG
_ONe]ZeEQ11Jj`922005@TQBZU;:F^]BZP02F//2H``04f]=Lhj448aaQ11S;4Y9F^]S35;:<HHYIBU5
<HHaIRU56<<@PQS3008YA@0<6><@PQ2R6><H`aRS6<<iaf</U9:]MLHh0[gg00J]MJDdS76446]]Lhh2
Hb`065::F^][KH`aW?>]MKFfaSS>NMJJcWW6>;FfW?=l3f]]DXXiib444888@D8XDXYBZP<Q100;6><@
XQ2R4:8YADYYLhj<DIcCYAB]E@02YC@3YA@3YC@02idCYABM4jDDWA>U59ccW=>D/YBBS7400_oo00<0
0?ooool02_oo00D00?oooomkcidC00><L@07Q52DTYdCU;:4<8aaQ3000Xaa00Z<<HaAQ12LlicCS76D
TXaaS36<T@:D/P09U7:<LIBBS56Ldh@`W?=c[]KJ00;>N@16DZZU=9BbW=><DJDDS76L/jEDW==[KG>^
DXZ<LIccS35kkh`a_ON<DG__Nln4<8aaNnn]EF=<Q31kkhaAHba[;G__<JIl3haA_OO>NJeES564<9BB
Q52<DIBBS35kciAbYCC66;ggQ11kch@@U=:<LMJJ8>BmejDDS564<8aAU;:4<8aaYABDTV]]W?<2Q300
1XaAS76<DIAbS56DTP><D@05U9:<LHaAS56<L@02S54018bAS76<DIBB0_oo00<00?ooool02_oo00@0
0?oooomS309[C@07Lhi[KF]=Hbb449cc[GD00[Ff0[FF00RM4haaF/]BJU[;HbaSC7>>0V]]00A[SG>>
Lhic[PAkk`0=aQPYIASS>LO668@`DXXaYV=<DXXYAIBB8@@00S6V01`iic6V>NLYAF;/@RPiac6V:FEB
RW>>_MNeU[gG[GFLlliIcWVU=6]]NnmS35:ZF^^<DJfEcWVeeP:me`0D]IJmmliI_OO66<HhcYWFf]kK
]KIkccW7<JHYACW7>NNmec76>NLj1`9:B@05<JHiacW7<LI:B@03U9800jeeYCBU5002YA@01YdCYABU
=:DDYCBLl`:U5009WA>LlidCW?><TIBBS76DTXaA00;oo`03003ooooo00[oo`002ooo00D00?oooomk
cf=<009Jb`08F^]Jbe:ZDZYcKXaa[EFe]P:mm`09_MNU=8@@F^]2:488BTUBRU[[00=Jb`9Jj`0IJbe[
CG>>Ljj<<G?>F^]225[;JhecKTYY@NPaYS5V<HHQ11S3488Q135V:BDH`a226<<00R4400THha228@A:
BG>^W?>e]/HH]MH00kgG00BU=9AbQ11k[`=c[P06S76U5;Ff_MO66<iI0]JJ0mJj01S6>;FfW==k[dY9
8@@8HAS3BVUJZe::8B@Q124T6><H`a2R6:<Hhd88Hbb<DIBbYA@2[ED00jDd[CFU=003[ED2YC@2YA@0
29ccY?BLliccU;:DTXaaU782ool00`00ooooo`0:ool01`00ooooog_?[EF<LIBB00><D@03W=>DTX@`
00:<D@0AS76DTXaAU9:44:DDW=>DLYBBU7:<LIBBS56DLX@`U9:<D@02S7408ibcS75[CKFFmijUE6/]
Q12U=9ccW=>4<9bcF/^LliBb[EFLljDdW?>DLX@`S36<DJDD_MNLdhaaW==c[X`aW?>Tm6]=S3400YBb
00jDT]JjYCC>NKFfU99kkf]=LljDTYBbU9:<DIbc0YBB00iccV]]HbakchaA]IJU=9cCWA>mmc6VaQRL
diAb0XaA00^D/YBBS76LljeEJff<LIbcNnnDTXaa00FDTP06S76DTXaaU7:<DHaa0XaA00F<LIAbU;:D
LYBB00;oo`03003ooooo00[oo`0=003oooooH`a[CG=^Jfe[CF</H`ac[ZCd[GD00[Ff00^mekGFYCB<
DF<<BTUJjf<<Lhi[KG>>009[K@0_HdacSW?>Nlmc[X?`Nnn<DJeENln]UHaAQ31kkhaa<HIkcc5VDXXa
QSW7DVYJjd88<HI1j3W7:DEkcbU5<JHiYiBBH^c>VKfg]IJTm;ggaQRmelHHH`bDTYcc]IJme`02aQP2
_ML06[Ff_OO>FLiIcSW6F<iicYWNfmkkg]^eUUZ[:DDaISW7Q12]EE::>NM223WWDXXaYSWW@PP2>LL0
0h`aW=><D@02YC@00jEDYCBU5002[ED00kEf[EFU=002YA@02YcCW?>D/YBbU9:LdhaaW;><LIBb0_oo
00<00?ooool02_oo000;ool05@00ooooog__JdeBZU[;DZYJZdYYF/][KIBBYEBe][gG_ONe]ZDdQ11J
j`02@PP014Y9DZYJbe[[0e[;00=Rk6</Jdd00V]]011ccW_?HbaJbf</NnmccV]=BVU2:24T<HHHhb44
264H``8Q10036<<@XQ22008Q10088>@Q91SS:FE:BG?>YAB]U@:e]P0:aQS6>;gGW?><DG__Q32<LIcc
[GD2_OL01<HHaSS>VMJJ0]Jj00[NnnLLkegO6lHhS55:JAS3468Q909Jb`03BTTHhb44008Q100=6<<@
XQ224:8YIE[;NnnDTYcC[EFU=:eEYC@00ZeE00F]MJEDYCBM4jDD00:Ll`03U=:L/iBb00>DTP04S97o
oooo000<ool01P00ooooog_?[EFDLPB<L@03YCBD/Xaa00:<D@03U7:4D8@`00:4<005W=>U=8aaU9:<
D@02S7402iBBS96LdhaaU9:<LIBBS76U55[[Jbd00W>>01]S;9BbQ11kkiBBNlnmmf<<]IJ<<G_?Q31k
cjDdU9:DLYdCJff]MIBbYCBDTV^=S75S;8aaYA@00X@@00Ikkh@@Q32LliAbLjh2Lhh02H@@NnnDTXaa
U9:4<8aAS76DLP02S7407hA@NnmSC6]]U;:LlicCYCB4D36V]KJ4<9BBU;:4<9bcS76<DHbA[GEc[W__
W?><<HaaU9:<DIBBQ32<LH@`00:<D@:<L@03U9:<LIBb00:DTP04S76D/XaaU;82ool00`00ooooo`0:
ool01@00ooooof</Jdd00V]]0V</00=BbX@`W?<00[FF0[Ff02JeUZDdS55S;4YYF^][CF^=Lhi[SG>>
Jfe[CG>>Ljikch@@Llikcg>^U99Jjh@`U9:<DG`?S55Jjd88:DEJbc6V:DDaYT88LjhaQT880S6600aR
k4YYS74Q9244Q11[KKFfYCBU5<Hh]MH2_ML01:eEYAB]MJeE0Zee1;Ff00K6><IHcUW6><iicYT2e[X0
4=kKcWVLle[[<HHYID88YCBLdbU5>NM224Y9BVU:BC660SW700LaQV</W?><DIccYEB]E@03YC@2[ED0
2JDdW=>U59BbW=>D/YcCS96DTP02U;800idCW=>Ll`02ool00`00ooooo`0:ool000_oo`05003ooooo
Q11[K@03F//01e::DVYBZW>>U9:]EKFf00:mm`08_MNU=8@`F^]::D88DVYBZP9Jb`0NF^]Jbe[[F^]S
;6=<Lfi[KG>>Nlmk[g_?Ljikkg_?Nnm[CDYY:DDY9ASS6<<@PQS3:BDQ123T488HXaSS0R3T00haIQS3
:BDYAE[[Q12U=:eE_MNn5lHh_ONeUZeE0ZDD00Z]EJee_KNmelGhaQS>NMJjg]_Nn`;W700Kkeg_ONmm
eYZLle::8@@@PT7XHbaS33W78>@Hhb4T8@@Pi12R6:<@PR44BTUc[XaaW=>U=:ee00>]E@03[GF]EJeE
00:U500:W?>LdiCBW;>DTYbcU;:LdiBbW=<2ool00`00ooooo`0:ool02`00ooooof]][EF<DIBBS56D
TXaaYC@00XaA00V4<8aaS76DLX@`S76449cCW?<018aA0haa00>DTYAbS7400XaA016DTYcCW?>4<;gG
Q12L/g__W;=[KJeES56mef]=[EFD/ZeE009kk`0>S76<DIcCYAA[CIAb@RRmmhaAcUU[KJDDQ12Tm0:4
4007U;9[KF]]W=>448aaS5400YBB00BDLXaaU9:<D@:<L@0EU9:<LIAbS76DLXaANlmkkibcW?>U5;FF
F/][KKFfU;:DLXaAQ32<DIBb00:DTP0IYEBL/f]]W=><LHaAS76DLYBBU7:<LHaAS76DTXaaU9:<LIBB
S76L/iBbU9:D/X`aS7400_oo00<00?ooool02_oo00@00?oooom[;@=[K@0AJbeJjf<<Q32Lljee]KJe
U[Ff]IJU=8aaH`a:JF<<Hba[C@03Jfd08G>^JfecSV^=Njmkkh@@Nnn3l7>>Q31kkf]]S56DLXaALjha
QT88F//aYSWW>JMBZSVW>LM223W7F//aYSVWF//YA@02>LL01:DdQ12U5;FF0/HH016<LKFFcWVeUZDD
W?>U=;Ef[IFe][FF_MO66<iIcWWF^/ii00;F^P0Tg__NfliiS55BRRU5<FIS;<HHH``YAC66BRU:JD88
@RQ223W7@PPaYSW7U;:LdiBb]IJU=:eEYAB]=JDdYABLljDDU=:L/icc0YcC00>L/iccYA@00ZDD0Ycc
0_oo00<00?ooool02_oo000;ool01@00oooooh@@Lhh00U[;00iBZU::BVUJbf^=U9:U=;Ff]MJmmkFf
YCB445[[0T8X00=:JE:ZDZX015[;00=Jjf<<Jdd016]]00=ccW__Nnl00W>^00Ukkg>>F//iabU56><H
`a226<<00R4400<HhaRS6<<00QS302lQ92UU<HHaQRU5@PQRk8@@W?>]MLHH_ONmekFf_ONe]ZeeYCB]
EJee]KJmelHhcWWF^]KJg__O6nLliec_ONMLcUV<LDY96><HXdY9JdeJjc5V488Hhb44:BDHhaS3008@
PP064:8iaf<<S56D/ZDD0ZeE0ZDd0ZDD0Ycc0YcC00FDdYccU=:LdiCB00BLl`;oo`03003ooooo00[o
o`05003oooooLhj]M@04S7400icCW?><L@03S542S742S5401h@`W=>U58aaU9:<TIBB00:<L@0JS56D
TXaaU;:<THaaS56<<Haa[EEkkjeeU;:<LH@@Nnn<DJDdYAAkkhaaW?>449cCQ32U=0:<L@0>Q32U=:DD
U;;>VIcC]KJ<DF]]W=>4<7__Q32]E@:<D@0=O0n<DICBU;:DTXaAQ52DLYBBS76<DHaaQ3000haa00n<
DH@@Jhf<LIBBYCBLdjDD>NN<LKggU9:<LHaAU9800Xaa00^DTXA@W?>eUV]]Q32D/W__U7:4D9Ab00><
D@06U9:<DIBBS76DTXaa0YBB00F<LH@`S764<9BB00;oo`03003ooooo00[oo`04003oooooHb`3Jfd0
1F]=H`acSX@@W=<00Zee00ReUZfE]KJM4iBBF^]BRU[;0V]]0V]=00E[KF=<Jfe[KG>^009kc`0_Ljik
kg?>JfggWW_?Ljikcg__Q12<DF]]BVTaYT8X<HIJbcWW<LI::CW7BVU222UULli226=<aQPHhdY9S764
<:eE_MNeeYcCYEBmmliI[EFM4iBbYAB]MJeE[GFeeP02aSP01<iIcWWFV/jI0]Jj00WNfkggLhi2:244
:FERk;ggHb`00S6600DaaTYY@RQ:BCX7008aYP06@PPYIH@@W=><DJDd0ZeE00>U59BbW=<00YBb00BL
liBBW=>Ld`:U=004WA>U59dCYA@3W?<2ool00`00ooooo`0:ool000_oo`06003oooooS55cSU[[0U[;
0U::00EJbg>>U9:]EKFf00:me`08_KNU=8@@F^]2:488BVUBRPAJb`9Jj`06Jde[KG>^JfecKV]=0XaA
00Z<LF]]LhiccW__JdeBRSW7:DDH``<Q108HX`0G6<<HhaS36<<Q12U5:FE22366@NPiif]=S76]EKgG
]KJeU[FfaSS66;Ff[GFUE002[GD01;gGaQS>NMJj0]kk0^Ll0^mm00cW?;ggQ10iaaS34:9BJV</H``Y
9A2R6<<38@@03QS36:<@PQ22:DEBZW__U;:LljeEYEBU=9dCY?@3W?<00jDDW?>U5006YA@01IdCYACo
oooo00003?oo01X00?oooomcSZeeS56DTXaaU7:<LIcCS56DLX@`U7:<LIAbQ32<DG__W=>LliAbQ12D
LXaA19BB01RDLYdCQ12U59BBS76DLZee:DFU59bcS76LdhaALjjDTYcCS76Tm9ccNnnDTYcCQ302S540
3X`aW=>3l6]=W;<@X/iIS76DTXaaU7:448?`[ED2S54038aaNlnL/iBbW;>LdiAbU9:DLXaAS76DTP:<
L@0JU7:DTYAbQ11kciBbW=>U=9cC[IDaQYBb[EFD/YBBQ32DTX@`U7:D/XaaS56eUW__NjnLl`><D@09
S76L/iBBW;>D/YBBU=:L/iBB00:<D@03U9:<DIBB00:<L@04U9;ooooo000<ool00`00ooooo`02Jdd0
4g>>JfecSV</H`akkicc[EFeU[Ff_KNeUZDDS55S348XFZ]S;6]=009cSP03JdecSV]]009[K@03]KIk
cg_?00=c[P03mki[KG_?009kc`09S76DLV]]JdeJjcW7<FIkkc6V008ia`8ii`0F>JM225[[JddaQYcC
:DDY9G=^S56]EKFfYCBD//Gh]KK>NJED]IJe]YcCYC@2[GD01;fg_OO>FLHh0/ii0mJj00WFV[FfHb`a
QR4T>LLaY[gGLhh00S6600I1j488@RQ:JD88<HH2>NL02S66BVVLdhaaW=>]EJDDW?>LdiCB0YcC00fU
5:eE[EFU5:eEYCB]EJDdW?>U5:DdW?>Tm002ool00`00ooooo`0:ool000_oo`05003oooooQ31cSP03
F//08eZ[DXYJbf^=U9:U=;Ff]MJmekFFYCB445[[>PM22498DXYBZU[;DZYJbe;:F^]S;6]]Jhe[CF</
LhjLljDDU;9[CF=<Jfd00W>^00ES;5::>LLY9B4T008Q108@PP8H``0>6><H`bU5:DDaQT8X>LLaQR3T
@RQc[YCB[EFUE0:]M@04aSRn5kgg[GD2[ED01Zee]IK66<iIe[[FfP;O6`0CiccWG>mMg]^eUV]]<FH@
XR44F/][KE[;:BD@PQRS6<<Q11SS6<<00Q2200P8HB3T@PQ[KHaAW;>M4jDd0Ycc00>LdiccW?<00ZDD
1JDd00FU5:DdWA>U59cc00;oo`03003ooooo00[oo`0=003oooooLjjUE9AbS56<LH@`U;:LliBbQ500
0XaA00Z<LHaAQ32<LH@`U=:U=9BbS56<L@><D@><L@0@S55S;8@@S76<DJee_OLYILiiQ32DTXaAQ31k
khaAU;82U9801KFfF/^LdiBbS5400YBb00jDTZeEHbbLdjee>NO6F9cCS95cSXaANln44:eE0W>^00><
TG>^S9400XaA0YBB01:D/XbAS76<LIBbS56DTXaAS76<DG__LjjLdidC[EFe]/iIBTT2W=<2U9803XaA
S76<DH@`W=><LH@`[GFLlg>>U;:<LH@@S544U9803IbcQ32<LH@`U9:4<9AbQ32<LHbAS76<DIAb00;o
o`03003ooooo00[oo`05003oooooHba[;@02Jfd05f]=JfeJjh@@W?>]MKFf[GF]UKFFW?><DF]=BRUB
ZV</H`a[CF</LhiSC6]]Jhd00V]]00Mkcg>^LjiS;<iikee[;@02Jfd03W>>NlmkkhaAHdakke[[<JIJ
bcW7:DDiicW7>NL2DXX05d8X<HI226</:FDQ91SSU;9c[ZeEYEB4<;Ff[EFmmkgGWA>U=;Ff[EFU=:eE
[ID00/Hh01;>NLjIcUW>NMKJcYW>FIccDZXQ9366F/^LlkhGBVTYACVW<JH3@PP03d8X>JLaQSVW<HI2
28aaU;:4<:DdW=>D/YCBYABUE002YC@03:eEYAB]EJDdYABU=:DDWA>U59ccYABLd`;oo`03003ooooo
00[oo`002ooo00l00?oooon<DG>>F^]Jbe[[DZYBRU[;Lhj<LJeE]KH00[gG00Re]ZDDQ11Jbd88>NM:
BE::0U:Z011JZe:ZF/]Jbf]=JfecSV=<Hbakkjee_MNLlf]]Jde[K@9c[P05LhiS;5[;>LLaQP028@@0
1A2R488H`b44:BD012U500/iic66:BD8HBU5DXYkkiBbW;>U=:ee00;6>003aQRm]jee00:eUP04]KJm
eliIeYX2g_/2ia`03>mMiccFVYccF//Q11S3<HI[CG>^F//Q908@PP056<<Hhb446<<HX`03488023VW
F^^448aaW=>M4jDDWA<2YC@00jeEYCB]E@04[ED01:ED[EFU=:Dd0ZDD0_oo00<00?ooool02_oo00D0
0?oooomc[Zee00:DTP1;S76DLXaAYAB<LHaAQ32<DHaaU7:4<8aaNnnD/YccU;:<LIBBS76DTXaAU7:<
LIAbYCB<DJDDU7:<DKfgLji:BKgg[GFDTZDDS76DTXaAU9:<DG_?_MMcSYBbYAB<DJDDQ12Ldh@`U;:U
E;FfHbbmejEDY?B<LG_?S75cS[FfNlmccZeEQ32L/iCBU9:<LHaAU;:DTX@`00><D@0DU9:DLXaAS55k
ch@@U;:]EIcCS35kcd88YCB]MIBBU;:<DIBBS76<D@:D/P07S76LljDdLjikkiccQ1000YBb00NL/iBB
S56<DIAbS56DTP02S742U9801HaaU9:<LIAbS7400_oo00<00?ooool02_oo00<00?ooool00V]=00Qc
SV^=JdeS;6<<NnnTm:ee0kFF00n]MJDDS55JjdY9F/]S;7>>JdeS;6=<JbeS;7>>Ljh00g_?01e[KF<<
mkkW7:eeF^]kkh@@Q31k[haAU99kkiAb8B@iae[[<HHaYSVWJhe:JE[;BTTYIG_?Hb`aQRUU008YA@0=
S75[CIccLjk>FKggaQS6>:eeW?>eM[gg[GD00ZeE01BmmlHHaUS>NLiIcWW>FMJJaQR444YY:BDYIF<<
]IJ]=E[;>LLaQS6V0T8X00E224XY>NLiac6V008ia`09JdfDdX?`U;:U5:Dd[GFUE;Ef00:]E@>U=003
[EFU=:eE00:U=0:U5005W?>U5?ooool0000<ool000_oo`05003oooooQ51c[P02F^/03U;:FZ]:JE[;
JffDTZDd]KJee[gG]IJU57__F//2>NL00d8XDVY:R@04DZX03U[;F^]S;6</JbeJjhaA]MKF^ZDdNnmS
C7>>Jfd2Ljh02g_?JheBZSWW:DDQ91S3488Pi24T<HH00RUU00hQ135V<HHaQQS3244@PRU5DXY[KG_?
U9:M4kgg0/HH00Ve][FF]IJmekFf_MNmmliie[X00]kk0]lK00kNnkhGS75:BBU58@ABRW_?Q11BbR4T
264@PQ2R0QSS01TPi1S34888HA228BA:JF]]Q32<LIccYABU=:ED[GF]EJeeYEB]EJDd[EFUE:eEYCB]
E@02YC@019dCooooo`003?oo00H00?oooomc[ZDdU982S7404YBBS56U=8aaS56<LHA@U9:<LHaAS764
<9BbYAB<LH@`S56<L@>DTP03U;:<DHaa00:<D@07S76<DMJJDVYJjicC[ED00Xaa01^4<9BBQ324<8@@
Llk6>9BBU7:D/YbcU99kch@@S7644;FfF/^448aaU;:e]XaAW?=cSX@`YA@00V</02>4<8@@NnnDTYcc
S76<DIAbW=><DHbAS764D9BbS76DLX@`Nnn<DIcc_ONLdjeeLhiS39ccWA><LIBBS564D9BbO0nD/XaA
00:<L@0;[EF4D7_?U=:DLX@`S764<8aaQ32DLP02S7401IBBS76<LHaaS5400Xaa00>DLXaaS7400_oo
00<00?ooool02_oo00d00?oooom[CG>>Jhe[KF</JdeJjhaAW=>]M@04]KH029ccS55BZT8XDXYS;6<<
Jdd3Jfd2Jdd00g>>Ljikc`02Lhh03E[[mkkW?<HhLhj447_?Q31ccW_?U;:DLX@@009S300<DZY2:3W7
@RQJjdYY@RQBZSWWS54YACWW0SW700HaQRU5LjiBZW>^YC@2]IH03<HH]KJ]EJfE_MNe][gGWA>eU[Ff
cUW>N@?>F@0CaSRe]W__BTTYIG__DZZLljDdNllQ92UU<HHiacWW@PQBRSWW>LL00S6V00HiYe::Q324
<8@@YE@3[ED03jED[EFUE:eEYABU=9cc[EFU=:eEYAB]EJDdW?>Ld`02ool00`00ooooo`0:ool000_o
o`0I003oooooS55c[V<<F^]Jbe:ZDXYJbg>>U9:]EKFf_ONmekFfYAB445:Z@NPiidY9BVT00U::0U:Z
0U[;00]S36</JdeS;5[;S56menLl_MNDTW>^00=cSP9kc`08NnmS;5Z[>NLiYb4T8>@YA@<aQP8Y9@0A
<HHiYc5V6<<8HA1R6:<aIT8XF/]c[YBb]IK66<HhaORe]P02_ML01[gg_MNmmlHheY[FfP?Nn`0;e[Ze
]W__DVXaYT88F^^448@`F^/YA@0226400a2R6<<Q10026><248801`QQ8>@iif<<Nln<LIcC00:]M@05
]IJ]MKEf[EF]M@06[ED01:Dd[CFU5:DD0_oo00<00?ooool02_oo00/00?oooomc[ZeES56DTXaaU;:<
LJDd00J<D@0:Q12<LH@@YABU=9BbS76DTXaAS742S542U9809haaU9:<DIAbQ33W736VQ31[CKFfS56D
LXaAU;:<DH@`Q11cSZDdQ12<LIcCU;:]EG>^YAB<DH`aU;9cSYBBYAB4<9BB[EFL/iCBS56UE002Nll0
5IBBS56<LHaAW=>DTX@@U9:LdiBBW;><DH@`S76DLYBBS55c[YcC[EFLd`02W?<04h@`Jff44:eEU;:L
/haaU9:<DH@`S76DTYBbU9:U59ccNnnDTYcC00:<D@0=U7:DTYAbU9:<LHaAU9:<LIBbS76DLXaAS740
0XaA00B<LOooool000coo`0F003oooooLfic[W=^JfecKV]=Jbf4<:DD[EFm]kFF]KJeUZDDS55S348X
H``3Hb`09F]=Hba[KF]=Jfe[SG>^NlmcSV]=F/_g_/iicUV<LG_?Nnm[KHaAQ11cSX@`Q11kkhaABTUJ
Ze::FZ][CD8X<HI::E[[BRU:JC66008ia`0:@RPaQSWWBTUS;8?`YCC66;FFaQP2]IH01;gG[GF]MKgG
0kFf00?>FLHhcUT00/iI00neUV<<BVV<LE[[W;>DdZeELjhY9BUU<HHiad7X@RP00T8801]1j366@PPi
adY9JhfL/h@@YABe]Zee[EF]MJDd[GFU=:eEYCB]=JED[CFU=:DDWA>U59ccW=<00_oo00<00?ooool0
2_oo000;ool01@00ooooohaANll00V<<0U[;00IBRU[[LhjD/ZED]KH2_ML01;FFYAAkke:Z0SW700=2
24YYBVT015:Z00=Jbe[[H``00V<<00UBbXaa]KKW?;FfU;9cSW>^Jhd00W>^0W__00Qc[V]]F^]:BC6V
:DDaYS660RU500DPi24T<HHYIB44008H``8@XP0<6><YID98H`b44:Dd]MK>FLHhaQRmmlHH0kgg00?6
6<IHeYX00]Jj01kFf/iiYAAc[U::DVYBZV]]Q12DTW>^@PP@PPQ1264HXaS36><H`a22264@HQ2R:FEB
RW>>Q32L/jDd]IH2[GD02ZeE[GF]EJeeYCB]EJDd[EFU=:eE0ZDd00BLloooool000coo`0;003ooooo
NnnU=8aAS76DTXaAS76M4`02S5400haaQ52DTP03S5400h@@U;:Ld`02Q30029BBS76<TIBbS56D/Xaa
U983S540:IBbe]Y:BIBBF/^eUW_?W=>D/XaaW=>D/YcCQ12DTW__W=>DdXaAS75cSYBbW?>Ldh@@S56L
dhaAYAB4D9BB]KJ<DLHHYCBDTYBbWA>449BBS7400YBb00B<THaaS96<D@:D/P0@Q32DTX@`S55c[W__
YABDTXaANnn<DH@@Q32DL/IH]IH2U9803haAU9:4<9BbQ32D/XaAU9:Llh`aLjjLdh@`Q124D00;S742
U9801HaaU9;ooooo00003?oo00D00?oooom[KG>>00=[K@0>JbeS;8@`WA>eU[Ff]IJ]UKFFW?><DE:Z
@RQBRP9S3003JfeSC6]=009[C@03JhecSW>^009[K@08HbakknLlaSS664Y9S55kk`:4400KS76<DH@`
Q52448aaQ31:JE[;DXY[CCWW<FHYIIAb8@A1j498@RQBbSW7<JI[;E:ZS36DdX@@00;>F@03aSS66;gG
00:me`08_ONe][Ff]MJmekgg]KJme`;6>00<S35BZW>^Jhec[XaAQ12UE=JjQ10YIC660SW701=1j3W7
>LLiic6V<HI22366DZZDTXaAS76]MJED[EFU5:eEYCB]E@02YC@2YA@2YC@01IdCYABLljDDWA<00_oo
00<00?ooool02_oo000;ool06@00ooooohaaLliS;5[[H^aJbeZ[F^]kciBb[GFe][gg_MNe]ZDDQ11B
ZT7X>NM:BDYY009BRP0?DZYBRU[;F/]Rk5[[H`aJbf]=W=?6>=KJ]IJD/W_?009c[P0<Lhikcg?>Nlmc
cW_?JfeRk488>NLiacVW0RU500DH`bU5:BDYIASS008Q100;8>@HXb4T8BA::E::Ljj<DKEfaSSFVP02
cUT06LHHaSS66<HH_OO>>LiIeY[>VMJj_MNDTV<<F/]Jjg>>Ljj<LIBbU99c[T888@@@HQ22008HX`0=
6<<@XQ2R264@XR44BRUS;8@`U9:U=:ee]IH01:ee0ZeE00BU=:eEYCB]E@:U=0:U50;oo`03003ooooo
00[oo`0F003oooooLljU58aaU9:<LIBBS76U=8aaS564<8aAS76DLX@`U7:4<:Cd[ED2U9800iBbS56D
LP02S740:iBBS56<LHaaS56DL[gG]IIS3:CdLjk669ccS56<LHaAQ12<DH@`S56<LF]]S76<<IccS564
49BbYAB]EE::[GFDdX@@S764<8@@[GES3;EfBVVD/YBB009kk`0RNln449AbS76<DIBBS56<LIAbS76D
LYcCU;:<LF]]U;:DTYccNnnLliBBW?=cSU:ZY?BDT/iiS56DTXaAW;>DTXaAW?<2U9803ZDDW?=kciBb
W=>4<9BBS76D/XaaU9:<LIAbS742U9801YAbS56DTXaaU9:<D@;oo`03003ooooo00[oo`05003ooooo
Nlm[C@02Ljh3Jdd038aaYAB]MKFF[IFe][FFYCB<DE[[@RQS30=[C@05JbeS;6]=HbacSP03Jfd03V]=
F/_oonLl[EFU=9BBNnn<DH@`LjikkhaANnl2Q1006haAJfecSTY9H`a2:5[;@RPaQV]]<FHYAG>>@PPi
idY9>JMkcbU5W==:BH@@S77>VLiiaQS6>002_ML01KGFaOReU[Ef_ML00lHH00Nee[FfDXY[CD8XJffU
5002S54059cc[IG6>=kK:DDaYSVW>NLiad88DXXaYSVW>LLiidY9Po2<LIAbYC@2[GD01JeE[GF]=JED
[ED00ZDd1ZDD0Ycc0_oo00<00?ooool02_oo000;ool01`00ooooohaANlmK2f;/009Jb`05DZYS;7?>
W;>]E@02]KH03;gG]IJU57__DZXiid88@TQBRTZ9DZYBRP9BZP07F/]Jje[[D/YJjh@@]KH00/ii00BU
58aaLhikc`=c[P0=NlmccW_?Nlmkkf^=F^]:BCWW<JHYAB4T8>@00R4T010Q11SS8B@aIR4T8@@aQSVW
BVU2:6</NlnLlkgGaUSFVP;>F@07aQS6>;hGaQRn5lHhcUT00/ii012e]X@@F/]:RF<<Jdekch@`YAB]
MJeEQ11BRR4T4:8@PP8@XP0:6:<@PQ1R264H`c6VF^]kkiBBW?<2[GD01kFF[GF]MJeE[GFUE:eE00BU
=003WA>U59cc00;oo`03003ooooo00[oo`06003oooooLjjM4haa0XaA00F<LIBBW=><LHA@00:<D@0;
U9:<DH@`Q32449cCYAB4D8@`S76<D@02U9806XaaU;:4D9BbS56DTZEDYAA[SE:Z[GE[CJDDQ124<8aa
U;:Ldh@`U;:<TIcCS76D/YccYA@2U9802HA@S56]EF/]YCBLlh@@S56Ll`02YC@01G>^aSQS;;hGaQP0
0iBB00=[KHaaS5400haa00ZDTXbAU;:4<8aaS96L/haAYAC6>0:DTP09Nln4<9BBW?=c[V]=LhjDT/ii
00>DTP0@S55kkhaaU9:<LIBBYAAl3h@`W=><DHA@S56DTXaAU982S7401IAbS76DTXaaU7800haa00BD
T_ooool000coo`0M003oooooJde[KF]=JfeS;6]]Lhj<DIcc[GF]UKFF[GFeUYdCS55BZTYYH`a[CF</
JdeS;6]]Hba[;@02Jfd04W>>JdeJbkgGiecW79cc[GF446<<Q12<LH@`Lhj448@`Nln4<0:DTP0[Q31c
[V]]@NQ2:5:Z>PLiae[;<FHiih@@>PLiag>^S552B5[[6<>]MIBBNlo>VLHh_ONmekFf_MNe][gg]KJ]
EKgGaSRn5liIaSRLdaSSNln447>>Hd`00ZDd0[Ff00?6>=KJ>LL00SWW00`aYSWW>NLiic66<JI2:3WW
H`bU59BbYA@2[ED00jDd]IJU=003YC@2YA@00iccYCBM4`04W?<2ool00`00ooooo`0:ool000_oo`06
003oooooS75c[V<<0U[[0U[;00]S;8?`U;:]MKFf_MNee[FfYAB445:Z00922008DVYBRU:ZDZYJZe:Z
FZ]BZP9Jb`0;DZY[KJDDe[[NnlIH[GFDTX?`Ljikk`02Nll017>^Nlmkcg__0W_?00I[KF]=DXY2:2UU
<HH2:DD01b4T6<<H`bU5<JHaQR4T008ii`09BTTYAE9ZF/^DTYccaQS>FMJJ00;>F@;6>009aQS6><iI
eY[>VMJJ_ONLlf]=009Jb`0:JdekchaaYABeU[gg]IJDTUZ[:DD248803aS36:<HXa1R488@XRTUBTUc
[YBBW?>U=;FF[IFeUP02[GD2[ED01:Dd[CFU=:Dd1:DD0_oo00<00?ooool02_oo00d00?oooomkcjDD
U;:DTXaaW;><LIcCS76DLP02S5401HaaU9:4<8aaQ1000Ycc0XaA00>DTXaaU7800iBB00j<LHaAS56<
DKgGQ11[KG__[CFDTYcC]MJL/h@@0iBb00B<LIBbS764409kk`0<W=><DJfEW;>LdiBBS76<<IccS55c
cYAb0YBB00/iakggLhkNfmJjBTVeUW_?W?=kchaa00:D/P03U7:<DIbc00:D/P:<L@0AQ31cS[FfYCC6
>7>>S76]MH@`S564<9AbBTV<DG?>aQR<D@02U9806XaAU9:L/iBBS76LdibcJdfDLXaaS36<LIBBQ32D
TXaaU7:<LIAbU9:DLXaAU9:<LIBbS742ool00`00ooooo`0:ool01`00ooooog=^Hbac[V]]009[C@06
Nln<DJDd[GFe]ZeE0[FF00JU58@`F/]:BE[;Hd`2Jdd017>^JdecSV]]0V</00U[KF</DZ[oomkKeY[6
6:Dd]GH00W_?00RDTYBbQ31kchaAS764<8?`0XaA02^DTZDDLji:BCWWQ10aYSW7<JHiag>>Jfdiad7X
S55JZbUU>JN<LF<<_OMkclHhcWVmmkfg]KK5n;gg_KNmmlHh_QO66<HhcSWFV]kK<HIcSV]=NlnU5002
[GD01ZeEYEBmenLL<HHY9@<ii`8ia`09>NM2235V>LNDdYccS76]MJDd00:]M@0:[EFU=:eEYABU=:DD
[EFU59ccWA<2YA@019ccooooo`003?oo000;ool01@00ooooohA@Ljh00U[[00MBbU[;F/][CG__W=>]
E@03]KH01jfEYAAkkeZ[>NM224Y9009BRPMBZP0=BVUkcjeEiacF^/HHYAB<DG>^LhiccW__Llh00W>^
0W_?0W__01^447__JfeJbd8X@PPiabUU<FHQ123T8@@iad88>LLaYSW7>NLYACW7@NQJjg_?W=>mmlHh
cWT01LHh0/ii0mJJ00nmeicCQ31c[V]]Ljj449BBU=:]EKFf]IJDTUZ[8B@00Q2200d@XQ22488@PQ2R
6<<iif</S76LdjDd[EFeUP02[GD2[ED4YC@2YA@00iccYABLl`02ool00`00ooooo`0:ool01`00oooo
og>^YCBDTXaA00:<L@03U9:D/Xaa00><D@03U9:<LHaA00:4<004W=>U=8aAU982S74058A@S564D9BB
S96D/XA@U9;6F4Y9Nnmc[X@`Lhi[SHaAS76447?>U982S5405X@`U9:<LIcCO0n<<F</W=>D/YccNnnL
lhaa]IJLlg_?Nnn]MIdCHbbU58@@0/ii02=:JG__U99JjjDdJff4D9BBS76<DHaaU9:4D8aaU9:<LG__
F/^DT/HH[GG669BbJfekcg>^Q32DTU[;S564<=JJS96<LHaA00><L@06S56U=;FfLjj4<9cC0Xaa00J<
THaAS76DLXaaU982S742S54019BBS76<LHaa0_oo00<00?ooool02_oo00L00?oooomS;6]=Jfe[C@02
Jfd01W>>U7:U5;FF]KJeUP:]M@06YCB4<5[[BRUS36</0V]=039S;6]]Jfe[CF=<JdeSC5[[DZ[_GMJj
aSRM4g__O0n4<5[[Nln<LH@`Q11kcg`?S564D7_?U=:DTXaAQ12DTV<<>NMS36=<@RPiad88U;9cSRUU
<HI2:7_?>LLaQR4T<FK>FG_?0/Hh00FeU[Ff]KK6>;hG00?6600M_QO6><HhcUW>NMkKcUU[CHaaQ31J
jf]]U9:]EJee_MOFfS66:FDaYT88>NLaQSW7>NM::C76LjjU5002W?<01JeeYCB]EJDd[ED00ZDd00VM
4jDdW?>U59CBYABM4iccU=800_oo00<00?ooool02_oo000;ool01P00ooooohaAJheJj`9Jb`0VDZYR
k6]=Q12LdkEf]KJmekFf]IJM4h@@DZY223WWBTUBRUZ[DZYJbe:ZFZ]BRU:ZBVUBZX@`_MOW?=JJ]IJT
m8aAQ11[SG>^Nln440=kk`0NPo1kch?`Q12<DG__LjiJjf<<DXY:BD88<HHQ9244<JI2:3WW>JLYID88
<JHiibU5>LM2:7_?W=>mmlHH0/iI0/ii00CFV/iieY[FVP;F^P03g]_6>;gG00:Ld`0;Q32447>>Nln4
49Bb[EF]MIBBDZXQ10054880212R6:<YAE:ZNnnLdidC[ED2[GD2[ED01ZED[EFU=:DdYABU=0BU50;o
o`03003ooooo00[oo`08003oooooLlj]EIBBS56<L@:DTP05W;><LHaaQ32<D@02S7400haAQ324<002
W?<00iAbQ32DTP03U982S7402iBBS56<LJDdeYYJbiBbQ12LdkGFS7400ZDd00VLlh@`S76LliBbW;><
LIAbU9800XaA02V3l8aaNjnLljDDW==kciBbY?B<DF;/LjjmeicC]II[KLGh_ONL/nLLS36U55[[YAAk
[iBBW=><DIAbS76DLXaaU9:<LIBBS75Jbh@`H`b]MIbc00:]E@09W?><<G?>Q31:JH@`S57>NHaa00:<
D@07W=><LHaaQ32U=8@`Lfh00Xaa00Z4<8aaS56DLXaAS76DTYAbS76DLP:DTP03S76DLXaa00;oo`03
003ooooo00[oo`0/003oooooJdeS37>>Hda[CF^=Po2DTZDD[IFe]Zee]IJUE:DdQ31Rk4YYDZYS;6/]
JhecKV^=JdeS;6]=JfeS;5[;[GGNfmJjaSRDTV^=Y?B<LH@@F^^<<@:DTP04S764<8@`S742Q1008IBb
W;=[SHaaU99[KH@@JfdiidXY>NMBZV</F/]BZU9ZS75Jbe:::DDQ1366cWUc[[ggcWW>FKgGaSS>NLHH
aSS66003aSP05<HHcUW>NMJJga_FVU[;H^aJbe::H`b<<JDdcWWNnb44:FDiYcW7>JL2>LL01T88>LLi
ijDDW?>L/`:]E@>U500;[CFLljDdWA>U59ccYCBLljDDW?>Tm002ool00`00ooooo`0:ool000_oo`0H
003oooooQ31[KE;:F/]BZU[;F^][KG`?W?>]MKgG]MJe]ZfEYAAkke:Z>NM224980U::1E:Z011BRTYY
H`bDT/Hhg__6>:DDQ52447?>Jfe[CG>^Nnn440Ekk`0TQ124<8@`Nnmc[W>>JbeJje[;BXU2:366>NM2
B4Y9>LLYICWW@PPiib3T488Q13WWLhjDd[FfaSS>NLjIe[[>VMJJcYWF^]JJ0]Jj017NfmKJcWW66:ee
U99[KE[;H^a[KH@@W=>U=8aAF//YAARS00<@PP8@XP0;6><iif]]S76LljDD[EFUE:eEYEB]E@02YC@2
YA@01IdCYABM4jDDW?<00_oo00<00?ooool02_oo00X00?oooomcSZEDU9:<DIbcS76DTP><L@:<D@03
U9:<LHaa00:4<00DU;:U58aaU9:<LH@`S56<<HaaU;:<DIAbS56e]X@`Jff4<7_?U=:U=09c[P0WU=:D
/XaaS35kkhaaS56D/X@`W?><LIBBQ32Ldh@`Ljj<TG__S96]MJDdcUVD/XaAW?>449ccDVZ<LIBBO0nL
dlIHNlnLlg>>Q32<DH@`00:<L@05U9:<LIBBS76DLP02U9804HaaS55SC8@@LhjeU[gg]KJ]EJDdS964
<3W7LjjM4liIW?<00YBB00RD/XbAS76M4jeeLhj449Bb0XaA00fDTYBbU9:<LIBbS56DTXaaU7:<DIBB
S56DTP02ool00`00ooooo`0:ool03000oooooe[[JdecSV/]JdecSW>^S56M4`:e]P0S]IJ]MKFFWA><
<E::BVUJbf]=H`a[KF<<JdeS;6]=Jhe[CE/;FZ_W?=JJcYW668@@Ljj<LG__Jff<DG>^Q12<TIAbS964
4002S54068@`S56DdYBBF`^DLX@`Q11[SHaaQ31Jjf]=Q11BZV;/BTUkcdYY@PPj1cW7:DDQ90:]E@05
WA>U5<jIeY[6F004aSP01<iI_QO>FLIH0liI013F^]lKW?=Jbe:ZH`aJjf</Q33>FMkKF^/YICWW@PPi
a`8ii`0?<LHYAG>^YABDTYcc[EFU=9cc[EFU=9ccYABLlidC00:U5004W?>M4icCW=<2ool00`00oooo
o`0:ool000_oo`0I003oooooS35[KE[;DZYJbe:ZH`a[KH@@W=>eU[GF_MNe][FFWA>445:Z@PPiidY9
DXX00U:Z00=JZe::FZ/00U:Z011:BG>^YACNfmJjaQRLliAbQ32446]]LficSW__Q12<D@:44004Nnn4
47__S542Q30037?>Nlmc[W>^JfeRk4YY@PQ2:5:ZH`aRk09:B@92:00<:FDHha1R8@@iag>>U;:mmlIH
e[[Ff]kK1MJj0]kK0]kk00kW7<jI_ONLdh@@JfeS;6<<Ljj<LIccU99JbbUU112200lHXa22<FIBZX`a
U=:U5:Dd[EFU=:eEYCB]EJDDYC@01:DD00FLljDDooooo`0000coo`08003oooooLjjeUXaaS56<L@:D
TP0DW=>DTYAbQ32<DIBBS76<DH`aS56U59dCU9:<DIBbS76D/XaaU9:<L@:<D@0:U7;>FDYYQ124<7_?
YCBe]W__YC@2U98018aAU=:<DHaA0YBB026DLXaAU9:DTW__W?>DTYccQ124<7__JdeJZiCBQ12<DJeE
W?>]=H@`S76<DJDDU;:DT/iiQ12UE6</Q32DLW__S3400YBB01N<LHaAS76DTXaaU7:<LIBbS75[CG__
S76melHh]IJeMZeEU992:7>>Hbc>FH@`00:<D@0;U9:<DIBB_ON<DG?>W=><LH`aS76DTP02S54019Bb
U7:<LIBB0Xaa0YBB00BD/_ooool000coo`05003oooooH`aS;002Jdd03g>>JhekchaaYCB]MKfg[GFe
]ZfEYCB4<6<<@RQS3002Jdd00f</LhiS;002Jdd0=F]]HbaS35:Zmik6>;gg]KJDTXaA]IIc[W>>Nnn<
DG>^U7:D/YAbS55kkhaAU9:4<9BbS76Lle[;YCB446]]F^]JZd88YCB]MIcCNlm[KCWWQ312:4Y9@PPa
QS6V:DFDd[gg_MNU5;gge[X00/iI00G6><iIaQS66<IH00?>N@03cUWF^]JJ00;Nn`0EaQR<DE[[DZYS
37>>cWW_GB4T<FHiicW7<HHiadYY<HIJbjDdW?><LJde00:U=003YAB]EIdC00:U5004Y?BLljDDW?<3
YA@2ool00`00ooooo`0:ool000_oo`05003oooooQ31[K@03DZX045[;F^][KG__W=>]MKgG]MJmekFF
YAAkce:Z>NM224Y915::0e:Z00]BRTY9NlnU==JjcUVe]ZDDU9:4<7?>009[K@9c[P03Q124<8aA00:4
4005Nnn448@`S564D002Q1004G_?Llic[V]]HbaBRU[[Jff4<7?>H`aBRU[;D/YJbd8X@NP00SW700QJ
bh@@[GFmmliieY[F^]kK1MJj1=kk00oW7=kkcWVe]ZDDS55c[U[[Jdf4<:DdU;9Jjb444680112200PH
hdXYLhjDTYCBYABU=:eE0ZDd1:DD00FM4jDDW?>U59cc00;oo`03003ooooo00[oo`0l003oooooJff]
MIAbS76D/XaAU9:D/XaAS76<<HA@U9:<DH`aQ32449BbYAB4<8aaS56<LHaAU7:<LIBBQ52DTXaAg_/a
YYcCQ32449CBU;9[CIcCU=:4<9BBU;:<LH`aS56LdhaaW=>4<9BbS76449cCS56DdW_?0Zee02:M4lii
Jfe[;G__Q12LlkFFU9:D/ZfEaQRmmlHHcYWW77_?[EEkkiccNnn4<8aaU9:<DIAbU9:<LHaAS764D9BB
Q31kc`9[C@03LhjDT[GF00:e]P06W==Jjf</W??FVXaA0iBB01B44:DdU=9[KH@`W=><DHaaU9:<LH@`
U9:4D9BBS76DTXaAU7:4<8aa0_oo00<00?ooool02_oo00L00?oooomS36/]Hba[C@02Jfd0;F^=U9:L
djee[IFeU[Ff]IJLlh@`DZY2:6<<Hba[KF]=Hda[;F]]HbaSC6]=HbaBR^ML_ON]EJDDWA>U59cCLhik
ch@@Nnn<<G_?U9:<LIbcU;9c[XaAU9:<D@03W?<055:ZYAB<LH@@LliBRZED]KJU=8@`Lli[CKgg_MN<
LIcc_MNU=2UU[GD2S7401/jIW?>e]]JJaUS660;6>004_QO>FLHhcWT2cUT3cWT05mJjg__WG:eeQ11:
RE[[NnoW7>Ll6<<YAD88>LLaYSW7BTTj1h@@W?>Ldicc[ED00ZDd0icc00BU59dCW?>Ld`BLl`;oo`03
003ooooo00[oo`002ooo01D00?oooon<DF]]FZ]BZUZ[DZYRk6]=Q12DdZee]KJmekGF]KJM4h?`DZX0
0T8800MBJU::FZ]BZUZ[DXYJZ`02DXX02dY9NnnU==JJ_MN]MIccW=><DG__Jfd00W_?0W__00><<HaA
S5400X@@029kkh`aS56DTXaaU7:<DH`aNnmc[V</H^a[KH`aU9:DLW__LjiccW__Q11kcf^=LhiS37>>
Q12]EKFFaQS>FMJJe[[Nf`?F^P;Nf`;Nn`;W70;W?00<iacFf/HHWA>446</Jff<LJeENnlii`Q11122
00HPi36VHbb4<9cCW?<2YC@01JeEYCBU=:DDYC@01:DD00FM4jDDooooo`0000coo`07003oooooJhfe
UXaaU9800Xaa00BDTYcCS56DLP:<L@08U9:<DH@`S564<9ccYCB<D@><L@0;U9:<LIAbS76DLXaaS57O
6cW7W=>D/P02S5403XaaLhjUE9bcU9:DLYcCU9:D/X`aQ32<LIBBW;<3S7407g>^YEBLdhaAQ11kkhaa
]MIkkf<<U;9kkicC[EEJbe:ZJbec[V<<F^][CLiiS56<LIBBS76L/h@`S36<LIAb00:DTP03S76DLXaa
00FDTP0EQ31c[V</NlnU5:eEaSRLdcWW>LNmeicCQ12DTYBbS56LdiccU99k[iBb00:<D@09S76DTYBB
U;:DTXaAU9:<LIBb00>DTP;oo`03003ooooo00[oo`07003oooooH`aS;7=^Hb`00V]=02=cSXaaY?B]
EKFf]IJeMZeeYAB<DE[[BTUS36</Jde[KF]=Jfe[CF</JfeSC6</DX[_GLHHYABD/YBBS76Ldg>>Nln<
LIbc00:<D@03Q32U58aA00:DTP0<Po2DTYcCS76L/jDd]GJDTW=^NlnDLZeE0ZDD01YBZZee[EF]MJCd
]KJ]EKFFYCBe][gg[IF]EJEDYAC6>;FF[GG66<IHcUW66<HhaQS>FLIH0lii0]JJ00K>NMJJe][Nnjee
[ED2H``01YBBkgdHhbTU@PPii`8ia`04>NMBZTY9[ED2W?<01idC[CFU=:eEW?>U59cc00:U5005YCBU
5:DDW?>U5002ool00`00ooooo`0:ool000_oo`08003oooooQ31cSU::DZYBRP9BZP0>JdekkicCYEBe
][GF_MN]UIccNlmBZSWW@PQ:B@9BRP0CDZYBRU:ZDXYBZU::BTUkcjDDcUVeUYdCU;:<LH@@Jhe[KG>^
Q1000g__00>4<8aAS5400h@@00B<DHaaU;:D/P:DTP:<D@06Q11kkh@`U9:LdiBb0YBB00BLdidCYCBU
50:U=008W=>D/YBbYEB]MKFf_OO6>0;>V@?F^P03cYWF^]KJ00;Nn`0KiacO6nLlga_WG>LLcUVU=8@@
Ljj4<:eeW==S323T264HXa226:<H`bU5BVUkciBbW?>M4jeE00:U=0>U5006YCBM4jDDWA>U59dC0_oo
00<00?ooool02_oo00H00?oooomcSZeeS542S7401HaAU;:DdXaAS7400XaA01fDTXaaS564<8@@U;:U
=8@@U;:<DHaaS56DLXaAU9:<DIAbQ33W736VW=><TIccS96DTW_?U;:DTW_?00:4<006S56<LH@@S764
<9Bb0Xaa01><DHaaU99[KIBBNnnmeiccS56<LG__W=>e]YcCJffD/W__Q124D002S74058aAHdbLde[;
YCAkchaaU;:<DIBbU9:449BBS76DTXaAS76<DHaaS542S7401YBBS95kkf]=Q11kc`:me`05[GE:BLii
aSR4<002U9801iCBS36LliccLjj4<9BB00:<L@08S564D9BBS76DTXaaU7:<D@:<L@04U9;ooooo000<
ool01`00oooooe/;JdeJjf/]009S300SJhf<LIcc[EF]UKFf[IF]MIccQ11JjdY9H`aS;6=<JdeSC6/]
Hba[CF</JfeS;5Z[ga_6>:eEU9:<LH@@LlicSV<<U9:4<002S7406G>^NnnDTYBBU;:<DH@@S76LdhaA
W?>LdjDdU;:mmiCBW=>D/Zee[IFLdkFF[GF]UJDd00J]M@06YCB]EJDdYCBLlmJJ0[FF0/ii00Rn5kFf
_QO6><HHcUW>NMJJ0lii01GF^]KJW?>]EIbc_MN<DLHH_MLHhcVW>NM:JCW7@RPaYTYYQ32U=9BbW?<0
0ZDd00BU59ccYABU=0>U5004YCBM4jDdYA@2ool00`00ooooo`0:ool000_oo`06003oooooS55[KE:Z
0e::00aJZf<<NnnD/Zee]KJmekGF]IJLlg__DZX2@PP00e9ZDXYJZ`02DZX04U::FZ]BZUZ[BVV44:Dd
cWV]UIccS764<7>^JdeS;7>^Q12<D@:44005Nnn<<HaAS764<002S542U;8039cCW?>U59CBU;:DTYcc
W=>U=9cCY?BU50B]E@0>]GJ]MKFF[IFeUZfE]GJ]MKFF]KJmmlHhcWW>V@;F^P04g]_F^]kKe]X2g_/0
7^LLga_W7>LLkegNnlhiYCBDTXaAYCBUE7_?>LL@HQ2R6:<@XQRS6><iaf</S76LdjCdYAB]EJDd[CFU
50NU=0;oo`03003ooooo00[oo`08003oooooJdfeUXaaU;:DTP:D/P05W=>4<8aAS76<D@02S7404XaA
S764<9ccYAB<DHaaU7:<LIBBS76D/YBBU7:DTXaAic`ii`:DTP:D/P06U9:DLYccW;><LHaA0YBB00FU
=9BBU;:<DH@@00:Ld`04S56LliBBU=82S5407H@@LjjDLXaAYCAcSYBbQ124<9BBQ32449AbU9:<DHaa
U9:<DIbcU9:U58aaW=>4<8aAU;:<DH@`U9800YcC0YBB01><LIAbS56DLXaaU9:<LH@`W?>D/W_?Q32L
de::H`c6>8@`S75kk`02S7402IBB[EEkcg?>U7:<LHaAS76DLP02U9801haaU9:<LIBBS76DLXaa00;o
o`03003ooooo00[oo`05003oooooH^aS3002Hb`03V]=Hba[KHaAYAB]EKgG]IJe]ZeeW?>445[;BVT2
Hb`05G>>Hba[KF</Jde[KG>^Jde[KE[;mkk6>:DdU=:DTXaAJfeS37>^JffDTP02U;804HaAQ12449Bb
W=>DTXaaYAB<LJeeW?>U59cc]GJD/Zde_OL00ZDd00ne]ZDd_MNDT[ggYAB]=KFF_MNU=;FF[GFmekFf
[GD00ZeE00nLllHH_MNe][ggeY[F^/iIaSS>>LHHaSS>FLiicUT00/ii0]Jj00bLdkggS56U5;gGkgdP
i366>LLiicVW<JH2>LL025[;W?>LliBbYABU=:eEYC@2YA@2YC@2YA@00jDdYABU=002ool00`00oooo
o`0:ool000_oo`08003oooooS55cSTZ9DXY:J@9BRP0>H`akcicC[EFe][GF_MN]MIccLliBZT88@RQ:
J@=BZP0EDXYBZU:ZF/]BZU::Q12]MLii]KJLliBBNnm[KE[;F^]S;7__Q124<7__00:440:<D@:<L@:D
TP:D/P06W=>LljDDYCB]EJED0ZDd0Zee00JeUZeE]IJUE:ee[ED2]KH00kgG]KJme`02]IH01jee]KJe
][gG_OO>FLjI00;F^P04g]_Ff]KJe[X2g]/00mlKg__W7002ia`02/ii_MNUE9ccYCBe]XaADXX8HARS
0Q2R00X8HA2R8BABRW?>U;:LdjDDYCB]E@RU=004YACooooo000<ool0>P00ooooof]][IF<LIBbS56<
LIBBW=>DTX@`S764<8aaQ52<DH@`S36LdjDDQ32DTXaAU9:<LIBBS76<DHA@S764<=kk<HJDTYBbW;><
LIBBU;:DTYdCQ12<TG__Q12DTYBbS76D/X@@S76D/XaAQ32<DG__0Xaa0iBB00Z448aAS56<LIAbS56L
dg__Q12D/P:<D@0@S36DdYAbS56<LHaAU7:U58@`S56D/W__W==kkh`aQ304U982S74059BBS96DTW?>
S564<:DDNlnmef^=8@CNfiBbS96<LIcCU7:D/ZeEU;82Q1001ibcS76<LHaAU7:<LIAb00J<L@;oo`03
003ooooo00[oo`03003ooooo009S300DF`][KF</JdeSC8aAYCB]MJfE]IJ]UJeEW=>445:ZDXYS36]]
Jhe[K@A[C@0FJfecSV]=H`cg_/iIYABU=9ccS55kcf]=DXYkcg>^U9:<DIBBS76Ldg?>W;<3W=<01Ycc
Q12LdiCBW?>]U@:eUP0;YAB]UKFFW?>mmjDd[GFU59bc[EFeUP02]KH04;hG_MN]MJee[IFeUZfE_MND
TYAbcYVe][hGcUWF^/jI0/Hh01:mmliIcUW>NLIHcWW>VMJj]IJLdkGFNnn]MMJJ8@@Q9498BRT2<HH2
>LL01E:ZNnnU59bcW=<00jDd00VU5:DdWA>]EJDDYCBLljDDWA<00_oo00<00?ooool02_oo000;ool0
1@00ooooohaAJfd015::01ABZV<<NlnD/Zee]KJmmkFf]IJLdg_?DZY::D8XDXYBZU[;DZYJZe:Z0e[;
00eBRXaA[GGF^[FfYABDTX@@JdeJje[;HbacSP02Q10018`aQ32<<HaA0Xaa00ZL/iBBW=>D/YcCW?>U
5:Dd[EF]M@>eUP04[IFe][FF]IH2[GD02:fE]IJe][gG_OO5n;hG_OL2_ML00kGF_MNe]P02_OL01Lii
cYWNnmKJg_/00]kK01?Ff]kkg__W7=kkiacW?=kkcUVe]ZDd[GG66:eEJddY9A224:8@HP0248801QSS
<JIS38@@W=>Ll`:U=005[EFU=:eEYCB]E@02YC@01JDDYCCooooo00003?oo00P00?oooom[CKFFS76L
/haa0YBB00>LlhaAS3400XaA00FDTXaaS56<DH@`00:Ll`06S56<LH`aS56DLXaa0YBB0Xaa00J<DMkk
<FJDTXaaS542Q100@9AbU;:U59ccQ32D/X@@S76<DHaaW;>DTX@@U99kkiccU;:LlibcU9:<<H@`S56<
LIBBS76DTXaAQ32Llh@`Q12]EHaaW;>449bcNnnD/XaaW;><LIAbW=>U=:eES56D/X@@U;:448aAU7:D
TYcCS76DTXaaU9:<LIAbNnnU58aA0ZDD00BeUU[[e[[>F@:4400<U;:DTYBBU;:DTX@@Njn<DIBBS56D
LXaa0YBB00BDLXaAU7:<L@:DTP;oo`03003ooooo00[oo`05003oooooH^aS;002Jdd047=^Jde[KH@`
W?>]MKgG[IFe]ZeeW==kke[[DXY[KF</0V]]00][CF]]Jde[CG>>Jfe[CF</mijmmjeE00:DTP0KQ11c
SV]]Jfec[XaAHbbDTXaAU9:D/YcCNnnLliBBYCB<LIccW=>]MKFFW=>]MKFf[EF]MJeE00:e]P0LYCBL
lkgG[EFmejDd_ONe]/HH]KK66;hG_MNee[gG_OO66;Ff[EFUE=kK]IK>FLHheY[>VLiicUT2cWT06LiI
cWW>NLiieYZ]EJDDaSS5n=kKeYXQ13W7<JHiYcW7>NLiacWW@PRDLZDdW=>U5:Dd00:]E@05YAB]EJDD
YCBLl`03YA@2ool00`00ooooo`0:ool000_oo`0K003oooooQ51cSU::DZYBRU:ZDXYS37>^U;:UE;Ff
]MJmejeeW==c[U:Z@PQ::DYYFZ]BZUZ[00=BZP0;F/]BbU:ZQ32]MLii]IJLdhaaLli[C@02F//035[[
Jdec[W__Q12<DH@`S76<DIBBU;:Ld`>D/P08W?>U=:ee[EFeUZfE]KJ]U@>e]P05]IJe]Zee]KJeUP02
_OL00lHhaQS6>002aQP02kggaQRmekgG]KJmekggaSS>VMJje]X00]kK1]kk00[W7=kke[[66;gG_OO>
NLHhQ30ii`<@PP07264@PQ2R8@A226]]S7400Ycc0ZDd00>]EJDd[ED00ZDd0ZDD00BM4oooool000co
o`07003oooooLhj]MIBBS7400XaA00><LICBU9800XaA00B4<8aaQ52<<@:<D@0BU=:Ldh@`S56<LHaA
U9:<LHaAU9:4<8aaS57Nfc66S76DTXaA0Xaa01>DTXaAS96<LH@`W=>D/XaAS95kkidCQ32LlhaAU9:4
<9cCS564<002U9800iccNnnLd`03S7401haAU=:Ldh@`S36DTXaa00:DTP><L@:<D@0<S764<8@@Nnn<
LHA@U;:449BBQ32Ldg`?0XaA00J<LIBBS56<LIBBS542Q3003iccU9:D/XaABVUBZ[ggS76DTYBbS76<
DIccU;:eUP02Nnl2S743S5401iBBS56DTXaaU9:<LIBB00;oo`03003ooooo00[oo`06003oooooH`aS
;6]]0V</03a[CF]]S36Ldjee[IFeUZfE[GFD/W__F/]:JE[;JfeS;6]]H`a[KF=<H`a[KG>>HdaS3>Ll
_MN<LIBBNlmc[V=<LjicSU[;Q124<7>^S56DTYbcNnn]MH@@YCBD/ZeEQ52LlkgG]KJ]EIcC_ON]MJeE
]IJe]ZeE]MH2]KH00kFF[IG>F@02_OL01KFF_OO6><Hh_OL00[gG00V]MKFf_ONUE:eeU;;66<jI]IH0
0/iI0]Jj01c66<iicUW6><IHcWW>VMJj[GGFV]KJiacO6b44:FDiYc6V@PPiac6V>PLYIF]=YCBD/YcC
YAB]E@:Ll`05[EFU5:DDW?>M4`02YA@2ool00`00ooooo`0:ool000_oo`0E003oooooS55[SE[;DZYJ
be:ZF/]S37_?U9:]EKFf_ONee[FFU=9k[e::0092:003DVYBRU:Z009BZP0ADXYJZe:ZF/]BZX@`[EG>
FJeEU99kkg>>HbaS35[[JbeSC002Ljh01X@@Q32DLXaaU9:<L@:D/P>Ll`03YCB]MKFF00:e]P04_KNe
][gG]KH5_ML00kggaOS66002aSP2cUT01LiicUW>FLHhcST00/Hh0[gg00Zn5liIcWWNfmKJiacNnnLL
ga_W70?Nn`0;iacNnmJJcWWFV^LLkgfU=5[;264@HP0248804Q1R488@PS5VDZZ449BbW?>U5:eEYCB]
EJDd[EFU5:DdYABU=0;oo`03003ooooo00[oo`0=003oooooJdfeMXaaU7:D/YBBU;:LlhaaU78018aa
00^4<8aaS56U59dCU9:<DIBBQ32LdhaA00:DTP><L@0MeYY::IBBW=>D/YbcU9:LdhaaW;>U58aAW=>4
<9ccQ12DTYAbU;:3l9cCNlnDdXaaW?=kkh@`W;>D/P02S7400iBBS76DTP02S5406IBBQ11kkiccQ32D
LW__W;><LIbcS56DLYBbU9:LliBbS76LljDdYABLdh`aW=><LIBB00:<D@0OW;><LIBbU9:D/XaaQ124
<9ccNnnDTW__<HK_GIBBS76DTX@`U7:DTYBb[IFD/W?>S76D/YAbS56DTYBbS5400Xaa00>DTYAbS740
0_oo00<00?ooool02_oo00<00?ooool00V</00QcSV=<Njm[CG>>S56U5:eE0[Ff00ZeUZeEW?=kke[;
DXYS36</H`a[K@=[C@0:Hba[CF]]LjiS;=JJcUVU57__Lfh2Ljh03F]]Nlmkkg__Q12DLV]]U;:DTZCd
U9:]EG>^00:Ld`08aQRD/ZeEYCC66;gg[GF]U@:me`0B[EFe][gG[GG66;FfaQRe][gg_MO>FLHhaQRm
mliI_OO>>KgG0[gg0/HH00^eU[ggaOS>FMJj_OO6><iieY[>VLii00;>F@0<cWWFV/iicUW>NMkKga__
GB44:DDiicVW0SW700`aYT7XBTUBZXaAYCBD/ZDDYCB]EJDDYC@2YA@019ccYCBLljDD0_oo00<00?oo
ool02_oo000;ool01@00oooooh@`Lhh01E:Z00iS;7?>U;:U=;Ff]MJmejeeW==c[U:Z@PQ2:4Y90U::
00EBZU::DZYBRUZ[009Jb`06LjjLlkFfYCB447>>0V</0f<<00I[CF^=LjiccX@@S542U98029cCS96L
/iCBYCBU5:Dd[ED2]KH01[gG]KJe][Ff_MNeeP:mm`04aQRmmlHHaQP3aSP00lIHcWW>N@03cWT04<Hh
cUW6><iI_OO66<HhcUW6F<iie[[NnmkKiacNnnLL0mkk00_W?=kkg__NnnmMmijmef]=8>@8HA2R008@
PP0<264@PQSS@PQ[CHaAU=:LljDD[EFU=:eE0ZDd0ZDD00BM4oooool000coo`0G003oooooLhj]EIBB
Q52DLX@@U9:D/XaAQ52<DHA@S56<LH`aQ52<LICBW?><D@02U9801HaAU9:<DHbAU;800Xaa00N4<;Ff
H`aS39BbS76Ld`02S7400iAbQ12DTP02Q1002XbAU9:DTW__U;9kkiccS76]MG>^0XaA01FD/XaaNnn<
DH@`S36<LH@@S76D/XA@U;:4<8aAS96<LHaAW;>4<8`aQ3000XaA03><LH@`U9:<LH@`S56449CBU99c
[YBBLjj<<IBbQ12DTX@`S76DTXaaU7:<LH@@U=:<DHaaS55:BMkK]KJ<LIBbS76DTYBbQ32LdhaaQ11c
cYBBS76<<HaaU9:<DIBbS76DTXaAU9800_oo00<00?ooool02_oo00`00?oooomS;6]=Hba[CF]]Jde[
KHaAW?<2[GD03[FF[IFeUYcCQ11K2e:ZH`aS;6^=JdeS;6]]Hb`2Jfd01g>>Jfe[CG?>g]^D/X@@009S
;09c[P09JfecSW>^Q11c[X@`NlnLdiBb00:Ld`0>]IIccZDdW?>e]YCB]IJ]MJeEYCBe]YBb]KJeUP:e
]P07_ONe][FFaSS66:ED_ML00[gg00Ree[gG_QO>FLHHcUVee/Hh0/HH00^mmlHHaSR<LIcceYZmmlii
_OONfljI00?>N@05cUWFV/iicWWF^P02ga/04Haa8BA223WW@PPaYSWW<JHiid8XH^bLlicCU;:U=9dC
[ED00ZDd00FM4jDDWA>U59CB00;oo`03003ooooo00[oo`002ooo01D00?oooon<DG>>F/]BZU[;DZYJ
bf</NnnDTZeE]IJmekGF]IJLdg_?DZX00T8X011BJU::FZ]BZUZ[DZYJZe:ZF^]Jbf]=U9:]MJDdPo1[
C@AS300=Jbe[CG>>Lhic[W?>S36<LIcCU=:LdhaaW?<00ZDD00J]EJee]KJmekGF_OL2_ML00kFf_MNm
m`04aQP02LiIaUS>NLiIeY[>NMJJcYWF^P02eYX03<jIeY[FV]JJcWWF^/iIaQRe]/HHeY[Nf`;Nn`03
iacW?>LL00?W7007ga_W?>mmmkkFVX`a>LL00a2R00h@PQ1R488H`bU5DXYccYBbW=>U5:Dd[EFUE:eE
0ZDd0ZDD0_oo00<00?ooool02_oo00`00?oooomcS[FFS76DTYBbS56DdYccS742S54028aaS56DLX@@
S564<9cCU;82S5401haaS56L/haAU9:<LIAb00:<L@07]IJ]EE:ZW=>DTZCdU;800Xaa00>D/XaaY?@0
0XaA01jLlh@`S764<9BbNlnD/X`aYCAc[YcCU9:DdYAbW=>LlhaaYABDTXaaU9:<<HaaU9:<LIAbS56D
LYccW=<3U;801IBBS76<DIBBU;800YBB016<LIcCU9:<DKFfU9:<DH`aQ12Ldh@`S56<LIBBS76DTXaA
00>DTP09S75JZh@`aQR4<8aaS56DLXaa00:DTP05W=>DdW>^Q32D/P05S74019BBS76<LIBB0_oo00<0
0?ooool02_oo00l00?oooomS;6]]Lhi[CG>>JdecSXaAW?>U=:eE[GD00[FF00RLdg__F/]:JF;/Hba[
KF]=0f]]00YS;7=^Lhikcg>>JbgNniAbLjicSP=[K@03Njmkcf]=00:<D@0OJff3l7>^U;:LljeEU;:U
57>^]GJU5;fg_MNm]icc_KO>NKFFW?>mekFFcSVeeZeeaQReU/HhcUWFV[ggaQP00/Hh00_66<IHcUW6
><iicUW>NLHhcWWFV]kK00:D/P08Q3366=lK]KJmemJJe][F^P;>N@0:cYWFV]JJg]_NnnLLe[XQ13W7
BTT2>LL0336V>JLaYSW7<HJ44:DdW=>DdZeEYCB]E@>U5003YCBLljDD00;oo`03003ooooo00[oo`00
2ooo00L00?oooon4<7>>DZYJb`03DZX016<<LjjDTZDd0[FF00Re]ZeeW==c[U:Z@PQ2:4YY0U:Z01aJ
Ze:ZF/]BZU[;F^]S35[[S76LljeELliS35[;F^]S36</H`a[CF]]LjicSW>^Llj4<8aaW?>Ld`:D/P04
YABLljee]IH2]KH01[gG]MJmekGF]KJme`;660?6>00KcUW>NLjIeY[>VLiicUW>NMJjg]_F^]kKe[[F
f]Jjg]_Ff/Hh[GFU5:eE_MO66=Jjg]_W7=lK00?W?00Hga_W?>LlkgggW^mmW?=BRQ226:<@XQ22264@
HQ226<<YIE[;Q12LdiccYABU=:eE0ZDd00>U5:DdWA<00_oo00<00?ooool02_oo00D00?oooomcSZED
00:<D@04S764<9AbU;82S543S7406haAQ12<DHaaW?>U58bAU;:<DIAbS76<DHaaW;><LIBBQ52D//iI
@PRU59cCS76DTXaAW=>4<002U;804h@`U9:D/ZDDS76<TH@@Q3244:DdU;:DdX@`S75kkhaaW=>4<7_?
00:DTP06U;:<LHA@U9:D/Ybc0YBb00R4<8aaQ12<LH@`U9:4<8aA0haa0XaA00ZDLXaaNnm[SIccYABL
dg`?Nln<L@:DTP04S564<9BBU982S7402IAbS56<LF^=BTWFfXaAQ32<L@03U982U;801ZeeQ31cSXaA
U;:4D0:<D@05S76DTXaaS56DTP02ool00`00ooooo`0:ool01000oooooe[[0V</015[KF=<HbaS38aA
W?>]EJee[EFU=:eEU;9kke[;FZ]Jjf]=009[K@04HbacSV^=Jdd2Ljh03G?>Nlm[CNMLYCAcSV<<Hbac
[W>>O0m[KG__00:4<00;S55kkg__Jdf<<IdCYCBDTYccW=>eUP02]KH02jee]KJmmjeE]IJmmjeE_ONm
ekgg_QL00/HH00S>NLHhcUWFV/iIYCB]EKgg1Lii00G6><iie[[NfjDd00>Ld`06S75kcliIicbn5lHH
0]KJ00g>NMJJcUW>VMJJg__O6nLl6><YACW7>NLj1`02<JH03SW7>NLYAC6VW=>M4iBBYABU=9dCYCBL
ljDdYA@2W?<2ool00`00ooooo`0:ool000_oo`08003oooooS55[KEZ[DZYJb`9BZP0?F^]kciBBYCB]
MKFf]IJ]MIBbLjiBRT88@RQBJU:Z009Jb`04F^]Jbe[[F^/2Hb`036<<S76U=:eENnmS36;/F^][;F</
Jde[K@9c[P0<Nlmc[W_?Nln<<IBBY?BDdYccWA>U5:ee0[gG0[gg0lHH0[gg00_66<hiaSS>NLiIeY[F
^]kke][NnmJJ00;>N@0<e[[Nnmkkg__W7=kkiccW7=Jj_ON]=IcC0ZDD00V]=JED_OO>VMkkga_W?>ML
ked00^Ll017_GONnmkj]EE[[488@XQS3488@HPQQ488@HQS3>LM[KHaa00:Ll`03[CFU=:eE00:U=0:U
50;oo`03003ooooo00[oo`06003oooooJffeUXaa0iBB00>D/ZDdS5400XaA0Xaa00ND/XaAS56<DIcC
U;:DLP02S5401HaaU;:<DIAbS7400haA00b4<=JJ:FFL/iccY?BD/YAbS76<DIBBW=<2Q3003YBBS76L
ljDDW?>3l9BBNnn]EHaAQ32L/h@`U;85U982S7404IAbQ12D/YBBQ12D/XaAU9:<<HaaS56DdZDDNnnD
LXaAS7400iBB016<<G_?U9:D/XaAW?>U59BBNjm[KF]=S76DTW__U9:<LIBb00:DTP04S76<<BU5mih2
U9801XaaS56<LIBBS56<L@:]E@0;NlmkkiBbU9:<DIAbS76D/XaaU7:DTP02ool00`00ooooo`0:ool0
1@00ooooof;/H``00V]]00M[CF=<Hbb4<9ccYEBeUP02[GD01jDdY?Akce[;DXYJjf]=009[K@0=Lhic
[W>>JfecSW>^NlmccV]]kgfe]W>>Jdd00g>>016447__Q12448@`NnnDLYBbS55cSX`aW=>meiBbYAC6
>:DD00:me`:mm`0X_MO5n;Ff_ONmekEfaQRmmlIHcUW6><iIaUS6><jIaSS66:DdcYW>FLiieY[>NMJj
e][NflHHQ12D/ZCdYABLdh@`DXYJbmkkaSR]EMKJg_/2e[X02/iieY[Ff^LLic`HXbU5@NQ2:3WW0S66
00/iacWW>LLY9F</[EFLliBBYCB]EJDD00:U=003YABLljDD00;oo`03003ooooo00[oo`002ooo00H0
0?oooon4<6]]BVT2DXX045:ZBVUJjg>>U9:U=:ee[IFeUZDdU99[SE::>NM2:4YY0U:Z0U[;02aJje[;
H`aS36/]H`bDLZED[GEkke[[F/]S36</JbeSC7>>Ljikcg>^NnmccW_?Ljj449BBW?>U=:ee[EFeU[Ff
_MNmmlHH_QO66;hGaSS66<HhaQS6><iI0]Jj00?NfmKJg]/00]kK017>VMJje[[O6mkkiacO6nLlga_F
^[GFYCBLljDDW?>D/XaA00:4400CW?>n5mJjg__W?>MLkegW?>mMkggogjeEF^/8HA224:8@PPQQ4680
0Q2200L8HB44BVUkkiBbW?>M4`03YC@00jDDYCBM4`02ool00`00ooooo`0:ool01P00ooooof]][GFD
TP:<D@:<L@0=YAB<DHaAS564<8aaS56<<H@@S56DdYcCS7400XaA00F<LHaAS564D9Bb00:<L@:<D@04
aUPiig_?YC@2S7402hA@U9:448aaQ52DTXaAU;:4<7>>U=800YBB00F<DG__U9:D/X@@00:<L@0:Q32<
DH@@S76<DIAbS96DTXaaU;83S54029BBS76<LIBbS764<9ccYA@3U9805XaAU7:<DG_?Ljj449ccW=><
LIAbQ32eUZfEYCAkkf]=Q32U57?>S56DTYBb0YBB01><DBU5mkjDTX@`S764D9cCS96DTX@`W=>]MIbc
Jff<LIBBU7:4<004S74019BBooooo`003?oo00<00?ooool00U[;00QS36]=Hba[KF<<S56LdjeE0Zee
00Z]EJDDU99c[U:ZBVUJbf/]Hda[C@E[K@0>NlmcSW>>LhkFf/HhHbaJjf]]Llikcf</Ljj440:4<00>
Lhj4<9cCLjj<DG?>NlnU=;gG[GF]EJee[EFme`:e]P08_ONee[ggaSRmekggYCBmm`?>N@0NaSS66<jI
cWW>VMJJcYWFf/iIcWW>VLiie[[NnjDdJff<LJDDWA>U5:DdW==[SBU56<?66>LlU;;>VNLL0]Jj00c>
VMJJg___GA22:BDiicW7>NLiYcWW>LL3>NL02C6VS96U=9BbW=>UE:DDW?>U=002YA@019dCooooo`00
3?oo000;ool01@00ooooohaAJdd01E::01=Jjg>^U9:]=Jee]IJ]MJdeU99cSTYY@NPiidY9DXYJZe[;
F^]Jb`02F^/016<<HbaS;8@@0ZDd00B4<5[[H^aS309S;004JdecSW_?Ljh2Nll01h@@Nlmkcg>^Q12D
TZeE00Fe]P04aOS66<HHaSP2cUT01liiaUS>FLHhcWWF^]kK00;Nn`03g]_Nnmkk00;Nf`0;g__O6nLl
icc_GNmme[Ze]YbcU;:Ll`02YA@02YcCS55S34YYF/^<<KFFeY[O6nmM0nmm00[gW_ON[GEJja1R4:8H
`a2R488@HP<@PP0:4:8iaf</S56D/YccYAB]EJDd[CD2YC@2ool00`00ooooo`0:ool02`00ooooof]=
]KJD/YBBS76DLXaAYA@00haA0Xaa01^DLXaAS56<LIccU;:DTX@`U7:<DIBBS56DTXaaU7:<LIBBS56m
]e:ZH`beUZDdS76DLXaaW=<00YBB0XaA01>U=8`aS56DLYCBU9:Llh@@NlnDTX@`Y?BDTX@`U;:<DIBB
U7:<L@02S540;iccU;:L/iBbS564<9AbU9:D/YBBQ32449AbLljD/XaaU9:DdYAbH`be]YBB[EF449BB
S564<7?>W;?NfjeeLli[KG__YAB448aAU9:L/iBbU78Q1?oOU9:D/XaaU;8018aa00F<DIccYCB446^=
00:DTP06S36<LIBBS56DTXaa0_oo00<00?ooool02_oo00P00?oooomJbe[[JdeS;6]=0V<<00n44:DD
[EFeMZeE[CFU=9BbLjiJbdYYDXYS36</Jdd00V]]00A[CF]]Lji[C@9kc`05Lhj4<=JJLhi[;@02Lhh3
Ljh05W__S56DTW_?S75cSYAbQ32<DF]]Jdfe]/Gh]KJ]EJDDcSVUE;gg[IG66<IH0/Hh00BmelIHcUVe
eP?>N@03eY[>FLii00;6>00<cWW>VMJJeY[F^/jIiccO6cVWLjjD/ZeE0jDD00ZLdg__@PPQ91SSS37W
G;gGcYWW70?Nn`;W700=6<<Q9488BTU223W7>NLiacWW>LM2:36VDXX00Ycc00><LJdeYA@00ZDd00>U
5:DdYC@00_oo00<00?ooool02_oo000;ool01@00oooooh@`Jdd014YY00E:BE[;JhfDTZDD00>]M@07
YABDLV]]BVTiacWW@RP00U::00AJZe:ZF/]Jb`9Jj`9S3006LjjDdYccQ31S35[;0V<<0V</00McSW?>
Nnmkcg__Nlmkk`02Nll01G>^Q12DdZee[ED00[Ff0[gg00S66;ggaSS>FLjIcWW>VLiI0/ii0]KJ00SN
nmkKga_O6nLLga_W7=lK0^Ll01CWG>mmicbe]XaALljDTYccYABM4iccS75S;366:BE227>>YAC>FNLl
0^mm00Kg__ONomnU=5[;24424:8011S3488@PQ220Q2R00PHXb44BTUc[YBBU=:LljDD1:Dd0_oo00<0
0?ooool02_oo00/00?oooom[CJfEU9:4D8aaS56<LJDD00:<D@05S36<DHaaS76<<@02S5400iBbW?>D
TP02U984S7400iBBS76DTP02S5401JeeYAA:JJeeU=800haa01>DTYAbS96<DH@@W=><TIBBW=>448aa
[GFDdXaAJff<LIBBW?><L@02U9802YBbS76<DHaAS764D9BBQ32<DIBb0XaA01b4<8aaS76DTYcCU;:D
TXaaU7:<DIBBF^]kckgg[EF4<8aAQ52DTXA@Q11kkicccYV]EG>>Q31Jb`:<L@0EQ32<DIBbO0laQ^ML
U9:4D8@@Q52DTXaaU9:<TIBBS56]EIccNlmkkicC00:<D@04S76DTXaaU782ool00`00ooooo`0:ool0
1`00oooooe[;H^aK2f<<009Jj`0=F/^<DIcC[EFUE:eEYCB]EHaaNnmBRTY9DZX00V</01IcSV</JdeS
C6]]Jhec[V^=Lhi[SG>>g]]kke[;LhiccW>>Nlmkkg?>S564<0:<L@0?S55kkhaaU9:447__JdfU=:ee
aSS>FJee_MNeU[gg00;6>00:_MO>NLHhaSS>NLHhaURmmlIHeYX2e[X2cWT2cYT03=JjcWW>VMkkieaS
;498Q32LljDDWA>Ll`:Ld`0;LjiBJRUU:FDQ93WWga_Nfkggg__W?002ked05;gg6<<YAC6VBTTaaSWW
>LM2236V@NPiidXY:FEc[ZDdU;:<LJDdYE@2YC@01JDDWA?ooooo00003?oo000;ool01P00ooooohaA
JdeBJP9:B@0B@RQ:BE:ZLjjDTZeE[GFeUZeeYCBDTW>>BVTiicW7BRU:JE::0e:Z00AJbe[[H`aS309S
;00BU9:D/YBBH`aRk6<<JbeSC6]=Jfek[g_?Q11kkh@@Nnn4<7__0W_?00J<<IcCW=>]EKgG_QL2aSP0
1<hiaSS>NLii0]Jj00GNfmJjg]_Ff]kK00;Nn`03ga_W?>LL00;W70;W?00?keg_OONncYVL/f]=LhjD
TZCdWA>U59ccU79[KD7X008HX`05<HIS39cceY[_O@02mih01_ooga^DTSWW468@PP8H``0A6:<@XQRS
4:8H`a2R6<<YAEZ[NnnD/YCBYABU=:eEYCB]E@02ool00`00ooooo`0:ool01@00ooooof]=]KH00Xaa
0iBB00ZU=8aAS76<LIBBS76DTX@@U7:<D@:Ll`0:W;>4<9AbQ32DTXaaU;:<LIAbS742U9805IcC_OLa
Q[FFYAB<DIBBQ32DLXaAU7:<DH@`U9:449ccU7:DTXaAS76]E@02W=<06G_?Q11kkhaAWA><LHaAU9:4
49BbS56D/XaAS76<DIbcS56LdiBBS764<8aAS76DTXaA00:DTP06U;:<LF;/[GG>FG__0XaA02BDTXaa
U9:448`aU;:LlkFF_OND/YAbDZZDTYBbQ11kke::F^_5n8aaW;>4<9bcU9:DLXaaU7:DTX`aS76]EH@@
Lhj<LIBBS742S5401IBBS77ooooo00003?oo00<00?ooool00U[;01AS;5[;F^]Jjf</S56U5:ee]IJ]
EJDdYEBL/g__F^]:JE[;Hba[;F=<0f]=00a[SG>>Lhic[W>>NlmcS^mMNnm[CF]]Jdd2Nnl04g>^Nlmc
SX@`S76DTXaAW=>DTX`aU;:<LH@@LhjDdZDDaUS6>;GF00;>N@09W?>n5liIcUWFV/jIaSS6F=JJ00;>
F@07aSSFV/iieY[>VMJJe]X00]JJ00[NnnMLic`Q15:ZS56U59ccYABLl`:Ld`03Po1BRS66008aYP0>
8B@aI]lKkgg6>=JJg]_W724T8>@YAC6V@RQ2208ii`0<>LM2:3WW@PPaYRUU>NN<LIdCW=>DTZde0jDd
00B]=Oooool000coo`002ooo00D00?oooon4D6]=009:B@07@TQ::D8XF/]cSYBBYC@00jee00BU59BB
JfeBRP8ii`03@RQBJU::009BZP04F/]BbV;/F`/2H``01V</Q12DLXaAJdeJb`9S3006JdeSC6]]Lhik
cg__0X@@00B<<H@`Q324409kk`06Q11kkiAbYEBmmliI0/ii013>FLIHcUW>VMJje][NnmKJg__Ff]kk
g]_W7=lKiccO6`;W?00;keg_OONnkife]W?>F/]c[YBBW?>U5002W?<018aaJfdj1b3T0PQ101TQ96<<
WA?>NMkKiacO6kggLlhaQPQ1488@XQS34:8HXa2R6:<@XQRS488H`c6VHbb4<002U;8019ccYCB]EJDd
0_oo00<00?ooool02_oo00`00?oooom[CKFFU;:<LIbcU9:D/YccQ103Q3002XaaS96448aAQ32D/Ycc
S56DLXaa1IBB016<LIBBS96DTXaAYCA2:8@@[EF<LHbAS56<LIBBU=:LdiBB00:<D@07S764<8aAS76<
DH@@YA@00iBB00YcSYBBS564<8aAW?><LIBbQ124<0:<L@0BU7:<TH`aU9:<LIBbU9:<LIBBQ32DTXaA
U;:<LG>^DZ[NnjeE0X@`00BDLXaaU9:<L@:4400CU9:LdiBBU;;F^YdCJdeS;7_?Nnn4<6]]YCCW?9BB
U;:<<HaAU9800haa00V<DHbAU9:]MIccQ11cSXaaU9800haA00BDL_ooool000coo`06003oooooF/]J
jf=<0V</00ERk6<<S56LljDd00:]E@06YEB]EIBBNnmJjdYY0V<<00ASC6]=JfecSP9[K@9c[P0KLlik
cg_?LhiccZeeF^][KG>>Nlm[CG_?Nnn447`?Q32449BBU=:DTX@`U9:D/YAbNlmcSV]]00;66006eYZn
5kgG_OO66:eE0/ii03C66<IHe[[>NLHhcWWF^/jIcUW6><iIe[[FV]Jjg]_O6nmMU=8aYV<<U7:LljDD
W?>U59ccU;9kke::<JHaQS6V<HI226</U;;6>;ggS36Ldh@`6><aIS6V>NM2:3W7>NM22376@NPaYP8i
i`04<HHiiiccW?<2S743YC@01:DDooooo`003?oo000;ool05@00ooooohaAJde:JDY9BVU2:4Y9F/]k
[iBBYCB]MKEf[GFU=9BBLhiBRP02@PP024Y9BVUBZU:ZF/]BZU[;F^/2Hb`00f]=Hbakc`02S5409G>>
H^aS36/]Hda[CF]]Lhic[W__Q12<DHaaS564<8aAS76447_?NnmkciBBYEC66<iieY[>FLiicUWF^]JJ
g]_Ff^LLga_W7=kk00;W70CW?0;_G@0Gmikg_]kKU;9Rk5::NlnDTZCdW?>U59ccU99[KD8X6><@HPQ1
6:=227__[GG5n002_OL01IccLhhaYQ2R26400Q2R014H`a2R6<<@XQRS488@XQ228>A226]]S56DTYBb
YABU=:eE00;oo`03003ooooo00[oo`07003oooooHbbe]XaaS3400XaA00BDTZDDS56DLP:<L@03S56D
LX@@00:<D@:Ld`:<L@0NU9:<DHaaQ32DTXaAU7:<DHaaS56<LKFfU79c[[FFS76D/XaAW=><LH`aS76D
LXaAW;><LH`aQ32U58@@0XaA00jU=:DD[GF447_?Nnn<LHaAW?><DJDDS56DTXaA0YBB00B<DHaaU9:D
TP:<D@05W;>D/YBBS76DLP02S5406E::Q13669BBQ32<DHaaU7:<LIAbQ32<<IBBW?><LIBBWA?>NIcc
YCB4<8aA[EEk[icC00:U=003U9:<DHaA00JDTP09S76DLZeEY?Akkg_?U;:L/haA00:<L@;oo`03003o
oooo00[oo`0E003oooooDZYJbf</H`a[;F<<Jff<LJCdYAB]EJDdYABU=9BbLliJbe::009S;09[C@03
Lfi[KF]=009[K@03Ljj447__009kc`04Ljk6>6/]Jfd2Nll077>^Nnn447>^Q32<DH@@U9:LdiCBNlnD
/ZDdU;:447__U99kkjeE_OO5n;ggaQS6><iiaSR]MLiI0]Jj00?>NMJJcUT00]Jj0]JJ00_>VMJJcWWN
fmkkg]_FfRTU@PQ[CHaa00>U5005WA>Tm9BbQ11BRP02<HH0136V>LM[KHaa0YBb0XaA00JDTZDDJfdY
ICVW<HH2@PP00d8X@PQ1j002>NL033W7BTTaYSVWF^^LdiBbS56LdjeEYEB]E@;oo`03003ooooo00[o
o`002ooo00L00?oooon<DF]=BTU:J@03BTT015[[LjjDTZDD0jee00BU59BBJheBRP922009BTUBRU:Z
F/]BbU[;DZYJjf<<009[C@03Jfe[CH@@009kc`05F^]S;6</JdeSC002Jfd01W>>Ljj448@`S764D0:<
D@0FU9:4<7__Nnmkch@`U;:UE;ggaUSFV/jIeY[>VMJJe[[NfmkkiccO6nLLga/4ic`2ie`05nmmmikW
7:eEJfe:BE[;NlnDTYccYABM4iccS75[KD888>@8@A228BA:BF^=U9800Ycc00FDdYbcQ11BZR440088
H@8@XP036<<@XQRS00@@PP094:8Y9DYYLjj4D9BBU=:U=:ED00;oo`03003ooooo00[oo`0J003ooooo
Jdfe]YBbS76DTXaAU9:D/X@`Q52DTXaAU;:DTXaAS76DLYBbYAB449BBS56DTP:<L@05S96D/XaaU7:<
D@02S7405IBbU=9BRYdCU7:<LH@`U9:<LHaAU9:<DH`aU9:DLX@@S76LlhaANnn44002U9803:DDU7:D
/XaANnnD/XbAQ12DTXaAW?>D/PB<D@03U9:<LHaA00:<D@0QU9:<LIcCS76D/U[;Q12]EKggU9:<DH@`
S56<LIAbQ32<<G__U;:DdYBbW=>U58aaU7:DTYcCU=:]EH@`Lhj4<:Dd00:DTPB<D@0<S96<DHaaU;9k
kicCYEBDTW__Q32DdYAb0XaA0_oo00<00?ooool02_oo00h00?oooomBZU[;H`aS;5[;F^][CHaaW?>U
=:fE0Zee00RU58aaNnmS;4Y9F^]S;6]=0V]]00AcSV]=Jbe[K@9c[P9kk`0ZQ11kch@`Nlmc[V]]Q11c
[W_?Llic[V^=Nnn4D8aaU9:<LHbAW=><LHaAQ32DTYBbW==l3h@@cUW>NLiIeYZmelHHaUSFV/iIcWWF
^/HhcYWFV/jI1=Jj00CFf]Jjg]_W?08aYP05FZ]c[XaaW?>U5002W?<03jDDU;9kce9Z<JHYAC66JffD
/YccWA>D/XaAU9:D/P02W?<033668B@aQSW7@RPaYSWW<JI223WW<FI220<ii`07LhjLliBbU;:Lljee
[ED00_oo00<00?ooool02_oo000;ool01@00ooooohaaJdd00TY901Y:JDY9BVUJbg_?U9:U=:ee]IJ]
EJDDS75c[U::@RQ2259ZDXYJZe:ZF/]BZU[;F^]S;6=<0V]]00IcSW_?NnmccV]=Hb`2Jdd01V]]Jdec
KV^=Njmkk`:4<006S36<DIAbS76<DH@@0X@`0Xaa00RLdjDdaOS>NMkKe][NnmJj0]kK00CW7=lKiacO
6`;W700KkegWG>mmkeg_ONnMicbeeW^_BTU2:6<<Q12DTZCdWA>U59ccU99[KD886<<@HQS3@PQS;8@`
00:DTP09S76DTYBbU;9c[T8X6:<8HA2200<H``0>4:8HXa226:<@PQRS6<<aYU[;Nnn<LIcCYAB]E@;o
o`03003ooooo00[oo`06003oooooH`bm]iBB0Xaa00>DTYBbW=<00XaA00n<LHaAS56<LH@`S76<DIBB
YABDTXaaU7:<DHaaS5400iBB01R<LIBBS56DLXaA[EEkkiccU=:DTX@`U;:<LIBBW?>LdiBBW=>448aa
Q32DTX@`U982U;8018aaS56DT[FF0YBb00mc[XaAS56LlhaAW=>449BBS76DLXaAU7:D/X`aU9800Xaa
00NDLXaaU99Jjh@`S77>N@02U982S5402haaU7:<LHaAQ32<DIBBW?>LdiccQ3000W__0XaA00ND/YBB
U99kch?`YCBe]P02U9804HaAU;:DTYBBS76DLYBbS76DTYcCWA><DG_?S56<LIBBQ3000_oo00<00?oo
ool02_oo00D00?oooomJbe:Z009S;006H`aJjf/]Q32]=JeE0Zee00R]EJDDU99kcf<<BVURk6]=0V]]
00E[CF</Jde[SG^_009c[P0>Nnn447__Q11kkicCJfec[W__Nlmkkh@@Llj<<@:44003U9:447__00>D
/P0KS56DTYBBW;>U=9BB]IJ<LLHHeY[>NLiIe[[FV/iiaQS6>=JJaUS>>MJjcWWF^]kKe][F^]kK00;W
7006DVXaQTYYF^]kkiBb0Ycc00fU59ccY?BD/X@@DXXaIR4TBVUkkibcYABLl`02U9801YBbW=>LdjDD
S74aIP8aQP07@RQ:BD88@NPaQSW7@RP00SW70T8800M::G_?Y?BLlibcYEB]E@02ool00`00ooooo`0:
ool000_oo`05003oooooS55[K@02BTT01d98BRU2:5[;LjjD/ZDd00>]M@04WA><LF^=DXX2@PP03TYY
FZ]BZUZ[DZYJZe:ZF^]K2f/]JdecSV^=Lhh2Ljh00f]=JbeS;002Jdd01V]]Jde[CF]]LjiccP9kk`:<
D@05S764D8aAQ52<L@02U9801YBbYCBe]/HHcWWF^PGNn`08ga_NnnLLga_W?>MLkegWG0;_O@0Jg_^e
]W__BXTiidY9JbekkiBbW?>U59dCW?><LF]]>NLH`a22<HIJbh@@S76D/XaaU9:<T@:D/P03S55S3366
008@PP044:8H`aS36:<5488021RS8@A1j6<<Q12DTYcCWA<2ool00`00ooooo`0:ool04000ooooof/]
[GFLlhaaS56<LIcCW?><LH@`S764<9BB0XaA0124D8aaS76U58aaU9:<DIBbU9:D/XaaU7:4<8aaS96<
L@:<D@03U9:<<G_?00:DTP03S56<LHaa00:<D@03Q12<<H@@00:<D@0KW=><LHaAS76D/XaaU9:<LH@`
S96LlhaaU9:4<7>^S764<8aAS76D/YcCU;:<DICBU9:<LIBb00:<L@0IS96445[;Q31kkliIW=>D/Xaa
S564<9AbS56DTX@`S55kkiBBWA>U=9ccS764<8aAQ5000YBB0haa00m[KH@@W?>]EIBBS564<8aAS96D
TXaaS564<9BbQ5000Ycc00><DG__Q3000Xaa0_oo00<00?ooool02_oo01T00?oooomc[U:ZF^]S;5[[
F/]SC9BBW?>]EJee[EFU=:DDU99c[U[;DXYJjg>>Nlm[K@02Jdd01F]]Jde[KG>>Ljh00W_?0W__0X@@
00Ekcg>>Lhic[X@@009kk`04Jfe[CG>^Nll2Nnl018@`U9:D/YBB0YBb0YcC00RLljeeaSRLdhbAcUW>
NMJJ1<ii01;6F<HhcYWNnmJjeY[>VMJJe[[W?<Hh>LM225::D/Y[KG__U;82W?<0:JDDW?>LliBbNlm:
JB44>NMcSYBBW?>U59BbU9:<LIcCU;:LdiBbYCASC2UU<JHiacWW@RQ223W7:DE223W7<HHiad8X@PQJ
bh@@YABD/XaAYC@00_oo00<00?ooool02_oo000;ool01P00ooooohaaLhiJZ`9:B@0=@RQ:BE[;NlnD
/ZeE[GFeUZeEYAB<LG>>DXX00T8X00IBRU:ZF/]BZUZ[DZX2F^/016<<Hba[KF]]0W>>00Ikcg>^LhiS
;6/]Hd`2Jfd017>>Jfe[KF]]0W>^00=kkh@@S7400haa00JDLYBBW=>D/ZDDYE@2]KH02/GhcUWNfmlK
iccO6nLLg__W7=lK0^Ll01c_ONmMmikg_^LL]KIkke:Z@PQ2:5::Jdf449BbYABM4jDDW=>DTV]]@NPH
hb4TBTUcSXaAW;>D/P:DTP:D/P06W=>D/X@@DXXYAA2R0aS300<@XQ2248800Q2200T@XQ226><YIDY9
Jff<<IBbW=<00_oo00<00?ooool02_oo00@00?oooomkc`>Ld`05S56DTYCBW=>4<002S542S7401iAb
S56<LIBBW=>LliAb00:4<003S56DTXaa00FDTP0>S76DTXaaU9:D/X@`U;:L/haaU9:4<9BBS76Ll`:U
5004U9:LdiBbU;82S542S7403haAU;:4<9ccNln<LIccYABD/X@`Q12DTXaAU7:<L@02U98049BbS764
48aaU7:LdiBBF^^U59cCaQRD/YAbU9:DLX@`18aa0haA00ND/[FFW=><DG__S364<002U9802iBbS76<
LIBBS55[KHaA]KJDTYBbU9800XaA00FDTYcCS76DTYBb00:DTP04YABDTXaANnl2U982ool00`00oooo
o`0:ool01@00oooooiAbLjh00U[[00ES;5[[Jff<DJCd00:]M@:]E@09YCBDTW_?H^aBRV<<Hba[KG>>
009[K@04Lfi[KG>>Lhh2Nll017__Q12447_?0X@@01=cSV^=NlmccW>>S764<7?>Nlmkkh@@Q32<DIcC
U;:4<9AbW?>Ld`02W?<04:Dd_ON]MKgGU;;66=JjeY[>FMJJcYWFV]JjeY[>NMJJ0mkk01K_OMkk>NM2
25::H`a[CF</Nnn<LJDDYCBU59ccYABLdh@@BVTYAE:ZQ32D/P:Ll`06W=>D/YcCU9:LliBB0YcC00^U
5366H^a2236V>LM1j488>LLaQT8X008ia`08<JI:BE[;F/^449ccYAB<D@;oo`03003ooooo00[oo`00
2ooo00l00?oooon<LH@@H`aBRT8XBRU:BE[[LljD/ZDd]IH00Zee01>M4iAbJfeBRT88BRU:RE[;D/YJ
be:ZF/]BbU[[F`][;F=<Jfe[S@02Lhh00g>^Jhe[C@03Hb`3Jfd2Jdd02F]]LhiccX@`Q52<LHA@U7:<
L@02U;803YcCWA>eU[Ff_MNe]/HHcUWFf]kkiccO6nLlga/2ic`2ked06NnMmikWG;gGNnmBRTXYBTU:
JE:ZJdf449BbW?>U59ccW=><LF]=>LLY9C6VH`b449BB00:D/P03S96DTYBB00:DTP05U;:<TG>^@RPQ
100248801A2R6<<@PQ2226400a2200L@XR44<JIBRV]]Q32DTP02ool00`00ooooo`0:ool00`00oooo
o`02S54019AbW=><LHA@0YBb00F<LHaAS76<DIBB00:<D@08Q32<DIBbW?><LIBbS56DLP:<L@0NS56<
LHaAU9:<DIBBS56<LH@`U;:4<9BBS96D/YBBS76<THaANlnD/X@`U9:<LIBBS764<8aaU;:DTXaA0Xaa
00^D/YcCNnnD/YcCW?><LIAbQ12DTXaA00:<L@03S56<LIBB00:DTP:<D@0;F/]kkidC_ON<THaaU9:L
diBBS764<002S5402YBBQ32447?>U;:]UIBbQ12DLX@`0XaA0haa00b<DIBBS95kcg__W?><LH@@S76D
TXaAS742U9801HaAS76<TIBbS7400YBB00>DLW?>S5400_oo00<00?ooool02_oo00`00?oooonLdhaA
F/]Jje/;F^][CHaaWA<2[GD2[ED00jDDU99kk`02F//01f</JdeSC6]]Jde[KF=<009[K@03Ljikkg_?
009kk`0<O0mkch@`Q124<7>^Hdakcg__Lhj4<7_?0g__036<<IBBU;:4<9AbS76U59BbYABLljee_MNe
][GFaQRmmicccUWNfmJjcUWFV]JjcWWFV]Jjg__O6nLlga]JjcX7F/]S;7>>Hda[CG_?S76LljDDW=>L
licCU99kkd88<JIcSP03W?<01IBbU9:DTYCBW;<00iBB00BLdidCU98YA@8YI@07>NM2:3VW>LLiYcW7
BRT00S6V00M2:4YYBVUBRXaAYABD/P02ool00`00ooooo`0:ool000_oo`0E003oooooW=><LG__F^]:
JD88BTUJbg_?U;:]EJfE]IJ]MJDdS75cSU::0092:003DXYBZU[;00AJb`03F^]S;6=<009[K@9cSP09
Njmc[W_?Lhi[CF</Jbe[CG>>009c[P9cSP03Jhek[g__00>4<0:<D@06S76LdicCYCB]MKgG0/HH00c6
><iIcWWF^]kKiacW?>mMiec_GNMLkgd2mkh01LiiU99JjdY9BVT00U::025Jbf]=Q32D/ZCdW?>U59cC
U79[CD8X<JIBRW>^U7:D/YbcU9:D/YBBU;:DTYBbU9:LdhaAJddiaaSS264@PQ2R6<<00a2200THXa22
6:<H`bU5<JIBJV]]S5400_oo00<00?ooool02_oo00l00?oooon<LH@@S56U59cCS56D/YcCQ32<DH@`
S5400Xaa0XaA00>4<9cCU9800XaA00RDTXaAU;:<DIBbS76D/YBB0Xaa00^DTXaaU7:D/YAbS56DLXaa
W?><DIcC00:DTP07U;:DTXaaU7:<DH@`Q1000Xaa00fDLX@@U9:<DIAbU;:449BbQ12D/YBBW?>DLP03
Q102U9801IAbU9:DTXaaU9800W_?00VU5<HHU9:<LH@`S76D/YBBS5400Xaa0YBB0XaA00B<<JDd_KN<
D@:4400?U7:<LIBbU9:<LIBBU7:D/YBBS75[KIBBYABeUYcc00:<D@03S76DTYBb00><D@07W=><DHaa
W?>D/YAbLhh00_oo00<00?ooool02_oo00h00?oooon]MIcCNnmBZU[[DXY[CIBBYCB]EKFF0Zee00>U
=9BBLlh00U::00=S36]=Jdd00f]]01U[;F^=Lhikch?`Ljik[g__S36448@`Q12<DH@`LhiccW_?Nnn<
<H@`S55kkg_?Jhf44002Q3004W__S56<LIBbW?>]EIdCaORmmliIaQRmmliI]KJ]ELiIg]_Nn`?F^P;N
n`0=kegW?9cc@PQS36]=Lhi[KF]=H`akkiBbYA@00Ycc02RLdjDDU99kcdYYF/^449ccYEBLdiBbW;>D
/YcCU;:L/iBbW;>D/YcCYCAcKS66<FHaQSW7@PQ:JCW7<HHaYTY9:FDiacWWDXY:JDY9S76]=@;oo`03
003ooooo00[oo`002ooo00P00?oooon<LIccS55[KE::0T8X00iJbg?>W=>UE;FF[IFeUZDDU99[KE::
@PQ::DYY0U:Z00IJbe:ZF/]BbV<<Hb`3Jfd02F^=Ljic[W_?Llikcf]]JdeS;002Jdd3Lhh00f]]Ljic
[P02Nnl03X@@O0n<<H@`S76D/YccWA>eU[GFcUW6F<iiaUP2cWT2e]X02]kkga_W?>MLkgg_WOoOg_^U
=6]=0U::0e:Z00AJbf]]Q12D/P>Ll`09W=>4D6]=BVUBJV=<S56DTYbc00BDTP03S96DTXbA00:D/P09
W=>445Z[8B@@HPQQ488@XQRS00D@PP064:8HhbU5<HI:BF]=0_oo00<00?ooool02_oo00/00?oooomc
SW_?Q12DTYccU;:U59CB00:4<0:<D@03S76<DHaA00:<L@07WA>LlhaAU9:<DIBBS7400iBB0Xaa00^<
DIBbU;:DTX@`U9:4<9BBQ32<<IBb00:<D@05S75kkh`aQ32<<@02W?<00icCW;>DdP02W=<049BBU;:D
LXaAW==kkiBBNnnDLX@@U;:DdZDDU;:L/g__0X@@00RDTXaaU9:<DF<<U9:eUYBB0XaA00J<LIBbW=>D
/XaAQ302S74019BBQ32<DH@`0ZDd00Z<DH@@S36<DIBBS56DTXA@U7:<D@:<L@0AU9:4D7>>Q32]EICB
U;:<DHaaNnn<LIBbS764<9cCU9:D/P02U9801IdCS57ooooo00003?oo00L00?oooon]UJDDS75[K@02
F^/00f=<S56Ll`02[GD02kFFYCBU=9BBNnmBZTYYF`][CG>>Jdd016]]00EcSW__O0n<<G?>00F44006
Nnn4<7_?LjiSC7_?0W__00M[KH@`NlnDTX@`S56<L@02S5400iBBW=>Ll`02YA@01Kgg_MO6>;gG_OL0
0/Hh00kF^[GF_ONeU]Jjg]_NnmkKkegNnmlK>NMJbf]]0V]=00IcSV]=LhicSYBbW?<2YA@2W?<02Xaa
Lhi[CG?>W;>M4iccU9:LdiCB19BB0YBb00JLliCBW?>U=47X<HH2<JH00cW7>NLii`02<HH02C6V>LLa
YSW7@PQS32U5@PRU5002ool00`00ooooo`0:ool000_oo`0K003oooooNlnLdjDDQ11S;4Y9BRUJbg_?
U=:]MKFF]KJ]UJDdS75cKTYY@PQ2:5::DZYJbe:Z009Jb`03F^]S36]=00=[K@0>Lhic[W_?Ljikcg?>
Q11kcg>^Hba[KF^=LjicSP9c[P9kc`:4400:S36<DHaAS76D/YcCYAB]MKgGaUP2cWT04MJJcWWFV/jI
g]_Ff^LLga_W?>MLkegNnkFFNnmS35[;F^/00U[;019BZU[[Jff4<9BbYABLljDDU;:<DG>>HbaSC8@@
U9:LdiBbW;<2U;800iBBU;:DTP02U;82W=<01YbcNlm:BASS4688H@8@XP046:<8HA22264248801AS3
8@@Y9BUUBTT00_oo00<00?ooool02_oo00D00?oooon446]=00:<D@0@U;:DTYBbW;><DHaaS56DLXaA
U9:4<8aAQ12Tm9BbU782S5402haaU7:4<9BBS56DTXaAS36449BBS5400haa00^DTYAbYCB4<:eeW?>D
/YBBU;:LdiBB00:<D@0=Q32<LIAbU9:L/haaU7:<LHaAU=:449BBS5400YBb01B448aAQ12LdiBbW=>U
=8aAQ32446^=H`aS;:Dd[IF<DIBbU9:<DHaa0YBb18aA00Z<LHaAS76DTYccU9:448`aS56L/`:<L@0A
U9:DLYBBU9:<LIBBS56DTW_?Po2D/[FFS76DLYBBS56DTP02U;8028aaU9:DLYBbS75kkjeeYC@2ool0
0`00ooooo`0:ool06@00oooookgG[EFU57__F/]:JF/]S76]MKFF[GF]UJeEYCBD/W__FZ]:JF;/Jdec
SV=<00A[K@05Lhic[W__Nlmc[P02Q1000g__Q11kk`02Q1001=kkLjikcg?>0W__0X@@012<DH@@S76<
LIBbW?>L/icCU;:DTYccYCBm]kFfaQRn5`;6>00@aOS>NLHhcWW>>Lii_MO66=JjW?=:BD8XF/][SG__
Jhd2Lhh016]]Hbb449Bb0Ycc00^U=9ccW=><LH@@NnnDLYccYCBDdYbc00:Ld`0LU9:LdiBbW=>D/YcC
W?>LdiccYABLdc5V:FDiYc66>LLiid88<JHaQSWW@PPaYSWW@RQ::B44F//2ool00`00ooooo`0:ool0
00_oo`0?003oooooF/^<LJEDU;9c[U:Z@RQJbg>^W=>UE;FF00:]M@07YABDTV]]DVXiid88BVT015:Z
0U[;00AS36</Jfe[C@9[K@Ac[P08Nlml3g__Lji[CF=<Lhi[K@9c[P9kk`:440:4<008S564<8aaS76L
djDD]IJeeP;6>003cWW>FMJJ00GF^P;Nn`07e[[66:DdQ11[CE[[H``00U[[0U[;00eJjf]]Q12D/Ycc
YABLliBbQ51kkg>^Nnn<D@05U;85U982U;801YcCU=:DLV^=@PPHh`88H@<@PP05264@PQ224:8@PP02
6<<01B3T8BCooooo00003?oo00/00?oooonmee[[S56449AbW?>]EIcC00:4<007Q12<LHaAS76<<HaA
Q3000Ycc00f<DIBBQ32D/XaAU7:<DIBbS76DTXaaU7:D/P02S74059BBS76D/XaaQ11:RH@@U9:<LHbA
S56<TH@`U=:<DIBbS55kkhaANll2S7404YcCU;:LdhaAU;9kkiBbNnnDTXbAS56DTYBbQ32DTXaaW?=c
[P:<D@0:YAC6>8`aQ32DTXaaU7:<LIcCU982Q30018aaQ32<LHA@0Xaa00BL/haaQ324<0><L@08Q52D
TX@`U7:<DIBBS76<D@:<L@07JdfD/YBbaQR<LIcCS5400Xaa00VDTYBbU9:<DIBBU=:449cC[GD00_oo
00<00?ooool02_oo00d00?ooooo66;gGYCBD/V]]BVUS;8aaW?>eUP02[ED2YC@04IBBQ11:JDYYF^]S
;6]]JdeS36]=Jhe[CG>>Nlmc[W>>Ljh00g__0X@@00>4<8@@Nnl00W>^01V4<7__Q12448@`Q12Ldg__
S56<TG__U;:4<8aAW?>]ULHH[GFeU[gG[EG6>;FfaUS>F@02aSP03<iiaSS>NLiIBXUJbe[[H`a[SG__
Llikc`=cSP03JfeccYBB00>Ll`03W=>DTYBB00:<L@03U9:LliBb00JD/P05U9:DdYBbU9:Ld`02U;80
1YcCYCB]UC5V>LLaQP8ia`0;<LI:BCW7>LM2247X:FDiadYY@RPH``02ool00`00ooooo`0:ool000_o
o`0M003oooooBVUkkkFfYAB<DF<<DVYJbg_?W=>]MJfE]IJ]MJDdU99cSU::@NQ2259ZDXYBZU::FZ]B
ZP02F^/016/]Hba[CF]=0W>>00Akcg>^Nlmc[P:44007Po1cSW>>Ljikcg>^Nll00g__00B448@`U7:<
L@:DTP0IU;:Lljee]KJmmkhGaSS>FLiicYWFV]Jjg]_Ff]kKeY[6>:eEU99c[V]=H`a[CF=<Jbd00V<<
00EJbf<<Jff<<IBb00>Ll`05U;:DTX@`S56<L@03U;8019BBU;:DTYBb19BB00BD/YcCU=:Ld`:Ll`0=
Q11BRR444688HA2R488HXa226:<@PQ2R48800aS30_oo00<00?ooool02_oo01L00?oooooNfe:ZS564
<8aAU;:U=:DDQ32DLXaAU9:<LIBBQ32DTX@@YABLdiAb00:<D@06S76D/XaaU7:DTXaA0iBB00BL/haa
S76DTP:<L@0HS56UE9BBW?>]=H@`U7:DTYAbU9:<DH@@U9:<LIBbW=>LlicCYCBDTX`aQ32DTXaa0YcC
01VDTYBbS76<DIBBS76DLXaaQ11[KHaAYCBeUZEDU7:4<8aAS76DLXaAU7:LdibcS56DLP02S7400iBB
U7:<L@02U98029BbS56DTXaaU9:<LIAbU982S74019AbS76DTXaa0YBB00VLdg>^U7:LllHHU9:<DIBB
S5400Xaa00N<DHaaS76LdhaaPo2D/P02ool00`00ooooo`0:ool02000ooooolHH_ONeUYCBS542H``0
3iBBYCB]MJee[EF]MJDdU;:445[[BTUJjf</JbeS;004Jdd02W_?Jfekkg__Nlmc[XaAQ124<8@@0X@`
02MkcjeeHbb4<9AbQ32<DH@@S36<DG__Q32<LICBY?BLlicC[GFmmkFF]KJmmjeeaSS>>KFfcUVn5mJJ
aSS>FKhG[EEJbf</Jfekcg?>Nll00W__0W>^0W>>00Y[KH@`U;:LdiccY?BD/YcCU9:L/`:Ll`0RYCBD
TYBBU9:D/YcCU9:L/iBbU7:D/YbcU;:LlicCU;;6>?NncYTYAC66>LLaQT8X>LM::CWW<JHiid7X<JHi
ad88<FH2ool00`00ooooo`0:ool000_oo`0?003ooooo@RQkkkFF[GFD/W_?F/]Rk7>^W=>UE;FF00:]
M@07YCBD/V^=DZXiid88BTT00U::0U:Z0U[;0V<<00A[CF=<Jfe[S@9c[P09Nlmc[W_?Ljikcg?>Nnmc
cW__009kc`09Llikkg__Q11kkh`aS76DTXbA00:D/P04YCB]MKgG_OL2aQP03<iIaUS>NLjIe][F^]kk
cWVmmidCQ31[K@9S;003Jfe[CF]]009S;008F`]Rk6<<Lhj449BBU;:Ld`:D/P>DTP04W;>D/YBbS745
U9801HaaU9:<LIBbU9800YBb00J]EKhGaSRD/U::6><226424:800aRS488@PP0348801ARS48;ooooo
00003?oo00L00?oooooW7488Q3244002Q3002iccYCB448aAS36<LIBBQ52<DHaaQ1000Ycc0YBB00R<
LIBbS76DTXaaU;:<LIBB0haa00bDTXaAS76<LIAbS56DLXaAQ12DTYcCQ303S74059BbS36LlicCQ32D
/W_?U7:4<8aAQ12<DHaaU;:<DHaaQ32DTXaaU982S54028bALjj4D8aaU;:mehaAU783S74029BBS76D
TXaaU;:<LH@`Q502S5401IAbS76<LHaaS5400X@`00><LIBBS9400Xaa00JDTXaAU;:<LIBBS742S540
2YAbYAAkkd98NnnLllHHS56DTXaa0XaA00N<LIBBU7:<DIBbS764<002ool00`00ooooo`0:ool04`00
oooookgG]KJUE:DDU99c[U[[U9:U5;FF[EFU=:ee[EFDdX@@009Jb`04F^][CF]=Jdd2Jfd01F=<Lhi[
KG__Ljh00W__0X@@016<DG__Q12448@`Nnn4<:DDQ12<LH`aQ124<7`?U9:4D8@`00:Ld`0MWA>LljDd
W?>U=;Ff_ONe]/HhaQR]MLiI_QO6><iIcWW6F7_?HbacSW>^Q11kkh@@Nnn447__Nlmc[P02Lhh01G>^
NnnDTYBbW=<00YBb00>DdYccU;800icc0iBB00JLliBBU;:D/YBBS742U;803ibcS76D/Yccicc_OONN
[GDY9C66>NLaYSWW>LM1j002<JH01D88>LLaQSW7>NL00_oo00<00?ooool02_oo000;ool03@00oooo
odY9Nlne]ZeeYCB<DG>>Jdf449cC00:]M@06]IJ]MJeEU;9k[e:Z0T8X0U::0U:Z00AJZe:ZF^]S309[
C@06Lhi[SG>^Ljikcg?>0g_?00=kkh?`Nnl00X@@00Z4<7__Nnmkkh@@Nnn448aAU;:DdP:Ld`06YCBU
E;Ff]KJmmkhG0/iI0/ii0mJj00G>FKFfU=:447>>009[K@05Lhi[SG>>Jfe[C@02Hb`02f<<JbecSX@`
U9:L/iBbW;>D/YbcU;800icC00BD/YBBU9:D/PBDTP0=S76DTYBBU;:DTYcc]KKNnoNng]^443W72640
0Q2200<HXa2R6:<01Q220_oo00<00?ooool02_oo01@00?oooooF^TY9U9:<DHaaS56LdjeeS76<DH@`
U7:DTXaAQ32<DH@@0YcC0XaA00RDTXaAU7:<DIBBS76<DIBB0haa00^DTXaAS56L/haaU9:<DJDdLhjD
TX@@00>DTP0EU;:DTX@`U9:<LHaAQ32<LH@`W=><LIccQ32DLX@`S764<9ccS76DLXaa00:44005Lhj4
49ccW?>]E@03S5401YAbS56<LHaaU9:<L@:DTP04U;:<DIBBS542U9801haaS56DTXaAU9:<DIbc00:D
TP03S56DTXaa00:<L@0=U;:<DHaaS76DTZDdW?>4<7>^DZYcK[gGU9800Xaa00VDTXaaS76D/YBBS56<
LIcCQ1000_oo00<00?ooool02_oo00`00?oooonmejfE_MN]EIcCS56448aa[CD2[GD02jED[GFU59cc
Q11JjdYYLhi[KF/]Jfd00V]=0V]]00Ic[W_?Q11kkh@`Nnl3Q10018aAS36448@@0X@`00b<DIBBW?><
LG_?Q32<LIBBS56DTYCBU;82W?<04KgGYCBe]ZDD[GG6>;gg_MO>NLHHaSS66;FFH`acSW_?Nnl018@@
00>4<7__Nll00W_?00]c[W=^Ljj3l8aaU;:DdYBBU;:LdiBb00>Ll`07W=>Tm9BbW=>DdYbcU;8019BB
00jLdiBBU9:<LMkkkeg_ONMLia`Pi35V>NLiYc6V0d8800HaYSW7>LLiid88<HH2ool00`00ooooo`0:
ool000_oo`0>003ooooo@PQkcjee]IJUE9cCQ11kch@@W=>U=0>]M@07YCBD/W>^FZ]2:4Y9BXT00U:Z
00QJbe;:F^]Jjf</HdacSV^=0W>^00Ikcg>^NlmccW__Nll2Nnl5Q1003g_?Q12448aAQ32<LIBBW=>D
dZDDYCB]MKFf_MNmm`02aQP02LHhaUS>NMJJcUVmmjeES95kk`03Lhh3Ljh2Lhh066]]JdeS36<<Hbac
[W__U7:DTYBbU9:L/iCBW?>DdYccU=:L/iBBU;:DTYBbS96DTP><L@0<U9:<LIBBYCC>NNmmooo_OJDd
BXT@XPQQ0Q2200<HXa2R4:800Q2200<8HA2226400_oo00<00?ooool02_oo00L00?oooooF^TZ9S764
4002S5405XaaW?><DHaAQ32<DIBBQ52<LHA@Q32LlicCQ32<<HaaU9:<TIBbU9:D/YBB0haa00><DIBB
S9400YBB00><LHaAS7400YBb00R4D9bcO0mkkh@`U;:DdX`a0YBb012<LIccS76LdhaaS56D/YAbWA>L
dh@@S56<LH@@U99c[P>4<005YABUE9bcS56DLP03S743U98028aaU9:DTYBbU9:<DHbAS742U9800hbA
U9:DTP03S7402XaAU7:<LHaAS96DLXaaU9:<LIBB0Xaa0Ycc00N4<7_?Q31S35;:aQRM4`03U98018aa
S36<LIBB0haa00B<DOooool000coo`04003ooooo]IH2[GD02KFFYCBLdh@`S76DdZeEYEBU=002[ED0
1YBbQ11Jbe[;F`][C@=[K@08LhiccW>>Llj447__Q11l3`:440>4<0:<D@0AQ12<DH@`S36448aAQ12<
<HaAW=><DIccU;:<LJDd[EFU=002]IH01/iI]KJmmkFFYCBme`;66007cUUc[V]]Lhj447__Q3000X@@
00J4<8aAQ124<8@@Q302Nll00f^=Lhikk`02U98029ccU;:DTYCBYCBLljDDU=83W=<019BbW=>DTYbc
0iBB01RD/YBBU;:<LKFfga__GNLliabLle[[:DDaQSX7>NLaaT88>LLiic66>NLaaSW7<HH2ool00`00
ooooo`0:ool000_oo`0E003ooooo@RQc[Zee[IFeUZDdW;><DHaaW=>]EJee]GJ]MJdeU;9kce:Z009:
B@9BZP9Jb`9Jj`04H`aS;6]]Jhd2Ljh017_?Llikcg_?0W__00B3l7__Nnmkk`:44009Q32448@@Nnn4
<8aAU7:<LIBb00:Ld`07YAB]EJee_MNee/Gh_OL00/Hh00c>NLHhaQR]EIccQ31kkg>^NlmccW_?Llh2
Nll02W^_LhicSV]]JdeS36]=Lhj448aa0YBB00FL/iCBW?>LljCd00:Ll`:Ld`0=U;:LdiBbU;:<LIAb
S76DLXaaU9:Llkggga/00_oO00KW7:DDH^`Q91RS264248800aRS4:8@XP044882ool00`00ooooo`0:
ool01P00ooooomKJDXZD/P><D@05S76LdiBbW;><D@02U9801haaQ32<LH@`YABLlhaa00:DTP05S56D
LXaAS36<L@03S5403XaaU7:<LHaaS56DTXaAS76<DIAbS76DLXaaW=<2U9800iBbS364<003S5402YBB
S56449BBQ12<LG>^S564<9Bb0Ycc00=c[X@@Lhh00Ycc00VTm:EDS56<LIAbS76DTXaAS7400XaA00V4
<8aAS76D/YBBU;:4<8aaQ3000YBB00NDLXaAS76<LIAbU9:DLP02U9804haaU;:<LIBBS76DLXaAU7:D
TZDDU;:448aAQ11c[W^_[GFLdicc00:<D@03U7:<DIBB00:DTP03S76D/XaA00;oo`03003ooooo00[o
o`09003ooooo_MN]MJeE[GFeUYcc00:D/P0IW=>]MJeEYEB]EJDdW;>4<6;/DZY[;F</Lhi[KG=^Jhek
cf]]Nlmc[X@@Nnn3l8@@S5400h@@00B<<H@`S55kk`:<D@06Q124<9BBQ12<DH@@0YBB00BLlhaaYABU
E0:U=00C]IJ]MKFF]KJmelHhaQRmmh?`Hbak[g?>Q124<8aAQ32<<H@@S5400X@`0X@@00=kkh?`Ljh0
0W>^00ekkhaaW=>D/YcCU;:Tm:DDY?BLdjDdW?>U5004W?<01IcCU9:<LIAbU;800YBB00jLlmKJkegW
G>Ll_OMS;7>^Hb`aISVW<JHiad880SWW00E223W7>JLiacWW00;oo`03003ooooo00[oo`002ooo00H0
0?oooom227>^YE@3[GD01IccU;:<TIcCYA@00jeE00NU59BbLjiJbd98BVUBRP02F//3F^/01F<<Hba[
CG>>Jhd00W>^00Akcg?>Nlmkc`Qkk`0>Q11kkh@@O0n<<HA@S76<TIcCU;:U5:Dd]IJmm`?66007]MJe
UZeEYCBLlhaANnl00W>^00Mkcg__NnmccW_?Llikc`02Ljh00f^=JfeS;002Hb`017>>Nnn<LHbA0YBb
0Ycc00>U59ccW?<00Ycc0YcC01FD/YcCU9:DTXaaU7:<LIBBU;:]MLjIkgggg^mM_ON<LF<<@PPQ912R
26400Q2200<H`a2R6:<00Q2200@8HOooool000coo`0:003ooooocWU:JIBBS76<DH@@S742U9801HbA
S564<9BbQ5000XaA00F4<9ccW=><DIBB00><L@05U7:4<9bcS76DTP04S74018@`U9:<TIBB0haa016D
TXaAS76<THaaQ52DLYBbS76D/X@@Q32Ldg__S76D/YBB00:Ld`06W?>DLW_?LjiS37>>0ZDd00N]EJee
S96DLX@`U7:<D@02S7401HaAS76DLXaaU7800haa012D/XbAS56<LHaAS76DTXaaS56<LIAbS56<LHaA
U7:<L@><D@0=S96L/hbAU9:<TIccW=>4<7__Q31[KHaAW?<00Xaa00FU59ccU;:DTXaA00B<L@05U9:<
DOooool0000<ool03`00oooookGF]IJU5:eE[GFU=9CBW=>LljDd[EFU5002YC@019BbS35S35[;0V]=
00=[KG>^Jfd00V]=00Q[KG?>Nlmkkh@@Nln448@`0X@@00><LH@@Q3000X@`00f<DH@`Nnn4<8aAS764
<8`aNnn<LG`?S56M4`02U;82_OL01[gGaSS66:EDNlm[C@9c[P9kk`:44003S564D8aA00:44004Q32<
<H@@Q102Nnl2Nll01f^=LhikkhaaU9:LdiBb00:Ll`0;YABLliccW=>U59dCYABLlicCU;:Ld`06U;80
2/HhiccW?>LlcYUcSV</Nlmkkf<<0S6600<aYSW7@PP00T8X00@iic66<JHaYP;oo`03003ooooo00[o
o`002ooo00D00?oooom2:7>^00:]M@04]IJ]MJeEWA<2W?<2[ED03Zee[EFU=9BbNlmJje9ZBVUJZe[;
F^]Jbe[[F//2H``01V]=JfecSW>>NlmccP9kc`Akk`0:Q11kkg__Nln3l7__Q11kkh@@Nnl2Q3001XaA
S76DTYBBW=>Ll`:U=00:[EFU=:DDU=:D/XaAQ11c[W^_Ljh2Nnl01H@@Nnmkkg_?Nnl00W_?0W>>00U[
KF]=Hba[CG>>Q12<DIBBU;800Ycc00NU59dCYABLljDDW?>U5002W?<2W=<2U98068aaU9:DTZDDaQSW
??ONmkk>NIccLji[CE[[BRTY9ARS264@XQRS6><H`aRS468@PP;oo`03003ooooo00[oo`06003ooooo
cWUBRXaa0YBB00F<DHaaW;>DTYbc00:<L@:DTP06Q32DLX@@W?>D/XaA0Xaa00>4<9BBU9800YBB00F<
DHaaU7:<DIbc00:<L@:DTP0:Q32DTXaaU7:<LHaAS76D/XaaS542S7401IBbU9:DTYBbU9800h@`00=[
CF</Hb`00V<<00>44:DdaOP00ZDd01:DTXaaS56DLYBBS56<LHaAS76DTXaAU9:<LIBBS76DLXaaU982
U;800haAU9:<L@03U98018aAU9:DTYBB0Xaa00J<DIBBS76D/XaaU982S7402XaAU9:LlhaANnn<DG__
NlnUE:de0X@@00B<LIccYABD/P:<L@:<D@03S76D/YBB00;oo`03003ooooo00[oo`07003ooooo_KN]
UJeEYC@00[FF00F]=JDDYCBU=;Ef00>U=005W;>446<<F^][C@02Jfd017>>Jfe[CG=^0g>^00=kkh@@
Nnl00h@@00B4<8aAQ12440:<D@03S36448@@00>4<008S36448aAQ124<8aAQ32440=kk`=cSP05Nlmk
kg__Nnn4<002Q1001H@`Q12<DH@@S5400X@@00><DH@`S5400X@@0W_?0W>^00McSX@@U9:D/YCBW?>U
5002YC@01JDDWA>LlidCYA@00Ycc00JU=:DDW=>LdiBbW=<2U98039cciac_GNLliabeUU::JfecSX@@
S75[C@8aYP08>LM2:488@RPiid7X<JI1j0;oo`03003ooooo00[oo`002ooo00H00?oooom227_?YE@2
[ED01;FF[GF]EJDD0ZDd00Z]EJED[EFM4iBbLjiJbdY9DXYBZP=Jb`05DZYJbe[[H`aS;002Jfd027>^
Lhikcg?>Nnmkcg__Llh2Nnl01H@@Nnmkkg_?Q1000W__00=kcg__Nll00W__0X@@00Z4<8@@S56<LIAb
S76DLX@`Nnmc[P9kc`04NnmccW_?Nll3Nnl2Nll017?>NnmccW>^0V]]019SC6/]Hdac[X@@S76DTYcC
W?>U59dCYABLljDDW?>U59ccYA@2W?<03ICBW;>DTYBBS76LdkFFe][_WOoOga^eUW__009[C@0<JfeS
34Y98B@@XPQQ6<<Hhb3T4:8@PPQQ0_oo00<00?ooool02_oo00X00?ooooo>VDYYS76<THaaQ52440B<
L@03Q32DTXA@00:<D@0VQ12LdicCQ32DTXaaS56<LIBBS56DLXaAU9:<LHaAS76DLXaAU9:<THaAS96D
TXaaU9:<DIBbU9:DLXbAU7:<TIBBS76DLXbAU;:<D@:U500BYCBUE;gG]KJeUYdCW?>DTXaaS56DTXaa
U9:<LIBBS76DTXaa0YBB0XaA0Xaa00FDTXaaU7:<LIbc00:<L@04S56DTXaaS743S5401YBBS76DTXaa
U9:<L@:<D@:<L@06U9:<LIBBWA>Llh@@0X@`00Y[KHA@]IJLliBBQ31kchA@W=>U50:<L@05S56<LIAb
S76DTP02ool00`00ooooo`0:ool02`00oooookgG]IJLljeEYAB]MJDd[ED00ZDd0ZDD00ZU=:DDU9:4
45:ZFZ][CG>>Jde[K@A[C@04Jfekcg_?Q102Nnl01H@@Q31l3h`aQ3000W__00N<DHaaS55kkh`aQ32<
D@02Q3001XA@Q32448@@Q51kk`9kc`03Nnmc[W?>009kk`:44005S56<LH`aQ12<<@04Q302Q1000h@`
S55l3`02Q3000g__Llikc`02Ljh03H@@U7:LlicCWA>U59dCYABM4jDDWA>U59cc00:U500>YCBLlicC
U;:LdiBbU9:<LLjIiccWG>LleYYS;09[K@9kk`:<L@07Hb`YACW7<JI:JD8X@PP00SWW00@aY_ooool0
00coo`002ooo00D00?oooom::G>^00:]E@:]M@0>]IJ]MJee[EF]MJED[EFU=:DDU99c[U[;DVYBRP9J
b`0<F^]Jbe[;F/]Jjf<<Jde[KG>>Ljik[g>^0W_?00Mkkg_?Nlmkch@@Nnn44003Nnl00h@@Nnn3l002
Nnl01W_?Nnmkcg__Llik[`9c[P=cSP9kc`9kk`07Q11kkh?`Nnn3l7_?Nnl00g_?0g__00ac[W>>Jfe[
KF</Jfec[X@`S76LdiccYA@4YC@5YA@00jDdWA>Ll`02W=<2U;804JDdcUWWG?oOmik>NIBbLhiS;7=^
Ljik[f=<BTTYAARS4:800aS300D@XQRSooooo`0000coo`0<003ooooocWUBRXaaU;:<LIBbS76DTXaa
19BB00JDLX@`U9:<DJdeW=<2S74019BBS76D/YBB0YBb00ZDTXaaU9:<DIBbS76DTXaaU9:<L@:DTP0C
W;><LHaAS56D/XaaU9:<DIAbU9:<DHaaU;:<LIBBS76L/iBBU7800YBB00B<DHaaS76DTP:<D@05S76D
/YBBS76DTP02S7401HaAS76DTXaAU9800haa00>DLXaaU7800YBB0XaA00j<LIAbS76DTXaaU9:<LIBB
S76DTXaaU7:<DIAb0YBB01J<LIBBU=:U58aANnn<DG__NlnU=:EDU7:<LIBBNnn3l8aaYCBU59BBQ124
<0:<D@04U;;ooooo000<ool01P00oooookgG[GFU=0:]E@03YCBeUZee00:]M@0@YCBLljDdYEBD/W__
H`aJjf]]JdecSV^=Lhic[W>>Jdd2Ljh4Q1001h@`Q12<DH@`S56448@`00:<D@03Q32<<HaA00:<D@03
S36448aA00:4<0F44005Q32448@@Nnn4<003S542S7400h`aS56<<@02Q302Q1000g__Q3244002S540
28@@Nln447?>Nlmc[X@@U982W=<5YC@2YA@2YC@2YA@00iccYCBM4`02YA@04icCU9:]MMkkkggW?>LL
W?=S36]]Nnn448@`Q12<<IBbJfdaISVW00<ia`03@PPiad8800;oo`03003ooooo00[oo`002ooo01/0
0?oooom2:7_?YCB]EJED[GF]EKFF[GFeUZee[EFU=:eEWA>D/W>>F/]:BE::DZYJje[;F^/00e[;00AS
36</Jfe[S@9c[P03NlmccW__009kk`08Llikcg__Q11kkh@@Nnn440Ikk`05Llikcg>^LjicSP04Ljh0
1g_?Llikkg__Q11l3h@@009kk`0<Nlmkkg_?NnmccW_?Llikkg?>Lji[SF]]0V]=00E[KG_?Q32D/YcC
00:U50>U=008YABU=:DDYCBU5:DdWA>U50:Ll`05U=:D/YcC_MOFfP02mkh01]kkYEAkkf</Jfe[S@9c
[P0:NlmS;4Y98B@H`a226<<@XQRS4882ool00`00ooooo`0:ool02@00oooooliiBVVDLXbAS36DTP04
S542S7402iBbS764<8aaS36DdYbcQ32DTXaAU7800haA00BDTXaaS76<L@:<D@F<L@06Q32DTXaaS56<
LIBB0haa012<DHbAU;:<DIBBS56DTXaAU9:<DIBBQ32D/XaaU;:<T@:<L@09U7:<DHaaS76DTX@`U9:<
LIAb00:DTP03U;:DLXaa00:<D@0;U9:<DIBBS76LdhbAU9:<LIBBS76DLP03S7401YBBS56DLXaAS76<
T@:<L@B<D@0;YABD/X@@Q124<6]]S76]EHaaS96<<@02S7402W__Ljj4D9cc[EF<LIBbU9:<DHaa0_oo
00<00?ooool02_oo00P00?ooooneUZeEYCB]MJDD0ZDd0Zee00^]EJDdYABM4jeeU;:446<<F/]SC6]=
009c[P=[K@0@Lhi[SG_?Nnn4<7__Q11kkh`aQ124<8aAQ32448aaQ303S5400h@@S5644002S5401X`a
S56447__Q11kk`>44006Q524<8@`S764<8`a0XaA00>4<8aANnl00X@`0X@@00><<H@`S3400X@`0W__
00Ukcg>^Ljikch@`U9:LljeEYA@00ZDd00V]EJDdYABU=9ccYABU=9cCYC@00Ycc00FDdYcCU;:D/]JJ
00;W?00>iac665[;H`akcg__Q31kkh@@Nnn<DIBbH``YI@8ia`@ii`;oo`03003ooooo00[oo`002ooo
00D00?oooom::G>^00:]E@04[GF]EJee[GD3]IH04jeE[CFU=:DdU;9k[e[;DXY:JE[;F^]S35[[H^aJ
bf;/H`a[CF]]009c[P9kc`9kk`0?Q11kkg__Nnn447__Q11kkh@@Nnn3l7__Q11kkh@@009kk`05Llik
cg>^Nlmc[P04Nll2Nnl2Q1000h@`Q1244002Nnl00g_?Nnmkc`02Nll3Nnl2Ljh03V]]JdeS;6]]Llj<
DIBbYABU=:eEYCB]EJDd[ED2YC@00jDDYCBU5003YA@02YccW=>LdjeecUW_OONnkgfmmiAb0V]]00Ac
SW^_Ljik[`9kc`08Jde:JBU56<<@PQ2R488HX`;oo`03003ooooo00[oo`08003oooooaSQJZhaaU9:<
D@>DTP:<L@05S56DTYBBU99kk`02S542W=<04haAS76<DH@`U9:<LIAbU9:DLYBBU7:<DIAbS76DTXaa
U7:DTXaA00:DTP0=S56DLXaAS76<DIBBS76DLXaaS56<LIAbS7400YBB00BD/YBBU7:<L@:<D@03S76<
DHaa00:DTP0BS56DTXaaS76D/YAbS56DTXaAU7:<LIAbS76D/XaaU9:<LIAb0Xaa0haA0haa00><DHaa
S7400Xaa00RDLXaAU9:<DIBBS76D/Xaa0Ycc00Z<DG__Q31c[X@@[IF]MHaaU;:<D@>DTP05Nnmkchaa
YCBLl`02S7401HaAS77ooooo00003?oo00D00?oooone]Zee00:U=005[CFLljDd[GFeUP02YC@2YA@0
1jeeW;=kcf</DZY[CF]]009cSP08Lfi[CG>>Jfek[g?>Po1kk`:44009S364<8aAQ32<DH@`S364<8aA
00>4<005S56448`aS56<L@02S5400h@@S5644002Q30018`aQ12<DH@`0X@@00>DTXaaU7801X@`00Yk
khaAQ324<8@@S56447__Q31kc`=c[P0<Q12DTZDdYCB]EJDd[CFM4jDdYAB]=Icc0ZDD00>LljDDYA@0
0Ycc00BDdYbc]KKW70;W?004cYV<<E[[Njl3Q3003H@@Llj448@@S56D/V]=<JHiac5V>LLaYT7X00;o
o`03003ooooo00[oo`002ooo00H00?oooom227>^YA@2YC@01JeEYCB]EJee]IH00Zee00VU=:eEYABD
/W>^F^]:JE::DZX00e[[00MJbe[[F^]S36</Jfe[S@02Ljh2Nll2Nnl01h@@Nnmkkg__Q11kkh@@00=k
k`03Q11kkh@@00=kk`08NlmccW_?Ljikcg?>Nnmkc`9kk`05Q11l3h@@Nnn44002Nnl2Nll00g?>Nlmc
cP03Nnl017?>Lji[SF]]0V</00E[CG_?S56LdjDD00:U=003[EFU=:Dd00:U=0:U5004WA>U59ccYA@2
W?<019BbYABmmmkk0_NN00G>VIccLji[CF]]00=c[P08Lhic[W_?Nnm[CDYY:FDHh`8@XP0448;ooooo
000<ool01P00oooooliIBVVDLP><L@0CU9:<THaaQ52DTXbAU9:<LH@`S56DLYcCW?>4D9BBQ52<LHbA
U7802haa00>DTXaaU9800haa0iBB00><LIBBU9800Xaa00ZDTXaAU9:<DIAbS76DLXaAU;:<D@:DTP09
U;:<DHaAS56<LIBBU;:<LIBB00:<L@07S96<LHaaU9:<DIBBS7400XaA00FDTXaaU;:DTXaa00><D@07
U7:<LIBBS76DTXaAU;800Xaa00><THaAS5400Xaa00FDTYccU;9kkhaA009kk`03U;:]MH@`00:4<003
S56<LIBb00:DTP06NnmkchaaYABU=9cC0YBb0_oo00<00?ooool02_oo00H00?oooon]UJDdW?<3YA@0
5iccYCB]MJeEYEB]EJDdYABLdhaAH`aJjf=<Jfe[SF]]Jdec[V=<Lhi[SG_?Ljh00W__0X@`00J<<H@`
S56<DHaaS542Q30018aAQ32<DHaA0X@`00RDTX@`Q32<DH@`Q524<8@@0X@`00B<<H@@Q32<L@:<D@0:
S76448aAQ32<DH@`Q11l3h@`O0l2Q3002X`aS764<7`?Nnmc[W>>Jfec[W__0Ycc00^U5:DdYCBU5:Dd
YAB]EIdCW?>U59cc00:Ld`0AW?>LdiccW?>D/]JjiccW7=kk[GEJjf]=Llikcg__Q11kk`02Q102Q300
29AbU99[CCWWBTTiicVW<JH2ool00`00ooooo`0:ool000_oo`05003ooooo@PQcSP02YC@01jeEYCB]
=JDd[EF]MKFF00:]M@0=[EFU=9BbNlmJje9ZDXYJbe[[H^aJjf;/F^/00V<<00A[CF]]Ljic[P9kc`03
Q11kkh@@00:44009Nnn447__Q11kkh@@Nnn447__00>4400;Nnn447__Q11kkh?`Nnn447__Q11kk`07
Q1001G__Po1kkg__Nll00W__00b447__Nnmc[W>>Jfe[;F<<JdekciAbW?<2YC@01JeEYEB]EJED[ED0
0ZDd0ZDD00fLljCdW?>LlicCYABeU]JJkegg_]kk]IJ44002Jdd00g>>Ljikc`03Ljh01g_?Nnn446]]
DXXYIAS3008@PP;oo`03003ooooo00[oo`0<003ooooocYUBZYBBU;:<LIAbS76D/Xaa0XaA00>DTXaA
U9800XaA00N449cCU;:DLXaaU9:<L@03U9801iBbU9:DTYBBU;:DLYBB00:<L@04U7:<LIAbS543U980
38aaU9:<LHaAU9:<LHaAU7:DTXaaU9:<L@:DTP06S76DTXaaU9:<LHaA0Xaa0YBB00FD/XaAS56DTXaa
00FDTP0>S76<DHaAU9:<DIBbU9:L/iCBU9:<DIAbS76DLPBDTP07S76DLYBBU7:<LIBbS7400YBB00><
LICBYA@00h@`00AcSXaAYCBLl`:DTP07U;:<LIAbU9:<DHaaU9800W__00F<DHaaU;:<<HaA00;oo`03
003ooooo00[oo`05003ooooo]IJ]E@02YC@01JdeYABU5:DD[CD00ZeE01N]UJeeW?>L/haAH`aJbf]=
LjicSV^=Lhi[KG^_Jfekcg__Q31kkhaANnn<DH@`00><D@05S76<DH@`S564<002S5401haaQ32DLX@`
S564<9Ab00><D@06U9:<LHaAS76<DH@`0XaA00J<LHaAS764<9cCQ104S5400h`aS76<L@02S542Q100
0g__Nlmc[P02Ljh03haaW?>U5:ED[EFU=:eE[GF]EJDDYCBM4jDDW?>Tm002W?<03YcCYABLdlHHga_W
?=lKcWUS;6<<Lhikcg__S342Q1000g__Q1244002S542U9801F]]:BDiYd8X<HH00_oo00<00?ooool0
2_oo000;ool01P00oooood88LhjM4`>U=0:U5004YCB]MJee]IH2[GD01jDDU;9ccV;/BVUBRU;:00=J
j`09F/]Jje[[H`aSC6]]Lhic[W?>009kk`0LQ11kkh@@Nnn447__Q11kkh@@Nnn447__Q11kkh@@Nnn4
47`?Q11kkh@@Nnn447__Q11kkh@@Nnl3Q10017__Q11l3h@@27__011kcg>^Jfe[CF<<Hba[CH@@S96U
5:Dd[EFU=:eEYEB]E@:U=00AWA>U59ccW?>LdiccW=>LljDdaQSNnoNNkeg6>9BBLhiS;002Jfd6Ljh3
Nnl01F]]DXXYIAS348800_oo00<00?ooool02_oo00P00?ooooo>NE::U9:4D8aa0XaA00B<LIBBS56D
TP:<L@07Q52DLX@`Q32DdYcCS7400XaA0Xaa0XaA00NDTXA@S564<8aaS56DLP05S742S5401iBBS76<
LHaaU7:<DIBB00><L@06U9:4<9AbS56DLX@`0haA00B<LIBBS56DTPB<L@04Q124<8aaS742S54028@`
U7:4<8aaS56DTXaaU782S74019BBU;:<LHaA0Xaa00>4D8aaS5400XaA0Xaa01BDLXaaU7:<DIBBS76D
TXaaW=><LG__Q31kkg_?[EF]MIBBS76DTX@`0Xaa00>DTXbAS7400Xaa00Ikkh@@U9:]EJDdS742ool0
0`00ooooo`0:ool01@00oooookFF[ED00ZDD00FM4jDDU=:LljED00:]M@06[EF]MJDDS95kcf</0V<<
0W>>00Ec[V=<LhicSV]]009c[P08Nln448@`Q32448aAQ12<<@:4<004Q12<<HA@S342Q302S5401hA@
S56448aAQ52<DH@`00><D@03Q32<DH@`00><D@03S76DLX@`00:4<008S56448@`Q32<DG`?Q32440:4
<009S35kkg_?Llic[V]]NlnDTZDD00:U=004YABU=:Dd[ED2YA@00iccYABLl`02W?<049cCW?>U59Bb
W??F^^Llga_NficcF^][CH@@Llikkh@`0W__00B4<7__Q11kk`:4<003S56D/V]]008aYP04>NOooooo
000<ool000_oo`05003ooooo@RQcSP02YC@03ZdeYCBU=:DDYCBUE;Ef]IJe]ZfE[CFDTW_?F^/2DXX0
1U[;F^]Rk5[[H^aJj`9S309[K@0<NjmccW__Nnn3l7__Q11kkh@@Nnn447__1h@@00=kkh@@Q1002H@@
00Akkh@@Q124<0J4400;Nnn447__Q11kkh@@Nnmkcg>^LhiSC002Hb`02g>^Q32LdjDD[CFU=:eEYEB]
EJED[ED00ZDd0ZDD00fLljCdW?>LljDD_MOFV^mmkigNfjDdNlmS;002Jfd00g>>Ljic[P03Ljh2Nll2
Nnl01H?`JdeBRRUU6><00_oo00<00?ooool02_oo00H00?ooooo>NE::S743U9801XaaW;>DTYBBQ32D
TP><L@05U;:<DIccU;:DLP02S5401XaaU9:DTXaAU;:<L@:DTP07S76DLXaaU9:<LIBBS7400iBB00><
LIBBS74019BB01BDLYBBU9:DTYAbS76DTXaaU7:<LIBbS56D/XaaU7:<DIBBQ32DTYBb0XaA00JL/haa
U9:DTYAbU;83U98028aAU9:<DIAbS76LdiBbS743S5403YAbS76DLXaAU9:<LIBBS76DLXaaU9:<LIBB
S742W?<028aAQ324<7>>S76]EIBbQ302U98039AbS76DTXaAU9:<LIBBS76DLW__Lhj<L@:Ll`;oo`03
003ooooo00[oo`07003ooooo]KJ]MJdeWA<01:DD00bTm:ee]GJ]UKFf[EFDTW__H`aJbg=^Hb`2Jfd0
5W>^JfecSV]=Nlmc[W__Q32448@`S36<DH@`Q12<LH@`S564<8`aS56<LHaA0Xaa00J<DH@`S76<DHaa
Q303S542Q30038aaS364<8aAS764<8aaQ12<DIAbQ32<D@:4<00AQ12<DHaAS564<8@@Q31kkg_?Lhi[
KG>>S56LdidC[EFU5002W?<2YA@05JDdYABU59ccYCBLlicCWA>U59ccW=?6>>LLga_W7;ggH^aS37_?
Q124<002Nnl00h@@Nnmkk`06Q1000haaU99c[P02>LL2ool00`00ooooo`0:ool000_oo`05003ooooo
BVUkc`02YC@2YA@01YdCYABLljDd[EFeUP:e]P0;YCBDTW>^F^]:JE::DZYJje[;F^]Jb`02F^/016<<
HdacSW>^0W_?17__00J447__Q11kkh@@Nnl3Q1001g`?Q11kkh@@O0n447`?00:44008Q32448@@Nnn4
47__Q11kk`>44004Nnn447__Q102Nnl00g_?Nnmkk`03Nnl2Ljh026]]JbeS36]=Llj<LIcCYC@2YA@0
19ccYCBU=:Dd0ZDD00jM4jDDW?>U59ccYABLljeeaSSW7>nMicbmehaA0V]=00M[KG>>Jhec[W>>Ljic
SP04Ljh01W_?Nnmkkf]]DXXaQP;oo`03003ooooo00[oo`08003oooooiaaBbYAbQ32DTP:<L@06S56D
TXaaU9:<DHaa0X@`00R<DHaaU;:D/XaaU7:<TIAb0haa00>D/XaAU9800haa00JDLXaaS76<LIBBS542
S7401YAbS96DTXaAU9:<D@><L@0BS56<LHaAU9:<LIBBS76DTXbAS56<LIBBS76DTXbAU7:<THaa0haA
0Xaa016DLXaaU9:4D8aaS96<DHbAU9:<LIcCU;:DTXaAS76<DHaa00:DTP03S76DLXaa00><L@0<S56D
TYBBU7:<LIBBW?><LG__S35c[X@`0ZeE00F<LHaAS56DTXaA00BDTP:<L@07U9:<LIBbNlmkkhaAW?<0
0_oo00<00?ooool02_oo00H00?ooooneUZeeYA@2W?<04:DDW?>LlidCYAB]MKFf[GF]EIBbNnmJje[;
H`acSV^=0V]=00IcSV]]Lhic[W_?Nnl2Q3000haAQ12<<@02Q302S5402h@`S764<8aAS76<DH@`S564
<8aAQ3000XaA00N4<8aaU;:<LHaAQ32<D@02Q3000haAS764<003S5400h@`S3644002Q102Q30038aA
Q32<DH@@Q31kcg__Lji[CH@@U;:Ll`>U=008U;:L/iccYABLljDDW?>U50>Ll`0=[EFM4jDD[EGNfmlK
iac>VH@@F^]c[W__Q1000W__00N4<8@@Nnn447__Q11l3`03Q1001H@`Q124D7__@TP00_oo00<00?oo
ool02_oo000;ool00`00ooooo`23ool00`00ooooo`0:ool06P00oooookggNnnDTYAbU;:DTXaaU9:<
LIbcS76DLXaAS764<9BBS56Tm9ccS76DTXaAU;84U982S74049BBQ12DLXaaU7:<LIAbU;:DLXaaU9:<
DIBbS56DLXaa1iBB00ND/XaAQ32<DHaaW;><L@02U98018aaS56DTXaa19BB00FD/YBBU9:<LIBB00><
L@08U9:<DIBBS56DLYcCU9:4<0:<L@09S36DTYBBU;:DTXaaU9:<LIBB00:<L@0IU9:DLXaAU7:DdYcC
Q12<<H@`NjnLdjeeS76DLXaaU9:<LIAbS56DLXaAU9:<DIBbS7400YBB00B<LH@`NnnD/P;oo`03003o
oooo00[oo`03003ooooo08?oo`03003ooooo00[oo`002ooo00<00?ooool0Pooo00<00?ooool02_oo
00<00?ooool0Pooo00<00?ooool02_oo00<00?ooool0Pooo00<00?ooool02_oo000;ool00`00oooo
o`23ool00`00ooooo`0:ool00`00ooooo`23ool00`00ooooo`0:ool00`00ooooo`23ool00`00oooo
o`0:ool000_oohL000coohL000coohL000coo`00ooooaOoo003oooo5ool00?ooolGoo`00\
\>"],
  ImageRangeCache->{{{0, 451.062}, {140.25, 0}} -> {-0.0829558, -0.0234425, 
  0.00701879, 0.00701879}, {{11.8125, 145.375}, {136.875, 
  3.3125}} -> {-14.4811, -6.05565, 0.998566, 0.998566}, {{158.688, 292.312}, {
  136.875, 3.3125}} -> {-161.071, -6.02282, 0.998098, 0.998098}, {{305.625, 
  439.188}, {136.875, 3.3125}} -> {-307.872, -6.05565, 0.998566, 0.998566}}]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"Microsoft Windows 3.0",
ScreenRectangle->{{0, 1280}, {0, 968}},
WindowToolbars->"EditBar",
CellGrouping->Manual,
WindowSize->{647, 648},
WindowMargins->{{89, Automatic}, {Automatic, 22}},
PrintingCopies->1,
PrintingPageRange->{Automatic, Automatic},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, -1}},
ShowCellLabel->True,
ShowCellTags->False,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False},
StyleDefinitions -> "ArticleClassic.nb"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1709, 49, 63, 0, 111, "Title"],
Cell[1775, 51, 162, 2, 72, "Address"],
Cell[1940, 55, 76, 2, 31, "Input"],

Cell[CellGroupData[{
Cell[2041, 61, 92, 2, 78, "Section"],
Cell[2136, 65, 736, 15, 112, "Text"],
Cell[2875, 82, 265, 5, 25, "NumberedEquation"],
Cell[3143, 89, 594, 13, 78, "Text"],
Cell[3740, 104, 221, 7, 27, "NumberedEquation"],
Cell[3964, 113, 996, 36, 78, "Text"],
Cell[4963, 151, 158, 5, 27, "NumberedEquation"],
Cell[5124, 158, 295, 8, 44, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5456, 171, 73, 0, 56, "Section"],
Cell[5532, 173, 139, 3, 27, "Text"],
Cell[5674, 178, 261, 7, 27, "NumberedEquation"],
Cell[5938, 187, 2415, 67, 163, "Text"],
Cell[8356, 256, 228, 7, 27, "NumberedEquation"],
Cell[8587, 265, 749, 21, 61, "Text"],
Cell[9339, 288, 72, 0, 24, "Caption"],
Cell[9414, 290, 138, 3, 51, "Input"],
Cell[9555, 295, 159, 4, 25, "Caption"],

Cell[CellGroupData[{
Cell[9739, 303, 136, 3, 31, "Input"],
Cell[9878, 308, 2139, 76, 137, "Output"]
}, Open  ]],
Cell[12032, 387, 1193, 32, 113, "Text"],

Cell[CellGroupData[{
Cell[13250, 423, 153, 3, 31, "Input"],
Cell[13406, 428, 1496, 52, 73, "Output"]
}, Open  ]],
Cell[14917, 483, 149, 3, 44, "Text"],
Cell[15069, 488, 136, 3, 25, "NumberedEquation"],
Cell[15208, 493, 392, 12, 44, "Text"],

Cell[CellGroupData[{
Cell[15625, 509, 159, 3, 51, "Input"],
Cell[15787, 514, 592, 13, 137, "Output"]
}, Open  ]],
Cell[16394, 530, 69, 0, 27, "Text"],
Cell[16466, 532, 133, 3, 51, "Input"],
Cell[16602, 537, 2140, 76, 137, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[18779, 618, 53, 0, 56, "Section"],
Cell[18835, 620, 354, 6, 61, "Text"],
Cell[19192, 628, 414, 12, 31, "NumberedEquation"],
Cell[19609, 642, 317, 5, 61, "Text"],
Cell[19929, 649, 292, 8, 27, "NumberedEquation"],
Cell[20224, 659, 348, 6, 61, "Text"],
Cell[20575, 667, 238, 4, 28, "NumberedEquation"],
Cell[20816, 673, 839, 24, 65, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[21692, 702, 52, 0, 56, "Section"],
Cell[21747, 704, 935, 27, 78, "Text"],
Cell[22685, 733, 255, 8, 30, "NumberedEquation"],
Cell[22943, 743, 660, 16, 78, "Text"],
Cell[23606, 761, 40637, 1397, 197, 14678, 1072, "GraphicsData", 
"PostScript", "Graphics"],
Cell[64246, 2160, 131, 2, 28, "SmallText"],
Cell[64380, 2164, 403, 8, 61, "Text"],
Cell[64786, 2174, 18472, 692, 93, 7639, 554, "GraphicsData", 
"PostScript", "Graphics"],
Cell[83261, 2868, 82, 1, 28, "SmallText"],
Cell[83346, 2871, 319, 11, 44, "Text"],
Cell[83668, 2884, 349, 10, 27, "NumberedEquation"],
Cell[84020, 2896, 644, 24, 44, "Text"],
Cell[84667, 2922, 311, 9, 45, "Text"],
Cell[84981, 2933, 388, 6, 61, "Text"],

Cell[CellGroupData[{
Cell[85394, 2943, 88, 1, 31, "Input"],
Cell[85485, 2946, 2086, 73, 105, "Output"]
}, Open  ]],
Cell[87586, 3022, 175, 2, 44, "Text"],

Cell[CellGroupData[{
Cell[87786, 3028, 159, 3, 31, "Input"],
Cell[87948, 3033, 38, 1, 30, "Output"]
}, Open  ]],
Cell[88001, 3037, 465, 12, 61, "Text"],

Cell[CellGroupData[{
Cell[88491, 3053, 120, 3, 31, "Input"],
Cell[88614, 3058, 504, 11, 105, "Output"]
}, Open  ]],
Cell[89133, 3072, 313, 8, 27, "Text"],

Cell[CellGroupData[{
Cell[89471, 3084, 106, 2, 51, "Input"],
Cell[89580, 3088, 2086, 73, 105, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[91715, 3167, 27, 0, 56, "Section"],
Cell[91745, 3169, 741, 11, 112, "Text"],
Cell[92489, 3182, 126, 3, 31, "Input"],
Cell[92618, 3187, 159, 5, 24, "Caption"],
Cell[92780, 3194, 278, 6, 64, "Input"],
Cell[93061, 3202, 73, 0, 24, "Caption"],
Cell[93137, 3204, 97, 2, 43, "Input"],
Cell[93237, 3208, 53, 0, 24, "Caption"],

Cell[CellGroupData[{
Cell[93315, 3212, 267, 6, 71, "Input"],
Cell[93585, 3220, 252912, 4366, 150, 103494, 2517, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

