(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    188682,       5144]*)
(*NotebookOutlinePosition[    189689,       5178]*)
(*  CellTagsIndexPosition[    189645,       5174]*)
(*WindowFrame->Normal*)



Notebook[{
Cell["DISCRETE-TIME FOURIER TRANSFORM", "Title",
  Evaluatable->False,
  CellHorizontalScrolling->False,
  TextAlignment->Center,
  AspectRatioFixed->True],

Cell[BoxData[
    \(<< ImageProcessing`\)], "Input",
  CellLabel->"In[1]:="],

Cell[BoxData[
    \(<< SignalPlot`\)], "Input",
  CellLabel->"In[2]:="],

Cell[CellGroupData[{

Cell[TextData["INTRODUCTION"], "Section",
  Evaluatable->False,
  CellHorizontalScrolling->False,
  AspectRatioFixed->True],

Cell["\<\
Fourier theory is a fundamental analysis tool in discrete-time signals and \
systems. An understanding of the basic concepts of discrete-time Fourier \
synthesis and analysis is indispensable, since the rapid advancement of \
digital computer technology and integrated circuit fabrication has made \
digital signal processing preferrable to analog in numerous application \
areas.\
\>", "Text",
  Evaluatable->False,
  CellHorizontalScrolling->False,
  AspectRatioFixed->True],

Cell["\<\
\"While continuous-time Fourier analysis can be traced to the investigation \
of problems in mathematical physics in the 1700's, the tools for analyzing \
discrete-time signals and systems have their own distinct roots. In \
particular, discrete-time concepts and methods are fundamental to the \
discipline of numerical analysis. Formulas for the processing of discrete \
sers of data points to produce numerical approximations for interpolation, \
integration, and differentiation were being investigated as early as the time \
of Newton in the 1600's... In the 1940s and 1950s major steps forward were \
taken in the development of discrete-time techniques in general and in the \
use of the tools of discrete-time Fourier analysis in particular. The reasons \
for this push forward were the increasing use and capabilities of digital \
computers and the development of design methods for sampled-data systems, \
that is, discrete-time systems for the processing of sampled continuous-time \
signals.\" [Oppenheim & Willsky, 1983] \
\>", "Text",
  Evaluatable->False,
  CellHorizontalScrolling->False,
  AspectRatioFixed->True,
  FontFamily->"Times New Roman",
  FontSize->10,
  FontWeight->"Plain",
  FontSlant->"Plain",
  FontTracking->"Plain",
  FontColor->GrayLevel[0],
  Background->GrayLevel[1],
  FontVariations->{"Underline"->False,
  "Outline"->False,
  "Shadow"->False}],

Cell["\<\
The discrete-time Fourier transform plays the same role as its classic \
continuous-time counterpart. Conceptually, the transforms are same, both \
decompose aperiodic signals into a continuum of frequencies. \
\>", "Text",
  Evaluatable->False,
  CellHorizontalScrolling->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["DTFT ANALYSIS FORMULA", "Section",
  PageWidth->WindowWidth,
  Evaluatable->False,
  CellHorizontalScrolling->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "The discrete-time Fourier transform of a sequence ",
  Cell[BoxData[
      \(TraditionalForm\`x[n]\)]],
  " is defined by the following infinite summation:"
}], "Text",
  PageWidth->WindowWidth,
  Evaluatable->False,
  CellHorizontalScrolling->False,
  AspectRatioFixed->True,
  FontFamily->"Times New Roman",
  FontSize->12,
  FontWeight->"Plain",
  FontSlant->"Plain",
  FontTracking->"Plain",
  FontColor->GrayLevel[0],
  Background->GrayLevel[1],
  FontVariations->{"Underline"->False,
  "Outline"->False,
  "Shadow"->False}],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm
    \`X(\[Omega])\  = \ 
      \[Sum]\+\(n = \(-\[Infinity]\)\)\%\[Infinity] x[n]\ 
          \[ExponentialE]\^\(\(-\ j\)\ \[Omega]\ n\)\)]]], "NumberedEquation",\

  PageWidth->WindowWidth],

Cell[TextData[{
  "where, \[Omega] is the radial frequency. The function ",
  Cell[BoxData[
      \(TraditionalForm\`X(\[Omega])\)]],
  " is referred to as the discrete-time Fourier transform (DTFT) of of the \
discrete-time sequence ",
  Cell[BoxData[
      \(TraditionalForm\`x[n]\)]],
  ". A major difference between the continuous- and discrete-time Fourier \
transforms is the periodicity of ",
  Cell[BoxData[
      \(TraditionalForm\`X(\[Omega])\)]],
  ". It is easy to show that ",
  Cell[BoxData[
      \(TraditionalForm\`X(\[Omega])\)]],
  " is periodic with a period ",
  Cell[BoxData[
      \(TraditionalForm\`T = 2  \[Pi]\)]],
  "."
}], "Text",
  PageWidth->WindowWidth,
  Evaluatable->False,
  CellHorizontalScrolling->False,
  AspectRatioFixed->True,
  FontFamily->"Times New Roman",
  FontSize->12,
  FontWeight->"Plain",
  FontSlant->"Plain",
  FontTracking->"Plain",
  FontColor->GrayLevel[0],
  Background->GrayLevel[1],
  FontVariations->{"Underline"->False,
  "Outline"->False,
  "Shadow"->False}],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm
    \`X(\[Omega] + 2  \[Pi])\  = \ \ 
      \(\[Sum]\+\(n = \(-\[Infinity]\)\)\%\[Infinity] x[n]\ 
            \[ExponentialE]\^\(\(-\ j\)\ \((\[Omega] + 2  \[Pi])\)\ n\) = \ 
        \(\[ExponentialE]\^\(\ \(-\ j\)\ 2  \[Pi]\ n\)\ 
            \(\[Sum]\+\(n = \(-\[Infinity]\)\)\%\[Infinity] x[n]\ 
                \[ExponentialE]\^\(\(-\ j\)\ \[Omega]\ n\)\)\  = \ 
          X(\[Omega])\)\)\)]]], "NumberedEquation",
  PageWidth->WindowWidth],

Cell[TextData[{
  "where we have used the fact that ",
  Cell[BoxData[
      \(TraditionalForm
      \`\[ExponentialE]\^\(\ \(-\ j\)\ 2  \[Pi]\ n\) = 1\)]],
  ". The interval ",
  Cell[BoxData[
      \(TraditionalForm
      \`\(-\[Pi]\)\  \[LessEqual] \[Omega] \[LessEqual] \ \[Pi]\)]],
  " is known as the fundamental interval. As an example consider the DTFT of \
an infinite-length causal, exponential signal ",
  Cell[BoxData[
      \(TraditionalForm\`x[n] = a\^n\ u[n]\)]],
  ", with ",
  Cell[BoxData[
      \(TraditionalForm\`\( | a | \( < 1\)\)\)]],
  ", and ",
  Cell[BoxData[
      \(TraditionalForm\`u[n]\)]],
  " is the unit step sequence:"
}], "Text",
  PageWidth->WindowWidth],

Cell[TextData[Cell[BoxData[
    FormBox[
      RowBox[{\(u[n]\), " ", "=", " ", 
        RowBox[{"{", GridBox[{
              {\(1, \), \(n \[GreaterEqual] 0\)},
              {"0", \(n < 0\)}
              }]}]}], TraditionalForm]]]], "NumberedEquation"],

Cell["Here we define and plot the signal.", "Text"],

Cell[BoxData[
    \(x[n_] := 0; \nx[n_] := a\^n\ \  /; \ n \[GreaterEqual] 0; \)], "Input",
  CellLabel->"In[3]:=",
  PageWidth->WindowWidth,
  AspectRatioFixed->True,
  FontFamily->"Courier New",
  FontSize->12,
  FontWeight->"Bold",
  FontColor->GrayLevel[0],
  Background->GrayLevel[1]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(ListSignalPlot[
      Evaluate[Table[{n, x[n]\  /. \ a -> 2\/3}, \ {n, \(-5\), 15}]]\ , \ 
      PlotRange -> All]; \)\)], "Input",
  CellLabel->"In[4]:=",
  PageWidth->WindowWidth],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.261905 0.047619 0.0147151 0.588604 [
[.02381 .00222 -6 -9 ]
[.02381 .00222 6 0 ]
[.5 .00222 -3 -9 ]
[.5 .00222 3 0 ]
[.7381 .00222 -6 -9 ]
[.7381 .00222 6 0 ]
[.97619 .00222 -6 -9 ]
[.97619 .00222 6 0 ]
[.2494 .13244 -18 -4.5 ]
[.2494 .13244 0 4.5 ]
[.2494 .25016 -18 -4.5 ]
[.2494 .25016 0 4.5 ]
[.2494 .36788 -18 -4.5 ]
[.2494 .36788 0 4.5 ]
[.2494 .4856 -18 -4.5 ]
[.2494 .4856 0 4.5 ]
[.2494 .60332 -6 -4.5 ]
[.2494 .60332 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.02381 .01472 m
.02381 .02097 L
s
[(-5)] .02381 .00222 0 1 Mshowa
.5 .01472 m
.5 .02097 L
s
[(5)] .5 .00222 0 1 Mshowa
.7381 .01472 m
.7381 .02097 L
s
[(10)] .7381 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(15)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.07143 .01472 m
.07143 .01847 L
s
.11905 .01472 m
.11905 .01847 L
s
.16667 .01472 m
.16667 .01847 L
s
.21429 .01472 m
.21429 .01847 L
s
.30952 .01472 m
.30952 .01847 L
s
.35714 .01472 m
.35714 .01847 L
s
.40476 .01472 m
.40476 .01847 L
s
.45238 .01472 m
.45238 .01847 L
s
.54762 .01472 m
.54762 .01847 L
s
.59524 .01472 m
.59524 .01847 L
s
.64286 .01472 m
.64286 .01847 L
s
.69048 .01472 m
.69048 .01847 L
s
.78571 .01472 m
.78571 .01847 L
s
.83333 .01472 m
.83333 .01847 L
s
.88095 .01472 m
.88095 .01847 L
s
.92857 .01472 m
.92857 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.2619 .13244 m
.26815 .13244 L
s
[(0.2)] .2494 .13244 1 0 Mshowa
.2619 .25016 m
.26815 .25016 L
s
[(0.4)] .2494 .25016 1 0 Mshowa
.2619 .36788 m
.26815 .36788 L
s
[(0.6)] .2494 .36788 1 0 Mshowa
.2619 .4856 m
.26815 .4856 L
s
[(0.8)] .2494 .4856 1 0 Mshowa
.2619 .60332 m
.26815 .60332 L
s
[(1)] .2494 .60332 1 0 Mshowa
.125 Mabswid
.2619 .04415 m
.26565 .04415 L
s
.2619 .07358 m
.26565 .07358 L
s
.2619 .10301 m
.26565 .10301 L
s
.2619 .16187 m
.26565 .16187 L
s
.2619 .1913 m
.26565 .1913 L
s
.2619 .22073 m
.26565 .22073 L
s
.2619 .27959 m
.26565 .27959 L
s
.2619 .30902 m
.26565 .30902 L
s
.2619 .33845 m
.26565 .33845 L
s
.2619 .39731 m
.26565 .39731 L
s
.2619 .42674 m
.26565 .42674 L
s
.2619 .45617 m
.26565 .45617 L
s
.2619 .51503 m
.26565 .51503 L
s
.2619 .54446 m
.26565 .54446 L
s
.2619 .57389 m
.26565 .57389 L
s
.25 Mabswid
.2619 0 m
.2619 .61803 L
s
.5 Mabswid
.02381 .01472 m
.02381 .01472 L
s
.01888 w
.02381 .01472 Mdot
.5 Mabswid
.07143 .01472 m
.07143 .01472 L
s
.01888 w
.07143 .01472 Mdot
.5 Mabswid
.11905 .01472 m
.11905 .01472 L
s
.01888 w
.11905 .01472 Mdot
.5 Mabswid
.16667 .01472 m
.16667 .01472 L
s
.01888 w
.16667 .01472 Mdot
.5 Mabswid
.21429 .01472 m
.21429 .01472 L
s
.01888 w
.21429 .01472 Mdot
.5 Mabswid
.2619 .01472 m
.2619 .60332 L
s
.01888 w
.2619 .60332 Mdot
.5 Mabswid
.30952 .01472 m
.30952 .40712 L
s
.01888 w
.30952 .40712 Mdot
.5 Mabswid
.35714 .01472 m
.35714 .27632 L
s
.01888 w
.35714 .27632 Mdot
.5 Mabswid
.40476 .01472 m
.40476 .18912 L
s
.01888 w
.40476 .18912 Mdot
.5 Mabswid
.45238 .01472 m
.45238 .13098 L
s
.01888 w
.45238 .13098 Mdot
.5 Mabswid
.5 .01472 m
.5 .09223 L
s
.01888 w
.5 .09223 Mdot
.5 Mabswid
.54762 .01472 m
.54762 .06639 L
s
.01888 w
.54762 .06639 Mdot
.5 Mabswid
.59524 .01472 m
.59524 .04916 L
s
.01888 w
.59524 .04916 Mdot
.5 Mabswid
.64286 .01472 m
.64286 .03768 L
s
.01888 w
.64286 .03768 Mdot
.5 Mabswid
.69048 .01472 m
.69048 .03003 L
s
.01888 w
.69048 .03003 Mdot
.5 Mabswid
.7381 .01472 m
.7381 .02492 L
s
.01888 w
.7381 .02492 Mdot
.5 Mabswid
.78571 .01472 m
.78571 .02152 L
s
.01888 w
.78571 .02152 Mdot
.5 Mabswid
.83333 .01472 m
.83333 .01925 L
s
.01888 w
.83333 .01925 Mdot
.5 Mabswid
.88095 .01472 m
.88095 .01774 L
s
.01888 w
.88095 .01774 Mdot
.5 Mabswid
.92857 .01472 m
.92857 .01673 L
s
.01888 w
.92857 .01673 Mdot
.5 Mabswid
.97619 .01472 m
.97619 .01606 L
s
.01888 w
.97619 .01606 Mdot
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[4]:=",
  PageWidth->WindowWidth,
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo000@Ool0
0`00Oomoo`1lOol00`00Oomoo`0iOol50002Ool00`00Oomoo`0fOol50002Ool00`00Oomoo`0;Ool0
00moo`03001oo`0007aoo`03001oo`0003aoo`07001oogooOol007oo0000>Goo00L007ooOomoo`00
Ool0000<Ool000Yoo`<000Aoo`03001oogoo07aoo`03001oogoo03Yoo`07001oogooOol007oo0000
>Goo00<007ooOol00goo00<007ooOol02Woo000?Ool2001mOol2000mOol01`00Oomoogoo001oo`00
03Uoo`04001oogooOol2000=Ool000moo`03001oogoo07aoo`03001oogoo03aoo`07001oogooOol0
07oo0000>Goo00D007ooOomoo`0000ioo`003goo0`00O7oo0`00>goo0P0017oo00<007ooOol0=goo
0P000goo0`0037oo003oOolQOol004ioo`03001oogoo0<moo`00CWoo00<007ooOol0cgoo000<Ool3
000:Ool3000:Ool3000:Ool3000:Ool3000;Ool00`00Oomoo`2nOol3000>Ool000]oo`D000Qoo`D0
00Qoo`D000Qoo`D000Qoo`D000Yoo`03001oogoo09Qoo`<000Yoo`<000Uoo`<000Uoo`D000eoo`00
1gooo`004P0027oo000;Ool50008Ool50008Ool50008Ool50008Ool5000:Ool00`00Oomoo`0:Ool0
0`00Oomoo`0:Ool00`00Oomoo`0:Ool00`00Oomoo`0:Ool00`00Oomoo`0:Ool00`00Oomoo`0:Ool0
0`00Oomoo`0:Ool00`00Oomoo`0:Ool00`00Oomoo`0:Ool00`00Oomoo`09Ool30009Ool50008Ool5
0008Ool50007Ool50008Ool5000=Ool000aoo`<000Yoo`<000Yoo`<000Yoo`<000Yoo`<000]oo`03
001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03
001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Uoo`<000Uoo`D000Qoo`D0
00Qoo`D000Qoo`D000Moo`D000Uoo`<000ioo`00CWoo00<007ooOol02Woo00<007ooOol02Woo00<0
07ooOol02Woo00<007ooOol02Woo00<007ooOol02Woo00<007ooOol02Woo00<007ooOol02Woo00<0
07ooOol02Woo00<007ooOol027oo1@0027oo1@0027oo1@002Goo0`002Woo0`002Goo0`006goo001>
Ool00`00Oomoo`0:Ool00`00Oomoo`0:Ool00`00Oomoo`0:Ool00`00Oomoo`0:Ool00`00Oomoo`0:
Ool00`00Oomoo`0:Ool00`00Oomoo`0:Ool00`00Oomoo`09Ool30009Ool50008Ool50009Ool30011
Ool004ioo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001o
ogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Qoo`D000Qoo`D000Uoo`<004io
o`00CWoo00<007ooOol02Woo00<007ooOol02Woo00<007ooOol02Woo00<007ooOol02Woo00<007oo
Ool02Woo00<007ooOol02Woo00<007ooOol02Woo00<007ooOol027oo1@002Goo0`00Fgoo001>Ool0
0`00Oomoo`0:Ool00`00Oomoo`0:Ool00`00Oomoo`0:Ool00`00Oomoo`0:Ool00`00Oomoo`0:Ool0
0`00Oomoo`0:Ool00`00Oomoo`09Ool30009Ool5001WOol004ioo`8000]oo`03001oogoo00Yoo`03
001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Qoo`D0
00Uoo`<006Qoo`00CWoo00<007ooOol02Woo00<007ooOol02Woo00<007ooOol02Woo00<007ooOol0
2Woo00<007ooOol02Woo00<007ooOol02Woo00<007ooOol027oo1@00M7oo001>Ool00`00Oomoo`0:
Ool00`00Oomoo`0:Ool00`00Oomoo`0:Ool00`00Oomoo`0:Ool00`00Oomoo`0:Ool00`00Oomoo`0:
Ool00`00Oomoo`08Ool5001dOol004ioo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yo
o`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Uoo`<007Eoo`00CWoo
00<007ooOol02Woo00<007ooOol02Woo00<007ooOol02Woo00<007ooOol02Woo00<007ooOol02Woo
00<007ooOol02Goo0`00PWoo001>Ool00`00Oomoo`0:Ool00`00Oomoo`0:Ool00`00Oomoo`0:Ool0
0`00Oomoo`0:Ool00`00Oomoo`0:Ool00`00Oomoo`08Ool50021Ool004ioo`03001oogoo00Yoo`03
001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Qoo`D0
085oo`00CWoo00<007ooOol02Woo00<007ooOol02Woo00<007ooOol02Woo00<007ooOol02Woo00<0
07ooOol02Woo00<007ooOol027oo1@00PGoo001>Ool2000;Ool00`00Oomoo`0:Ool00`00Oomoo`0:
Ool00`00Oomoo`0:Ool00`00Oomoo`0:Ool00`00Oomoo`09Ool30022Ool004ioo`03001oogoo00Yo
o`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo08io
o`00CWoo00<007ooOol02Woo00<007ooOol02Woo00<007ooOol02Woo00<007ooOol02Woo00<007oo
Ool02Woo00<007ooOol0SWoo001>Ool00`00Oomoo`0:Ool00`00Oomoo`0:Ool00`00Oomoo`0:Ool0
0`00Oomoo`0:Ool00`00Oomoo`09Ool3002?Ool004ioo`03001oogoo00Yoo`03001oogoo00Yoo`03
001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Qoo`D008ioo`00CWoo00<007ooOol02Woo00<0
07ooOol02Woo00<007ooOol02Woo00<007ooOol02Woo00<007ooOol027oo1@00SWoo001>Ool00`00
Oomoo`0:Ool00`00Oomoo`0:Ool00`00Oomoo`0:Ool00`00Oomoo`0:Ool00`00Oomoo`08Ool5002>
Ool004ioo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001o
ogoo00Uoo`<008moo`00CWoo0P002goo00<007ooOol02Woo00<007ooOol02Woo00<007ooOol02Woo
00<007ooOol0Vgoo001>Ool00`00Oomoo`0:Ool00`00Oomoo`0:Ool00`00Oomoo`0:Ool00`00Oomo
o`0:Ool00`00Oomoo`2KOol004ioo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03
001oogoo00Yoo`03001oogoo09]oo`00CWoo00<007ooOol02Woo00<007ooOol02Woo00<007ooOol0
2Woo00<007ooOol02Woo00<007ooOol0Vgoo001>Ool00`00Oomoo`0:Ool00`00Oomoo`0:Ool00`00
Oomoo`0:Ool00`00Oomoo`0:Ool00`00Oomoo`2KOol004ioo`03001oogoo00Yoo`03001oogoo00Yo
o`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo09]oo`00?Woo00<007ooOol00Woo00@007oo
Oomoo`<000Aoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Uoo`<0
09aoo`00?Goo00<007oo00001goo00<007ooOol017oo00<007ooOol02Woo00<007ooOol02Woo00<0
07ooOol02Woo00<007ooOol027oo1@00Vgoo000mOol00`00Ool00008Ool00`00Oomoo`03Ool3000:
Ool00`00Oomoo`0:Ool00`00Oomoo`0:Ool00`00Oomoo`08Ool5002KOol003eoo`03001oo`0000Qo
o`03001oogoo00=oo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Qo
o`D009]oo`00?Goo00<007oo00001goo00<007oo000017oo00<007ooOol02Woo00<007ooOol02Woo
00<007ooOol02Woo00<007ooOol02Goo0`00W7oo000nOol00`00Oomoo`07Ool00`00Oomoo`03Ool0
0`00Oomoo`0:Ool00`00Oomoo`0:Ool00`00Oomoo`0:Ool00`00Oomoo`2XOol004ioo`03001oogoo
00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo0:Qoo`00CWoo00<007ooOol02Woo00<0
07ooOol02Woo00<007ooOol02Woo00<007ooOol0Z7oo001>Ool00`00Oomoo`0:Ool00`00Oomoo`0:
Ool00`00Oomoo`0:Ool00`00Oomoo`2XOol004ioo`03001oogoo00Yoo`03001oogoo00Yoo`03001o
ogoo00Yoo`03001oogoo0:Qoo`00CWoo0P002goo00<007ooOol02Woo00<007ooOol02Woo00<007oo
Ool0Z7oo001>Ool00`00Oomoo`0:Ool00`00Oomoo`0:Ool00`00Oomoo`0:Ool00`00Oomoo`2XOol0
04ioo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo0:Qoo`00CWoo00<0
07ooOol02Woo00<007ooOol02Woo00<007ooOol02Woo00<007ooOol0Z7oo001>Ool00`00Oomoo`0:
Ool00`00Oomoo`0:Ool00`00Oomoo`0:Ool00`00Oomoo`2XOol004ioo`03001oogoo00Yoo`03001o
ogoo00Yoo`03001oogoo00Uoo`<00:Uoo`00CWoo00<007ooOol02Woo00<007ooOol02Woo00<007oo
Ool027oo1@00Z7oo001>Ool00`00Oomoo`0:Ool00`00Oomoo`0:Ool00`00Oomoo`08Ool5002XOol0
04ioo`8000]oo`03001oogoo00Yoo`03001oogoo00Qoo`D00:Qoo`00CWoo00<007ooOol02Woo00<0
07ooOol02Woo00<007ooOol02Goo0`00ZGoo001>Ool00`00Oomoo`0:Ool00`00Oomoo`0:Ool00`00
Oomoo`2eOol004ioo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo0;Eoo`00CWoo00<007oo
Ool02Woo00<007ooOol02Woo00<007ooOol0]Goo001>Ool00`00Oomoo`0:Ool00`00Oomoo`0:Ool0
0`00Oomoo`2eOol004ioo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo0;Eoo`00CWoo00<0
07ooOol02Woo00<007ooOol02Woo00<007ooOol0]Goo001>Ool2000;Ool00`00Oomoo`0:Ool00`00
Oomoo`2eOol004ioo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo0;Eoo`00CWoo00<007oo
Ool02Woo00<007ooOol02Woo00<007ooOol0]Goo001>Ool00`00Oomoo`0:Ool00`00Oomoo`0:Ool0
0`00Oomoo`2eOol004ioo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo0;Eoo`00CWoo00<0
07ooOol02Woo00<007ooOol02Woo00<007ooOol0]Goo000nOol00`00Oomoo`02Ool00`00Oomoo`02
Ool30003Ool00`00Oomoo`0:Ool00`00Oomoo`0:Ool00`00Oomoo`2eOol003eoo`03001oo`0000Uo
o`03001oogoo009oo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo0;Eoo`00?Goo00<007oo
00001goo10000goo0`002Woo00<007ooOol02Woo00<007ooOol0]Goo000mOol00`00Ool00007Ool0
0`00Ool00004Ool00`00Oomoo`0:Ool00`00Oomoo`0:Ool00`00Oomoo`2eOol003eoo`03001oo`00
00Qoo`8000Aoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo0;Eoo`00?Woo00<007ooOol0
27oo00<007ooOol00Woo00<007ooOol02Woo00<007ooOol02Woo00<007ooOol0]Goo001>Ool00`00
Oomoo`0:Ool00`00Oomoo`0:Ool00`00Oomoo`2eOol004ioo`03001oogoo00Yoo`03001oogoo00Uo
o`<00;Ioo`00CWoo00<007ooOol02Woo00<007ooOol027oo1@00]Goo001>Ool00`00Oomoo`0:Ool0
0`00Oomoo`08Ool5002eOol004ioo`8000]oo`03001oogoo00Qoo`D00;Eoo`00CWoo00<007ooOol0
2Woo00<007ooOol02Goo0`00]Woo001>Ool00`00Oomoo`0:Ool00`00Oomoo`32Ool004ioo`03001o
ogoo00Yoo`03001oogoo0<9oo`00CWoo00<007ooOol02Woo00<007ooOol0`Woo001>Ool00`00Oomo
o`0:Ool00`00Oomoo`32Ool004ioo`03001oogoo00Yoo`03001oogoo0<9oo`00CWoo00<007ooOol0
2Woo00<007ooOol0`Woo001>Ool2000;Ool00`00Oomoo`32Ool004ioo`03001oogoo00Yoo`03001o
ogoo0<9oo`00CWoo00<007ooOol02Woo00<007ooOol0`Woo001>Ool00`00Oomoo`0:Ool00`00Oomo
o`32Ool004ioo`03001oogoo00Yoo`03001oogoo0<9oo`00CWoo00<007ooOol02Woo00<007ooOol0
`Woo001>Ool00`00Oomoo`0:Ool00`00Oomoo`32Ool004ioo`03001oogoo00Yoo`03001oogoo0<9o
o`00CWoo0P002goo00<007ooOol0`Woo001>Ool00`00Oomoo`0:Ool00`00Oomoo`32Ool004ioo`03
001oogoo00Yoo`03001oogoo0<9oo`00CWoo00<007ooOol02Woo00<007ooOol0`Woo001>Ool00`00
Oomoo`0:Ool00`00Oomoo`32Ool004ioo`03001oogoo00Yoo`03001oogoo0<9oo`00?Woo00<007oo
Ool00Woo00@007ooOomoo`8000Eoo`03001oogoo00Yoo`03001oogoo0<9oo`00?Goo00<007oo0000
1goo00<007oo000017oo00<007ooOol02Woo00<007ooOol0`Woo000mOol00`00Ool00007Ool00`00
Ool00004Ool3000:Ool00`00Oomoo`32Ool003eoo`03001oo`0000Moo`8000Eoo`03001oogoo00Yo
o`03001oogoo0<9oo`00?Goo00<007oo00001goo00<007ooOol017oo00<007ooOol02Woo00<007oo
Ool0`Woo000nOol00`00Oomoo`07Ool20004Ool00`00Oomoo`0:Ool00`00Oomoo`32Ool004ioo`03
001oogoo00Yoo`03001oogoo0<9oo`00CWoo00<007ooOol02Woo00<007ooOol0`Woo001>Ool00`00
Oomoo`0:Ool00`00Oomoo`32Ool004ioo`03001oogoo00Yoo`03001oogoo0<9oo`00CWoo0P002goo
00<007ooOol0`Woo001>Ool00`00Oomoo`09Ool30033Ool004ioo`03001oogoo00Qoo`D00<9oo`00
CWoo00<007ooOol027oo1@00`Woo001>Ool00`00Oomoo`08Ool50032Ool004ioo`03001oogoo00Uo
o`<00<=oo`00CWoo00<007ooOol0cgoo001>Ool00`00Oomoo`3?Ool004ioo`800=1oo`00CWoo00<0
07ooOol0cgoo001>Ool00`00Oomoo`3?Ool004ioo`03001oogoo0<moo`00CWoo00<007ooOol0cgoo
001>Ool00`00Oomoo`3?Ool004ioo`03001oogoo0<moo`00CWoo00<007ooOol0cgoo001>Ool2003@
Ool004ioo`03001oogoo0<moo`00CWoo00<007ooOol0cgoo001>Ool00`00Oomoo`3?Ool004ioo`03
001oogoo0<moo`00CWoo00<007ooOol0cgoo000nOol00`00Oomoo`02Ool00`00Oomoo`02Ool00`00
Oomoo`03Ool00`00Oomoo`3?Ool003eoo`03001oo`0000Moo`03001oo`0000Aoo`03001oogoo0<mo
o`00?Goo00<007oo00001goo00<007oo000017oo0`00cgoo000mOol00`00Ool00008Ool00`00Oomo
o`03Ool00`00Oomoo`3?Ool003eoo`03001oo`0000Moo`03001oo`0000Aoo`03001oogoo0<moo`00
?Woo00<007ooOol01goo00<007ooOol00goo00<007ooOol0cgoo001>Ool00`00Oomoo`3?Ool004io
o`03001oogoo0<moo`00CWoo00<007ooOol0cgoo001>Ool00`00Oomoo`3?Ool004ioo`800=1oo`00
CWoo00<007ooOol0cgoo001>Ool00`00Oomoo`3?Ool004ioo`03001oogoo0<moo`00CWoo00<007oo
Ool0cgoo001>Ool00`00Oomoo`3?Ool004ioo`03001oogoo0<moo`00CWoo00<007ooOol0cgoo001>
Ool2003@Ool004ioo`03001oogoo0<moo`00CWoo00<007ooOol0cgoo001>Ool00`00Oomoo`3?Ool0
04ioo`03001oogoo0<moo`00CWoo00<007ooOol0cgoo001>Ool00`00Oomoo`3?Ool004ioo`03001o
ogoo0<moo`00CWoo0P00d7oo001>Ool00`00Oomoo`3?Ool004ioo`03001oogoo0<moo`00CWoo00<0
07ooOol0cgoo001>Ool00`00Oomoo`3?Ool004ioo`03001oogoo0<moo`00AWoo1@000Woo0`00d7oo
0018Ool01000Oomoogoo1@00cgoo0018Ool01000Oomoogoo1@00cgoo0018Ool01000Oomoogoo1@00
cgoo0018Ool00`00Oomoo`02Ool3003@Ool004Moo`8000Eoo`03001oogoo0<moo`00CWoo00<007oo
Ool0cgoo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-6.08335, -0.07747, 
  0.0772359, 0.00624851}}]
}, Open  ]],

Cell["Using (1) we get DTFT of a causal exponential sequence as", "Text",
  PageWidth->WindowWidth,
  Evaluatable->False,
  CellHorizontalScrolling->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[Sum]\+\(n = 0\)\%\[Infinity] a\^n\ 
        \[ExponentialE]\^\(\ \(-\ \[ImaginaryI]\)\ \[Omega]\ n\)\)], "Input",
  CellLabel->"In[10]:=",
  PageWidth->WindowWidth,
  AspectRatioFixed->True],

Cell[BoxData[
    \(E\^\(I\ \[Omega]\)\/\(\(-a\) + E\^\(I\ \[Omega]\)\)\)], "Output",
  CellLabel->"Out[10]="]
}, Open  ]],

Cell[TextData[{
  "which for a value of ",
  Cell[BoxData[
      \(TraditionalForm\`a = 2\/3\)]],
  " has the following magnitude response,"
}], "Text",
  PageWidth->WindowWidth,
  Evaluatable->False,
  CellHorizontalScrolling->False],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Plot[{
        Abs[E\^\(I\ \[Omega]\)\/\(\(-\(1\/3\)\) + E\^\(I\ \[Omega]\)\)], \ 
        Abs[E\^\(I\ \[Omega]\)\/\(\(-\(2\/3\)\) + E\^\(I\ \[Omega]\)\)]}, {
        \[Omega], \(-2\)\ \[Pi], 3\ \[Pi]}, \ PlotRange -> {0, 3}, \ 
      PlotStyle -> {RGBColor[1, 0, 0], RGBColor[0, 0, 1]}]; \)\)], "Input",
  CellLabel->"In[13]:=",
  PageWidth->WindowWidth,
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.404762 0.0606305 0 0.206011 [
[.10161 -0.0125 -6 -9 ]
[.10161 -0.0125 6 0 ]
[.25319 -0.0125 -12 -9 ]
[.25319 -0.0125 12 0 ]
[.55634 -0.0125 -9 -9 ]
[.55634 -0.0125 9 0 ]
[.70791 -0.0125 -3 -9 ]
[.70791 -0.0125 3 0 ]
[.85949 -0.0125 -9 -9 ]
[.85949 -0.0125 9 0 ]
[.39226 .10301 -18 -4.5 ]
[.39226 .10301 0 4.5 ]
[.39226 .20601 -6 -4.5 ]
[.39226 .20601 0 4.5 ]
[.39226 .30902 -18 -4.5 ]
[.39226 .30902 0 4.5 ]
[.39226 .41202 -6 -4.5 ]
[.39226 .41202 0 4.5 ]
[.39226 .51503 -18 -4.5 ]
[.39226 .51503 0 4.5 ]
[.39226 .61803 -6 -4.5 ]
[.39226 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.10161 0 m
.10161 .00625 L
s
[(-5)] .10161 -0.0125 0 1 Mshowa
.25319 0 m
.25319 .00625 L
s
[(-2.5)] .25319 -0.0125 0 1 Mshowa
.55634 0 m
.55634 .00625 L
s
[(2.5)] .55634 -0.0125 0 1 Mshowa
.70791 0 m
.70791 .00625 L
s
[(5)] .70791 -0.0125 0 1 Mshowa
.85949 0 m
.85949 .00625 L
s
[(7.5)] .85949 -0.0125 0 1 Mshowa
.125 Mabswid
.13192 0 m
.13192 .00375 L
s
.16224 0 m
.16224 .00375 L
s
.19256 0 m
.19256 .00375 L
s
.22287 0 m
.22287 .00375 L
s
.2835 0 m
.2835 .00375 L
s
.31382 0 m
.31382 .00375 L
s
.34413 0 m
.34413 .00375 L
s
.37445 0 m
.37445 .00375 L
s
.43508 0 m
.43508 .00375 L
s
.46539 0 m
.46539 .00375 L
s
.49571 0 m
.49571 .00375 L
s
.52602 0 m
.52602 .00375 L
s
.58665 0 m
.58665 .00375 L
s
.61697 0 m
.61697 .00375 L
s
.64728 0 m
.64728 .00375 L
s
.6776 0 m
.6776 .00375 L
s
.73823 0 m
.73823 .00375 L
s
.76854 0 m
.76854 .00375 L
s
.79886 0 m
.79886 .00375 L
s
.82918 0 m
.82918 .00375 L
s
.07129 0 m
.07129 .00375 L
s
.04098 0 m
.04098 .00375 L
s
.01066 0 m
.01066 .00375 L
s
.88981 0 m
.88981 .00375 L
s
.92012 0 m
.92012 .00375 L
s
.95044 0 m
.95044 .00375 L
s
.98075 0 m
.98075 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.40476 .10301 m
.41101 .10301 L
s
[(0.5)] .39226 .10301 1 0 Mshowa
.40476 .20601 m
.41101 .20601 L
s
[(1)] .39226 .20601 1 0 Mshowa
.40476 .30902 m
.41101 .30902 L
s
[(1.5)] .39226 .30902 1 0 Mshowa
.40476 .41202 m
.41101 .41202 L
s
[(2)] .39226 .41202 1 0 Mshowa
.40476 .51503 m
.41101 .51503 L
s
[(2.5)] .39226 .51503 1 0 Mshowa
.40476 .61803 m
.41101 .61803 L
s
[(3)] .39226 .61803 1 0 Mshowa
.125 Mabswid
.40476 .0206 m
.40851 .0206 L
s
.40476 .0412 m
.40851 .0412 L
s
.40476 .0618 m
.40851 .0618 L
s
.40476 .0824 m
.40851 .0824 L
s
.40476 .12361 m
.40851 .12361 L
s
.40476 .14421 m
.40851 .14421 L
s
.40476 .16481 m
.40851 .16481 L
s
.40476 .18541 m
.40851 .18541 L
s
.40476 .22661 m
.40851 .22661 L
s
.40476 .24721 m
.40851 .24721 L
s
.40476 .26781 m
.40851 .26781 L
s
.40476 .28842 m
.40851 .28842 L
s
.40476 .32962 m
.40851 .32962 L
s
.40476 .35022 m
.40851 .35022 L
s
.40476 .37082 m
.40851 .37082 L
s
.40476 .39142 m
.40851 .39142 L
s
.40476 .43262 m
.40851 .43262 L
s
.40476 .45322 m
.40851 .45322 L
s
.40476 .47383 m
.40851 .47383 L
s
.40476 .49443 m
.40851 .49443 L
s
.40476 .53563 m
.40851 .53563 L
s
.40476 .55623 m
.40851 .55623 L
s
.40476 .57683 m
.40851 .57683 L
s
.40476 .59743 m
.40851 .59743 L
s
.25 Mabswid
.40476 0 m
.40476 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
.02381 .30902 m
.02499 .30897 L
.02605 .30886 L
.02729 .30864 L
.02846 .30834 L
.03053 .3076 L
.03279 .30651 L
.03527 .30497 L
.0379 .30297 L
.04262 .29852 L
.05205 .28694 L
.06244 .27161 L
.08274 .24024 L
.10458 .21097 L
.12562 .18939 L
.1356 .18132 L
.14487 .17496 L
.16385 .16493 L
.17388 .16111 L
.17945 .15938 L
.18458 .15803 L
.18948 .15696 L
.19486 .156 L
.20027 .15528 L
.20323 .15499 L
.20599 .15478 L
.20724 .1547 L
.2086 .15464 L
.20989 .15458 L
.21108 .15455 L
.21215 .15453 L
.21333 .15451 L
.21456 .15451 L
.21572 .15452 L
.217 .15454 L
.21764 .15455 L
.21834 .15457 L
.22074 .15467 L
.2221 .15475 L
.22355 .15485 L
.22616 .15507 L
.23149 .15568 L
.2364 .15645 L
.24179 .15753 L
.2475 .15893 L
.2571 .16194 L
.26766 .16624 L
.2871 .17717 L
.29802 .18524 L
.308 .19398 L
Mistroke
.34776 .24312 L
.36783 .27423 L
.37656 .287 L
.386 .29857 L
.39129 .30348 L
.39361 .30518 L
.39616 .30671 L
.39732 .30729 L
.39856 .30781 L
.39964 .30819 L
.40081 .30853 L
.40213 .3088 L
.40338 .30896 L
.40459 .30902 L
.40571 .30899 L
.40692 .30887 L
.40821 .30864 L
.40944 .30833 L
.41056 .30796 L
.41316 .30682 L
.4159 .30519 L
.42106 .30102 L
.4267 .29502 L
.46731 .23495 L
.48609 .21032 L
.50641 .18953 L
.51754 .18059 L
.5278 .17373 L
.53822 .16798 L
.54796 .16363 L
.55703 .16039 L
.56676 .15774 L
.5723 .1566 L
.57756 .15575 L
.58228 .15517 L
.58495 .15493 L
.58742 .15475 L
.58859 .15468 L
.58983 .15462 L
.5909 .15458 L
.59204 .15455 L
.59327 .15452 L
.59442 .15451 L
.59512 .15451 L
.59578 .15451 L
.59703 .15452 L
.59812 .15454 L
.59928 .15457 L
.60027 .15461 L
.60136 .15466 L
Mistroke
.60378 .1548 L
.60606 .15497 L
.61124 .15552 L
.61598 .15622 L
.62145 .15725 L
.62665 .15846 L
.63625 .16131 L
.64647 .16528 L
.66486 .17509 L
.67516 .18225 L
.68629 .19152 L
.70646 .21279 L
.72603 .23912 L
.74749 .27224 L
.75735 .28677 L
.76278 .29383 L
.76792 .29956 L
.7727 .30384 L
.77523 .30561 L
.7779 .30711 L
.78015 .30805 L
.78143 .30844 L
.78263 .30872 L
.78372 .30889 L
.78473 .30899 L
.78583 .30902 L
.78699 .30897 L
.78823 .30882 L
.78893 .30869 L
.78957 .30855 L
.79075 .30822 L
.792 .30778 L
.79417 .30679 L
.79655 .30539 L
.80182 .30119 L
.80675 .29607 L
.82512 .27042 L
.86397 .21399 L
.88516 .1915 L
.8949 .1833 L
.90526 .17592 L
.91569 .16977 L
.92512 .16521 L
.93472 .16147 L
.94353 .15878 L
.95117 .157 L
.95507 .15628 L
.95923 .15565 L
.96342 .15515 L
.96732 .15482 L
Mistroke
.96847 .15474 L
.96971 .15467 L
.97081 .15462 L
.97197 .15458 L
.97301 .15455 L
.97416 .15452 L
.97521 .15451 L
.97619 .15451 L
Mfstroke
0 0 1 r
.02381 .61803 m
.04262 .49281 L
.0522 .40828 L
.06244 .33742 L
.07286 .28457 L
.08255 .2481 L
.09409 .21585 L
.10458 .19386 L
.11454 .17762 L
.12373 .16562 L
.13446 .15443 L
.14451 .14611 L
.15429 .13964 L
.16324 .13489 L
.17317 .13074 L
.17835 .129 L
.18386 .12744 L
.18902 .12623 L
.19371 .12534 L
.19841 .12463 L
.20285 .12414 L
.20537 .12393 L
.20674 .12384 L
.20803 .12376 L
.20922 .12371 L
.2103 .12367 L
.21151 .12364 L
.2128 .12362 L
.21347 .12361 L
.21418 .12361 L
.21545 .12361 L
.21616 .12362 L
.21682 .12363 L
.21755 .12365 L
.21833 .12367 L
.21966 .12372 L
.22106 .12379 L
.22357 .12396 L
.22614 .12418 L
.22857 .12443 L
.23311 .12505 L
.23801 .12591 L
.24331 .12708 L
.25287 .12986 L
.26168 .13324 L
.27137 .13798 L
.28044 .14354 L
.29103 .15167 L
.30108 .16138 L
.31079 .17308 L
Mistroke
.32137 .1892 L
.33099 .20786 L
.3399 .22976 L
.3505 .26369 L
.36047 .30663 L
.36942 .3579 L
.37909 .4306 L
.38942 .52575 L
.39447 .57077 L
.39667 .5875 L
.39906 .60229 L
.40036 .6085 L
.40156 .61293 L
.4027 .61591 L
.40392 .61768 L
.4052 .61794 L
.40639 .6167 L
.40771 .61371 L
.40844 .61131 L
.40912 .60868 L
.41169 .5952 L
.41449 .57527 L
.42014 .52534 L
.4311 .425 L
.44143 .34939 L
.45071 .29859 L
.46076 .25743 L
.47065 .22696 L
.48111 .20243 L
.49004 .18603 L
.49985 .1716 L
.51934 .15095 L
.53027 .14275 L
.54024 .13686 L
.55014 .13227 L
.55931 .129 L
.56936 .12636 L
.57444 .12537 L
.57712 .12494 L
.58006 .12454 L
.58243 .12427 L
.58496 .12403 L
.58764 .12384 L
.58884 .12377 L
.59013 .12371 L
.59143 .12367 L
.59262 .12363 L
.59377 .12362 L
.59498 .12361 L
.59606 .12361 L
Mistroke
.59707 .12362 L
.59819 .12364 L
.59938 .12368 L
.60077 .12373 L
.60205 .12379 L
.60496 .12399 L
.60753 .12422 L
.61027 .12452 L
.61549 .12528 L
.62023 .12617 L
.63026 .12872 L
.63949 .13194 L
.64962 .13654 L
.66031 .14282 L
.6698 .14984 L
.67997 .15921 L
.69831 .18261 L
.70849 .20065 L
.71956 .22625 L
.73002 .25848 L
.73969 .29822 L
.74932 .35117 L
.75837 .41666 L
.76841 .50707 L
.77388 .55777 L
.77655 .57966 L
.77897 .59634 L
.78013 .60287 L
.78137 .60875 L
.78255 .61306 L
.78364 .61588 L
.78479 .61761 L
.78606 .61797 L
.7867 .61755 L
.78738 .61663 L
.78862 .61381 L
.78933 .61156 L
.78998 .60907 L
.79145 .60208 L
.79414 .58514 L
.79917 .54323 L
.81768 .38112 L
.82829 .31545 L
.83826 .27021 L
.84721 .23945 L
.85688 .21375 L
.86642 .19397 L
.87688 .17699 L
.88779 .16315 L
.89796 .15298 L
Mistroke
.90845 .14464 L
.91837 .13839 L
.9272 .13394 L
.93694 .13009 L
.94663 .12722 L
.95193 .12602 L
.9569 .12512 L
.96154 .12448 L
.96578 .12404 L
.96813 .12387 L
.96936 .1238 L
.97068 .12373 L
.97195 .12368 L
.9731 .12365 L
.97425 .12362 L
.97534 .12361 L
.97619 .12361 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[13]:=",
  PageWidth->WindowWidth,
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo000ZOol0
0`00Oomoo`0NOol30003Ool00`00Oomoo`02Ool00`00Oomoo`0nOol30003Ool00`00Oomoo`02Ool0
0`00Oomoo`0OOol00`00Oomoo`0POol00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`0/Ool0
02Uoo`03001oo`0001moo`03001oogoo00Moo`03001oo`0003moo`03001oogoo00Moo`03001oo`00
01moo`03001oo`00025oo`03001oogoo00Ioo`03001oo`0002eoo`0097oo0`0017oo00<007ooOol0
67oo0`000goo00<007ooOol027oo00<007ooOol0?Woo00<007ooOol027oo00<007ooOol07goo00<0
07ooOol07goo00<007ooOol027oo00<007ooOol0:goo000YOol2000QOol00`00Oomoo`06Ool20011
Ool00`00Oomoo`06Ool2000POol2000SOol00`00Oomoo`05Ool2000^Ool002Uoo`03001oogoo01mo
o`03001oo`0000Moo`03001oogoo03moo`03001oo`0000Moo`03001oogoo01moo`03001oogoo021o
o`03001oo`0000Moo`03001oogoo02eoo`00:Goo0`0087oo00<007ooOol01Woo0`00@7oo00<007oo
Ool01Woo0`007goo0`0087oo0`001goo0`00;Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`003Gooo`001P003Woo000@Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomo
o`05Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomo
o`05Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomo
o`05Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomo
o`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomo
o`05Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomo
o`05Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomo
o`0AOol007Ioo`03001oogoo0:Moo`00MWoo00<007ooOol0Ygoo001fOol00`00Oomoo`2WOol007Io
o`800:Qoo`00MWoo00<007ooOol0Ygoo001fOol00`00Oomoo`2WOol007Ioo`03001oogoo0:Moo`00
MWoo00<007ooOol0Ygoo001fOol2002XOol007Ioo`03001oogoo0:Moo`00MWoo00<007ooOol0Ygoo
001fOol00`00Oomoo`2WOol007Ioo`03001oogoo0:Moo`00MWoo00<007ooOol0Ygoo001fOol2002X
Ool007Ioo`03001oogoo0:Moo`00MWoo00<007ooOol0Ygoo001fOol00`00Oomoo`2WOol007Ioo`03
001oogoo0:Moo`00MWoo0P00Z7oo001fOol00`00Oomoo`2WOol007Ioo`03001oogoo0:Moo`00MWoo
00<007ooOol0Ygoo001VOol00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomo
o`2WOol006Eoo`03001oo`0000Moo`03001oo`0000Aoo`03001oogoo0:Moo`00IGoo00<007oo0000
2Goo00<007ooOol00Woo0`00Ygoo001UOol00`00Ool00007Ool20005Ool00`00Oomoo`2WOol006Eo
o`03001oo`0000Moo`03001oogoo00Aoo`03001oogoo0:Moo`00IWoo00<007ooOol01Woo0`0017oo
00<007ooOol0Ygoo001fOol00`00Oomoo`2WOol0041oo``07bYoo`8002Yoo``07eIoo`L07aEoo`00
?7oo100O37oo100O9Woo00<007ooOol09Goo100O37oo100OD7oo0P0O77oo000jOol201lDOol201lT
Ool00`00Oomoo`0ROol301lDOol301m;Ool201lNOol003Moo`<07aQoo`807b9oo`03001oogoo021o
o`807aYoo`807dIoo`<07b1oo`00=Goo0P0O7Goo00<07gooOol07goo00<007ooOol07goo00<07goo
Ool077oo0P0O@Woo0P0O8goo000dOol00`0OOomoo`0NOol201lOOol2000OOol00`0OOomoo`0OOol0
0`0OOomoo`0mOol201lUOol003=oo`0301moogoo025oo`807aeoo`03001oogoo01aoo`807b=oo`03
01moogoo03Yoo`807bMoo`00<Goo0P0O9Woo00<07gooOol06Woo00<007ooOol06goo00<07gooOol0
97oo00<07gooOol0>7oo00<07gooOol09goo000`Ool00`0OOomoo`0<Ool=O00>Ool00`0OOomoo`0I
Ool00`00Oomoo`0JOol00`0OOomoo`0<Ool<O00>Ool201lgOol00`0OOomoo`0<Ool7O00EOol002mo
o`0301moogoo00Yoo`=l00eoo`=l00]oo`0301moogoo01Uoo`03001oogoo01Uoo`0301moogoo00Qo
o`El00aoo`=l00eoo`0301moogoo03Aoo`0301moogoo00Yoo`9l01aoo`00;Woo00<07gooOol02Goo
0W`04goo0g`02Goo00<07gooOol067oo00<007ooOol067oo00<07gooOol01goo0W`057oo0g`02goo
00<07gooOol0<Woo00<07gooOol027oo0g`07Woo000]Ool00`0OOomoo`07Ool3O00HOol2O008Ool0
0`0OOomoo`0GOol2000HOol00`0OOomoo`06Ool2O00IOol3O008Ool00`0OOomoo`0aOol00`0OOomo
o`07Ool2O00QOol002aoo`0301moogoo00Ioo`9l01eoo`9l00Moo`0301moogoo01Ioo`03001oogoo
01Ioo`0301moogoo00Eoo`9l01ioo`9l00Moo`0301moogoo02moo`0301moogoo00Eoo`=l02=oo`00
;7oo00<07gooOol017oo0W`08Goo0W`01Woo00<07gooOol05Goo00<007ooOol05Goo00<07gooOol0
1Goo00=l07ooOol087oo0W`01Woo00<07gooOol0;Woo00<07gooOol00goo0W`09Woo000[Ool00`0O
Oomoo`04Ool00g`0Oomoo`0SOol00g`0Oomoo`04Ool00`0OOomoo`0DOol00`00Oomoo`0DOol00`0O
Oomoo`05Ool00g`0Oomoo`0SOol00g`0Oomoo`03Ool00`0OOomoo`0]Ool00`0OOomoo`02Ool2O00X
Ool002Yoo`0301moogoo00Aoo`03O01oogoo02Eoo`9l00Aoo`0301moogoo01Aoo`03001oogoo01Ao
o`0301moogoo00Aoo`03O01oogoo02Eoo`03O01oogoo00=oo`0301moogoo02]oo`0301moogoo009o
o`03O01oogoo02Qoo`00:Woo00<07gooOol00Woo0W`0:Woo00=l07ooOol00Woo00<07gooOol04goo
0P0057oo00<07gooOol00goo0W`0:Goo0W`017oo00<07gooOol0:Goo00<07gooOol00Woo00=l07oo
Ool0:Goo000YOol00`0OOomoo`02Ool00g`0Oomoo`0[Ool00g`0Oomoo`02Ool00`0OOomoo`0BOol0
0`00Oomoo`0BOol00`0OOomoo`03Ool00g`0Oomoo`0[Ool01G`0Oomoogoo01l0:goo00D07gooOomo
og`002aoo`00:Goo00D07gooOomoog`002moo`05O01oogooOol07`0DOol00`00Oomoo`0BOol00`0O
Oomoo`02Ool00g`0Oomoo`0]Ool01G`0Oomoogoo01l0:Goo00D07gooOomoog`002eoo`00:7oo00D0
7gooOomoog`0035oo`05O01oogooOol07`0;Ool50003Ool00`00Oomoo`0AOol00`0OOomoo`02Ool0
0g`0Oomoo`0_Ool017`0Oomoo`0O:Goo00@07gooOoml02ioo`00:7oo00@07gooOoml03=oo`04O01o
ogoo01l=Ool00`00Oomoo`03Ool00`00Oomoo`0AOol00`0OOomoo`02O00cOol017`0Oomoo`0O9goo
00@07gooOoml02moo`009goo00@07gooOoml03Eoo`04O01oogoo01l<Ool00`00Oomoo`03Ool3000A
Ool00`0OOoml000fOol00g`0Ool07`0WOol00`0OOoml000`Ool002Moo`0301moog`003Ioo`04O01o
ogoo01l<Ool00`00Oomoo`03Ool00`00Oomoo`0@Ool00`0OOoml000hOol00g`0Ool07`0UOol00`0O
Ooml000aOol002Ioo`0301moog`003Qoo`04O01oogoo01l;Ool00`00Oomoo`03Ool00`00Oomoo`0@
Ool00`0OO01oo`0iOol00g`001moo`0TOol00`0OO01oo`0aOol002Ioo`0301ml07oo03Uoo`03O01o
o`0O00Yoo`8000Eoo`03001oogoo00moo`0301moog`003]oo`03O0007goo02=oo`0301moogoo035o
o`009Woo00<07g`0Ool0>Woo00=l07oo01l047oo00<007ooOol03goo00<07g`0Ool0>goo00=l000O
Ool08Woo00<07g`0Ool0<Woo000UOol00`0OO01oo`0lOol00g`001moo`0?Ool00`00Oomoo`0>Ool0
0`0OOoml000mOol00g`001moo`0QOol00`0OOomoo`0bOol002Eoo`0301moogoo03eoo`03O0007goo
00ioo`8000moo`0301ml07oo03ioo`0301moogoo01moo`0301moogoo03=oo`0097oo00<07gooOol0
?Woo00=l000OOol03Woo00<007ooOol03Woo00<07g`0Ool0?goo00<07gooOol07Woo00<07gooOol0
<goo000TOol00`0OOomoo`0oOol00`0OOomoo`0=Ool00`00Oomoo`0=Ool00`0OO01oo`10Ool00`0O
Oomoo`0MOol00`0OOomoo`0dOol002=oo`03O0007goo045oo`0301moogoo00aoo`03001oogoo00eo
o`0301moogoo041oo`0301ml07oo01aoo`03O0007goo03Eoo`008Woo00=l000OOol0@Woo00<07g`0
Ool037oo00<007ooOol03Goo00<07gooOol0@Goo00<07g`0Ool06goo00=l000OOol0=Goo000ROol0
0g`001moo`12Ool00`0OOoml000<Ool2000=Ool00g`001moo`12Ool00`0OO01oo`0JOol00g`001mo
o`0fOol0025oo`03O01oo`0O04=oo`0301moog`000aoo`03001oogoo00]oo`03O0007goo04=oo`03
01moog`001Uoo`03O01oo`0O03Moo`0087oo00=l07oo01l0AGoo00<07gooO0002goo00<007ooOol0
2Woo00=l07oo01l0AGoo00<07g`0Ool067oo00=l07oo01l0=goo000POol00g`0Ool07`15Ool00`0O
Ooml000;Ool00`00Oomoo`0:Ool00g`0Ool07`15Ool00`0OOoml000GOol017`0Oomoo`0O=goo000O
Ool017`0Oomoo`0OAGoo00@07gooOoml00Yoo`03001oogoo00Uoo`04O01oogoo01m5Ool0100OOomo
og`05Goo00Al07ooOol07cQoo`007goo00=l07oo01l0AWoo00D07gooOomoog`000Uoo`8000Uoo`04
O01oogoo01m6Ool0100OOomoog`05Goo00Al07ooOol07cQoo`007Woo00Al07ooOol07dMoo`0401mo
ogooO009Ool00`00Oomoo`07Ool01G`0Oomoogoo01l0Agoo00@07gooOoml01=oo`05O01oogooOol0
7`0hOol001eoo`05O01oogooOol07`17Ool01@0OOomoogooO00027oo00<007ooOol01goo00El07oo
Oomoo`0O04Moo`0501moogooOoml000AOol00g`0Oomoo`02Ool00`0OOomoo`0fOol001aoo`03O01o
ogoo009oo`0301moogoo04Eoo`0301moogoo009oo`03O01oogoo00Eoo`03001oogoo00Ioo`05O01o
ogooOol07`18Ool01@0OOomoogooO0004Goo00El07ooOomoo`0O03Uoo`0077oo00El07ooOomoo`0O
04Qoo`0301moogoo009oo`03O01oogoo00Eoo`03001oogoo00Eoo`03O01oogoo009oo`0301moogoo
04Ioo`0301moogoo009oo`03O01oogoo00eoo`03O01oogoo009oo`0301moogoo03Moo`006goo00=l
07ooOol00Woo00<07gooOol0Agoo00<07gooOol00Woo00=l07ooOol017oo00<007ooOol017oo00=l
07ooOol00goo00<07gooOol0AWoo00<07gooOol00goo00=l07ooOol037oo00=l07ooOol00Woo00<0
7gooOol0=goo000JOol00g`0Oomoo`03Ool00`0OOomoo`17Ool00`0OOomoo`03Ool00g`0Oomoo`03
Ool20005Ool00g`0Oomoo`03Ool00`0OOomoo`17Ool00`0OOomoo`02Ool00g`0Oomoo`0;Ool00g`0
Oomoo`03Ool00`0OOomoo`0gOol001Uoo`03O01oogoo00Aoo`0301moogoo04Moo`0301moogoo00=o
o`03O01oogoo00=oo`03001oogoo00=oo`03O01oogoo00=oo`0301moogoo04Qoo`0301moogoo00=o
o`03O01oogoo00Yoo`03O01oogoo009oo`0301moogoo03Qoo`0067oo00=l07ooOol01Goo00<07goo
Ool0Agoo00<07gooOol017oo00=l07ooOol00Woo00<007ooOol00Woo00=l07ooOol017oo00<07goo
Ool0B7oo00<07gooOol017oo00=l07ooOol027oo00=l07ooOol00goo00<07gooOol0>7oo000GOol0
0g`0Oomoo`05Ool00`0OOomoo`12Ool50002Ool00`0OOomoo`02Ool01000Ooml07`00Woo00<007oo
Ool00Woo00=l07ooOol017oo00<07gooOol0B7oo00<07gooOol01Goo00=l07ooOol01Goo0W`01Woo
00<07gooOol0>7oo000FOol2O007Ool00`0OOomoo`14Ool00`00Oomoo`02Ool0200OOomoogoo001o
o`00Ool2O0000goo001oo`03O007Ool00`0OOomoo`18Ool00`0OOomoo`06Ool2O003Ool2O008Ool0
0`0OOomoo`0hOol001Aoo`9l00Uoo`0301moogoo04Aoo`03001oogoo009oo`0301moogoo00=oo`04
001oogooOol4O009Ool00`0OOomoo`19Ool00`0OOomoo`07Ool4O008Ool00`0OOomoo`0iOol001mo
o`0301moogoo04Aoo`03001oogoo009oo`0401moogooOol20005Ool00`00Oomoo`08Ool00`0OOomo
o`1:Ool00`0OOomoo`0COol00`0OOomoo`0iOol001moo`0301moogoo04Aoo`03001oogoo009oo`05
01moogooOol00006Ool00`00Oomoo`08Ool00`0OOomoo`1:Ool00`0OOomoo`0COol00`0OOomoo`0i
Ool001moo`0301moogoo04=oo`8000Eoo`0301moogoo00<000Aoo`03001oogoo00Qoo`0301moogoo
04Yoo`0301moogoo01=oo`0301moogoo03Uoo`007Woo00<07gooOol0Bgoo00<07gooOol01goo00<0
07ooOol027oo00<07gooOol0BWoo00<07gooOol04goo00<07gooOol0>Goo000NOol00`0OOomoo`1;
Ool00`0OOomoo`07Ool20009Ool00`0OOomoo`1;Ool00`0OOomoo`0AOol00`0OOomoo`0jOol001io
o`0301moogoo04]oo`0301moogoo00Moo`03001oogoo00Qoo`0301moogoo04]oo`0301moogoo015o
o`0301moogoo03Yoo`007Woo00<07gooOol0Bgoo00<07gooOol01goo00<007ooOol01goo00<07goo
Ool0C7oo00<07gooOol04Goo00<07gooOol0>Woo000NOol00`0OOomoo`1;Ool00`0OOomoo`07Ool0
0`00Oomoo`07Ool00`0OOomoo`1<Ool00`0OOomoo`0AOol00`0OOomoo`0jOol001ioo`0301moogoo
04]oo`0301moogoo00Moo`03001oogoo00Moo`0301moogoo04eoo`0301moogoo011oo`0301moogoo
03Yoo`007Woo00<07gooOol0C7oo00<07gooOol01Woo00<007ooOol01goo00<07gooOol0CGoo00<0
7gooOol047oo00<07gooOol0>Woo000MOol00`0OOomoo`1=Ool00`0OOomoo`06Ool20008Ool00`0O
Oomoo`1=Ool00`0OOomoo`0?Ool00`0OOomoo`0kOol001eoo`0301moogoo04eoo`0301moogoo00Io
o`03001oogoo00Moo`0301moogoo04eoo`0301moogoo00moo`0301moogoo03]oo`007Goo00<07goo
Ool0CGoo00<07gooOol01Woo00<007ooOol01goo00<07gooOol0CGoo00<07gooOol03goo00<07goo
Ool0>goo000MOol00`0OOomoo`1=Ool00`0OOomoo`06Ool00`00Oomoo`06Ool00`0OOomoo`1>Ool0
0`0OOomoo`0?Ool00`0OOomoo`0kOol001eoo`0301moogoo04eoo`0301moogoo00Ioo`03001oogoo
00Ioo`0301moogoo04ioo`0301moogoo00moo`0301moogoo03]oo`007Goo00<07gooOol0CGoo00<0
7gooOol01Woo0P001goo00<07gooOol0Cgoo00<07gooOol03Woo00<07gooOol0>goo000LOol00`0O
Oomoo`1?Ool00`0OOomoo`05Ool00`00Oomoo`06Ool00`0OOomoo`1?Ool00`0OOomoo`0=Ool00`0O
Oomoo`0lOol001aoo`0301moogoo04moo`0301moogoo00Eoo`03001oogoo00Ioo`0301moogoo04mo
o`0301moogoo00eoo`0301moogoo03aoo`0077oo00<07gooOol0Cgoo00<07gooOol01Goo00<007oo
Ool01Woo00<07gooOol0Cgoo00<07gooOol03Goo00<07gooOol0?7oo000LOol00`0OOomoo`1?Ool0
0`0OOomoo`05Ool00`00Oomoo`05Ool00`0OOomoo`1@Ool00`0OOomoo`0=Ool00`0OOomoo`0lOol0
01aoo`0301moogoo04moo`0301moogoo00Eoo`8000Ioo`0301moogoo051oo`0301moogoo00eoo`03
01moogoo03aoo`0077oo00<07gooOol0Cgoo00<07gooOol01Goo00<007ooOol01Goo00<07gooOol0
D7oo00<07gooOol03Goo00<07gooOol0?7oo000KOol00`0OOomoo`1AOol00`0OOomoo`04Ool00`00
Oomoo`05Ool00`0OOomoo`1@Ool00`0OOomoo`0=Ool00`0OOomoo`0lOol001]oo`0301moogoo055o
o`0301moogoo00Aoo`03001oogoo00Eoo`0301moogoo055oo`0301moogoo00aoo`0301moogoo03ao
o`006goo00<07gooOol0DGoo00<07`00000017oo00<007ooOol01Goo00<07gooOol0DGoo00<07goo
Ool02goo00<07gooOol0?Goo000KOol00`0OOomoo`1AOol00`0OOomoo`04Ool00`00Oomoo`05Ool0
0`0OOomoo`1AOol00`0OOomoo`0;Ool00`0OOomoo`0mOol001]oo`0301moogoo055oo`0301l007oo
00Aoo`<000Aoo`0301moogoo059oo`0301moogoo00]oo`0301moogoo03eoo`006goo00<07gooOol0
DGoo00<07`00Ool017oo00<007ooOol017oo00<07gooOol0DWoo00<07gooOol02goo00<07gooOol0
?Goo000KOol00`0OOomoo`1AOol00`0001l00004Ool00`00Oomoo`04Ool00`0OOomoo`1BOol00`0O
Oomoo`0;Ool00`0OOomoo`0mOol001Yoo`0301moogoo05=oo`0301moogoo00=oo`03001oogoo00Ao
o`0301moogoo059oo`0301moogoo00]oo`0301moogoo03eoo`006Woo00<07gooOol0Dgoo00<07goo
Ool00goo00<007ooOol017oo00<07gooOol0DWoo00<07gooOol02goo00<07gooOol0?Goo000JOol0
0`0OOomoo`1COol00`0OOomoo`03Ool20005Ool00`0OOomoo`1COol00`0OOomoo`0:Ool00`0OOomo
o`0mOol001Yoo`0301moogoo05=oo`0301moogoo00=oo`03001oogoo00Aoo`0301moogoo05=oo`03
01moogoo00Yoo`0301moogoo03eoo`006Woo00<07gooOol0Dgoo00<07gooOol00goo00<007ooOol0
17oo00<07gooOol0Dgoo00<07gooOol02Woo00<07gooOol0?Goo000JOol00`0OOomoo`1COol00`0O
Oomoo`03Ool00`00Oomoo`03Ool00`0OOomoo`1DOol00`0OOomoo`09Ool00`0OOomoo`0nOol001Yo
o`0301moogoo05=oo`0301moogoo00=oo`03001oogoo00=oo`0301moogoo05Aoo`0301moogoo00Uo
o`0301moogoo03ioo`006Goo00<07gooOol0E7oo00<07gooOol00goo0P0017oo00<07gooOol0E7oo
00<07gooOol02Goo00<07gooOol0?Woo000IOol00`0OOomoo`1EOol00`0OOomoo`02Ool00`00Oomo
o`03Ool00`0OOomoo`1DOol00`0OOomoo`09Ool00`0OOomoo`0nOol001Uoo`0301moogoo05Eoo`03
01moogoo009oo`03001oogoo00=oo`0301moogoo05Aoo`0301moogoo00Uoo`0301moogoo03ioo`00
6Goo00<07gooOol0EGoo00<07gooOol00Woo00<007ooOol00goo00<07gooOol0EGoo00<07gooOol0
27oo00<07gooOol0?Woo000IOol00`0OOomoo`1EOol00`0OOomoo`02Ool00`00Oomoo`03Ool00`0O
Oomoo`1EOol00`0OOomoo`08Ool00`0OOomoo`0nOol001Uoo`0301moogoo05Eoo`0301moogoo009o
o`03001oogoo00=oo`0301moogoo05Eoo`0301moogoo00Qoo`0301moogoo03ioo`006Goo00<07goo
Ool0EGoo00<07gooOol00Woo0P000goo00<07gooOol0EWoo00<07gooOol027oo00<07gooOol0?Woo
000IOol00`0OOomoo`1EOol00`0OOomoo`02Ool00`00Oomoo`02Ool00`0OOomoo`1FOol00`0OOomo
o`08Ool00`0OOomoo`0nOol001Qoo`0301moogoo05Ioo`0301moogoo009oo`03001oogoo009oo`03
01moogoo05Ioo`0301moogoo00Qoo`0301moogoo03ioo`0067oo00<07gooOol0EWoo00<07gooOol0
0Woo00<007ooOol00Woo00<07gooOol0EWoo00<07gooOol01goo00<07gooOol0?goo000HOol00`0O
Oomoo`1FOol00`0OOomoo`02Ool00`00Oomoo`02Ool00`0OOomoo`1FOol00`0OOomoo`07Ool00`0O
Oomoo`0oOol001Qoo`0301moogoo05Ioo`0301moogoo009oo`8000=oo`0301moogoo05Moo`0301mo
ogoo00Ioo`0301moogoo03moo`0067oo00<07gooOol0EWoo00<07gooOol00Woo00<007ooOol00Woo
00<07gooOol0Egoo00<07gooOol01Woo00<07gooOol0?goo000HOol00`0OOomoo`1GOol01@0OOomo
ogoo000017oo00<07gooOol0Egoo00<07gooOol01Woo00<07gooOol0?goo000HOol00`0OOomoo`1:
Ool30003Ool00`00Oomoo`02Ool00`00Ool07`03Ool00`00Oomoo`02Ool00`0OOomoo`1GOol00`0O
Oomoo`06Ool00`0OOomoo`0oOol001Moo`0301moogoo04]oo`03001oogoo00Moo`04001oo`0001l3
Ool01@00Oomoogoo01l0FWoo00<07gooOol01Woo00<07gooOol0?goo000GOol00`0OOomoo`1<Ool0
0`00Oomoo`08Ool00`0001moo`02Ool300000goo01moo`1IOol00`0OOomoo`06Ool00`0OOomoo`0o
Ool001Moo`0301moogoo04aoo`03001oogoo00Ioo`800003Ool07goo009oo`05001oogooOol07`1J
Ool00`0OOomoo`06Ool00`0OOomoo`0oOol001Moo`0301moogoo04]oo`03001oo`0000Moo`04001o
ogoo01l3Ool01@00Oomoogoo01l0FWoo00<07gooOol01Woo00<07gooOol0?goo000GOol00`0OOomo
o`1<Ool00`00Oomoo`06Ool300001@0OOomoogoo00000goo00<07gooOol0F7oo00<07gooOol01Goo
00<07gooOol0@7oo000GOol00`0OOomoo`1HOol01@0OOomoogoo00000goo00<07gooOol0F7oo00<0
7gooOol01Goo00<07gooOol0@7oo000GOol00`0OOomoo`1HOol01@0OOomoogoo00000goo00<07goo
Ool0FGoo00<07gooOol017oo00<07gooOol0@7oo000GOol00`0OOomoo`1HOol0100OOomoogoo0P00
0Woo00<07gooOol0FGoo00<07gooOol017oo00<07gooOol0@7oo000FOol00`0OOomoo`1JOol0100O
Oomoo`000goo00<07gooOol0FGoo00<07gooOol017oo00<07gooOol0@7oo000FOol00`0OOomoo`1J
Ool0100OOomoo`000goo00<07gooOol0FGoo00<07gooOol017oo00<07gooOol0@7oo000FOol00`0O
Oomoo`1JOol0100OOomoo`000goo00<07gooOol0FGoo00<07gooOol017oo00<07gooOol0@7oo000F
Ool00`0OOomoo`1JOol0100OOomoo`000Woo00<07gooOol0FWoo00<07gooOol017oo00<07gooOol0
@7oo000FOol00`0OOomoo`1JOol00`0OOomoo`0200000goo01moo`1KOol00`0OOomoo`03Ool00`0O
Oomoo`11Ool001Ioo`0301moogoo05Yoo`0401moogoo0002Ool00`0OOomoo`1JOol00`0OOomoo`03
Ool00`0OOomoo`11Ool001Ioo`0301moogoo05]oo`0301moo`00009oo`0301moogoo05Yoo`0301mo
ogoo00=oo`0301moogoo045oo`005Woo00<07gooOol0Fgoo00<07goo00000Woo00<07gooOol0FWoo
00<07gooOol00goo00<07gooOol0@Goo000EOol00`0OOomoo`1LOol00`0OOol00002Ool00`0OOomo
o`1KOol00`0OOomoo`02Ool00`0OOomoo`11Ool001Eoo`0301moogoo05aoo`0601moo`00001oo`0O
GGoo00D07gooOomoo`0O04Aoo`005Goo00<07gooOol0G7oo00<07goo00000Woo00<07gooOol0Fgoo
00D07gooOomoo`0O04Aoo`005Goo00<07gooOol0G7oo00<07goo00000Woo00<07gooOol0Fgoo00D0
7gooOomoo`0O04Aoo`005Goo00<07gooOol0G7oo00D07goo001oo`0O05ioo`0501moogooOol07`14
Ool001Eoo`0301moogoo05aoo`0501moo`00Ool07`1NOol01@0OOomoogoo01l0A7oo000EOol00`0O
Oomoo`1LOol01@0OOol007oo01l0GWoo00D07gooOomoo`0O04Aoo`005Goo00<07gooOol0GGoo00@0
7`0000007eioo`0501moogooOol07`14Ool001Aoo`0301moogoo05ioo`0301l0000O061oo`0401mo
ogoo01m4Ool001Aoo`0301moogoo05ioo`0301l0000O061oo`0301moo`0O04Eoo`0057oo00<07goo
Ool0F7oo0P0017oo00<07`0001l0H7oo00<07goo01l0AGoo000DOol00`0OOomoo`1JOol01000Oomo
ogoo0`0OH7oo0`0OAGoo000DOol00`0OOomoo`1IOol00`00Oomoo`03Ool201l00`00Oomoo`1NOol0
0`0OOomoo`14Ool0075oo`03001oogoo0:aoo`00Kgoo00<007oo0000[Woo001`Ool00`00Oomoo`2]
Ool00?moob5oo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-7.56022, -0.229235, 
  0.0636308, 0.018727}}]
}, Open  ]],

Cell[TextData[{
  "where we purposely ploted over the extended frequency domain of ",
  Cell[BoxData[
      \(TraditionalForm
      \`\(-2\) \[Pi] \[LessEqual] \[Omega] \[LessEqual] 4  \[Pi]\)]],
  ", to show the periodicity of the DTFT. It is common to show just the \
fundamental interval, or in the case of real signals, simply the half \
interval ",
  Cell[BoxData[
      \(TraditionalForm\`0 \[LessEqual] \[Omega] \[LessEqual] \[Pi]\)]],
  ". As a second example, consider the DTFT of the so-called ",
  StyleBox["moving average",
    FontSlant->"Italic"],
  " (MA) filter. An MA filter is a finite impulse response filter with a unit \
sample response in the form of a unit pulse scaled by its length. The filter \
is commonly used to smooth data. For a casual MA filter of length ",
  Cell[BoxData[
      \(TraditionalForm\`N\)]],
  ", (1) reduces to"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(1\/\[ScriptCapitalN]\) 
      \(\[Sum]\+\(n = 0\)\%\(\[ScriptCapitalN] - 1\)\[ExponentialE]\^\(\ 
          \(-\ \[ImaginaryI]\)\ \[Omega]\ n\)\)\)], "Input",
  CellLabel->"In[30]:="],

Cell[BoxData[
    \(\(E\^\(I\ \[Omega] - I\ \[ScriptCapitalN]\ \[Omega]\)\ 
        \((\(-1\) + E\^\(I\ \[ScriptCapitalN]\ \[Omega]\))\)\)\/\(\((
          \(-1\) + E\^\(I\ \[Omega]\))\)\ \[ScriptCapitalN]\)\)], "Output",
  CellLabel->"Out[30]="]
}, Open  ]],

Cell[TextData[{
  "which results in the following frequency response (note that we have \
additionaly normalized the frequency response with respect to the filters \
length ",
  Cell[BoxData[
      \(TraditionalForm\`N\)]],
  "):"
}], "Text",
  PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Plot[
      Evaluate[Map[
          Abs[\(E\^\(I\ \[Omega] - I\ \[ScriptCapitalN]\ \[Omega]\)\ 
                    \((\(-1\) + E\^\(I\ \[ScriptCapitalN]\ \[Omega]\))
                      \)\)\/\(\((\(-1\) + E\^\(I\ \[Omega]\))\)\ 
                    \[ScriptCapitalN]\)]\  /. \ #\ &, {
            \[ScriptCapitalN] -> 5, \ \[ScriptCapitalN] -> 19}]], {\[Omega], 
        0, \ \[Pi]}, \ PlotRange -> All, \ 
      PlotStyle -> {RGBColor[1, 0, 0], RGBColor[0, 0, 1]}]; \)\)], "Input",
  CellLabel->"In[34]:=",
  PageWidth->WindowWidth,
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.303152 0.014708 0.588611 [
[.17539 .00221 -9 -9 ]
[.17539 .00221 9 0 ]
[.32696 .00221 -3 -9 ]
[.32696 .00221 3 0 ]
[.47854 .00221 -9 -9 ]
[.47854 .00221 9 0 ]
[.63011 .00221 -3 -9 ]
[.63011 .00221 3 0 ]
[.78169 .00221 -9 -9 ]
[.78169 .00221 9 0 ]
[.93327 .00221 -3 -9 ]
[.93327 .00221 3 0 ]
[.01131 .13243 -18 -4.5 ]
[.01131 .13243 0 4.5 ]
[.01131 .25015 -18 -4.5 ]
[.01131 .25015 0 4.5 ]
[.01131 .36787 -18 -4.5 ]
[.01131 .36787 0 4.5 ]
[.01131 .4856 -18 -4.5 ]
[.01131 .4856 0 4.5 ]
[.01131 .60332 -6 -4.5 ]
[.01131 .60332 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.17539 .01471 m
.17539 .02096 L
s
[(0.5)] .17539 .00221 0 1 Mshowa
.32696 .01471 m
.32696 .02096 L
s
[(1)] .32696 .00221 0 1 Mshowa
.47854 .01471 m
.47854 .02096 L
s
[(1.5)] .47854 .00221 0 1 Mshowa
.63011 .01471 m
.63011 .02096 L
s
[(2)] .63011 .00221 0 1 Mshowa
.78169 .01471 m
.78169 .02096 L
s
[(2.5)] .78169 .00221 0 1 Mshowa
.93327 .01471 m
.93327 .02096 L
s
[(3)] .93327 .00221 0 1 Mshowa
.125 Mabswid
.05412 .01471 m
.05412 .01846 L
s
.08444 .01471 m
.08444 .01846 L
s
.11476 .01471 m
.11476 .01846 L
s
.14507 .01471 m
.14507 .01846 L
s
.2057 .01471 m
.2057 .01846 L
s
.23602 .01471 m
.23602 .01846 L
s
.26633 .01471 m
.26633 .01846 L
s
.29665 .01471 m
.29665 .01846 L
s
.35728 .01471 m
.35728 .01846 L
s
.38759 .01471 m
.38759 .01846 L
s
.41791 .01471 m
.41791 .01846 L
s
.44822 .01471 m
.44822 .01846 L
s
.50885 .01471 m
.50885 .01846 L
s
.53917 .01471 m
.53917 .01846 L
s
.56948 .01471 m
.56948 .01846 L
s
.5998 .01471 m
.5998 .01846 L
s
.66043 .01471 m
.66043 .01846 L
s
.69074 .01471 m
.69074 .01846 L
s
.72106 .01471 m
.72106 .01846 L
s
.75137 .01471 m
.75137 .01846 L
s
.81201 .01471 m
.81201 .01846 L
s
.84232 .01471 m
.84232 .01846 L
s
.87264 .01471 m
.87264 .01846 L
s
.90295 .01471 m
.90295 .01846 L
s
.96358 .01471 m
.96358 .01846 L
s
.9939 .01471 m
.9939 .01846 L
s
.25 Mabswid
0 .01471 m
1 .01471 L
s
.02381 .13243 m
.03006 .13243 L
s
[(0.2)] .01131 .13243 1 0 Mshowa
.02381 .25015 m
.03006 .25015 L
s
[(0.4)] .01131 .25015 1 0 Mshowa
.02381 .36787 m
.03006 .36787 L
s
[(0.6)] .01131 .36787 1 0 Mshowa
.02381 .4856 m
.03006 .4856 L
s
[(0.8)] .01131 .4856 1 0 Mshowa
.02381 .60332 m
.03006 .60332 L
s
[(1)] .01131 .60332 1 0 Mshowa
.125 Mabswid
.02381 .04414 m
.02756 .04414 L
s
.02381 .07357 m
.02756 .07357 L
s
.02381 .103 m
.02756 .103 L
s
.02381 .16186 m
.02756 .16186 L
s
.02381 .19129 m
.02756 .19129 L
s
.02381 .22072 m
.02756 .22072 L
s
.02381 .27958 m
.02756 .27958 L
s
.02381 .30901 m
.02756 .30901 L
s
.02381 .33844 m
.02756 .33844 L
s
.02381 .39731 m
.02756 .39731 L
s
.02381 .42674 m
.02756 .42674 L
s
.02381 .45617 m
.02756 .45617 L
s
.02381 .51503 m
.02756 .51503 L
s
.02381 .54446 m
.02756 .54446 L
s
.02381 .57389 m
.02756 .57389 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
1 0 0 r
.5 Mabswid
.02381 .60332 m
.02499 .60331 L
.02605 .60329 L
.02729 .60324 L
.02846 .60318 L
.03053 .60303 L
.03279 .6028 L
.03527 .60248 L
.0379 .60205 L
.04262 .60106 L
.04749 .59973 L
.05205 .59822 L
.06244 .5938 L
.07305 .58791 L
.08274 .58131 L
.10458 .56237 L
.14429 .51443 L
.18248 .45415 L
.22313 .37837 L
.26226 .29817 L
.30384 .21006 L
.34391 .12713 L
.38246 .05332 L
.39277 .03504 L
.3978 .02638 L
.40239 .01864 L
.40359 .01665 L
.40488 .01491 L
.40611 .01692 L
.40724 .01878 L
.41244 .02716 L
.42346 .04423 L
.46273 .09647 L
.48242 .1172 L
.50048 .1328 L
.51982 .1458 L
.52998 .15109 L
.54068 .1555 L
.55022 .15845 L
.55557 .1597 L
.56042 .16059 L
.56495 .1612 L
.56751 .16146 L
.56987 .16164 L
.57193 .16176 L
.5731 .1618 L
.5742 .16183 L
.57536 .16185 L
.57641 .16186 L
.57763 .16186 L
Mistroke
.57879 .16184 L
.58004 .1618 L
.58074 .16178 L
.58139 .16175 L
.58383 .16161 L
.58605 .16143 L
.5884 .1612 L
.59328 .16054 L
.59863 .15958 L
.60815 .15722 L
.61703 .15432 L
.63742 .14523 L
.65599 .13425 L
.69589 .10347 L
.73427 .06729 L
.7537 .04762 L
.76401 .03702 L
.77511 .02559 L
.78027 .02028 L
.78309 .0174 L
.78446 .01599 L
.7857 .01472 L
.78685 .01587 L
.78794 .01698 L
.79034 .01941 L
.7954 .02453 L
.81443 .04333 L
.85294 .07799 L
.87247 .09307 L
.89392 .10721 L
.91431 .11797 L
.93337 .12544 L
.9438 .12842 L
.94894 .12959 L
.9537 .13049 L
.95792 .13115 L
.96258 .13172 L
.96483 .13193 L
.96726 .13212 L
.9686 .13221 L
.96983 .13227 L
.97108 .13233 L
.97225 .13237 L
.97316 .13239 L
.97413 .13241 L
.97521 .13243 L
.97619 .13243 L
Mfstroke
0 0 1 r
.02381 .60332 m
.02499 .60319 L
.02605 .60283 L
.02729 .60216 L
.02846 .60125 L
.03053 .59899 L
.03279 .59561 L
.03527 .59079 L
.0379 .58443 L
.04262 .56992 L
.05205 .52961 L
.06244 .47 L
.08274 .32184 L
.10458 .14841 L
.10974 .10988 L
.11537 .07013 L
.11794 .0529 L
.12068 .03528 L
.12202 .02701 L
.12327 .0194 L
.1244 .0167 L
.12562 .02376 L
.13557 .07437 L
.14487 .10949 L
.14945 .12228 L
.15437 .13263 L
.15718 .13699 L
.15983 .14011 L
.16099 .14116 L
.16221 .14208 L
.16285 .14248 L
.16356 .14286 L
.16481 .14337 L
.16544 .14355 L
.16613 .14368 L
.16686 .14376 L
.16753 .14377 L
.16874 .14365 L
.17003 .14332 L
.17076 .14304 L
.17155 .14267 L
.17299 .14181 L
.17567 .13956 L
.17825 .13666 L
.18098 .13284 L
.18587 .12422 L
.19531 .10227 L
.20544 .07322 L
.21495 .04361 L
.21957 .02916 L
Mistroke
.22158 .02296 L
.22264 .01974 L
.22376 .01637 L
.22508 .01699 L
.22629 .02056 L
.22866 .02742 L
.23389 .04168 L
.2396 .0557 L
.24493 .06701 L
.24995 .0759 L
.25452 .0824 L
.2596 .08774 L
.26239 .08982 L
.26366 .09056 L
.26503 .09122 L
.26627 .09169 L
.26741 .09202 L
.2685 .09223 L
.26964 .09236 L
.2709 .09239 L
.27206 .09231 L
.27335 .0921 L
.27406 .09193 L
.27471 .09175 L
.27725 .09073 L
.27868 .08995 L
.28 .08911 L
.28498 .08488 L
.28925 .08004 L
.29394 .07358 L
.30342 .05754 L
.31342 .03776 L
.31834 .02756 L
.32051 .02305 L
.3229 .01811 L
.32421 .01543 L
.32544 .01649 L
.32674 .01911 L
.32814 .02191 L
.33383 .03285 L
.34381 .0496 L
.34843 .056 L
.35336 .06173 L
.3562 .06445 L
.35878 .06656 L
.36123 .06822 L
.36382 .06961 L
.36511 .07017 L
.36653 .07067 L
.36782 .07102 L
Mistroke
.36903 .07127 L
.36975 .07138 L
.37045 .07146 L
.37175 .07153 L
.37247 .07153 L
.37314 .0715 L
.37388 .07145 L
.37467 .07135 L
.37536 .07124 L
.376 .07111 L
.37744 .07075 L
.37871 .07034 L
.38004 .06981 L
.38492 .06712 L
.38747 .06525 L
.38988 .0632 L
.3944 .05871 L
.40457 .04596 L
.41329 .03298 L
.41792 .02568 L
.42052 .02153 L
.42291 .01773 L
.42407 .01589 L
.42534 .01554 L
.42598 .01655 L
.42666 .01762 L
.42789 .01954 L
.43257 .02666 L
.44283 .04072 L
.4478 .04646 L
.45249 .05108 L
.45702 .05473 L
.46126 .05737 L
.46349 .05844 L
.46589 .05935 L
.46726 .05975 L
.46856 .06006 L
.46972 .06027 L
.47099 .06042 L
.47169 .06048 L
.47235 .06051 L
.47358 .06052 L
.47427 .06049 L
.4749 .06045 L
.4756 .06039 L
.47633 .06029 L
.47756 .06008 L
.4787 .05983 L
.48129 .05904 L
.48369 .05807 L
Mistroke
.48595 .05692 L
.4902 .05425 L
.49974 .04595 L
.50943 .03501 L
.51474 .02831 L
.51971 .0218 L
.52187 .01893 L
.52393 .0162 L
.52507 .01472 L
.52631 .01635 L
.52848 .01919 L
.53815 .03117 L
.54827 .04177 L
.55324 .04594 L
.55781 .04907 L
.56309 .05176 L
.56587 .05276 L
.56727 .05316 L
.56881 .0535 L
.57011 .05372 L
.57129 .05387 L
.57195 .05393 L
.57266 .05397 L
.57396 .054 L
.57517 .05397 L
.57646 .05387 L
.57756 .05374 L
.57878 .05354 L
.58112 .053 L
.58369 .05217 L
.58637 .05106 L
.58886 .04981 L
.59812 .04344 L
.6082 .03398 L
.6138 .02794 L
.61897 .02207 L
.62154 .01909 L
.62394 .0163 L
.62515 .0149 L
.62645 .01602 L
.62921 .01919 L
.64031 .0312 L
.64537 .03601 L
.65076 .0405 L
.65575 .04397 L
.66045 .04656 L
.66301 .04767 L
.66577 .04862 L
.66699 .04897 L
.66827 .04927 L
Mistroke
.66948 .04951 L
.67058 .04968 L
.67189 .04983 L
.67262 .04988 L
.6733 .04992 L
.67452 .04995 L
.67521 .04994 L
.67585 .04992 L
.67653 .04988 L
.67718 .04983 L
.67788 .04975 L
.67865 .04966 L
.6802 .0494 L
.68162 .04909 L
.68405 .0484 L
.6863 .0476 L
.69142 .04519 L
.6964 .04211 L
.70172 .03812 L
.71198 .02882 L
.71738 .02334 L
.72034 .02025 L
.7231 .01733 L
.72433 .01601 L
.72551 .01477 L
.72615 .01533 L
.72686 .01608 L
.7281 .01738 L
.73359 .02308 L
.74326 .0323 L
.75263 .03962 L
.75798 .04284 L
.763 .04513 L
.76556 .04601 L
.76696 .0464 L
.76826 .04672 L
.76947 .04696 L
.77057 .04714 L
.77179 .04729 L
.7731 .0474 L
.77377 .04744 L
.77449 .04746 L
.77578 .04746 L
.7765 .04744 L
.77717 .0474 L
.77791 .04734 L
.7787 .04726 L
.78012 .04707 L
.78146 .04682 L
.78399 .04621 L
Mistroke
.78658 .04539 L
.78902 .04443 L
.79358 .04218 L
.80381 .03525 L
.81257 .02767 L
.81722 .02325 L
.82219 .01833 L
.82355 .01697 L
.82484 .01569 L
.82599 .01488 L
.82725 .01614 L
.83196 .02081 L
.84228 .03037 L
.85181 .03773 L
.85647 .0406 L
.86075 .04275 L
.86528 .04447 L
.86765 .04514 L
.87016 .04565 L
.8714 .04584 L
.87208 .04592 L
.87272 .04598 L
.87398 .04607 L
.87511 .04611 L
.87577 .04612 L
.87647 .04611 L
.87771 .04605 L
.87841 .046 L
.87906 .04594 L
.88053 .04575 L
.88183 .04553 L
.88325 .04524 L
.88583 .04454 L
.89066 .04273 L
.89631 .03981 L
.90154 .0364 L
.91214 .02787 L
.91734 .02312 L
.92211 .01855 L
.9232 .0175 L
.92437 .01636 L
.92547 .01529 L
.92647 .0151 L
.92759 .0162 L
.92866 .01723 L
.93106 .01955 L
.94073 .02847 L
.94968 .03561 L
.95457 .03886 L
.95916 .04139 L
Mistroke
.96306 .04311 L
.96726 .04449 L
.9684 .04477 L
.96965 .04504 L
.97075 .04524 L
.97192 .04541 L
.97308 .04554 L
.97414 .04562 L
.97519 .04567 L
.97619 .04569 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[34]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo000iOol0
0`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`0OOol5000OOol50002Ool00`00Oomoo`02Ool0
0`00Oomoo`0POol3000ROol30003Ool00`00Oomoo`02Ool00`00Oomoo`0POol2000COol003Qoo`03
001oo`0000Moo`03001oo`00029oo`03001oogoo025oo`03001oogoo00Ioo`03001oo`00025oo`03
001oogoo029oo`03001oogoo00Moo`03001oo`0002=oo`03001oogoo011oo`00>7oo00<007oo0000
2Goo00<007ooOol087oo00<007ooOol08Goo00<007ooOol027oo00<007ooOol087oo00<007ooOol0
8Woo00<007ooOol027oo00<007ooOol087oo00<007ooOol04Goo000hOol00`00Ool00007Ool2000S
Ool00`00Oomoo`0QOol00`00Oomoo`06Ool2000SOol00`00Oomoo`0ROol00`00Oomoo`06Ool2000T
Ool00`00Oomoo`0@Ool003Qoo`03001oo`0000Moo`03001oogoo029oo`03001oogoo025oo`03001o
ogoo00Ioo`03001oogoo025oo`03001oo`00029oo`03001oo`0000Moo`03001oogoo025oo`03001o
o`00019oo`00>Goo00<007ooOol01Woo0`008Goo0P008Woo0P0027oo0`008Woo00<007ooOol08Woo
00<007ooOol01Woo0`008Woo00<007ooOol04Goo003oOolQOol001Eoo`03001oogoo0?moo`Uoo`00
5Goo00<007ooOol0ogoo2Goo000EOol00`00Oomoo`3oOol9Ool001Eoo`03001oogoo0?moo`Uoo`00
3goo?00000<07`0000006@0000<07`0000004P000W`0100000<07`00000060000P0O6@000P0O6@00
0P0O3`0000=l00000000200000<07`00000060000P0O4`000Goo000EOol00`00Oomoo`05Ool00`00
Oomoo`05Ool00`00Oomoo`06Ool00`00Ool07`05Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00
Oomoo`02Ool201l2Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`04Ool201l8Ool00`00
Oomoo`05Ool01000Oomoogoo0W`00Woo00@007oo01l07`Aoo`03001oogoo00Ioo`03001oogoo00Eo
o`06001oogoo01moo`0O0Woo00<007ooOol01Goo00<007ooOol01Woo00<007ooOol00goo00<07goo
01l01goo00<007ooOol01Goo00<007ooOol01Goo0`0O1Woo00<007ooOol01Goo00=l07ooO0001Goo
00H007ooOol07goo01l3Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`02Ool401l8Ool0
0`00Oomoo`05Ool10001Ool1Ool001Eoo`03001oogoo01Qoo`807`aoo`03001oogoo00Yoo`807aUo
o`0301l0000O019oo`04O01oogooO002Ool00`0OOol07`0=Ool00`00Oomoo`08Ool0100OOomoo`0O
5goo00D07gooOol0000O01Ioo`0301moogoo00807`]oo`05O00007ooOoml0006Ool01@0OOomoogoo
01l05Woo00H07gooOomoo`0001lBOol001Eoo`03001oogoo01Qoo`807aQoo`0401moogoo01lGOol0
100OOomoo`0O4Woo00Il07ooOomoog`001l3Ool00`0OOomoo`0DOol00`0OOomoo`02Ool00`0OOomo
o`0COol00`0OOomoo`03Ool00`0OOomoo`0BOol00`0OOomoo`03Ool00`0OOomoo`07Ool00g`0Oomo
o`03Ool017`0Oomoogoo0P0O1Goo0P0O4goo00<07gooOol00goo00<07gooOol047oo000EOol00`00
Oomoo`0HOol201lHOol0100OOomoo`0O5goo00D07gooOomoo`0O011oo`03O01oogoo009oo`0301ml
07oo00=oo`0301moogoo019oo`0301moogoo00Aoo`0301moogoo015oo`0301moogoo00Eoo`0301mo
ogoo011oo`0301moogoo00Eoo`0301moogoo00Eoo`03O01oogoo00Eoo`03O01oo`0O00Uoo`0301mo
ogoo011oo`0301moogoo00Aoo`0301moogoo00moo`005Goo00<007ooOol05goo00<07goo01l067oo
00@07gooOol07aIoo`0301moogoo009oo`0301moogoo00eoo`03O01oogoo00=oo`0301ml07oo00=o
o`0301moogoo015oo`0301moogoo00Ioo`0301moogoo00moo`0301moogoo00Ioo`0301moogoo00io
o`807`Uoo`0301moogoo00=oo`03O01oogoo00Moo`03O0007goo00Uoo`0301moogoo00eoo`807`Qo
o`807`moo`005Goo00<007ooOol05goo00@07gooOol07aIoo`0301moogoo009oo`0301moogoo01=o
o`0301moogoo00=oo`0301moogoo00aoo`03O01oogoo009oo`0401moogooO004Ool00`0OOomoo`0?
Ool00`0OOomoo`08Ool00`0OOomoo`0=Ool00`0OOomoo`08Ool00`0OOomoo`0<Ool00`0OOomoo`0:
Ool01@0OOomoogooO0002Goo0P0O00=l07ooOol02Goo00<07gooOol02goo00<07gooOol02Woo00<0
7gooOol037oo000EOol00`00Oomoo`0GOol0100OOomoo`0O5Woo00<07gooOol00Woo00<07gooOol0
4Woo00<07gooOol017oo00<07gooOol02goo00=l07ooOol00goo00@07gooOoml00Eoo`0301moogoo
00eoo`0301moogoo00Yoo`0301moogoo00]oo`0301moogoo00Yoo`0301moogoo00Yoo`0301moogoo
00aoo`0301moog`000Qoo`807`=oo`03O01oogoo00Uoo`0301moogoo00Qoo`807`ioo`807`aoo`00
5Goo0P0067oo00@07gooOol07aIoo`0301moogoo009oo`0301moogoo019oo`0301moogoo00Eoo`03
01moogoo00Yoo`03O01oogoo009oo`0301moogoo009oo`03O01oogoo009oo`0301moogoo00aoo`03
01moogoo00aoo`0301moogoo00Uoo`0301moogoo00aoo`807`Uoo`0301moogoo00ioo`@07`Aoo`80
7`Ioo`03O01oogoo00Uoo`X07a9oo`D07`Moo`005Goo00<007ooOol05goo00@07gooOol07aIoo`03
01moogoo00=oo`0301moogoo011oo`0301moogoo00Moo`0301moogoo00Qoo`03O01oogoo009oo`03
01moogoo00Aoo`03O01oogoo009oo`0301moogoo00Yoo`0301moogoo00ioo`0301moogoo00Moo`03
01moogoo00moo`@07`03Ool07`0O00807a1oo`04O01oogooOol601l8Ool00g`0Oomoo`0=Ool00`0O
Oomoo`0POol001Eoo`03001oogoo01Moo`0401moogoo01lEOol00`0OOomoo`04Ool00`0OOomoo`0@
Ool00`0OOomoo`07Ool00`0OOomoo`08Ool01G`0Oomoogoo01l01goo00=l07ooOol00goo0P0O2Woo
00<07gooOol03goo0`0O0goo0`0O5Goo0`0O4Woo00=l07ooOol04Goo00=l07ooOol0;goo000EOol0
0`00Oomoo`0GOol0100OOomoo`0O5Goo00<07gooOol01Goo00<07gooOol03Woo00<07gooOol02Goo
00<07gooOol01Woo00=l07ooOol00Woo00<07gooOol01Woo00=l07ooOol017oo00<07gooOol01Goo
0P0O57oo100O;7oo00=l07ooOol04goo00=l07ooOol0;Woo000EOol00`00Oomoo`0GOol0100OOomo
o`0O57oo00<07gooOol01Woo00<07gooOol03Woo00<07gooOol02Woo00<07gooOol01Goo00El07oo
Oomoo`0O00Yoo`03O01oogoo00Aoo`L07dEoo`03O01oogoo01Eoo`03O01oogoo02eoo`005Goo00<0
07ooOol05Woo00<07gooOol00Woo00<07gooOol04Goo00<07gooOol01goo00<07gooOol037oo00<0
7gooOol037oo00<07gooOol00goo00El07ooOomoo`0O00aoo`03O01oogoo04ioo`03O01oogoo01Mo
o`9l02eoo`005Goo00<007ooOol05Woo00<07gooOol00Woo00<07gooOol04Goo00<07gooOol01goo
00<07gooOol02goo00<07gooOol03Woo00<07gooOol00Woo00Al07oo01l07`eoo`03O01oogoo04eo
o`03O01oogoo01Yoo`03O01oogoo02Yoo`005Goo00<007ooOol05Woo00<07gooOol00Woo00<07goo
Ool047oo00<07gooOol027oo00<07gooOol02goo00<07gooOol03goo1P0O47oo00=l07ooOol0Bgoo
00=l07ooOol077oo00=l07ooOol0:Goo000EOol2000GOol00`0OOomoo`02Ool00`0OOomoo`0@Ool0
0`0OOomoo`09Ool00`0OOomoo`09Ool00`0OOomoo`0COol00g`0Oomoo`0AOol00g`0Oomoo`19Ool0
0g`0Oomoo`0NOol00g`0Oomoo`0XOol001Eoo`03001oogoo01Ioo`0301moogoo009oo`0301moogoo
011oo`0301moogoo00Uoo`0301moogoo00Qoo`0301moogoo01=oo`03O01oogoo019oo`03O01oogoo
04Qoo`03O01oogoo021oo`03O01oogoo02Moo`005Goo00<007ooOol05Goo00<07gooOol017oo00<0
7gooOol03Woo00<07gooOol02goo0P0O27oo00<07gooOol04goo00=l07ooOol04goo00=l07ooOol0
AWoo00=l07ooOol08Woo0W`09goo000EOol00`00Oomoo`0EOol00`0OOomoo`04Ool00`0OOomoo`0>
Ool00`0OOomoo`0<Ool00`0OOomoo`05Ool00`0OOomoo`0COol00g`0Oomoo`0EOol00g`0Oomoo`14
Ool00g`0Oomoo`0UOol00g`0Oomoo`0TOol001Eoo`03001oogoo01Eoo`0301moogoo00Aoo`0301mo
ogoo00ioo`0301moogoo00eoo`807`=oo`807aIoo`03O01oogoo01Ioo`03O01oogoo049oo`03O01o
ogoo02Moo`9l02Aoo`005Goo00<007ooOol05Goo00<07gooOol017oo00<07gooOol03Woo00<07goo
Ool03Woo1@0O5Woo00=l07ooOol05goo00=l07ooOol0@Goo00=l07ooOol0:Woo00=l07ooOol08Goo
000EOol00`00Oomoo`0EOol00`0OOomoo`05Ool00`0OOomoo`0<Ool00`0OOomoo`0ZOol00g`0Oomo
o`0HOol00g`0Oomoo`0oOol00g`0Oomoo`0/Ool2O00QOol001Eoo`03001oogoo01Eoo`0301moogoo
00Eoo`0301moogoo00aoo`0301moogoo02Uoo`03O01oogoo01Yoo`03O01oogoo03eoo`03O01oogoo
02moo`03O01oogoo01ioo`005Goo0P005Goo00<07gooOol01Woo00<07gooOol037oo00<07gooOol0
:Goo00=l07ooOol06goo00=l07ooOol0>goo00=l07ooOol0<Goo0W`07Woo000EOol00`00Oomoo`0D
Ool00`0OOomoo`07Ool00`0OOomoo`0:Ool00`0OOomoo`0YOol00g`0Oomoo`0MOol00g`0Oomoo`0h
Ool2O00fOol00g`0Oomoo`0KOol001Eoo`03001oogoo01Aoo`0301moogoo00Moo`0301moogoo00Yo
o`0301moogoo02Uoo`03O01oogoo01ioo`03O01oogoo03Ioo`03O01oogoo03Moo`9l01]oo`005Goo
00<007ooOol057oo00<07gooOol01goo00<07gooOol02Goo00<07gooOol0:Goo00=l07ooOol087oo
00=l07ooOol0=7oo00=l07ooOol0>Woo0W`06Goo000EOol00`00Oomoo`0DOol00`0OOomoo`08Ool0
0`0OOomoo`08Ool00`0OOomoo`0YOol00g`0Oomoo`0QOol00g`0Oomoo`0aOol2O00oOol2O00GOol0
01Eoo`03001oogoo01Aoo`0301moogoo00Qoo`0301moogoo00Moo`0301moogoo02Uoo`03O01oogoo
02=oo`03O01oogoo02moo`03O01oogoo045oo`9l01Eoo`001Goo00<007ooOol00Woo00@007ooOomo
o`<000Aoo`03001oogoo01Aoo`0301moogoo00Qoo`0301moogoo00Moo`0301moogoo02Uoo`03O01o
ogoo02Aoo`9l02ioo`03O01oogoo04Aoo`=l019oo`0017oo00<007oo00001goo00<007ooOol017oo
00<007ooOol04goo00<07gooOol02Woo00<07gooOol01Goo00<07gooOol0:Goo00=l07ooOol09goo
00=l07ooOol0:Goo0W`0BWoo1G`03Goo0004Ool00`00Ool00008Ool00`00Oomoo`03Ool3000COol0
0`0OOomoo`0:Ool00`0OOomoo`05Ool00`0OOomoo`0XOol00g`0Oomoo`0YOol00g`0Oomoo`0WOol0
0g`0Oomoo`1?Ool6O007Ool000Aoo`03001oo`0000Qoo`03001oogoo00=oo`03001oogoo01=oo`03
01moogoo00]oo`0301moogoo00=oo`0301moogoo02Uoo`03O01oogoo02Yoo`03O01oogoo02Aoo`9l
05moo`0017oo00<007oo00001goo00<007oo000017oo00<007ooOol04goo00<07gooOol037oo00D0
7gooOomoo`0O02]oo`03O01oogoo02aoo`9l029oo`9l065oo`001Goo00<007ooOol01goo00<007oo
Ool00goo00<007ooOol04goo00<07gooOol03Goo100O:goo00=l07ooOol0;Woo00=l07ooOol07Woo
00=l07ooOol0HGoo000EOol00`00Oomoo`0COol00`0OOomoo`0kOol00g`0Oomoo`0`Ool2O00LOol2
O01TOol001Eoo`03001oogoo01=oo`0301moogoo03]oo`03O01oogoo039oo`=l01Moo`9l06Ioo`00
5Goo00<007ooOol04goo00<07gooOol0>Woo00=l07ooOol0=Woo0W`04goo0W`0J7oo000EOol00`00
Oomoo`0COol00`0OOomoo`0jOol00g`0Oomoo`0hOol4O00:Ool5O01ZOol001Eoo`8001=oo`0301mo
ogoo03Yoo`03O01oogoo03eoo`Yl06moo`005Goo00<007ooOol04Woo00<07gooOol0>Woo00=l07oo
Ool0]Woo000EOol00`00Oomoo`0BOol00`0OOomoo`0iOol00g`0Oomoo`2gOol001Eoo`03001oogoo
019oo`0301moogoo03Uoo`03O01oogoo0;Moo`005Goo00<007ooOol04Woo00<07gooOol0>7oo00=l
07ooOol0^7oo000EOol00`00Oomoo`0BOol00`0OOomoo`0hOol00g`0Oomoo`2hOol001Eoo`03001o
ogoo019oo`0301moogoo03Moo`03O01oogoo0;Uoo`005Goo00<007ooOol04Woo00<07gooOol0=goo
00=l07ooOol0^Goo000EOol2000BOol00`0OOomoo`0gOol00g`0Oomoo`2jOol001Eoo`03001oogoo
015oo`0301moogoo03Moo`03O01oogoo0;Yoo`005Goo00<007ooOol04Goo00<07gooOol0=Woo00=l
07ooOol0^goo000EOol00`00Oomoo`0AOol00`0OOomoo`0fOol00g`0Oomoo`2kOol001Eoo`03001o
ogoo015oo`0301moogoo03Eoo`03O01oogoo0;aoo`005Goo00<007ooOol04Goo00<07gooOol0=Goo
00=l07ooOol0_7oo000EOol00`00Oomoo`0AOol00`0OOomoo`0eOol00g`0Oomoo`2lOol001Eoo`03
001oogoo015oo`0301moogoo03Aoo`03O01oogoo0;eoo`005Goo0P004Goo00<07gooOol0=Goo00=l
07ooOol0_Goo000EOol00`00Oomoo`0@Ool00`0OOomoo`0dOol00g`0Oomoo`2nOol001Eoo`03001o
ogoo011oo`0301moogoo03Aoo`03O01oogoo0;ioo`005Goo00<007ooOol047oo00<07gooOol0<goo
00=l07ooOol0_goo000EOol00`00Oomoo`0@Ool00`0OOomoo`0cOol00g`0Oomoo`2oOol001Eoo`03
001oogoo011oo`0301moogoo039oo`03O01oogoo0<1oo`001Goo00<007ooOol00Woo00<007ooOol0
0Woo0`000goo00<007ooOol047oo00<07gooOol0<Woo00=l07ooOol0`7oo0004Ool00`00Ool00009
Ool00`00Oomoo`02Ool00`00Oomoo`0@Ool00`0OOomoo`0aOol00g`0Oomoo`31Ool000Aoo`03001o
o`0000Moo`@000=oo`<000moo`0301moogoo039oo`03O01oogoo0<5oo`0017oo00<007oo00001goo
00<007oo000017oo00<007ooOol03goo00<07gooOol0<Goo00=l07ooOol0`Woo0004Ool00`00Ool0
0008Ool20004Ool00`00Oomoo`0?Ool00`0OOomoo`0aOol00g`0Oomoo`32Ool000Eoo`03001oogoo
00Qoo`03001oogoo009oo`03001oogoo00moo`0301moogoo035oo`03O01oogoo0<9oo`005Goo00<0
07ooOol03goo00<07gooOol0<7oo00=l07ooOol0`goo000EOol00`00Oomoo`0?Ool00`0OOomoo`0`
Ool00g`0Oomoo`33Ool001Eoo`03001oogoo00moo`0301moogoo02moo`03O01oogoo0<Aoo`005Goo
00<007ooOol03goo00<07gooOol0;goo00=l07ooOol0a7oo000EOol2000?Ool00`0OOomoo`0_Ool0
0g`0Oomoo`35Ool001Eoo`03001oogoo00ioo`0301moogoo02moo`03O01oogoo0<Eoo`005Goo00<0
07ooOol03Woo00<07gooOol0;Woo00=l07ooOol0aWoo000EOol00`00Oomoo`0>Ool00`0OOomoo`0^
Ool00g`0Oomoo`36Ool001Eoo`03001oogoo00ioo`0301moogoo02eoo`03O01oogoo0<Moo`005Goo
00<007ooOol03Woo00<07gooOol0;Goo00=l07ooOol0agoo000EOol00`00Oomoo`0>Ool00`0OOomo
o`0/Ool00g`0Oomoo`38Ool001Eoo`03001oogoo00ioo`0301moogoo02aoo`03O01oogoo0<Qoo`00
5Goo0P003Woo00<07gooOol0;7oo00=l07ooOol0bGoo000EOol00`00Oomoo`0=Ool00`0OOomoo`0/
Ool00g`0Oomoo`39Ool001Eoo`03001oogoo00eoo`0301moogoo02]oo`03O01oogoo0<Yoo`005Goo
00<007ooOol03Goo00<07gooOol0:goo00=l07ooOol0bWoo000EOol00`00Oomoo`0=Ool00`0OOomo
o`0ZOol00g`0Oomoo`3;Ool001Eoo`03001oogoo00eoo`0301moogoo02Yoo`03O01oogoo0<]oo`00
5Goo00<007ooOol03Goo00<07gooOol0:Goo00=l07ooOol0c7oo000EOol00`00Oomoo`0<Ool00`0O
Oomoo`0ZOol00g`0Oomoo`3<Ool001Eoo`8000eoo`0301moogoo02Uoo`03O01oogoo0<eoo`005Goo
00<007ooOol037oo00<07gooOol0:Goo00=l07ooOol0cGoo000EOol00`00Oomoo`0<Ool00`0OOomo
o`0XOol00g`0Oomoo`3>Ool001Eoo`03001oogoo00aoo`0301moogoo02Qoo`03O01oogoo0<ioo`00
5Goo00<007ooOol037oo00<07gooOol09goo00=l07ooOol0cgoo000EOol00`00Oomoo`0<Ool00`0O
Oomoo`0WOol00g`0Oomoo`3?Ool000Eoo`03001oogoo009oo`04001oogooOol20005Ool00`00Oomo
o`0;Ool00`0OOomoo`0WOol00g`0Oomoo`3@Ool000Aoo`03001oo`0000Moo`03001oo`0000Aoo`03
001oogoo00]oo`0301moogoo02Moo`03O01oogoo0=1oo`0017oo00<007oo00001goo00<007oo0000
17oo0`002goo00<07gooOol09Woo00=l07ooOol0dGoo0004Ool00`00Ool00007Ool20005Ool00`00
Oomoo`0;Ool00`0OOomoo`0VOol00g`0Oomoo`3AOol000Aoo`03001oo`0000Moo`03001oogoo00Ao
o`03001oogoo00]oo`0301moogoo02Eoo`03O01oogoo0=9oo`001Goo00<007ooOol01goo0P0017oo
00<007ooOol02goo00<07gooOol09Goo00=l07ooOol0dWoo000EOol00`00Oomoo`0;Ool00`0OOomo
o`0TOol00g`0Oomoo`3COol001Eoo`03001oogoo00Yoo`0301moogoo02Eoo`03O01oogoo0==oo`00
5Goo00<007ooOol02Woo00<07gooOol097oo00=l07ooOol0e7oo000EOol00`00Oomoo`0:Ool00`0O
Oomoo`0TOol00g`0Oomoo`3DOol001Eoo`8000]oo`0301moogoo02=oo`03O01oogoo0=Eoo`005Goo
00<007ooOol02Woo00<07gooOol08goo00=l07ooOol0eGoo000EOol00`00Oomoo`0:Ool00`0OOomo
o`0ROol00g`0Oomoo`3FOol001Eoo`03001oogoo00Uoo`0301moogoo02=oo`03O01oogoo0=Ioo`00
5Goo00<007ooOol02Goo00<07gooOol08Woo00=l07ooOol0egoo000EOol00`00Oomoo`09Ool00`0O
Oomoo`0QOol00g`0Oomoo`3HOol001Eoo`03001oogoo00Uoo`0301moogoo025oo`03O01oogoo0=Qo
o`005Goo00<007ooOol02Goo00<07gooOol087oo00=l07ooOol0fGoo000EOol2000:Ool00`0OOomo
o`0POol00g`0Oomoo`3IOol001Eoo`03001oogoo00Uoo`0301moogoo01moo`03O01oogoo0=Yoo`00
5Goo00<007ooOol027oo00<07gooOol087oo00=l07ooOol0fWoo000EOol00`00Oomoo`08Ool00`0O
Oomoo`0OOol00g`0Oomoo`3KOol001Eoo`03001oogoo00Qoo`0301moogoo01moo`03O01oogoo0=]o
o`005Goo00<007ooOol027oo00<07gooOol07Woo00=l07ooOol0g7oo000EOol00`00Oomoo`08Ool0
0`0OOomoo`0NOol00g`0Oomoo`3LOol001Eoo`03001oogoo00Qoo`0301moogoo01eoo`03O01oogoo
0=eoo`005Goo0P002Goo00<07gooOol077oo00=l07ooOol0gWoo000EOol00`00Oomoo`07Ool00`0O
Oomoo`0MOol00g`0Oomoo`3NOol001Eoo`03001oogoo00Moo`0301moogoo01aoo`03O01oogoo0=mo
o`005Goo00<007ooOol01goo00<07gooOol077oo00=l07ooOol0ggoo000EOol00`00Oomoo`07Ool0
0`0OOomoo`0KOol00g`0Oomoo`3POol001Eoo`03001oogoo00Moo`0301moogoo01Yoo`03O01oogoo
0>5oo`001Goo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol00goo00<007ooOol01goo00<0
7gooOol06Woo00=l07ooOol0hGoo0004Ool00`00Ool00007Ool00`00Ool00004Ool00`00Oomoo`07
Ool00`0OOomoo`0IOol00g`0Oomoo`3ROol000Aoo`03001oo`0000Moo`03001oo`0000Aoo`<000Io
o`0301moogoo01Yoo`03O01oogoo0>9oo`0017oo00<007oo000027oo00<007ooOol00goo00<007oo
Ool01Woo00<07gooOol06Goo00=l07ooOol0hgoo0004Ool00`00Ool00007Ool00`00Ool00004Ool0
0`00Oomoo`06Ool00`0OOomoo`0IOol00g`0Oomoo`3SOol000Eoo`03001oogoo00Moo`03001oogoo
00=oo`03001oogoo00Ioo`0301moogoo01Qoo`03O01oogoo0>Aoo`005Goo00<007ooOol01Woo00<0
7gooOol05goo00=l07ooOol0iGoo000EOol00`00Oomoo`06Ool00`0OOomoo`0GOol00g`0Oomoo`3U
Ool001Eoo`03001oogoo00Ioo`0301moogoo01Ioo`03O01oogoo0>Ioo`005Goo00<007ooOol01Woo
00<07gooOol05Woo00=l07ooOol0iWoo000EOol20006Ool00`0OOomoo`0FOol00g`0Oomoo`3WOol0
01Eoo`03001oogoo00Eoo`0301moogoo01Eoo`03O01oogoo0>Qoo`005Goo00<007ooOol01Goo00<0
7gooOol057oo00=l07ooOol0jGoo000EOol00`00Oomoo`05Ool00`0OOomoo`0COol00g`0Oomoo`3Z
Ool001Eoo`03001oogoo00Eoo`0301moogoo01=oo`03O01oogoo0>Yoo`005Goo00<007ooOol01Goo
00<07gooOol04Woo00=l07ooOol0jgoo000EOol00`00Oomoo`04Ool00`0OOomoo`0BOol00g`0Oomo
o`3/Ool001Eoo`03001oogoo00Aoo`0301moogoo015oo`03O01oogoo0>eoo`005Goo0P001Goo00<0
7gooOol047oo00=l07ooOol0kWoo000EOol00`00Oomoo`04Ool00`0OOomoo`0?Ool00g`0Oomoo`3_
Ool001Eoo`03001oogoo00=oo`0301moogoo011oo`03O01oogoo0>moo`005Goo00<007ooOol00goo
00<07gooOol03goo00=l07ooOol0l7oo000EOol00`00Oomoo`03Ool00`0OOomoo`0>Ool00g`0Oomo
o`3aOol001Eoo`03001oogoo00=oo`0301moogoo00eoo`03O01oogoo0?9oo`005Goo00<007ooOol0
0Woo00<07gooOol03Goo00=l07ooOol0lgoo000EOol00`00Oomoo`02Ool00`0OOomoo`0<Ool00g`0
Oomoo`3dOol001Eoo`8000=oo`0301moogoo00Yoo`9l0?Moo`005Goo00D007ooOomoo`0O00aoo`03
O01oogoo0?Moo`005Goo00D007ooOomoo`0O00]oo`03O01oogoo0?Qoo`005Goo00D007ooOomoo`0O
00Uoo`9l0?]oo`005Goo00@007ooOol07`Qoo`9l0?eoo`005Goo00@007ooOol07`Ioo`9l0?moo`00
3Goo1@000goo00<007oo01l01Woo00=l07ooOol0ogoo000?Ool00`00Oomoo`03Ool00`0001l07`02
Ool4O03oOol3Ool000moo`03001oogoo00=oo`807`=l0?moo`Moo`003goo00<007ooOol00goo00<0
07ooOol0ogoo2Goo000?Ool00`00Oomoo`03Ool00`00Oomoo`3oOol9Ool000ioo`8000Eoo`03001o
ogoo0?moo`Uoo`005Goo00<007ooOol0ogoo2Goo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.260737, -0.077475, 
  0.0121324, 0.00624854}}]
}, Open  ]],

Cell[TextData[{
  "The filter clearly has a lowpass characteristic (that it why it is used to \
smooth data!), but its attenuation in the high frequencies is very poor. The \
so-called ",
  StyleBox["sidelobes",
    FontSlant->"Italic"],
  " have relatively large magnitudes. A lowpass filter with the \
characteristics shown above would be unacceptable for many signal/image \
processing applications. Two features of particular importance are ",
  StyleBox["mainlobe width",
    FontSlant->"Italic"],
  " and ",
  StyleBox["sidelobe attenuation",
    FontSlant->"Italic"],
  ". For the two case shown above we have\n\n\t",
  Cell[BoxData[
      FormBox[GridBox[{
            {"length", \(mainlobe\ width\), \(peak\ sidelobe\ \)},
            {\(\[ScriptCapitalN] = 5\), "1.25", "0.25"},
            {\(\[ScriptCapitalN] = 19\), "0.33", "0.25"}
            }], TraditionalForm]]],
  "\n\nThe attenuation is typically measured in decibels at the peak of the \
largest sidelobe. The approximate dB value is"
}], "Text",
  PageWidth->WindowWidth,
  Evaluatable->False,
  CellHorizontalScrolling->False],

Cell[CellGroupData[{

Cell[BoxData[
    \(20\ Log[0.25]\ dB\)], "Input",
  CellLabel->"In[36]:=",
  PageWidth->WindowWidth],

Cell[BoxData[
    \(\(-27.7258872223978158`\)\ dB\)], "Output",
  CellLabel->"Out[36]="]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(4  \[Pi]/5\  // N\)], "Input",
  CellLabel->"In[38]:="],

Cell[BoxData[
    \(2.51327412287183449`\)], "Output",
  CellLabel->"Out[38]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["DTFT SYNTHESIS FORMULA"], "Section",
  Evaluatable->False,
  CellHorizontalScrolling->False,
  AspectRatioFixed->True],

Cell[TextData[
"The frequency variable \[Omega] is continuous, so functions of frequency are \
complex and continuous.  In addition, as stated above, the DTFT is periodic \
with period 2\[Pi]. The synthesis equation is therefore similar in form to \
the analysis equation of the  continuous-time Fourier series [Oppenheim, \
1996]."], "Text",
  Evaluatable->False,
  CellHorizontalScrolling->False,
  AspectRatioFixed->True,
  FontFamily->"Times New Roman",
  FontSize->12,
  FontWeight->"Plain",
  FontSlant->"Plain",
  FontTracking->"Plain",
  FontColor->GrayLevel[0],
  Background->GrayLevel[1],
  FontVariations->{"Underline"->False,
  "Outline"->False,
  "Shadow"->False}],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm
    \`x[n]\  = \ 
      1\/\(2  \[Pi]\)\ 
        \(\[Integral]\_\(-\[Pi]\)\%\[Pi]\( X(\[Omega])\)\ 
            \(\[ExponentialE]\^\(\ \ j\ \[Omega]\ n\)\) 
            \[DifferentialD]\[Omega]\)\)]]], "NumberedEquation"],

Cell[TextData[{
  "A simple, but important result is the inverse DTFT of the ",
  StyleBox["ideal lowpass",
    FontSlant->"Italic"],
  " filter. This filter has the following definition:"
}], "Text",
  Evaluatable->False,
  CellHorizontalScrolling->False,
  AspectRatioFixed->True],

Cell[TextData[Cell[BoxData[
    FormBox[
      RowBox[{\(X(\[Omega])\), " ", "=", " ", 
        RowBox[{"{", GridBox[{
              {"1", 
                \(for\  | \[Omega] - 2  \[Pi]\ \ l | \( \[LessEqual] a\)\)},
              {"0", "otherwise"}
              }]}]}], TraditionalForm]]]], "NumberedEquation"],

Cell[TextData[{
  "where ",
  StyleBox["l",
    FontSlant->"Italic"],
  " is an integer. In the fundamental interval, ",
  Cell[BoxData[
      \(TraditionalForm\`l = 0\)]],
  ". The impulse response of this filter is given by the inverse DTFT. "
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(1\/\(2  \[Pi]\)\) 
        \(\[Integral]\_\(-a\)\%a
            \( \[ExponentialE]\^\(\ \[ImaginaryI]\ \[Omega]\ n\)\) 
            \[DifferentialD]\[Omega]\)\  // FullSimplify\)], "Input",
  CellLabel->"In[41]:="],

Cell[BoxData[
    \(Sin[a\ n]\/\(n\ \[Pi]\)\)], "Output",
  CellLabel->"Out[41]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(ListSignalPlot[
      Evaluate[Table[{n, If[n == 0, \ 0.4, Sin[0.4\ \[Pi]\ n]\/\(n\ \[Pi]\)]}
            \ , {n, \(-25\), 25}]]\ , \ PlotRange -> All]; \)\)], "Input",
  CellLabel->"In[5]:=",
  PageWidth->WindowWidth],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0190476 0.108364 1.23739 [
[.11905 .09586 -9 -9 ]
[.11905 .09586 9 0 ]
[.30952 .09586 -9 -9 ]
[.30952 .09586 9 0 ]
[.69048 .09586 -6 -9 ]
[.69048 .09586 6 0 ]
[.88095 .09586 -6 -9 ]
[.88095 .09586 6 0 ]
[.4875 .2321 -18 -4.5 ]
[.4875 .2321 0 4.5 ]
[.4875 .35584 -18 -4.5 ]
[.4875 .35584 0 4.5 ]
[.4875 .47958 -18 -4.5 ]
[.4875 .47958 0 4.5 ]
[.4875 .60332 -18 -4.5 ]
[.4875 .60332 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.11905 .10836 m
.11905 .11461 L
s
[(-20)] .11905 .09586 0 1 Mshowa
.30952 .10836 m
.30952 .11461 L
s
[(-10)] .30952 .09586 0 1 Mshowa
.69048 .10836 m
.69048 .11461 L
s
[(10)] .69048 .09586 0 1 Mshowa
.88095 .10836 m
.88095 .11461 L
s
[(20)] .88095 .09586 0 1 Mshowa
.125 Mabswid
.15714 .10836 m
.15714 .11211 L
s
.19524 .10836 m
.19524 .11211 L
s
.23333 .10836 m
.23333 .11211 L
s
.27143 .10836 m
.27143 .11211 L
s
.34762 .10836 m
.34762 .11211 L
s
.38571 .10836 m
.38571 .11211 L
s
.42381 .10836 m
.42381 .11211 L
s
.4619 .10836 m
.4619 .11211 L
s
.5381 .10836 m
.5381 .11211 L
s
.57619 .10836 m
.57619 .11211 L
s
.61429 .10836 m
.61429 .11211 L
s
.65238 .10836 m
.65238 .11211 L
s
.72857 .10836 m
.72857 .11211 L
s
.76667 .10836 m
.76667 .11211 L
s
.80476 .10836 m
.80476 .11211 L
s
.84286 .10836 m
.84286 .11211 L
s
.08095 .10836 m
.08095 .11211 L
s
.04286 .10836 m
.04286 .11211 L
s
.00476 .10836 m
.00476 .11211 L
s
.91905 .10836 m
.91905 .11211 L
s
.95714 .10836 m
.95714 .11211 L
s
.99524 .10836 m
.99524 .11211 L
s
.25 Mabswid
0 .10836 m
1 .10836 L
s
.5 .2321 m
.50625 .2321 L
s
[(0.1)] .4875 .2321 1 0 Mshowa
.5 .35584 m
.50625 .35584 L
s
[(0.2)] .4875 .35584 1 0 Mshowa
.5 .47958 m
.50625 .47958 L
s
[(0.3)] .4875 .47958 1 0 Mshowa
.5 .60332 m
.50625 .60332 L
s
[(0.4)] .4875 .60332 1 0 Mshowa
.125 Mabswid
.5 .13311 m
.50375 .13311 L
s
.5 .15786 m
.50375 .15786 L
s
.5 .18261 m
.50375 .18261 L
s
.5 .20735 m
.50375 .20735 L
s
.5 .25685 m
.50375 .25685 L
s
.5 .2816 m
.50375 .2816 L
s
.5 .30635 m
.50375 .30635 L
s
.5 .33109 m
.50375 .33109 L
s
.5 .38059 m
.50375 .38059 L
s
.5 .40534 m
.50375 .40534 L
s
.5 .43008 m
.50375 .43008 L
s
.5 .45483 m
.50375 .45483 L
s
.5 .50433 m
.50375 .50433 L
s
.5 .52908 m
.50375 .52908 L
s
.5 .55382 m
.50375 .55382 L
s
.5 .57857 m
.50375 .57857 L
s
.5 .08362 m
.50375 .08362 L
s
.5 .05887 m
.50375 .05887 L
s
.5 .03412 m
.50375 .03412 L
s
.5 .00937 m
.50375 .00937 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
.5 Mabswid
.02381 .10836 m
.02381 .10836 L
s
.01504 w
.02381 .10836 Mdot
.5 Mabswid
.04286 .10836 m
.04286 .09276 L
s
.01504 w
.04286 .09276 Mdot
.5 Mabswid
.0619 .10836 m
.0619 .0983 L
s
.01504 w
.0619 .0983 Mdot
.5 Mabswid
.08095 .10836 m
.08095 .11889 L
s
.01504 w
.08095 .11889 Mdot
.5 Mabswid
.1 .10836 m
.1 .1262 L
s
.01504 w
.1 .1262 Mdot
.5 Mabswid
.11905 .10836 m
.11905 .10836 L
s
.01504 w
.11905 .10836 Mdot
.5 Mabswid
.1381 .10836 m
.1381 .08865 L
s
.01504 w
.1381 .08865 Mdot
.5 Mabswid
.15714 .10836 m
.15714 .0955 L
s
.01504 w
.15714 .0955 Mdot
.5 Mabswid
.17619 .10836 m
.17619 .12198 L
s
.01504 w
.17619 .12198 Mdot
.5 Mabswid
.19524 .10836 m
.19524 .13178 L
s
.01504 w
.19524 .13178 Mdot
.5 Mabswid
.21429 .10836 m
.21429 .10836 L
s
.01504 w
.21429 .10836 Mdot
.5 Mabswid
.23333 .10836 m
.23333 .08161 L
s
.01504 w
.23333 .08161 Mdot
.5 Mabswid
.25238 .10836 m
.25238 .09056 L
s
.01504 w
.25238 .09056 Mdot
.5 Mabswid
.27143 .10836 m
.27143 .12766 L
s
.01504 w
.27143 .12766 Mdot
.5 Mabswid
.29048 .10836 m
.29048 .14242 L
s
.01504 w
.29048 .14242 Mdot
.5 Mabswid
.30952 .10836 m
.30952 .10836 L
s
.01504 w
.30952 .10836 Mdot
.5 Mabswid
.32857 .10836 m
.32857 .06674 L
s
.01504 w
.32857 .06674 Mdot
.5 Mabswid
.34762 .10836 m
.34762 .07942 L
s
.01504 w
.34762 .07942 Mdot
.5 Mabswid
.36667 .10836 m
.36667 .14144 L
s
.01504 w
.36667 .14144 Mdot
.5 Mabswid
.38571 .10836 m
.38571 .1708 L
s
.01504 w
.38571 .1708 Mdot
.5 Mabswid
.40476 .10836 m
.40476 .10836 L
s
.01504 w
.40476 .10836 Mdot
.5 Mabswid
.42381 .10836 m
.42381 .01472 L
s
.01504 w
.42381 .01472 Mdot
.5 Mabswid
.44286 .10836 m
.44286 .03119 L
s
.01504 w
.44286 .03119 Mdot
.5 Mabswid
.4619 .10836 m
.4619 .22412 L
s
.01504 w
.4619 .22412 Mdot
.5 Mabswid
.48095 .10836 m
.48095 .48296 L
s
.01504 w
.48095 .48296 Mdot
.5 Mabswid
.5 .10836 m
.5 .60332 L
s
.01504 w
.5 .60332 Mdot
.5 Mabswid
.51905 .10836 m
.51905 .48296 L
s
.01504 w
.51905 .48296 Mdot
.5 Mabswid
.5381 .10836 m
.5381 .22412 L
s
.01504 w
.5381 .22412 Mdot
.5 Mabswid
.55714 .10836 m
.55714 .03119 L
s
.01504 w
.55714 .03119 Mdot
.5 Mabswid
.57619 .10836 m
.57619 .01472 L
s
.01504 w
.57619 .01472 Mdot
.5 Mabswid
.59524 .10836 m
.59524 .10836 L
s
.01504 w
.59524 .10836 Mdot
.5 Mabswid
.61429 .10836 m
.61429 .1708 L
s
.01504 w
.61429 .1708 Mdot
.5 Mabswid
.63333 .10836 m
.63333 .14144 L
s
.01504 w
.63333 .14144 Mdot
.5 Mabswid
.65238 .10836 m
.65238 .07942 L
s
.01504 w
.65238 .07942 Mdot
.5 Mabswid
.67143 .10836 m
.67143 .06674 L
s
.01504 w
.67143 .06674 Mdot
.5 Mabswid
.69048 .10836 m
.69048 .10836 L
s
.01504 w
.69048 .10836 Mdot
.5 Mabswid
.70952 .10836 m
.70952 .14242 L
s
.01504 w
.70952 .14242 Mdot
.5 Mabswid
.72857 .10836 m
.72857 .12766 L
s
.01504 w
.72857 .12766 Mdot
.5 Mabswid
.74762 .10836 m
.74762 .09056 L
s
.01504 w
.74762 .09056 Mdot
.5 Mabswid
.76667 .10836 m
.76667 .08161 L
s
.01504 w
.76667 .08161 Mdot
.5 Mabswid
.78571 .10836 m
.78571 .10836 L
s
.01504 w
.78571 .10836 Mdot
.5 Mabswid
.80476 .10836 m
.80476 .13178 L
s
.01504 w
.80476 .13178 Mdot
.5 Mabswid
.82381 .10836 m
.82381 .12198 L
s
.01504 w
.82381 .12198 Mdot
.5 Mabswid
.84286 .10836 m
.84286 .0955 L
s
.01504 w
.84286 .0955 Mdot
.5 Mabswid
.8619 .10836 m
.8619 .08865 L
s
.01504 w
.8619 .08865 Mdot
.5 Mabswid
.88095 .10836 m
.88095 .10836 L
s
.01504 w
.88095 .10836 Mdot
.5 Mabswid
.9 .10836 m
.9 .1262 L
s
.01504 w
.9 .1262 Mdot
.5 Mabswid
.91905 .10836 m
.91905 .11889 L
s
.01504 w
.91905 .11889 Mdot
.5 Mabswid
.9381 .10836 m
.9381 .0983 L
s
.01504 w
.9381 .0983 Mdot
.5 Mabswid
.95714 .10836 m
.95714 .09276 L
s
.01504 w
.95714 .09276 Mdot
.5 Mabswid
.97619 .10836 m
.97619 .10836 L
s
.01504 w
.97619 .10836 Mdot
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[5]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00OSgoo00<007ooOol0
SWoo002?Ool00`00Oomoo`2>Ool007Uoo`8001Aoo`8001=oo`8007Yoo`00N7oo10004goo00<007oo
Ool04Goo1000NGoo001hOol4000COol00`00Oomoo`0AOol4001iOol007Uoo`8001Aoo`03001oogoo
019oo`8007Yoo`00NGoo00<007ooOol04goo00<007ooOol04goo00<007ooOol0N7oo001iOol00`00
Oomoo`02Ool2000?Ool00`00Oomoo`0=Ool20004Ool00`00Oomoo`1hOol007Uoo`04001oogooOol4
000>Ool00`00Oomoo`0<Ool40003Ool00`00Oomoo`1hOol007Uoo`04001oogooOol4000>Ool2000=
Ool40003Ool00`00Oomoo`1hOol007Uoo`03001oogoo009oo`8000moo`03001oogoo00eoo`8000Ao
o`03001oogoo07Qoo`00NGoo00<007ooOol00goo00<007ooOol03Goo00<007ooOol03Goo00<007oo
Ool00goo00<007ooOol0N7oo001iOol00`00Oomoo`03Ool00`00Oomoo`0=Ool00`00Oomoo`0=Ool0
0`00Oomoo`03Ool00`00Oomoo`1hOol007Uoo`03001oogoo00=oo`03001oogoo00eoo`03001oogoo
00eoo`03001oogoo00=oo`03001oogoo07Qoo`00NGoo00<007ooOol00goo00<007ooOol03Goo00<0
07ooOol03Goo00<007ooOol00goo00<007ooOol0N7oo001iOol00`00Oomoo`03Ool00`00Oomoo`0=
Ool00`00Oomoo`0=Ool00`00Oomoo`03Ool00`00Oomoo`1hOol007Uoo`03001oogoo00=oo`03001o
ogoo00eoo`8000ioo`03001oogoo00=oo`03001oogoo07Qoo`00GGoo0P006Woo00<007ooOol00goo
00<007ooOol03Goo00<007ooOol03Goo00<007ooOol00goo00<007ooOol05goo0P00Ggoo001LOol4
000IOol00`00Oomoo`03Ool00`00Oomoo`0=Ool00`00Oomoo`0=Ool00`00Oomoo`03Ool00`00Oomo
o`0FOol4001NOol0025oo`<000=oo`03001oogoo02aoo`D00003Ool00000008001Uoo`03001oogoo
00=oo`03001oogoo00eoo`03001oogoo00eoo`03001oogoo00=oo`03001oogoo01Ioo`L0009oo`03
001oogoo02ioo`<000=oo`03001oogoo01moo`008Goo00<007ooOol00Woo00<007oo0000;goo00@0
07ooOomoo`<001Yoo`03001oogoo00=oo`03001oogoo00eoo`03001oogoo00eoo`03001oogoo00=o
o`03001oogoo01Moo`800003Ool007oo009oo`03001oo`0002moo`03001oogoo009oo`03001oo`00
021oo`0077oo0`000goo00L007ooOomoo`00Ool0000YOol30003Ool01`00Oomoogoo001oo`0000Ao
o`8001Aoo`03001oogoo00=oo`03001oogoo00eoo`03001oogoo00eoo`03001oogoo00=oo`03001o
ogoo019oo`8000Aoo`03001oo`0000=oo`03001oo`00031oo`07001oogooOol007oo000087oo000R
Ool01`00Oomoogoo001oo`0001Uoo`8001Aoo`07001oogooOol007oo00000goo10004goo00<007oo
Ool00goo00<007ooOol03Goo00<007ooOol03Goo00<007ooOol00goo00<007ooOol04Goo10000goo
00<007oo00000goo00<007oo00004Woo0P0077oo00L007ooOomoo`00Ool0000POol0025oo`03001o
o`00009oo`03001oo`0001Qoo`@001=oo`07001oogooOol007oo00000goo10004goo00<007ooOol0
0goo00<007ooOol03Goo0P003Woo00<007ooOol00goo00<007ooOol04Goo10000goo00<007oo0000
0goo00<007oo00004Goo10006Woo00<007oo00000Woo00<007oo000087oo000ROol00`00Oomoo`02
Ool2000HOol40003Ool2000=Ool20004Ool20004Ool2000DOol00`00Oomoo`03Ool00`00Oomoo`0=
Ool00`00Oomoo`0=Ool00`00Oomoo`03Ool00`00Oomoo`0BOol20004Ool30004Ool00`00Oomoo`0;
Ool20003Ool4000HOol200000goo001oo`03Ool00`00Oomoo`0OOol000aoo`8001Qoo`@0009oo`80
01Aoo`8000=oo`@001=oo`03001oogoo009oo`03001oogoo01=oo`03001oogoo00=oo`03001oogoo
00eoo`03001oogoo00eoo`03001oogoo00=oo`03001oogoo01=oo`03001oogoo009oo`03001oogoo
015oo`@000=oo`8001=oo`8000=oo`@001Qoo`8000eoo`002goo10000Woo0P004goo100000=oo`00
00000P0057oo00@007ooOomoo`@001=oo`03001oogoo009oo`03001oogoo01=oo`03001oogoo00=o
o`03001oogoo00eoo`03001oogoo00eoo`03001oogoo00=oo`03001oogoo01=oo`03001oogoo009o
o`03001oogoo015oo`@000=oo`03001oogoo015oo`@0009oo`@001=oo`80009oo`@000aoo`002goo
100000=oo`0000000P004goo0P000Woo100057oo00<007ooOol00Woo0P0057oo00<007ooOol00Woo
00<007ooOol04goo00<007ooOol00goo00<007ooOol03Goo00<007ooOol03Goo00<007ooOol00goo
00<007ooOol04goo00<007ooOol00Woo00<007ooOol04Woo0P0017oo00<007ooOol04Goo10000goo
0P004goo100000=oo`0000000P0037oo000<Ool20002Ool4000DOol01000Oomoogoo0P005Goo00<0
07ooOol00Woo00<007ooOol04goo00<007ooOol00Woo00<007ooOol04goo00<007ooOol00goo00<0
07ooOol03Goo00<007ooOol03Goo00<007ooOol00goo00<007ooOol04goo00<007ooOol00Woo00<0
07ooOol04goo00<007ooOol00Woo00<007ooOol04Woo0P0017oo00<007ooOol04Woo10000Woo0P00
3Goo0006Ool20004Ool00`00Oomoo`02Ool2000>Ool20005Ool00`00Oomoo`02Ool00`00Oomoo`0=
Ool20004Ool00`00Oomoo`02Ool00`00Oomoo`0=Ool20004Ool00`00Oomoo`02Ool00`00Oomoo`0=
Ool20004Ool00`00Oomoo`03Ool00`00Oomoo`0=Ool00`00Oomoo`0=Ool00`00Oomoo`03Ool00`00
Oomoo`02Ool2000?Ool00`00Oomoo`02Ool00`00Oomoo`02Ool2000?Ool00`00Oomoo`02Ool00`00
Oomoo`02Ool2000?Ool00`00Oomoo`02Ool00`00Oomoo`02Ool2000?Ool20004Ool01000Oomoogoo
0P0027oo0005Ool40003Ool00`00Oomoo`03Ool00`00Oomoo`0;Ool40004Ool00`00Oomoo`02Ool0
0`00Oomoo`0<Ool40003Ool00`00Oomoo`02Ool00`00Oomoo`0<Ool40003Ool00`00Oomoo`02Ool0
0`00Oomoo`0<Ool40003Ool00`00Oomoo`03Ool00`00Oomoo`0=Ool00`00Oomoo`0=Ool00`00Oomo
o`03Ool01000Oomoogoo10003Woo00<007ooOol00Woo00@007ooOomoo`@000ioo`03001oogoo009o
o`04001oogooOol4000>Ool00`00Oomoo`02Ool01000Oomoogoo10003Woo00<007ooOol00goo00<0
07ooOol010001goo003o000P0001Ool00003Ool007oo00=oo`8000Aoo`03001oogoo00Qoo`8000Ao
o`04001oogooOol2000:Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`02Ool20004Ool0
0`00Oomoo`08Ool00`00Oomoo`02Ool00`00Oomoo`02Ool20009Ool00`00Oomoo`03Ool00`00Oomo
o`02Ool00`00Oomoo`02Ool20004Ool00`00Oomoo`08Ool00`00Oomoo`03Ool00`00Oomoo`02Ool0
0`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`08Ool00`00Oomoo`02Ool20004Ool00`00Oomo
o`02Ool00`00Oomoo`03Ool00`00Oomoo`07Ool20004Ool00`00Oomoo`02Ool00`00Oomoo`08Ool0
0`00Oomoo`02Ool20004Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`07Ool20004Ool0
0`00Oomoo`02Ool2000:Ool01000Oomoogoo0P001Goo0@000Goo0Goo000FOol40003Ool00`00Oomo
o`0BOol20004Ool00`00Oomoo`0COol00`00Oomoo`02Ool00`00Oomoo`0COol00`00Oomoo`02Ool0
0`00Oomoo`0COol00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`03Ool0
0`00Oomoo`0COol00`00Oomoo`02Ool00`00Oomoo`0COol00`00Oomoo`02Ool00`00Oomoo`0COol0
0`00Oomoo`02Ool2000DOol01000Oomoogoo10005goo000FOol40002Ool2000COol40003Ool00`00
Oomoo`0COol00`00Oomoo`02Ool00`00Oomoo`0COol00`00Oomoo`02Ool00`00Oomoo`0COol00`00
Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`0COol00`00
Oomoo`02Ool00`00Oomoo`0COol00`00Oomoo`02Ool00`00Oomoo`0COol01000Oomoogoo10004goo
0P000Woo10005goo000GOol20002Ool4000BOol40003Ool00`00Oomoo`0BOol20004Ool00`00Oomo
o`0COol00`00Oomoo`02Ool00`00Oomoo`0COol00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomo
o`02Ool00`00Oomoo`03Ool00`00Oomoo`0COol00`00Oomoo`02Ool00`00Oomoo`0COol00`00Oomo
o`02Ool2000DOol01000Oomoogoo10004Woo10000Woo0P0067oo000KOol4000COol20003Ool2000C
Ool40003Ool00`00Oomoo`0COol00`00Oomoo`02Ool00`00Oomoo`0COol00`00Oomoo`03Ool00`00
Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`0COol00`00Oomoo`02Ool00`00
Oomoo`0COol01000Oomoogoo10004Woo0P0017oo0P004goo100077oo000LOol2000HOol4000BOol4
0003Ool00`00Oomoo`0COol00`00Oomoo`02Ool00`00Oomoo`0COol00`00Oomoo`03Ool00`00Oomo
o`02Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`0COol00`00Oomoo`02Ool00`00Oomo
o`0COol01000Oomoogoo10004Goo10006Goo0P007Goo000fOol4000COol20004Ool00`00Oomoo`0C
Ool00`00Oomoo`02Ool00`00Oomoo`0COol00`00Oomoo`03Ool00`00Oomoo`02Ool20003Ool00`00
Oomoo`03Ool00`00Oomoo`0COol00`00Oomoo`02Ool00`00Oomoo`0COol00`00Oomoo`02Ool2000B
Ool4000hOol003Moo`8001Uoo`8001Aoo`8000Aoo`03001oogoo01=oo`03001oogoo00=oo`03001o
ogoo009oo`03001oogoo009oo`03001oogoo00=oo`03001oogoo01=oo`04001oogooOol2000DOol2
000IOol2000iOol0055oo`@0019oo`@000=oo`03001oogoo01=oo`03001oogoo00=oo`03001oogoo
009oo`03001oogoo009oo`03001oogoo00=oo`03001oogoo01=oo`03001oogoo00@0019oo`@005=o
o`00DGoo10004Woo10000goo00<007ooOol04goo00<007ooOol00goo00<007ooOol00Woo00<007oo
Ool00Woo00<007ooOol00goo00<007ooOol04goo00<007ooOol010004Woo1000Dgoo001BOol2000D
Ool20004Ool00`00Oomoo`0COol00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00
Oomoo`03Ool00`00Oomoo`0COol01000Oomoogoo0P0057oo0P00E7oo001^Ool00`00Oomoo`0COol0
0`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`0COol0
0`00Oomoo`1]Ool006ioo`03001oogoo01=oo`03001oogoo00=oo`03001oogoo009oo`03001oogoo
009oo`03001oogoo00=oo`03001oogoo01=oo`03001oogoo06eoo`00KWoo00<007ooOol04goo00<0
07ooOol00goo00<007ooOol00Woo0P000goo00<007ooOol00goo00<007ooOol04goo00<007ooOol0
KGoo001^Ool00`00Oomoo`0COol00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00
Oomoo`03Ool00`00Oomoo`0COol00`00Oomoo`1]Ool006ioo`8001Aoo`03001oogoo00=oo`03001o
ogoo009oo`03001oogoo009oo`03001oogoo00=oo`03001oogoo019oo`8006moo`00KGoo10004goo
00<007ooOol00goo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol00goo00<007ooOol04Goo
1000KWoo001]Ool4000COol00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomo
o`03Ool00`00Oomoo`0AOol4001^Ool006ioo`8001Aoo`03001oogoo00=oo`03001oogoo009oo`03
001oogoo009oo`03001oogoo00=oo`03001oogoo019oo`8006moo`00Q7oo00<007ooOol00goo00<0
07ooOol00Woo00<007ooOol00Woo00<007ooOol00goo00<007ooOol0Pgoo0024Ool00`00Oomoo`03
Ool00`00Oomoo`02Ool20003Ool00`00Oomoo`03Ool00`00Oomoo`23Ool008Aoo`03001oogoo00=o
o`03001oogoo009oo`03001oogoo009oo`03001oogoo00=oo`03001oogoo08=oo`00Q7oo00<007oo
Ool00goo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol00goo00<007ooOol0Pgoo0024Ool0
0`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`23Ool0
08Aoo`03001oogoo00=oo`03001oogoo009oo`03001oogoo009oo`03001oogoo00=oo`03001oogoo
08=oo`00Q7oo00<007ooOol00goo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol00goo00<0
07ooOol0Pgoo0024Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`03
Ool00`00Oomoo`23Ool008Aoo`03001oogoo00=oo`03001oogoo009oo`8000=oo`03001oogoo00=o
o`03001oogoo08=oo`00Q7oo00<007ooOol00goo00<007ooOol00Woo00<007ooOol00Woo00<007oo
Ool00goo00<007ooOol0Pgoo0024Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`02Ool0
0`00Oomoo`03Ool00`00Oomoo`23Ool008=oo`8000Eoo`03001oogoo009oo`03001oogoo009oo`03
001oogoo009oo`8008Eoo`00PWoo100017oo00<007ooOol00Woo00<007ooOol00Woo00@007ooOomo
o`@008Aoo`00OWoo00@007ooOomoo`T000Aoo`03001oogoo009oo`04001oogooOol40024Ool007eo
o`03001oo`0000=oo`8000=oo`03001oo`0000Aoo`03001oogoo009oo`03001oogoo009oo`8008Eo
o`00OGoo00<007oo000027oo00<007oo000017oo0`000Woo00<007ooOol0RGoo001mOol00`00Ool0
0008Ool00`00Ool00004Ool00`00Oomoo`02Ool00`00Oomoo`29Ool007eoo`03001oo`0000Qoo`03
001oo`0000Aoo`03001oogoo009oo`03001oogoo08Uoo`00OWoo00<007ooOol01Woo0P0000=oo`00
Ool00goo00<007ooOol00Woo00<007ooOol0RGoo002:Ool00`00Oomoo`02Ool00`00Oomoo`02Ool0
0`00Oomoo`29Ool008Yoo`03001oogoo009oo`03001oogoo009oo`03001oogoo08Uoo`00RWoo00<0
07ooOol00Woo00<007ooOol00Woo00<007ooOol0RGoo002:Ool00`00Oomoo`02Ool20003Ool00`00
Oomoo`29Ool008Yoo`03001oogoo009oo`03001oogoo009oo`03001oogoo08Uoo`00RWoo00<007oo
Ool00Woo00<007ooOol00Woo00<007ooOol0RGoo002:Ool00`00Oomoo`02Ool00`00Oomoo`02Ool0
0`00Oomoo`29Ool008Yoo`03001oogoo009oo`03001oogoo009oo`03001oogoo08Uoo`00RWoo00<0
07ooOol00Woo00<007ooOol00Woo00<007ooOol0RGoo002:Ool00`00Oomoo`02Ool00`00Oomoo`02
Ool00`00Oomoo`29Ool008Yoo`03001oogoo009oo`8000=oo`03001oogoo08Uoo`00RWoo00<007oo
Ool00Woo00<007ooOol00Woo00<007ooOol0RGoo002:Ool00`00Oomoo`02Ool00`00Oomoo`02Ool0
0`00Oomoo`29Ool008Yoo`03001oogoo009oo`03001oogoo009oo`03001oogoo08Uoo`00RWoo00<0
07ooOol00Woo00<007ooOol00Woo00<007ooOol0RGoo002:Ool00`00Oomoo`02Ool00`00Oomoo`02
Ool00`00Oomoo`29Ool008Yoo`03001oogoo009oo`03001oogoo009oo`03001oogoo08Uoo`00RWoo
00<007ooOol00Woo0P000goo00<007ooOol0RGoo002:Ool00`00Oomoo`02Ool00`00Oomoo`02Ool0
0`00Oomoo`29Ool008Yoo`03001oogoo009oo`03001oogoo009oo`03001oogoo08Uoo`00RWoo00<0
07ooOol00Woo00<007ooOol00Woo00<007ooOol0RGoo002:Ool00`00Oomoo`02Ool00`00Oomoo`02
Ool00`00Oomoo`29Ool008Yoo`03001oogoo009oo`03001oogoo009oo`03001oogoo08Uoo`00RWoo
00<007ooOol00Woo00<007ooOol00Woo00<007ooOol0RGoo002:Ool00`00Oomoo`02Ool20003Ool0
0`00Oomoo`29Ool008Yoo`03001oogoo009oo`03001oogoo009oo`03001oogoo08Uoo`00RWoo00<0
07ooOol00Woo00<007ooOol00Woo00<007ooOol0RGoo002:Ool00`00Oomoo`02Ool00`00Oomoo`02
Ool00`00Oomoo`29Ool008Yoo`03001oogoo009oo`03001oogoo009oo`03001oogoo08Uoo`00OWoo
00<007ooOol00Woo00@007ooOomoo`@000Aoo`03001oogoo009oo`03001oogoo08Uoo`00OGoo00<0
07oo00001goo00@007ooOol000Aoo`03001oogoo009oo`03001oogoo08Uoo`00OGoo00<007oo0000
27oo00<007oo000017oo0`000Woo00<007ooOol0RGoo001mOol00`00Ool00008Ool00`00Ool00004
Ool00`00Oomoo`02Ool00`00Oomoo`29Ool007eoo`03001oo`0000Moo`04001oo`000004Ool00`00
Oomoo`02Ool00`00Oomoo`29Ool007ioo`03001oogoo00Moo`03001oo`0000Aoo`03001oogoo009o
o`03001oogoo08Uoo`00RWoo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol0RGoo002:Ool0
0`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`29Ool008Yoo`03001oogoo009oo`03001oogoo
009oo`03001oogoo08Uoo`00RWoo00<007ooOol00Woo0P000goo00<007ooOol0RGoo002:Ool00`00
Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`29Ool008Yoo`03001oogoo009oo`03001oogoo009o
o`03001oogoo08Uoo`00RWoo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol0RGoo002:Ool0
0`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`29Ool008Yoo`03001oogoo009oo`03001oogoo
009oo`03001oogoo08Uoo`00RWoo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol0RGoo002:
Ool00`00Oomoo`02Ool20003Ool00`00Oomoo`29Ool008Yoo`03001oogoo009oo`03001oogoo009o
o`03001oogoo08Uoo`00RWoo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol0RGoo002:Ool0
0`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`29Ool008Yoo`03001oogoo009oo`03001oogoo
009oo`03001oogoo08Uoo`00RWoo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol0RGoo002:
Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`29Ool008Yoo`03001oogoo009oo`8000=o
o`03001oogoo08Uoo`00RWoo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol0RGoo002:Ool0
0`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`29Ool008Yoo`03001oogoo009oo`03001oogoo
009oo`03001oogoo08Uoo`00RWoo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol0RGoo002:
Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`29Ool008Yoo`03001oogoo009oo`03001o
ogoo009oo`03001oogoo08Uoo`00RWoo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol0RGoo
002:Ool00`00Oomoo`02Ool20003Ool00`00Oomoo`29Ool008Yoo`03001oogoo009oo`03001oogoo
009oo`03001oogoo08Uoo`00RWoo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol0RGoo002:
Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`29Ool008Yoo`03001oogoo009oo`03001o
ogoo009oo`03001oogoo08Uoo`00OWoo00<007ooOol00Woo00@007ooOomoo`800003Ool007oo00=o
o`03001oogoo009oo`03001oogoo08Uoo`00OGoo00<007oo00002Goo0P0017oo00<007ooOol00Woo
0P00RWoo001mOol00`00Ool00008Ool40003Ool300000goo000000020029Ool007eoo`03001oo`00
00Qoo`@000=oo`04001oogooOol40029Ool007eoo`03001oo`0000Moo`04001oo`000004Ool00`00
Oomoo`02Ool2002:Ool007ioo`03001oogoo00Moo`03001oogoo00Aoo`03001oogoo08ioo`00Sgoo
00<007ooOol0SWoo002?Ool00`00Oomoo`2>Ool008moo`03001oogoo08ioo`00Sgoo0P00Sgoo002?
Ool00`00Oomoo`2>Ool008moo`03001oogoo08ioo`00Sgoo00<007ooOol0SWoo002?Ool00`00Oomo
o`2>Ool008moo`03001oogoo08ioo`00Sgoo00<007ooOol0SWoo002?Ool2002?Ool008moo`03001o
ogoo08ioo`00Sgoo00<007ooOol0SWoo002?Ool00`00Oomoo`2>Ool008moo`03001oogoo08ioo`00
Sgoo00<007ooOol0SWoo002?Ool00`00Oomoo`2>Ool008moo`8008moo`00Sgoo00<007ooOol0SWoo
002?Ool00`00Oomoo`2>Ool008moo`03001oogoo08ioo`00Sgoo00<007ooOol0SWoo002?Ool00`00
Oomoo`2>Ool008moo`03001oogoo08ioo`00Sgoo0P00Sgoo002?Ool00`00Oomoo`2>Ool008moo`03
001oogoo08ioo`00Sgoo00<007ooOol0SWoo002?Ool00`00Oomoo`2>Ool007ioo`03001oogoo009o
o`03001oogoo009oo`<000Aoo`03001oogoo08ioo`00OGoo00<007oo00002Goo00<007ooOol00Woo
0P00T7oo001mOol00`00Ool00007Ool40002Ool5002>Ool007eoo`03001oo`0000Moo`03001oo`00
00=oo`@008moo`00OGoo00<007oo000027oo0P0017oo0P00T7oo001nOol00`00Oomoo`08Ool00`00
Oomoo`03Ool00`00Oomoo`2>Ool008moo`03001oogoo08ioo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-26.3592, -0.0875771, 
  0.183688, 0.00282757}}]
}, Open  ]],

Cell[TextData[{
  "where we set ",
  Cell[BoxData[
      \(TraditionalForm\`a = 0.4  \[Pi]\)]],
  ". The impulse response is the discrete ",
  StyleBox["sinc",
    FontSlant->"Italic"],
  " function."
}], "Text"]
}, Open  ]],

Cell["TWO-DIMENSIONAL DTFT", "Section"],

Cell["\<\
The two-dimensional DTFT is a straightforward extension of the 1D DTFT. The \
transform is defined by the following pair of formulas:\
\>", "Text"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm
    \`X(\[Omega]\_1, \ \[Omega]\_2)\  = \ 
      \[Sum]\+\(n\_1 = \(-\[Infinity]\)\)\%\[Infinity]\ 
        \(\[Sum]\+\(n\_2 = \(-\[Infinity]\)\)\%\[Infinity] x[n\_1, \ n\_2]\ 
            \[ExponentialE]\^\(\(-\ j\)\ 
                \((\[Omega]\_1\ n\_1\  + \ \[Omega]\_2\ n\_2)\)\ \)\)\)]]], 
  "NumberedEquation",
  PageWidth->WindowWidth],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm
    \`\(x[n\_1, \ n\_2]\  = \ 
      \(1\/\(4  \[Pi]\^2\)\) 
        \(\[Integral]\_\(-
              \[Pi]\)\%\[Pi]\(\[Integral]\_\(-\[Pi]\)\%\[Pi]\( X(\[Omega]\_1, 
                \ \[Omega]\_2)\)\ 
              \(\[ExponentialE]\^\(\ \ 
                  j\ \((\[Omega]\_1\ n\_1\  + \ \[Omega]\_2\ n\_2)\)\)\) 
              \[DifferentialD]\[Omega]\_1 \[DifferentialD]\[Omega]\_2\)\)\ 
    \)\)]]], "NumberedEquation"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`n\_1\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`n\_2\)]],
  " are the two spatial variables, ",
  Cell[BoxData[
      \(TraditionalForm\`n\_1, \ 
      n\_2\  \[Element] \ \[DoubleStruckCapitalZ]\)]],
  ", and ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\_1, \ \[Omega]\_2\)]],
  " are the corresponding two frequency variables. We end this section with \
two examples. First, consider the simple example of calculating the DTFT a 2D \
equivalent of the MA filter, typically and suggestively called the \"box\" \
filter. The filter is a sequence that is constant in a rectangular region of \
support. For example,"
}], "Text"],

Cell[TextData[Cell[BoxData[
    FormBox[
      RowBox[{\(x[n\_1, \ n\_2}\), " ", "=", " ", 
        RowBox[{"{", GridBox[{
              {\(1, \), \(\(-2\) \[LessEqual] n\_1 \[LessEqual] 2, \ 
                \(-3\) \[LessEqual] n\_2 \[LessEqual] 3\)},
              {"0", "otherwise"}
              }]}]}], TraditionalForm]]]], "NumberedEquation"],

Cell["The analysis formula (6) reduces to", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[Sum]\+\(n\_1 = \(-2\)\)\%2
        \(\[Sum]\+\(n\_2 = \(-3\)\)\%3 
          \[ExponentialE]\^\(\(-\ \[ImaginaryI]\)\ 
            \((\[Omega]\_1\ n\_1\  + \ \[Omega]\_2\ n\_2)\)\)\)\)], "Input",
  CellLabel->"In[25]:="],

Cell[BoxData[
    \(1 + E\^\(\(-I\)\ \[Omega]\_1\) + E\^\(I\ \[Omega]\_1\) + 
      E\^\(\(-2\)\ I\ \[Omega]\_1\) + E\^\(2\ I\ \[Omega]\_1\) + 
      E\^\(\(-I\)\ \((\(-2\)\ \[Omega]\_1 - 3\ \[Omega]\_2)\)\) + 
      E\^\(\(-I\)\ \((\(-\[Omega]\_1\) - 3\ \[Omega]\_2)\)\) + 
      E\^\(\(-I\)\ \((\[Omega]\_1 - 3\ \[Omega]\_2)\)\) + 
      E\^\(\(-I\)\ \((2\ \[Omega]\_1 - 3\ \[Omega]\_2)\)\) + 
      E\^\(\(-I\)\ \((\(-2\)\ \[Omega]\_1 - 2\ \[Omega]\_2)\)\) + 
      E\^\(\(-I\)\ \((\(-\[Omega]\_1\) - 2\ \[Omega]\_2)\)\) + 
      E\^\(\(-I\)\ \((\[Omega]\_1 - 2\ \[Omega]\_2)\)\) + 
      E\^\(\(-I\)\ \((2\ \[Omega]\_1 - 2\ \[Omega]\_2)\)\) + 
      E\^\(\(-I\)\ \((\(-2\)\ \[Omega]\_1 - \[Omega]\_2)\)\) + 
      E\^\(\(-I\)\ \((\(-\[Omega]\_1\) - \[Omega]\_2)\)\) + 
      E\^\(\(-I\)\ \((\[Omega]\_1 - \[Omega]\_2)\)\) + 
      E\^\(\(-I\)\ \((2\ \[Omega]\_1 - \[Omega]\_2)\)\) + 
      E\^\(\(-I\)\ \[Omega]\_2\) + E\^\(I\ \[Omega]\_2\) + 
      E\^\(\(-2\)\ I\ \[Omega]\_2\) + E\^\(2\ I\ \[Omega]\_2\) + 
      E\^\(\(-3\)\ I\ \[Omega]\_2\) + E\^\(3\ I\ \[Omega]\_2\) + 
      E\^\(\(-I\)\ \((\(-2\)\ \[Omega]\_1 + \[Omega]\_2)\)\) + 
      E\^\(\(-I\)\ \((\(-\[Omega]\_1\) + \[Omega]\_2)\)\) + 
      E\^\(\(-I\)\ \((\[Omega]\_1 + \[Omega]\_2)\)\) + 
      E\^\(\(-I\)\ \((2\ \[Omega]\_1 + \[Omega]\_2)\)\) + 
      E\^\(\(-I\)\ \((\(-2\)\ \[Omega]\_1 + 2\ \[Omega]\_2)\)\) + 
      E\^\(\(-I\)\ \((\(-\[Omega]\_1\) + 2\ \[Omega]\_2)\)\) + 
      E\^\(\(-I\)\ \((\[Omega]\_1 + 2\ \[Omega]\_2)\)\) + 
      E\^\(\(-I\)\ \((2\ \[Omega]\_1 + 2\ \[Omega]\_2)\)\) + 
      E\^\(\(-I\)\ \((\(-2\)\ \[Omega]\_1 + 3\ \[Omega]\_2)\)\) + 
      E\^\(\(-I\)\ \((\(-\[Omega]\_1\) + 3\ \[Omega]\_2)\)\) + 
      E\^\(\(-I\)\ \((\[Omega]\_1 + 3\ \[Omega]\_2)\)\) + 
      E\^\(\(-I\)\ \((2\ \[Omega]\_1 + 3\ \[Omega]\_2)\)\)\)], "Output",
  CellLabel->"Out[25]="]
}, Open  ]],

Cell[TextData[{
  "The magnitude response of the example sequence is a surface in the \
two-dimensional frequency domain of ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\_1\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\_2\)]],
  ". Here we plot the magnitude in the fundamental interval, ",
  Cell[BoxData[
      \(TraditionalForm\`\(-\[Pi]\)\  \[LessEqual] \ \[Omega]\_1, \ 
      \[Omega]\_2\  \[LessEqual] \ \[Pi]\)]],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Plot3D[Evaluate[Abs[%]], 
      \ {\[Omega]\_1, \(-\[Pi]\), \ \[Pi]}, {\[Omega]\_2, \(-\[Pi]\), \ 
        \[Pi]}, \ PlotRange -> All, \ PlotPoints -> 20]; \)\)], "Input",
  CellLabel->"In[26]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1.04977 -0.0679587 1.04977 [
[.13491 .20394 -11.9698 -9 ]
[.13491 .20394 .03022 0 ]
[.3345 .12542 -5.5867 -9 ]
[.3345 .12542 .4133 0 ]
[.55031 .04057 -5.18851 -9 ]
[.55031 .04057 .81149 0 ]
[.76162 .0881 0 -6.17057 ]
[.76162 .0881 12 2.82943 ]
[.8565 .23339 0 -6.03127 ]
[.8565 .23339 6 2.96873 ]
[.93925 .36012 0 -5.91342 ]
[.93925 .36012 6 3.08658 ]
[.02412 .26505 -6 -2.74227 ]
[.02412 .26505 0 6.25773 ]
[.01361 .33094 -12 -2.798 ]
[.01361 .33094 0 6.202 ]
[.00264 .39972 -12 -2.85643 ]
[.00264 .39972 0 6.14357 ]
[-0.00883 .47157 -12 -2.91774 ]
[-0.00883 .47157 0 6.08226 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.03716 .25514 m
.68874 0 L
s
.14416 .21324 m
.14879 .21789 L
s
[(-2)] .13491 .20394 .99496 1 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.55805 .05117 m
.56192 .05647 L
s
[(2)] .55031 .04057 .7295 1 Mshowa
.125 Mabswid
.19248 .19432 m
.19521 .19716 L
s
.24172 .17504 m
.2444 .17792 L
s
.2919 .15539 m
.29453 .15832 L
s
.39523 .11493 m
.39774 .11796 L
s
.44843 .0941 m
.45088 .09718 L
s
.50269 .07285 m
.50508 .07598 L
s
.09674 .23181 m
.09956 .23455 L
s
.05019 .25004 m
.05305 .25274 L
s
.61454 .02905 m
.61679 .03228 L
s
.67219 .00648 m
.67437 .00976 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.74932 .09266 m
.74316 .09495 L
s
[(-2)] .76162 .0881 -1 .37124 Mshowa
.84407 .23761 m
.83786 .23973 L
s
[(0)] .8565 .23339 -1 .34028 Mshowa
.92673 .36405 m
.92047 .36602 L
s
[(2)] .93925 .36012 -1 .31409 Mshowa
.125 Mabswid
.77428 .13086 m
.77058 .1322 L
s
.79837 .1677 m
.79466 .16902 L
s
.82162 .20326 m
.8179 .20455 L
s
.86578 .27081 m
.86204 .27206 L
s
.88677 .30292 m
.88302 .30414 L
s
.90707 .33398 m
.90332 .33518 L
s
.72342 .05305 m
.71974 .05445 L
s
.69654 .01193 m
.69287 .01336 L
s
.94577 .39318 m
.94201 .39434 L
s
.96423 .4214 m
.96046 .42254 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03635 .26027 m
.04246 .25789 L
s
[(0)] .02412 .26505 1 -0.39061 Mshowa
.02588 .3263 m
.03202 .32398 L
s
[(10)] .01361 .33094 1 -0.37822 Mshowa
.01496 .39522 m
.02112 .39297 L
s
[(20)] .00264 .39972 1 -0.36524 Mshowa
.00355 .46722 m
.00974 .46505 L
s
[(30)] -0.00883 .47157 1 -0.35161 Mshowa
.125 Mabswid
.03429 .27326 m
.03796 .27183 L
s
.03221 .28635 m
.03589 .28493 L
s
.03012 .29955 m
.0338 .29815 L
s
.02801 .31287 m
.03169 .31147 L
s
.02374 .33985 m
.02742 .33846 L
s
.02157 .35351 m
.02526 .35214 L
s
.01939 .36729 m
.02308 .36593 L
s
.01718 .3812 m
.02088 .37984 L
s
.01272 .40937 m
.01642 .40802 L
s
.01046 .42364 m
.01416 .42231 L
s
.00818 .43804 m
.01188 .43671 L
s
.00587 .45256 m
.00958 .45125 L
s
.00121 .48201 m
.00492 .48071 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.5 Mabswid
.671 .703 .871 r
.38887 .59104 .40492 .60959 .43205 .59963 .41613 .58202 Metetra
.68 .717 .877 r
.41613 .58202 .43205 .59963 .45947 .58787 .44367 .57222 Metetra
.636 .73 .916 r
.44367 .57222 .45947 .58787 .48701 .58444 .47141 .56576 Metetra
.653 .701 .882 r
.47141 .56576 .48701 .58444 .51492 .57821 .49948 .55811 Metetra
.673 .695 .862 r
.49948 .55811 .51492 .57821 .54313 .56712 .52786 .54842 Metetra
.673 .711 .877 r
.52786 .54842 .54313 .56712 .57159 .55643 .55651 .53884 Metetra
.606 .702 .912 r
.55651 .53884 .57159 .55643 .6006 .55837 .58554 .53436 Metetra
.616 .643 .854 r
.58554 .53436 .6006 .55837 .63008 .55986 .61495 .52963 Metetra
.631 .606 .807 r
.61495 .52963 .63008 .55986 .65988 .55735 .64468 .5232 Metetra
.646 .595 .782 r
.64468 .5232 .65988 .55735 .68981 .54853 .67467 .51416 Metetra
.663 .603 .777 r
.67467 .51416 .68981 .54853 .7197 .53335 .70483 .50248 Metetra
.681 .63 .792 r
.70483 .50248 .7197 .53335 .74952 .51405 .73518 .48906 Metetra
.695 .676 .827 r
.73518 .48906 .74952 .51405 .77944 .49418 .76576 .47533 Metetra
.653 .718 .896 r
.76576 .47533 .77944 .49418 .8106 .48711 .79702 .46677 Metetra
.651 .703 .885 r
.79702 .46677 .8106 .48711 .84219 .48047 .82867 .45832 Metetra
.671 .695 .864 r
.82867 .45832 .84219 .48047 .87366 .46882 .86047 .44775 Metetra
.683 .713 .871 r
.86047 .44775 .87366 .46882 .9051 .45422 .89249 .43592 Metetra
.645 .73 .91 r
.89249 .43592 .9051 .45422 .93789 .44825 .92525 .42755 Metetra
.655 .709 .887 r
.92525 .42755 .93789 .44825 .97088 .44042 .95832 .41835 Metetra
.681 .77 .918 r
.37232 .57758 .38887 .59104 .41613 .58202 .39979 .56782 Metetra
.696 .765 .905 r
.39979 .56782 .41613 .58202 .44367 .57222 .42756 .55674 Metetra
.611 .728 .929 r
.42756 .55674 .44367 .57222 .47141 .56576 .45544 .55164 Metetra
.639 .757 .934 r
.45544 .55164 .47141 .56576 .49948 .55811 .4837 .5445 Metetra
.688 .778 .92 r
.4837 .5445 .49948 .55811 .52786 .54842 .51229 .53381 Metetra
.683 .766 .914 r
.51229 .53381 .52786 .54842 .55651 .53884 .54116 .52339 Metetra
.534 .706 .95 r
.54116 .52339 .55651 .53884 .58554 .53436 .57042 .52205 Metetra
.507 .745 .981 r
.57042 .52205 .58554 .53436 .61495 .52963 .60013 .52035 Metetra
.535 .807 .996 r
.60013 .52035 .61495 .52963 .64468 .5232 .63019 .51573 Metetra
.618 .867 .99 r
.63019 .51573 .64468 .5232 .67467 .51416 .66048 .50653 Metetra
.705 .889 .965 r
.66048 .50653 .67467 .51416 .70483 .50248 .69087 .49272 Metetra
.751 .868 .933 r
.69087 .49272 .70483 .50248 .73518 .48906 .72134 .4759 Metetra
.753 .822 .906 r
.72134 .4759 .73518 .48906 .76576 .47533 .75198 .45863 Metetra
.642 .744 .923 r
.75198 .45863 .76576 .47533 .79702 .46677 .78355 .45057 Metetra
.636 .751 .931 r
.78355 .45057 .79702 .46677 .82867 .45832 .81553 .44279 Metetra
.681 .779 .925 r
.81553 .44279 .82867 .45832 .86047 .44775 .84755 .43134 Metetra
.705 .779 .909 r
.84755 .43134 .86047 .44775 .89249 .43592 .87967 .41774 Metetra
.63 .729 .919 r
.87967 .41774 .89249 .43592 .92525 .42755 .91284 .41033 Metetra
.645 .75 .926 r
.91284 .41033 .92525 .42755 .95832 .41835 .94627 .40154 Metetra
.69 .775 .917 r
.35542 .56415 .37232 .57758 .39979 .56782 .38312 .55355 Metetra
.711 .77 .898 r
.38312 .55355 .39979 .56782 .42756 .55674 .41113 .54099 Metetra
.579 .718 .938 r
.41113 .54099 .42756 .55674 .45544 .55164 .43914 .53752 Metetra
.625 .757 .941 r
.43914 .53752 .45544 .55164 .4837 .5445 .46758 .53099 Metetra
.7 .786 .918 r
.46758 .53099 .4837 .5445 .51229 .53381 .49641 .51915 Metetra
.693 .772 .912 r
.49641 .51915 .51229 .53381 .54116 .52339 .5255 .50776 Metetra
.442 .668 .958 r
.5255 .50776 .54116 .52339 .57042 .52205 .55497 .51015 Metetra
.387 .701 .983 r
.55497 .51015 .57042 .52205 .60013 .52035 .58497 .51206 Metetra
.444 .787 .998 r
.58497 .51206 .60013 .52035 .63019 .51573 .61537 .5096 Metetra
.596 .883 .992 r
.61537 .5096 .63019 .51573 .66048 .50653 .64599 .50025 Metetra
.732 .917 .956 r
.64599 .50025 .66048 .50653 .69087 .49272 .67662 .48394 Metetra
.792 .889 .915 r
.67662 .48394 .69087 .49272 .72134 .4759 .70723 .46314 Metetra
.79 .836 .888 r
.70723 .46314 .72134 .4759 .75198 .45863 .73793 .44172 Metetra
.631 .742 .928 r
.73793 .44172 .75198 .45863 .78355 .45057 .7698 .43428 Metetra
.62 .748 .938 r
.7698 .43428 .78355 .45057 .81553 .44279 .80213 .42731 Metetra
.691 .788 .925 r
.80213 .42731 .81553 .44279 .84755 .43134 .83437 .41486 Metetra
.725 .789 .903 r
.83437 .41486 .84755 .43134 .87967 .41774 .86659 .3992 Metetra
.612 .722 .923 r
.86659 .3992 .87967 .41774 .91284 .41033 .90018 .39295 Metetra
.635 .749 .931 r
.90018 .39295 .91284 .41033 .94627 .40154 .934 .38467 Metetra
.662 .679 .856 r
.33862 .5424 .35542 .56415 .38312 .55355 .36637 .53345 Metetra
.666 .698 .87 r
.36637 .53345 .38312 .55355 .41113 .54099 .39441 .52423 Metetra
.657 .733 .906 r
.39441 .52423 .41113 .54099 .43914 .53752 .42272 .51581 Metetra
.658 .683 .863 r
.42272 .51581 .43914 .53752 .46758 .53099 .45135 .50701 Metetra
.661 .666 .845 r
.45135 .50701 .46758 .53099 .49641 .51915 .48029 .4976 Metetra
.664 .69 .865 r
.48029 .4976 .49641 .51915 .5255 .50776 .50953 .48815 Metetra
.65 .707 .889 r
.50953 .48815 .5255 .50776 .55497 .51015 .53909 .47995 Metetra
.642 .619 .811 r
.53909 .47995 .55497 .51015 .58497 .51206 .569 .47161 Metetra
.634 .567 .761 r
.569 .47161 .58497 .51206 .61537 .5096 .59923 .46274 Metetra
.632 .545 .738 r
.59923 .46274 .61537 .5096 .64599 .50025 .6298 .45312 Metetra
.636 .547 .738 r
.6298 .45312 .64599 .50025 .67662 .48394 .66067 .44274 Metetra
.645 .573 .759 r
.66067 .44274 .67662 .48394 .70723 .46314 .69185 .43181 Metetra
.66 .627 .806 r
.69185 .43181 .70723 .46314 .73793 .44172 .72335 .42072 Metetra
.66 .71 .885 r
.72335 .42072 .73793 .44172 .7698 .43428 .75528 .4109 Metetra
.658 .688 .867 r
.75528 .4109 .7698 .43428 .80213 .42731 .78758 .40101 Metetra
.66 .666 .845 r
.78758 .40101 .80213 .42731 .83437 .41486 .8202 .39049 Metetra
.666 .687 .86 r
.8202 .39049 .83437 .41486 .86659 .3992 .85316 .37954 Metetra
.659 .733 .904 r
.85316 .37954 .86659 .3992 .90018 .39295 .88659 .36941 Metetra
.66 .696 .872 r
.88659 .36941 .90018 .39295 .934 .38467 .92039 .35897 Metetra
.69 .845 .957 r
.32075 .53344 .33862 .5424 .36637 .53345 .34886 .52206 Metetra
.724 .817 .922 r
.34886 .52206 .36637 .53345 .39441 .52423 .37732 .5083 Metetra
.555 .715 .947 r
.37732 .5083 .39441 .52423 .42272 .51581 .40561 .50564 Metetra
.59 .812 .985 r
.40561 .50564 .42272 .51581 .45135 .50701 .43441 .49927 Metetra
.699 .876 .964 r
.43441 .49927 .45135 .50701 .48029 .4976 .46369 .48644 Metetra
.698 .828 .945 r
.46369 .48644 .48029 .4976 .50953 .48815 .49322 .47417 Metetra
.329 .645 .967 r
.49322 .47417 .50953 .48815 .53909 .47995 .52301 .47873 Metetra
.131 0 0 r
.52301 .47873 .53909 .47995 .569 .47161 .55337 .48274 Metetra
.309 0 0 r
.55337 .48274 .569 .47161 .59923 .46274 .58424 .48144 Metetra
.239 0 0 r
.58424 .48144 .59923 .46274 .6298 .45312 .61537 .47171 Metetra
.025 0 0 r
.61537 .47171 .6298 .45312 .66067 .44274 .64655 .4535 Metetra
.64655 .4535 .66067 .44274 .69185 .43181 .67767 .42981 Metetra
.799 .98 .9 r
.67767 .42981 .69185 .43181 .72335 .42072 .70884 .40542 Metetra
.616 .767 .952 r
.70884 .40542 .72335 .42072 .75528 .4109 .74123 .39809 Metetra
.589 .795 .978 r
.74123 .39809 .75528 .4109 .78758 .40101 .77411 .39136 Metetra
.681 .879 .972 r
.77411 .39136 .78758 .40101 .8202 .39049 .80686 .37796 Metetra
.741 .856 .933 r
.80686 .37796 .8202 .39049 .85316 .37954 .83956 .36067 Metetra
.599 .721 .93 r
.83956 .36067 .85316 .37954 .88659 .36941 .87378 .35486 Metetra
.616 .79 .965 r
.87378 .35486 .88659 .36941 .92039 .35897 .90821 .3466 Metetra
.698 .76 .9 r
.30288 .51782 .32075 .53344 .34886 .52206 .33121 .50597 Metetra
.723 .761 .883 r
.33121 .50597 .34886 .52206 .37732 .5083 .35992 .49149 Metetra
.543 .703 .944 r
.35992 .49149 .37732 .5083 .40561 .50564 .38833 .4894 Metetra
.616 .738 .933 r
.38833 .4894 .40561 .50564 .43441 .49927 .41731 .48318 Metetra
.71 .767 .897 r
.41731 .48318 .43441 .49927 .46369 .48644 .44682 .46975 Metetra
.701 .76 .898 r
.44682 .46975 .46369 .48644 .49322 .47417 .47658 .45695 Metetra
.34 .608 .948 r
.47658 .45695 .49322 .47417 .52301 .47873 .50651 .46296 Metetra
.331 .625 .958 r
.50651 .46296 .52301 .47873 .55337 .48274 .53705 .46839 Metetra
.473 .719 .977 r
.53705 .46839 .55337 .48274 .58424 .48144 .56815 .46789 Metetra
.654 .801 .953 r
.56815 .46789 .58424 .48144 .61537 .47171 .59956 .45798 Metetra
.766 .826 .899 r
.59956 .45798 .61537 .47171 .64655 .4535 .63103 .43857 Metetra
.809 .819 .859 r
.63103 .43857 .64655 .4535 .67767 .42981 .66242 .41305 Metetra
.807 .802 .847 r
.66242 .41305 .67767 .42981 .70884 .40542 .69383 .38679 Metetra
.62 .73 .925 r
.69383 .38679 .70884 .40542 .74123 .39809 .7265 .37958 Metetra
.609 .729 .931 r
.7265 .37958 .74123 .39809 .77411 .39136 .75966 .37305 Metetra
.7 .769 .905 r
.75966 .37305 .77411 .39136 .80686 .37796 .79268 .35909 Metetra
.74 .779 .884 r
.79268 .35909 .80686 .37796 .83956 .36067 .82562 .3408 Metetra
.593 .712 .926 r
.82562 .3408 .83956 .36067 .87378 .35486 .86016 .33534 Metetra
.627 .734 .924 r
.86016 .33534 .87378 .35486 .90821 .3466 .89492 .32714 Metetra
.672 .692 .86 r
.28508 .49588 .30288 .51782 .33121 .50597 .31346 .48544 Metetra
.686 .71 .867 r
.31346 .48544 .33121 .50597 .35992 .49149 .34219 .47381 Metetra
.621 .724 .92 r
.34219 .47381 .35992 .49149 .38833 .4894 .37094 .46739 Metetra
.646 .688 .875 r
.37094 .46739 .38833 .4894 .41731 .48318 .40013 .45916 Metetra
.675 .682 .849 r
.40013 .45916 .41731 .48318 .44682 .46975 .42975 .4478 Metetra
.675 .702 .867 r
.42975 .4478 .44682 .46975 .47658 .45695 .45966 .43665 Metetra
.571 .682 .915 r
.45966 .43665 .47658 .45695 .50651 .46296 .48979 .43341 Metetra
.59 .609 .839 r
.48979 .43341 .50651 .46296 .53705 .46839 .52039 .42981 Metetra
.611 .57 .783 r
.52039 .42981 .53705 .46839 .56815 .46789 .55143 .42364 Metetra
.634 .56 .754 r
.55143 .42364 .56815 .46789 .59956 .45798 .58283 .41345 Metetra
.657 .573 .749 r
.58283 .41345 .59956 .45798 .63103 .43857 .61448 .3992 Metetra
.681 .605 .765 r
.61448 .3992 .63103 .43857 .66242 .41305 .64631 .3823 Metetra
.702 .66 .805 r
.64631 .3823 .66242 .41305 .69383 .38679 .67837 .36497 Metetra
.647 .71 .893 r
.67837 .36497 .69383 .38679 .7265 .37958 .71115 .35565 Metetra
.643 .69 .879 r
.71115 .35565 .7265 .37958 .75966 .37305 .74435 .34654 Metetra
.671 .681 .851 r
.74435 .34654 .75966 .37305 .79268 .35909 .77773 .3342 Metetra
.69 .705 .859 r
.77773 .3342 .79268 .35909 .82562 .3408 .81131 .31995 Metetra
.636 .725 .912 r
.81131 .31995 .82562 .3408 .86016 .33534 .84579 .31107 Metetra
.649 .698 .882 r
.84579 .31107 .86016 .33534 .89492 .32714 .8806 .30094 Metetra
.651 .968 .894 r
.26493 .49985 .28508 .49588 .31346 .48544 .29414 .48259 Metetra
.83 .927 .897 r
.29414 .48259 .31346 .48544 .34219 .47381 .32397 .45808 Metetra
.083 .487 .896 r
.32397 .45808 .34219 .47381 .37094 .46739 .35201 .46875 Metetra
.017 0 0 r
.35201 .46875 .37094 .46739 .40013 .45916 .38122 .46799 Metetra
.569 .926 .751 r
.38122 .46799 .40013 .45916 .42975 .4478 .41163 .44693 Metetra
.736 .968 .934 r
.41163 .44693 .42975 .4478 .45966 .43665 .44211 .42788 Metetra
.74 .218 0 r
.44211 .42788 .45966 .43665 .48979 .43341 .4719 .46254 Metetra
.707 .322 .316 r
.4719 .46254 .48979 .43341 .52039 .42981 .50288 .4965 Metetra
.595 .274 .396 r
.50288 .4965 .52039 .42981 .55143 .42364 .53503 .51387 Metetra
.488 .2 .402 r
.53503 .51387 .55143 .42364 .58283 .41345 .56775 .50375 Metetra
.353 .085 .362 r
.56775 .50375 .58283 .41345 .61448 .3992 .60022 .46591 Metetra
.11 0 .228 r
.60022 .46591 .61448 .3992 .64631 .3823 .63196 .41096 Metetra
.63196 .41096 .64631 .3823 .67837 .36497 .66313 .35486 Metetra
.409 .764 .995 r
.66313 .35486 .67837 .36497 .71115 .35565 .69669 .35321 Metetra
.078 .633 .807 r
.69669 .35321 .71115 .35565 .74435 .34654 .73099 .35373 Metetra
.406 .824 .644 r
.73099 .35373 .74435 .34654 .77773 .3342 .76436 .33336 Metetra
.84 .997 .835 r
.76436 .33336 .77773 .3342 .81131 .31995 .79691 .30102 Metetra
.409 .64 .95 r
.79691 .30102 .81131 .31995 .84579 .31107 .83299 .30514 Metetra
.332 .781 .956 r
.83299 .30514 .84579 .31107 .8806 .30094 .86905 .30179 Metetra
.808 .95 .913 r
.24453 .49887 .26493 .49985 .29414 .48259 .27451 .47617 Metetra
.874 .861 .824 r
.27451 .47617 .29414 .48259 .32397 .45808 .30539 .44157 Metetra
0 .057 .537 r
.30539 .44157 .32397 .45808 .35201 .46875 .33273 .46556 Metetra
.129 0 0 r
.33273 .46556 .35201 .46875 .38122 .46799 .36192 .47068 Metetra
.84 .985 .867 r
.36192 .47068 .38122 .46799 .41163 .44693 .3931 .44188 Metetra
.828 .921 .897 r
.3931 .44188 .41163 .44693 .44211 .42788 .42416 .4166 Metetra
.884 .452 .129 r
.42416 .4166 .44211 .42788 .4719 .46254 .45333 .48144 Metetra
.819 .435 .326 r
.45333 .48144 .4719 .46254 .50288 .4965 .48429 .54659 Metetra
.679 .329 .374 r
.48429 .54659 .50288 .4965 .53503 .51387 .51716 .58416 Metetra
.46 .146 .346 r
.51716 .58416 .53503 .51387 .56775 .50375 .55102 .57409 Metetra
.078 0 .205 r
.55102 .57409 .56775 .50375 .60022 .46591 .58445 .51593 Metetra
.58445 .51593 .60022 .46591 .63196 .41096 .61651 .42924 Metetra
.959 .904 .533 r
.61651 .42924 .63196 .41096 .66313 .35486 .64738 .34213 Metetra
.278 .656 .969 r
.64738 .34213 .66313 .35486 .69669 .35321 .68155 .34645 Metetra
0 .51 .815 r
.68155 .34645 .69669 .35321 .73099 .35373 .71669 .35454 Metetra
.748 .994 .852 r
.71669 .35454 .73099 .35373 .76436 .33336 .75019 .32775 Metetra
.935 .934 .774 r
.75019 .32775 .76436 .33336 .79691 .30102 .78213 .2812 Metetra
.191 .499 .907 r
.78213 .2812 .79691 .30102 .83299 .30514 .81944 .29539 Metetra
.276 .7 .968 r
.81944 .29539 .83299 .30514 .86905 .30179 .8565 .29733 Metetra
.778 .763 .839 r
.22502 .48116 .24453 .49887 .27451 .47617 .25528 .4582 Metetra
.83 .761 .787 r
.25528 .4582 .27451 .47617 .30539 .44157 .28652 .42328 Metetra
0 .083 .58 r
.28652 .42328 .30539 .44157 .33273 .46556 .31383 .44723 Metetra
.342 .614 .951 r
.31383 .44723 .33273 .46556 .36192 .47068 .34314 .45221 Metetra
.808 .77 .818 r
.34314 .45221 .36192 .47068 .3931 .44188 .37465 .4231 Metetra
.791 .77 .834 r
.37465 .4231 .3931 .44188 .42416 .4166 .40602 .39754 Metetra
.87 .435 .034 r
.40602 .39754 .42416 .4166 .45333 .48144 .43497 .46252 Metetra
.857 .416 .005 r
.43497 .46252 .45333 .48144 .48429 .54659 .46574 .52785 Metetra
.588 .089 0 r
.46574 .52785 .48429 .54659 .51716 .58416 .49861 .56547 Metetra
.646 .762 .934 r
.49861 .56547 .51716 .58416 .55102 .57409 .53275 .55517 Metetra
.899 .789 .731 r
.53275 .55517 .55102 .57409 .58445 .51593 .5667 .4965 Metetra
.933 .773 .661 r
.5667 .4965 .58445 .51593 .61651 .42924 .59943 .40917 Metetra
.935 .772 .654 r
.59943 .40917 .61651 .42924 .64738 .34213 .63094 .32145 Metetra
.408 .626 .942 r
.63094 .32145 .64738 .34213 .68155 .34645 .66531 .3256 Metetra
.327 .58 .934 r
.66531 .3256 .68155 .34645 .71669 .35454 .70065 .33352 Metetra
.795 .788 .846 r
.70065 .33352 .71669 .35454 .75019 .32775 .7345 .3064 Metetra
.882 .798 .762 r
.7345 .3064 .75019 .32775 .78213 .2812 .76689 .25944 Metetra
.22 .5 .904 r
.76689 .25944 .78213 .2812 .81944 .29539 .8044 .27347 Metetra
.466 .649 .938 r
.8044 .27347 .81944 .29539 .8565 .29733 .84173 .2752 Metetra
.698 .63 .777 r
.20671 .44648 .22502 .48116 .25528 .4582 .23665 .4285 Metetra
.751 .676 .778 r
.23665 .4285 .25528 .4582 .28652 .42328 .26736 .40318 Metetra
.176 .5 .908 r
.26736 .40318 .28652 .42328 .31383 .44723 .2956 .41353 Metetra
.553 .573 .828 r
.2956 .41353 .31383 .44723 .34314 .45221 .32526 .41227 Metetra
.706 .617 .755 r
.32526 .41227 .34314 .45221 .37465 .4231 .35651 .39041 Metetra
.713 .654 .789 r
.35651 .39041 .37465 .4231 .40602 .39754 .38781 .37059 Metetra
0 .016 .572 r
.38781 .37059 .40602 .39754 .43497 .46252 .41747 .40522 Metetra
.196 .252 .694 r
.41747 .40522 .43497 .46252 .46574 .52785 .44841 .43917 Metetra
.463 .368 .662 r
.44841 .43917 .46574 .52785 .49861 .56547 .48084 .45629 Metetra
.586 .434 .642 r
.48084 .45629 .49861 .56547 .53275 .55517 .51434 .44547 Metetra
.663 .486 .636 r
.51434 .44547 .53275 .55517 .5667 .4965 .54804 .4065 Metetra
.723 .541 .643 r
.54804 .4065 .5667 .4965 .59943 .40917 .58127 .35017 Metetra
.781 .612 .671 r
.58127 .35017 .59943 .40917 .63094 .32145 .61392 .29271 Metetra
.553 .623 .875 r
.61392 .29271 .63094 .32145 .66531 .3256 .64815 .29045 Metetra
.537 .57 .835 r
.64815 .29045 .66531 .3256 .70065 .33352 .68314 .29036 Metetra
.693 .613 .762 r
.68314 .29036 .70065 .33352 .7345 .3064 .7175 .2691 Metetra
.769 .674 .758 r
.7175 .2691 .7345 .3064 .76689 .25944 .75119 .23571 Metetra
.443 .618 .925 r
.75119 .23571 .76689 .25944 .8044 .27347 .788 .23922 Metetra
.575 .602 .842 r
.788 .23922 .8044 .27347 .84173 .2752 .8249 .23516 Metetra
.644 .583 .771 r
.18874 .40638 .20671 .44648 .23665 .4285 .2181 .39492 Metetra
.664 .625 .8 r
.2181 .39492 .23665 .4285 .26736 .40318 .24786 .38223 Metetra
.622 .709 .908 r
.24786 .38223 .26736 .40318 .2956 .41353 .2775 .37486 Metetra
.628 .584 .786 r
.2775 .37486 .2956 .41353 .32526 .41227 .30766 .36562 Metetra
.639 .56 .749 r
.30766 .36562 .32526 .41227 .35651 .39041 .33838 .35316 Metetra
.652 .606 .79 r
.33838 .35316 .35651 .39041 .38781 .37059 .36941 .3409 Metetra
.58 .621 .857 r
.36941 .3409 .38781 .37059 .41747 .40522 .40044 .33671 Metetra
.573 .468 .696 r
.40044 .33671 .41747 .40522 .44841 .43917 .432 .33215 Metetra
.572 .422 .639 r
.432 .33215 .44841 .43917 .48084 .45629 .4641 .32493 Metetra
.578 .411 .62 r
.4641 .32493 .48084 .45629 .51434 .44547 .49672 .31358 Metetra
.589 .419 .62 r
.49672 .31358 .51434 .44547 .54804 .4065 .52972 .29807 Metetra
.606 .446 .638 r
.52972 .29807 .54804 .4065 .58127 .35017 .563 .27983 Metetra
.638 .509 .689 r
.563 .27983 .58127 .35017 .61392 .29271 .59654 .26114 Metetra
.64 .646 .841 r
.59654 .26114 .61392 .29271 .64815 .29045 .63062 .25061 Metetra
.628 .594 .796 r
.63062 .25061 .64815 .29045 .68314 .29036 .66517 .24027 Metetra
.636 .558 .75 r
.66517 .24027 .68314 .29036 .7175 .2691 .70001 .22662 Metetra
.66 .601 .778 r
.70001 .22662 .7175 .2691 .75119 .23571 .73512 .21099 Metetra
.636 .71 .9 r
.73512 .21099 .75119 .23571 .788 .23922 .77105 .20083 Metetra
.635 .611 .809 r
.77105 .20083 .788 .23922 .8249 .23516 .80738 .18938 Metetra
.701 .809 .932 r
.16767 .39262 .18874 .40638 .2181 .39492 .19745 .37929 Metetra
.729 .793 .903 r
.19745 .37929 .2181 .39492 .24786 .38223 .22775 .36321 Metetra
.542 .707 .947 r
.22775 .36321 .24786 .38223 .2775 .37486 .25721 .35992 Metetra
.606 .782 .965 r
.25721 .35992 .2775 .37486 .30766 .36562 .28748 .35235 Metetra
.715 .829 .935 r
.28748 .35235 .30766 .36562 .33838 .35316 .31864 .3373 Metetra
.705 .8 .923 r
.31864 .3373 .33838 .35316 .36941 .3409 .35004 .32289 Metetra
.31 .617 .956 r
.35004 .32289 .36941 .3409 .40044 .33671 .38086 .32787 Metetra
.107 .61 .899 r
.38086 .32787 .40044 .33671 .432 .33215 .4124 .33223 Metetra
.073 .635 .748 r
.4124 .33223 .432 .33215 .4641 .32493 .4448 .33045 Metetra
.275 .77 .717 r
.4448 .33045 .4641 .32493 .49672 .31358 .47794 .31891 Metetra
.589 .944 .811 r
.47794 .31891 .49672 .31358 .52972 .29807 .51153 .29754 Metetra
.8 .989 .885 r
.51153 .29754 .52972 .29807 .563 .27983 .54529 .26985 Metetra
.834 .906 .888 r
.54529 .26985 .563 .27983 .59654 .26114 .5791 .24138 Metetra
.618 .751 .941 r
.5791 .24138 .59654 .26114 .63062 .25061 .61354 .23254 Metetra
.6 .767 .959 r
.61354 .23254 .63062 .25061 .66517 .24027 .64852 .22437 Metetra
.702 .833 .945 r
.64852 .22437 .66517 .24027 .70001 .22662 .68364 .20851 Metetra
.749 .823 .91 r
.68364 .20851 .70001 .22662 .73512 .21099 .71884 .18816 Metetra
.592 .715 .929 r
.71884 .18816 .73512 .21099 .77105 .20083 .75534 .18099 Metetra
.623 .766 .948 r
.75534 .18099 .77105 .20083 .80738 .18938 .79219 .17098 Metetra
.692 .739 .887 r
.14682 .37229 .16767 .39262 .19745 .37929 .17677 .35901 Metetra
.716 .747 .877 r
.17677 .35901 .19745 .37929 .22775 .36321 .20726 .34323 Metetra
.559 .707 .94 r
.20726 .34323 .22775 .36321 .25721 .35992 .23694 .339 Metetra
.624 .722 .917 r
.23694 .339 .25721 .35992 .28748 .35235 .26741 .33087 Metetra
.702 .741 .882 r
.26741 .33087 .28748 .35235 .31864 .3373 .29878 .31597 Metetra
.696 .743 .888 r
.29878 .31597 .31864 .3373 .35004 .32289 .3304 .30164 Metetra
.397 .627 .946 r
.3304 .30164 .35004 .32289 .38086 .32787 .36142 .3048 Metetra
.428 .623 .934 r
.36142 .3048 .38086 .32787 .4124 .33223 .39315 .30737 Metetra
.543 .662 .914 r
.39315 .30737 .4124 .33223 .4448 .33045 .42573 .30437 Metetra
.657 .7 .878 r
.42573 .30437 .4448 .33045 .47794 .31891 .45908 .29255 Metetra
.733 .726 .844 r
.45908 .29255 .47794 .31891 .51153 .29754 .49294 .27186 Metetra
.773 .744 .827 r
.49294 .27186 .51153 .29754 .54529 .26985 .52702 .24544 Metetra
.782 .759 .832 r
.52702 .24544 .54529 .26985 .5791 .24138 .5612 .21828 Metetra
.626 .723 .917 r
.5612 .21828 .5791 .24138 .61354 .23254 .5959 .20883 Metetra
.617 .716 .916 r
.5959 .20883 .61354 .23254 .64852 .22437 .63112 .19996 Metetra
.693 .742 .889 r
.63112 .19996 .64852 .22437 .68364 .20851 .66656 .18413 Metetra
.73 .758 .875 r
.66656 .18413 .68364 .20851 .71884 .18816 .70215 .16422 Metetra
.601 .713 .923 r
.70215 .16422 .71884 .18816 .75534 .18099 .7389 .1562 Metetra
.632 .722 .912 r
.7389 .1562 .75534 .18099 .79219 .17098 .77604 .14558 Metetra
.657 .671 .852 r
.12638 .34485 .14682 .37229 .17677 .35901 .1562 .33371 Metetra
.662 .692 .867 r
.1562 .33371 .17677 .35901 .20726 .34323 .18638 .32224 Metetra
.656 .733 .906 r
.18638 .32224 .20726 .34323 .23694 .339 .21682 .31158 Metetra
.653 .676 .859 r
.21682 .31158 .23694 .339 .26741 .33087 .24766 .30049 Metetra
.655 .656 .839 r
.24766 .30049 .26741 .33087 .29878 .31597 .27892 .28872 Metetra
.659 .684 .862 r
.27892 .28872 .29878 .31597 .3304 .30164 .31054 .27688 Metetra
.647 .703 .887 r
.31054 .27688 .3304 .30164 .36142 .3048 .34246 .26631 Metetra
.631 .602 .802 r
.34246 .26631 .36142 .3048 .39315 .30737 .37479 .25555 Metetra
.618 .541 .745 r
.37479 .25555 .39315 .30737 .42573 .30437 .40756 .24421 Metetra
.613 .515 .72 r
.40756 .24421 .42573 .30437 .45908 .29255 .44077 .23204 Metetra
.617 .518 .719 r
.44077 .23204 .45908 .29255 .49294 .27186 .4744 .21902 Metetra
.629 .547 .743 r
.4744 .21902 .49294 .27186 .52702 .24544 .50843 .2054 Metetra
.65 .611 .797 r
.50843 .2054 .52702 .24544 .5612 .21828 .54287 .19157 Metetra
.658 .706 .883 r
.54287 .19157 .5612 .21828 .5959 .20883 .57775 .17901 Metetra
.654 .681 .864 r
.57775 .17901 .5959 .20883 .63112 .19996 .61307 .16635 Metetra
.654 .656 .84 r
.61307 .16635 .63112 .19996 .66656 .18413 .64883 .15297 Metetra
.661 .679 .856 r
.64883 .15297 .66656 .18413 .70215 .16422 .68503 .13911 Metetra
.659 .733 .904 r
.68503 .13911 .70215 .16422 .7389 .1562 .72175 .12605 Metetra
.656 .69 .87 r
.72175 .12605 .7389 .1562 .77604 .14558 .75894 .11262 Metetra
.693 .816 .941 r
.10375 .33077 .12638 .34485 .1562 .33371 .13406 .31744 Metetra
.716 .797 .915 r
.13406 .31744 .1562 .33371 .18638 .32224 .16492 .302 Metetra
.579 .721 .94 r
.16492 .302 .18638 .32224 .21682 .31158 .19503 .29617 Metetra
.621 .793 .964 r
.19503 .29617 .21682 .31158 .24766 .30049 .22593 .28705 Metetra
.703 .837 .946 r
.22593 .28705 .24766 .30049 .27892 .28872 .25772 .27226 Metetra
.696 .804 .932 r
.25772 .27226 .27892 .28872 .31054 .27688 .2898 .25791 Metetra
.43 .682 .969 r
.2898 .25791 .31054 .27688 .34246 .26631 .32124 .25811 Metetra
.256 .719 .949 r
.32124 .25811 .34246 .26631 .37479 .25555 .35336 .25778 Metetra
.139 .684 .739 r
.35336 .25778 .37479 .25555 .40756 .24421 .38634 .25276 Metetra
.38634 .25276 .40756 .24421 .44077 .23204 .42014 .24037 Metetra
.461 .873 .729 r
.42014 .24037 .44077 .23204 .4744 .21902 .45454 .22056 Metetra
.718 .986 .881 r
.45454 .22056 .4744 .21902 .50843 .2054 .48926 .19594 Metetra
.799 .922 .919 r
.48926 .19594 .50843 .2054 .54287 .19157 .52416 .17066 Metetra
.63 .759 .94 r
.52416 .17066 .54287 .19157 .57775 .17901 .55938 .16011 Metetra
.617 .78 .959 r
.55938 .16011 .57775 .17901 .61307 .16635 .59514 .15 Metetra
.692 .839 .954 r
.59514 .15 .61307 .16635 .64883 .15297 .63123 .13405 Metetra
.731 .825 .923 r
.63123 .13405 .64883 .15297 .68503 .13911 .66757 .11466 Metetra
.612 .725 .926 r
.66757 .11466 .68503 .13911 .72175 .12605 .70486 .10514 Metetra
.634 .776 .949 r
.70486 .10514 .72175 .12605 .75894 .11262 .7426 .09341 Metetra
.677 .723 .884 r
.08174 .30775 .10375 .33077 .13406 .31744 .11215 .29489 Metetra
.692 .733 .882 r
.11215 .29489 .13406 .31744 .16492 .302 .14307 .28056 Metetra
.611 .724 .925 r
.14307 .28056 .16492 .302 .19503 .29617 .17356 .27261 Metetra
.642 .715 .901 r
.17356 .27261 .19503 .29617 .22593 .28705 .20471 .26242 Metetra
.682 .72 .878 r
.20471 .26242 .22593 .28705 .25772 .27226 .23663 .24838 Metetra
.68 .729 .887 r
.23663 .24838 .25772 .27226 .2898 .25791 .26887 .23458 Metetra
.544 .688 .933 r
.26887 .23458 .2898 .25791 .32124 .25811 .30075 .23044 Metetra
.559 .654 .899 r
.30075 .23044 .32124 .25811 .35336 .25778 .33322 .22587 Metetra
.601 .641 .862 r
.33322 .22587 .35336 .25778 .38634 .25276 .36644 .21811 Metetra
.647 .644 .833 r
.36644 .21811 .38634 .25276 .42014 .24037 .40038 .20541 Metetra
.686 .661 .819 r
.40038 .20541 .42014 .24037 .45454 .22056 .4349 .18772 Metetra
.715 .688 .823 r
.4349 .18772 .45454 .22056 .48926 .19594 .46981 .16676 Metetra
.728 .72 .843 r
.46981 .16676 .48926 .19594 .52416 .17066 .50499 .14528 Metetra
.643 .724 .907 r
.50499 .14528 .52416 .17066 .55938 .16011 .54047 .13356 Metetra
.638 .714 .902 r
.54047 .13356 .55938 .16011 .59514 .15 .57647 .12208 Metetra
.677 .72 .882 r
.57647 .12208 .59514 .15 .63123 .13405 .61288 .10663 Metetra
.699 .736 .879 r
.61288 .10663 .63123 .13405 .66757 .11466 .64964 .08883 Metetra
.63 .725 .916 r
.64964 .08883 .66757 .11466 .70486 .10514 .68716 .07755 Metetra
.646 .719 .901 r
.68716 .07755 .70486 .10514 .7426 .09341 .72516 .06472 Metetra
.671 .724 .89 r
.05923 .28457 .08174 .30775 .11215 .29489 .08975 .27207 Metetra
.68 .733 .89 r
.08975 .27207 .11215 .29489 .14307 .28056 .12072 .25868 Metetra
.635 .732 .918 r
.12072 .25868 .14307 .28056 .17356 .27261 .15159 .24885 Metetra
.651 .721 .9 r
.15159 .24885 .17356 .27261 .20471 .26242 .18301 .23768 Metetra
.674 .721 .885 r
.18301 .23768 .20471 .26242 .23663 .24838 .21506 .22424 Metetra
.673 .729 .892 r
.21506 .22424 .23663 .24838 .26887 .23458 .24746 .21088 Metetra
.601 .712 .922 r
.24746 .21088 .26887 .23458 .30075 .23044 .27979 .20295 Metetra
.606 .68 .894 r
.27979 .20295 .30075 .23044 .33322 .22587 .31265 .1947 Metetra
.625 .661 .864 r
.31265 .1947 .33322 .22587 .36644 .21811 .34613 .18455 Metetra
.65 .656 .843 r
.34613 .18455 .36644 .21811 .40038 .20541 .38023 .17152 Metetra
.674 .666 .835 r
.38023 .17152 .40038 .20541 .4349 .18772 .41487 .15559 Metetra
.693 .688 .841 r
.41487 .15559 .4349 .18772 .46981 .16676 .44994 .13771 Metetra
.702 .717 .86 r
.44994 .13771 .46981 .16676 .50499 .14528 .48537 .11946 Metetra
.652 .728 .905 r
.48537 .11946 .50499 .14528 .54047 .13356 .52113 .10668 Metetra
.649 .72 .901 r
.52113 .10668 .54047 .13356 .57647 .12208 .5574 .09396 Metetra
.671 .721 .887 r
.5574 .09396 .57647 .12208 .61288 .10663 .59412 .07889 Metetra
.684 .733 .888 r
.59412 .07889 .61288 .10663 .64964 .08883 .63127 .06239 Metetra
.645 .732 .912 r
.63127 .06239 .64964 .08883 .68716 .07755 .66905 .04953 Metetra
.653 .724 .901 r
.66905 .04953 .68716 .07755 .72516 .06472 .70733 .0357 Metetra
.691 .786 .923 r
.03532 .26675 .05923 .28457 .08975 .27207 .06626 .25279 Metetra
.711 .777 .904 r
.06626 .25279 .08975 .27207 .12072 .25868 .0978 .23681 Metetra
.586 .721 .937 r
.0978 .23681 .12072 .25868 .15159 .24885 .12846 .22985 Metetra
.631 .769 .946 r
.12846 .22985 .15159 .24885 .18301 .23768 .15996 .21978 Metetra
.702 .8 .926 r
.15996 .21978 .18301 .23768 .21506 .22424 .19249 .20434 Metetra
.694 .78 .918 r
.19249 .20434 .21506 .22424 .24746 .21088 .2253 .18929 Metetra
.463 .683 .961 r
.2253 .18929 .24746 .21088 .27979 .20295 .25725 .18792 Metetra
.411 .738 .992 r
.25725 .18792 .27979 .20295 .31265 .1947 .2899 .186 Metetra
.447 .826 .99 r
.2899 .186 .31265 .1947 .34613 .18455 .32351 .17965 Metetra
.575 .913 .972 r
.32351 .17965 .34613 .18455 .38023 .17152 .3581 .16634 Metetra
.713 .952 .952 r
.3581 .16634 .38023 .17152 .41487 .15559 .39344 .14604 Metetra
.786 .925 .928 r
.39344 .14604 .41487 .15559 .44994 .13771 .42923 .1212 Metetra
.789 .858 .902 r
.42923 .1212 .44994 .13771 .48537 .11946 .46523 .09571 Metetra
.635 .748 .93 r
.46523 .09571 .48537 .11946 .52113 .10668 .5013 .08402 Metetra
.626 .759 .942 r
.5013 .08402 .52113 .10668 .5574 .09396 .53792 .07272 Metetra
.693 .802 .932 r
.53792 .07272 .5574 .09396 .59412 .07889 .57502 .0559 Metetra
.724 .797 .91 r
.57502 .0559 .59412 .07889 .63127 .06239 .61246 .03583 Metetra
.616 .724 .923 r
.61246 .03583 .63127 .06239 .66905 .04953 .65069 .02499 Metetra
.639 .758 .935 r
.65069 .02499 .66905 .04953 .70733 .0357 .68944 .01204 Metetra
0 g
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.14416 .21324 m
.14879 .21789 L
s
[(-2)] .13491 .20394 .99496 1 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.55805 .05117 m
.56192 .05647 L
s
[(2)] .55031 .04057 .7295 1 Mshowa
.125 Mabswid
.19248 .19432 m
.19521 .19716 L
s
.24172 .17504 m
.2444 .17792 L
s
.2919 .15539 m
.29453 .15832 L
s
.39523 .11493 m
.39774 .11796 L
s
.44843 .0941 m
.45088 .09718 L
s
.50269 .07285 m
.50508 .07598 L
s
.09674 .23181 m
.09956 .23455 L
s
.05019 .25004 m
.05305 .25274 L
s
.61454 .02905 m
.61679 .03228 L
s
.67219 .00648 m
.67437 .00976 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[26]:=",
  ImageSize->{288, 233.563},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000jA000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00bGoo0P00EGoo0035Ool01@00Ool00000
Ool00P00E7oo0034Ool30003Ool2001DOol00:5oo`<001eoo`<000Eoo`@005=oo`00XGoo00<007oo
Ool06goo0P0017oo100000EC7@00001oo`00059oo`00XWoo00<007ooOol05goo0`000Woo10001E<M
00@005<M0000059oo`00XWoo00<007ooOol05Goo0P000Woo0`002E<M00D005<M001oo`00055oo`00
XGoo00<007oo00004goo0`0000Aoo`000000009>o@03001C7E<M00MC7@06001C7E<M001oo`00D7oo
002ROol00`00Oomoo`0@Ool60005C_d00`00DaeC7@07Dad01000DaeC7E<M0P00D7oo002bOol5000:
C_d00`00DaeC7@07Dad00`00DaeC7@03001?Ool00:moo`<00005Ool00000Gcd0000;C_d00`00DaeC
7@06Dad30002D_`00`00Oomoo`1=Ool00:eoo`80009oo`8000=O?@03001>oDkm00Y>o@03001C7E<M
00=C7@<000ABo08004ioo`00ZWoo0`000goo00<005lmGcd015lm00<004kmC_d02Dkm00<005<MDad0
0`000U;l00<005;lD_`00e;l0P00CGoo002XOol20004Ool20007Gcd00`00C_e>o@09C_d30005D_`0
0`00D_aBo003D_`2001=Ool00:Eoo`<000Aoo`8000YO?@03001>oDkm00I>o@80009Bo@03001Bo5;l
00=Bo003001Bo5;l00ABo08004aoo`00Xgoo0P000Woo00<007ooOol00P003Elm00<004kmC_d00Tkm
0`0015;m00<005;lD_`00e;l00<005;lD_`01E;l0P00Bgoo002POol30005Ool20002Fcd00`00GceO
?@0:Gcd00`00C_e>o@020008D_d00`00D_aBo002D_`00`00D_aBo005D_`2001;Ool009eoo`<000Eo
o`<000EK?@03001O?Elm00UO?@<000YBo@03001Bo5;l009Bo003001Bo5;l00EBo0<004Yoo`00Vgoo
0P001Woo0P0025/m00<005lmGcd01elm0P000UKl00<005;mD_d02E;m00D005;lD_aBo00000ABo0<0
0004D_`007oo0019Ool009Qoo`<000Eoo`<000]K?@03001O?Elm00=O?@<000AFo003001BoE;m00YB
o@04001Bo5;l0002D_`20005D_`2000=Ool3000iOol009Ioo`<000Eoo`80009C7P03001K?E/m00YK
?@03001O?Elm008000QFo003001BoE;m00UBo@03001Bo5;l00<000MBo003001oo`0000aoo`03001o
ogoo03Uoo`00Tgoo0`001Goo0`001E<N00<005/mFcd02E/m0`002eKl00<005;mD_d025;m10002U;l
00<007oo00001Woo0`000goo00<007ooOol0>7oo002@Ool30006Ool20008Dah00`00FceK?@07Fcd2
0002E_`00`00E_aFo00:E_`00`00D_eBo@04D_d30002D_d2000:D_`00`00Ool0000<Ool00`00Oomo
o`0hOol008ioo`8000Ioo`<000]C7P03001K?E/m00=K?@<000AFo003001Fo5Kl00YFo003001BoE;m
00@000EBo@8000]Bo003001oo`0000Yoo`03001oo`0003Uoo`00Rgoo0`001Goo0`000U;m00<005<N
Dah02U<N00<005/mFcd00P0025Kl00<005KlE_`02UKl0P002U;m00<005;lD_`02E;l00@007ooOol0
00Yoo`03001oogoo03Qoo`00R7oo0`0017oo10001U;m00<005<NDah02E<N0`002UKl00<005KlE_`0
25Kl0P0000=Jo000D_d02E;m0P002U;l0P0000=oo`00Ool0A7oo001VOol00`00Oomoo`0MOol40003
Ool2000:D_d00`00DaiC7P07Dah20002D_`00`00E_aFo009E_`00`00E_aFo005E_`20003F_`00`00
D_eBo@09D_d20006D_`30002Dah00`00Ool00014Ool006Eoo`03001oo`0001aoo`8000Eoo`800003
Ig`005;m00YBo@03001C7U<N00=C7P<000ABo003001Fo5Kl00YFo003001Fo5Kl009Fo08000IJo003
001BoE;m00QBo@80009Bo0@000IC7P03001oo`0004=oo`00IGoo00<007oo00006Goo0`001Woo00<0
06MlIg`00VMl00<005;mD_d02E;m00<005<NDah00P0025;l00<005KlE_`02EKl00<005KlE_`00P00
2E[l00<005;mD_d01e;m10002e<N0P00@goo001UOol00`00Ool0000FOol30008Ool00`00IgaWO003
Ig`00`00D_eBo@09D_d3000:D_`00`00E_aFo009E_`3000<F_`00`00D_eBo@04D_d30002C_d00`00
DaiC7P0:Dah20012Ool006Eoo`03001oo`0001Aoo`8000Uoo`8000MWO003001BoE;m00EBo@<0009B
o003001Bo5;l00UBo003001Fo5Kl00IFo080009Fo003001Jo5[l00YJo003001BoE;m00@0009>o@05
001>oDkmC_d0000;Dah20012Ool006Ioo`03001oogoo011oo`<000Yoo`03001WO6Ml00QWO003001B
oE;m00@000EBo003001Bo5;l00YBo003001Fo5Kl009Fo0<000AFo003001Jo5[l00]Jo08000I>o@05
001>oDkmC_d00009Dah200000e;K00000011Ool007Moo`800003Ool007oo00Qoo`8000aWO08000YB
o003001Bo5;l00UBo003001Fo5Kl008000QFo003001Jo5[l00QJo0800003Ged004km00E>o@03001>
oDkm009>o@03001C7U<N00=C7P<000ABf`80041oo`00M7oo0`0037oo00<006MlIg`02VMl0P0000=J
f`00D_`02U;l00<005;lD_`025;l0`002eKl00<005[lF_`01E[l0P000emM00<004kmC_d014km00<0
04kmC_d00dkm00<005<NDah00P001e;K0P00@7oo001bOol2000=Ool200000fNm00000008Ig`20004
F]/00`00D_aBo009D_`00`00D_aBo004D_`30002D]`00`00E_aFo00:E_`00`00F_aJo002F_`20006
Ged00`00C_e>o@03C_d00`00C_e>o@03C_d3000:D]/2000oOol006moo`<000eoo`8000EW_@03001W
O6Ml00=WO08000MJf`03001Bo5;l00QBo003001Bo5;l00@000EBg003001Fo5Kl00YFo003001Jo5[l
008000UOG@03001>oDkm009>o@04001>oDkmC_d200000eKl001Bf`0:D]/00`00Ool0000nOol006ao
o`<000moo`03001W_FNm00IW_@800003Ig`0000000UJf`03001Bo5;l00QBo0<000YBg003001Fo5Kl
00YFo08000aOG@04001>oDkmC_d40004E_`00`00D]]Bf`09D]/2000nOol006Yoo`80011oo`8000]W
_@03001Jfe[K00YJf`03001Bo5;l00ABo0<0009Bo@03001Bg5;L00QBg003001Fo5Kl00QFo0800003
Feh005mM00]OG@03001>oDkm008000MFo003001Bfe;K00UBf`03001oo`0003eoo`00Igoo0`000Woo
0P0037oo0P002fNm0P0000=JfP00F]/02e[K00<005;lD_`00`001E;m00<005;LD]`02E;L00<005Kl
E_`01EKl0P0015]N00<005mMGed02EmM0`0000=Fo000E_`01eKl00<005;KD]/02E;K00<007oo0000
?7oo001UOol2000BOol00`00IkeW_@09Ikd20003F]X00`00F]]Jf`0;F]/20009D_d00`00D]aBg009
D]`00`00E_aFo002E_`20007Feh00`00GeeOG@05Ged30002E[/00`00E_`00008E_`00`00D]]Bf`08
D]/200000goo001oo`0kOol0069oo`<0019oo`800003Fmh0000000MW_@8000IJfP03001Jfe[K00QJ
f`800003G_X005;m00UBo@03001Bg5;L00QBg003001Fo5Kl008000YKGP03001OGEmM00@000EF^`03
001Fo00000UFo003001Bfe;K00ABf`<0009Bo@03001oo`0003]oo`00Ggoo0`0057oo00<005_NFmh0
0e_N0P000fNm0P0025[J00<005[KF]/01U[K0P000ekj00<005;mD_d02E;m00<005;LD]`01U;L1000
35]N0`002UJk0P002EKl00<005;KD]/010001E;m00@007ooOol003Yoo`00GGoo0P005Goo0P0025_N
0`002e[J00<005[KF]/015[K00<005kjG_X015kj00<005;mD_d025;m00@005;LD]aBg0D000=?7P03
001KGU]N00QKGP80009BVP03001F^eJk00UF^`8000MFo0@000YBo@03001oo`0003Yoo`00FWoo0`00
00=oo`00Ool04goo00<005_NFmh01U_N0P000UJj00<005[JF]X02U[J00@005[KF]]Jf`8000QNnP03
001BoE;m00MBo@@000U?7P8000EKGP<000ABVP03001F^eJk00UF^`80009Fo0D000=>g@03001BoE;m
00UBo@03001oo`0003Uoo`00F7oo0P005goo0P001e_N0P0015Jj00<005[JF]X02U[J00@005[K0000
00]NnP03001BoE;m00=Bo@<0009C7P03001?7TlN00Y?7P03001KGU]N008000QBVP03001F^eJk00UF
^`<000Q>g@03001BoE;m00YBo@03001oo`0003Qoo`00EGoo0`005goo10001E_N0P001eJj00<005[J
F]X02U[J00<005kjG_X02ekj00<005;mD_d00`001U<N00<004lNCah02DlN0`002U:J00<005JkE[/0
1eJk10002TkM00<005;mD_d02E;m00@007oo000003Moo`00Dgoo0P0067oo0P0014^o1@002EJj00<0
05[JF]X025[J0P0000=JfP00G_X035kj0P002U<N00<004lNCah01DlN0`000U:k00<005:JDYX02E:J
00<005JkE[/01EJk00<005lKGa/00P002dkM00<005;mD_d025;m1000=goo000_Ool3000NOol3000G
Ool30006Bkl200000e:J001F^P0:E[X00`00F]YJfP05F]X20003F]X00`00G_YNnP09G_X200000fNm
001C7P0:Dah00`00Cai?7P040005D[/00`00DYYBVP09DYX00`00E[]F^`03E[/20003Ga/00`00Ga/0
000;C]d00`00D_eBo@04D_d30002Cah00`00Ool0000fOol002moo`03001oogoo01]oo`<00003Ool0
07oo01Eoo`8000I;_`<000ABVP03001F^UJj00QF^P03001JfU[J00AJfP03001JfU[J00AJfP03001N
nUkj00MNnP03001W_FNm009W_@03001C7U<N00QC7P<000YB^`03001BVU:J00UBVP05001F^eJkE[/0
0005Ga/01000Ga]O6`002TkM00<005;mD_d010001TlN0P00=Woo000ZOol30003Ool00`00Oomoo`0H
Ool2000EOol70005Bkl20007DYX00`00E[YF^P09E[X01000F]YJfU[J0P001e[J00<005kjG_X01Ukj
00<006NmIkd00fNm00<005<NDah01U<N0P000UKL00<005:kD[/025:k00<005:JDYX02E:J00@005Jk
000000IO6`05001O6elKGa/00008C]d4000:Cah00`00Ool0000eOol0031oo`03001oogoo01Eoo`<0
00ioo`T000LkG`D000YBVP03001F^UJj00QF^P04001JfP00000:F]X00`00G_YNnP03G_X20007Ikd0
0`00DaiC7P03Dah20004E]`00`00D[]B^`09D[/00`00DYYBVP08DYX20008Ga/01@00Ga]O6elK0000
0dkM1@000d[M00<004lNCah02DlN0P00=Goo000_Ool00`00Ool0000DOol20002Ool?0005=_l20008
>el30002C[/00`00DYYBVP08DYX00`00E[YF^P09E[X00`00F]YJfP0;F]X01@00G_YNnUkj00002VNm
00<005<NDah00P001eKL00<005:kD[/025:k00<005:JDYX01U:J0P000U[l00<005lKGa/01ElK00<0
05lKGa/00UlK0`002D[M00<004lNCah024lN0`00=7oo000`Ool00`00Oomoo`0@Ool30002Ool20002
Fad00`00>[hj_P06>[h20009=_l20003>el30005C[/00`00DYYBVP09DYX00`00E[YF^P06E[X20000
0eJj001JfP0;F]X01000G_X000002fNm0`002EKL00<005:kD[/02E:k00<005:JDYX00U:J0`0015[l
00<005lKGa/01ElK00<005lKGa/00P0000=OG@00B]d02D[M00<004lNCah01DlN0`0000ABN@00Ool0
03=oo`00@7oo10000Woo0P001E/M00<003Zn>[h01cZn00<003Ko=_l01cKo10002Djk00<005:JDYX0
25:J00<005JjE[X015Jj0P000eJj00<005[JF]X02e[J00<006NmIkd02FNm0P000U9i00<005KLE]`0
25KL00<005:kD[/025:k00<005:JDYX00P0025[l00<005lKGa/015lK0`000emM00<004[MB]d02D[M
00<004lNCah010001E9i0P00<goo000nOol20004Ool20008Fad00`00>[hj_P07>[h20003=_l40003
C[`00`00C[]>^`08C[/00`00DYYBVP08DYX01000E[YF^UJj0P001UJj00<005[JF]X02E[J00@005_l
000000MW_@8000ABN@03001Fg5KL00QFg003001B^e:k00QB^`<000YJo003001O6elK00AO6`03001O
GEmM00AOG@03001:gD[M00Q:g@<000UBN@03001oo`00039oo`00>goo0`0017oo0P002e/M00<003Zn
>[h01SZn1@001djl00<004jkC[/024jk00<005:JDYX025:J00@005Jj000000UF^P03001JfU[J00IJ
fP8000AKo08000=W_@8000MBN@03001Fg5KL00QFg003001B^e:k00AB^`<0009>g@03001Jo5[l00UJ
o004001O6elKGa/30007Ged00`00B]e:g@04B]d300000e;L001BN@0:DWT3000aOol003Uoo`8000Eo
o`800003Fcd005/M00]K7@04000j_SZn>[h40003C]d00`00C[a>_007C[`00`00C[]>^`08C[/00`00
DYYBVP07DYX2000;E[X00`00F]YJfP05F]X00`00FoaKo006Fo`3000:DWT00`00E]aFg007E]`00`00
D[]B^`040005C]d00`00F_aJo009F_`01000Ga/000000UmM00<005mMGed01EmM00<004[MB]d01000
1E;L00<0059iDWT0259i00<007oo0000<Goo000fOol30006Ool00`00FceK?@02Fcd00`00FaeK7@0:
Fad30008C]d00`00C[a>_007C[`00`00C[]>^`08C[/00`00DYYBVP03DYX30002DYX00`00E[YF^P09
E[X00`00F]YJfP03F]X00`00FoaKo004Fo`300000e8g001BN@0;DWT00`00E]aFg005E]`4000:C]d0
0`00F_aJo008F_`20004Ged00`00GeeOG@05Ged30009D]`00`00DWUBN@08DWT01000Oomoo`00<7oo
000dOol20007Ool20006Fcd20008Fad200000eKl001>g@09C]d00`00C[a>_007C[`00`00C[]>^`07
C[/00`00DYYBVP030005DYX00`00E[YF^P0:E[X00`00F]YJfP020003Fo`40005DSL00`00DWUBN@09
DWT01000E]aFg5KL10000e;m00<004kMC]d02DkM00<005[lF_`01E[l0P000U]N00D005mMGeeOG@00
00EOG@80009FN003001Bg5;L00QBg003001BNE9i00QBN@04001oogoo000_Ool0035oo`<0009oo`03
001oogoo009oo`8000YK?@03001K7E/M00=K7@8000AFo003001>gDkM00M>g@03001>_4jl00M>_003
001>^djk00I>^`@000UBVP03001F^UJj00UF^P04001JfP00Fo`40009DSL00`00DWUBN@0:DWT30008
D_d00`00C]e>g@09C]d00`00F_aJo002F_`20005Feh20002Ged00`00GeeOG@020004EWP00`00D]aB
g008D]`00`00DWUBN@08DWT01000Oomoo`0027oo00<007ooOol097oo000^Ool30007Ool3000=Fcd0
0`00FaeK7@020007E_`00`00C]e>g@07C]d00`00C[a>_007C[`01000C[]>^djk10000TjK00<005:J
DYX025:J00<005JjE[X02UJj100000=>5`00DSL02U8g00<0059iDWT0259i00<006LJ00002E;m00<0
04kMC]d02DkM00<005[lF_`00P002E]N00<005mM00000P001eIh00<005;LD]`025;L00<0059iDWT0
1e9i00D007ooOomoo`0000Ioo`03001oo`0002Eoo`00;7oo0P001Woo10000e<N0P002e/m0`002EKl
00<004kMC]d024kM00<004jlC[`00djl1`001djK00<005:JDYX025:J00<005JjE[X01eJj100014hG
00<0058gDSL0258g00<0059iDWT01e9i00D006LJIaYW6P0000UBo@03001>gDkM00M>g@@000]KGP<0
00YFN003001Bg5;L00MBg003001BNE9i00QBN@05001oogooOol00005Ool00`00Ool0000UOol002Uo
o`<000Aoo`@000UC7P03001K?E/m00EK?@<0009Fo003001Fo5Kl00QFo003001>gDkM00I>g@L000E6
W003001>VdjK00I>V`03001BVU:J00QBVP03001F^UJj00EF^P@000I>5`03001B=e8g00UB=`03001B
NE9i00EBN@03001W6VLJ009W6P03001BoE;m00QBo@04001>gDkMC]d50003Cah00`00FeiKGP07Feh2
00000e8g0000000;EWP00`00D]aBg007D]`00`00DWUBN@07DWT01@00Oomoogoo00001Goo00<007oo
00009Goo000WOol20003Ool40002B_d00`00DaiC7P09Dah20002Fcd30006E_`00`00E_aFo008E_`0
1000C]e>gDkM10000dKM00<004JLAY`01TJL00<004jKCY/01djK00<005:JDYX025:J00<005JjE[X0
0UJj100024hG00<0058gDSL02E8g00<0059iDWT00e9i0P001VLJ00<005;mD_d01U;m1@002DlN00<0
05]NFeh00e]N0`00158g00<005IhEWP02EIh00<005;LD]`01e;L00<0059iDWT0259i00D007ooOomo
o`0000Aoo`03001oo`0002Eoo`0097oo0`000Woo0`001d[m00<005<NDah02E<N0`002EKl00<005Kl
E_`025Kl10001dKM00<004JLAY`01dJL00<004jKCY/01TjK00<005:JDYX025:J00<005JjE[X00`00
00=>5`00CQL02DhG00<0058gDSL02E8g00D0059iDWUBN@0000UW6P04001BoE;mD_d40003Cah00`00
Cai?7P09Cah00`00FeiKGP020007DSL00`00EWQFN00:EWP50005D]`00`00DWUBN@03DWT50004Ool0
0`00Oomoo`02Ool00`00Oomoo`0TOol0029oo`8000=oo`800003Fa`004[m00Q:o@8000IC7P<0009B
o003001Fo5Kl00QFo003001Fo5Kl00AFo0<0009Fo0030016gDKM00M6g@030016W4JL00I6W003001>
VdjK00M>V`03001BVU:J00MBVP<000E>5`03001>5dhG00M>5`03001B=e8g00UB=`04001BNE9i000;
IaX30008Cah00`00Cai?7P08Cah30009DSL00`00EWQFN009EWP00`00H[P00003>Wd;0004BWX00`00
Oomoo`03000[Ool001moo`<000=oo`8000AK7003001:oD[m00Q:o@03001C7U<N00<000IBo003001F
o5Kl00QFo003001Fo5Kl00<000IFo0030016gDKM00I6g@030016W4JL00M6W003001>VdjK00I>V`03
001BVU:J00EBVP8000Q>5`03001>5dhG00M>5`03001B=e8g00YB=`8000]W6P03001[W00000Y?7P03
001?7TlN00A?7P<00003DWT0058g00UB=`8000UFN004001R^6:h0008>Wd00`00BWY:NP08BWX00`00
Oomoo`02Ool00`00Oomoo`0XOol001aoo`<000Aoo`8000MK7003001:oD[m00M:o@<000YBo003001F
o5Kl00QFo08000YFo0030016gDKM00I6g@030016W4JL00I6W003001>VdjK00M>V`03001BVU:J009B
VP<000U>5`03001>5dhG00Q>5`03001B=e8g00UB=`03001W6VLJ00UW6P05001[W6^LJi`0000:Cah0
0`00Cai?7P030005DWT00`00DSMB=`06DSL30008EWP00`00H[QR^002H[P00`00>WdjO@06>Wd00`00
BWY:NP07BWX00`00Oomoo`03Ool00`00Oomoo`0WOol001Yoo`<000Aoo`8000YK7003001:oD[m00A:
o@80009Bo@03001Bo5;l00QBo003001Fo5Kl00IFo0800003E_`005Kl00YFo0030016gDKM00I6g@03
0016W4JL00I6W003001>VdjK00I>V`03001BVU:J008000=>=`03001>5dhG00M>5`03001>5dhG00M>
5`03001B=e8g00MB=`800003H_X006LJ00QW6P03001[W6^L009[W003001?7TlN00Q?7P<000QBN@03
001B=e8g00=B=`<0009B=`03001FN5Ih00EFN003001R^6:h00AR^003000jOCYm00DjO@03001:NTYj
00M:NP03001oogoo00=oo`03001oogoo02Moo`0067oo0P000Woo00<007ooOol00P003E/L00<004[m
B_d00`001E;m00<005;lD_`025;l00<005KlE_`00eKl0P0015Kl00<005KlE_`02EKl00<004KMA]d0
1DKM00<004JLAY`01TJL00<004jKCY/00djK1P001Dhg00<004hGCQL01dhG00<004hGCQL01dhG00<0
058gDSL01U8g00<006;jH_X00V;j00<006LJIaX016LJ0P001V^L00<004lNCah014lN0`0000=BVP00
DWT0259i00<0058gDSL00`001E8g0P0015Ih0P001f:h00<003Ym>Wd01SYm00<004YjBWX01dYj00<0
07ooOol00goo00<007ooOol09Woo000HOol20003Ool20002Fcd00`00FaaK700:Fa`30009D_d00`00
D_aBo008D_`00`00E_aFo0020007E_`00`00E_aFo008E_`G00000e9i001>=`08CSL00`00CQM>5`07
CQL00`00CQM>5`08CQL00`00DSMB=`04DSL00`00H_YRnP03H_X00`00IaYW6P03IaX00`00Jia[W007
Ji`00`00Cai?7P030005DYX00`00DWUBN@06DWT30009DSL01@00EWQFN5Ih00002V:h0P001SYm00<0
04YjBWX01dYj00<007ooOol00goo00<007ooOol09Woo000HOol00`00Ool000020005Fcd00`00FaaK
7007Fa`20002E_`00`00D_eBo@07D_d00`00D_aBo008D_`30009E_`00`00E_aFo006E_`20002Fcd0
0`00=[lf_`06=[l300038_h30005DWT00`00CSM>=`06CSL00`00CQM>5`07CQL00`00CQM>5`08CQL0
0`00DSMB=`02DSL20007H_X01@00IaYW6VLJ00002f^L0P0025:J00<0059iDWT00e9i0`0000=BN@00
DSL02E8g0P0000=FN000H[P02F:h00<007<h00000P001CYm00<004YjBWX01dYj00<007ooOol00goo
00<007ooOol09Goo000AOol00`00Oomoo`04Ool20009Fcd20005Fa`20005E_`00`00D_eBo@07D_d0
0`00D_aBo004D_`30002D]`00`00E_aFo008E_`00`00E_aFo003E_`20005Fcd00`00=[lf_`08=[l3
0008DWT00`00CSM>=`07CSL00`00CQM>5`07CQL00`00CQM>5`07CQL01@00DSMB=e8g00002V;j00<0
06LJ00002V^L0`002U:J00<0059iDWT00P00159i00<0058gDSL02E8g0P002f:h00<007<h00000Qgl
0`000SYm00<004YjBWX01dYj00<007ooOol017oo00<007ooOol097oo000@Ool00`00Ool00004Ool0
0`00Ool0000;Fcd00`00FaaK70020008E_`00`00D_eBo@07D_d00`00D_aBo0030005D]`00`00E_aF
o009E_`00`00E_aFo0020008Fcd20006=[l200000e;L001BN@08DWT00`00CSM>=`07CSL00`00CQM>
5`07CQL00`00CQM>5`08CQL3000<H_X00`00Jia[W007Ji`20003DQH00`00DYYBVP07DYX30007DWT0
0`00DSMB=`08DSL2000:H[P01@00LcQc>7<h000011gl0P0000<jO@00BWX01dYj00<007ooOol017oo
0P009Goo000@Ool00`00Ool00004Ool200000goo001K?@09Fcd3000;E_`00`00D_eBo@06D_d30009
D]`00`00E_aFo008E_`3000<Fcd00`00=[lf_`030004D]`00`00DWUBN@07DWT00`00CSM>=`06CSL0
0`00CQM>5`07CQL00`00CQM>5`08CQL00`00H_YRnP0;H_X00`00Io`00006Ji`20005DQH00`00DYYB
VP04DYX300000e:J001BN@07DWT00`00DSMB=`06DSL300000f:h001R^007H[P00`00LcQc>003LcP0
0`007O`Mo0037O`60005BWX00`00Oomoo`03Ool2000UOol0011oo`03001oo`0000Aoo`04001oogoo
Ool20006Fcd20002E_`00`00E_aFo00:E_`01000D_eBoE;m10000Tkm00<005;LD]`025;L00<005Kl
E_`01EKl0P000U]N0P002e/m0`001e;L00<0059iDWT01e9i00<004hgCSL01dhg00<004hGCQL01dhG
00<004hGCQL01DhG0P0000=Nn`00H_X02F;j0P000fOl0P000V^L0P00258F00<005:JDYX00`0015:J
00<0059iDWT01e9i00<0058gDSL0158g00L005YhFWQJN000H[P00007H[P00`00LcQc>003LcP00`00
7O`Mo0057O`01000>YhjWSZN1P001goo00<007ooOol08Woo000@Ool00`00Ool00004Ool00`00Oomo
o`03Ool00`00FceK?@030005E_`00`00E_aFo009E_`40007C_d00`00D]aBg008D]`00`00E_aFo002
E_`20006Feh00`00FceK?@05Fcd30002E[/00`00D]aBg006D]`00`00DWUBN@06DWT00`00CSM>=`07
CSL00`00CQM>5`07CQL00`00CQM>5`03CQL20003G_/00`00H_YRnP07H_X00`00IoaWo005Io`2000:
DQH30008DYX00`00DWUBN@06DWT00`00DSMB=`02DSL20004FWP01000H[QR^0001F:h00<007<hLcP0
1G<h0P001Agl00<003ZN>Yh01cZN00<007ooOol017oo00<007ooOol08Woo000AOol00`00Oomoo`03
Ool20005Ool20009E_`00`00E_aFo006E_`20002F_`00`00C_e>o@07C_d00`00D]aBg007D]`00`00
E_aFo0020009Feh20002Fcd30005E[/00`00D]aBg006D]`00`00DWUBN@07DWT00`00CSM>=`06CSL0
0`00CQM>5`07CQL01000CQM>5dhG0P001Ukk00<006;jH_X01F;j00<006OlIo`016Ol0`00258F0`00
00=B5P00DYX025:J00<0059iDWT01U9i00D0058gDSMB=`0000MJN003001R^00000AR^003001c>7<h
00Ec>003001g^000008000@Mo003000jWSZN00HjWP03001oogoo00Eoo`03001oogoo025oo`005goo
00<007ooOol01Goo00<005KlE_`025Kl00<005KlE_`00eKl0P001E[l00<004kmC_d01dkm00<005;L
D]`01U;L0`0035]N0`002EJk00<005;LD]`01U;L00<0059iDWT01U9i00<004hgCSL01dhg00<004hG
CQL01dhG0`002Ekk00<006;jH_X00f;j00<006OlIo`00fOl0P000dgD00<0058FDQH00U8F0`00158F
00<005:JDYX025:J00<0059iDWT01U9i0`0025Yh00@006:hH[P0009R^003001c>7<h00Ic>003001g
^000008Io@<0008Mo003000jWSZN00HjWP03001oogoo00Eoo`03001oogoo021oo`005Woo00<007oo
Ool01goo00<005KlE_`025Kl00<005KlE_`00P0025[l00<004kmC_d01dkm00@005;LD]aBg0@0009?
?P8000UKGP80009BVP03001F^eJk00QF^`03001Bg5;L00EBg003001BNE9i00MBN@03001>=dhg00I>
=`03001>5dhG00I>5`8000aNn`03001RnV;j008000AWo08000E=e003001B5P00008000QB5Q@000]J
N006001R^6:h001R^0001g<h00D007NhMkQg^00000@Io@<000TjWP03001oogoo00Aoo`03001oogoo
021oo`005Woo00<007ooOol027oo00<005KlE_`025Kl0P002e[l00<004kmC_d01Tkm100024ln00<0
05]NFeh015]N0P0015:J00<005JkE[/02EJk00<005;LD]`01E;L00<0059iDWT01U9i00<004hgCSL0
1Thg00<004hGCQL014hG0P000UKL00<005kkG_/02Ekk00<006;j000016Ol0P001TgD0`002U8F00<0
069e000024Ik00<004IJAUX01TIJ00<005YhFWP02EYh00<006:hH[P00P001g<h00<007NhMkP00gNh
00<001Wm6Od00aWm1P0013ZN00<007ooOol01Goo00<007ooOol07goo000FOol20009Ool00`00E_aF
o006E_`200000eKl001Jo00;F_`01000C_e>oDkm10000T[n00<004lnCch024ln0P000U]N0P001e:J
00<005JkE[/025Jk00<005;LD]`01E;L00<0059iDWT01U9i00<004hgCSL01Thg00<004hGCQL00ThG
0P0015KL00<005kkG_/02Ukk1P001DgD0`0000==e000DQH02U8F00<0069e00002DIk00<004IJAUX0
1TIJ00<005YhFWP02EYh00@006:h000000Mc>003001g^7Nh00=g^003000IoAWm00DIo@04000RgR;N
8]h70006Ool00`00Oomoo`0NOol001Ioo`03001oogoo00Uoo`03001Fo5Kl00=Fo08000AFo003001J
o5[l00UJo0@000M:oP03001??Tln00Q??P<000UBVP03001F^eJk00QF^`D000ABg003001BNE9i00IB
N@03001>=dhg00I>=`04001>5`000007E]`00`00G_]Nn`07G_/20002BmT2000014Vc001=e4gD0`00
1DgD00<0058FDQH01e8F00D0069eHWERM@0000Q6N`030016FTIJ00I6FP03001JN5Yh00UJN005001R
^000LcP00005LcP00`00MkQg^005MkP500036Od200068]h:000OOol001Ioo`03001oogoo00Yoo`03
001Fo5Kl008000MFo003001Jo5[l00IJo080009K?@03001:oT[n00M:oP8000I??P80009B^`03001B
VU:J00QBVP03001F^eJk00EF^`80009Jo003000bWS:N01P000UFg003001Nnekk00INn`03001;fD_I
008000=9/`<000Q=e003001B5U8F00MB5P05001RMF9eHWD00009AW/00`00AUY6FP06AUX00`00FWQJ
N009FWP01@00LcQc>7<h00000g<h00<007NhMkP01GNh00<006_j00000cJN40000e;L0P007goo000F
Ool00`00Oomoo`0;Ool2000:E_`00`00F_aJo003F_`20005Fcd00`00B_i:oP08B_h00`00Cci??P03
0004D[/00`00DYYBVP09DYX00`00E[]F^`02E[/20005F_`00`00<YhbWP04<Yh00`00=WdfO@06=Wd0
0`00A[e6_@06A[d00`00E]aFg008E]`00`00G_]Nn`03G_/200000d_I00000003BK<40009CM@00`00
DQIB5P06DQH00`00HWERM@03HWD00`00AW]6N`06AW/00`00AUY6FP06AUX00`00FWQJN008FWP00`00
Ic/00002LcP01000LcQc>0001gNh00D006_jJoY[nP0000TfWP@000QBg003001oo`0001ioo`005Goo
0`003Goo00<005KlE_`02EKl00<005[lF_`00P0025/m00<004[nB_h01d[n0`0025:k00<005:JDYX0
25:J00<005JkE[/00P001e[l00<003:N<Yh01C:N00<003Im=Wd01CIm00<004JmA[d01TJm00<005KL
E]`02EKL00@005kkG_]Nn`@00099/`<000=9/`03001=e4gD00M=e003001B5U8F00IB5P03001RMF9e
00ARM@030016NdIk00I6N`030016FTIJ00E6FP03001JN5Yh00MJN004001W>fLk0003LcP00`00LcP0
0006MkP00`00JoY[nP02JoX00`00=YhfWP04=Yh30002D_d00`00D]aBg008D]`2000NOol001Eoo`03
001oogoo00ioo`03001Fo5Kl00UFo08000]K?@03001:oT[n00A:oP80009Bo003001B^e:k00MB^`03
001BVU:J00QBVP8000YJo003000bWS:N00DbWP03000fOCIm00DfO@030016_DJm00I6_@03001Fg5KL
00QFg003001Nn`0000800003BK<00000008000I9/`03001=e4gD00Q=e003001B5U8F00AB5P03001R
MF9e00ERM@030016NdIk00I6N`030016FTIJ00I6FP03001JN5Yh00EJN003001W>fLk009W>`05001c
>7<hLcP00006MkP00`00JoY[nP04JoX00`00=YhfWP030005D_d00`00D]aBg008D]`00`00Ool0000M
Ool001Eoo`03001oogoo00moo`03001Fo5Kl00IFo0800003Feh005/m00]K?@03001:oT[n00<000AB
o003001B^e:k00QB^`03001BVU:J00EBVP800003F_`005[l00YJo003000bWS:N00DbWP03000fOCIm
00DfO@030016_DJm00I6_@03001Fg5KL00MFg0<00004BK<000000009BK<00`00CMA=e008CM@00`00
DQIB5P03DQH00`00HWERM@07HWD50004AW/00`00AUY6FP05AUX00`00FWQJN003FWP20006Ic/01@00
LcP007Nh000017Nh00<006_jJoX01F_j0`002E;m00<005;LD]`025;L00<007oo000077oo000EOol0
0`00Ool0000@Ool00`00E_aFo003E_`20004Feh00`00FceK?@09Fcd30008D_`00`00D[]B^`07D[/0
0`00DYYBVP03DYX20004F_`00`00F_aJo009F_`50003<Yh00`00=WdfO@05=Wd00`00A[e6_@06A[d0
0`00E]aFg003E]`3000014Vc000000000TVc00<004VcBK<01dVc00<004gDCM@024gD00<0058FDQH0
0e8F00<0069eHWD01f9e0P000cJN1P001dIJ00D005YhFWQJN00000QW>`05001c>000MkP00003MkP0
0`00JoY[nP04JoX20002F]/00`00D_eBo@07D_d00`00D]aBg008D]`00`00Ool0000LOol001Eoo`80
019oo`03001Fo5Kl008000MKGP8000IK?@<0009Ff`03001Bo5;l00MBo003001B^e:k00MB^`03001B
VU:J008000MJo003001Jo5[l00IJo0800003Fcd002In008VOPP000<fO@030016_DJm00I6_@03001F
g5KL00L000I9/`030019/dVc00I9/`03001=e4gD00Q=e003001B5U8F009B5P03001RMF9e00MRM@03
001g500000PfWP@000A6FP04001JN5Yh000:Ic/01`00MkQg^7Nh001g^00000E[nP8000AJf`03001B
oE;m00QBo@03001Bg5;L00IBg0<00003Ool007oo01Yoo`0027oo1@000Woo00<007ooOol00goo00<0
07ooOol04Woo0P002e]N00<005/mFcd00`001UKK00<005;lD_`01e;l00<005:kD[/01E:k10002U[l
00<005[lF_`00e[l0P0015/m00<002In9Wh01RIn4@0000A9]000000000U9/`030019/dVc00M9/`03
001=e4gD00Q=e005001B5U8FDQH00009HWD01000MaAg500023JN00<002YM:Ud0100000=6FP000000
2VLk00@005ok0000009g^003001[nV_j009[nP8000MJf`03001BoE;m00MBo@04001Bg5;LD]`50003
D_d2000KOol000Yoo`07001oogooOol007oo000017oo00<007ooOol04goo0P002U]N0`002UKK00<0
05;lD_`01U;l00@005:kD[]B^`@000=>o@03001Jo5[l00UJo003001Jo5[l008000MK?@8000PVOPH0
00A9eP030019]4Vd00<00099]0030019/dVc00M9/`030019/dVc00M9/`03001=e4gD00Q=e004001B
5U8F0009HWD00`00MaAg5002Ma@00`00=YhfWP05=Yh00`00:UdZG@04:Ud20009Ic/20004Go/7000:
F]/00`00D_eBo@05D_d50008D_d3000JOol000Yoo`07001oogooOol007oo00000goo0P005goo00<0
05]NFeh01E]N0P000UJk00<005KKE]/02EKK00<005;lD_`00e;l1P0024km00<005[lF_`025[l0`00
2e/m00@002In9WhVOP@00003BW/004WF00M9eP<000I9]0030019/dVc00I9/`030019/dVc00M9/`03
001=e4gD00Q=e004001B5U8F0009HWD00`00MaAg5002Ma@00`00=YhfWP06=Yh00`00:UdZG@05:Ud0
0`00Ic]W>`05Ic/00`00Go]On`03Go/50002E[/00`00F]]Jf`08F]/01000D_eBoE;m10000d[M00<0
05;mD_d025;m00<007oo00006Goo000:Ool01`00Oomoogoo001oo`0000=oo`03001oogoo01Moo`80
009KGP<000EF^`03001FfeKK00UFf`D000A6gP03001>oDkm00M>o@03001Jo5[l00IJo080009KG@03
001K?E/m00UK?@@000I:N`030019eTWF0099eP@000Q9]0030019/dVc00I9/`030019/dVc00M9/`03
001=e4gD00Q=e003001B5P0000YRM@03001g57LD00=g50D000@fWP03000ZGBYM00DZG@03001W>fLk
00=W>`03001Oneok009On`@000=F^`03001F^`0000]Jf`<000Q:g@03001BoE;m00MBo@03001oo`00
01Uoo`002Woo00L007ooOomoo`00Ool00003Ool00`00Oomoo`0IOol20009E[/00`00E]]Ff`06E]/2
00000e[l0016gP07A]h00`00C_e>o@07C_d00`00F_aJo003F_`20005Fed20006Fcd30002DWT00`00
BW]:N`05BW/00`00BMI9eP020004BMH00`00BKA9]005BK@00`00BK=9/`06BK<00`00BK=9/`07BK<0
0`00CMA=e009CM@20009HWD00`00MaAg5004Ma@300028Yl80004:Ud01000Ic]W>fLk0P000eok0`00
1eJk00<005Jk000025[K0P0000=O7000B]d024[M00<005;mD_d01U;m0`0000=oo`00Ool01Woo0`00
3Woo0009Ool20004Ool00`00Oomoo`02Ool00`00Oomoo`0JOol00`00E[]F^`07E[/00`00E]]Ff`05
E]/00`00F_aJo002F_`00`00A]i6gP06A]h00`00C_e>o@07C_d00`00F_aJo0020009Fed00`00FceK
?@030005DWT00`00BW]:N`05BW/30006BMH00`00BKA9]005BK@00`00BK=9/`06BK<00`00BK=9/`07
BK<00`00CMA=e009CM@00`00HWERM@08HWD00`00MaAg5003Ma@01000Ni5kTG^A0P001R:O1P0000@Z
G@00Ic/000=On`<00003D]`005Jk00IF^`03001F^`0000IJf`8000AO7003001:gD[M00M:g@04001B
oE;mD_d40003Cch00`00Ool00006Ool00`00Oomoo`0>Ool001Aoo`8001aoo`03001F^eJk00MF^`03
001FfeKK009Ff`8000IJo0030016gTKN00I6gP03001>oDkm00I>o@<000]KG@<000UBN@04001:NdYk
BW/40008BMH00`00BKA9]005BK@00`00BK=9/`07BK<00`00BK=9/`07BK<00`00CMA=e007CM@2000:
HWD00`00MaAg5003Ma@00`00Ni5kT@03Ni4D0003D]`00`00E[]F^`06E[/00`00E[/00003F]/20006
Ga`00`00B]e:g@06B]d50008Cch20007Ool00`00Oomoo`0=Ool001Aoo`03001oogoo01aoo`03001F
^eJk00MF^`04001Ff`000009F_`00`00A]i6gP06A]h01000C_e>oDkm10000Tln0P0025]M0P0000=B
=`00DWT02E9i100014Yk00<004WFBMH01DWF00<004VdBK@01DVd00<004VcBK<01dVc00<004VcBK<0
1dVc00<004gDCM@01dgD00<005hd0000269e00<007LDMa@017LD00<007^ANi400W^A0`002CLO1000
2E;L00<005JkE[/01UJk0P0000=Jf`0000002ElL00@004[MB]e:g@@000=>o@03001??Tln00Q??P80
00Ioo`03001oogoo00eoo`004goo00<007ooOol07Goo00<005JkE[/01eJk0P0035[l00<004KNA]h0
0dKN1P0024ln0P000e]M0`00158g00<0059iDWT01E9i10001TYk00<004WFBMH01DWF00<004VdBK@0
1DVd00<004VcBK<01dVc00<004VcBK<01dVc00<004gDCM@01TgD00@005hdGS@000QRM@03001g57LD
00=g5003001kTG^A00=kT@D000<g7`@000=Bg003001Bg5;L00MBg003001F^eJk00MF^`8000aO70<0
00Q>o@03001??Tln00I??P@000Aoo`03001oo`0000ioo`004goo0P007goo00<005JkE[/015Jk0P00
0U[l00<005[lF_`02U[l1@0014KN0P002Tln0`001e8g00<0059iDWT00U9i0`00159i00<004YkBW/0
0dYk00<004WFBMH01DWF00<004VdBK@01TVd00<004VcBK<01TVc00<004VcBK<01dVc00<004gDCM@0
1TgD00@005hdGS@000MRM@03001g57LD00Ag5003001kTG^A009kT@T000MBg003001Bg5;L00QBg003
001F^eJk00=F^`@00003Fa`005lL00QO70800003Ggd004km00U>o@04001??TlnCch40003E]/20004
Ool00`00Oomoo`0=Ool001=oo`03001oogoo01moo`03001F^eJk00<000EJo003001Jo5[l00MJo080
0003Gc`004KN00Q6gP03001??Tln00E??P800003DUT0058g00QB=`@000MBN@03001:NdYk00=:N`03
0019eTWF00E9eP030019]4Vd00I9]0030019/dVc00I9/`030019/dVc00M9/`03001=e4gD00E=e003
001N=5hd009N=003001RMF9e00ARM@03001g57LD00Ag5003001kTG^A009kT@H00003F[T005;L00QB
g003001Bg5;L00MBg003001F^eJk00<000AK7003001K700000IO708000=OO@03001>oDkm00Q>o@@0
00MFf`8001Aoo`004goo00<007ooOol087oo0P002E[l0P001E[l0P0015ll00<004KNA]h01dKN0P00
0Tln0`00159I00<0058gDSL0158g0`002e9i00<004YkBW/00dYk00<004WFBMH01DWF00<004VdBK@0
1DVd00<004VcBK<01TVc00<004VcBK<01dVc00<004gDCM@014gD00<005hdGS@00ehd00<0069eHWD0
169e00<007LDMa@00gLD00<007^ANi400W^A1@000eZi00<005;LD]`025;L00<005;LD]`01E;L1000
25/L0P0015lL0P001Umm00<004kmC_d014km0`0000=Fo000E]/02EKK0P004goo000COol00`00Oomo
o`0QOol00`00F_aJo009F_`00`00F_aJo0020007Gc`00`00A]i6gP06A]h40007DUT01000DSMB=e8g
0`000e8g00<0059iDWT01U9i0P0000=JV@00BW/00dYk00<004WFBMH01DWF00<004VdBK@01DVd00<0
04VcBK<01TVc00<004VcBK<024Vc00<004gDCM@00dgD00<005hdGS@00ehd00<0069eHWD00f9e00<0
07LDMa@017LD00<007^ANi400W^A0`001UZi00<005;LD]`01e;L00@005;LD]aBg0@000=>o@03001K
75/L00MK70800003Ga`0000000QOO@03001>oDkm00@000EFo003001FfeKK00MFf`8001=oo`004goo
0P008goo00<005[lF_`02E[l0P002Ull00@004KNA]i6gP@0009>g@03001BFE9I00MBF@<000IB=`03
001BNE9i00ABN@8000=JV@8000=:N`030019eTWF00E9eP030019]4Vd00E9]0030019/dVc00I9/`03
0019/dVc00Q9/`03001=e4gD009=e003001N=5hd00AN=003001RMF9e00=RM@03001g57LD00Ag5004
001kTG^ANi420009F[T00`00D]aBg005D]`50008C_d00`00FaaK7006Fa`3000:Ggd30009E_`00`00
E]]Ff`08E]/2000BOol001=oo`03001oogoo02=oo`03001Jo5[l00IJo0800003Fcd005ll00UO?0@0
00M>g@03001BFE9I00=BF@@000UB=`04001BNE9iDWT20006FYT20002BW/00`00BMI9eP05BMH00`00
BKA9]005BK@00`00BK=9/`07BK<00`00BK=9/`07BK<00`00CMA=e002CM@00`00GSAN=005GS@00`00
HWERM@02HWD00`00MaAg5003Ma@01@00Ni5kTG^A00002eZi00@005;LD]aBg0@000=>o@03001>oDkm
00M>o@03001K75/L00AK70@00003Eil005mm00EOO@<0009F^`03001Fo5Kl00QFo003001FfeKK00MF
f`03001oo`00015oo`004Woo00<007ooOol09Goo00<005[lF_`00e[l0P0015/m0P001Ull0P000UIi
00<004kMC]d01TkM00@0059IDUUBF@8000=BF@03001B=e8g00MB=`04001BN@000009FYT20002BW/0
0`00BMI9eP04BMH00`00BKA9]005BK@00`00BK=9/`07BK<00`00BK=9/`07BK<01@00CMA=e4gD0000
25hd00D0069eHWERM@0000Ig5005001kTG^ANi40000<F[T30008C_d00`00C_e>o@07C_d00`00FaaK
70030004Eil00`00Eil00002Ggd30006E[/00`00E_aFo007E_`00`00E]]Ff`06E]/4000AOol0019o
o`03001oogoo02Ioo`03001Jo5[l008000QK?@03001O?5ll00<000EFN@03001>gDkM00I>g@<000IB
F@03001B=e8g00MB=`03001JVEZI00YJV@04001:NdYk0006BMH00`00BKA9]005BK@00`00BK=9/`07
BK<00`00BK=9/`07BK<01000CMA=e0002Ehd00D0069eHWERM@0000Ig5006001kTG^A001FN0002UZi
00<006Lk00002Dkm00<004kmC_d01Tkm10001eNO00<005NO00000P002EJk00<005KlE_`025Kl00<0
05KKE]/01@000e;m0P0047oo000BOol3000WOol2000:Fcd30009EWT00`00C]e>g@02C]d40008DUT0
0`00DSMB=`06DSL00`00FWP0000;FYT200000dYk0019eP05BMH00`00BKA9]006BK@00`00BK=9/`06
BK<00`00BK=9/`07BK<01000CMA=e0002Uhd00<0069e00001WLD00L007^ANi5kT@00EWP00008F[T2
0003Ic/00`00C_e>o@07C_d01000C_e>oDkm10000d/o00<005NOEil01ENO0P000UJk00<005JkE[/0
25Jk00<005KlE_`00eKl1`0025;m0`003goo000BOol00`00Oomoo`0XOol20007Fcd20002DUP00`00
EWUFN@08EWT40003C]d00`00DUUBF@06DUT00`00DSMB=`04DSL20002FWP00`00FYUJV@0:FYT30006
BMH00`00BKA9]006BK@00`00BK=9/`06BK<00`00BK=9/`08BK<2000;GS@00`00HWD00006Ma@01000
Ni5kT@000eIh00<005ZiF[T015Zi00<006LkIc/00fLk00<004kmC_d01Tkm1@0024/o0P000UNO0`00
0UJk00<005Jk00002eJk1@001Dkm00<005;mD_d025;m0P003goo0006Ool30003Ool00`00Oomoo`03
Ool00`00Oomoo`0ZOol20002Fcd30004DUP00`00EWUFN@06EWT40006C]d00`00DUUBF@06DUT00`00
DSMB=`02DSL00`00FWQJN003FWP00`00FYUJV@08FYT200000`0B00000006BMH00`00BKA9]005BK@0
0`00BK=9/`06BK<00`00BK=9/`08BK<2000;GS@00`00HWD00006Ma@01000Ni5kT@000eIh00<005Zi
F[T00eZi00<006LkIc/01FLk00@004kmC_e>o@@000=?7P03001;?d/o00Q;?`<000IF^`03001F^`00
00QF^`800003Gc`004km00Q>o@03001BoE;m00MBo@<000ioo`001Woo00<007ooOol00Woo00<007oo
000017oo00<007ooOol0;7oo0P00259H00<005IiEWT00UIi0`0015Ii0P0014kM00<0059IDUT01U9I
00D0058gDSMB=`0000IJN003001JVEZI00IJV@80009W6P0300004P0000I9eP030019]4Vd00E9]003
0019/dVc00I9/`030019/dVc00Q9/`03001N=5hd00]N=003001g57LD00Ag5004001kTG^A0005EWP0
0`00F[UJ^@020009Ic/30008Cah00`00Bcm;?`04Bcl30002E]/00`00E[]F^`04E[/00`00E[/00006
E[/20003Gc`00`00C_e>o@07C_d00`00D_eBo@04D_d30002D_d00`00Oomoo`0<Ool000Moo`07001o
ogooOol007oo00000goo0P00;Woo00<0059HDUP01e9H00<005Ii00000P001EIi0P0000=R^0000000
0`0000=>g@00DUT01e9I0`0025Yh00<005ZIFYT015ZI00<006LJIaX00VLJ00@0000B000000E9eP03
0019]4Vd00E9]0030019/dVc00M9/`030019/dVc00I9/`8000eN=003001g57LD00Ag5004001kTG^A
0005EWP00`00F[T0000:Ic/00`00Io`0000:Cah00`00Bcm;?`030005E]/00`00E[]F^`05E[/00`00
E[/00003E[/20006Gc`00`00C_e>o@07C_d00`00D_eBo@030005D_d2000=Ool000Moo`07001oogoo
Ool007oo00000goo00<007ooOol0;Woo00<0059HDUP01E9H0`001eIi00<006:hH[P00V:h00@001Gm
5OdEo@/000YJN003001JVEZI00=JV@03001W6VLJ00AW6P8000036AH004WF00=9eP030019]4Vd00E9
]0030019/dVc00M9/`030019/dVc00E9/`03001Em00000eN=08000Eg5003001kT@0000MFN003001W
>fLk00QW>`05001Wo6OlIo`00008Cah40009E]/00`00E[]F^`05E[/200000eJk00000009Gc`00`00
C_e>o@05C_d40009D_d2000<Ool000Ioo`03001oo`00009oo`03001oo`0000=oo`03001oogoo02io
o`03001BF59H009BF0<0009BF003001FNEIi00=FN@8000IR^005000EoAGm5Od00008AUX00`00FWQJ
N009FWP00`00FYUJV@020007IaX01@00018001TF00000dWF00<004VdBK@01DVd00<004VcBK<01dVc
00<004VcBK<01DVc00@005GdEO@000]N=004001g5GLE0003Ma@00`00Ni400007EWP00`00Ie/00008
Ic/00`00IoaWo003Io`01000Cai?7TlN10000eKL00<005KKE]/01eKK00<005JkE[/01UJk0P002ell
00@004kmC_e>o@@000=Bo@03001BoE;m00MBo@8000aoo`001goo00<007ooOol00Woo00<007ooOol0
0Woo00<007ooOol0;goo10001U9H00D005IiEWUFN@0000UR^005000EoAGm5Od00008AUX00`00FWQJ
N008FWP00`00FYT00009IaX00`00018000026AH01000BMI9eP0024Vd00<004VcBK<01TVc00<004Vc
BK<014Vc00D005GdEOAEm00000]N=004001g5GLE0003Ma@30006EWP01@00Ie]WFfMK00001FLk0P00
1VOl10001eKL00<005KKE]/025KK00<005JkE[/00eJk0`0000=K?@00Gc`02Ell10001e;m00<005;m
D_d01U;m10002goo000AOol2000^Ool30009DUP01000EWT000002f:h00@001Gm5Od000Q6FP03001J
N5Yh00UJN003001W6VLJ00QW6P<0008I5P040019eTWF0008BK@00`00BK=9/`06BK<00`00BK=9/`03
BK<00`00EOAEm002EO@00`00GSAN=008GS@00`00MaEg5@02MaD00`00MaAg50020006EWP00`00Ie]W
F`03Ie/01@00Ic]W>fLk00001VOl0P000UJI00<005KLE]`01eKL00<005KKE]/01eKK00<005JkE[/0
0`000e/m00<005/m00001Ull0`000U/M00<005;mD_d01e;m00@005;mD_eBo@@000=Bg08000Yoo`00
4Goo00<007ooOol0:goo0P000goo00<0059HDUP01e9H00<006:hH[P02V:h00<006/I00000QGm00<0
04IJAUX01DIJ00<005YhFWP025Yh00<006LJ000026LJ00@006^l000000<I5P040019eTWF0007BK@0
0`00BK=9/`06BK<00`00BK=9/`02BK<00`00EOAEm003EO@00`00GSAN=008GS@00`00MaEg5@03MaD5
0003EWP20007Ie/00`00Ic/00004Io`30004EYT00`00E]aFg008E]`00`00E]]Ff`05E]/40007Fcd0
0`00Fcd00002Gc`30005Fad00`00D_eBo@06D_d50007D]`2000:Ool0011oo`03001oogoo02Uoo`<0
00Eoo`03001BF59H00EBF0800003FYP006:h00UR^007001[6F/IJaT001Gm000024IJ00<005YhFWP0
1UYh00D006LJIaYW6P0000IW6P06001[_6^l00004P000aTF00<004WF00001dVd00<004VcBK<01TVc
00D004VcBK=9/`0000IEm003001N=5hd00QN=003001g5GLE00Ag5@800005EUL005IhEWP0000:Ie/6
0008EYT00`00E]aFg007E]`01000E]]FfeKK10000dkn00<005/mFcd01E/m00<005/m00000P002E/M
00@005;mD_eBo@@000=Bo@03001Bg5;L00MBg08000Uoo`0047oo00<007ooOol09Woo0`002Goo00<0
059HDUP00e9H00D005ZHFYQJV00000UR^003001[6F/I00=[6@03000Eo@0000M6FP03001JN5Yh00EJ
N003001W6VLJ00=W6P04001W6VLJIaX20004Jk`200046AH20007BK@00`00BK=9/`07BK<00`00BK<0
0008EO@00`00GSAN=006GS@00`00MaEg5@05MaD20002EUL20009Ie/500000e9H001FV@09EYT00`00
E]aFg005E]`50007C_h00`00FceK?@04Fcd30002Ead00`00FaeK7@07Fad40007D_d00`00D]aBg008
D]`00`00Oomoo`07Ool0011oo`8002Aoo`<000aoo`04001BF59HDUP20005FYP00`00H[QR^005H[P0
0`00JaU[6@05JaT20008AUX00`00FWQJN002FWP20007IaX00`00IaX00006Jk`200056AH00`00BKA9
]005BK@00`00BK=9/`07BK<00`00BK<00008EO@00`00GSAN=006GS@00`00MaEg5@04MaD20003EUL0
0`00Ie]WF`07Ie/30005DUP00`00EYUFV@07EYT01000E]aFg5KL10000e;m00<004knC_h01dkn00<0
05/mFcd00`000eLM00<005LM00001e/M0P000UKK00<005;mD_d01e;m00<005;LD]`01e;L00<007oo
Ool01goo000@Ool00`00Oomoo`0POol3000@Ool30007FYP00`00H[QR^004H[P00`00JaU[6@07JaT2
0007AUX01@00FWQJN5Yh00002VLJ0`000f^l0P0000=Og@006AH011TF0`001DVd00<004VcBK<01dVc
0P002EGd00<005hdGS@01Uhd00<007LEMaD017LE0P0000EFE`00001SG00000IWF`8000QBF003001F
VEJI00QFV@<000MBo@03001>oTkn00I>oP@000MG7@03001G7@0000AK7@8000EFf`03001BoE;m00MB
o@03001Bg5;L00EBg0<000Qoo`0047oo00<007ooOol07Goo0`004goo00<005ZHFYP025ZH00<006:h
H[P00f:h00<006/IJaT01V/I00<006mj00001dIJ00@005YhFWP000YW6P04001[nf_kJo/500000eoM
000000046AH00`00>GDiM@020004BK@00`00BK=9/`05BK<2000:EO@00`00GSAN=005GS@00`00MaEg
5@04MaD200000eIG001SG003He`00`00Ie]WF`02Ie/2000:DUP00`00EYUFV@06EYT00`00Ie`00009
D_d01000C_i>oTkn10000e<M00<005LMEad01ELM00<005LM00000U/M0P001eKK00<005;mD_d01e;m
00@005;LD]aBg0@0009oo`03001oogoo00Ioo`0047oo00<007ooOol06Woo0`005Woo00<005ZHFYP0
25ZH00<006:hH[P00V:h00<006/IJaT01V/I00@006mjKgY_NP@000A6FP8000YW6P03001[nf_k00=[
n`04001;^4^hBkP300056AH01000>GDiMCUe0P000TVd00<004VcBK<00TVc0`0000=9]000EO@02EGd
00<005hdGS@01Ehd00<007LEMaD017LE0`001V=L00@006MK0000009B=`03001BF59H00MBF003001F
VEJI00AFV@8000=WG003001BoE;m00IBo@@000QC7@03001G7ELM00EG7@@000YFf`03001BoE;m00=B
o@L000Ioo`03001oogoo00Ioo`0047oo0P0067oo0`006Woo00<005ZHFYP025ZH00@006:hH[P000Q[
6@03001_NVmj00=_NP03000ZORYn00D000YW6P03001[nf_k009[n`8000=;^0800003E[/001TF00@I
5P03000iMCUe00<iM@<00004BK<000000004BK@00`00EOAEm009EO@00`00GSAN=003GS@00`00MaEg
5@05MaD00`00HeaSG007He`00`00DSMB=`02DSL00`00DUQBF008DUP00`00EYUFV@02EYT00`00IeaW
G003Ie`00`00D_eBo@04D_d20002D_d00`00DaeC7@07Dad00`00EaeG7@04Ead300000eKK001Ff`09
E]/6000=Ool00`00Oomoo`06Ool000moo`03001oogoo01Eoo`<001eoo`03001JV5ZH00QJV003001R
^00000Q[6@03001_NVmj00E_NP03000ZORYn00@ZOP03001W6VLJ00IW6P03001[nf_k009[n`03001;
^4^h00<000=F^`03000I5QTF00<I5P03000iMCUe00DiM@8000M9]003001Em5Gd00UEm003001N=5hd
00=N=003001g5GLE00Ag5@8000MSG08000EB=`03001BF59H00QBF005001FVEJIEYT00007Ie`00`00
D_eBo@030005D_d00`00DaeC7@07Dad00`00EaeG7@030003E]/00`00E]/00007E]/2000COol00`00
Oomoo`06Ool000moo`03001oogoo019oo`<0025oo`03001JV5ZH00QJV003001[6F/I00M[6@03001_
NVmj00I_NP8000DZOP03001W6VLJ00AW6P03001[nf_k009[n`@000MF^`03000I5QTF008I5P03000i
MCUe00DiM@030019]4Vd00M9]003001Em5Gd00QEm003001N=5hd00=N=003001g5GLE00Ag5@03001S
G6=L00ESG003001B=e8g00IB=`03001BF59H00QBF0<000UWG08000QBo@03001C7E<M00IC7@@000IF
f`03001Ff`0000EFf`8001Eoo`03001oogoo00Ioo`003goo00<007oo00003goo0`0097oo00<005ZH
FYP01eZH00@006<J000000I[6@03001_NVmj00I_NP04001[_0000005:Wh20003IaX01000Jo][nf_k
0`000U;K00<005JkE[/01EJk00<001TF6AH00QTF00<003Ue>GD01CUe00<004VdBK@01dVd00<005Gd
EO@025Gd00<005hdGS@00Uhd00<007LEMaD017LE0P001F=L0`00258g00<0059HDUP0259H00<006ML
Ie`01fML0P0000=SG000D_d025;m00@005<MDaeC7@@0009Bg003001FfeKK00IFf`03001Ff`00009F
f`8001Moo`03001oogoo00Ioo`003goo0P003Woo0P00:7oo00<005ZHFYP015ZH0P0016<J00<006/I
JaT00V/I00<006mjKgX01Fmj0P000f^l1@000bYn00@006LJ001[n`@000EBf`03001F^eJk00AF^`03
000I5QTF00<I5P03000iMCUe00@iM@030019]4Vd00M9]003001Em5Gd00QEm003001N=5hd009N=003
001g5GLE00Ag5@05001C?P00001SG0020002DSL00`00DSMB=`06DSL00`00DUQBF006DUP200000fNM
001WG005Ie`20004He`00`00D_eBo@06D_d40007D]`00`00E]]Ff`06E]/4000IOol00`00Oomoo`06
Ool000=oo`8000Aoo`03001oogoo00=oo`03001oogoo00Yoo`<002Yoo`03001JV5ZH00=JV003001S
6V<J00ES6P800003JaT006mj00I_NP03001[_6^l00E[_0030009o0Wl00P000QBf`03001F^eJk00EF
^`03000I5QTF008I5P03000iMCUe00DiM@030019]4Vd00I9]003001Em5Gd00UEm005001N=5hdGS@0
0006MaD00`00DciC?P020005DSL00`00DSMB=`06DSL00`00DUQBF004DUP00`00IieWW@02Iid20002
Ie`20007He`01000D_eBoE;m10000U;L00<005;LD]`01U;L00<005KKE]/01EKK0`0077oo00<007oo
Ool01Goo0005Ool01P00Oomoo`00Ool000Aoo`03001oogoo00Moo`<002ioo`05001JV5ZHFYP0000:
HaX20006KgX00`00Jka[_006Jk`40007C_d00`00D]]Bf`06D]/00`00E[]F^`04E[/00`006AHI5P02
6AH00`00>GDiM@05>GD00`00BKA9]006BK@00`00EOAEm009EO@01000GSAN=0001WLE10001e8g00<0
058gDSL01U8g00<0059HDUP00U9H0P001fNM0P002F=L10001e;L00<005;LD]`01U;L00<005KKE]/0
0UKK0P000Woo00<007ooOol06Woo00<007ooOol01Goo0004Ool01`00Oomoogoo001oo`0000=oo`03
001oogoo00Eoo`<0035oo`04001JV000000:HaX00`00ImeWg@020002KgX20007Jk`20002E]/00`00
C_e>o@06C_d00`00D]]Bf`07D]/00`00E[]F^`0300000e/L000I5P026AH00`00>GDiM@05>GD00`00
BKA9]006BK@00`00EOAEm009EO@01000GSAN=0001WLE00<0059H0000258g00<0058gDSL01U8g00D0
059HDUQBF00000MWW@800003Hgd006=L00ISG080009J^P03001Bg5;L00IBg003001Bg5;L00IBg003
001FfeKK008000Eoo`03001oogoo01Uoo`03001oogoo00Eoo`001Goo00H007ooOol007oo0003Ool2
0003Ool3000eOol00`00HaYS6P09HaX00`00ImeWg@03Imd40004Jk`30005E]/00`00C_e>o@06C_d0
0`00D]]Bf`06D]/30004Fa`01@006AHI5QTF00001cUe00<004VdBK@01dVd00<005GdEO@025Gd00<0
05hd00001gLE00<0059H0000258g00<0058gDSL01e8g0`001VNM0P000f=m00<006=LHe`00f=L0P00
15Zj00<005;LD]`01e;L00<005;LD]`00e;L1@0027oo00<007ooOol067oo00<007ooOol01Goo0003
Ool00`00Ool00002Ool00`00Ool00003Ool00`00Ool00002000iOol00`00HaYS6P07HaX00`00ImeW
g@03Imd20003Dm`40009E]/00`00C_e>o@06C_d01000D]]Bfe;K10000Tkm00<005/LFa`00e/L00D0
01TF6AHI5P0000HiM@030019]4Vd00M9]003001Em5Gd00QEm003001N=00000Ig5@04001BF59H0009
DSL00`00DSMB=`06DSL00`00IieWW@04Iid20006Hgd00`00HeaSG0020007F[X00`00D]aBg005D]`7
000=Ool00`00Oomoo`0HOol00`00Oomoo`05Ool000Aoo`03001oogoo009oo`03001oogoo009oo`80
03eoo`03001S6V<J00AS6P8000EWg@03001Cg5?L009Cg080009Ff`03001FfeKK00QFf`03001>oDkm
00=>o@H000M>o@03001K75/L009K7005000I5QTF6AH00006>GD00`00BKA9]007BK@00`00EOAEm009
EO@20006MaD01@00DUQBF59H0000258g00<0058gDSL0158g0P0000=O_P0000000VNM0P002F=m0P00
2EZj00@005;LD]aBg0@001Eoo`03001oogoo01Moo`03001oogoo00Eoo`003goo00<007ooOol0?7oo
0P000f<J00<006OMImd00fOM0P000e?L0P001EKK00<005KKE]/025KK1@0014KN00<004kmC_d01Tkm
00<005/LFa`00e/L00@001TF6AH000LiM@030019]4Vd00I9]003001Em5Gd00UEm003001g5GLE00Ag
5@03001BF59H009BF003001B=e8g00IB=`03001B=e8g009B=`8000EO_P8000USO@800003EYT005Zj
00UJ^P<001Yoo`03001oogoo01Moo`03001oogoo00Aoo`0047oo0P00?Woo00<006<J000016OM0P00
00=Cg00000000P001eKK00<005KKE]/01UKK0P0000=O7000A]h01dKN00<004kmC_d01Tkm00<005/L
Fa`00`000QTF00<003Ue>GD01CUe00<004VdBK@01TVd00<005GdEO@02EGd00<007LEMaD017LE00<0
059HDUP00U9H00<0058gDSL01e8g00@0058g000000IO_P800003Fih006=m00ESO@8000=FV@03001J
^UZj00MJ^P03001oogoo01aoo`03001oogoo01Ioo`03001oogoo00Aoo`004Woo00<007ooOol0?7oo
2@000goo00<005KKE]/01UKK00<005KKE]/00eKK0P0015lL0P001dKN00<004kmC_d00dkm1@000e^N
00<001TF00001cUe00<004VdBK@01TVd00<005GdEO@025Gd00<007<g00001GLE00<0059HDUP00e9H
00<0058gDSL01E8g0`001Unn0P0015^N0P000V=m0P001UJI00<005ZjF[X015Zj0P007goo00<007oo
Ool05Woo00<007ooOol017oo000COol00`00Oomoo`17Ool00`00E]]Ff`07E]/00`00E]]Ff`020008
Ga`00`00A]i6gP02A]h80005Bcl200001E^N000I5QTF00001SUe00<004VdBK@01dVd00<005GdEO@0
1eGd00@007<gLcL000=g5@03001BF59H00ABF003001B=e8g00=B=`80009?W`8000=O_P8000MKWP<0
00QFV@03001J^UZj00=J^P03001oogoo021oo`03001oogoo01Eoo`03001oogoo00Aoo`0057oo00<0
07ooOol0Agoo00<005KKE]/01UKK0`002elL100014KN0P002D/o0`0000<I5P00>GD01CUe00<004Vd
BK@01dVd00<005GdEO@01UGd00<007<gLcL00W<g00@007LEMaD000MBF003001B=`00008000I?W`<0
00MKWP800003EWP005JI00UFV@05001J^UZjF[X0000TOol00`00Oomoo`0DOol00`00Oomoo`04Ool0
01Eoo`03001oogoo04Moo`03001FfeKK00=Ff`80009K7003001O75lL00MO70800003Ged004KN00M6
gP8000=;?`@0009F^`03000I5P0000HiM@030019]4Vd00M9]003001Em5Gd00IEm003001c=g<g00=c
=``000E?W`@0009?O`8000=KWP<000AFN003001FVEJI00MFV@04001J^P00000VOol00`00Oomoo`0C
Ool00`00Oomoo`04Ool001Ioo`8004Moo`03001FfeKK00<000EK708000EO708000AOG@030016gTKN
00I6gP@000IF^`<000LiM@030019]4Vd00I9]003001Em5Gd00EEm003001c=g<g00Ec=`8000Tk?`D0
00Q?O`<000MFN003001FVEJI00QFV@03001oogoo02Ioo`03001oogoo01=oo`03001oogoo00Aoo`00
67oo00<007ooOol0AGoo0P002U/L00<005lLGa`00P001UmM00<004KNA]h014KN0P000UKl00<005Jk
E[/01UJk0P001cUe00<004VdBK@01TVd00<005GdEO@01EGd00<007<gLcL017<g00<003;O<]l00P00
0c/o10000dLo0P0014mo100000=BN@00EWP025Ih00<005JIEYT01EJI0P00:Woo00<007ooOol04goo
00<007ooOol00goo000IOol00`00Oomoo`15Ool00`00FaaK7008Fa`30009Ged00`00A]i6gP030005
E_`00`00E[]F^`06E[/20006>GD00`00BKA9]006BK@00`00EOAEm004EO@00`00LcMc=`05LcL80009
Acl40006DWT00`00EWQFN006EWP00`00EYUFV@04EYT00`00Oomoo`0[Ool00`00Oomoo`0BOol00`00
Oomoo`03Ool001Yoo`03001oogoo04Eoo`8000IK7080009KOP8000QOG@<000QFo003001F^eJk00IF
^`8000HiM@030019]4Vd00M9]003001Em5Gd009Em003001c=g<g00Ec=`030012od;o00E2o`8000A7
?`@00003DWT0059i00MBN@03001FN5Ih00MFN004001FVEJIEYT2000^Ool00`00Oomoo`0BOol00`00
Oomoo`03Ool001]oo`8004Moo`03001K75/L00<000IKOP80009OG@@0009Ff`03001Fo5Kl00MFo003
001F^eJk00EF^`8000HiM@030019]4Vd00M9]003001Em5Gd009Em003001c=g<g00Ec=`<000E2o`H0
00IBN@03001BNE9i00IBN@03001FN5Ih00IFN004001FV@00000aOol00`00Oomoo`0AOol00`00Oomo
o`03Ool001eoo`03001oogoo04Eoo`8000YKOP<000MFf`8000QFo003001F^eJk00@0009?7P03000i
MCUe00<iM@030019]4Vd00M9]005001Em5GdEO@00007LcL00`00A]i6gP060003CY/00`00DWUBN@06
DWT00`00DWUBN@06DWT00`00EWQFN007EWP00`00Oomoo`0bOol00`00Oomoo`0@Ool00`00Oomoo`03
Ool001ioo`03001oogoo04Eoo`8000MKOP80009F^`03001FfeKK00MFf`03001Fo5Kl00=Fo0D000M?
7P03000iMCUe00<iM@030019]4Vd00I9]005001Em5GdEO@00007LcL30002C]d00`00CY]>V`05CY/0
0`00DWUBN@06DWT00`00DWUBN@06DWT00`00EWQFN004EWP2000fOol00`00Oomoo`0?Ool00`00Oomo
o`03Ool001moo`03001oogoo04Ioo`80009KOP<000AF^`03001FfeKK00QFf`D000A:gP03001?7TlN
00I?7P03000iMCUe008iM@030019]4Vd00I9]004001Em5Gd0007LcL00`00C]e>g@03C]d00`00CY]>
V`05CY/00`00DWUBN@06DWT00`00DWUBN@06DWT00`00EWQFN002EWP2000hOol00`00Oomoo`0?Ool0
0`00Oomoo`03Ool0021oo`8004Qoo`8000QF^`03001FfeKK00EFf`800003Fa`004[N00M:gP03001?
7TlN00I?7P05000iMCUe>GD00008BK@01000EOAEm0001W<g00<004kMC]d01DkM00<004jKCY/01DjK
00<0059iDWT01E9i00<0059iDWT01e9i00@005Ih000003]oo`03001oogoo00moo`03001oogoo009o
o`008Woo00<007ooOol0AWoo00<005JkE[/01eJk00<005KKE]/00UKK0P0015/L00<004[NB]h01T[N
00@004lNCai?7PD000<iM@030019]4Vd00M9]08000Mc=`03001>gDkM00E>g@03001>VdjK00E>V`03
001BNE9i00IBN@03001BNE9i00EBN@<003ioo`03001oogoo00ioo`03001oogoo009oo`008goo00<0
07ooOol0AWoo00<005JkE[/01UJk00<005KKE]/00P001e/L00<004[NB]h00d[N1P001E<M00@003Ue
>GD000U9]08000Ic=`03001Fg00000M>g@03001>VdjK00E>V`03001BNE9i00EBN@03001BNE9i00=B
N@80049oo`03001oogoo00eoo`03001oogoo009oo`0097oo00<007ooOol0AWoo00<005JkE[/01EJk
0`002E/L1P0014km00<005<MDad01E<M00<003Ue000024Vd0P001g<g00<005KL000010000dkM00<0
04jKCY/01DjK00<0059iDWT01U9i00<0059i00000P00A7oo00<007ooOol03Goo00<007ooOol00Woo
000UOol00`00Oomoo`16Ool00`00E[]F^`040002Fad20006Fa`20002Fa`00`00C_e>o@06C_d00`00
DaeC7@05Dad00`00>GD00004BK@30002Dad00`00LcMc=`03LcL30005OolF0018Ool00`00Oomoo`0<
Ool00`00Oomoo`02Ool002Ioo`8004Moo`8000QK7@80009K708000EK7003001>oDkm00I>o@04001C
7E<MDad6000014Vd000000001U<M00<007<gLcL00W<g00<007ooOol0I7oo00<007ooOol02goo00<0
07ooOol00Woo000XOol00`00Oomoo`15Ool00`00FaeK7@07Fad30008Fa`00`00C_e>o@05C_d40005
D]`2000:Dad01000LcMc=`00Igoo00<007ooOol02goo00<007ooOol00Woo000YOol00`00Oomoo`15
Ool00`00FaeK7@04Fad20002Ead00`00FaaK7007Fa`00`00C_e>o@040002D_d00`00D]aBg005D]`0
0`00DaeC7@09Dad00`00LcL0001XOol00`00Oomoo`0;Ool00`00Oomoo`01Ool002Yoo`03001oogoo
04Eoo`03001K7E/M00<000EG7@03001K75/L00IK70<000MBo@03001Bg5;L00EBg003001C7E<M00QC
7@8006Yoo`03001oogoo00Yoo`03001oogoo005oo`00:goo0P00AWoo0P002ELM00@005/LFaaK70@0
009Fg003001BoE;m00IBo@03001Bg5;L00EBg003001C7E<M00AC7@<006eoo`03001oogoo00Uoo`03
001oogoo005oo`00;Goo00<007ooOol0A7oo00<005LMEad01eLM10001eKL00<005;mD_d01U;m00<0
05;LD]`0100000Aoo`00DaeC7@<0071oo`03001oogoo00Uoo`03001oogoo005oo`00;Woo00<007oo
Ool0A7oo0P001ELM0P000UKK00<005KLE]`01eKL00<005;mD_d00e;m1@001Woo0P00M7oo00<007oo
Ool027oo00<007ooOol00Goo000_Ool00`00Oomoo`15Ool00`00EaeG7@020005E]/00`00E]aFg006
E]`60022Ool00`00Oomoo`07Ool00`00Oomoo`01Ool0031oo`03001oogoo04Eoo`8000QFf`03001F
g5KL00=Fg08008Uoo`03001oogoo00Ioo`03001oogoo005oo`00<Goo0P00AWoo00<005KKE]/01eKK
00<005KLE]`00P00Rgoo00<007ooOol01goo0@000Goo0Goo000cOol00`00Oomoo`14Ool00`00E]]F
f`06E]/3002>Ool00`00Oomoo`06Ool10001Ool1Ool003Aoo`03001oogoo04=oo`03001FfeKK00AF
f`80099oo`03001oogoo00Eoo`40005oo`5oo`00=Goo00<007ooOol0@goo00<005KKE]/00`00UGoo
00<007ooOol017oo0@000Goo0Goo000fOol20014Ool2002HOol00`00Oomoo`04Ool10001Ool1Ool0
03Qoo`03001oogoo045oo`03001oogoo09Qoo`03001oogoo00=oo`40005oo`5oo`00>Goo00<007oo
Ool0@7oo00<007ooOol0VGoo00<007ooOol00goo0@000Goo000jOol00`00Oomoo`0oOol00`00Oomo
o`2IOol00`00Oomoo`03Ool10001Ool003]oo`8003moo`03001oogoo09Yoo`03001oogoo009oo`40
005oo`00?Goo00<007ooOol0?7oo00<007ooOol0Vgoo00D007ooOomoo`00005oo`00?Woo00<007oo
Ool0>goo00<007ooOol0W7oo00@007ooOol0005oo`00?goo00<007ooOol0>Woo00<007ooOol0W7oo
00@007ooOol0005oo`00@7oo00<007ooOol0>Goo00<007ooOol0WGoo00<007oo00000Goo0011Ool2
000iOol00`00Oomoo`2NOol10001Ool1000004=oo`03001oogoo03Ioo`03001oogoo09moo`800000
A7oo00<007ooOol0=Goo00<007ooOol0Wgoo0P000015Ool00`00Oomoo`0cOol00`00Oomoo`2POol2
000004Ioo`8003=oo`03001oogoo09aoo`@0009oo`00B7oo00<007ooOol0<7oo00<007ooOol0V7oo
10001Woo0019Ool00`00Oomoo`0_Ool00`00Oomoo`2DOol4000:Ool004Yoo`03001oogoo02ioo`03
001oogoo091oo`@000ioo`00Bgoo00<007ooOol0;Goo00<007ooOol0S7oo10004Woo001<Ool2000]
Ool00`00Oomoo`29Ool3000FOol004ioo`03001oogoo02Yoo`03001oogoo08Eoo`@001Uoo`00Cgoo
00<007ooOol0:Goo00<007ooOol0PGoo10007Goo001@Ool00`00Oomoo`0XOol00`00Oomoo`1mOol4
000QOol0055oo`8002Qoo`03001oogoo07Uoo`@002Eoo`00Dgoo00<007ooOol09Goo00<007ooOol0
MGoo1000:Goo001DOol00`00Oomoo`0TOol00`00Oomoo`1bOol3000]Ool005Eoo`03001oogoo02=o
o`03001oogoo06ioo`@0031oo`00EWoo0P008goo00<007ooOol0JWoo1000=7oo001HOol00`00Oomo
o`0POol00`00Oomoo`1VOol4000hOol005Uoo`03001oogoo01moo`03001oogoo069oo`@003aoo`00
FWoo00<007ooOol07Woo00<007ooOol0GWoo1000@7oo001KOol00`00Oomoo`0MOol00`00Oomoo`1K
Ool30014Ool005aoo`8001eoo`03001oogoo05Moo`@004Moo`00GWoo00<007ooOol06Woo00<007oo
Ool0Dgoo1000Bgoo001OOol00`00Oomoo`0IOol00`00Oomoo`1?Ool4001?Ool0061oo`03001oogoo
01Qoo`03001oogoo04]oo`@005=oo`00HGoo0P0067oo00<007ooOol0Agoo1000Egoo001SOol00`00
Oomoo`0EOol00`00Oomoo`13Ool4001KOol006Aoo`03001oogoo01Aoo`03001oogoo041oo`<005mo
o`00IGoo00<007ooOol04goo00<007ooOol0?7oo1000HWoo001VOol00`00Oomoo`0BOol00`00Oomo
o`0hOol4001VOol006Moo`80019oo`03001oogoo03Aoo`@006Yoo`00JGoo00<007ooOol03Woo00<0
07ooOol0<Goo1000KWoo001ZOol00`00Oomoo`0=Ool00`00Oomoo`0]Ool4001bOol006]oo`03001o
ogoo00aoo`03001oogoo02Yoo`<007Ioo`00K7oo0P0037oo00<007ooOol09Woo1000NGoo001^Ool0
0`00Oomoo`09Ool00`00Oomoo`0ROol4001mOol006moo`03001oogoo00Qoo`03001oogoo01ioo`@0
085oo`00L7oo00<007ooOol01goo00<007ooOol06Woo1000QGoo001aOol20007Ool00`00Oomoo`0F
Ool40029Ool007=oo`03001oogoo00Aoo`03001oogoo01=oo`<008eoo`00M7oo00<007ooOol00goo
00<007ooOol03goo1000T7oo001eOol00`00Oomoo`02Ool00`00Oomoo`0;Ool4002DOol007Ioo`05
001oogooOol00009Ool4002HOol007Moo`800003Ool007oo00Aoo`@009aoo`00NGoo0P0000=oo`00
00000P00X7oo001jOol2002TOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo
0000\
\>"],
  ImageRangeCache->{{{0, 287}, {232.563, 0}} -> {-0.0503512, 0.0447239, 
  0.00349458, 0.00349458}}]
}, Open  ]],

Cell["\<\
As  a more complex example, consider the problem of determining the impulse \
response of the ideal circular lowpass filter given by\
\>", "Text"],

Cell[TextData[Cell[BoxData[
    FormBox[
      RowBox[{\(H(\[Omega]\_1, \ \[Omega]\_2)\), " ", "=", " ", 
        RowBox[{"{", GridBox[{
              {\(1, \), 
                \(\[Omega]\_1\  + \ \[Omega]\_2\  \[LessEqual] R\^2 
                  \[LessEqual] \[Pi]\^2\)},
              {\(0, \), "otherwise"}
              }]}]}], TraditionalForm]]]], "NumberedEquation"],

Cell["***NOT FINISHED ***", "Text"]
},
FrontEndVersion->"Microsoft Windows 3.0",
ScreenRectangle->{{0, 1280}, {0, 968}},
AutoGeneratedPackage->Automatic,
WindowToolbars->"EditBar",
CellGrouping->Manual,
WindowSize->{551, 712},
WindowMargins->{{Automatic, 336}, {Automatic, 9}},
PrintingCopies->1,
PrintingPageRange->{Automatic, Automatic},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, -1}},
ShowCellLabel->True,
ShowCellTags->False,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False},
StyleDefinitions -> "ArticleClassic.nb"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1709, 49, 155, 4, 111, "Title",
  Evaluatable->False],
Cell[1867, 55, 76, 2, 31, "Input"],
Cell[1946, 59, 71, 2, 31, "Input"],

Cell[CellGroupData[{
Cell[2042, 65, 123, 3, 56, "Section",
  Evaluatable->False],
Cell[2168, 70, 486, 10, 78, "Text",
  Evaluatable->False],
Cell[2657, 82, 1393, 28, 138, "Text",
  Evaluatable->False],
Cell[4053, 112, 315, 7, 61, "Text",
  Evaluatable->False]
}, Open  ]],

Cell[CellGroupData[{
Cell[4405, 124, 148, 4, 56, "Section",
  Evaluatable->False],
Cell[4556, 130, 548, 19, 43, "Text",
  Evaluatable->False],
Cell[5107, 151, 240, 6, 29, "NumberedEquation"],
Cell[5350, 159, 1018, 33, 94, "Text",
  Evaluatable->False],
Cell[6371, 194, 495, 9, 29, "NumberedEquation"],
Cell[6869, 205, 690, 21, 61, "Text"],
Cell[7562, 228, 255, 6, 40, "NumberedEquation"],
Cell[7820, 236, 51, 0, 27, "Text"],
Cell[7874, 238, 289, 9, 67, "Input"],

Cell[CellGroupData[{
Cell[8188, 251, 203, 5, 87, "Input"],
Cell[8394, 258, 14991, 460, 186, 4232, 321, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],
Cell[23400, 721, 181, 4, 27, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[23606, 729, 212, 5, 50, "Input"],
Cell[23821, 736, 110, 2, 45, "Output"]
}, Open  ]],
Cell[23946, 741, 234, 8, 31, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[24205, 753, 403, 8, 98, "Input"],
Cell[24611, 763, 25265, 813, 186, 8751, 603, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],
Cell[49891, 1579, 870, 19, 112, "Text"],

Cell[CellGroupData[{
Cell[50786, 1602, 205, 4, 52, "Input"],
Cell[50994, 1608, 246, 4, 47, "Output"]
}, Open  ]],
Cell[51255, 1615, 268, 8, 44, "Text"],

Cell[CellGroupData[{
Cell[51548, 1627, 585, 12, 113, "Input"],
Cell[52136, 1641, 25644, 856, 186, 9854, 656, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],
Cell[77795, 2500, 1100, 26, 211, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[78920, 2530, 101, 3, 31, "Input"],
Cell[79024, 2535, 88, 2, 30, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[79161, 2543, 75, 2, 31, "Input"],
Cell[79239, 2547, 79, 2, 30, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[79355, 2554, 133, 3, 56, "Section",
  Evaluatable->False],
Cell[79491, 2559, 677, 18, 77, "Text",
  Evaluatable->False],
Cell[80171, 2579, 272, 6, 31, "NumberedEquation"],
Cell[80446, 2587, 282, 8, 44, "Text",
  Evaluatable->False],
Cell[80731, 2597, 312, 7, 40, "NumberedEquation"],
Cell[81046, 2606, 257, 8, 44, "Text"],

Cell[CellGroupData[{
Cell[81328, 2618, 236, 5, 43, "Input"],
Cell[81567, 2625, 82, 2, 43, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[81686, 2632, 240, 5, 87, "Input"],
Cell[81929, 2639, 21556, 718, 186, 6570, 528, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],
Cell[103500, 3360, 212, 8, 27, "Text"]
}, Open  ]],
Cell[103727, 3371, 39, 0, 56, "Section"],
Cell[103769, 3373, 157, 3, 44, "Text"],
Cell[103929, 3378, 393, 8, 32, "NumberedEquation"],
Cell[104325, 3388, 474, 10, 31, "NumberedEquation"],
Cell[104802, 3400, 717, 19, 78, "Text"],
Cell[105522, 3421, 348, 7, 40, "NumberedEquation"],
Cell[105873, 3430, 51, 0, 27, "Text"],

Cell[CellGroupData[{
Cell[105949, 3434, 242, 5, 65, "Input"],
Cell[106194, 3441, 1859, 30, 125, "Output"]
}, Open  ]],
Cell[108068, 3474, 466, 13, 44, "Text"],

Cell[CellGroupData[{
Cell[108559, 3491, 218, 4, 51, "Input"],
Cell[108780, 3497, 79312, 1627, 242, 33104, 1051, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],
Cell[188107, 5127, 156, 3, 44, "Text"],
Cell[188266, 5132, 374, 8, 43, "NumberedEquation"],
Cell[188643, 5142, 35, 0, 27, "Text"]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

