(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    106084,       3287]*)
(*NotebookOutlinePosition[    106996,       3318]*)
(*  CellTagsIndexPosition[    106952,       3314]*)
(*WindowFrame->Normal*)



Notebook[{
Cell["FREQUENCY SAMPLING", "Title",
  Evaluatable->False,
  CellHorizontalScrolling->False,
  TextAlignment->Center,
  AspectRatioFixed->True],

Cell[BoxData[
    \(<< ImageProcessing`\)], "Input",
  CellLabel->"In[1]:="],

Cell[BoxData[
    \(<< SignalPlot`\)], "Input",
  CellLabel->"In[2]:="],

Cell[CellGroupData[{

Cell["INTRODUCTION", "Section",
  Evaluatable->False,
  CellHorizontalScrolling->False,
  AspectRatioFixed->True],

Cell["\<\
Frequency sampling is a simple FIR filter design technique that yields linear \
phase filters. Given a frequency domain specification of a filter's amplitude \
response at a uniformly spaced set of points the impulse response \
coefficients may be obtained from a set of design equations. The design \
equations guarrantee a linear phase impulse response. The resulting filters \
have poor stopband attenuation characteristics and lack flexibility, but are \
attractive for narrow-band frequency selective filters where only a few of \
the samples of the frequency response are non-zero. Such filters have \
efficient realizations.\
\>", "Text",
  FontFamily->"Times New Roman"]
}, Open  ]],

Cell[CellGroupData[{

Cell["FREQUENCY DOMAIN SAMPLING", "Section",
  PageWidth->WindowWidth,
  Evaluatable->False,
  CellHorizontalScrolling->False,
  AspectRatioFixed->True],

Cell["\<\
The frequency sampling method requires a frequency domain specification in \
terms of uniformly spaced samples of the amplitude response. There are two \
possible sequences of sample points: (1) integer multiples of an elementary \
step size or (2) at points half-step between them. \
\>", "Text",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(\(samples[M_, \[Alpha]_] := 
      Table[\(\(2  \[Pi]\)\/M\) \((m + \[Alpha])\), \ {m, 0, M - 1}]; \)\)], 
  "Input",
  CellLabel->"In[27]:="],

Cell[CellGroupData[{

Cell[BoxData[
    \({samples[8, 0], samples[8, 1\/2]}\)], "Input",
  CellLabel->"In[28]:="],

Cell[BoxData[
    \({{0, \[Pi]\/4, \[Pi]\/2, \(3\ \[Pi]\)\/4, \[Pi], \(5\ \[Pi]\)\/4, 
        \(3\ \[Pi]\)\/2, \(7\ \[Pi]\)\/4}, {\[Pi]\/8, \(3\ \[Pi]\)\/8, 
        \(5\ \[Pi]\)\/8, \(7\ \[Pi]\)\/8, \(9\ \[Pi]\)\/8, \(11\ \[Pi]\)\/8, 
        \(13\ \[Pi]\)\/8, \(15\ \[Pi]\)\/8}}\)], "Output",
  CellLabel->"Out[28]="]
}, Open  ]],

Cell["\<\
(*  Insert a graphic that displays the samples on the unit circle in two \
colors. *)\
\>", "Text",
  FontFamily->"Times New Roman"]
}, Open  ]],

Cell[CellGroupData[{

Cell["DESIGN EQUATIONS", "Section",
  PageWidth->WindowWidth,
  Evaluatable->False,
  CellHorizontalScrolling->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "There are four types of linear phase filters, depending on the filter's \
symmetry properties and length (even, or odd). The ",
  StyleBox["FrequencySampling", "Program"],
  " function takes an amplitude specification as a list of equally spaced \
samples of the desired amplitude response and a length specification and \
computes the impulse response of a linear phase FIR filter. The function \
accepts two optional arguments which determine the type of frequency domain \
spacing (\[Alpha] \[Rule]0 or \[Alpha]\[Rule]",
  Cell[BoxData[
      \(TraditionalForm\`1\/2\)]],
  ") and the desired impulse response symmetry. A choice of symmetric->True \
(default) leads to Type 1 and 2 filters with even symmetry in the impulse \
response coefficients, while symmetric->False leads to Type 3 and 4 filters. \
The latter is useful in designing differentiators and Hilbert transforms \
filters. The number of unique amplitude coefficients needed to compute a \
filter of length ",
  Cell[BoxData[
      \(TraditionalForm\`M\)]],
  " is:\n\n",
  Cell[BoxData[
      FormBox[GridBox[{
            {\(Type\ 1\), \(L = \(M + 1\)\/2\)},
            {\(Type\ 2\), \(L = M\/2\)},
            {\(Type\ 3\), \(L = \(M - 1\)\/2\)},
            {\(Type\ 4\), \(L = M\/2\)}
            }], TraditionalForm]]],
  " "
}], "Text",
  Evaluatable->False,
  FontFamily->"Times New Roman"],

Cell["Design equations:", "Text"]
}, Open  ]],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {\(h\_1[n] = \(h\_2[n] = \)\), 
            StyleBox[
              RowBox[{"{", GridBox[{
                    {
                      \(A\_0\/M\  + 
                        \(2\/M\) 
                          \(\[Sum]\+\(k = 1\)\%L\ 
                            \((\(-1\))\)\^k\ \ A\_k\ \ 
                              \(cos(\(\(2 \[Pi]\ \)\/M\) k\ \ \((n + 1\/2)\))
                                \)\), \), \(\[Alpha] = 0\)},
                    {
                      \(\(2\/M\) 
                        \(\[Sum]\+\(k = 0\)\%L\ 
                          \((\(-1\))\)\^k\ \ A\_k\ \ 
                            \(sin(\(\(2 \[Pi]\ \)\/M\) k\ \ \((n + 1\/2)\))
                              \)\), \), \(\[Alpha] = 1\/2\)}
                    },
                  ColumnAlignments->{Left}]}],
              GridBoxOptions->{ColumnAlignments->{Center}}]},
          {\(h\_3[n] = \), 
            StyleBox[
              RowBox[{"{", GridBox[{
                    {
                      \(\(-\(2\/M\)\) 
                        \(\[Sum]\+\(k = 1\)\%L\ 
                          \((\(-1\))\)\^k\ \ A\_k\ \ 
                            \(sin(\(\(2 \[Pi]\ \)\/M\) k\ \ \((n + 1\/2)\))
                              \)\), \), \(\[Alpha] = 0\)},
                    {
                      \(\(2\/M\) 
                        \(\[Sum]\+\(k = 0\)\%\(L - 1\)\ 
                          \((\(-1\))\)\^k\ \ A\_\(k + 1\)\ \ 
                            \(cos(\(\(2 \[Pi]\ \)\/M\) \((k + 1\/2)\)\ \ 
                                \((n + 1\/2)\))\)\), \), \(\[Alpha] = 1\/2\)}
                    },
                  ColumnAlignments->{Left}]}],
              GridBoxOptions->{ColumnAlignments->{Center}}]},
          {\(h\_4[n] = \), 
            StyleBox[
              RowBox[{"{", GridBox[{
                    {
                      \(\(1\/M\) 
                        \((\(\((\(-1\))\)\^\(n + M\/2\)\) A\_\(M\/2\) - 
                            2 \(\[Sum]\+\(k = 1\)\%L\ 
                                \((\(-1\))\)\^k\ \ A\_k\ \ 
                                  \(sin(
                                    \(\(2 \[Pi]\ \)\/M\) k\ \ \((n + 1\/2)\))
                                    \)\))\), \), \(\[Alpha] = 0\)},
                    {
                      \(\(2\/M\) 
                        \(\[Sum]\+\(k = 0\)\%\(L - 1\)\ 
                          \((\(-1\))\)\^k\ \ A\_\(k + 1\)\ \ 
                            \(cos(\(\(2 \[Pi]\ \)\/M\) \((k + 1\/2)\)\ \ 
                                \((n + 1\/2)\))\)\), \), \(\[Alpha] = 1\/2\)}
                    },
                  ColumnAlignments->{Left}]}],
              GridBoxOptions->{ColumnAlignments->{Center}}]}
          },
        RowSpacings->2,
        ColumnAlignments->{Left}], TraditionalForm]]]], "Text"],

Cell[CellGroupData[{

Cell["DESIGN PROCEDURE", "Section",
  PageWidth->WindowWidth,
  Evaluatable->False,
  CellHorizontalScrolling->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "Given the design equations, the design process reduces to specifying a \
desired amplitude response. Here a length 15, Type 1, lowpass FIR filter with \
a bandwidth of approximately",
  Cell[BoxData[
      \(TraditionalForm\`\[Pi]\/2\)]],
  "will be obtained (Example 8.2.1, Proakis (1996))."
}], "Text",
  Evaluatable->False,
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(L = 15; \ BW = 4; \n
    Amplitude = Join[Table[1. , {BW}], Table[0. , {\(L + 1\)\/2 - BW}]]; \)], 
  "Input",
  CellLabel->"In[3]:=",
  PageWidth->Infinity],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(ListSignalPlot[Amplitude]; \)\)], "Input",
  CellLabel->"In[4]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.136054 0.0147151 0.588604 [
[.15986 .00222 -3 -9 ]
[.15986 .00222 3 0 ]
[.29592 .00222 -3 -9 ]
[.29592 .00222 3 0 ]
[.43197 .00222 -3 -9 ]
[.43197 .00222 3 0 ]
[.56803 .00222 -3 -9 ]
[.56803 .00222 3 0 ]
[.70408 .00222 -3 -9 ]
[.70408 .00222 3 0 ]
[.84014 .00222 -3 -9 ]
[.84014 .00222 3 0 ]
[.97619 .00222 -3 -9 ]
[.97619 .00222 3 0 ]
[.01131 .13244 -18 -4.5 ]
[.01131 .13244 0 4.5 ]
[.01131 .25016 -18 -4.5 ]
[.01131 .25016 0 4.5 ]
[.01131 .36788 -18 -4.5 ]
[.01131 .36788 0 4.5 ]
[.01131 .4856 -18 -4.5 ]
[.01131 .4856 0 4.5 ]
[.01131 .60332 -6 -4.5 ]
[.01131 .60332 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.15986 .01472 m
.15986 .02097 L
s
[(1)] .15986 .00222 0 1 Mshowa
.29592 .01472 m
.29592 .02097 L
s
[(2)] .29592 .00222 0 1 Mshowa
.43197 .01472 m
.43197 .02097 L
s
[(3)] .43197 .00222 0 1 Mshowa
.56803 .01472 m
.56803 .02097 L
s
[(4)] .56803 .00222 0 1 Mshowa
.70408 .01472 m
.70408 .02097 L
s
[(5)] .70408 .00222 0 1 Mshowa
.84014 .01472 m
.84014 .02097 L
s
[(6)] .84014 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(7)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.05102 .01472 m
.05102 .01847 L
s
.07823 .01472 m
.07823 .01847 L
s
.10544 .01472 m
.10544 .01847 L
s
.13265 .01472 m
.13265 .01847 L
s
.18707 .01472 m
.18707 .01847 L
s
.21429 .01472 m
.21429 .01847 L
s
.2415 .01472 m
.2415 .01847 L
s
.26871 .01472 m
.26871 .01847 L
s
.32313 .01472 m
.32313 .01847 L
s
.35034 .01472 m
.35034 .01847 L
s
.37755 .01472 m
.37755 .01847 L
s
.40476 .01472 m
.40476 .01847 L
s
.45918 .01472 m
.45918 .01847 L
s
.48639 .01472 m
.48639 .01847 L
s
.51361 .01472 m
.51361 .01847 L
s
.54082 .01472 m
.54082 .01847 L
s
.59524 .01472 m
.59524 .01847 L
s
.62245 .01472 m
.62245 .01847 L
s
.64966 .01472 m
.64966 .01847 L
s
.67687 .01472 m
.67687 .01847 L
s
.73129 .01472 m
.73129 .01847 L
s
.7585 .01472 m
.7585 .01847 L
s
.78571 .01472 m
.78571 .01847 L
s
.81293 .01472 m
.81293 .01847 L
s
.86735 .01472 m
.86735 .01847 L
s
.89456 .01472 m
.89456 .01847 L
s
.92177 .01472 m
.92177 .01847 L
s
.94898 .01472 m
.94898 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02381 .13244 m
.03006 .13244 L
s
[(0.2)] .01131 .13244 1 0 Mshowa
.02381 .25016 m
.03006 .25016 L
s
[(0.4)] .01131 .25016 1 0 Mshowa
.02381 .36788 m
.03006 .36788 L
s
[(0.6)] .01131 .36788 1 0 Mshowa
.02381 .4856 m
.03006 .4856 L
s
[(0.8)] .01131 .4856 1 0 Mshowa
.02381 .60332 m
.03006 .60332 L
s
[(1)] .01131 .60332 1 0 Mshowa
.125 Mabswid
.02381 .04415 m
.02756 .04415 L
s
.02381 .07358 m
.02756 .07358 L
s
.02381 .10301 m
.02756 .10301 L
s
.02381 .16187 m
.02756 .16187 L
s
.02381 .1913 m
.02756 .1913 L
s
.02381 .22073 m
.02756 .22073 L
s
.02381 .27959 m
.02756 .27959 L
s
.02381 .30902 m
.02756 .30902 L
s
.02381 .33845 m
.02756 .33845 L
s
.02381 .39731 m
.02756 .39731 L
s
.02381 .42674 m
.02756 .42674 L
s
.02381 .45617 m
.02756 .45617 L
s
.02381 .51503 m
.02756 .51503 L
s
.02381 .54446 m
.02756 .54446 L
s
.02381 .57389 m
.02756 .57389 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .01472 m
.02381 .60332 L
s
.02502 w
.02381 .60332 Mdot
.5 Mabswid
.15986 .01472 m
.15986 .60332 L
s
.02502 w
.15986 .60332 Mdot
.5 Mabswid
.29592 .01472 m
.29592 .60332 L
s
.02502 w
.29592 .60332 Mdot
.5 Mabswid
.43197 .01472 m
.43197 .60332 L
s
.02502 w
.43197 .60332 Mdot
.5 Mabswid
.56803 .01472 m
.56803 .01472 L
s
.02502 w
.56803 .01472 Mdot
.5 Mabswid
.70408 .01472 m
.70408 .01472 L
s
.02502 w
.70408 .01472 Mdot
.5 Mabswid
.84014 .01472 m
.84014 .01472 L
s
.02502 w
.84014 .01472 Mdot
.5 Mabswid
.97619 .01472 m
.97619 .01472 L
s
.02502 w
.97619 .01472 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[4]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo000gOol5
000QOol3000ROol2000TOol3000ROol00`00Oomoo`0QOol2000TOol00`00Oomoo`06Ool003Uoo`03
001oogoo025oo`03001oogoo02Aoo`03001oogoo029oo`03001oogoo021oo`03001oo`00029oo`03
001oo`0002=oo`03001oogoo00Ioo`00>Goo00<007ooOol08Woo00<007ooOol08Woo00<007ooOol0
8Goo10008goo00<007ooOol087oo00<007oo00008goo00<007ooOol01Woo000iOol00`00Oomoo`0R
Ool00`00Oomoo`0SOol00`00Oomoo`0POol00`00Ool0000ROol2000SOol2000UOol00`00Oomoo`05
Ool003Uoo`03001oogoo025oo`03001oo`00029oo`03001oo`0002=oo`80029oo`03001oogoo029o
o`03001oogoo029oo`03001oo`0000Moo`00>7oo0P0097oo00<007ooOol08Woo00<007ooOol08goo
00<007ooOol087oo0`008goo0P008Woo0`001goo003oOolQOol001Eoo`03001oogoo0?moo`Uoo`00
5Goo00<007ooOol0ogoo2Goo000EOol00`00Oomoo`2@Ool2000SOol2000SOol2000SOol20007Ool0
01Eoo`03001oogoo08moo`@0025oo`@0025oo`@0025oo`@000Ioo`003gooo`004@000Goo000EOol0
0`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool0
0`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool0
0`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool0
0`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool01000Oomoogoo1P00
17oo00<007ooOol01Goo00<007ooOol017oo00<007ooOol01Goo00@007ooOomoo`H000Aoo`03001o
ogoo00Eoo`03001oogoo00Aoo`03001oogoo00Eoo`04001oogooOol60004Ool00`00Oomoo`05Ool0
0`00Oomoo`04Ool00`00Oomoo`05Ool01000Oomoogoo1P001Goo000EOol00`00Oomoo`0ROol00`00
Oomoo`0ROol00`00Oomoo`0ROol00`00Oomoo`0POol4000QOol4000QOol4000QOol40006Ool001Eo
o`03001oogoo029oo`03001oogoo029oo`03001oogoo029oo`03001oogoo025oo`8002=oo`8002=o
o`8002=oo`8000Moo`005Goo00<007ooOol08Woo00<007ooOol08Woo00<007ooOol08Woo00<007oo
Ool0VGoo000EOol00`00Oomoo`0ROol00`00Oomoo`0ROol00`00Oomoo`0ROol00`00Oomoo`2IOol0
01Eoo`03001oogoo029oo`03001oogoo029oo`03001oogoo029oo`03001oogoo09Uoo`005Goo00<0
07ooOol08Woo00<007ooOol08Woo00<007ooOol08Woo00<007ooOol0VGoo000EOol2000SOol00`00
Oomoo`0ROol00`00Oomoo`0ROol00`00Oomoo`2IOol001Eoo`03001oogoo029oo`03001oogoo029o
o`03001oogoo029oo`03001oogoo09Uoo`005Goo00<007ooOol08Woo00<007ooOol08Woo00<007oo
Ool08Woo00<007ooOol0VGoo000EOol00`00Oomoo`0ROol00`00Oomoo`0ROol00`00Oomoo`0ROol0
0`00Oomoo`2IOol001Eoo`03001oogoo029oo`03001oogoo029oo`03001oogoo029oo`03001oogoo
09Uoo`005Goo00<007ooOol08Woo00<007ooOol08Woo00<007ooOol08Woo00<007ooOol0VGoo000E
Ool00`00Oomoo`0ROol00`00Oomoo`0ROol00`00Oomoo`0ROol00`00Oomoo`2IOol001Eoo`03001o
ogoo029oo`03001oogoo029oo`03001oogoo029oo`03001oogoo09Uoo`005Goo0P008goo00<007oo
Ool08Woo00<007ooOol08Woo00<007ooOol0VGoo000EOol00`00Oomoo`0ROol00`00Oomoo`0ROol0
0`00Oomoo`0ROol00`00Oomoo`2IOol001Eoo`03001oogoo029oo`03001oogoo029oo`03001oogoo
029oo`03001oogoo09Uoo`005Goo00<007ooOol08Woo00<007ooOol08Woo00<007ooOol08Woo00<0
07ooOol0VGoo000EOol00`00Oomoo`0ROol00`00Oomoo`0ROol00`00Oomoo`0ROol00`00Oomoo`2I
Ool001Eoo`03001oogoo029oo`03001oogoo029oo`03001oogoo029oo`03001oogoo09Uoo`005Goo
00<007ooOol08Woo00<007ooOol08Woo00<007ooOol08Woo00<007ooOol0VGoo000EOol00`00Oomo
o`0ROol00`00Oomoo`0ROol00`00Oomoo`0ROol00`00Oomoo`2IOol001Eoo`8002=oo`03001oogoo
029oo`03001oogoo029oo`03001oogoo09Uoo`005Goo00<007ooOol08Woo00<007ooOol08Woo00<0
07ooOol08Woo00<007ooOol0VGoo000EOol00`00Oomoo`0ROol00`00Oomoo`0ROol00`00Oomoo`0R
Ool00`00Oomoo`2IOol001Eoo`03001oogoo029oo`03001oogoo029oo`03001oogoo029oo`03001o
ogoo09Uoo`005Goo00<007ooOol08Woo00<007ooOol08Woo00<007ooOol08Woo00<007ooOol0VGoo
000EOol00`00Oomoo`0ROol00`00Oomoo`0ROol00`00Oomoo`0ROol00`00Oomoo`2IOol000Eoo`03
001oogoo009oo`04001oogooOol30004Ool00`00Oomoo`0ROol00`00Oomoo`0ROol00`00Oomoo`0R
Ool00`00Oomoo`2IOol000Aoo`03001oo`0000Moo`03001oogoo00Aoo`03001oogoo029oo`03001o
ogoo029oo`03001oogoo029oo`03001oogoo09Uoo`0017oo00<007oo000027oo00<007ooOol00goo
0`008Woo00<007ooOol08Woo00<007ooOol08Woo00<007ooOol0VGoo0004Ool00`00Ool00008Ool0
0`00Oomoo`03Ool00`00Oomoo`0ROol00`00Oomoo`0ROol00`00Oomoo`0ROol00`00Oomoo`2IOol0
00Aoo`03001oo`0000Moo`03001oo`0000Aoo`03001oogoo029oo`03001oogoo029oo`03001oogoo
029oo`03001oogoo09Uoo`001Goo00<007ooOol01goo00<007ooOol00goo00<007ooOol08Woo00<0
07ooOol08Woo00<007ooOol08Woo00<007ooOol0VGoo000EOol00`00Oomoo`0ROol00`00Oomoo`0R
Ool00`00Oomoo`0ROol00`00Oomoo`2IOol001Eoo`03001oogoo029oo`03001oogoo029oo`03001o
ogoo029oo`03001oogoo09Uoo`005Goo00<007ooOol08Woo00<007ooOol08Woo00<007ooOol08Woo
00<007ooOol0VGoo000EOol00`00Oomoo`0ROol00`00Oomoo`0ROol00`00Oomoo`0ROol00`00Oomo
o`2IOol001Eoo`8002=oo`03001oogoo029oo`03001oogoo029oo`03001oogoo09Uoo`005Goo00<0
07ooOol08Woo00<007ooOol08Woo00<007ooOol08Woo00<007ooOol0VGoo000EOol00`00Oomoo`0R
Ool00`00Oomoo`0ROol00`00Oomoo`0ROol00`00Oomoo`2IOol001Eoo`03001oogoo029oo`03001o
ogoo029oo`03001oogoo029oo`03001oogoo09Uoo`005Goo00<007ooOol08Woo00<007ooOol08Woo
00<007ooOol08Woo00<007ooOol0VGoo000EOol00`00Oomoo`0ROol00`00Oomoo`0ROol00`00Oomo
o`0ROol00`00Oomoo`2IOol001Eoo`03001oogoo029oo`03001oogoo029oo`03001oogoo029oo`03
001oogoo09Uoo`005Goo00<007ooOol08Woo00<007ooOol08Woo00<007ooOol08Woo00<007ooOol0
VGoo000EOol2000SOol00`00Oomoo`0ROol00`00Oomoo`0ROol00`00Oomoo`2IOol001Eoo`03001o
ogoo029oo`03001oogoo029oo`03001oogoo029oo`03001oogoo09Uoo`005Goo00<007ooOol08Woo
00<007ooOol08Woo00<007ooOol08Woo00<007ooOol0VGoo000EOol00`00Oomoo`0ROol00`00Oomo
o`0ROol00`00Oomoo`0ROol00`00Oomoo`2IOol001Eoo`03001oogoo029oo`03001oogoo029oo`03
001oogoo029oo`03001oogoo09Uoo`005Goo00<007ooOol08Woo00<007ooOol08Woo00<007ooOol0
8Woo00<007ooOol0VGoo000EOol00`00Oomoo`0ROol00`00Oomoo`0ROol00`00Oomoo`0ROol00`00
Oomoo`2IOol001Eoo`03001oogoo029oo`03001oogoo029oo`03001oogoo029oo`03001oogoo09Uo
o`005Goo0P008goo00<007ooOol08Woo00<007ooOol08Woo00<007ooOol0VGoo000EOol00`00Oomo
o`0ROol00`00Oomoo`0ROol00`00Oomoo`0ROol00`00Oomoo`2IOol001Eoo`03001oogoo029oo`03
001oogoo029oo`03001oogoo029oo`03001oogoo09Uoo`005Goo00<007ooOol08Woo00<007ooOol0
8Woo00<007ooOol08Woo00<007ooOol0VGoo000EOol00`00Oomoo`0ROol00`00Oomoo`0ROol00`00
Oomoo`0ROol00`00Oomoo`2IOol001Eoo`03001oogoo029oo`03001oogoo029oo`03001oogoo029o
o`03001oogoo09Uoo`001Goo00<007ooOol00Woo00<007ooOol00Woo0`000goo00<007ooOol08Woo
00<007ooOol08Woo00<007ooOol08Woo00<007ooOol0VGoo0004Ool00`00Ool00009Ool00`00Oomo
o`02Ool00`00Oomoo`0ROol00`00Oomoo`0ROol00`00Oomoo`0ROol00`00Oomoo`2IOol000Aoo`03
001oo`0000Moo`@000=oo`<0029oo`03001oogoo029oo`03001oogoo029oo`03001oogoo09Uoo`00
17oo00<007oo00001goo00<007oo000017oo00<007ooOol08Woo00<007ooOol08Woo00<007ooOol0
8Woo00<007ooOol0VGoo0004Ool00`00Ool00008Ool20004Ool00`00Oomoo`0ROol00`00Oomoo`0R
Ool00`00Oomoo`0ROol00`00Oomoo`2IOol000Eoo`03001oogoo00Qoo`03001oogoo009oo`03001o
ogoo029oo`03001oogoo029oo`03001oogoo029oo`03001oogoo09Uoo`005Goo00<007ooOol08Woo
00<007ooOol08Woo00<007ooOol08Woo00<007ooOol0VGoo000EOol00`00Oomoo`0ROol00`00Oomo
o`0ROol00`00Oomoo`0ROol00`00Oomoo`2IOol001Eoo`03001oogoo029oo`03001oogoo029oo`03
001oogoo029oo`03001oogoo09Uoo`005Goo00<007ooOol08Woo00<007ooOol08Woo00<007ooOol0
8Woo00<007ooOol0VGoo000EOol2000SOol00`00Oomoo`0ROol00`00Oomoo`0ROol00`00Oomoo`2I
Ool001Eoo`03001oogoo029oo`03001oogoo029oo`03001oogoo029oo`03001oogoo09Uoo`005Goo
00<007ooOol08Woo00<007ooOol08Woo00<007ooOol08Woo00<007ooOol0VGoo000EOol00`00Oomo
o`0ROol00`00Oomoo`0ROol00`00Oomoo`0ROol00`00Oomoo`2IOol001Eoo`03001oogoo029oo`03
001oogoo029oo`03001oogoo029oo`03001oogoo09Uoo`005Goo00<007ooOol08Woo00<007ooOol0
8Woo00<007ooOol08Woo00<007ooOol0VGoo000EOol00`00Oomoo`0ROol00`00Oomoo`0ROol00`00
Oomoo`0ROol00`00Oomoo`2IOol001Eoo`03001oogoo029oo`03001oogoo029oo`03001oogoo029o
o`03001oogoo09Uoo`005Goo0P008goo00<007ooOol08Woo00<007ooOol08Woo00<007ooOol0VGoo
000EOol00`00Oomoo`0ROol00`00Oomoo`0ROol00`00Oomoo`0ROol00`00Oomoo`2IOol001Eoo`03
001oogoo029oo`03001oogoo029oo`03001oogoo029oo`03001oogoo09Uoo`005Goo00<007ooOol0
8Woo00<007ooOol08Woo00<007ooOol08Woo00<007ooOol0VGoo000EOol00`00Oomoo`0ROol00`00
Oomoo`0ROol00`00Oomoo`0ROol00`00Oomoo`2IOol001Eoo`03001oogoo029oo`03001oogoo029o
o`03001oogoo029oo`03001oogoo09Uoo`005Goo00<007ooOol08Woo00<007ooOol08Woo00<007oo
Ool08Woo00<007ooOol0VGoo000EOol00`00Oomoo`0ROol00`00Oomoo`0ROol00`00Oomoo`0ROol0
0`00Oomoo`2IOol001Eoo`8002=oo`03001oogoo029oo`03001oogoo029oo`03001oogoo09Uoo`00
5Goo00<007ooOol08Woo00<007ooOol08Woo00<007ooOol08Woo00<007ooOol0VGoo000EOol00`00
Oomoo`0ROol00`00Oomoo`0ROol00`00Oomoo`0ROol00`00Oomoo`2IOol001Eoo`03001oogoo029o
o`03001oogoo029oo`03001oogoo029oo`03001oogoo09Uoo`005Goo00<007ooOol08Woo00<007oo
Ool08Woo00<007ooOol08Woo00<007ooOol0VGoo000EOol00`00Oomoo`0ROol00`00Oomoo`0ROol0
0`00Oomoo`0ROol00`00Oomoo`2IOol000Eoo`03001oogoo009oo`04001oogooOol20005Ool00`00
Oomoo`0ROol00`00Oomoo`0ROol00`00Oomoo`0ROol00`00Oomoo`2IOol000Aoo`03001oo`0000Mo
o`03001oo`0000Aoo`03001oogoo029oo`03001oogoo029oo`03001oogoo029oo`03001oogoo09Uo
o`0017oo00<007oo00001goo00<007oo000017oo0`008Woo00<007ooOol08Woo00<007ooOol08Woo
00<007ooOol0VGoo0004Ool00`00Ool00007Ool20005Ool00`00Oomoo`0ROol00`00Oomoo`0ROol0
0`00Oomoo`0ROol00`00Oomoo`2IOol000Aoo`03001oo`0000Moo`03001oogoo00Aoo`03001oogoo
029oo`03001oogoo029oo`03001oogoo029oo`03001oogoo09Uoo`001Goo00<007ooOol01goo0P00
17oo00<007ooOol08Woo00<007ooOol08Woo00<007ooOol08Woo00<007ooOol0VGoo000EOol00`00
Oomoo`0ROol00`00Oomoo`0ROol00`00Oomoo`0ROol00`00Oomoo`2IOol001Eoo`03001oogoo029o
o`03001oogoo029oo`03001oogoo029oo`03001oogoo09Uoo`005Goo00<007ooOol08Woo00<007oo
Ool08Woo00<007ooOol08Woo00<007ooOol0VGoo000EOol00`00Oomoo`0ROol00`00Oomoo`0ROol0
0`00Oomoo`0ROol00`00Oomoo`2IOol001Eoo`8002=oo`03001oogoo029oo`03001oogoo029oo`03
001oogoo09Uoo`005Goo00<007ooOol08Woo00<007ooOol08Woo00<007ooOol08Woo00<007ooOol0
VGoo000EOol00`00Oomoo`0ROol00`00Oomoo`0ROol00`00Oomoo`0ROol00`00Oomoo`2IOol001Eo
o`03001oogoo029oo`03001oogoo029oo`03001oogoo029oo`03001oogoo09Uoo`005Goo00<007oo
Ool08Woo00<007ooOol08Woo00<007ooOol08Woo00<007ooOol0VGoo000EOol00`00Oomoo`0ROol0
0`00Oomoo`0ROol00`00Oomoo`0ROol00`00Oomoo`2IOol001Eoo`03001oogoo029oo`03001oogoo
029oo`03001oogoo029oo`03001oogoo09Uoo`005Goo00<007ooOol08Woo00<007ooOol08Woo00<0
07ooOol08Woo00<007ooOol0VGoo000EOol2000SOol00`00Oomoo`0ROol00`00Oomoo`0ROol00`00
Oomoo`2IOol001Eoo`03001oogoo029oo`03001oogoo029oo`03001oogoo029oo`03001oogoo09Uo
o`005Goo00<007ooOol08Woo00<007ooOol08Woo00<007ooOol08Woo00<007ooOol0VGoo000EOol0
0`00Oomoo`0ROol00`00Oomoo`0ROol00`00Oomoo`0ROol00`00Oomoo`2IOol001Eoo`03001oogoo
029oo`03001oogoo029oo`03001oogoo029oo`03001oogoo09Uoo`005Goo00<007ooOol08Woo00<0
07ooOol08Woo00<007ooOol08Woo00<007ooOol0VGoo000EOol00`00Oomoo`0ROol00`00Oomoo`0R
Ool00`00Oomoo`0ROol00`00Oomoo`2IOol001Eoo`03001oogoo029oo`03001oogoo029oo`03001o
ogoo029oo`03001oogoo09Uoo`005Goo0P008goo00<007ooOol08Woo00<007ooOol08Woo00<007oo
Ool0VGoo000EOol00`00Oomoo`0ROol00`00Oomoo`0ROol00`00Oomoo`0ROol00`00Oomoo`2IOol0
01Eoo`03001oogoo029oo`03001oogoo029oo`03001oogoo029oo`03001oogoo09Uoo`005Goo00<0
07ooOol08Woo00<007ooOol08Woo00<007ooOol08Woo00<007ooOol0VGoo000EOol00`00Oomoo`0R
Ool00`00Oomoo`0ROol00`00Oomoo`0ROol00`00Oomoo`2IOol001Eoo`03001oogoo029oo`03001o
ogoo029oo`03001oogoo029oo`03001oogoo09Uoo`001Goo00<007ooOol00Woo00<007ooOol00Woo
00<007ooOol00goo00<007ooOol08Woo00<007ooOol08Woo00<007ooOol08Woo00<007ooOol0VGoo
0004Ool00`00Ool00007Ool00`00Ool00004Ool00`00Oomoo`0ROol00`00Oomoo`0ROol00`00Oomo
o`0ROol00`00Oomoo`2IOol000Aoo`03001oo`0000Moo`03001oo`0000Aoo`<0029oo`03001oogoo
029oo`03001oogoo029oo`03001oogoo09Uoo`0017oo00<007oo000027oo00<007ooOol00goo00<0
07ooOol08Woo00<007ooOol08Woo00<007ooOol08Woo00<007ooOol0VGoo0004Ool00`00Ool00007
Ool00`00Ool00004Ool00`00Oomoo`0ROol00`00Oomoo`0ROol00`00Oomoo`0ROol00`00Oomoo`2I
Ool000Eoo`03001oogoo00Moo`03001oogoo00=oo`03001oogoo029oo`03001oogoo029oo`03001o
ogoo029oo`03001oogoo09Uoo`005Goo00<007ooOol08Woo00<007ooOol08Woo00<007ooOol08Woo
00<007ooOol0VGoo000EOol00`00Oomoo`0ROol00`00Oomoo`0ROol00`00Oomoo`0ROol00`00Oomo
o`2IOol001Eoo`03001oogoo029oo`03001oogoo029oo`03001oogoo029oo`03001oogoo09Uoo`00
5Goo00<007ooOol08Woo00<007ooOol08Woo00<007ooOol08Woo00<007ooOol0VGoo000EOol2000S
Ool00`00Oomoo`0ROol00`00Oomoo`0ROol00`00Oomoo`2IOol001Eoo`03001oogoo029oo`03001o
ogoo029oo`03001oogoo029oo`03001oogoo09Uoo`005Goo00<007ooOol08Woo00<007ooOol08Woo
00<007ooOol08Woo00<007ooOol0VGoo000EOol00`00Oomoo`0ROol00`00Oomoo`0ROol00`00Oomo
o`0ROol00`00Oomoo`2IOol001Eoo`03001oogoo029oo`03001oogoo029oo`03001oogoo029oo`03
001oogoo09Uoo`005Goo00<007ooOol08Woo00<007ooOol08Woo00<007ooOol08Woo00<007ooOol0
VGoo000EOol00`00Oomoo`0ROol00`00Oomoo`0ROol00`00Oomoo`0ROol00`00Oomoo`2IOol001Eo
o`03001oogoo029oo`03001oogoo029oo`03001oogoo029oo`03001oogoo09Uoo`005Goo0P008goo
00<007ooOol08Woo00<007ooOol08Woo00<007ooOol0VGoo000EOol00`00Oomoo`0ROol00`00Oomo
o`0ROol00`00Oomoo`0ROol00`00Oomoo`2IOol001Eoo`03001oogoo029oo`03001oogoo029oo`03
001oogoo029oo`03001oogoo09Uoo`005Goo00<007ooOol08Woo00<007ooOol08Woo00<007ooOol0
8Woo00<007ooOol0VGoo000EOol00`00Oomoo`0ROol00`00Oomoo`0ROol00`00Oomoo`0ROol00`00
Oomoo`2IOol001Eoo`03001oogoo029oo`03001oogoo029oo`03001oogoo029oo`03001oogoo09Uo
o`005Goo00<007ooOol08Woo00<007ooOol08Woo00<007ooOol08Woo00<007ooOol0VGoo000EOol0
0`00Oomoo`0ROol00`00Oomoo`0ROol00`00Oomoo`0ROol00`00Oomoo`2IOol001Eoo`8002=oo`03
001oogoo029oo`03001oogoo029oo`03001oogoo09Uoo`005Goo00<007ooOol08Woo00<007ooOol0
8Woo00<007ooOol08Woo00<007ooOol0VGoo000EOol00`00Oomoo`0ROol00`00Oomoo`0ROol00`00
Oomoo`0ROol00`00Oomoo`2IOol001Eoo`03001oogoo029oo`03001oogoo029oo`03001oogoo029o
o`03001oogoo09Uoo`005Goo00<007ooOol08Woo00<007ooOol08Woo00<007ooOol08Woo00<007oo
Ool0VGoo000EOol00`00Oomoo`0ROol00`00Oomoo`0ROol00`00Oomoo`0ROol00`00Oomoo`2IOol0
00eoo`D0009oo`8002=oo`8002=oo`8002=oo`8009]oo`003goo00@007ooOomoo`@0025oo`@0025o
o`@0025oo`@009Yoo`003goo00<007ooOol01P007goo1P007goo1P007goo1P00VGoo000?Ool00`00
Oomoo`06000OOol6000OOol6000OOol6002IOol000moo`04001oogooOol4000QOol4000QOol4000Q
Ool4002JOol000ioo`8000Aoo`8002=oo`8002=oo`8002=oo`8009]oo`005Goo00<007ooOol0ogoo
2Goo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.580898, -0.07747, 
  0.0270326, 0.00624851}}]
}, Open  ]],

Cell["The impulse response is", "Text",
  Evaluatable->False,
  FontFamily->"Times New Roman"],

Cell[CellGroupData[{

Cell[BoxData[
    \(h = FrequencySamplingFilter[L, Amplitude]\)], "Input",
  CellLabel->"In[5]:=",
  PageWidth->Infinity],

Cell[BoxData[
    \({\(-0.0498158849954869786`\), 0.0412022659166596483`, 
      0.0666666666666666785`, \(-0.0364878759502015581`\), 
      \(-0.107868932583326326`\), 0.0340780198288341562`, 
      0.318892407783520726`, 0.466666666666666696`, 0.318892407783521036`, 
      0.0340780198288344582`, \(-0.107868932583326326`\), 
      \(-0.0364878759502015892`\), 0.0666666666666665896`, 
      0.0412022659166597016`, \(-0.0498158849954869609`\)}\)], "Output",
  CellLabel->"Out[5]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(ListSignalPlot[h, \ Causal -> True, PlotRange -> All]; \)\)], "Input",\

  CellLabel->"In[7]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0680272 0.125225 1.02449 [
[.09184 .11273 -6 -9 ]
[.09184 .11273 6 0 ]
[.22789 .11273 -6 -9 ]
[.22789 .11273 6 0 ]
[.36395 .11273 -6 -9 ]
[.36395 .11273 6 0 ]
[.63605 .11273 -3 -9 ]
[.63605 .11273 3 0 ]
[.77211 .11273 -3 -9 ]
[.77211 .11273 3 0 ]
[.90816 .11273 -3 -9 ]
[.90816 .11273 3 0 ]
[.4875 .02278 -24 -4.5 ]
[.4875 .02278 0 4.5 ]
[.4875 .22767 -18 -4.5 ]
[.4875 .22767 0 4.5 ]
[.4875 .33012 -18 -4.5 ]
[.4875 .33012 0 4.5 ]
[.4875 .43257 -18 -4.5 ]
[.4875 .43257 0 4.5 ]
[.4875 .53502 -18 -4.5 ]
[.4875 .53502 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.09184 .12523 m
.09184 .13148 L
s
[(-6)] .09184 .11273 0 1 Mshowa
.22789 .12523 m
.22789 .13148 L
s
[(-4)] .22789 .11273 0 1 Mshowa
.36395 .12523 m
.36395 .13148 L
s
[(-2)] .36395 .11273 0 1 Mshowa
.63605 .12523 m
.63605 .13148 L
s
[(2)] .63605 .11273 0 1 Mshowa
.77211 .12523 m
.77211 .13148 L
s
[(4)] .77211 .11273 0 1 Mshowa
.90816 .12523 m
.90816 .13148 L
s
[(6)] .90816 .11273 0 1 Mshowa
.125 Mabswid
.12585 .12523 m
.12585 .12898 L
s
.15986 .12523 m
.15986 .12898 L
s
.19388 .12523 m
.19388 .12898 L
s
.2619 .12523 m
.2619 .12898 L
s
.29592 .12523 m
.29592 .12898 L
s
.32993 .12523 m
.32993 .12898 L
s
.39796 .12523 m
.39796 .12898 L
s
.43197 .12523 m
.43197 .12898 L
s
.46599 .12523 m
.46599 .12898 L
s
.53401 .12523 m
.53401 .12898 L
s
.56803 .12523 m
.56803 .12898 L
s
.60204 .12523 m
.60204 .12898 L
s
.67007 .12523 m
.67007 .12898 L
s
.70408 .12523 m
.70408 .12898 L
s
.7381 .12523 m
.7381 .12898 L
s
.80612 .12523 m
.80612 .12898 L
s
.84014 .12523 m
.84014 .12898 L
s
.87415 .12523 m
.87415 .12898 L
s
.05782 .12523 m
.05782 .12898 L
s
.02381 .12523 m
.02381 .12898 L
s
.94218 .12523 m
.94218 .12898 L
s
.97619 .12523 m
.97619 .12898 L
s
.25 Mabswid
0 .12523 m
1 .12523 L
s
.5 .02278 m
.50625 .02278 L
s
[(-0.1)] .4875 .02278 1 0 Mshowa
.5 .22767 m
.50625 .22767 L
s
[(0.1)] .4875 .22767 1 0 Mshowa
.5 .33012 m
.50625 .33012 L
s
[(0.2)] .4875 .33012 1 0 Mshowa
.5 .43257 m
.50625 .43257 L
s
[(0.3)] .4875 .43257 1 0 Mshowa
.5 .53502 m
.50625 .53502 L
s
[(0.4)] .4875 .53502 1 0 Mshowa
.125 Mabswid
.5 .04327 m
.50375 .04327 L
s
.5 .06376 m
.50375 .06376 L
s
.5 .08425 m
.50375 .08425 L
s
.5 .10474 m
.50375 .10474 L
s
.5 .14572 m
.50375 .14572 L
s
.5 .1662 m
.50375 .1662 L
s
.5 .18669 m
.50375 .18669 L
s
.5 .20718 m
.50375 .20718 L
s
.5 .24816 m
.50375 .24816 L
s
.5 .26865 m
.50375 .26865 L
s
.5 .28914 m
.50375 .28914 L
s
.5 .30963 m
.50375 .30963 L
s
.5 .35061 m
.50375 .35061 L
s
.5 .3711 m
.50375 .3711 L
s
.5 .39159 m
.50375 .39159 L
s
.5 .41208 m
.50375 .41208 L
s
.5 .45306 m
.50375 .45306 L
s
.5 .47355 m
.50375 .47355 L
s
.5 .49404 m
.50375 .49404 L
s
.5 .51453 m
.50375 .51453 L
s
.5 .00229 m
.50375 .00229 L
s
.5 .55551 m
.50375 .55551 L
s
.5 .576 m
.50375 .576 L
s
.5 .59649 m
.50375 .59649 L
s
.5 .61698 m
.50375 .61698 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
.5 Mabswid
.02381 .12523 m
.02381 .07419 L
s
.02076 w
.02381 .07419 Mdot
.5 Mabswid
.09184 .12523 m
.09184 .16744 L
s
.02076 w
.09184 .16744 Mdot
.5 Mabswid
.15986 .12523 m
.15986 .19352 L
s
.02076 w
.15986 .19352 Mdot
.5 Mabswid
.22789 .12523 m
.22789 .08784 L
s
.02076 w
.22789 .08784 Mdot
.5 Mabswid
.29592 .12523 m
.29592 .01472 L
s
.02076 w
.29592 .01472 Mdot
.5 Mabswid
.36395 .12523 m
.36395 .16014 L
s
.02076 w
.36395 .16014 Mdot
.5 Mabswid
.43197 .12523 m
.43197 .45193 L
s
.02076 w
.43197 .45193 Mdot
.5 Mabswid
.5 .12523 m
.5 .60332 L
s
.02076 w
.5 .60332 Mdot
.5 Mabswid
.56803 .12523 m
.56803 .45193 L
s
.02076 w
.56803 .45193 Mdot
.5 Mabswid
.63605 .12523 m
.63605 .16014 L
s
.02076 w
.63605 .16014 Mdot
.5 Mabswid
.70408 .12523 m
.70408 .01472 L
s
.02076 w
.70408 .01472 Mdot
.5 Mabswid
.77211 .12523 m
.77211 .08784 L
s
.02076 w
.77211 .08784 Mdot
.5 Mabswid
.84014 .12523 m
.84014 .19352 L
s
.02076 w
.84014 .19352 Mdot
.5 Mabswid
.90816 .12523 m
.90816 .16744 L
s
.02076 w
.90816 .16744 Mdot
.5 Mabswid
.97619 .12523 m
.97619 .07419 L
s
.02076 w
.97619 .07419 Mdot
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[7]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00OSgoo0P00Sgoo002?
Ool00`00Oomoo`2>Ool005=oo`<003Uoo`03001oogoo03Ioo`<005Eoo`00DWoo1@00>7oo00<007oo
Ool0=Goo1@00E7oo001BOol5000WOol00`00Oomoo`02Ool00`00Oomoo`050004Ool00`00Oomoo`0e
Ool5001DOol0059oo`D002Ioo`03001oo`0000Qoo`03001oogoo00Aoo`03001oogoo03Eoo`D005Ao
o`00Dgoo0`008Woo0`000Woo00<007oo000027oo00<007ooOol017oo0`00=Woo0`00EGoo001EOol0
0`00Oomoo`0UOol00`00Ool00008Ool00`00Oomoo`04Ool00`00Oomoo`0gOol00`00Oomoo`1DOol0
05Eoo`03001oogoo02Eoo`03001oo`0000Qoo`03001oogoo00Aoo`03001oogoo03Moo`03001oogoo
05Aoo`00EGoo00<007ooOol09Woo00<007ooOol01Woo0P001Woo00<007ooOol0=goo00<007ooOol0
E7oo001EOol00`00Oomoo`0gOol00`00Oomoo`0gOol00`00Oomoo`1DOol005Eoo`03001oogoo03Mo
o`03001oogoo03Moo`03001oogoo05Aoo`00EGoo00<007ooOol0=goo0P00>7oo00<007ooOol0E7oo
001EOol00`00Oomoo`0gOol00`00Oomoo`0gOol00`00Oomoo`1DOol005Eoo`03001oogoo03Moo`03
001oogoo03Moo`03001oogoo05Aoo`00EGoo00<007ooOol0=goo00<007ooOol0=goo00<007ooOol0
E7oo001EOol00`00Oomoo`0gOol00`00Oomoo`0gOol00`00Oomoo`1DOol005Eoo`03001oogoo03Mo
o`03001oogoo03Moo`03001oogoo05Aoo`00EGoo00<007ooOol0=goo0P00>7oo00<007ooOol0E7oo
0005Ool3001=Ool00`00Oomoo`0gOol00`00Oomoo`0gOol00`00Oomoo`1:Ool30007Ool000Aoo`D0
04aoo`03001oogoo03Moo`03001oogoo03Moo`03001oogoo04Uoo`D000Ioo`0017oo1@00C7oo00<0
07ooOol0=goo00<007ooOol0=goo00<007ooOol0BGoo1@001Woo0004Ool5001<Ool00`00Oomoo`0g
Ool00`00Oomoo`0gOol00`00Oomoo`19Ool50006Ool000Eoo`<003Qoo`<0019oo`03001oogoo03Mo
o`03001oogoo03Moo`03001oogoo00moo`<003Qoo`<000Moo`001goo00<007ooOol04Goo0P008Woo
1`003goo00<007ooOol04Goo0`008goo0P008goo0`004Woo00<007ooOol03Woo1@008goo0P004goo
00<007ooOol01Woo0007Ool00`00Oomoo`0AOol00`00Ool0000QOol6000@Ool00`00Oomoo`0AOol0
0`00Oomoo`0SOol00`00Oomoo`0ROol00`00Oomoo`0BOol00`00Oomoo`0>Ool5000SOol00`00Ool0
000BOol00`00Oomoo`06Ool000Moo`03001oogoo00aoo`<0009oo`03001oo`0001moo`T000moo`03
001oogoo00aoo`<000=oo`03001oogoo029oo`03001oogoo02=oo`03001oogoo015oo`03001oogoo
00ioo`D002=oo`03001oo`00019oo`03001oogoo00Ioo`001goo00<007ooOol04Goo0P008goo0`00
00=oo`00Ool03goo00<007ooOol04Woo00<007ooOol08Woo00<007ooOol08goo00<007ooOol04Goo
00<007ooOol03goo0`0097oo0P004goo00<007ooOol01Woo0007Ool00`00Oomoo`0AOol00`00Oomo
o`0SOol01000Ool0000047oo00<007ooOol04Goo00<007oo00008goo00<007ooOol08Woo00<007oo
00004Woo00<007ooOol047oo0P0097oo00<007ooOol04Woo00<007ooOol01Woo0007Ool00`00Oomo
o`0BOol2000SOol01000Oomoo`0047oo00<007ooOol04Woo00<007ooOol08Woo00<007ooOol08goo
00<007ooOol04Goo00<007ooOol04Goo00<007ooOol08goo0P004Woo00<007ooOol01Woo0007Ool0
0`00Oomoo`0gOol00`00Oomoo`0AOol00`00Oomoo`0gOol2000hOol00`00Oomoo`0AOol00`00Oomo
o`0gOol00`00Oomoo`06Ool000Moo`03001oogoo03Moo`03001oogoo015oo`03001oogoo03Moo`03
001oogoo03Moo`03001oogoo015oo`03001oogoo03Moo`03001oogoo00Ioo`001goo00<007ooOol0
=goo00<007ooOol04Goo00<007ooOol0=goo00<007ooOol0=goo00<007ooOol04Goo00<007ooOol0
=goo00<007ooOol01Woo0007Ool00`00Oomoo`0gOol00`00Oomoo`0AOol00`00Oomoo`0gOol00`00
Oomoo`0gOol00`00Oomoo`0AOol00`00Oomoo`0gOol00`00Oomoo`06Ool000Moo`03001oogoo03Mo
o`03001oogoo015oo`03001oogoo03Moo`03001oogoo03Moo`03001oogoo015oo`03001oogoo03Mo
o`03001oogoo00Ioo`00o`0080000Goo0007Ool00`00Oomoo`06Ool00`00Oomoo`07Ool00`00Oomo
o`07Ool00`00Oomoo`07Ool00`00Oomoo`06Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomo
o`07Ool00`00Oomoo`06Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomo
o`06Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`06Ool00`00Oomoo`07Ool00`00Oomo
o`07Ool00`00Oomoo`07Ool00`00Oomoo`06Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomo
o`07Ool00`00Oomoo`06Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomo
o`06Ool00`00Oomoo`06Ool001Yoo`03001oogoo015oo`03001oogoo011oo`03001oogoo02Aoo`03
001oogoo015oo`03001oogoo011oo`03001oogoo011oo`03001oogoo015oo`03001oogoo02Aoo`03
001oogoo011oo`03001oogoo015oo`03001oogoo01Uoo`006Woo00<007ooOol04Goo00<007ooOol0
=goo00<007ooOol04Goo00<007ooOol047oo00<007ooOol047oo00<007ooOol04Goo00<007ooOol0
=goo00<007ooOol04Goo00<007ooOol06Goo000JOol00`00Oomoo`0AOol00`00Oomoo`0gOol00`00
Oomoo`0AOol00`00Oomoo`0@Ool00`00Oomoo`0@Ool00`00Oomoo`0AOol00`00Oomoo`0gOol00`00
Oomoo`0AOol00`00Oomoo`0IOol001Yoo`03001oogoo015oo`03001oogoo03Moo`03001oogoo015o
o`03001oogoo011oo`03001oogoo011oo`03001oogoo015oo`03001oogoo03Moo`03001oogoo015o
o`03001oogoo01Uoo`006Woo00<007ooOol04Goo00<007ooOol0=goo00<007ooOol04Goo00<007oo
Ool047oo0P004Goo00<007ooOol04Goo00<007ooOol0=goo00<007ooOol04Goo00<007ooOol06Goo
000JOol00`00Oomoo`0AOol00`00Oomoo`0gOol00`00Oomoo`0AOol00`00Oomoo`0@Ool00`00Oomo
o`0@Ool00`00Oomoo`0AOol00`00Oomoo`0gOol00`00Oomoo`0AOol00`00Oomoo`0IOol001Yoo`03
001oogoo015oo`03001oogoo03Moo`03001oogoo015oo`03001oogoo011oo`03001oogoo011oo`03
001oogoo015oo`03001oogoo03Moo`03001oogoo015oo`03001oogoo01Uoo`006Woo00<007ooOol0
4Goo00<007ooOol0=Woo0`004Woo00<007ooOol047oo00<007ooOol047oo00<007ooOol047oo0`00
>7oo00<007ooOol04Goo00<007ooOol06Goo000JOol00`00Oomoo`0AOol00`00Oomoo`0eOol5000A
Ool00`00Oomoo`0@Ool00`00Oomoo`0@Ool00`00Oomoo`0?Ool5000gOol00`00Oomoo`0AOol00`00
Oomoo`0IOol001Uoo`<0019oo`03001oogoo03Eoo`D0015oo`03001oogoo011oo`03001oogoo011o
o`03001oogoo00moo`D003Moo`03001oogoo00moo`<001]oo`0067oo1@004Goo00<007ooOol0=Goo
1@004Goo00<007ooOol047oo0P004Goo00<007ooOol03goo1@00=goo00<007ooOol03Woo1@006Woo
000HOol5000AOol00`00Oomoo`0fOol3000BOol00`00Oomoo`0@Ool00`00Oomoo`0@Ool00`00Oomo
o`0@Ool3000hOol00`00Oomoo`0>Ool5000JOol001Qoo`D0015oo`03001oogoo04]oo`03001oogoo
011oo`03001oogoo011oo`03001oogoo04]oo`03001oogoo00ioo`D001Yoo`006Goo0`004Woo00<0
07ooOol0Bgoo00<007ooOol047oo00<007ooOol047oo00<007ooOol0Bgoo00<007ooOol03goo0`00
6goo000^Ool00`00Oomoo`1;Ool00`00Oomoo`0@Ool00`00Oomoo`0@Ool00`00Oomoo`1;Ool00`00
Oomoo`0]Ool002ioo`03001oogoo04]oo`03001oogoo011oo`03001oogoo011oo`03001oogoo04]o
o`03001oogoo02eoo`00;7oo0`00CGoo00<007ooOol047oo0P004Goo00<007ooOol0BWoo0`00;Woo
000[Ool5001<Ool00`00Oomoo`0@Ool00`00Oomoo`0@Ool00`00Oomoo`19Ool5000]Ool002]oo`D0
04aoo`03001oogoo011oo`03001oogoo011oo`03001oogoo04Uoo`D002eoo`00:goo1@00C7oo00<0
07ooOol047oo00<007ooOol047oo00<007ooOol0BGoo1@00;Goo000/Ool3001=Ool00`00Oomoo`0@
Ool00`00Oomoo`0@Ool00`00Oomoo`1:Ool3000^Ool007aoo`03001oogoo011oo`03001oogoo011o
o`03001oogoo07]oo`00O7oo00<007ooOol047oo0P004Goo00<007ooOol0Ngoo001lOol00`00Oomo
o`0@Ool00`00Oomoo`0@Ool00`00Oomoo`1kOol007aoo`03001oogoo011oo`03001oogoo011oo`03
001oogoo07]oo`00O7oo00<007ooOol047oo00<007ooOol047oo00<007ooOol0Ngoo001lOol00`00
Ool00004Ool00`00Oomoo`050004Ool00`00Oomoo`0@Ool00`00Oomoo`1kOol007aoo`800003Ool0
07oo00Moo`03001oogoo00Aoo`03001oogoo011oo`03001oogoo07]oo`00O7oo0P0000=oo`00Ool0
1goo00<007ooOol017oo0`0047oo00<007ooOol0Ngoo001lOol200000goo001oo`07Ool00`00Oomo
o`04Ool00`00Oomoo`0@Ool00`00Oomoo`1kOol007aoo`800003Ool007oo00Moo`03001oogoo00Ao
o`03001oogoo011oo`03001oogoo07]oo`00O7oo00<007oo000027oo0P001Woo00<007ooOol047oo
00<007ooOol0Ngoo001lOol00`00Oomoo`0@Ool00`00Oomoo`0@Ool00`00Oomoo`1kOol007aoo`03
001oogoo011oo`03001oogoo011oo`03001oogoo07]oo`00O7oo00<007ooOol047oo0P004Goo00<0
07ooOol0Ngoo001lOol00`00Oomoo`0@Ool00`00Oomoo`0@Ool00`00Oomoo`1kOol007aoo`03001o
ogoo011oo`03001oogoo011oo`03001oogoo07]oo`00O7oo00<007ooOol047oo00<007ooOol047oo
00<007ooOol0Ngoo001lOol00`00Oomoo`0@Ool00`00Oomoo`0@Ool00`00Oomoo`1kOol007aoo`03
001oogoo011oo`80015oo`03001oogoo07]oo`00O7oo00<007ooOol047oo00<007ooOol047oo00<0
07ooOol0Ngoo001lOol00`00Oomoo`0@Ool00`00Oomoo`0@Ool00`00Oomoo`1kOol007aoo`03001o
ogoo011oo`03001oogoo011oo`03001oogoo07]oo`00O7oo00<007ooOol047oo00<007ooOol047oo
00<007ooOol0Ngoo001lOol00`00Oomoo`0@Ool00`00Oomoo`0@Ool00`00Oomoo`1kOol007aoo`03
001oogoo011oo`80015oo`03001oogoo07]oo`00O7oo00<007ooOol047oo00<007ooOol047oo00<0
07ooOol0Ngoo001lOol00`00Oomoo`0@Ool00`00Oomoo`0@Ool00`00Oomoo`1kOol007aoo`03001o
ogoo011oo`03001oogoo011oo`03001oogoo07]oo`00O7oo00<007ooOol047oo00<007ooOol047oo
00<007ooOol0Ngoo001lOol00`00Oomoo`0@Ool00`00Oomoo`0@Ool00`00Oomoo`1kOol007aoo`03
001oogoo011oo`80015oo`03001oogoo07]oo`00O7oo00<007ooOol047oo00<007ooOol047oo00<0
07ooOol0Ngoo001lOol00`00Oomoo`0@Ool00`00Oomoo`0@Ool00`00Oomoo`1kOol007aoo`03001o
ogoo011oo`03001oogoo011oo`03001oogoo07]oo`00O7oo00<007oo000017oo00@007ooOomoo`<0
00Eoo`03001oogoo011oo`03001oogoo07]oo`00O7oo0P0000=oo`00Ool01Woo00<007ooOol01Goo
00<007ooOol047oo00<007ooOol0Ngoo001lOol200000goo001oo`07Ool00`00Oomoo`04Ool3000@
Ool00`00Oomoo`1kOol007aoo`800003Ool007oo00Moo`03001oogoo00Aoo`03001oogoo011oo`03
001oogoo07]oo`00O7oo0P0000=oo`00Ool01Woo00<007oo00001Goo00<007ooOol047oo00<007oo
Ool0Ngoo001lOol00`00Ool00009Ool00`00Oomoo`04Ool00`00Oomoo`0@Ool00`00Oomoo`1kOol0
07aoo`03001oogoo011oo`03001oogoo011oo`03001oogoo07]oo`00O7oo00<007ooOol047oo00<0
07ooOol047oo00<007ooOol0Ngoo001lOol00`00Oomoo`0@Ool2000AOol00`00Oomoo`1kOol007ao
o`03001oogoo011oo`03001oogoo011oo`03001oogoo07]oo`00O7oo00<007ooOol047oo00<007oo
Ool047oo00<007ooOol0Ngoo001lOol00`00Oomoo`0@Ool00`00Oomoo`0@Ool00`00Oomoo`1kOol0
07aoo`03001oogoo011oo`03001oogoo011oo`03001oogoo07]oo`00O7oo00<007ooOol047oo00<0
07ooOol047oo00<007ooOol0Ngoo001lOol00`00Oomoo`0@Ool2000AOol00`00Oomoo`1kOol007ao
o`03001oogoo011oo`03001oogoo011oo`03001oogoo07]oo`00O7oo00<007ooOol047oo00<007oo
Ool047oo00<007ooOol0Ngoo001lOol00`00Oomoo`0@Ool00`00Oomoo`0@Ool00`00Oomoo`1kOol0
07aoo`03001oogoo011oo`03001oogoo011oo`03001oogoo07]oo`00O7oo00<007ooOol047oo00<0
07ooOol047oo00<007ooOol0Ngoo001lOol00`00Oomoo`0@Ool2000AOol00`00Oomoo`1kOol007ao
o`03001oogoo011oo`03001oogoo011oo`03001oogoo07]oo`00O7oo00<007ooOol047oo00<007oo
Ool047oo00<007ooOol0Ngoo001lOol00`00Oomoo`0@Ool00`00Oomoo`0@Ool00`00Oomoo`1kOol0
07aoo`03001oogoo011oo`03001oogoo011oo`03001oogoo07]oo`00O7oo00<007ooOol047oo00<0
07ooOol047oo00<007ooOol0Ngoo001lOol00`00Oomoo`0@Ool2000AOol00`00Oomoo`1kOol007ao
o`03001oogoo011oo`03001oogoo011oo`03001oogoo07]oo`00O7oo00<007ooOol047oo00<007oo
Ool047oo00<007ooOol0Ngoo001lOol00`00Ool00004Ool01000Oomoogoo0P001Woo00<007ooOol0
47oo00<007ooOol0Ngoo001lOol200000goo001oo`08Ool00`00Oomoo`03Ool00`00Oomoo`0@Ool0
0`00Oomoo`1kOol007aoo`800003Ool007oo00Moo`03001oogoo00Aoo`<0011oo`03001oogoo07]o
o`00O7oo0P0000=oo`00Ool027oo00<007ooOol00goo00<007ooOol047oo00<007ooOol0Ngoo001l
Ool200000goo001oo`06Ool00`00Ool00005Ool00`00Oomoo`0@Ool00`00Oomoo`1kOol007aoo`03
001oo`0000Uoo`03001oogoo00Aoo`03001oogoo011oo`03001oogoo07]oo`00NWoo0`004Woo00<0
07ooOol03goo0`00O7oo001iOol5000AOol00`00Oomoo`0>Ool5001kOol007Uoo`D0015oo`8000mo
o`D007]oo`00NGoo1@004Goo00<007ooOol03Woo1@00Ngoo001jOol3000BOol00`00Oomoo`0?Ool3
001lOol008moo`03001oogoo08ioo`00Sgoo00<007ooOol0SWoo002?Ool00`00Oomoo`2>Ool008mo
o`8008moo`00Sgoo00<007ooOol0SWoo002?Ool00`00Oomoo`2>Ool008moo`03001oogoo08ioo`00
Sgoo00<007ooOol0SWoo002?Ool00`00Oomoo`2>Ool008moo`8008moo`00Sgoo00<007ooOol0SWoo
002?Ool00`00Oomoo`2>Ool008moo`03001oogoo08ioo`00Sgoo00<007ooOol0SWoo002?Ool00`00
Oomoo`2>Ool008moo`8008moo`00Sgoo00<007ooOol0SWoo002?Ool00`00Oomoo`2>Ool008moo`03
001oogoo08ioo`00OWoo00<007ooOol00Woo00<007ooOol00Woo0`0017oo00<007ooOol0SWoo001m
Ool00`00Ool00009Ool00`00Oomoo`03Ool00`00Oomoo`2>Ool007eoo`03001oo`0000Moo`@000Ao
o`<008ioo`00OGoo00<007oo00001goo00<007oo00001Goo00<007ooOol0SWoo001mOol00`00Ool0
0008Ool20005Ool00`00Oomoo`2>Ool007ioo`03001oogoo00Qoo`03001oogoo00=oo`03001oogoo
08ioo`00Sgoo00<007ooOol0SWoo002?Ool00`00Oomoo`2>Ool008moo`8008moo`00Sgoo00<007oo
Ool0SWoo002?Ool00`00Oomoo`2>Ool008moo`03001oogoo08ioo`00Sgoo00<007ooOol0SWoo002?
Ool2002?Ool008moo`03001oogoo08ioo`00Sgoo00<007ooOol0SWoo002?Ool00`00Oomoo`2>Ool0
08moo`03001oogoo08ioo`00Sgoo00<007ooOol0SWoo002?Ool2002?Ool008ioo`<008moo`00SGoo
1@00SWoo002=Ool5002>Ool008eoo`D008ioo`00SWoo0`00Sgoo002?Ool2002?Ool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-7.36823, -0.122235, 
  0.0513466, 0.00340947}}]
}, Open  ]],

Cell["\<\
The edge of the passband for this filter is located at (in radians/second):\
\>", "Text",
  FontFamily->"Times New Roman"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\(2  \[Pi]\)\/L\) \((BW - 1)\)\)], "Input",
  CellLabel->"In[10]:="],

Cell[BoxData[
    \(\(2\ \[Pi]\)\/5\)], "Output",
  CellLabel->"Out[10]="]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["VERIFICATION OF FREQUENCY RESPONSE", "Section",
  PageWidth->WindowWidth,
  Evaluatable->False,
  CellHorizontalScrolling->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "The frequency response of the filter may be obtained by calculating the \
DTFT of the impulse response sequence ",
  Cell[BoxData[
      \(TraditionalForm\`h\)]],
  ". Note the rather poor peak attenuation of about -18 dB. "
}], "Text",
  Evaluatable->False,
  FontFamily->"Times New Roman"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(ListMagnitudePlot[h]; \)\)], "Input",
  CellLabel->"In[8]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 1.90476 0.596823 0.00722606 [
[.21429 .58432 -9 -9 ]
[.21429 .58432 9 0 ]
[.40476 .58432 -9 -9 ]
[.40476 .58432 9 0 ]
[.59524 .58432 -9 -9 ]
[.59524 .58432 9 0 ]
[.78571 .58432 -9 -9 ]
[.78571 .58432 9 0 ]
[.97619 .58432 -9 -9 ]
[.97619 .58432 9 0 ]
[.01131 .01874 -18 -4.5 ]
[.01131 .01874 0 4.5 ]
[.01131 .16326 -18 -4.5 ]
[.01131 .16326 0 4.5 ]
[.01131 .30778 -18 -4.5 ]
[.01131 .30778 0 4.5 ]
[.01131 .4523 -18 -4.5 ]
[.01131 .4523 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.21429 .59682 m
.21429 .60307 L
s
[(0.1)] .21429 .58432 0 1 Mshowa
.40476 .59682 m
.40476 .60307 L
s
[(0.2)] .40476 .58432 0 1 Mshowa
.59524 .59682 m
.59524 .60307 L
s
[(0.3)] .59524 .58432 0 1 Mshowa
.78571 .59682 m
.78571 .60307 L
s
[(0.4)] .78571 .58432 0 1 Mshowa
.97619 .59682 m
.97619 .60307 L
s
[(0.5)] .97619 .58432 0 1 Mshowa
.125 Mabswid
.0619 .59682 m
.0619 .60057 L
s
.1 .59682 m
.1 .60057 L
s
.1381 .59682 m
.1381 .60057 L
s
.17619 .59682 m
.17619 .60057 L
s
.25238 .59682 m
.25238 .60057 L
s
.29048 .59682 m
.29048 .60057 L
s
.32857 .59682 m
.32857 .60057 L
s
.36667 .59682 m
.36667 .60057 L
s
.44286 .59682 m
.44286 .60057 L
s
.48095 .59682 m
.48095 .60057 L
s
.51905 .59682 m
.51905 .60057 L
s
.55714 .59682 m
.55714 .60057 L
s
.63333 .59682 m
.63333 .60057 L
s
.67143 .59682 m
.67143 .60057 L
s
.70952 .59682 m
.70952 .60057 L
s
.74762 .59682 m
.74762 .60057 L
s
.82381 .59682 m
.82381 .60057 L
s
.8619 .59682 m
.8619 .60057 L
s
.9 .59682 m
.9 .60057 L
s
.9381 .59682 m
.9381 .60057 L
s
.25 Mabswid
0 .59682 m
1 .59682 L
s
.02381 .01874 m
.03006 .01874 L
s
[(-80)] .01131 .01874 1 0 Mshowa
.02381 .16326 m
.03006 .16326 L
s
[(-60)] .01131 .16326 1 0 Mshowa
.02381 .30778 m
.03006 .30778 L
s
[(-40)] .01131 .30778 1 0 Mshowa
.02381 .4523 m
.03006 .4523 L
s
[(-20)] .01131 .4523 1 0 Mshowa
.125 Mabswid
.02381 .05487 m
.02756 .05487 L
s
.02381 .091 m
.02756 .091 L
s
.02381 .12713 m
.02756 .12713 L
s
.02381 .19939 m
.02756 .19939 L
s
.02381 .23552 m
.02756 .23552 L
s
.02381 .27165 m
.02756 .27165 L
s
.02381 .34391 m
.02756 .34391 L
s
.02381 .38004 m
.02756 .38004 L
s
.02381 .41617 m
.02756 .41617 L
s
.02381 .48843 m
.02756 .48843 L
s
.02381 .52456 m
.02756 .52456 L
s
.02381 .56069 m
.02756 .56069 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
.5 Mabswid
.02381 .59682 m
.06244 .59717 L
.08255 .59746 L
.08806 .59753 L
.09109 .59756 L
.09396 .59758 L
.09662 .5976 L
.09803 .59761 L
.09952 .59762 L
.10077 .59763 L
.10215 .59763 L
.1034 .59763 L
.10458 .59764 L
.10585 .59764 L
.10702 .59764 L
.10831 .59764 L
.10903 .59764 L
.10968 .59764 L
.11088 .59763 L
.11218 .59763 L
.11454 .59762 L
.11684 .5976 L
.11928 .59758 L
.12364 .59752 L
.1287 .59744 L
.13342 .59735 L
.14415 .59705 L
.1645 .59626 L
.18306 .5954 L
.19231 .59499 L
.20215 .59461 L
.20727 .59444 L
.20999 .59437 L
.21293 .5943 L
.21561 .59425 L
.21807 .59421 L
.22043 .59418 L
.22161 .59417 L
.22291 .59417 L
.22423 .59416 L
.22544 .59416 L
.22608 .59416 L
.22678 .59416 L
.22751 .59416 L
.22819 .59416 L
.22945 .59417 L
.2306 .59418 L
.23192 .59419 L
.23318 .59421 L
.2355 .59424 L
Mistroke
.23765 .59429 L
.24252 .59442 L
.24784 .59463 L
.25266 .59487 L
.26347 .59557 L
.28275 .59733 L
.30359 .59962 L
.32317 .60167 L
.32854 .60213 L
.33428 .60256 L
.33967 .60289 L
.34464 .60312 L
.34711 .6032 L
.34974 .60327 L
.3511 .60329 L
.35237 .60331 L
.3531 .60331 L
.35377 .60332 L
.3545 .60332 L
.35528 .60332 L
.35648 .60331 L
.35777 .6033 L
.35898 .60328 L
.36008 .60326 L
.36138 .60323 L
.36279 .60319 L
.36534 .60308 L
.36761 .60297 L
.3701 .60281 L
.37515 .60239 L
.37982 .60188 L
.38418 .60129 L
.39461 .59939 L
.40451 .5969 L
.41339 .59402 L
.42306 .59011 L
.44281 .57918 L
.45278 .57184 L
.46381 .56197 L
.48313 .53863 L
.494 .52049 L
.50398 .4985 L
.50907 .48414 L
.51389 .46745 L
.51655 .45631 L
.51943 .44193 L
.52448 .40667 L
.52568 .3948 L
.52697 .3792 L
.52819 .36015 L
Mistroke
.5293 .33607 L
.53055 .29073 L
.53173 .01472 L
.53301 .29283 L
.53374 .32086 L
.53441 .33878 L
.53561 .36147 L
.53673 .37696 L
.53884 .39791 L
.54111 .41403 L
.54357 .42717 L
.54817 .44491 L
.55078 .45244 L
.55322 .45832 L
.55814 .4677 L
.5634 .47503 L
.56831 .47996 L
.57072 .48184 L
.57295 .4833 L
.57712 .48537 L
.57931 .48614 L
.58165 .48674 L
.58278 .48695 L
.58403 .48712 L
.58533 .48723 L
.58654 .48728 L
.58768 .48727 L
.58871 .48723 L
.5899 .48712 L
.59103 .48698 L
.59225 .48676 L
.59355 .48648 L
.59588 .48582 L
.59838 .48489 L
.60113 .4836 L
.60569 .48084 L
.61058 .47697 L
.61942 .46729 L
.62468 .45956 L
.62956 .45073 L
.63491 .43861 L
.64061 .42172 L
.64322 .41193 L
.64605 .39921 L
.64871 .38422 L
.65116 .36639 L
.65239 .35509 L
.65373 .34002 L
.65499 .32155 L
.65616 .29785 L
Mistroke
.65721 .26465 L
.65837 .17412 L
.65958 .22773 L
.66071 .28069 L
.6619 .30987 L
.66299 .32811 L
.66424 .344 L
.66543 .35597 L
.66785 .37458 L
.67048 .38967 L
.6752 .40914 L
.67959 .42211 L
.68484 .43368 L
.6896 .44159 L
.69509 .4485 L
.70027 .45328 L
.70492 .45639 L
.70756 .45771 L
.71003 .45866 L
.71137 .45908 L
.71263 .4594 L
.71378 .45964 L
.71501 .45984 L
.71564 .45992 L
.71633 .45999 L
.71756 .46007 L
.71825 .46009 L
.71899 .46009 L
.7197 .46007 L
.72034 .46004 L
.72142 .45995 L
.72257 .4598 L
.72365 .45962 L
.72464 .45941 L
.72705 .45875 L
.72934 .45793 L
.73388 .45567 L
.73881 .45227 L
.7437 .44781 L
.74827 .44254 L
.75329 .4353 L
.75868 .42543 L
.76432 .41194 L
.76967 .39462 L
.77448 .37264 L
.7772 .35534 L
.77972 .3333 L
.78101 .31807 L
.78171 .30786 L
.78237 .29658 L
Mistroke
.78353 .26972 L
.78481 .21459 L
.78552 .11774 L
.7862 .17461 L
.78746 .25539 L
.78817 .27667 L
.78882 .29142 L
.79031 .31566 L
.79149 .32991 L
.7926 .34077 L
.79514 .35995 L
.79761 .37402 L
.80027 .38601 L
.80501 .40227 L
.80999 .41488 L
.81424 .42321 L
.81889 .43043 L
.82418 .43679 L
.82918 .44129 L
.83367 .44428 L
.8362 .44557 L
.83853 .44652 L
.83974 .44692 L
.84104 .44729 L
.84216 .44756 L
.84338 .44779 L
.84412 .4479 L
.84481 .44799 L
.84547 .44805 L
.84617 .4481 L
.84738 .44815 L
.84807 .44815 L
.84871 .44813 L
.85003 .44805 L
.85069 .44798 L
.85142 .44789 L
.8527 .44768 L
.8539 .44742 L
.8566 .44665 L
.85949 .4455 L
.86207 .44419 L
.8648 .4425 L
.86971 .43861 L
.87499 .43308 L
.8808 .42506 L
.88581 .41609 L
.8912 .40355 L
.89629 .38768 L
.90094 .36744 L
.90344 .35269 L
Mistroke
.90571 .33523 L
.90697 .32285 L
.90832 .30591 L
.90961 .28413 L
.91079 .25391 L
.91189 .20029 L
.91291 .11556 L
.91403 .23132 L
.91524 .27162 L
.9165 .29687 L
.91769 .31394 L
.91993 .33697 L
.92243 .35528 L
.92509 .36999 L
.92986 .38942 L
.93499 .40443 L
.94066 .41668 L
.945 .42394 L
.94958 .43007 L
.95353 .43432 L
.95776 .43794 L
.96232 .44091 L
.96436 .44194 L
.96656 .44286 L
.96791 .44333 L
.96916 .44369 L
.97032 .44398 L
.97161 .44424 L
.97276 .44441 L
.97383 .44453 L
.97497 .44461 L
.97619 .44464 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[8]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol001Eoo`03001oogoo0?moo`Uoo`005Goo00<007ooOol0
ogoo2Goo000EOol00`00Oomoo`3oOol9Ool000Yoo`03001oogoo009oo`03001oogoo00=oo`03001o
ogoo0?moo`Uoo`002Goo00<007oo00000Woo00<007oo000017oo00<007ooOol0QWoo00<007ooOol0
Ogoo0004Ool30002Ool00`00Ool00002Ool00`00Ool00004Ool30026Ool00`00Oomoo`1oOol000Yo
o`07001oogooOol007oo000017oo00<007ooOol0QWoo00<007ooOol0Ogoo0009Ool00`00Ool00002
Ool00`00Ool00004Ool00`00Oomoo`26Ool00`00Oomoo`1oOol000Yoo`03001oogoo009oo`03001o
ogoo00=oo`03001oogoo08Ioo`03001oogoo07moo`005Goo00<007ooOol0QWoo00<007ooOol0Ogoo
000EOol00`00Oomoo`26Ool00`00Oomoo`1oOol001Eoo`03001oogoo08Ioo`03001oogoo07moo`00
5Goo00<007ooOol0QWoo00<007ooOol0Ogoo000EOol00`00Oomoo`26Ool00`00Oomoo`1oOol001Eo
o`03001oogoo08Ioo`03001oogoo07moo`005Goo0P00Qgoo00<007ooOol0Ogoo000EOol00`00Oomo
o`26Ool00`00Oomoo`1oOol001Eoo`03001oogoo08Ioo`03001oogoo07moo`005Goo00<007ooOol0
QWoo00<007ooOol0Ogoo000EOol00`00Oomoo`26Ool00`00Oomoo`1oOol001Eoo`03001oogoo08Io
o`03001oogoo07moo`005Goo00<007ooOol0QWoo00<007ooOol0Ogoo000EOol00`00Oomoo`26Ool0
0`00Oomoo`1oOol001Eoo`03001oogoo08Ioo`03001oogoo07moo`005Goo0P00Qgoo00<007ooOol0
Ogoo000EOol00`00Oomoo`26Ool00`00Oomoo`1oOol001Eoo`03001oogoo08Ioo`03001oogoo07mo
o`005Goo00<007ooOol0QWoo00<007ooOol0Ogoo000EOol00`00Oomoo`26Ool00`00Oomoo`1oOol0
01Eoo`03001oogoo08Ioo`03001oogoo07moo`005Goo00<007ooOol0QWoo00<007ooOol0Ogoo000E
Ool00`00Oomoo`26Ool00`00Oomoo`11Ool00`00Oomoo`0OOol00`00Oomoo`0IOol001Eoo`03001o
ogoo08Ioo`03001oogoo045oo`03001oogoo01moo`03001oogoo01Uoo`005Goo00<007ooOol0QWoo
00<007ooOol0@Goo00<007ooOol07goo00<007ooOol06Goo000EOol20027Ool00`00Oomoo`11Ool0
0`00Oomoo`0OOol00`00Oomoo`0IOol001Eoo`03001oogoo08Ioo`03001oogoo045oo`03001oogoo
01moo`03001oogoo01Uoo`005Goo00<007ooOol0QWoo00<007ooOol0@Goo00<007ooOol07goo00<0
07ooOol06Goo000EOol00`00Oomoo`26Ool00`00Oomoo`11Ool00`00Oomoo`0OOol00`00Oomoo`0I
Ool001Eoo`03001oogoo08Ioo`03001oogoo045oo`03001oogoo01moo`03001oogoo01Uoo`005Goo
00<007ooOol0QWoo00<007ooOol0@Goo00<007ooOol07goo00<007ooOol06Goo000EOol00`00Oomo
o`26Ool00`00Oomoo`11Ool00`00Oomoo`0OOol00`00Oomoo`0IOol001Eoo`03001oogoo08Eoo`80
04=oo`03001oogoo01moo`03001oogoo01Uoo`002Goo0P0017oo00<007ooOol00goo00<007ooOol0
QGoo0P00@goo00<007ooOol07goo00<007ooOol06Goo0009Ool00`00Ool00002Ool00`00Ool00004
Ool00`00Oomoo`25Ool20013Ool00`00Oomoo`0OOol00`00Oomoo`0IOol000Aoo`<0009oo`03001o
o`00009oo`03001oo`0000Aoo`<008Eoo`8004=oo`03001oogoo01moo`03001oogoo01Uoo`002Goo
0P000goo00<007oo000017oo00<007ooOol0QGoo0P00@goo00<007ooOol07goo00<007ooOol06Goo
0009Ool00`00Oomoo`02Ool00`00Ool00004Ool00`00Oomoo`25Ool20013Ool00`00Oomoo`0OOol0
0`00Oomoo`0IOol000Yoo`8000=oo`03001oogoo00=oo`03001oogoo08Eoo`80025oo`03001oogoo
01moo`03001oogoo01moo`8001Yoo`005Goo00<007ooOol0QGoo0P008Goo00<007ooOol07goo00<0
07ooOol07goo0P006Woo000EOol00`00Oomoo`25Ool2000QOol00`00Oomoo`0OOol00`00Oomoo`0O
Ool2000JOol001Eoo`03001oogoo08Eoo`80025oo`03001oogoo01moo`03001oogoo01moo`8001Yo
o`005Goo00<007ooOol0QGoo0P008Goo00<007ooOol07goo00<007ooOol07goo0P006Woo000EOol0
0`00Oomoo`25Ool2000QOol00`00Oomoo`0OOol00`00Oomoo`0OOol2000JOol001Eoo`8008Ioo`80
025oo`03001oogoo01moo`03001oogoo01moo`8001Yoo`005Goo00<007ooOol0QGoo0P008Goo00<0
07ooOol07goo00<007ooOol07goo0P006Woo000EOol00`00Oomoo`25Ool2000QOol00`00Oomoo`0O
Ool00`00Oomoo`0OOol2000JOol001Eoo`03001oogoo08Eoo`80025oo`03001oogoo01moo`03001o
ogoo01moo`8001Yoo`005Goo00<007ooOol0QGoo0P008Goo00<007ooOol07goo00<007ooOol07goo
0P006Woo000EOol00`00Oomoo`25Ool2000QOol00`00Oomoo`0OOol00`00Oomoo`0OOol2000JOol0
01Eoo`03001oogoo08Eoo`80025oo`03001oogoo01moo`80021oo`8001Yoo`005Goo00<007ooOol0
QGoo0P008Goo00<007ooOol07goo0P0087oo0P006Woo000EOol00`00Oomoo`25Ool2000QOol00`00
Oomoo`0OOol2000POol2000JOol001Eoo`03001oogoo08Eoo`80025oo`03001oogoo01moo`80021o
o`8001Yoo`005Goo0P00QWoo0P008Goo00<007ooOol07goo0P0087oo0P006Woo000EOol00`00Oomo
o`25Ool2000QOol00`00Oomoo`0OOol2000POol2000JOol001Eoo`03001oogoo08Eoo`80025oo`03
001oogoo01moo`80021oo`8001Yoo`005Goo00<007ooOol0QGoo0P008Goo00<007ooOol07goo0P00
87oo0P006Woo000EOol00`00Oomoo`25Ool2000QOol00`00Oomoo`0OOol2000POol2000JOol001Eo
o`03001oogoo08Eoo`80025oo`03001oogoo01moo`80021oo`8001Yoo`005Goo00<007ooOol0QGoo
0P008Goo00<007ooOol07goo0P0087oo0P006Woo000EOol00`00Oomoo`25Ool2000QOol00`00Oomo
o`0OOol2000POol2000JOol001Eoo`03001oogoo08Eoo`80025oo`03001oogoo01moo`80021oo`80
01Yoo`005Goo00<007ooOol0QGoo0P008Goo00<007ooOol07goo0P0087oo0P006Woo000EOol20026
Ool2000QOol00`00Oomoo`0OOol2000POol2000JOol001Eoo`03001oogoo08Eoo`80025oo`03001o
ogoo01moo`80021oo`8001Yoo`005Goo00<007ooOol0QGoo0P008Goo00<007ooOol07goo0P0087oo
0P006Woo000EOol00`00Oomoo`25Ool2000POol2000POol00`00Ool0000POol2000JOol001Eoo`03
001oogoo08Eoo`80021oo`80021oo`03001oo`00021oo`8001Yoo`005Goo00<007ooOol0QGoo0P00
87oo0P0087oo00<007oo000087oo0P006Woo000EOol00`00Oomoo`25Ool2000POol2000POol00`00
Ool0000OOol00`00Ool0000JOol001Eoo`03001oogoo08Eoo`80021oo`03001oo`0001moo`03001o
o`0001moo`03001oo`0001Yoo`002Woo0`000Woo00<007ooOol00goo00<007ooOol0QGoo0P0087oo
00<007oo00007goo00<007oo00007goo00<007oo00006Woo000;Ool01P00Oomoo`00Ool000Aoo`03
001oogoo08Eoo`80021oo`03001oo`0001moo`03001oo`0001moo`03001oo`0001Yoo`0017oo0`00
0Woo100000Aoo`00Ool000Aoo`<008Eoo`80021oo`03001oo`0001moo`03001oo`0001moo`04001o
ogoo000IOol000Uoo`03001oo`00009oo`03001oo`0000Aoo`03001oogoo08Eoo`80021oo`03001o
o`0001moo`03001oo`0001moo`04001oogoo000IOol000Yoo`80009oo`03001oo`0000Aoo`03001o
ogoo08Eoo`80021oo`03001oo`0001moo`03001oo`0001moo`04001oogoo000IOol000]oo`05001o
ogooOol00005Ool00`00Oomoo`25Ool2000POol00`00Ool0000OOol00`00Ool0000OOol01000Oomo
o`006Goo000EOol00`00Oomoo`25Ool2000POol00`00Ool0000OOol00`00Ool0000OOol01000Oomo
o`006Goo000EOol00`00Oomoo`25Ool2000POol00`00Ool0000OOol01000Oomoo`007Woo00@007oo
Ool001Uoo`005Goo00<007ooOol0QGoo0P0087oo00<007oo00007goo00@007ooOol001ioo`04001o
ogoo000IOol001Eoo`03001oogoo08Eoo`80021oo`03001oo`0001moo`04001oogoo000NOol01000
Oomoo`006Goo000EOol00`00Oomoo`25Ool2000POol00`00Ool0000OOol01000Oomoo`007Woo00@0
07ooOol001Uoo`005Goo0P00QWoo0P0087oo00<007oo00007goo00@007ooOol001ioo`04001oogoo
000IOol001Eoo`03001oogoo08Eoo`8001moo`04001oogoo000NOol01@00Oomoogoo00007Goo00D0
07ooOomoo`0001Uoo`005Goo00<007ooOol0QGoo0P007goo00@007ooOol001ioo`05001oogooOol0
000MOol00`00Oomoo`02Ool00`00Oomoo`0FOol001Eoo`03001oogoo08Eoo`03001oo`0001ioo`05
001oogooOol0000MOol00`00Oomoo`02Ool00`00Oomoo`0JOol00`00Oomoo`02Ool00`00Oomoo`0F
Ool001Eoo`03001oogoo08Eoo`03001oo`0001ioo`05001oogooOol0000MOol00`00Oomoo`02Ool0
0`00Oomoo`0JOol00`00Oomoo`02Ool00`00Oomoo`0FOol001Eoo`03001oogoo08Eoo`03001oo`00
01ioo`05001oogooOol0000MOol00`00Oomoo`02Ool00`00Oomoo`0IOol00`00Oomoo`03Ool00`00
Oomoo`0FOol001Eoo`03001oogoo08Eoo`03001oo`0001ioo`05001oogooOol0000LOol00`00Oomo
o`03Ool00`00Oomoo`0IOol00`00Oomoo`04Ool00`00Oomoo`0EOol001Eoo`03001oogoo08Eoo`03
001oo`0001ioo`05001oogooOol0000LOol00`00Oomoo`03Ool00`00Oomoo`0IOol00`00Oomoo`04
Ool00`00Oomoo`0EOol001Eoo`03001oogoo08Aoo`04001oogoo000NOol01@00Oomoogoo000077oo
00<007ooOol00goo00<007ooOol06Goo00<007ooOol017oo00<007ooOol05Goo000EOol00`00Oomo
o`24Ool01000Oomoo`007Goo00<007ooOol00Woo00<007ooOol06Woo00<007ooOol00goo00<007oo
Ool06Goo00<007ooOol017oo00<007ooOol05Goo000EOol20025Ool01000Oomoo`007Goo00<007oo
Ool00Woo00<007ooOol06Woo00<007ooOol00goo00<007ooOol067oo00<007ooOol01Goo00<007oo
Ool05Goo000EOol00`00Oomoo`24Ool01000Oomoo`007Goo00<007ooOol00Woo00<007ooOol06Goo
00<007ooOol01Goo00<007ooOol05goo00<007ooOol01Woo00<007ooOol057oo000EOol00`00Oomo
o`24Ool01000Oomoo`007Goo00<007ooOol00goo00<007ooOol067oo00<007ooOol01Goo00<007oo
Ool05goo00<007ooOol01Woo00<007ooOol057oo000EOol00`00Oomoo`24Ool01@00Oomoogoo0000
77oo00<007ooOol00goo00<007ooOol067oo00<007ooOol01Goo00<007ooOol05goo00<007ooOol0
1Woo00<007ooOol057oo000EOol00`00Oomoo`24Ool01@00Oomoogoo000077oo00<007ooOol00goo
00<007ooOol067oo00<007ooOol01Goo00<007ooOol05goo00<007ooOol01Woo00<007ooOol057oo
000EOol00`00Oomoo`24Ool01@00Oomoogoo000077oo00<007ooOol00goo00<007ooOol067oo00<0
07ooOol01Woo00<007ooOol05Goo00<007ooOol01goo00<007ooOol057oo000EOol00`00Oomoo`24
Ool01@00Oomoogoo000077oo00<007ooOol017oo00<007ooOol05Woo00<007ooOol01goo00<007oo
Ool05Goo00<007ooOol027oo00<007ooOol04goo000EOol00`00Oomoo`24Ool01@00Oomoogoo0000
6goo00<007ooOol01Goo00<007ooOol05Woo00<007ooOol01goo00<007ooOol05Goo00<007ooOol0
27oo00<007ooOol04goo000EOol00`00Oomoo`24Ool01@00Oomoogoo00006goo00<007ooOol01Goo
00<007ooOol05Goo00<007ooOol02Goo00<007ooOol04goo00<007ooOol02Woo00<007ooOol04Woo
000EOol00`00Oomoo`24Ool01@00Oomoogoo00006goo00<007ooOol01Goo00<007ooOol05Goo00<0
07ooOol02Goo00<007ooOol04goo00<007ooOol02Woo00<007ooOol04Woo000EOol20024Ool00`00
Oomoo`02Ool00`00Oomoo`0HOol00`00Oomoo`07Ool00`00Oomoo`0DOol00`00Oomoo`0:Ool00`00
Oomoo`0AOol00`00Oomoo`0<Ool00`00Oomoo`0AOol001Eoo`03001oogoo08=oo`03001oogoo009o
o`03001oogoo01Qoo`03001oogoo00Moo`03001oogoo01=oo`03001oogoo00]oo`03001oogoo011o
o`03001oogoo00eoo`03001oogoo015oo`005Goo00<007ooOol0Pgoo00<007ooOol00goo00<007oo
Ool05goo00<007ooOol027oo00<007ooOol04Woo00<007ooOol037oo00<007ooOol03goo00<007oo
Ool03Woo00<007ooOol047oo000EOol00`00Oomoo`23Ool00`00Oomoo`03Ool00`00Oomoo`0GOol0
0`00Oomoo`08Ool00`00Oomoo`0AOol00`00Oomoo`0=Ool00`00Oomoo`0>Ool00`00Oomoo`0?Ool0
0`00Oomoo`0@Ool001Eoo`03001oogoo08=oo`03001oogoo00=oo`03001oogoo01Ioo`03001oogoo
00Yoo`03001oogoo011oo`03001oogoo00ioo`03001oogoo00aoo`03001oogoo015oo`03001oogoo
00moo`005Goo00<007ooOol0PWoo00<007ooOol017oo00<007ooOol05Woo00<007ooOol02Woo00<0
07ooOol03goo00<007ooOol047oo0P002goo00<007ooOol04goo00<007ooOol03Woo000EOol00`00
Oomoo`22Ool00`00Oomoo`05Ool00`00Oomoo`0EOol00`00Oomoo`0:Ool00`00Oomoo`0>Ool00`00
Oomoo`0BOol00`00Oomoo`09Ool00`00Oomoo`0DOol2000>Ool001Eoo`03001oogoo089oo`03001o
ogoo00Eoo`03001oogoo01Aoo`03001oogoo00aoo`03001oogoo00eoo`03001oogoo01=oo`8000Mo
o`8001Uoo`<000]oo`002Goo0`000goo00<007ooOol00goo00<007ooOol0PWoo00<007ooOol01Goo
00<007ooOol057oo00<007ooOol03Goo00<007ooOol02goo00<007ooOol05Woo0`0000Aoo`000000
01ioo`8000Uoo`002Goo00<007ooOol00Woo00<007oo000017oo00<007ooOol0PWoo00<007ooOol0
1Goo00<007ooOol04goo00<007ooOol03goo00<007ooOol02Goo00<007ooOol06Goo0P00;7oo0004
Ool30003Ool01`00Oomoogoo001oo`0000Aoo`<0089oo`03001oogoo00Ioo`03001oogoo019oo`03
001oogoo011oo`03001oogoo00Qoo`03001oogoo04Moo`002Woo00L007ooOomoo`00Ool00004Ool0
0`00Oomoo`22Ool00`00Oomoo`07Ool00`00Oomoo`0@Ool00`00Oomoo`0BOol30003Ool4001:Ool0
00Uoo`03001oo`00009oo`03001oo`0000Aoo`03001oogoo089oo`03001oogoo00Moo`03001oogoo
011oo`03001oogoo01Aoo`D004eoo`002Woo00<007ooOol00Woo00<007ooOol00goo00<007ooOol0
PGoo00<007ooOol02Goo00<007ooOol03Woo00<007ooOol0Igoo000EOol00`00Oomoo`21Ool00`00
Oomoo`09Ool00`00Oomoo`0=Ool00`00Oomoo`1XOol001Eoo`03001oogoo085oo`03001oogoo00Uo
o`03001oogoo00aoo`03001oogoo06Uoo`005Goo00<007ooOol0P7oo00<007ooOol02goo00<007oo
Ool02Woo00<007ooOol0JWoo000EOol00`00Oomoo`20Ool00`00Oomoo`0<Ool20009Ool00`00Oomo
o`1[Ool001Eoo`03001oogoo081oo`03001oogoo00eoo`8000Ioo`8006ioo`005Goo0P00P7oo00<0
07ooOol047oo1P00L7oo000EOol00`00Oomoo`1oOol00`00Oomoo`26Ool001Eoo`03001oogoo07io
o`03001oogoo08Moo`005Goo00<007ooOol0OWoo00<007ooOol0Qgoo000EOol00`00Oomoo`1nOol0
0`00Oomoo`27Ool001Eoo`03001oogoo07eoo`03001oogoo08Qoo`005Goo00<007ooOol0OGoo00<0
07ooOol0R7oo000EOol00`00Oomoo`1mOol00`00Oomoo`28Ool001Eoo`03001oogoo07aoo`03001o
ogoo08Uoo`005Goo00<007ooOol0O7oo00<007ooOol0RGoo000EOol2001lOol00`00Oomoo`2:Ool0
01Eoo`03001oogoo07]oo`03001oogoo08Yoo`005Goo00<007ooOol0NWoo00<007ooOol0Rgoo000E
Ool00`00Oomoo`1jOol00`00Oomoo`2;Ool001Eoo`03001oogoo07Uoo`03001oogoo08aoo`005Goo
00<007ooOol0N7oo00<007ooOol0SGoo000EOol00`00Oomoo`1gOol00`00Oomoo`2>Ool001Eoo`03
001oogoo07Ioo`03001oogoo08moo`005Goo00<007ooOol0:goo00<007ooOol00Woo00<007ooOol0
1@009Woo00<007ooOol00Woo00@007ooOomoo`<000]oo`03001oogoo01Uoo`03001oogoo009oo`04
001oogooOol2000YOol00`00Oomoo`02Ool00`00Oomoo`02Ool3000VOol00`00Oomoo`02Ool00`00
Oomoo`02Ool00`00Oomoo`03Ool001Eoo`03001oogoo02Yoo`03001oo`0000Qoo`03001oogoo02Eo
o`03001oo`0000Moo`03001oogoo00Yoo`03001oogoo01Uoo`03001oo`0000Uoo`03001oogoo02Eo
o`03001oo`0000Uoo`03001oogoo02Aoo`03001oo`0000Moo`03001oo`0000Aoo`005Goo0P00:goo
00<007oo000027oo00<007ooOol09Goo00<007oo000027oo00<007ooOol027oo00<007ooOol06Woo
00<007oo000027oo00<007ooOol09Woo00<007oo00001goo10009Goo00<007oo00002Goo00<007oo
Ool00Woo000EOol00`00Oomoo`0ZOol00`00Ool00008Ool00`00Oomoo`0UOol00`00Ool00008Ool0
0`00Oomoo`07Ool00`00Oomoo`0KOol00`00Ool00009Ool00`00Oomoo`0UOol00`00Ool00007Ool0
0`00Ool0000VOol00`00Ool00007Ool20005Ool001Eoo`03001oogoo02Yoo`03001oo`0000Qoo`03
001oogoo02Eoo`03001oo`0000Moo`03001oo`0000Moo`03001oogoo01aoo`03001oo`0000Moo`03
001oo`0002Moo`03001oo`0000Qoo`8002Ioo`03001oo`0000Moo`03001oogoo00Aoo`005Goo00<0
07ooOol0:goo00<007ooOol01Woo0P00:7oo00<007ooOol01goo00<007ooOol01Goo00<007ooOol0
7Woo00<007ooOol01goo00<007ooOol09goo00<007ooOol027oo00<007ooOol09Goo00<007ooOol0
1Woo0`0017oo000EOol00`00Oomoo`1_Ool00`00Oomoo`2FOol001Eoo`03001oogoo06ioo`03001o
ogoo09Moo`005Goo00<007ooOol0K7oo0P00VWoo000EOol00`00Oomoo`1ZOol2002LOol001Eoo`03
001oogoo06Qoo`8009ioo`005Goo00<007ooOol08Goo7`009Goo0`00X7oo000>Oooo000@0003Ool0
01Eoo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Qoo`03001oogoo00Moo`03001oogoo
00Moo`03001oogoo00Moo`03001oogoo00Qoo`03001oogoo00=ooaD000Aoo`03001oogoo00Moo`03
001oogoo00Moo`03001oogoo00Moo`03001oogoo00Qoo`03001oogoo00Moo`03001oogoo00Moo`03
001oogoo00Moo`03001oogoo00Qoo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Moo`03
001oogoo00Qoo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Qoo`03001oogoo00Moo`00
5Goo00<007ooOol0ogoo2Goo000EOol00`00Oomoo`3oOol9Ool001Eoo`03001oogoo0?moo`Uoo`00
5Goo00<007ooOol0ogoo2Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.0416348, -85.2644, 
  0.00194834, 0.513574}}]
}, Open  ]],

Cell["\<\
Here we show the resultant magnitude response superimposed on the desired \
amplitude values.  \
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[
      ListMagnitudePlot[h, \ Decibel -> False, DisplayFunction -> Identity], 
      Graphics[Table[{PointSize[0.03], \n\t\t\t\t
            Point[{\(1\/L\) \((i - 1)\), Amplitude[\([i]\)]}]}, {i, 
            Length[Amplitude]}]], \ DisplayFunction -> $DisplayFunction]; 
    \)\)], "Input",
  CellLabel->"In[10]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 1.90476 0.0147151 0.530736 [
[.21429 .00222 -9 -9 ]
[.21429 .00222 9 0 ]
[.40476 .00222 -9 -9 ]
[.40476 .00222 9 0 ]
[.59524 .00222 -9 -9 ]
[.59524 .00222 9 0 ]
[.78571 .00222 -9 -9 ]
[.78571 .00222 9 0 ]
[.97619 .00222 -9 -9 ]
[.97619 .00222 9 0 ]
[.01131 .12086 -18 -4.5 ]
[.01131 .12086 0 4.5 ]
[.01131 .22701 -18 -4.5 ]
[.01131 .22701 0 4.5 ]
[.01131 .33316 -18 -4.5 ]
[.01131 .33316 0 4.5 ]
[.01131 .4393 -18 -4.5 ]
[.01131 .4393 0 4.5 ]
[.01131 .54545 -6 -4.5 ]
[.01131 .54545 0 4.5 ]
[ 0 -0.00028 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.21429 .01472 m
.21429 .02097 L
s
[(0.1)] .21429 .00222 0 1 Mshowa
.40476 .01472 m
.40476 .02097 L
s
[(0.2)] .40476 .00222 0 1 Mshowa
.59524 .01472 m
.59524 .02097 L
s
[(0.3)] .59524 .00222 0 1 Mshowa
.78571 .01472 m
.78571 .02097 L
s
[(0.4)] .78571 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(0.5)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.0619 .01472 m
.0619 .01847 L
s
.1 .01472 m
.1 .01847 L
s
.1381 .01472 m
.1381 .01847 L
s
.17619 .01472 m
.17619 .01847 L
s
.25238 .01472 m
.25238 .01847 L
s
.29048 .01472 m
.29048 .01847 L
s
.32857 .01472 m
.32857 .01847 L
s
.36667 .01472 m
.36667 .01847 L
s
.44286 .01472 m
.44286 .01847 L
s
.48095 .01472 m
.48095 .01847 L
s
.51905 .01472 m
.51905 .01847 L
s
.55714 .01472 m
.55714 .01847 L
s
.63333 .01472 m
.63333 .01847 L
s
.67143 .01472 m
.67143 .01847 L
s
.70952 .01472 m
.70952 .01847 L
s
.74762 .01472 m
.74762 .01847 L
s
.82381 .01472 m
.82381 .01847 L
s
.8619 .01472 m
.8619 .01847 L
s
.9 .01472 m
.9 .01847 L
s
.9381 .01472 m
.9381 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02381 .12086 m
.03006 .12086 L
s
[(0.2)] .01131 .12086 1 0 Mshowa
.02381 .22701 m
.03006 .22701 L
s
[(0.4)] .01131 .22701 1 0 Mshowa
.02381 .33316 m
.03006 .33316 L
s
[(0.6)] .01131 .33316 1 0 Mshowa
.02381 .4393 m
.03006 .4393 L
s
[(0.8)] .01131 .4393 1 0 Mshowa
.02381 .54545 m
.03006 .54545 L
s
[(1)] .01131 .54545 1 0 Mshowa
.125 Mabswid
.02381 .04125 m
.02756 .04125 L
s
.02381 .06779 m
.02756 .06779 L
s
.02381 .09433 m
.02756 .09433 L
s
.02381 .1474 m
.02756 .1474 L
s
.02381 .17394 m
.02756 .17394 L
s
.02381 .20047 m
.02756 .20047 L
s
.02381 .25355 m
.02756 .25355 L
s
.02381 .28008 m
.02756 .28008 L
s
.02381 .30662 m
.02756 .30662 L
s
.02381 .35969 m
.02756 .35969 L
s
.02381 .38623 m
.02756 .38623 L
s
.02381 .41277 m
.02756 .41277 L
s
.02381 .46584 m
.02756 .46584 L
s
.02381 .49238 m
.02756 .49238 L
s
.02381 .51891 m
.02756 .51891 L
s
.02381 .57199 m
.02756 .57199 L
s
.02381 .59852 m
.02756 .59852 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
.5 Mabswid
.02381 .54545 m
.06244 .54835 L
.08255 .55086 L
.08806 .55143 L
.09109 .5517 L
.09396 .55192 L
.09662 .55209 L
.09803 .55216 L
.09952 .55223 L
.10077 .55228 L
.10215 .55233 L
.1034 .55236 L
.10458 .55238 L
.10585 .55239 L
.10702 .55239 L
.10831 .55238 L
.10903 .55237 L
.10968 .55236 L
.11088 .55234 L
.11218 .5523 L
.11454 .55219 L
.11684 .55205 L
.11928 .55186 L
.12364 .55141 L
.1287 .55071 L
.13342 .54988 L
.14415 .54738 L
.1645 .54072 L
.18306 .53356 L
.19231 .53016 L
.20215 .52704 L
.20727 .52571 L
.20999 .52511 L
.21293 .52455 L
.21561 .52413 L
.21807 .52382 L
.22043 .5236 L
.22161 .52351 L
.22291 .52344 L
.22423 .5234 L
.22544 .52338 L
.22608 .52338 L
.22678 .52338 L
.22751 .52339 L
.22819 .52341 L
.22945 .52347 L
.2306 .52354 L
.23192 .52365 L
.23318 .52378 L
.2355 .52408 L
Mistroke
.23765 .52444 L
.24252 .52555 L
.24784 .52723 L
.25266 .52917 L
.26347 .53497 L
.27352 .54203 L
.28275 .54972 L
.30359 .56966 L
.31347 .57929 L
.32405 .58876 L
.33319 .59559 L
.33801 .59848 L
.34312 .60089 L
.34565 .6018 L
.347 .6022 L
.34844 .60256 L
.34976 .60284 L
.35098 .60304 L
.35213 .60318 L
.35335 .60328 L
.35451 .60332 L
.35575 .60331 L
.35692 .60324 L
.35798 .60314 L
.35922 .60295 L
.36058 .60269 L
.36303 .60201 L
.36521 .60118 L
.36761 .60003 L
.37246 .5969 L
.37695 .593 L
.38115 .58844 L
.39158 .57314 L
.40148 .55324 L
.42003 .5017 L
.43991 .42756 L
.45832 .34546 L
.49756 .15516 L
.50713 .11138 L
.51723 .06853 L
.52584 .03535 L
.5282 .02688 L
.5295 .02235 L
.53073 .01815 L
.53187 .01513 L
.53311 .01922 L
.53527 .02616 L
.54466 .05314 L
.5546 .07593 L
.55976 .08532 L
Mistroke
.56544 .09371 L
.57061 .09957 L
.57545 .10355 L
.57802 .10509 L
.58041 .10616 L
.58179 .10662 L
.58304 .10695 L
.58373 .10709 L
.58448 .10721 L
.58519 .10729 L
.58584 .10735 L
.58702 .10738 L
.58813 .10734 L
.58934 .10723 L
.59064 .10701 L
.59129 .10687 L
.592 .10669 L
.59329 .10629 L
.59571 .10532 L
.59793 .10417 L
.60038 .10263 L
.60534 .09866 L
.61424 .08901 L
.6336 .05965 L
.64356 .04199 L
.64883 .03243 L
.65173 .02719 L
.65446 .02228 L
.65707 .01763 L
.65779 .01636 L
.65855 .01503 L
.6592 .01553 L
.65991 .01677 L
.66485 .02519 L
.67452 .04039 L
.68555 .05499 L
.69037 .06025 L
.69562 .06511 L
.7008 .06898 L
.70333 .07051 L
.70561 .07169 L
.70781 .07266 L
.7102 .0735 L
.71151 .07388 L
.71272 .07416 L
.71395 .0744 L
.71508 .07457 L
.7163 .0747 L
.7176 .07478 L
.7188 .0748 L
Mistroke
.71994 .07477 L
.72058 .07473 L
.72126 .07468 L
.72249 .07453 L
.7238 .07432 L
.72525 .07401 L
.72792 .07326 L
.73079 .07218 L
.73598 .06955 L
.74122 .06605 L
.74608 .06212 L
.75711 .05108 L
.76675 .03959 L
.77719 .02604 L
.77987 .02249 L
.78269 .01873 L
.78386 .01718 L
.7851 .01552 L
.78582 .01486 L
.78647 .01572 L
.78775 .0174 L
.79771 .03008 L
.81631 .04998 L
.82111 .05394 L
.82622 .0575 L
.83063 .06001 L
.83539 .0621 L
.83804 .06298 L
.84047 .0636 L
.8428 .06402 L
.84397 .06418 L
.84525 .0643 L
.84599 .06434 L
.84668 .06437 L
.84798 .06439 L
.84871 .06438 L
.84938 .06435 L
.85011 .0643 L
.85089 .06424 L
.85218 .06409 L
.85339 .06391 L
.85614 .06333 L
.85872 .06259 L
.86112 .06174 L
.86654 .05922 L
.87642 .0527 L
.8854 .04491 L
.89495 .03513 L
.90526 .02346 L
.90808 .02015 L
Mistroke
.90963 .01834 L
.91106 .01664 L
.91229 .01519 L
.91361 .01579 L
.91436 .01667 L
.91507 .0175 L
.9164 .01906 L
.92619 .03023 L
.93658 .04102 L
.94606 .04933 L
.95109 .053 L
.95652 .05629 L
.96148 .05864 L
.96365 .05947 L
.96603 .06023 L
.96813 .06077 L
.97037 .06121 L
.97162 .06139 L
.97274 .06152 L
.97388 .06161 L
.97495 .06166 L
.97619 .06169 L
Mfstroke
.03 w
.02381 .54545 Mdot
.15079 .54545 Mdot
.27778 .54545 Mdot
.40476 .54545 Mdot
.53175 .01472 Mdot
.65873 .01472 Mdot
.78571 .01472 Mdot
.9127 .01472 Mdot
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[10]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo003oOolQ
Ool004=oo`03001oogoo009oo`03001oogoo00D002Ioo`03001oogoo009oo`04001oogooOol3000W
Ool00`00Oomoo`02Ool01000Oomoogoo0P00:Goo00<007ooOol00Woo00<007ooOol00Woo0`009Woo
00<007ooOol00Woo00<007ooOol00Woo00<007ooOol00goo0012Ool00`00Ool00008Ool00`00Oomo
o`0UOol00`00Ool00007Ool00`00Oomoo`0VOol00`00Ool00009Ool00`00Oomoo`0UOol00`00Ool0
0009Ool00`00Oomoo`0TOol00`00Ool00007Ool00`00Ool00004Ool0049oo`03001oo`0000Qoo`03
001oogoo02Eoo`03001oo`0000Qoo`03001oogoo02Eoo`03001oo`0000Qoo`03001oogoo02Ioo`03
001oo`0000Moo`@002Eoo`03001oo`0000Uoo`03001oogoo009oo`00@Woo00<007oo000027oo00<0
07ooOol09Goo00<007oo000027oo00<007ooOol09Goo00<007oo00002Goo00<007ooOol09Goo00<0
07oo00001goo00<007oo00009Woo00<007oo00001goo0P001Goo0012Ool00`00Ool00008Ool00`00
Oomoo`0UOol00`00Ool00007Ool00`00Ool0000VOol00`00Ool00007Ool00`00Ool0000WOol00`00
Ool00008Ool2000VOol00`00Ool00007Ool00`00Oomoo`04Ool004=oo`03001oogoo00Ioo`8002Qo
o`03001oogoo00Moo`03001oogoo02Ioo`03001oogoo00Moo`03001oogoo02Moo`03001oogoo00Qo
o`03001oogoo02Eoo`03001oogoo00Ioo`<000Aoo`00ogoo8Goo000EOol00`00Oomoo`25Ool2000P
Ool2000QOol2000POol2000JOol001Eoo`03001oogoo08=oo`H001aoo`H001eoo`H001aoo`H001Qo
o`005Goo00<007ooOol0Pgoo1P0077oo1P007Goo1P0077oo1P0067oo000EOol00`00Oomoo`22Ool8
000JOol8000KOol8000JOol8000GOol000ioool0010000=oo`005Goo00<007ooOol01goo00<007oo
Ool01goo00<007ooOol027oo00<007ooOol01goo00<007ooOol01goo00<007ooOol01goo00<007oo
Ool027oo00<007ooOol01goo00<007ooOol01goo00<007ooOol027oo00<007ooOol01goo00<007oo
Ool01goo00<007ooOol01goo1`0017oo00<007ooOol01goo00<007ooOol01goo00@007ooOomoo`L0
00Yoo`03001oogoo00Moo`03001oogoo00Eoo`H000Ioo`03001oogoo00Qoo`03001oogoo00Moo`L0
00=oo`03001oogoo00Qoo`03001oogoo00Moo`005Goo00<007ooOol0<7oo00<007ooOol0<Goo00<0
07ooOol077oo1P003Woo00<007ooOol02goo1P007Goo1P0077oo1P003Woo00<007ooOol01goo000E
Ool00`00Oomoo`25Ool3000NOol300000goo001oo`0LOol00`00Ool00002000LOol00`00Oomoo`02
00000goo001oo`0GOol001Eoo`03001oogoo08Aoo`04001oogoo000MOol00`00Oomoo`02Ool00`00
Oomoo`0JOol00`00Oomoo`03Ool00`00Oomoo`0IOol00`00Oomoo`04Ool00`00Oomoo`0EOol001Eo
o`03001oogoo08Aoo`05001oogooOol0000LOol00`00Oomoo`03Ool00`00Oomoo`0HOol00`00Oomo
o`05Ool00`00Oomoo`0GOol00`00Oomoo`06Ool00`00Oomoo`0DOol001Eoo`03001oogoo08Aoo`05
001oogooOol0000KOol00`00Oomoo`04Ool00`00Oomoo`0HOol00`00Oomoo`06Ool00`00Oomoo`0E
Ool00`00Oomoo`08Ool00`00Oomoo`0COol001Eoo`8008Eoo`05001oogooOol0000KOol00`00Oomo
o`05Ool00`00Oomoo`0FOol00`00Oomoo`08Ool00`00Oomoo`0COol00`00Oomoo`0:Ool00`00Oomo
o`0BOol001Eoo`03001oogoo08=oo`03001oogoo009oo`03001oogoo01Qoo`03001oogoo00Moo`03
001oogoo01Aoo`03001oogoo00Yoo`03001oogoo015oo`03001oogoo00aoo`03001oogoo015oo`00
5Goo00<007ooOol0Pgoo00<007ooOol00goo00<007ooOol05goo00<007ooOol01goo00<007ooOol0
4goo00<007ooOol037oo00<007ooOol03goo00<007ooOol03Woo00<007ooOol047oo000EOol00`00
Oomoo`23Ool00`00Oomoo`03Ool00`00Oomoo`0FOol00`00Oomoo`09Ool00`00Oomoo`0AOol00`00
Oomoo`0>Ool2000>Ool00`00Oomoo`0@Ool2000@Ool001Eoo`03001oogoo08=oo`03001oogoo00=o
o`03001oogoo01Ioo`03001oogoo00Yoo`03001oogoo00moo`03001oogoo015oo`03001oogoo00Uo
o`8001Eoo`03001oogoo00eoo`005Goo00<007ooOol0PWoo00<007ooOol01Goo00<007ooOol057oo
00<007ooOol037oo00<007ooOol03Goo00<007ooOol04goo00<007ooOol01goo00<007ooOol05Woo
10002goo000EOol00`00Oomoo`22Ool00`00Oomoo`05Ool00`00Oomoo`0COol00`00Oomoo`0>Ool0
0`00Oomoo`0;Ool00`00Oomoo`0EOol9000LOol30009Ool001Eoo`8008=oo`03001oogoo00Ioo`03
001oogoo019oo`03001oogoo00moo`03001oogoo00Uoo`03001oogoo04Moo`005Goo00<007ooOol0
PWoo00<007ooOol01Woo00<007ooOol04Goo00<007ooOol04Goo0`001Goo0`00BWoo000EOol00`00
Oomoo`21Ool00`00Oomoo`08Ool00`00Oomoo`0?Ool00`00Oomoo`0DOol7001<Ool001Eoo`03001o
ogoo085oo`03001oogoo00Qoo`03001oogoo00moo`03001oogoo06Moo`005Goo00<007ooOol0PGoo
00<007ooOol02Goo00<007ooOol03Goo00<007ooOol0J7oo000EOol00`00Oomoo`21Ool00`00Oomo
o`09Ool00`00Oomoo`0=Ool00`00Oomoo`1XOol001Eoo`03001oogoo081oo`03001oogoo00]oo`03
001oogoo00]oo`03001oogoo06Uoo`005Goo0P00PGoo00<007ooOol037oo00<007ooOol02Goo00<0
07ooOol0JWoo000EOol00`00Oomoo`20Ool00`00Oomoo`0<Ool00`00Oomoo`09Ool00`00Oomoo`1Z
Ool001Eoo`03001oogoo081oo`03001oogoo00eoo`03001oogoo00Moo`03001oogoo06]oo`005Goo
00<007ooOol0Ogoo00<007ooOol03goo0P0017oo0`00KWoo000EOol00`00Oomoo`1oOol00`00Oomo
o`0AOol4001aOol001Eoo`03001oogoo07moo`03001oogoo08Ioo`001Goo00<007ooOol00Woo00@0
07ooOomoo`<000Aoo`03001oogoo07moo`03001oogoo08Ioo`0017oo00<007oo00001goo00<007oo
Ool017oo00<007ooOol0Ogoo00<007ooOol0QWoo0004Ool00`00Ool00008Ool00`00Oomoo`03Ool3
001nOol00`00Oomoo`27Ool000Aoo`03001oo`0000Qoo`03001oogoo00=oo`03001oogoo07ioo`03
001oogoo08Moo`0017oo00<007oo00001goo00<007oo000017oo00<007ooOol0OWoo00<007ooOol0
Qgoo0005Ool00`00Oomoo`07Ool00`00Oomoo`03Ool00`00Oomoo`1nOol00`00Oomoo`27Ool001Eo
o`03001oogoo07ioo`03001oogoo08Moo`005Goo00<007ooOol0OWoo00<007ooOol0Qgoo000EOol0
0`00Oomoo`1mOol00`00Oomoo`28Ool001Eoo`8007ioo`03001oogoo08Qoo`005Goo00<007ooOol0
OGoo00<007ooOol0R7oo000EOol00`00Oomoo`1mOol00`00Oomoo`28Ool001Eoo`03001oogoo07eo
o`03001oogoo08Qoo`005Goo00<007ooOol0OGoo00<007ooOol0R7oo000EOol00`00Oomoo`1lOol0
0`00Oomoo`29Ool001Eoo`03001oogoo07aoo`03001oogoo08Uoo`005Goo0P00OGoo00<007ooOol0
RGoo000EOol00`00Oomoo`1lOol00`00Oomoo`29Ool001Eoo`03001oogoo07]oo`03001oogoo08Yo
o`005Goo00<007ooOol0Ngoo00<007ooOol0RWoo000EOol00`00Oomoo`1kOol00`00Oomoo`2:Ool0
01Eoo`03001oogoo07]oo`03001oogoo08Yoo`005Goo00<007ooOol0Ngoo00<007ooOol0RWoo000E
Ool2001kOol00`00Oomoo`2;Ool001Eoo`03001oogoo07Yoo`03001oogoo08]oo`005Goo00<007oo
Ool0NWoo00<007ooOol0Rgoo000EOol00`00Oomoo`1jOol00`00Oomoo`2;Ool001Eoo`03001oogoo
07Yoo`03001oogoo08]oo`001Goo00<007ooOol00Woo00<007ooOol00Woo0`000goo00<007ooOol0
NGoo00<007ooOol0S7oo0004Ool00`00Ool00009Ool00`00Oomoo`02Ool00`00Oomoo`1iOol00`00
Oomoo`2<Ool000Aoo`03001oo`0000Moo`@000=oo`<007Uoo`03001oogoo08aoo`0017oo00<007oo
00001goo00<007oo000017oo00<007ooOol0NGoo00<007ooOol0S7oo0004Ool00`00Ool00008Ool2
0004Ool00`00Oomoo`1hOol00`00Oomoo`2=Ool000Eoo`03001oogoo00Qoo`03001oogoo009oo`03
001oogoo07Qoo`03001oogoo08eoo`005Goo00<007ooOol0N7oo00<007ooOol0SGoo000EOol00`00
Oomoo`1hOol00`00Oomoo`2=Ool001Eoo`03001oogoo07Qoo`03001oogoo08eoo`005Goo0P00N7oo
00<007ooOol0SWoo000EOol00`00Oomoo`1gOol00`00Oomoo`2>Ool001Eoo`03001oogoo07Moo`03
001oogoo08ioo`005Goo00<007ooOol0Mgoo00<007ooOol0SWoo000EOol00`00Oomoo`1gOol00`00
Oomoo`2>Ool001Eoo`03001oogoo07Ioo`03001oogoo08moo`005Goo00<007ooOol0MWoo00<007oo
Ool0Sgoo000EOol2001gOol00`00Oomoo`2?Ool001Eoo`03001oogoo07Ioo`03001oogoo08moo`00
5Goo00<007ooOol0MGoo00<007ooOol0T7oo000EOol00`00Oomoo`1eOol00`00Oomoo`2@Ool001Eo
o`03001oogoo07Eoo`03001oogoo091oo`005Goo00<007ooOol0MGoo00<007ooOol0T7oo000EOol0
0`00Oomoo`1eOol00`00Oomoo`2@Ool001Eoo`03001oogoo07Aoo`03001oogoo095oo`005Goo0P00
MGoo00<007ooOol0TGoo000EOol00`00Oomoo`1dOol00`00Oomoo`2AOol001Eoo`03001oogoo07Ao
o`03001oogoo095oo`005Goo00<007ooOol0M7oo00<007ooOol0TGoo000EOol00`00Oomoo`1cOol0
0`00Oomoo`2BOol000Eoo`03001oogoo009oo`04001oogooOol20005Ool00`00Oomoo`1cOol00`00
Oomoo`2BOol000Aoo`03001oo`0000Moo`03001oo`0000Aoo`03001oogoo07=oo`03001oogoo099o
o`0017oo00<007oo00001goo00<007oo000017oo0`00Lgoo00<007ooOol0TWoo0004Ool00`00Ool0
0007Ool20005Ool00`00Oomoo`1bOol00`00Oomoo`2COol000Aoo`03001oo`0000Moo`03001oogoo
00Aoo`03001oogoo079oo`03001oogoo09=oo`001Goo00<007ooOol01goo0P0017oo00<007ooOol0
LWoo00<007ooOol0Tgoo000EOol00`00Oomoo`1bOol00`00Oomoo`2COol001Eoo`03001oogoo079o
o`03001oogoo09=oo`005Goo00<007ooOol0LGoo00<007ooOol0U7oo000EOol2001bOol00`00Oomo
o`2DOol001Eoo`03001oogoo075oo`03001oogoo09Aoo`005Goo00<007ooOol0LGoo00<007ooOol0
U7oo000EOol00`00Oomoo`1`Ool00`00Oomoo`2EOol001Eoo`03001oogoo071oo`03001oogoo09Eo
o`005Goo00<007ooOol0L7oo00<007ooOol0UGoo000EOol00`00Oomoo`1`Ool00`00Oomoo`2EOol0
01Eoo`80071oo`03001oogoo09Ioo`005Goo00<007ooOol0Kgoo00<007ooOol0UWoo000EOol00`00
Oomoo`1_Ool00`00Oomoo`2FOol001Eoo`03001oogoo06moo`03001oogoo09Ioo`005Goo00<007oo
Ool0Kgoo00<007ooOol0UWoo000EOol00`00Oomoo`1^Ool00`00Oomoo`2GOol001Eoo`03001oogoo
06ioo`03001oogoo09Moo`005Goo0P00Kgoo00<007ooOol0Ugoo000EOol00`00Oomoo`1^Ool00`00
Oomoo`2GOol001Eoo`03001oogoo06eoo`03001oogoo09Qoo`005Goo00<007ooOol0KGoo00<007oo
Ool0V7oo000EOol00`00Oomoo`1]Ool00`00Oomoo`2HOol000Eoo`03001oogoo009oo`03001oogoo
009oo`03001oogoo00=oo`03001oogoo06eoo`03001oogoo09Qoo`0017oo00<007oo00001goo00<0
07oo000017oo00<007ooOol0K7oo00<007ooOol0VGoo0004Ool00`00Ool00007Ool00`00Ool00004
Ool3001/Ool00`00Oomoo`2IOol000Aoo`03001oo`0000Qoo`03001oogoo00=oo`03001oogoo06ao
o`03001oogoo09Uoo`0017oo00<007oo00001goo00<007oo000017oo00<007ooOol0K7oo00<007oo
Ool0VGoo0005Ool00`00Oomoo`07Ool00`00Oomoo`03Ool00`00Oomoo`1[Ool00`00Oomoo`2JOol0
01Eoo`03001oogoo06]oo`03001oogoo09Yoo`005Goo00<007ooOol0Jgoo00<007ooOol0VWoo000E
Ool00`00Oomoo`1[Ool00`00Oomoo`2JOol001Eoo`8006]oo`03001oogoo09]oo`005Goo00<007oo
Ool0JWoo00<007ooOol0Vgoo000EOol00`00Oomoo`1ZOol00`00Oomoo`2KOol001Eoo`03001oogoo
06Yoo`03001oogoo09]oo`005Goo00<007ooOol0JGoo00<007ooOol0W7oo000EOol00`00Oomoo`1Y
Ool00`00Oomoo`2LOol001Eoo`03001oogoo06Uoo`03001oogoo09aoo`005Goo00<007ooOol0JGoo
00<007ooOol0W7oo000EOol2001YOol00`00Oomoo`2MOol001Eoo`03001oogoo06Qoo`03001oogoo
09eoo`005Goo00<007ooOol0J7oo00<007ooOol0WGoo000EOol00`00Oomoo`1XOol00`00Oomoo`2M
Ool001Eoo`03001oogoo06Moo`03001oogoo09ioo`005Goo00<007ooOol0Igoo00<007ooOol0WWoo
000EOol00`00Oomoo`1WOol00`00Oomoo`2NOol001Eoo`8006Moo`03001oogoo09moo`005Goo00<0
07ooOol0;goo2000;goo00<007ooOol0Wgoo000EOol00`00Oomoo`0/Ool30008Ool3000[Ool00`00
Oomoo`2POol001Aoo`80025oo`8000Uoo`8000ioo`8000Eoo`80021oo`<00:9oo`004Woo1P007Goo
1P0017oo0`004Woo0P0000=oo`000000100077oo1P00XGoo000=Ool;000MOol60002Ool2000GOol7
000LOol6002QOol000moo`03001oo`0000L001]oo`T001Uoo`P001Yoo`P00:1oo`003goo00<007oo
000020006Woo20006Woo20006Woo2000X7oo000?Ool00`00Oomoo`060002Ool<000;Ool300000goo
00000004000LOol6000LOol6002QOol000moo`03001oogoo00H000ioo`/000Aoo`H001aoo`H001ao
o`H00:5oo`003Woo0P0017oo0P008Goo0P0087oo0P000Woo00<007ooOol06Woo0`00Xgoo000EOol0
0`00Oomoo`16Ool00`00Oomoo`0IOol00`00Oomoo`2SOol001Eoo`03001oogoo04Moo`03001oogoo
01Moo`03001oogoo0:Aoo`005Goo00<007ooOol0B7oo00<007ooOol05Woo00<007ooOol0Y7oo000E
Ool2001:Ool00`00Oomoo`0DOol00`00Oomoo`2UOol001Eoo`03001oogoo04Yoo`03001oogoo019o
o`03001oogoo0:Ioo`005Goo00<007ooOol0Bgoo00<007ooOol04Goo00<007ooOol0YWoo000EOol0
0`00Oomoo`1<Ool00`00Oomoo`0?Ool00`00Oomoo`2WOol001Eoo`03001oogoo04eoo`03001oogoo
00ioo`03001oogoo0:Moo`005Goo00<007ooOol0CWoo00<007ooOol037oo00<007ooOol0Z7oo000E
Ool00`00Oomoo`1?Ool2000;Ool00`00Oomoo`2YOol001Eoo`80059oo`8000Qoo`03001oogoo0:Yo
o`005Goo00<007ooOol0Dgoo0`0000=oo`0000000P00[Goo000EOol00`00Oomoo`1FOol2002`Ool0
01Eoo`03001oogoo0?moo`Uoo`005Goo00<007ooOol0ogoo2Goo000EOol00`00Oomoo`3oOol9Ool0
0?moob5oo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.0416348, -0.0934697, 
  0.00194834, 0.00699239}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["WIDENING THE TRANSITION BAND", "Section"],

Cell[TextData[{
  "The poor performance of the filter is due to the sharp transition from \
passband to stopband implied by the specification in the above example. To \
reduce the sidelobes, the transition band may be widened by the introduction \
one or more transition coefficients that take values in the range {0.0, 1.0}. \
In 1970,  Rabiner, Gold and McGonegal investigated this problem. They found \
the best ",
  StyleBox["transition band coefficients",
    FontSlant->"Italic"],
  " in the sense of minimizing the maximum deviation of the synthesized \
filter from the desired filter (so-called minimax optimization). Tables are \
available that for a given filter specification give the value of the \
\"best\" transition coefficient(s). The optimum coefficient for our example, \
a symmetric, odd length N=15 filter, with BW=4, is "
}], "Text",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(\(coeff = 0.40405884; \)\)], "Input",
  CellLabel->"In[11]:="],

Cell["\<\
We modify the filter specification used above by adding the transition \
coefficient coeff.\
\>", "Text",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(L = 15; \nA = Join[Table[1. , {4}], {coeff}, Table[0. , {3}]]; \)], 
  "Input",
  CellLabel->"In[12]:=",
  PageWidth->Infinity],

Cell[CellGroupData[{

Cell[BoxData[
    \(h = FrequencySamplingFilter[L, \ A]\)], "Input",
  CellLabel->"In[14]:="],

Cell[BoxData[
    \({\(-0.0137668001136393725`\), \(-0.00238312985499739005`\), 
      0.0397294106666666593`, 0.0127289397701102213`, 
      \(-0.0912207928116692734`\), \(-0.0186192048246704562`\), 
      0.313260987834865956`, 0.520541178666666581`, 0.3132609878348664`, 
      \(-0.0186192048246701666`\), \(-0.0912207928116693267`\), 
      0.012728939770110248`, 0.0397294106666667303`, 
      \(-0.00238312985499736207`\), \(-0.0137668001136394679`\)}\)], "Output",\

  CellLabel->"Out[14]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(ListMagnitudePlot[h]; \)\)], "Input",
  CellLabel->"In[15]:=",
  PageWidth->Infinity],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 1.90476 0.600856 0.00623235 [
[.21429 .58836 -9 -9 ]
[.21429 .58836 9 0 ]
[.40476 .58836 -9 -9 ]
[.40476 .58836 9 0 ]
[.59524 .58836 -9 -9 ]
[.59524 .58836 9 0 ]
[.78571 .58836 -9 -9 ]
[.78571 .58836 9 0 ]
[.97619 .58836 -9 -9 ]
[.97619 .58836 9 0 ]
[.01131 .10227 -18 -4.5 ]
[.01131 .10227 0 4.5 ]
[.01131 .22692 -18 -4.5 ]
[.01131 .22692 0 4.5 ]
[.01131 .35156 -18 -4.5 ]
[.01131 .35156 0 4.5 ]
[.01131 .47621 -18 -4.5 ]
[.01131 .47621 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.21429 .60086 m
.21429 .60711 L
s
[(0.1)] .21429 .58836 0 1 Mshowa
.40476 .60086 m
.40476 .60711 L
s
[(0.2)] .40476 .58836 0 1 Mshowa
.59524 .60086 m
.59524 .60711 L
s
[(0.3)] .59524 .58836 0 1 Mshowa
.78571 .60086 m
.78571 .60711 L
s
[(0.4)] .78571 .58836 0 1 Mshowa
.97619 .60086 m
.97619 .60711 L
s
[(0.5)] .97619 .58836 0 1 Mshowa
.125 Mabswid
.0619 .60086 m
.0619 .60461 L
s
.1 .60086 m
.1 .60461 L
s
.1381 .60086 m
.1381 .60461 L
s
.17619 .60086 m
.17619 .60461 L
s
.25238 .60086 m
.25238 .60461 L
s
.29048 .60086 m
.29048 .60461 L
s
.32857 .60086 m
.32857 .60461 L
s
.36667 .60086 m
.36667 .60461 L
s
.44286 .60086 m
.44286 .60461 L
s
.48095 .60086 m
.48095 .60461 L
s
.51905 .60086 m
.51905 .60461 L
s
.55714 .60086 m
.55714 .60461 L
s
.63333 .60086 m
.63333 .60461 L
s
.67143 .60086 m
.67143 .60461 L
s
.70952 .60086 m
.70952 .60461 L
s
.74762 .60086 m
.74762 .60461 L
s
.82381 .60086 m
.82381 .60461 L
s
.8619 .60086 m
.8619 .60461 L
s
.9 .60086 m
.9 .60461 L
s
.9381 .60086 m
.9381 .60461 L
s
.25 Mabswid
0 .60086 m
1 .60086 L
s
.02381 .10227 m
.03006 .10227 L
s
[(-80)] .01131 .10227 1 0 Mshowa
.02381 .22692 m
.03006 .22692 L
s
[(-60)] .01131 .22692 1 0 Mshowa
.02381 .35156 m
.03006 .35156 L
s
[(-40)] .01131 .35156 1 0 Mshowa
.02381 .47621 m
.03006 .47621 L
s
[(-20)] .01131 .47621 1 0 Mshowa
.125 Mabswid
.02381 .13343 m
.02756 .13343 L
s
.02381 .16459 m
.02756 .16459 L
s
.02381 .19575 m
.02756 .19575 L
s
.02381 .25808 m
.02756 .25808 L
s
.02381 .28924 m
.02756 .28924 L
s
.02381 .3204 m
.02756 .3204 L
s
.02381 .38272 m
.02756 .38272 L
s
.02381 .41389 m
.02756 .41389 L
s
.02381 .44505 m
.02756 .44505 L
s
.02381 .50737 m
.02756 .50737 L
s
.02381 .53853 m
.02756 .53853 L
s
.02381 .56969 m
.02756 .56969 L
s
.02381 .07111 m
.02756 .07111 L
s
.02381 .03994 m
.02756 .03994 L
s
.02381 .00878 m
.02756 .00878 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
.5 Mabswid
.02381 .60086 m
.06244 .60097 L
.08255 .60106 L
.08806 .60108 L
.09109 .60109 L
.09396 .6011 L
.09662 .60111 L
.09952 .60112 L
.1008 .60112 L
.10215 .60112 L
.10331 .60112 L
.10458 .60112 L
.10584 .60112 L
.10655 .60112 L
.10721 .60112 L
.10843 .60112 L
.10972 .60112 L
.11099 .60112 L
.11219 .60112 L
.11442 .60111 L
.11707 .60111 L
.11951 .6011 L
.12501 .60108 L
.12945 .60105 L
.13432 .60102 L
.14415 .60093 L
.16366 .60068 L
.18458 .60037 L
.19475 .60022 L
.20012 .60015 L
.20582 .60009 L
.21078 .60004 L
.21342 .60002 L
.21627 .6 L
.21887 .59999 L
.22001 .59999 L
.22125 .59998 L
.22236 .59998 L
.22354 .59998 L
.22478 .59997 L
.22594 .59997 L
.22717 .59997 L
.22787 .59997 L
.22853 .59997 L
.22985 .59998 L
.23059 .59998 L
.23127 .59998 L
.23247 .59998 L
.23379 .59999 L
.23618 .6 L
Mistroke
.23897 .60002 L
.24194 .60005 L
.24728 .60011 L
.25273 .6002 L
.25786 .6003 L
.26743 .60054 L
.28755 .60121 L
.30604 .60195 L
.31592 .60235 L
.3265 .60274 L
.33163 .60291 L
.33649 .60304 L
.34081 .60314 L
.34327 .60319 L
.34558 .60323 L
.34798 .60326 L
.35017 .60329 L
.3513 .6033 L
.35252 .60331 L
.35375 .60331 L
.35505 .60332 L
.3562 .60332 L
.35725 .60332 L
.35845 .60332 L
.35959 .60331 L
.36064 .6033 L
.36161 .6033 L
.3638 .60327 L
.36617 .60324 L
.36839 .6032 L
.37343 .60306 L
.37833 .60288 L
.3836 .60262 L
.39376 .60193 L
.3995 .60141 L
.40482 .60085 L
.41519 .5995 L
.42493 .5979 L
.44357 .59387 L
.46416 .58774 L
.48432 .57979 L
.50282 .57058 L
.52332 .55788 L
.54241 .5433 L
.58049 .50384 L
.60092 .47438 L
.6195 .43901 L
.62947 .41431 L
.63866 .38494 L
.64347 .36512 L
Mistroke
.64876 .3363 L
.65142 .31646 L
.65288 .30263 L
.65428 .28623 L
.65557 .26613 L
.6563 .251 L
.65698 .23244 L
.65816 .17047 L
.65945 .18129 L
.66074 .23518 L
.66144 .25054 L
.6621 .26143 L
.66327 .2761 L
.66453 .28769 L
.66601 .29799 L
.66741 .30559 L
.67003 .31623 L
.67251 .32342 L
.6748 .32838 L
.67732 .33244 L
.67871 .3342 L
.67999 .33554 L
.68219 .33733 L
.68334 .33803 L
.68455 .33861 L
.68561 .33899 L
.6866 .33924 L
.68768 .33942 L
.68884 .3395 L
.6901 .33945 L
.69081 .33937 L
.69147 .33926 L
.69268 .33897 L
.69395 .33855 L
.69617 .33754 L
.6986 .33604 L
.70382 .33152 L
.70877 .32558 L
.71806 .30976 L
.72325 .29773 L
.72806 .28385 L
.73334 .26432 L
.73608 .25159 L
.73896 .23517 L
.74153 .21646 L
.74289 .20404 L
.74434 .18757 L
.74503 .17805 L
.74568 .16751 L
.7469 .14107 L
Mistroke
.74804 .09673 L
.74928 .03103 L
.74997 .09578 L
.75062 .1222 L
.75133 .14068 L
.75209 .15477 L
.75289 .16585 L
.75365 .17419 L
.75508 .18613 L
.7564 .19435 L
.75763 .20028 L
.75899 .20538 L
.76043 .20954 L
.76179 .2125 L
.76304 .2145 L
.7637 .2153 L
.76442 .216 L
.76517 .21652 L
.76588 .21684 L
.76717 .21698 L
.76836 .21662 L
.76901 .21623 L
.76972 .21563 L
.77101 .21409 L
.77216 .2122 L
.77343 .20949 L
.77476 .20586 L
.776 .20159 L
.77822 .19124 L
.77947 .18329 L
.78061 .17399 L
.78189 .16016 L
.78309 .14124 L
.78418 .11374 L
.78535 .03719 L
.78663 .08841 L
.78733 .11991 L
.78798 .13903 L
.78914 .16247 L
.79041 .18077 L
.79271 .20432 L
.79481 .22017 L
.79953 .24596 L
.80461 .26551 L
.81014 .28144 L
.81537 .29313 L
.82023 .30184 L
.82531 .30926 L
.83081 .31563 L
.83601 .3203 L
Mistroke
.84078 .32356 L
.8451 .32571 L
.84755 .32661 L
.84984 .32724 L
.85108 .3275 L
.85225 .32769 L
.85331 .32782 L
.85445 .32792 L
.8557 .32796 L
.85702 .32794 L
.85815 .32788 L
.8594 .32774 L
.86062 .32756 L
.86175 .32733 L
.86432 .32662 L
.86683 .32566 L
.86951 .32434 L
.87436 .32107 L
.87877 .31703 L
.88393 .31072 L
.88951 .30144 L
.89478 .28934 L
.89732 .28183 L
.89964 .2736 L
.90188 .26393 L
.90432 .25058 L
.90566 .24139 L
.9069 .23109 L
.90809 .21887 L
.90935 .20172 L
.91036 .1824 L
.91143 .1496 L
.91259 .01472 L
.91366 .1349 L
.91484 .17799 L
.91612 .2035 L
.91732 .21976 L
.91843 .23147 L
.92112 .25226 L
.92366 .26643 L
.92841 .28552 L
.93353 .30002 L
.93908 .31161 L
.94351 .31874 L
.94765 .32415 L
.95259 .32928 L
.9571 .33292 L
.96181 .33579 L
.96398 .33681 L
.9663 .33771 L
Mistroke
.96875 .33845 L
.97103 .33895 L
.9717 .33906 L
.97242 .33916 L
.97374 .3393 L
.97501 .33938 L
.97619 .33941 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[15]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol001Eoo`03001oogoo0?moo`Uoo`005Goo00<007ooOol0
ogoo2Goo000EOol2003oOol:Ool001Eoo`03001oogoo0?moo`Uoo`005Goo00<007ooOol0k7oo00<0
07ooOol06Goo000EOol00`00Oomoo`3/Ool00`00Oomoo`0IOol001Eoo`03001oogoo0>aoo`03001o
ogoo01Uoo`005Goo00<007ooOol0k7oo00<007ooOol06Goo000EOol00`00Oomoo`30Ool00`00Oomo
o`0YOol00`00Oomoo`0IOol001Eoo`03001oogoo0<1oo`03001oogoo02Uoo`03001oogoo01Uoo`00
5Goo00<007ooOol0`7oo00<007ooOol01goo00<007ooOol07goo00<007ooOol06Goo000EOol20031
Ool00`00Oomoo`07Ool00`00Oomoo`0OOol00`00Oomoo`0IOol001Eoo`03001oogoo0<1oo`03001o
ogoo00Moo`03001oogoo01moo`03001oogoo01Uoo`005Goo00<007ooOol0`7oo00<007ooOol01goo
00<007ooOol07goo00<007ooOol06Goo000EOol00`00Oomoo`30Ool00`00Oomoo`07Ool00`00Oomo
o`0OOol00`00Oomoo`0IOol001Eoo`03001oogoo0<1oo`03001oogoo00Moo`03001oogoo01moo`03
001oogoo01Uoo`005Goo00<007ooOol0`7oo00<007ooOol01goo00<007ooOol07goo00<007ooOol0
6Goo000EOol00`00Oomoo`30Ool00`00Oomoo`07Ool00`00Oomoo`0OOol00`00Oomoo`0IOol001Eo
o`03001oogoo0<1oo`8000Qoo`03001oogoo01moo`03001oogoo01Uoo`005Goo0P00`Goo0P0027oo
00<007ooOol07goo00<007ooOol06Goo000EOol00`00Oomoo`30Ool20008Ool00`00Oomoo`0OOol0
0`00Oomoo`0IOol001Eoo`03001oogoo0<1oo`8000Qoo`03001oogoo01moo`8001Yoo`005Goo00<0
07ooOol0`7oo0P0027oo00<007ooOol07goo0P006Woo000EOol00`00Oomoo`30Ool20008Ool00`00
Oomoo`0OOol2000JOol001Eoo`03001oogoo0<1oo`8000Qoo`03001oogoo01moo`8001Yoo`002Woo
00<007ooOol00Woo00<007ooOol00goo00<007ooOol0`7oo0P0027oo00<007ooOol07goo0P006Woo
0009Ool00`00Ool00002Ool00`00Ool00004Ool00`00Oomoo`30Ool20008Ool00`00Oomoo`0OOol2
000JOol000Aoo`<0009oo`03001oo`00009oo`03001oo`0000Aoo`<00<1oo`8000Qoo`03001oogoo
01moo`8001Yoo`002Woo00L007ooOomoo`00Ool00004Ool00`00Oomoo`30Ool20008Ool00`00Oomo
o`0OOol2000JOol000Uoo`03001oo`00009oo`03001oo`0000Aoo`03001oogoo0<1oo`8000Qoo`80
021oo`8001Yoo`002Woo00<007ooOol00Woo00<007ooOol00goo00<007ooOol0`7oo0P0027oo0P00
87oo0P006Woo000EOol00`00Oomoo`30Ool20008Ool2000POol2000JOol001Eoo`03001oogoo0<1o
o`8000Qoo`80021oo`8001Yoo`005Goo00<007ooOol0`7oo0P0027oo0P0087oo0P006Woo000EOol0
0`00Oomoo`30Ool20007Ool00`00Ool0000POol2000JOol001Eoo`03001oogoo0<1oo`8000Moo`03
001oo`00021oo`8001Yoo`005Goo0P00`Goo0P001goo00<007oo000087oo0P006Woo000EOol00`00
Oomoo`30Ool20007Ool00`00Ool0000POol2000JOol001Eoo`03001oogoo0<1oo`8000Moo`03001o
o`00021oo`8001Yoo`005Goo00<007ooOol0`7oo0P001goo00<007oo000087oo0P006Woo000EOol0
0`00Oomoo`30Ool20007Ool00`00Ool0000POol2000JOol001Eoo`03001oogoo0<1oo`8000Moo`03
001oo`00021oo`8001Yoo`005Goo00<007ooOol0_goo00<007oo00001goo00<007oo000087oo0P00
6Woo000EOol00`00Oomoo`2oOol00`00Ool00007Ool00`00Ool0000POol2000JOol001Eoo`800<1o
o`03001oo`0000Moo`03001oo`00021oo`8001Yoo`005Goo00<007ooOol0_goo00<007oo00001goo
00<007oo000087oo0P006Woo000EOol00`00Oomoo`2XOol00`00Oomoo`0DOol01000Oomoo`001Woo
00<007oo000087oo0P006Woo000EOol00`00Oomoo`2XOol00`00Oomoo`0DOol01000Oomoo`001Woo
00<007oo000087oo0P006Woo000EOol00`00Oomoo`2XOol00`00Oomoo`0DOol01000Oomoo`001Goo
00@007ooOol0021oo`8001Yoo`005Goo00<007ooOol0Z7oo00<007ooOol057oo00@007ooOol000Eo
o`04001oogoo000POol2000JOol001Eoo`03001oogoo0:Qoo`03001oogoo01Aoo`04001oogoo0005
Ool01000Oomoo`0087oo0P006Woo000EOol00`00Oomoo`2XOol00`00Oomoo`0DOol01000Oomoo`00
1Goo00@007ooOol0021oo`8001Yoo`005Goo00<007ooOol0Z7oo00<007ooOol057oo00@007ooOol0
00Eoo`05001oogooOol0000NOol00`00Ool0000JOol001Eoo`800:Uoo`03001oogoo01Aoo`04001o
ogoo0005Ool01@00Oomoogoo00007Woo00<007oo00006Woo000EOol00`00Oomoo`2WOol2000FOol0
1@00Oomoogoo000017oo00D007ooOomoo`0001ioo`03001oo`0001Yoo`005Goo00<007ooOol0Ygoo
0P005Woo00D007ooOomoo`0000=oo`03001oogoo009oo`03001oogoo01aoo`03001oo`0001Yoo`00
5Goo00<007ooOol0Ygoo0P005Woo00D007ooOomoo`0000=oo`03001oogoo009oo`03001oogoo01ao
o`03001oo`0001Yoo`005Goo00<007ooOol0Ygoo0P005Goo00<007ooOol00goo00@007oo000000Ao
o`03001oogoo01aoo`03001oo`0001Yoo`005Goo00<007ooOol0Ygoo0P005Goo00<007ooOol00goo
0`001Woo00<007ooOol06goo00@007ooOol001Uoo`002Goo0P0017oo00<007ooOol00goo00<007oo
Ool0Ygoo0P005Goo00<007ooOol037oo00<007ooOol06goo00@007ooOol001Uoo`002Goo00<007oo
00000Woo00<007oo000017oo00<007ooOol0Ygoo0P005Goo00<007ooOol037oo00<007ooOol06goo
00@007ooOol001Uoo`0017oo0`000Woo00<007oo00000Woo00<007oo000017oo0`00Ygoo0P005Goo
00<007ooOol037oo00<007ooOol06goo00@007ooOol001Uoo`002Goo0P000goo00<007oo000017oo
00<007ooOol0Ygoo0P005Goo00<007ooOol037oo00<007ooOol06goo00@007ooOol001Uoo`002Goo
00<007ooOol00Woo00<007oo000017oo00<007ooOol0Ygoo0P005Goo00<007ooOol03Goo00<007oo
Ool06Woo00@007ooOol001Uoo`002Woo0P000goo00<007ooOol00goo00<007ooOol0Ygoo0P005Goo
00<007ooOol03Goo00<007ooOol06Goo00D007ooOomoo`0001Uoo`005Goo00<007ooOol0Ygoo0P00
5Goo00<007ooOol03Goo00<007ooOol06Goo00D007ooOomoo`0001Uoo`005Goo00<007ooOol0Ygoo
00<007oo00004goo00<007ooOol03Woo00<007ooOol06Goo00<007ooOol00Woo00<007ooOol05Woo
000EOol00`00Oomoo`2WOol00`00Ool0000COol00`00Oomoo`0>Ool00`00Oomoo`0IOol00`00Oomo
o`02Ool00`00Oomoo`0FOol001Eoo`03001oogoo0:Moo`03001oo`0001=oo`03001oogoo00ioo`03
001oogoo01Uoo`03001oogoo009oo`03001oogoo01Ioo`005Goo0P00Z7oo00<007oo00004goo00<0
07ooOol03goo00<007ooOol05goo00<007ooOol00goo00<007ooOol05Woo000EOol00`00Oomoo`2W
Ool00`00Ool0000BOol00`00Oomoo`0@Ool00`00Oomoo`0GOol00`00Oomoo`03Ool00`00Oomoo`0F
Ool001Eoo`03001oogoo0:Moo`03001oo`00019oo`03001oogoo011oo`03001oogoo01Moo`03001o
ogoo00=oo`03001oogoo01Ioo`005Goo00<007ooOol0Ygoo00<007oo00004Woo00<007ooOol047oo
00<007ooOol05goo00<007ooOol00goo00<007ooOol05Woo000EOol00`00Oomoo`2WOol00`00Ool0
000BOol00`00Oomoo`0AOol00`00Oomoo`0FOol00`00Oomoo`03Ool00`00Oomoo`0FOol001Eoo`03
001oogoo0:Moo`03001oo`00015oo`03001oogoo019oo`03001oogoo01Ioo`03001oogoo00Aoo`03
001oogoo01Eoo`005Goo00<007ooOol0Ygoo00<007oo00004Goo00<007ooOol04goo00<007ooOol0
57oo00<007ooOol01Goo00<007ooOol05Goo000EOol00`00Oomoo`2WOol01000Oomoo`0047oo00<0
07ooOol04goo00<007ooOol057oo00<007ooOol01Woo00<007ooOol057oo000EOol00`00Oomoo`2W
Ool01000Oomoo`003goo00<007ooOol057oo00<007ooOol057oo00<007ooOol01Woo00<007ooOol0
57oo000EOol2002XOol01000Oomoo`003goo00<007ooOol05Goo00<007ooOol04goo00<007ooOol0
1Woo00<007ooOol057oo000EOol00`00Oomoo`2VOol01@00Oomoogoo00003Woo00<007ooOol05Woo
00<007ooOol04Woo00<007ooOol01goo00<007ooOol057oo000EOol00`00Oomoo`2VOol01@00Oomo
ogoo00003Woo00<007ooOol05Woo00<007ooOol04Woo00<007ooOol027oo00<007ooOol04goo000E
Ool00`00Oomoo`2VOol01@00Oomoogoo00003Woo00<007ooOol05goo00<007ooOol047oo00<007oo
Ool02Goo00<007ooOol04goo000EOol00`00Oomoo`2VOol01@00Oomoogoo00003Goo00<007ooOol0
6Goo00<007ooOol03Woo00<007ooOol02goo00<007ooOol04Woo000EOol00`00Oomoo`2VOol01@00
Oomoogoo00003Goo00<007ooOol06Woo00<007ooOol03Goo00<007ooOol02goo00<007ooOol04Woo
000EOol00`00Oomoo`2VOol00`00Oomoo`02Ool00`00Oomoo`09Ool00`00Oomoo`0KOol00`00Oomo
o`0<Ool00`00Oomoo`0=Ool00`00Oomoo`0AOol001Eoo`03001oogoo0:Ioo`03001oogoo009oo`03
001oogoo00Qoo`03001oogoo01eoo`03001oogoo00Yoo`03001oogoo00ioo`03001oogoo015oo`00
5Goo0P00Ygoo00<007ooOol00Woo00<007ooOol027oo00<007ooOol07Woo0P002Goo00<007ooOol0
47oo00<007ooOol047oo000EOol00`00Oomoo`2VOol00`00Oomoo`03Ool00`00Oomoo`06Ool00`00
Oomoo`0QOol00`00Oomoo`05Ool00`00Oomoo`0BOol00`00Oomoo`0?Ool001Eoo`03001oogoo0:Eo
o`03001oogoo00Aoo`03001oogoo00Eoo`03001oogoo02=oo`L001Ioo`03001oogoo00ioo`005Goo
00<007ooOol0YGoo00<007ooOol01Goo00<007ooOol017oo00<007ooOol0@Goo00<007ooOol03Goo
000EOol00`00Oomoo`2UOol00`00Oomoo`05Ool20004Ool00`00Oomoo`13Ool2000=Ool001Eoo`03
001oogoo0:Eoo`03001oogoo00Ioo`D004Moo`D000Uoo`002Woo0`000Woo00<007ooOol00goo00<0
07ooOol0YGoo00<007ooOol0H7oo000;Ool01P00Oomoo`00Ool000Aoo`03001oogoo0:Eoo`03001o
ogoo061oo`0017oo0`000Woo100000Aoo`00Ool000Aoo`<00:Aoo`03001oogoo065oo`002Goo00<0
07oo00000Woo00<007oo000017oo00<007ooOol0Y7oo00<007ooOol0HGoo000:Ool20002Ool00`00
Ool00004Ool00`00Oomoo`2TOol00`00Oomoo`1QOol000]oo`05001oogooOol00005Ool00`00Oomo
o`2TOol00`00Oomoo`1QOol001Eoo`03001oogoo0:Aoo`03001oogoo065oo`005Goo00<007ooOol0
Y7oo00<007ooOol0HGoo000EOol00`00Oomoo`2TOol00`00Oomoo`1QOol001Eoo`03001oogoo0:=o
o`03001oogoo069oo`005Goo00<007ooOol0Xgoo00<007ooOol0HWoo000EOol2002TOol00`00Oomo
o`1ROol001Eoo`03001oogoo0:=oo`03001oogoo069oo`005Goo00<007ooOol0XWoo00<007ooOol0
Hgoo000EOol00`00Oomoo`2ROol00`00Oomoo`1SOol001Eoo`03001oogoo0:5oo`03001oogoo06Ao
o`005Goo00<007ooOol0XGoo00<007ooOol0I7oo000EOol00`00Oomoo`2QOol00`00Oomoo`1TOol0
01Eoo`03001oogoo0:1oo`03001oogoo06Eoo`005Goo0P00XGoo00<007ooOol0IGoo000EOol00`00
Oomoo`2POol00`00Oomoo`1UOol001Eoo`03001oogoo09moo`03001oogoo06Ioo`005Goo00<007oo
Ool0Wgoo00<007ooOol0IWoo000EOol00`00Oomoo`2NOol00`00Oomoo`1WOol001Eoo`03001oogoo
09ioo`03001oogoo06Moo`005Goo00<007ooOol0WGoo00<007ooOol0J7oo000EOol00`00Oomoo`2M
Ool00`00Oomoo`1XOol001Eoo`03001oogoo09aoo`03001oogoo06Uoo`005Goo0P00WGoo00<007oo
Ool0JGoo000EOol00`00Oomoo`2KOol00`00Oomoo`1ZOol001Eoo`03001oogoo09]oo`03001oogoo
06Yoo`005Goo00<007ooOol0VWoo00<007ooOol0Jgoo000EOol00`00Oomoo`2JOol00`00Oomoo`1[
Ool001Eoo`03001oogoo09Uoo`03001oogoo06aoo`002Goo0`000goo00<007ooOol00goo00<007oo
Ool0VGoo00<007ooOol0K7oo0009Ool00`00Oomoo`02Ool00`00Ool00004Ool00`00Oomoo`2HOol0
0`00Oomoo`1]Ool000Aoo`<000=oo`07001oogooOol007oo000017oo0`00V7oo00<007ooOol0KGoo
000:Ool01`00Oomoogoo001oo`0000Aoo`03001oogoo09Moo`03001oogoo06ioo`002Goo00<007oo
00000Woo00<007oo000017oo00<007ooOol0Ugoo00<007ooOol0KWoo000:Ool00`00Oomoo`02Ool0
0`00Oomoo`03Ool00`00Oomoo`2FOol00`00Oomoo`1_Ool001Eoo`03001oogoo09Eoo`03001oogoo
071oo`005Goo00<007ooOol0UGoo00<007ooOol0L7oo000EOol00`00Oomoo`2DOol00`00Oomoo`1a
Ool001Eoo`03001oogoo09Aoo`03001oogoo075oo`005Goo0P00U7oo00<007ooOol0LWoo000EOol0
0`00Oomoo`2BOol00`00Oomoo`1cOol001Eoo`03001oogoo095oo`03001oogoo07Aoo`005Goo00<0
07ooOol0T7oo00<007ooOol0MGoo000EOol00`00Oomoo`2?Ool00`00Oomoo`1fOol001Eoo`03001o
ogoo08ioo`03001oogoo07Moo`005Goo00<007ooOol0SGoo00<007ooOol0N7oo000EOol00`00Oomo
o`2<Ool00`00Oomoo`1iOol001Eoo`03001oogoo08]oo`03001oogoo07Yoo`005Goo0P00Rgoo00<0
07ooOol0Ngoo000EOol00`00Oomoo`29Ool00`00Oomoo`1lOol001Eoo`03001oogoo08Moo`8007mo
o`005Goo00<007ooOol0QWoo00<007ooOol0Ogoo000EOol00`00Oomoo`24Ool20022Ool001Eoo`03
001oogoo02]oo`03001oogoo009oo`03001oogoo00D002Ioo`03001oogoo009oo`04001oogooOol3
000IOol00`00Oomoo`0;Ool00`00Oomoo`02Ool01000Oomoogoo0P00:Goo00<007ooOol00Woo00<0
07ooOol00Woo0`009Woo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol00goo000EOol00`00
Oomoo`0ZOol00`00Ool00008Ool00`00Oomoo`0UOol00`00Ool00007Ool00`00Oomoo`0HOol00`00
Oomoo`0;Ool00`00Ool00009Ool00`00Oomoo`0UOol00`00Ool00009Ool00`00Oomoo`0TOol00`00
Ool00007Ool00`00Ool00004Ool001Eoo`03001oogoo02Yoo`03001oo`0000Qoo`03001oogoo02Eo
o`03001oo`0000Qoo`03001oogoo01Eoo`8000ioo`03001oo`0000Qoo`03001oogoo02Ioo`03001o
o`0000Moo`@002Eoo`03001oo`0000Uoo`03001oogoo009oo`005Goo0P00:goo00<007oo000027oo
00<007ooOol09Goo00<007oo000027oo00<007ooOol057oo00<007ooOol03Woo00<007oo00002Goo
00<007ooOol09Goo00<007oo00001goo00<007oo00009Woo00<007oo00001goo0P001Goo000EOol0
0`00Oomoo`0ZOol00`00Ool00008Ool00`00Oomoo`0UOol00`00Ool00007Ool00`00Ool0000COol2
000AOol00`00Ool00007Ool00`00Ool0000WOol00`00Ool00008Ool2000VOol00`00Ool00007Ool0
0`00Oomoo`04Ool001Eoo`03001oogoo02]oo`03001oogoo00Ioo`8002Qoo`03001oogoo00Moo`03
001oogoo011oo`8001Aoo`03001oogoo00Moo`03001oogoo02Moo`03001oogoo00Qoo`03001oogoo
02Eoo`03001oogoo00Ioo`<000Aoo`005Goo00<007ooOol0N7oo0`00SGoo000EOol00`00Oomoo`1f
Ool2002@Ool001Eoo`03001oogoo07=oo`<0099oo`005Goo00<007ooOol0L7oo0`00UGoo000EOol0
0`00Oomoo`1/Ool4002HOol001Eoo`03001oogoo02Yooa8002Yoo`H009aoo`003Wooo`0040000goo
000EOol00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`08Ool00`00Oomoo`07Ool00`00Oomo
o`07Ool00`00Oomoo`07Ool00`00Oomoo`08Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomo
o`08Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`08Ool00`00Oomo
o`07Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`08Ool00`00Oomoo`07Ool00`00Oomo
o`07Ool00`00Oomoo`07Ool00`00Oomoo`08Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomo
o`08Ool00`00Oomoo`07Ool001Eoo`03001oogoo0?moo`Uoo`005Goo00<007ooOol0ogoo2Goo000E
Ool00`00Oomoo`3oOol9Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo0000
\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.0416348, -99.5064, 
  0.00194834, 0.59546}}]
}, Open  ]],

Cell["\<\
Note that the attenuation has more than  doubled (on dB scale)!\
\>", "Text",
  FontFamily->"Times New Roman"]
}, Open  ]]
},
FrontEndVersion->"Microsoft Windows 3.0",
ScreenRectangle->{{0, 1280}, {0, 968}},
WindowToolbars->"EditBar",
CellGrouping->Manual,
WindowSize->{617, 517},
WindowMargins->{{Automatic, 233}, {Automatic, 6}},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, -1}},
ShowCellLabel->True,
ShowCellTags->False,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False},
StyleDefinitions -> "ArticleClassic.nb"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1709, 49, 142, 4, 72, "Title",
  Evaluatable->False],
Cell[1854, 55, 76, 2, 31, "Input"],
Cell[1933, 59, 71, 2, 31, "Input"],

Cell[CellGroupData[{
Cell[2029, 65, 113, 3, 56, "Section",
  Evaluatable->False],
Cell[2145, 70, 688, 11, 112, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2870, 86, 152, 4, 56, "Section",
  Evaluatable->False],
Cell[3025, 92, 340, 6, 61, "Text"],
Cell[3368, 100, 162, 4, 43, "Input"],

Cell[CellGroupData[{
Cell[3555, 108, 91, 2, 43, "Input"],
Cell[3649, 112, 320, 5, 77, "Output"]
}, Open  ]],
Cell[3984, 120, 142, 4, 27, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4163, 129, 143, 4, 56, "Section",
  Evaluatable->False],
Cell[4309, 135, 1386, 30, 269, "Text",
  Evaluatable->False],
Cell[5698, 167, 33, 0, 27, "Text"]
}, Open  ]],
Cell[5746, 170, 2839, 61, 196, "Text"],

Cell[CellGroupData[{
Cell[8610, 235, 143, 4, 56, "Section",
  Evaluatable->False],
Cell[8756, 241, 378, 9, 48, "Text",
  Evaluatable->False],
Cell[9137, 252, 177, 5, 64, "Input"],

Cell[CellGroupData[{
Cell[9339, 261, 88, 2, 31, "Input"],
Cell[9430, 265, 17982, 474, 186, 4092, 297, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],
Cell[27427, 742, 94, 2, 27, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[27546, 748, 121, 3, 31, "Input"],
Cell[27670, 753, 485, 8, 68, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[28192, 766, 118, 3, 31, "Input"],
Cell[28313, 771, 16160, 494, 186, 4474, 345, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],
Cell[44488, 1268, 132, 3, 27, "Text"],

Cell[CellGroupData[{
Cell[44645, 1275, 90, 2, 43, "Input"],
Cell[44738, 1279, 74, 2, 43, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[44861, 1287, 161, 4, 56, "Section",
  Evaluatable->False],
Cell[45025, 1293, 310, 8, 44, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[45360, 1305, 83, 2, 31, "Input"],
Cell[45446, 1309, 21112, 663, 186, 7312, 487, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],
Cell[66573, 1975, 119, 3, 27, "Text"],

Cell[CellGroupData[{
Cell[66717, 1982, 344, 7, 108, "Input"],
Cell[67064, 1991, 17619, 595, 186, 6799, 456, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[84732, 2592, 47, 0, 56, "Section"],
Cell[84782, 2594, 887, 15, 129, "Text"],
Cell[85672, 2611, 82, 2, 31, "Input"],
Cell[85757, 2615, 148, 4, 27, "Text"],
Cell[85908, 2621, 147, 4, 51, "Input"],

Cell[CellGroupData[{
Cell[86080, 2629, 93, 2, 31, "Input"],
Cell[86176, 2633, 499, 9, 68, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[86712, 2647, 107, 3, 31, "Input"],
Cell[86822, 2652, 19111, 626, 186, 7011, 471, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],
Cell[105948, 3281, 120, 3, 27, "Text"]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

