(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    181794,       4438]*)
(*NotebookOutlinePosition[    182599,       4466]*)
(*  CellTagsIndexPosition[    182555,       4462]*)
(*WindowFrame->Normal*)



Notebook[{
Cell["KAISER WINDOW FOR FILTER DESIGN", "Title",
  TextJustification->0,
  FontFamily->"Arial"],

Cell[CellGroupData[{

Cell["Introduction", "Section",
  TextJustification->0,
  FontFamily->"Arial"],

Cell["\<\
The window method is one of the simplest methods of designing FIR digital \
filters. It is well suited for designing filters with simple frequency \
responses, such as ideal lowpass, ideal highpass, differentiators and Hilbert \
transformers. A double-sided infinite impulse response is obtained from a \
desired ideal frequency response by the inverse discrete-time Fourier \
transform (IDTFT). The window method calls for the truncation of the infinite \
impulse response to a finite length. The truncation may be combined with a \
smooth weighing of the impulse response coefficients, and is then typically \
referred to as a time-domain windowing.

\tA large number of \"windows\" i.e. smooth weighing sequences, have been \
investigated. Many, such as the Hamming, Hanning, Blackman-Harris, that are \
variations on the basic idea of smoothing with a raised cosine window have \
one limitation; they all have fixed stopband ripple, which depends on the \
window shape. The windows that do not suffer from this limitation are those \
with an adjustable shape parameter. Of these, the Kaiser window is one of the \
better known. It has near optimal performance (in the sense of minimizing the \
sidelobe energy of the window), as well as having a simple implementation.\
\>", "Text",
  TextJustification->0,
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(<< "\<SignalProcessing`Master`\>"\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Discrete Kaiser Window", "Section",
  TextJustification->0,
  FontFamily->"Arial"],

Cell["\<\
The Kaiser window is based on the evaluation of the modified Bessel function \
of the first kind and 0th order. Like all window functions, the Kaiser window \
is symmetric about its middle.\
\>", "Text",
  TextJustification->0,
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(KaiserWindow[\[Alpha]_, L_] := 
      Table[BesselI[0, \[Alpha]*\@\(1.  - \((\(2\ n\)\/\(L - 1\))\)\^2\)]/
          BesselI[0, \[Alpha]], \n
        \t\t{n, \(-\(\(L - 1\)\/2\)\), \(L - 1\)\/2}]\)], "Input",
  TextJustification->0],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(DiscreteSignalPlot[KaiserWindow[6.5, 20]]; \)\)], "Input",
  TextJustification->0],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0501253 0.0147151 0.5935 [
[.27444 .00222 -3 -9 ]
[.27444 .00222 3 0 ]
[.52506 .00222 -6 -9 ]
[.52506 .00222 6 0 ]
[.77569 .00222 -6 -9 ]
[.77569 .00222 6 0 ]
[.01131 .13342 -18 -4.5 ]
[.01131 .13342 0 4.5 ]
[.01131 .25211 -18 -4.5 ]
[.01131 .25211 0 4.5 ]
[.01131 .37081 -18 -4.5 ]
[.01131 .37081 0 4.5 ]
[.01131 .48951 -18 -4.5 ]
[.01131 .48951 0 4.5 ]
[.01131 .60821 -6 -4.5 ]
[.01131 .60821 0 4.5 ]
[.5 .63053 -62 0 ]
[.5 .63053 62 12.875 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.27444 .01472 m
.27444 .02097 L
s
[(5)] .27444 .00222 0 1 Mshowa
.52506 .01472 m
.52506 .02097 L
s
[(10)] .52506 .00222 0 1 Mshowa
.77569 .01472 m
.77569 .02097 L
s
[(15)] .77569 .00222 0 1 Mshowa
0 .01472 m
1 .01472 L
s
.02381 .13342 m
.03006 .13342 L
s
[(0.2)] .01131 .13342 1 0 Mshowa
.02381 .25211 m
.03006 .25211 L
s
[(0.4)] .01131 .25211 1 0 Mshowa
.02381 .37081 m
.03006 .37081 L
s
[(0.6)] .01131 .37081 1 0 Mshowa
.02381 .48951 m
.03006 .48951 L
s
[(0.8)] .01131 .48951 1 0 Mshowa
.02381 .60821 m
.03006 .60821 L
s
[(1)] .01131 .60821 1 0 Mshowa
.125 Mabswid
.02381 .04439 m
.02756 .04439 L
s
.02381 .07407 m
.02756 .07407 L
s
.02381 .10374 m
.02756 .10374 L
s
.02381 .16309 m
.02756 .16309 L
s
.02381 .19276 m
.02756 .19276 L
s
.02381 .22244 m
.02756 .22244 L
s
.02381 .28179 m
.02756 .28179 L
s
.02381 .31146 m
.02756 .31146 L
s
.02381 .34114 m
.02756 .34114 L
s
.02381 .40049 m
.02756 .40049 L
s
.02381 .43016 m
.02756 .43016 L
s
.02381 .45984 m
.02756 .45984 L
s
.02381 .51919 m
.02756 .51919 L
s
.02381 .54886 m
.02756 .54886 L
s
.02381 .57854 m
.02756 .57854 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -124 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.875 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 62.000000 16.875000 moveto
 460.000000 16.875000 lineto
 460.000000 4.000000 lineto
 62.000000 4.000000 lineto
 62.000000 16.875000 lineto
closepath
clip newpath
64.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
64.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Discrete) show
118.000000 13.000000 moveto
(Signal) show
160.000000 13.000000 moveto
(Plot) show
184.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
.00596 w
.02381 .01472 m
.02381 .0203 L
s
.01788 w
.02381 .0203 Mdot
.00596 w
.07393 .01472 m
.07393 .03991 L
s
.01788 w
.07393 .03991 Mdot
.00596 w
.12406 .01472 m
.12406 .07726 L
s
.01788 w
.12406 .07726 Mdot
.00596 w
.17419 .01472 m
.17419 .13542 L
s
.01788 w
.17419 .13542 Mdot
.00596 w
.22431 .01472 m
.22431 .21374 L
s
.01788 w
.22431 .21374 Mdot
.00596 w
.27444 .01472 m
.27444 .30687 L
s
.01788 w
.27444 .30687 Mdot
.00596 w
.32456 .01472 m
.32456 .40508 L
s
.01788 w
.32456 .40508 Mdot
.00596 w
.37469 .01472 m
.37469 .49565 L
s
.01788 w
.37469 .49565 Mdot
.00596 w
.42481 .01472 m
.42481 .56537 L
s
.01788 w
.42481 .56537 Mdot
.00596 w
.47494 .01472 m
.47494 .60332 L
s
.01788 w
.47494 .60332 Mdot
.00596 w
.52506 .01472 m
.52506 .60332 L
s
.01788 w
.52506 .60332 Mdot
.00596 w
.57519 .01472 m
.57519 .56537 L
s
.01788 w
.57519 .56537 Mdot
.00596 w
.62531 .01472 m
.62531 .49565 L
s
.01788 w
.62531 .49565 Mdot
.00596 w
.67544 .01472 m
.67544 .40508 L
s
.01788 w
.67544 .40508 Mdot
.00596 w
.72556 .01472 m
.72556 .30687 L
s
.01788 w
.72556 .30687 Mdot
.00596 w
.77569 .01472 m
.77569 .21374 L
s
.01788 w
.77569 .21374 Mdot
.00596 w
.82581 .01472 m
.82581 .13542 L
s
.01788 w
.82581 .13542 Mdot
.00596 w
.87594 .01472 m
.87594 .07726 L
s
.01788 w
.87594 .07726 Mdot
.00596 w
.92607 .01472 m
.92607 .03991 L
s
.01788 w
.92607 .03991 Mdot
.00596 w
.97619 .01472 m
.97619 .0203 L
s
.01788 w
.97619 .0203 Mdot
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  TextJustification->0,
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo001NOol0
0`00Oomoo`0gOol50002Ool00`00Oomoo`0dOol50002Ool00`00Oomoo`10Ool005eoo`03001oo`00
03Yoo`07001oogooOol007oo0000=goo00L007ooOomoo`00Ool00011Ool005moo`03001oogoo03Qo
o`07001oogooOol007oo0000=goo00<007ooOol00goo00<007ooOol0?goo001MOol2000kOol01`00
Oomoogoo001oo`0003Moo`04001oogooOol20012Ool005eoo`03001oogoo03Yoo`07001oogooOol0
07oo0000=goo00D007ooOomoo`0004=oo`00GGoo0`00>Goo0P0017oo00<007ooOol0=Goo0P000goo
0`00@Goo003oOolQOol0025oo`03001oogoo0?aoo`008Goo00<007ooOol0o7oo000QOol00`00Oomo
o`3lOol0025oo`03001oogoo0?aoo`006goon0003Goo000OOol4000:Ool00`00Oomoo`0:Ool00`00
Oomoo`09Ool00`00Oomoo`0:Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`0:Ool00`00
Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`0:Ool00`00Oomoo`09Ool00`00Oomoo`0:Ool00`00
Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`0:Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00
Oomoo`0:Ool00`00Oomoo`07Ool4000BOol001moo`@000Yoo`03001oogoo00Yoo`03001oogoo00Uo
o`03001oogoo00Yoo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Yoo`03001oogoo00Uo
o`03001oogoo00Uoo`03001oogoo00Yoo`03001oogoo00Uoo`03001oogoo00Yoo`03001oogoo00Uo
o`03001oogoo00Uoo`03001oogoo00Yoo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Yo
o`03001oogoo00Moo`@0019oo`0087oo0P002goo00<007ooOol02Woo00<007ooOol02Goo00<007oo
Ool02Woo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol02Woo00<007ooOol02Goo00<007oo
Ool02Goo00<007ooOol02Woo00<007ooOol02Goo00<007ooOol02Woo00<007ooOol02Goo00<007oo
Ool02Goo00<007ooOol02Woo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol02Woo00<007oo
Ool027oo0P004goo000QOol00`00Oomoo`09Ool00`00Oomoo`0:Ool00`00Oomoo`09Ool00`00Oomo
o`0:Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`0:Ool00`00Oomoo`09Ool00`00Oomo
o`09Ool00`00Oomoo`0:Ool00`00Oomoo`09Ool00`00Oomoo`0:Ool00`00Oomoo`09Ool00`00Oomo
o`09Ool00`00Oomoo`0:Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`0:Ool00`00Oomo
o`0MOol0025oo`03001oogoo00Uoo`8000]oo`03001oogoo00Uoo`03001oogoo00Yoo`03001oogoo
00Uoo`03001oogoo00Uoo`03001oogoo00Yoo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo
00Yoo`03001oogoo00Uoo`03001oogoo00Yoo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo
00Yoo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Uoo`8001moo`008Goo00<007ooOol0
27oo10002Woo00<007ooOol02Goo00<007ooOol02Woo00<007ooOol02Goo00<007ooOol02Goo00<0
07ooOol02Woo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol02Woo00<007ooOol02Goo00<0
07ooOol02Woo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol02Woo00<007ooOol02Goo00<0
07ooOol02Goo00<007ooOol027oo10007Woo000QOol20009Ool4000:Ool00`00Oomoo`09Ool00`00
Oomoo`0:Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`0:Ool00`00Oomoo`09Ool00`00
Oomoo`09Ool00`00Oomoo`0:Ool00`00Oomoo`09Ool00`00Oomoo`0:Ool00`00Oomoo`09Ool00`00
Oomoo`09Ool00`00Oomoo`0:Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`08Ool4000N
Ool0025oo`03001oogoo00Uoo`8000]oo`03001oogoo00Uoo`03001oogoo00Yoo`03001oogoo00Uo
o`03001oogoo00Uoo`03001oogoo00Yoo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Yo
o`03001oogoo00Uoo`03001oogoo00Yoo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Yo
o`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Uoo`8001moo`008Goo00<007ooOol05Woo
00<007ooOol02Goo00<007ooOol02Woo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol02Woo
00<007ooOol02Goo00<007ooOol02Goo00<007ooOol02Woo00<007ooOol02Goo00<007ooOol02Woo
00<007ooOol02Goo00<007ooOol02Goo00<007ooOol02Woo00<007ooOol02Goo00<007ooOol02Goo
00<007ooOol0:Woo000QOol00`00Oomoo`0FOol00`00Oomoo`09Ool00`00Oomoo`0:Ool00`00Oomo
o`09Ool00`00Oomoo`09Ool00`00Oomoo`0:Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomo
o`0:Ool00`00Oomoo`09Ool00`00Oomoo`0:Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomo
o`0:Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`0ZOol0025oo`03001oogoo01Ioo`03
001oogoo00Uoo`03001oogoo00Yoo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Yoo`03
001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Yoo`03001oogoo00Uoo`03001oogoo00Yoo`03
001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Yoo`03001oogoo00Uoo`03001oogoo00Uoo`03
001oogoo02Yoo`008Goo00<007ooOol05Woo00<007ooOol02Goo00<007ooOol02Woo00<007ooOol0
2Goo00<007ooOol02Goo00<007ooOol02Woo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol0
2Woo00<007ooOol02Goo00<007ooOol02Woo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol0
2Woo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol0:Woo000QOol00`00Oomoo`0FOol00`00
Oomoo`09Ool00`00Oomoo`0:Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`0:Ool00`00
Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`0:Ool00`00Oomoo`09Ool00`00Oomoo`0:Ool00`00
Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`0:Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00
Oomoo`0ZOol0025oo`8001Ioo`8000]oo`03001oogoo00Yoo`03001oogoo00Uoo`03001oogoo00Uo
o`03001oogoo00Yoo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Yoo`03001oogoo00Uo
o`03001oogoo00Yoo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Yoo`03001oogoo00Uo
o`03001oogoo00Uoo`8002]oo`008Goo00<007ooOol057oo10002Woo00<007ooOol02Woo00<007oo
Ool02Goo00<007ooOol02Goo00<007ooOol02Woo00<007ooOol02Goo00<007ooOol02Goo00<007oo
Ool02Woo00<007ooOol02Goo00<007ooOol02Woo00<007ooOol02Goo00<007ooOol02Goo00<007oo
Ool02Woo00<007ooOol02Goo00<007ooOol027oo1000:Woo000QOol00`00Oomoo`0DOol4000:Ool0
0`00Oomoo`0:Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`0:Ool00`00Oomoo`09Ool0
0`00Oomoo`09Ool00`00Oomoo`0:Ool00`00Oomoo`09Ool00`00Oomoo`0:Ool00`00Oomoo`09Ool0
0`00Oomoo`09Ool00`00Oomoo`0:Ool00`00Oomoo`09Ool00`00Oomoo`08Ool4000ZOol0025oo`03
001oogoo01Eoo`8000]oo`03001oogoo00Yoo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo
00Yoo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Yoo`03001oogoo00Uoo`03001oogoo
00Yoo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Yoo`03001oogoo00Uoo`03001oogoo
00Uoo`8002]oo`008Goo00<007ooOol08Woo00<007ooOol02Woo00<007ooOol02Goo00<007ooOol0
2Goo00<007ooOol02Woo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol02Woo00<007ooOol0
2Goo00<007ooOol02Woo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol02Woo00<007ooOol0
2Goo00<007ooOol0=Woo000QOol00`00Oomoo`0ROol00`00Oomoo`0:Ool00`00Oomoo`09Ool00`00
Oomoo`09Ool00`00Oomoo`0:Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`0:Ool00`00
Oomoo`09Ool00`00Oomoo`0:Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`0:Ool00`00
Oomoo`09Ool00`00Oomoo`0fOol0025oo`03001oogoo029oo`03001oogoo00Yoo`03001oogoo00Uo
o`03001oogoo00Uoo`03001oogoo00Yoo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Yo
o`03001oogoo00Uoo`03001oogoo00Yoo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Yo
o`03001oogoo00Uoo`03001oogoo03Ioo`008Goo00<007ooOol08Woo00<007ooOol02Woo00<007oo
Ool02Goo00<007ooOol02Goo00<007ooOol02Woo00<007ooOol02Goo00<007ooOol02Goo00<007oo
Ool02Woo00<007ooOol02Goo00<007ooOol02Woo00<007ooOol02Goo00<007ooOol02Goo00<007oo
Ool02Woo00<007ooOol02Goo00<007ooOol0=Woo000QOol2000SOol00`00Oomoo`0:Ool00`00Oomo
o`09Ool00`00Oomoo`09Ool00`00Oomoo`0:Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomo
o`0:Ool00`00Oomoo`09Ool00`00Oomoo`0:Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomo
o`0:Ool00`00Oomoo`09Ool00`00Oomoo`0fOol0025oo`03001oogoo029oo`03001oogoo00Yoo`03
001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Yoo`03001oogoo00Uoo`03001oogoo00Uoo`03
001oogoo00Yoo`03001oogoo00Uoo`03001oogoo00Yoo`03001oogoo00Uoo`03001oogoo00Uoo`03
001oogoo00Yoo`03001oogoo00Uoo`03001oogoo03Ioo`008Goo00<007ooOol08Woo00<007ooOol0
2Woo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol02Woo00<007ooOol02Goo00<007ooOol0
2Goo00<007ooOol02Woo00<007ooOol02Goo00<007ooOol02Woo00<007ooOol02Goo00<007ooOol0
2Goo00<007ooOol02Woo00<007ooOol02Goo00<007ooOol0=Woo000QOol00`00Oomoo`0ROol00`00
Oomoo`0:Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`0:Ool00`00Oomoo`09Ool00`00
Oomoo`09Ool00`00Oomoo`0:Ool00`00Oomoo`09Ool00`00Oomoo`0:Ool00`00Oomoo`09Ool00`00
Oomoo`09Ool00`00Oomoo`0:Ool00`00Oomoo`09Ool00`00Oomoo`0fOol0025oo`03001oogoo029o
o`03001oogoo00Yoo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Yoo`03001oogoo00Uo
o`03001oogoo00Uoo`03001oogoo00Yoo`03001oogoo00Uoo`03001oogoo00Yoo`03001oogoo00Uo
o`03001oogoo00Uoo`03001oogoo00Yoo`03001oogoo00Uoo`03001oogoo03Ioo`004Goo00<007oo
Ool00Woo00@007ooOomoo`<000Aoo`03001oogoo029oo`03001oogoo00Yoo`03001oogoo00Uoo`03
001oogoo00Uoo`03001oogoo00Yoo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Yoo`03
001oogoo00Uoo`03001oogoo00Yoo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Yoo`03
001oogoo00Uoo`03001oogoo03Ioo`0047oo00<007oo00001goo00<007ooOol017oo00<007ooOol0
8Woo0P002goo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol02Woo00<007ooOol02Goo00<0
07ooOol02Goo00<007ooOol02Woo00<007ooOol02Goo00<007ooOol02Woo00<007ooOol02Goo00<0
07ooOol02Goo00<007ooOol02Woo00<007ooOol027oo0P00>7oo000@Ool00`00Ool00008Ool00`00
Oomoo`03Ool3000QOol4000:Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`0:Ool00`00
Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`0:Ool00`00Oomoo`09Ool00`00Oomoo`0:Ool00`00
Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`0:Ool00`00Oomoo`07Ool4000gOol0011oo`03001o
o`0000Qoo`03001oogoo00=oo`03001oogoo025oo`@000Yoo`03001oogoo00Uoo`03001oogoo00Uo
o`03001oogoo00Yoo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Yoo`03001oogoo00Uo
o`03001oogoo00Yoo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Yoo`03001oogoo00Mo
o`@003Moo`0047oo00<007oo00001goo00<007oo000017oo00<007ooOol08Woo0P002goo00<007oo
Ool02Goo00<007ooOol02Goo00<007ooOol02Woo00<007ooOol02Goo00<007ooOol02Goo00<007oo
Ool02Woo00<007ooOol02Goo00<007ooOol02Woo00<007ooOol02Goo00<007ooOol02Goo00<007oo
Ool02Woo00<007ooOol027oo0P00>7oo000AOol00`00Oomoo`07Ool00`00Oomoo`03Ool00`00Oomo
o`0_Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`0:Ool00`00Oomoo`09Ool00`00Oomo
o`09Ool00`00Oomoo`0:Ool00`00Oomoo`09Ool00`00Oomoo`0:Ool00`00Oomoo`09Ool00`00Oomo
o`09Ool00`00Oomoo`0:Ool00`00Oomoo`12Ool0025oo`03001oogoo02moo`03001oogoo00Uoo`03
001oogoo00Uoo`03001oogoo00Yoo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Yoo`03
001oogoo00Uoo`03001oogoo00Yoo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Yoo`03
001oogoo049oo`008Goo00<007ooOol0;goo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol0
2Woo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol02Woo00<007ooOol02Goo00<007ooOol0
2Woo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol02Woo00<007ooOol0@Woo000QOol00`00
Oomoo`0_Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`0:Ool00`00Oomoo`09Ool00`00
Oomoo`09Ool00`00Oomoo`0:Ool00`00Oomoo`09Ool00`00Oomoo`0:Ool00`00Oomoo`09Ool00`00
Oomoo`09Ool00`00Oomoo`0:Ool00`00Oomoo`12Ool0025oo`80031oo`03001oogoo00Uoo`03001o
ogoo00Uoo`03001oogoo00Yoo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Yoo`03001o
ogoo00Uoo`03001oogoo00Yoo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Yoo`03001o
ogoo049oo`008Goo00<007ooOol0;goo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol02Woo
00<007ooOol02Goo00<007ooOol02Goo00<007ooOol02Woo00<007ooOol02Goo00<007ooOol02Woo
00<007ooOol02Goo00<007ooOol02Goo00<007ooOol02Woo00<007ooOol0@Woo000QOol00`00Oomo
o`0_Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`0:Ool00`00Oomoo`09Ool00`00Oomo
o`09Ool00`00Oomoo`0:Ool00`00Oomoo`09Ool00`00Oomoo`0:Ool00`00Oomoo`09Ool00`00Oomo
o`09Ool00`00Oomoo`0:Ool00`00Oomoo`12Ool0025oo`03001oogoo02moo`03001oogoo00Uoo`03
001oogoo00Uoo`03001oogoo00Yoo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Yoo`03
001oogoo00Uoo`03001oogoo00Yoo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Yoo`03
001oogoo049oo`008Goo00<007ooOol0;goo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol0
2Woo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol02Woo00<007ooOol02Goo00<007ooOol0
2Woo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol02Woo00<007ooOol0@Woo000QOol00`00
Oomoo`0_Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`0:Ool00`00Oomoo`09Ool00`00
Oomoo`09Ool00`00Oomoo`0:Ool00`00Oomoo`09Ool00`00Oomoo`0:Ool00`00Oomoo`09Ool00`00
Oomoo`09Ool00`00Oomoo`0:Ool00`00Oomoo`12Ool0025oo`03001oogoo02moo`03001oogoo00Uo
o`03001oogoo00Uoo`03001oogoo00Yoo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Yo
o`03001oogoo00Uoo`03001oogoo00Yoo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Yo
o`03001oogoo049oo`008Goo00<007ooOol0;goo00<007ooOol02Goo00<007ooOol02Goo00<007oo
Ool02Woo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol02Woo00<007ooOol02Goo00<007oo
Ool02Woo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol02Woo00<007ooOol0@Woo000QOol2
000`Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`0:Ool00`00Oomoo`09Ool00`00Oomo
o`09Ool00`00Oomoo`0:Ool00`00Oomoo`09Ool00`00Oomoo`0:Ool00`00Oomoo`09Ool00`00Oomo
o`09Ool00`00Oomoo`0:Ool00`00Oomoo`12Ool0025oo`03001oogoo02moo`03001oogoo00Uoo`03
001oogoo00Uoo`03001oogoo00Yoo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Yoo`03
001oogoo00Uoo`03001oogoo00Yoo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Yoo`03
001oogoo049oo`008Goo00<007ooOol0;goo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol0
2Woo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol02Woo00<007ooOol02Goo00<007ooOol0
2Woo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol02Woo00<007ooOol0@Woo000QOol00`00
Oomoo`0^Ool2000;Ool00`00Oomoo`09Ool00`00Oomoo`0:Ool00`00Oomoo`09Ool00`00Oomoo`09
Ool00`00Oomoo`0:Ool00`00Oomoo`09Ool00`00Oomoo`0:Ool00`00Oomoo`09Ool00`00Oomoo`09
Ool00`00Oomoo`09Ool20014Ool0025oo`03001oogoo02eoo`@000Yoo`03001oogoo00Uoo`03001o
ogoo00Yoo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Yoo`03001oogoo00Uoo`03001o
ogoo00Yoo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Qoo`@004=oo`008Goo00<007oo
Ool0;Goo10002Woo00<007ooOol02Goo00<007ooOol02Woo00<007ooOol02Goo00<007ooOol02Goo
00<007ooOol02Woo00<007ooOol02Goo00<007ooOol02Woo00<007ooOol02Goo00<007ooOol02Goo
00<007ooOol027oo1000@goo000QOol00`00Oomoo`0^Ool2000;Ool00`00Oomoo`09Ool00`00Oomo
o`0:Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`0:Ool00`00Oomoo`09Ool00`00Oomo
o`0:Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`09Ool20014Ool0025oo`8003aoo`03
001oogoo00Uoo`03001oogoo00Yoo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Yoo`03
001oogoo00Uoo`03001oogoo00Yoo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo04moo`00
8Goo00<007ooOol0>goo00<007ooOol02Goo00<007ooOol02Woo00<007ooOol02Goo00<007ooOol0
2Goo00<007ooOol02Woo00<007ooOol02Goo00<007ooOol02Woo00<007ooOol02Goo00<007ooOol0
2Goo00<007ooOol0Cgoo000QOol00`00Oomoo`0kOol00`00Oomoo`09Ool00`00Oomoo`0:Ool00`00
Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`0:Ool00`00Oomoo`09Ool00`00Oomoo`0:Ool00`00
Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`1?Ool0025oo`03001oogoo03]oo`03001oogoo00Uo
o`03001oogoo00Yoo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Yoo`03001oogoo00Uo
o`03001oogoo00Yoo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo04moo`008Goo00<007oo
Ool0>goo00<007ooOol02Goo00<007ooOol02Woo00<007ooOol02Goo00<007ooOol02Goo00<007oo
Ool02Woo00<007ooOol02Goo00<007ooOol02Woo00<007ooOol02Goo00<007ooOol02Goo00<007oo
Ool0Cgoo000AOol00`00Oomoo`02Ool00`00Oomoo`02Ool30003Ool00`00Oomoo`0kOol00`00Oomo
o`09Ool00`00Oomoo`0:Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`0:Ool00`00Oomo
o`09Ool00`00Oomoo`0:Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`1?Ool0011oo`03
001oo`0000Uoo`03001oogoo009oo`03001oogoo03]oo`03001oogoo00Uoo`03001oogoo00Yoo`03
001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Yoo`03001oogoo00Uoo`03001oogoo00Yoo`03
001oogoo00Uoo`03001oogoo00Uoo`03001oogoo04moo`0047oo00<007oo00001goo10000goo0`00
>goo00<007ooOol02Goo00<007ooOol02Woo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol0
2Woo00<007ooOol02Goo00<007ooOol02Woo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol0
Cgoo000@Ool00`00Ool00007Ool00`00Ool00004Ool00`00Oomoo`0kOol00`00Oomoo`09Ool00`00
Oomoo`0:Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`0:Ool00`00Oomoo`09Ool00`00
Oomoo`0:Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`1?Ool0011oo`03001oo`0000Qo
o`8000Aoo`03001oogoo03]oo`03001oogoo00Uoo`03001oogoo00Yoo`03001oogoo00Uoo`03001o
ogoo00Uoo`03001oogoo00Yoo`03001oogoo00Uoo`03001oogoo00Yoo`03001oogoo00Uoo`03001o
ogoo00Uoo`03001oogoo04moo`004Goo00<007ooOol027oo00<007ooOol00Woo00<007ooOol0>goo
00<007ooOol02Goo00<007ooOol02Woo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol02Woo
00<007ooOol02Goo00<007ooOol02Woo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol0Cgoo
000QOol00`00Oomoo`0kOol00`00Oomoo`09Ool00`00Oomoo`0:Ool00`00Oomoo`09Ool00`00Oomo
o`09Ool00`00Oomoo`0:Ool00`00Oomoo`09Ool00`00Oomoo`0:Ool00`00Oomoo`09Ool00`00Oomo
o`09Ool00`00Oomoo`1?Ool0025oo`03001oogoo03]oo`03001oogoo00Uoo`03001oogoo00Yoo`03
001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Yoo`03001oogoo00Uoo`03001oogoo00Yoo`03
001oogoo00Uoo`03001oogoo00Uoo`03001oogoo04moo`008Goo00<007ooOol0>goo00<007ooOol0
2Goo00<007ooOol02Woo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol02Woo00<007ooOol0
2Goo00<007ooOol02Woo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol0Cgoo000QOol00`00
Oomoo`0kOol00`00Oomoo`09Ool00`00Oomoo`0:Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00
Oomoo`0:Ool00`00Oomoo`09Ool00`00Oomoo`0:Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00
Oomoo`1?Ool0025oo`8003aoo`03001oogoo00Uoo`03001oogoo00Yoo`03001oogoo00Uoo`03001o
ogoo00Uoo`03001oogoo00Yoo`03001oogoo00Uoo`03001oogoo00Yoo`03001oogoo00Uoo`03001o
ogoo00Uoo`03001oogoo04moo`008Goo00<007ooOol0>goo00<007ooOol02Goo00<007ooOol02Woo
00<007ooOol02Goo00<007ooOol02Goo00<007ooOol02Woo00<007ooOol02Goo00<007ooOol02Woo
00<007ooOol02Goo00<007ooOol02Goo00<007ooOol0Cgoo000QOol00`00Oomoo`0kOol00`00Oomo
o`09Ool00`00Oomoo`0:Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`0:Ool00`00Oomo
o`09Ool00`00Oomoo`0:Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`1?Ool0025oo`03
001oogoo03]oo`03001oogoo00Uoo`03001oogoo00Yoo`03001oogoo00Uoo`03001oogoo00Uoo`03
001oogoo00Yoo`03001oogoo00Uoo`03001oogoo00Yoo`03001oogoo00Uoo`03001oogoo00Uoo`03
001oogoo04moo`008Goo00<007ooOol0>Woo0P002goo00<007ooOol02Woo00<007ooOol02Goo00<0
07ooOol02Goo00<007ooOol02Woo00<007ooOol02Goo00<007ooOol02Woo00<007ooOol02Goo00<0
07ooOol02Goo0P00D7oo000QOol00`00Oomoo`0iOol4000:Ool00`00Oomoo`0:Ool00`00Oomoo`09
Ool00`00Oomoo`09Ool00`00Oomoo`0:Ool00`00Oomoo`09Ool00`00Oomoo`0:Ool00`00Oomoo`09
Ool00`00Oomoo`08Ool4001?Ool0025oo`03001oogoo03Uoo`@000Yoo`03001oogoo00Yoo`03001o
ogoo00Uoo`03001oogoo00Uoo`03001oogoo00Yoo`03001oogoo00Uoo`03001oogoo00Yoo`03001o
ogoo00Uoo`03001oogoo00Qoo`@004moo`008Goo0P00>goo0P002goo00<007ooOol02Woo00<007oo
Ool02Goo00<007ooOol02Goo00<007ooOol02Woo00<007ooOol02Goo00<007ooOol02Woo00<007oo
Ool02Goo00<007ooOol02Goo0P00D7oo000QOol00`00Oomoo`17Ool00`00Oomoo`0:Ool00`00Oomo
o`09Ool00`00Oomoo`09Ool00`00Oomoo`0:Ool00`00Oomoo`09Ool00`00Oomoo`0:Ool00`00Oomo
o`09Ool00`00Oomoo`1KOol0025oo`03001oogoo04Moo`03001oogoo00Yoo`03001oogoo00Uoo`03
001oogoo00Uoo`03001oogoo00Yoo`03001oogoo00Uoo`03001oogoo00Yoo`03001oogoo00Uoo`03
001oogoo05]oo`008Goo00<007ooOol0Agoo00<007ooOol02Woo00<007ooOol02Goo00<007ooOol0
2Goo00<007ooOol02Woo00<007ooOol02Goo00<007ooOol02Woo00<007ooOol02Goo00<007ooOol0
Fgoo000QOol00`00Oomoo`17Ool00`00Oomoo`0:Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00
Oomoo`0:Ool00`00Oomoo`09Ool00`00Oomoo`0:Ool00`00Oomoo`09Ool00`00Oomoo`1KOol0025o
o`03001oogoo04Moo`03001oogoo00Yoo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Yo
o`03001oogoo00Uoo`03001oogoo00Yoo`03001oogoo00Uoo`03001oogoo05]oo`008Goo00<007oo
Ool0Agoo00<007ooOol02Woo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol02Woo00<007oo
Ool02Goo00<007ooOol02Woo00<007ooOol02Goo00<007ooOol0Fgoo000QOol20018Ool00`00Oomo
o`0:Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`0:Ool00`00Oomoo`09Ool00`00Oomo
o`0:Ool00`00Oomoo`09Ool00`00Oomoo`1KOol0025oo`03001oogoo04Moo`03001oogoo00Yoo`03
001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Yoo`03001oogoo00Uoo`03001oogoo00Yoo`03
001oogoo00Uoo`03001oogoo05]oo`008Goo00<007ooOol0Agoo00<007ooOol02Woo00<007ooOol0
2Goo00<007ooOol02Goo00<007ooOol02Woo00<007ooOol02Goo00<007ooOol02Woo00<007ooOol0
2Goo00<007ooOol0Fgoo000QOol00`00Oomoo`17Ool00`00Oomoo`0:Ool00`00Oomoo`09Ool00`00
Oomoo`09Ool00`00Oomoo`0:Ool00`00Oomoo`09Ool00`00Oomoo`0:Ool00`00Oomoo`09Ool00`00
Oomoo`1KOol0025oo`03001oogoo04Moo`03001oogoo00Yoo`03001oogoo00Uoo`03001oogoo00Uo
o`03001oogoo00Yoo`03001oogoo00Uoo`03001oogoo00Yoo`03001oogoo00Uoo`03001oogoo05]o
o`008Goo00<007ooOol0Agoo00<007ooOol02Woo00<007ooOol02Goo00<007ooOol02Goo00<007oo
Ool02Woo00<007ooOol02Goo00<007ooOol02Woo00<007ooOol02Goo00<007ooOol0Fgoo000AOol0
0`00Oomoo`02Ool01000Oomoogoo0P001Goo00<007ooOol0Agoo00<007ooOol02Woo00<007ooOol0
2Goo00<007ooOol02Goo00<007ooOol02Woo00<007ooOol02Goo00<007ooOol02Woo00<007ooOol0
2Goo00<007ooOol0Fgoo000@Ool00`00Ool00007Ool00`00Ool00004Ool00`00Oomoo`17Ool00`00
Oomoo`0:Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`0:Ool00`00Oomoo`09Ool00`00
Oomoo`0:Ool00`00Oomoo`09Ool00`00Oomoo`1KOol0011oo`03001oo`0000Moo`03001oo`0000Ao
o`<004Moo`03001oogoo00Yoo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Yoo`03001o
ogoo00Uoo`03001oogoo00Yoo`03001oogoo00Uoo`03001oogoo05]oo`0047oo00<007oo00001goo
0P001Goo00<007ooOol0Agoo00<007ooOol02Woo00<007ooOol02Goo00<007ooOol02Goo00<007oo
Ool02Woo00<007ooOol02Goo00<007ooOol02Woo00<007ooOol02Goo00<007ooOol0Fgoo000@Ool0
0`00Ool00007Ool00`00Oomoo`04Ool00`00Oomoo`17Ool00`00Oomoo`0:Ool00`00Oomoo`09Ool0
0`00Oomoo`09Ool00`00Oomoo`0:Ool00`00Oomoo`09Ool00`00Oomoo`0:Ool00`00Oomoo`09Ool0
0`00Oomoo`1KOol0015oo`03001oogoo00Moo`8000Aoo`03001oogoo04Moo`03001oogoo00Yoo`03
001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Yoo`03001oogoo00Uoo`03001oogoo00Yoo`03
001oogoo00Uoo`03001oogoo05]oo`008Goo00<007ooOol0Agoo00<007ooOol02Woo00<007ooOol0
2Goo00<007ooOol02Goo00<007ooOol02Woo00<007ooOol02Goo00<007ooOol02Woo00<007ooOol0
2Goo00<007ooOol0Fgoo000QOol00`00Oomoo`17Ool00`00Oomoo`0:Ool00`00Oomoo`09Ool00`00
Oomoo`09Ool00`00Oomoo`0:Ool00`00Oomoo`09Ool00`00Oomoo`0:Ool00`00Oomoo`09Ool00`00
Oomoo`1KOol0025oo`03001oogoo04Moo`03001oogoo00Yoo`03001oogoo00Uoo`03001oogoo00Uo
o`03001oogoo00Yoo`03001oogoo00Uoo`03001oogoo00Yoo`03001oogoo00Uoo`03001oogoo05]o
o`008Goo0P00B7oo0P002goo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol02Woo00<007oo
Ool02Goo00<007ooOol02Woo00<007ooOol027oo0P00GGoo000QOol00`00Oomoo`16Ool4000:Ool0
0`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`0:Ool00`00Oomoo`09Ool00`00Oomoo`0:Ool0
0`00Oomoo`07Ool4001LOol0025oo`03001oogoo04Ioo`@000Yoo`03001oogoo00Uoo`03001oogoo
00Uoo`03001oogoo00Yoo`03001oogoo00Uoo`03001oogoo00Yoo`03001oogoo00Moo`@005aoo`00
8Goo00<007ooOol0Agoo0P002goo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol02Woo00<0
07ooOol02Goo00<007ooOol02Woo00<007ooOol027oo0P00GGoo000QOol00`00Oomoo`1DOol00`00
Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`0:Ool00`00Oomoo`09Ool00`00Oomoo`0:Ool00`00
Oomoo`1WOol0025oo`03001oogoo05Aoo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Yo
o`03001oogoo00Uoo`03001oogoo00Yoo`03001oogoo06Moo`008Goo00<007ooOol0E7oo00<007oo
Ool02Goo00<007ooOol02Goo00<007ooOol02Woo00<007ooOol02Goo00<007ooOol02Woo00<007oo
Ool0Igoo000QOol2001EOol00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`0:Ool00`00Oomo
o`09Ool00`00Oomoo`0:Ool00`00Oomoo`1WOol0025oo`03001oogoo05Aoo`03001oogoo00Uoo`03
001oogoo00Uoo`03001oogoo00Yoo`03001oogoo00Uoo`03001oogoo00Yoo`03001oogoo06Moo`00
8Goo00<007ooOol0E7oo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol02Woo00<007ooOol0
2Goo00<007ooOol02Woo00<007ooOol0Igoo000QOol00`00Oomoo`1DOol00`00Oomoo`09Ool00`00
Oomoo`09Ool00`00Oomoo`0:Ool00`00Oomoo`09Ool00`00Oomoo`0:Ool00`00Oomoo`1WOol0025o
o`03001oogoo05Aoo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Yoo`03001oogoo00Uo
o`03001oogoo00Yoo`03001oogoo06Moo`008Goo00<007ooOol0E7oo00<007ooOol02Goo00<007oo
Ool02Goo00<007ooOol02Woo00<007ooOol02Goo00<007ooOol02Woo00<007ooOol0Igoo000QOol0
0`00Oomoo`1DOol00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`0:Ool00`00Oomoo`09Ool0
0`00Oomoo`0:Ool00`00Oomoo`1WOol0025oo`8005Eoo`03001oogoo00Uoo`03001oogoo00Uoo`03
001oogoo00Yoo`03001oogoo00Uoo`03001oogoo00Yoo`03001oogoo06Moo`008Goo00<007ooOol0
E7oo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol02Woo00<007ooOol02Goo00<007ooOol0
2Woo00<007ooOol0Igoo000QOol00`00Oomoo`1DOol00`00Oomoo`09Ool00`00Oomoo`09Ool00`00
Oomoo`0:Ool00`00Oomoo`09Ool00`00Oomoo`0:Ool00`00Oomoo`1WOol0025oo`03001oogoo05Ao
o`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Yoo`03001oogoo00Uoo`03001oogoo00Yo
o`03001oogoo06Moo`008Goo00<007ooOol0E7oo00<007ooOol02Goo00<007ooOol02Goo00<007oo
Ool02Woo00<007ooOol02Goo00<007ooOol02Woo00<007ooOol0Igoo000QOol00`00Oomoo`1DOol0
0`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`0:Ool00`00Oomoo`09Ool00`00Oomoo`0:Ool0
0`00Oomoo`1WOol0015oo`03001oogoo009oo`03001oogoo009oo`03001oogoo00=oo`03001oogoo
05Aoo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Yoo`03001oogoo00Uoo`03001oogoo
00Yoo`03001oogoo06Moo`0047oo00<007oo00001goo00<007oo000017oo00<007ooOol0E7oo00<0
07ooOol02Goo00<007ooOol02Goo00<007ooOol02Woo00<007ooOol02Goo00<007ooOol02Woo00<0
07ooOol0Igoo000@Ool00`00Ool00007Ool00`00Ool00004Ool3001COol2000;Ool00`00Oomoo`09
Ool00`00Oomoo`0:Ool00`00Oomoo`09Ool00`00Oomoo`09Ool2001YOol0011oo`03001oo`0000Qo
o`03001oogoo00=oo`03001oogoo059oo`@000Yoo`03001oogoo00Uoo`03001oogoo00Yoo`03001o
ogoo00Uoo`03001oogoo00Qoo`@006Qoo`0047oo00<007oo00001goo00<007oo000017oo00<007oo
Ool0DWoo10002Woo00<007ooOol02Goo00<007ooOol02Woo00<007ooOol02Goo00<007ooOol027oo
1000J7oo000AOol00`00Oomoo`07Ool00`00Oomoo`03Ool00`00Oomoo`1COol2000;Ool00`00Oomo
o`09Ool00`00Oomoo`0:Ool00`00Oomoo`09Ool00`00Oomoo`09Ool2001YOol0025oo`03001oogoo
061oo`03001oogoo00Uoo`03001oogoo00Yoo`03001oogoo00Uoo`03001oogoo07Aoo`008Goo00<0
07ooOol0H7oo00<007ooOol02Goo00<007ooOol02Woo00<007ooOol02Goo00<007ooOol0M7oo000Q
Ool00`00Oomoo`1POol00`00Oomoo`09Ool00`00Oomoo`0:Ool00`00Oomoo`09Ool00`00Oomoo`1d
Ool0025oo`80065oo`03001oogoo00Uoo`03001oogoo00Yoo`03001oogoo00Uoo`03001oogoo07Ao
o`008Goo00<007ooOol0H7oo00<007ooOol02Goo00<007ooOol02Woo00<007ooOol02Goo00<007oo
Ool0M7oo000QOol00`00Oomoo`1POol00`00Oomoo`09Ool00`00Oomoo`0:Ool00`00Oomoo`09Ool0
0`00Oomoo`1dOol0025oo`03001oogoo061oo`03001oogoo00Uoo`03001oogoo00Yoo`03001oogoo
00Uoo`03001oogoo07Aoo`008Goo00<007ooOol0H7oo00<007ooOol02Goo00<007ooOol02Woo00<0
07ooOol02Goo00<007ooOol0M7oo000QOol00`00Oomoo`1POol00`00Oomoo`09Ool00`00Oomoo`0:
Ool00`00Oomoo`09Ool00`00Oomoo`1dOol0025oo`03001oogoo061oo`03001oogoo00Uoo`03001o
ogoo00Yoo`03001oogoo00Uoo`03001oogoo07Aoo`008Goo0P00HGoo00<007ooOol02Goo00<007oo
Ool02Woo00<007ooOol02Goo00<007ooOol0M7oo000QOol00`00Oomoo`1POol00`00Oomoo`09Ool0
0`00Oomoo`0:Ool00`00Oomoo`09Ool00`00Oomoo`1dOol0025oo`03001oogoo061oo`03001oogoo
00Uoo`03001oogoo00Yoo`03001oogoo00Uoo`03001oogoo07Aoo`008Goo00<007ooOol0Ggoo0P00
2goo00<007ooOol02Woo00<007ooOol027oo0P00MWoo000QOol00`00Oomoo`1NOol4000:Ool00`00
Oomoo`0:Ool00`00Oomoo`07Ool4001eOol0025oo`03001oogoo05ioo`@000Yoo`03001oogoo00Yo
o`03001oogoo00Moo`@007Eoo`008Goo00<007ooOol0Ggoo0P002goo00<007ooOol02Woo00<007oo
Ool027oo0P00MWoo000QOol00`00Oomoo`1/Ool00`00Oomoo`0:Ool00`00Oomoo`20Ool0025oo`80
06eoo`03001oogoo00Yoo`03001oogoo081oo`008Goo00<007ooOol0K7oo00<007ooOol02Woo00<0
07ooOol0P7oo000QOol00`00Oomoo`1/Ool00`00Oomoo`0:Ool00`00Oomoo`20Ool0025oo`03001o
ogoo06aoo`03001oogoo00Yoo`03001oogoo081oo`008Goo00<007ooOol0K7oo00<007ooOol02Woo
00<007ooOol0P7oo000IOol50003Ool00`00Oomoo`1/Ool2000:Ool20022Ool001]oo`03001oogoo
00=oo`03001oogoo06]oo`@000Qoo`@0085oo`006goo00<007ooOol00goo0`00Jgoo100027oo1000
PGoo000KOol00`00Oomoo`03Ool00`00Oomoo`1/Ool2000:Ool20022Ool001]oo`03001oogoo00=o
o`03001oogoo0?aoo`006Woo0P001Goo00<007ooOol0o7oo003oOolQOol00?moob5oo`00ogoo8Goo
003oOolQOol009eoo`80085oo`00Wgoo00<007ooOol0OWoo001KOol40002Ool30002Ool20003Ool3
0002Ool30003Ool20003Ool20003Ool2000@Ool30002Ool30003Ool50002Ool00`00Ool000030000
17oo000000003Goo0`000goo0`000goo0P000goo0P00DWoo001LOol01000Oomoo`000Woo00<007oo
Ool00goo00@007ooOol000Eoo`05001oogooOol00004Ool01P00Oomoo`00Ool0019oo`03001oo`00
00=oo`05001oogooOol00002Ool00`00Ool00002Ool00`00Ool000020003Ool00`00Oomoo`0=Ool0
0`00Oomoo`03Ool01@00Oomoogoo00000Woo00<007oo00000Woo00<007ooOol0Cgoo001LOol01000
Oomoo`000Woo00<007ooOol00Woo00D007ooOomoo`0000Eoo`04001oogooOol30002Ool00`00Oomo
o`02Ool3000BOol01@00Oomoogoo00000goo00H007ooOol007oo0002Ool01@00Oomoogoo00000goo
00<007ooOol03Goo0`000goo00D007ooOomoo`00009oo`03001oo`0005Aoo`00G7oo00D007ooOol0
07oo008000Aoo`80009oo`<0009oo`@00005Ool00000001oo`040002Ool3000AOol01000Oomoogoo
0P0017oo1`000goo0P000goo00<007ooOol03Goo00@007ooOol0009oo`03001oogoo009oo`800003
Ool000000080059oo`00G7oo00@007ooOol001Yoo`03001oogoo01Eoo`03001oo`0001Moo`03001o
ogoo00eoo`04001oogoo0002Ool00`00Oomoo`06Ool00`00Oomoo`1BOol005]oo`@000=oo`03001o
ogoo02eoo`<000=oo`03001oogoo011oo`8000ioo`@0009oo`8005eoo`00ogoo8Goo003oOolQOol0
0?moob5oo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-2.71495, -0.0825045, 
  0.0808378, 0.00682733}}]
}, Open  ]],

Cell[TextData[
"The two window parameters {L, \[Alpha]} are computable from filter \
specifications: the ripple A in dB and transition width w in radians/sec. The \
design equations developed by Kaiser (1963, 1974) are as follows."], "Text",
  TextJustification->0,
  FontFamily->"Times New Roman"],

Cell[TextData[
"First, the design equations for the shape parameter \[Alpha]"], "Text",
  TextJustification->0,
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(alpha[A_] := 0.1102 \((A - 8.7)\)\  /; \ A >= 50; \n
    alpha[A_] := 
      0.5842 \((A - 21)\)\^0.4 + 0.07886\ \((A - 21)\)\  /; \ 
        A > 21\  && \ A < 50; \nalpha[A_] := 0\  /; \ A < 21; \)], "Input",
  TextJustification->0],

Cell["\<\
where A is the ripple in dB. Next, the formula for the window length WL \
\>", "Text",
  TextJustification->0,
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(\(WL[w_, A_] := 
      Block[{d}, \n\t\td = If[A > 21, \(A - 7.95\)\/14.36, 0.922\ ]; \n\t\t
        Ceiling[2  \[Pi]\ d/w + 1]]; \)\)], "Input",
  TextJustification->0],

Cell["\<\
where w is the width of the transition region in radians per second \
(normalized).\
\>", "Text",
  TextJustification->0,
  FontFamily->"Times New Roman"],

Cell[CellGroupData[{

Cell["Example 1", "Subsubsection",
  TextJustification->0,
  FontFamily->"Times New Roman"],

Cell[TextData[
"Obtain the Kaiser window for a desired ripple of 80 dB and a transition \
width of 0.1\[Pi]."], "Text",
  TextJustification->0,
  FontFamily->"Times New Roman"],

Cell[TextData[{
  StyleBox["Solution.",
    FontWeight->"Bold"],
  " The window parameters, and the window itself are "
}], "Text",
  TextJustification->0,
  FontFamily->"Times New Roman"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[Alpha] = alpha[80]\)], "Input",
  TextJustification->0],

Cell["7.85726", "Output",
  TextJustification->0]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(L = WL[0.1  \[Pi], 80]\)], "Input",
  TextJustification->0],

Cell["102", "Output",
  TextJustification->0]
}, Open  ]],

Cell[BoxData[
    \(\(w = KaiserWindow[\[Alpha], L]; \)\)], "Input",
  TextJustification->0],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(DiscreteSignalPlot[w]; \)\)], "Input",
  TextJustification->0],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00942951 0.0147151 0.588816 [
[.2124 .00222 -6 -9 ]
[.2124 .00222 6 0 ]
[.40099 .00222 -6 -9 ]
[.40099 .00222 6 0 ]
[.58958 .00222 -6 -9 ]
[.58958 .00222 6 0 ]
[.77817 .00222 -6 -9 ]
[.77817 .00222 6 0 ]
[.96676 .00222 -9 -9 ]
[.96676 .00222 9 0 ]
[.01131 .13248 -18 -4.5 ]
[.01131 .13248 0 4.5 ]
[.01131 .25024 -18 -4.5 ]
[.01131 .25024 0 4.5 ]
[.01131 .368 -18 -4.5 ]
[.01131 .368 0 4.5 ]
[.01131 .48577 -18 -4.5 ]
[.01131 .48577 0 4.5 ]
[.01131 .60353 -6 -4.5 ]
[.01131 .60353 0 4.5 ]
[.5 .63053 -62 0 ]
[.5 .63053 62 16 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.2124 .01472 m
.2124 .02097 L
s
[(20)] .2124 .00222 0 1 Mshowa
.40099 .01472 m
.40099 .02097 L
s
[(40)] .40099 .00222 0 1 Mshowa
.58958 .01472 m
.58958 .02097 L
s
[(60)] .58958 .00222 0 1 Mshowa
.77817 .01472 m
.77817 .02097 L
s
[(80)] .77817 .00222 0 1 Mshowa
.96676 .01472 m
.96676 .02097 L
s
[(100)] .96676 .00222 0 1 Mshowa
0 .01472 m
1 .01472 L
s
.02381 .13248 m
.03006 .13248 L
s
[(0.2)] .01131 .13248 1 0 Mshowa
.02381 .25024 m
.03006 .25024 L
s
[(0.4)] .01131 .25024 1 0 Mshowa
.02381 .368 m
.03006 .368 L
s
[(0.6)] .01131 .368 1 0 Mshowa
.02381 .48577 m
.03006 .48577 L
s
[(0.8)] .01131 .48577 1 0 Mshowa
.02381 .60353 m
.03006 .60353 L
s
[(1)] .01131 .60353 1 0 Mshowa
.125 Mabswid
.02381 .04416 m
.02756 .04416 L
s
.02381 .0736 m
.02756 .0736 L
s
.02381 .10304 m
.02756 .10304 L
s
.02381 .16192 m
.02756 .16192 L
s
.02381 .19136 m
.02756 .19136 L
s
.02381 .2208 m
.02756 .2208 L
s
.02381 .27968 m
.02756 .27968 L
s
.02381 .30912 m
.02756 .30912 L
s
.02381 .33856 m
.02756 .33856 L
s
.02381 .39745 m
.02756 .39745 L
s
.02381 .42689 m
.02756 .42689 L
s
.02381 .45633 m
.02756 .45633 L
s
.02381 .51521 m
.02756 .51521 L
s
.02381 .54465 m
.02756 .54465 L
s
.02381 .57409 m
.02756 .57409 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -123 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Discrete) show
117.000000 15.000000 moveto
(Signal) show
159.000000 15.000000 moveto
(Plot) show
183.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.00397 w
.02381 .01472 m
.02381 .01629 L
s
.0119 w
.02381 .01629 Mdot
.00397 w
.03324 .01472 m
.03324 .0174 L
s
.0119 w
.03324 .0174 Mdot
.00397 w
.04267 .01472 m
.04267 .01882 L
s
.0119 w
.04267 .01882 Mdot
.00397 w
.0521 .01472 m
.0521 .02061 L
s
.0119 w
.0521 .02061 Mdot
.00397 w
.06153 .01472 m
.06153 .02281 L
s
.0119 w
.06153 .02281 Mdot
.00397 w
.07096 .01472 m
.07096 .02547 L
s
.0119 w
.07096 .02547 Mdot
.00397 w
.08039 .01472 m
.08039 .02864 L
s
.0119 w
.08039 .02864 Mdot
.00397 w
.08982 .01472 m
.08982 .03236 L
s
.0119 w
.08982 .03236 Mdot
.00397 w
.09925 .01472 m
.09925 .03669 L
s
.0119 w
.09925 .03669 Mdot
.00397 w
.10868 .01472 m
.10868 .04168 L
s
.0119 w
.10868 .04168 Mdot
.00397 w
.1181 .01472 m
.1181 .04735 L
s
.0119 w
.1181 .04735 Mdot
.00397 w
.12753 .01472 m
.12753 .05377 L
s
.0119 w
.12753 .05377 Mdot
.00397 w
.13696 .01472 m
.13696 .06096 L
s
.0119 w
.13696 .06096 Mdot
.00397 w
.14639 .01472 m
.14639 .06895 L
s
.0119 w
.14639 .06895 Mdot
.00397 w
.15582 .01472 m
.15582 .07779 L
s
.0119 w
.15582 .07779 Mdot
.00397 w
.16525 .01472 m
.16525 .08749 L
s
.0119 w
.16525 .08749 Mdot
.00397 w
.17468 .01472 m
.17468 .09806 L
s
.0119 w
.17468 .09806 Mdot
.00397 w
.18411 .01472 m
.18411 .10952 L
s
.0119 w
.18411 .10952 Mdot
.00397 w
.19354 .01472 m
.19354 .12187 L
s
.0119 w
.19354 .12187 Mdot
.00397 w
.20297 .01472 m
.20297 .1351 L
s
.0119 w
.20297 .1351 Mdot
.00397 w
.2124 .01472 m
.2124 .1492 L
s
.0119 w
.2124 .1492 Mdot
.00397 w
.22183 .01472 m
.22183 .16415 L
s
.0119 w
.22183 .16415 Mdot
.00397 w
.23126 .01472 m
.23126 .17991 L
s
.0119 w
.23126 .17991 Mdot
.00397 w
.24069 .01472 m
.24069 .19644 L
s
.0119 w
.24069 .19644 Mdot
.00397 w
.25012 .01472 m
.25012 .21369 L
s
.0119 w
.25012 .21369 Mdot
.00397 w
.25955 .01472 m
.25955 .23161 L
s
.0119 w
.25955 .23161 Mdot
.00397 w
.26898 .01472 m
.26898 .25011 L
s
.0119 w
.26898 .25011 Mdot
.00397 w
.27841 .01472 m
.27841 .26913 L
s
.0119 w
.27841 .26913 Mdot
.00397 w
.28784 .01472 m
.28784 .28858 L
s
.0119 w
.28784 .28858 Mdot
.00397 w
.29727 .01472 m
.29727 .30837 L
s
.0119 w
.29727 .30837 Mdot
.00397 w
.30669 .01472 m
.30669 .3284 L
s
.0119 w
.30669 .3284 Mdot
.00397 w
.31612 .01472 m
.31612 .34855 L
s
.0119 w
.31612 .34855 Mdot
.00397 w
.32555 .01472 m
.32555 .36872 L
s
.0119 w
.32555 .36872 Mdot
.00397 w
.33498 .01472 m
.33498 .38879 L
s
.0119 w
.33498 .38879 Mdot
.00397 w
.34441 .01472 m
.34441 .40865 L
s
.0119 w
.34441 .40865 Mdot
.00397 w
.35384 .01472 m
.35384 .42817 L
s
.0119 w
.35384 .42817 Mdot
.00397 w
.36327 .01472 m
.36327 .44722 L
s
.0119 w
.36327 .44722 Mdot
.00397 w
.3727 .01472 m
.3727 .46568 L
s
.0119 w
.3727 .46568 Mdot
.00397 w
.38213 .01472 m
.38213 .48344 L
s
.0119 w
.38213 .48344 Mdot
.00397 w
.39156 .01472 m
.39156 .50036 L
s
.0119 w
.39156 .50036 Mdot
.00397 w
.40099 .01472 m
.40099 .51634 L
s
.0119 w
.40099 .51634 Mdot
.00397 w
.41042 .01472 m
.41042 .53127 L
s
.0119 w
.41042 .53127 Mdot
.00397 w
.41985 .01472 m
.41985 .54503 L
s
.0119 w
.41985 .54503 Mdot
.00397 w
.42928 .01472 m
.42928 .55753 L
s
.0119 w
.42928 .55753 Mdot
.00397 w
.43871 .01472 m
.43871 .56867 L
s
.0119 w
.43871 .56867 Mdot
.00397 w
.44814 .01472 m
.44814 .57838 L
s
.0119 w
.44814 .57838 Mdot
.00397 w
.45757 .01472 m
.45757 .58659 L
s
.0119 w
.45757 .58659 Mdot
.00397 w
.467 .01472 m
.467 .59323 L
s
.0119 w
.467 .59323 Mdot
.00397 w
.47643 .01472 m
.47643 .59826 L
s
.0119 w
.47643 .59826 Mdot
.00397 w
.48586 .01472 m
.48586 .60163 L
s
.0119 w
.48586 .60163 Mdot
.00397 w
.49529 .01472 m
.49529 .60332 L
s
.0119 w
.49529 .60332 Mdot
.00397 w
.50471 .01472 m
.50471 .60332 L
s
.0119 w
.50471 .60332 Mdot
.00397 w
.51414 .01472 m
.51414 .60163 L
s
.0119 w
.51414 .60163 Mdot
.00397 w
.52357 .01472 m
.52357 .59826 L
s
.0119 w
.52357 .59826 Mdot
.00397 w
.533 .01472 m
.533 .59323 L
s
.0119 w
.533 .59323 Mdot
.00397 w
.54243 .01472 m
.54243 .58659 L
s
.0119 w
.54243 .58659 Mdot
.00397 w
.55186 .01472 m
.55186 .57838 L
s
.0119 w
.55186 .57838 Mdot
.00397 w
.56129 .01472 m
.56129 .56867 L
s
.0119 w
.56129 .56867 Mdot
.00397 w
.57072 .01472 m
.57072 .55753 L
s
.0119 w
.57072 .55753 Mdot
.00397 w
.58015 .01472 m
.58015 .54503 L
s
.0119 w
.58015 .54503 Mdot
.00397 w
.58958 .01472 m
.58958 .53127 L
s
.0119 w
.58958 .53127 Mdot
.00397 w
.59901 .01472 m
.59901 .51634 L
s
.0119 w
.59901 .51634 Mdot
.00397 w
.60844 .01472 m
.60844 .50036 L
s
.0119 w
.60844 .50036 Mdot
.00397 w
.61787 .01472 m
.61787 .48344 L
s
.0119 w
.61787 .48344 Mdot
.00397 w
.6273 .01472 m
.6273 .46568 L
s
.0119 w
.6273 .46568 Mdot
.00397 w
.63673 .01472 m
.63673 .44722 L
s
.0119 w
.63673 .44722 Mdot
.00397 w
.64616 .01472 m
.64616 .42817 L
s
.0119 w
.64616 .42817 Mdot
.00397 w
.65559 .01472 m
.65559 .40865 L
s
.0119 w
.65559 .40865 Mdot
.00397 w
.66502 .01472 m
.66502 .38879 L
s
.0119 w
.66502 .38879 Mdot
.00397 w
.67445 .01472 m
.67445 .36872 L
s
.0119 w
.67445 .36872 Mdot
.00397 w
.68388 .01472 m
.68388 .34855 L
s
.0119 w
.68388 .34855 Mdot
.00397 w
.69331 .01472 m
.69331 .3284 L
s
.0119 w
.69331 .3284 Mdot
.00397 w
.70273 .01472 m
.70273 .30837 L
s
.0119 w
.70273 .30837 Mdot
.00397 w
.71216 .01472 m
.71216 .28858 L
s
.0119 w
.71216 .28858 Mdot
.00397 w
.72159 .01472 m
.72159 .26913 L
s
.0119 w
.72159 .26913 Mdot
.00397 w
.73102 .01472 m
.73102 .25011 L
s
.0119 w
.73102 .25011 Mdot
.00397 w
.74045 .01472 m
.74045 .23161 L
s
.0119 w
.74045 .23161 Mdot
.00397 w
.74988 .01472 m
.74988 .21369 L
s
.0119 w
.74988 .21369 Mdot
.00397 w
.75931 .01472 m
.75931 .19644 L
s
.0119 w
.75931 .19644 Mdot
.00397 w
.76874 .01472 m
.76874 .17991 L
s
.0119 w
.76874 .17991 Mdot
.00397 w
.77817 .01472 m
.77817 .16415 L
s
.0119 w
.77817 .16415 Mdot
.00397 w
.7876 .01472 m
.7876 .1492 L
s
.0119 w
.7876 .1492 Mdot
.00397 w
.79703 .01472 m
.79703 .1351 L
s
.0119 w
.79703 .1351 Mdot
.00397 w
.80646 .01472 m
.80646 .12187 L
s
.0119 w
.80646 .12187 Mdot
.00397 w
.81589 .01472 m
.81589 .10952 L
s
.0119 w
.81589 .10952 Mdot
.00397 w
.82532 .01472 m
.82532 .09806 L
s
.0119 w
.82532 .09806 Mdot
.00397 w
.83475 .01472 m
.83475 .08749 L
s
.0119 w
.83475 .08749 Mdot
.00397 w
.84418 .01472 m
.84418 .07779 L
s
.0119 w
.84418 .07779 Mdot
.00397 w
.85361 .01472 m
.85361 .06895 L
s
.0119 w
.85361 .06895 Mdot
.00397 w
.86304 .01472 m
.86304 .06096 L
s
.0119 w
.86304 .06096 Mdot
.00397 w
.87247 .01472 m
.87247 .05377 L
s
.0119 w
.87247 .05377 Mdot
.00397 w
.8819 .01472 m
.8819 .04735 L
s
.0119 w
.8819 .04735 Mdot
.00397 w
.89132 .01472 m
.89132 .04168 L
s
.0119 w
.89132 .04168 Mdot
.00397 w
.90075 .01472 m
.90075 .03669 L
s
.0119 w
.90075 .03669 Mdot
.00397 w
.91018 .01472 m
.91018 .03236 L
s
.0119 w
.91018 .03236 Mdot
.00397 w
.91961 .01472 m
.91961 .02864 L
s
.0119 w
.91961 .02864 Mdot
.00397 w
.92904 .01472 m
.92904 .02547 L
s
.0119 w
.92904 .02547 Mdot
.00397 w
.93847 .01472 m
.93847 .02281 L
s
.0119 w
.93847 .02281 Mdot
.00397 w
.9479 .01472 m
.9479 .02061 L
s
.0119 w
.9479 .02061 Mdot
.00397 w
.95733 .01472 m
.95733 .01882 L
s
.0119 w
.95733 .01882 Mdot
.00397 w
.96676 .01472 m
.96676 .0174 L
s
.0119 w
.96676 .0174 Mdot
.00397 w
.97619 .01472 m
.97619 .01629 L
s
.0119 w
.97619 .01629 Mdot
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  TextJustification->0,
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo001=Ool3
0003Ool00`00Oomoo`0UOol30002Ool00`00Oomoo`0UOol20004Ool00`00Oomoo`0UOol00`00Oomo
o`02Ool00`00Oomoo`0ROol50002Ool00`00Oomoo`02Ool00`00Oomoo`0AOol004eoo`03001oogoo
009oo`03001oo`0002Moo`06001oogoo001oo`009Woo00<007oo00000Woo00<007oo00009Goo00<0
07oo00000Woo00<007oo00009Goo00L007ooOomoo`00Ool00002Ool00`00Ool0000BOol004ioo`07
001oogooOol007oo00009Goo100000Aoo`00Ool002Ioo`03001oo`00009oo`03001oo`0002Eoo`03
001oo`00009oo`03001oo`0002Eoo`07001oogooOol007oo00000Woo00<007oo00004Woo001>Ool0
1`00Oomoogoo001oo`0002Eoo`03001oo`00009oo`03001oo`0002Ioo`8000=oo`03001oo`0002Io
o`07001oogooOol007oo00009Goo00L007ooOomoo`00Ool00002Ool00`00Ool0000BOol004eoo`03
001oo`00009oo`03001oo`0002Ioo`80009oo`03001oo`0002Ioo`03001oogoo009oo`03001oo`00
02Eoo`03001oo`00009oo`03001oo`0002Eoo`07001oogooOol007oo00000Woo00<007oo00004Woo
001>Ool00`00Oomoo`02Ool00`00Oomoo`0VOol01@00Oomoogoo0000:7oo0P000goo00<007ooOol0
9Goo00<007ooOol00Woo00<007ooOol08goo0P0017oo00<007ooOol00Woo00<007ooOol04Goo003o
OolQOol002=oo`03001oogoo0?Yoo`008goo00<007ooOol0nWoo000SOol00`00Oomoo`3jOol002=o
o`03001oogoo0?Yoo`007Gool`0047oo000ROol30003Ool01`00Ool007oo001oo`00009oo`05001o
o`00Ool00002Ool01`00Ool007oo001oo`00009oo`07001oo`00Ool007oo00000Woo00D007oo001o
o`00009oo`07001oo`00Ool007oo00000Woo00D007oo001oo`00009oo`07001oo`00Ool007oo0000
0Woo00D007oo001oo`00009oo`07001oo`00Ool007oo00000Woo00L007oo001oo`00Ool00002Ool0
1@00Ool007oo00000Woo00L007oo001oo`00Ool00002Ool01@00Ool007oo00000Woo00L007oo001o
o`00Ool00002Ool01@00Ool007oo00000Woo00L007oo001oo`00Ool00002Ool01`00Ool007oo001o
o`00009oo`05001oo`00Ool00002Ool01`00Ool007oo001oo`00009oo`05001oo`00Ool00002Ool0
1`00Ool007oo001oo`00009oo`05001oo`00Ool00002Ool01`00Ool007oo001oo`00009oo`05001o
o`00Ool00002Ool01`00Ool007oo001oo`00009oo`07001oo`00Ool007oo00000Woo10005goo000S
Ool02000Oomoogoo001oo`00Ool200002Goo001oogoo001oo`00Ool00002Ool01`00Ool007oo001o
o`00009oo`07001oo`00Ool007oo00000Woo00D007oo001oo`00009oo`07001oo`00Ool007oo0000
0Woo00D007oo001oo`00009oo`07001oo`00Ool007oo00000Woo00D007oo001oo`00009oo`07001o
o`00Ool007oo00000Woo00L007oo001oo`00Ool00002Ool01@00Ool007oo00000Woo00L007oo001o
o`00Ool00002Ool01@00Ool007oo00000Woo00L007oo001oo`00Ool00002Ool01@00Ool007oo0000
0Woo00L007oo001oo`00Ool00002Ool01`00Ool007oo001oo`00009oo`05001oo`00Ool00002Ool0
1`00Ool007oo001oo`00009oo`05001oo`00Ool00002Ool01`00Ool007oo001oo`00009oo`05001o
o`00Ool00002Ool01`00Ool007oo001oo`00009oo`05001oo`00Ool00002Ool01`00Ool007oo001o
o`00009oo`03001oo`0000800004Ool007oo000KOol002=oo`03001oogoo00Moo`09001oogooOol0
07oo001oo`00009oo`07001oo`00Ool007oo00000Woo00L007oo001oo`00Ool00002Ool01@00Ool0
07oo00000Woo00L007oo001oo`00Ool00002Ool01@00Ool007oo00000Woo00L007oo001oo`00Ool0
0002Ool01@00Ool007oo00000Woo00L007oo001oo`00Ool00002Ool01`00Ool007oo001oo`00009o
o`05001oo`00Ool00002Ool01`00Ool007oo001oo`00009oo`05001oo`00Ool00002Ool01`00Ool0
07oo001oo`00009oo`05001oo`00Ool00002Ool01`00Ool007oo001oo`00009oo`07001oo`00Ool0
07oo00000Woo00D007oo001oo`00009oo`07001oo`00Ool007oo00000Woo00D007oo001oo`00009o
o`07001oo`00Ool007oo00000Woo00D007oo001oo`00009oo`07001oo`00Ool007oo00000Woo00D0
07oo001oo`00009oo`07001oo`00Ool007oo00000Woo0P008Woo000SOol00`00Oomoo`0:Ool01P00
Oomoo`00Ool0009oo`07001oo`00Ool007oo00000Woo00L007oo001oo`00Ool00002Ool01@00Ool0
07oo00000Woo00L007oo001oo`00Ool00002Ool01@00Ool007oo00000Woo00L007oo001oo`00Ool0
0002Ool01@00Ool007oo00000Woo00L007oo001oo`00Ool00002Ool01`00Ool007oo001oo`00009o
o`05001oo`00Ool00002Ool01`00Ool007oo001oo`00009oo`05001oo`00Ool00002Ool01`00Ool0
07oo001oo`00009oo`05001oo`00Ool00002Ool01`00Ool007oo001oo`00009oo`07001oo`00Ool0
07oo00000Woo00D007oo001oo`00009oo`07001oo`00Ool007oo00000Woo00D007oo001oo`00009o
o`07001oo`00Ool007oo00000Woo00D007oo001oo`00009oo`07001oo`00Ool007oo00000Woo00D0
07oo001oo`00009oo`09001oo`00Ool007oo001oo`0002Aoo`008goo00<007ooOol037oo00@007oo
Ool0009oo`07001oo`00Ool007oo00000Woo00L007oo001oo`00Ool00002Ool01@00Ool007oo0000
0Woo00L007oo001oo`00Ool00002Ool01@00Ool007oo00000Woo00L007oo001oo`00Ool00002Ool0
1@00Ool007oo00000Woo00L007oo001oo`00Ool00002Ool01`00Ool007oo001oo`00009oo`05001o
o`00Ool00002Ool01`00Ool007oo001oo`00009oo`05001oo`00Ool00002Ool01`00Ool007oo001o
o`00009oo`05001oo`00Ool00002Ool01`00Ool007oo001oo`00009oo`07001oo`00Ool007oo0000
0Woo00D007oo001oo`00009oo`07001oo`00Ool007oo00000Woo00D007oo001oo`00009oo`07001o
o`00Ool007oo00000Woo00D007oo001oo`00009oo`07001oo`00Ool007oo00000Woo00D007oo001o
o`00009oo`04001oo`00Ool2000WOol002=oo`03001oogoo00ioo`0;001oogooOol007oo001oo`00
Ool00002Ool01`00Ool007oo001oo`00009oo`05001oo`00Ool00002Ool01`00Ool007oo001oo`00
009oo`05001oo`00Ool00002Ool01`00Ool007oo001oo`00009oo`05001oo`00Ool00002Ool01`00
Ool007oo001oo`00009oo`07001oo`00Ool007oo00000Woo00D007oo001oo`00009oo`07001oo`00
Ool007oo00000Woo00D007oo001oo`00009oo`07001oo`00Ool007oo00000Woo00D007oo001oo`00
009oo`07001oo`00Ool007oo00000Woo00L007oo001oo`00Ool00002Ool01@00Ool007oo00000Woo
00L007oo001oo`00Ool00002Ool01@00Ool007oo00000Woo00L007oo001oo`00Ool00002Ool01@00
Ool007oo00000Woo00L007oo001oo`00Ool00002Ool01@00Ool007oo00000Woo00@007oo000002Uo
o`008goo0P004Woo00P007ooOol007oo001oo`000Woo00L007oo001oo`00Ool00002Ool01@00Ool0
07oo00000Woo00L007oo001oo`00Ool00002Ool01@00Ool007oo00000Woo00L007oo001oo`00Ool0
0002Ool01@00Ool007oo00000Woo00L007oo001oo`00Ool00002Ool01`00Ool007oo001oo`00009o
o`05001oo`00Ool00002Ool01`00Ool007oo001oo`00009oo`05001oo`00Ool00002Ool01`00Ool0
07oo001oo`00009oo`05001oo`00Ool00002Ool01`00Ool007oo001oo`00009oo`07001oo`00Ool0
07oo00000Woo00D007oo001oo`00009oo`07001oo`00Ool007oo00000Woo00D007oo001oo`00009o
o`07001oo`00Ool007oo00000Woo00D007oo001oo`00009oo`07001oo`00Ool007oo00000Woo00D0
07oo001oo`00009oo`8002]oo`008goo00<007ooOol04goo00H007ooOol007oo0002Ool01`00Ool0
07oo001oo`00009oo`05001oo`00Ool00002Ool01`00Ool007oo001oo`00009oo`05001oo`00Ool0
0002Ool01`00Ool007oo001oo`00009oo`05001oo`00Ool00002Ool01`00Ool007oo001oo`00009o
o`07001oo`00Ool007oo00000Woo00D007oo001oo`00009oo`07001oo`00Ool007oo00000Woo00D0
07oo001oo`00009oo`07001oo`00Ool007oo00000Woo00D007oo001oo`00009oo`07001oo`00Ool0
07oo00000Woo00L007oo001oo`00Ool00002Ool01@00Ool007oo00000Woo00L007oo001oo`00Ool0
0002Ool01@00Ool007oo00000Woo00L007oo001oo`00Ool00002Ool01@00Ool007oo00000Woo00L0
07oo001oo`00Ool00002Ool01`00Ool007oo001oo`0002eoo`008goo00<007ooOol05Woo00<007oo
00000Woo00L007oo001oo`00Ool00002Ool01@00Ool007oo00000Woo00L007oo001oo`00Ool00002
Ool01@00Ool007oo00000Woo00L007oo001oo`00Ool00002Ool01@00Ool007oo00000Woo00L007oo
001oo`00Ool00002Ool01`00Ool007oo001oo`00009oo`05001oo`00Ool00002Ool01`00Ool007oo
001oo`00009oo`05001oo`00Ool00002Ool01`00Ool007oo001oo`00009oo`05001oo`00Ool00002
Ool01`00Ool007oo001oo`00009oo`07001oo`00Ool007oo00000Woo00D007oo001oo`00009oo`07
001oo`00Ool007oo00000Woo00D007oo001oo`00009oo`07001oo`00Ool007oo00000Woo00D007oo
001oo`00009oo`07001oo`00Ool007oo00000Woo00D007oo001oo`0002moo`008goo00<007ooOol0
5Goo00@007ooOol0009oo`07001oo`00Ool007oo00000Woo00D007oo001oo`00009oo`07001oo`00
Ool007oo00000Woo00D007oo001oo`00009oo`07001oo`00Ool007oo00000Woo00D007oo001oo`00
009oo`07001oo`00Ool007oo00000Woo00L007oo001oo`00Ool00002Ool01@00Ool007oo00000Woo
00L007oo001oo`00Ool00002Ool01@00Ool007oo00000Woo00L007oo001oo`00Ool00002Ool01@00
Ool007oo00000Woo00L007oo001oo`00Ool00002Ool01`00Ool007oo001oo`00009oo`05001oo`00
Ool00002Ool01`00Ool007oo001oo`00009oo`05001oo`00Ool00002Ool01`00Ool007oo001oo`00
009oo`05001oo`00Ool00002Ool01`00Ool007oo001oo`00009oo`04001oo`00000`Ool002=oo`03
001oogoo01Qoo`0:001oogoo001oo`00Ool007oo0002Ool01@00Ool007oo00000Woo00L007oo001o
o`00Ool00002Ool01@00Ool007oo00000Woo00L007oo001oo`00Ool00002Ool01@00Ool007oo0000
0Woo00L007oo001oo`00Ool00002Ool01`00Ool007oo001oo`00009oo`05001oo`00Ool00002Ool0
1`00Ool007oo001oo`00009oo`05001oo`00Ool00002Ool01`00Ool007oo001oo`00009oo`05001o
o`00Ool00002Ool01`00Ool007oo001oo`00009oo`07001oo`00Ool007oo00000Woo00D007oo001o
o`00009oo`07001oo`00Ool007oo00000Woo00D007oo001oo`00009oo`07001oo`00Ool007oo0000
0Woo00D007oo001oo`00009oo`07001oo`00Ool007oo00000Woo00<007oo0000<Goo000SOol00`00
Oomoo`0GOol02`00Oomoogoo001oo`00Ool007oo00000Woo00D007oo001oo`00009oo`07001oo`00
Ool007oo00000Woo00D007oo001oo`00009oo`07001oo`00Ool007oo00000Woo00D007oo001oo`00
009oo`07001oo`00Ool007oo00000Woo00L007oo001oo`00Ool00002Ool01@00Ool007oo00000Woo
00L007oo001oo`00Ool00002Ool01@00Ool007oo00000Woo00L007oo001oo`00Ool00002Ool01@00
Ool007oo00000Woo00L007oo001oo`00Ool00002Ool01`00Ool007oo001oo`00009oo`05001oo`00
Ool00002Ool01`00Ool007oo001oo`00009oo`05001oo`00Ool00002Ool01`00Ool007oo001oo`00
009oo`05001oo`00Ool00002Ool01`00Ool007oo001oo`00009oo`80039oo`008goo00<007ooOol0
6goo00L007oo001oo`00Ool00002Ool01@00Ool007oo00000Woo00L007oo001oo`00Ool00002Ool0
1@00Ool007oo00000Woo00L007oo001oo`00Ool00002Ool01@00Ool007oo00000Woo00L007oo001o
o`00Ool00002Ool01`00Ool007oo001oo`00009oo`05001oo`00Ool00002Ool01`00Ool007oo001o
o`00009oo`05001oo`00Ool00002Ool01`00Ool007oo001oo`00009oo`05001oo`00Ool00002Ool0
1`00Ool007oo001oo`00009oo`07001oo`00Ool007oo00000Woo00D007oo001oo`00009oo`07001o
o`00Ool007oo00000Woo00D007oo001oo`00009oo`07001oo`00Ool007oo00000Woo00D007oo001o
o`00009oo`07001oo`00Ool007oo00000Woo00<007ooOol0<Goo000SOol2000KOol02000Oomoo`00
Ool007oo0002Ool01@00Ool007oo00000Woo00L007oo001oo`00Ool00002Ool01@00Ool007oo0000
0Woo00L007oo001oo`00Ool00002Ool01@00Ool007oo00000Woo00L007oo001oo`00Ool00002Ool0
1`00Ool007oo001oo`00009oo`05001oo`00Ool00002Ool01`00Ool007oo001oo`00009oo`05001o
o`00Ool00002Ool01`00Ool007oo001oo`00009oo`05001oo`00Ool00002Ool01`00Ool007oo001o
o`00009oo`07001oo`00Ool007oo00000Woo00D007oo001oo`00009oo`07001oo`00Ool007oo0000
0Woo00D007oo001oo`00009oo`07001oo`00Ool007oo00000Woo00D007oo001oo`00009oo`09001o
o`00Ool007oo001oo`0003Aoo`008goo00<007ooOol07Goo00D007oo001oo`00009oo`05001oo`00
Ool00002Ool01`00Ool007oo001oo`00009oo`05001oo`00Ool00002Ool01`00Ool007oo001oo`00
009oo`05001oo`00Ool00002Ool01`00Ool007oo001oo`00009oo`07001oo`00Ool007oo00000Woo
00D007oo001oo`00009oo`07001oo`00Ool007oo00000Woo00D007oo001oo`00009oo`07001oo`00
Ool007oo00000Woo00D007oo001oo`00009oo`07001oo`00Ool007oo00000Woo00L007oo001oo`00
Ool00002Ool01@00Ool007oo00000Woo00L007oo001oo`00Ool00002Ool01@00Ool007oo00000Woo
00L007oo001oo`00Ool00002Ool01@00Ool007oo00000Woo00L007oo001oo`00Ool0000fOol002=o
o`03001oogoo01aoo`06001oogoo001oo`000Woo00D007oo001oo`00009oo`07001oo`00Ool007oo
00000Woo00D007oo001oo`00009oo`07001oo`00Ool007oo00000Woo00D007oo001oo`00009oo`07
001oo`00Ool007oo00000Woo00L007oo001oo`00Ool00002Ool01@00Ool007oo00000Woo00L007oo
001oo`00Ool00002Ool01@00Ool007oo00000Woo00L007oo001oo`00Ool00002Ool01@00Ool007oo
00000Woo00L007oo001oo`00Ool00002Ool01`00Ool007oo001oo`00009oo`05001oo`00Ool00002
Ool01`00Ool007oo001oo`00009oo`05001oo`00Ool00002Ool01`00Ool007oo001oo`00009oo`05
001oo`00Ool00002Ool01000Ool007oo0P00=goo000SOol00`00Oomoo`0OOol00`00Ool00002Ool0
1@00Ool007oo00000Woo00L007oo001oo`00Ool00002Ool01@00Ool007oo00000Woo00L007oo001o
o`00Ool00002Ool01@00Ool007oo00000Woo00L007oo001oo`00Ool00002Ool01`00Ool007oo001o
o`00009oo`05001oo`00Ool00002Ool01`00Ool007oo001oo`00009oo`05001oo`00Ool00002Ool0
1`00Ool007oo001oo`00009oo`05001oo`00Ool00002Ool01`00Ool007oo001oo`00009oo`07001o
o`00Ool007oo00000Woo00D007oo001oo`00009oo`07001oo`00Ool007oo00000Woo00D007oo001o
o`00009oo`07001oo`00Ool007oo00000Woo00D007oo001oo`00009oo`05001oo`00Ool0000hOol0
02=oo`03001oogoo01ioo`04001oogoo0002Ool01@00Ool007oo00000Woo00L007oo001oo`00Ool0
0002Ool01@00Ool007oo00000Woo00L007oo001oo`00Ool00002Ool01@00Ool007oo00000Woo00L0
07oo001oo`00Ool00002Ool01`00Ool007oo001oo`00009oo`05001oo`00Ool00002Ool01`00Ool0
07oo001oo`00009oo`05001oo`00Ool00002Ool01`00Ool007oo001oo`00009oo`05001oo`00Ool0
0002Ool01`00Ool007oo001oo`00009oo`07001oo`00Ool007oo00000Woo00D007oo001oo`00009o
o`07001oo`00Ool007oo00000Woo00D007oo001oo`00009oo`07001oo`00Ool007oo00000Woo00D0
07oo001oo`00009oo`04001oo`00000iOol002=oo`03001oogoo025oo`08001oogoo001oo`00Ool0
009oo`07001oo`00Ool007oo00000Woo00D007oo001oo`00009oo`07001oo`00Ool007oo00000Woo
00D007oo001oo`00009oo`07001oo`00Ool007oo00000Woo00L007oo001oo`00Ool00002Ool01@00
Ool007oo00000Woo00L007oo001oo`00Ool00002Ool01@00Ool007oo00000Woo00L007oo001oo`00
Ool00002Ool01@00Ool007oo00000Woo00L007oo001oo`00Ool00002Ool01`00Ool007oo001oo`00
009oo`05001oo`00Ool00002Ool01`00Ool007oo001oo`00009oo`05001oo`00Ool00002Ool01`00
Ool007oo001oo`00009oo`05001oo`00Ool00002Ool00`00Ool0000jOol002=oo`03001oogoo025o
o`08001oogoo001oo`00Ool0009oo`07001oo`00Ool007oo00000Woo00D007oo001oo`00009oo`07
001oo`00Ool007oo00000Woo00D007oo001oo`00009oo`07001oo`00Ool007oo00000Woo00L007oo
001oo`00Ool00002Ool01@00Ool007oo00000Woo00L007oo001oo`00Ool00002Ool01@00Ool007oo
00000Woo00L007oo001oo`00Ool00002Ool01@00Ool007oo00000Woo00L007oo001oo`00Ool00002
Ool01`00Ool007oo001oo`00009oo`05001oo`00Ool00002Ool01`00Ool007oo001oo`00009oo`05
001oo`00Ool00002Ool01`00Ool007oo001oo`00009oo`05001oo`00Ool00002Ool00`00Ool0000j
Ool002=oo`80029oo`08001oogoo001oo`00Ool0009oo`07001oo`00Ool007oo00000Woo00D007oo
001oo`00009oo`07001oo`00Ool007oo00000Woo00D007oo001oo`00009oo`07001oo`00Ool007oo
00000Woo00L007oo001oo`00Ool00002Ool01@00Ool007oo00000Woo00L007oo001oo`00Ool00002
Ool01@00Ool007oo00000Woo00L007oo001oo`00Ool00002Ool01@00Ool007oo00000Woo00L007oo
001oo`00Ool00002Ool01`00Ool007oo001oo`00009oo`05001oo`00Ool00002Ool01`00Ool007oo
001oo`00009oo`05001oo`00Ool00002Ool01`00Ool007oo001oo`00009oo`05001oo`00Ool00002
Ool2000kOol002=oo`03001oogoo02Aoo`05001oo`00Ool00002Ool01`00Ool007oo001oo`00009o
o`05001oo`00Ool00002Ool01`00Ool007oo001oo`00009oo`05001oo`00Ool00002Ool01`00Ool0
07oo001oo`00009oo`07001oo`00Ool007oo00000Woo00D007oo001oo`00009oo`07001oo`00Ool0
07oo00000Woo00D007oo001oo`00009oo`07001oo`00Ool007oo00000Woo00D007oo001oo`00009o
o`07001oo`00Ool007oo00000Woo00L007oo001oo`00Ool00002Ool01@00Ool007oo00000Woo00L0
07oo001oo`00Ool00002Ool01@00Ool007oo00000Woo00L007oo001oo`00Ool00002Ool01@00Ool0
07oo00000Woo00<007ooOol0>Woo000SOol00`00Oomoo`0SOol2000017oo001oo`000Woo00L007oo
001oo`00Ool00002Ool01@00Ool007oo00000Woo00L007oo001oo`00Ool00002Ool01@00Ool007oo
00000Woo00L007oo001oo`00Ool00002Ool01`00Ool007oo001oo`00009oo`05001oo`00Ool00002
Ool01`00Ool007oo001oo`00009oo`05001oo`00Ool00002Ool01`00Ool007oo001oo`00009oo`05
001oo`00Ool00002Ool01`00Ool007oo001oo`00009oo`07001oo`00Ool007oo00000Woo00D007oo
001oo`00009oo`07001oo`00Ool007oo00000Woo00D007oo001oo`00009oo`07001oo`00Ool007oo
00000Woo00H007oo001oo`00Ool2000lOol002=oo`03001oogoo02Ioo`03001oo`00009oo`07001o
o`00Ool007oo00000Woo00D007oo001oo`00009oo`07001oo`00Ool007oo00000Woo00D007oo001o
o`00009oo`07001oo`00Ool007oo00000Woo00L007oo001oo`00Ool00002Ool01@00Ool007oo0000
0Woo00L007oo001oo`00Ool00002Ool01@00Ool007oo00000Woo00L007oo001oo`00Ool00002Ool0
1@00Ool007oo00000Woo00L007oo001oo`00Ool00002Ool01`00Ool007oo001oo`00009oo`05001o
o`00Ool00002Ool01`00Ool007oo001oo`00009oo`05001oo`00Ool00002Ool01`00Ool007oo001o
o`00009oo`05001oo`00Ool0000oOol002=oo`03001oogoo02Ioo`03001oo`00009oo`07001oo`00
Ool007oo00000Woo00D007oo001oo`00009oo`07001oo`00Ool007oo00000Woo00D007oo001oo`00
009oo`07001oo`00Ool007oo00000Woo00L007oo001oo`00Ool00002Ool01@00Ool007oo00000Woo
00L007oo001oo`00Ool00002Ool01@00Ool007oo00000Woo00L007oo001oo`00Ool00002Ool01@00
Ool007oo00000Woo00L007oo001oo`00Ool00002Ool01`00Ool007oo001oo`00009oo`05001oo`00
Ool00002Ool01`00Ool007oo001oo`00009oo`05001oo`00Ool00002Ool01`00Ool007oo001oo`00
009oo`05001oo`00Ool0000oOol001=oo`03001oogoo009oo`04001oogooOol30004Ool00`00Oomo
o`0UOol01000Oomoo`000Woo00L007oo001oo`00Ool00002Ool01@00Ool007oo00000Woo00L007oo
001oo`00Ool00002Ool01@00Ool007oo00000Woo00L007oo001oo`00Ool00002Ool01`00Ool007oo
001oo`00009oo`05001oo`00Ool00002Ool01`00Ool007oo001oo`00009oo`05001oo`00Ool00002
Ool01`00Ool007oo001oo`00009oo`05001oo`00Ool00002Ool01`00Ool007oo001oo`00009oo`07
001oo`00Ool007oo00000Woo00D007oo001oo`00009oo`07001oo`00Ool007oo00000Woo00D007oo
001oo`00009oo`07001oo`00Ool007oo00000Woo00@007oo0000041oo`004Woo00<007oo00001goo
00<007ooOol017oo00<007ooOol0:7oo00X007ooOol007oo001oo`00Ool0009oo`05001oo`00Ool0
0002Ool01`00Ool007oo001oo`00009oo`05001oo`00Ool00002Ool01`00Ool007oo001oo`00009o
o`07001oo`00Ool007oo00000Woo00D007oo001oo`00009oo`07001oo`00Ool007oo00000Woo00D0
07oo001oo`00009oo`07001oo`00Ool007oo00000Woo00D007oo001oo`00009oo`07001oo`00Ool0
07oo00000Woo00L007oo001oo`00Ool00002Ool01@00Ool007oo00000Woo00L007oo001oo`00Ool0
0002Ool01@00Ool007oo00000Woo00L007oo001oo`00Ool00002Ool00`00Ool00011Ool0019oo`03
001oo`0000Qoo`03001oogoo00=oo`<002Qoo`0:001oogoo001oo`00Ool007oo0002Ool01@00Ool0
07oo00000Woo00L007oo001oo`00Ool00002Ool01@00Ool007oo00000Woo00L007oo001oo`00Ool0
0002Ool01`00Ool007oo001oo`00009oo`05001oo`00Ool00002Ool01`00Ool007oo001oo`00009o
o`05001oo`00Ool00002Ool01`00Ool007oo001oo`00009oo`05001oo`00Ool00002Ool01`00Ool0
07oo001oo`00009oo`07001oo`00Ool007oo00000Woo00D007oo001oo`00009oo`07001oo`00Ool0
07oo00000Woo00D007oo001oo`00009oo`07001oo`00Ool007oo00000Woo00<007oo0000@Goo000B
Ool00`00Ool00008Ool00`00Oomoo`03Ool00`00Oomoo`0XOol02P00Oomoo`00Ool007oo001oo`00
0Woo00D007oo001oo`00009oo`07001oo`00Ool007oo00000Woo00D007oo001oo`00009oo`07001o
o`00Ool007oo00000Woo00L007oo001oo`00Ool00002Ool01@00Ool007oo00000Woo00L007oo001o
o`00Ool00002Ool01@00Ool007oo00000Woo00L007oo001oo`00Ool00002Ool01@00Ool007oo0000
0Woo00L007oo001oo`00Ool00002Ool01`00Ool007oo001oo`00009oo`05001oo`00Ool00002Ool0
1`00Ool007oo001oo`00009oo`05001oo`00Ool00002Ool01`00Ool007oo001oo`00009oo`03001o
o`00045oo`004Woo00<007oo00001goo00<007oo000017oo00<007ooOol09goo00/007ooOomoo`00
Ool007oo001oo`00009oo`05001oo`00Ool00002Ool01`00Ool007oo001oo`00009oo`05001oo`00
Ool00002Ool01`00Ool007oo001oo`00009oo`07001oo`00Ool007oo00000Woo00D007oo001oo`00
009oo`07001oo`00Ool007oo00000Woo00D007oo001oo`00009oo`07001oo`00Ool007oo00000Woo
00D007oo001oo`00009oo`07001oo`00Ool007oo00000Woo00L007oo001oo`00Ool00002Ool01@00
Ool007oo00000Woo00L007oo001oo`00Ool00002Ool01@00Ool007oo00000Woo00L007oo001oo`00
Ool00002Ool20012Ool001=oo`03001oogoo00Moo`03001oogoo00=oo`03001oogoo02]oo`07001o
o`00Ool007oo00000Woo00D007oo001oo`00009oo`07001oo`00Ool007oo00000Woo00D007oo001o
o`00009oo`07001oo`00Ool007oo00000Woo00L007oo001oo`00Ool00002Ool01@00Ool007oo0000
0Woo00L007oo001oo`00Ool00002Ool01@00Ool007oo00000Woo00L007oo001oo`00Ool00002Ool0
1@00Ool007oo00000Woo00L007oo001oo`00Ool00002Ool01`00Ool007oo001oo`00009oo`05001o
o`00Ool00002Ool01`00Ool007oo001oo`00009oo`05001oo`00Ool00002Ool01`00Ool007oo001o
o`00009oo`03001oogoo045oo`008goo00<007ooOol0:goo00L007oo001oo`00Ool00002Ool01@00
Ool007oo00000Woo00L007oo001oo`00Ool00002Ool01@00Ool007oo00000Woo00L007oo001oo`00
Ool00002Ool01`00Ool007oo001oo`00009oo`05001oo`00Ool00002Ool01`00Ool007oo001oo`00
009oo`05001oo`00Ool00002Ool01`00Ool007oo001oo`00009oo`05001oo`00Ool00002Ool01`00
Ool007oo001oo`00009oo`07001oo`00Ool007oo00000Woo00D007oo001oo`00009oo`07001oo`00
Ool007oo00000Woo00D007oo001oo`00009oo`07001oo`00Ool007oo00000Woo00<007ooOol0@Goo
000SOol00`00Oomoo`0ZOol02000Oomoo`00Ool007oo0002Ool01@00Ool007oo00000Woo00L007oo
001oo`00Ool00002Ool01@00Ool007oo00000Woo00L007oo001oo`00Ool00002Ool01`00Ool007oo
001oo`00009oo`05001oo`00Ool00002Ool01`00Ool007oo001oo`00009oo`05001oo`00Ool00002
Ool01`00Ool007oo001oo`00009oo`05001oo`00Ool00002Ool01`00Ool007oo001oo`00009oo`07
001oo`00Ool007oo00000Woo00D007oo001oo`00009oo`07001oo`00Ool007oo00000Woo00D007oo
001oo`00009oo`09001oo`00Ool007oo001oo`0004Aoo`008goo00<007ooOol0;Goo00D007oo001o
o`00009oo`05001oo`00Ool00002Ool01`00Ool007oo001oo`00009oo`05001oo`00Ool00002Ool0
1`00Ool007oo001oo`00009oo`07001oo`00Ool007oo00000Woo00D007oo001oo`00009oo`07001o
o`00Ool007oo00000Woo00D007oo001oo`00009oo`07001oo`00Ool007oo00000Woo00D007oo001o
o`00009oo`07001oo`00Ool007oo00000Woo00L007oo001oo`00Ool00002Ool01@00Ool007oo0000
0Woo00L007oo001oo`00Ool00002Ool01@00Ool007oo00000Woo00L007oo001oo`00Ool00016Ool0
02=oo`8002ioo`05001oo`00Ool00002Ool01@00Ool007oo00000Woo00L007oo001oo`00Ool00002
Ool01@00Ool007oo00000Woo00L007oo001oo`00Ool00002Ool01`00Ool007oo001oo`00009oo`05
001oo`00Ool00002Ool01`00Ool007oo001oo`00009oo`05001oo`00Ool00002Ool01`00Ool007oo
001oo`00009oo`05001oo`00Ool00002Ool01`00Ool007oo001oo`00009oo`07001oo`00Ool007oo
00000Woo00D007oo001oo`00009oo`07001oo`00Ool007oo00000Woo00D007oo001oo`00009oo`07
001oo`00Ool007oo0000AWoo000SOol00`00Oomoo`0]Ool01@00Ool007oo00000Woo00D007oo001o
o`00009oo`07001oo`00Ool007oo00000Woo00D007oo001oo`00009oo`07001oo`00Ool007oo0000
0Woo00L007oo001oo`00Ool00002Ool01@00Ool007oo00000Woo00L007oo001oo`00Ool00002Ool0
1@00Ool007oo00000Woo00L007oo001oo`00Ool00002Ool01@00Ool007oo00000Woo00L007oo001o
o`00Ool00002Ool01`00Ool007oo001oo`00009oo`05001oo`00Ool00002Ool01`00Ool007oo001o
o`00009oo`05001oo`00Ool00002Ool01`00Ool007oo001oo`0004Ioo`008goo00<007ooOol0;7oo
00H007ooOol007oo0002Ool01@00Ool007oo00000Woo00L007oo001oo`00Ool00002Ool01@00Ool0
07oo00000Woo00L007oo001oo`00Ool00002Ool01`00Ool007oo001oo`00009oo`05001oo`00Ool0
0002Ool01`00Ool007oo001oo`00009oo`05001oo`00Ool00002Ool01`00Ool007oo001oo`00009o
o`05001oo`00Ool00002Ool01`00Ool007oo001oo`00009oo`07001oo`00Ool007oo00000Woo00D0
07oo001oo`00009oo`07001oo`00Ool007oo00000Woo00D007oo001oo`00009oo`04001oo`00Ool2
0017Ool002=oo`03001oogoo02moo`03001oo`00009oo`05001oo`00Ool00002Ool01`00Ool007oo
001oo`00009oo`05001oo`00Ool00002Ool01`00Ool007oo001oo`00009oo`07001oo`00Ool007oo
00000Woo00D007oo001oo`00009oo`07001oo`00Ool007oo00000Woo00D007oo001oo`00009oo`07
001oo`00Ool007oo00000Woo00D007oo001oo`00009oo`07001oo`00Ool007oo00000Woo00L007oo
001oo`00Ool00002Ool01@00Ool007oo00000Woo00L007oo001oo`00Ool00002Ool01@00Ool007oo
00000Woo00D007oo001oo`0004Qoo`008goo00<007ooOol0;goo00<007oo00000Woo00D007oo001o
o`00009oo`07001oo`00Ool007oo00000Woo00D007oo001oo`00009oo`07001oo`00Ool007oo0000
0Woo00L007oo001oo`00Ool00002Ool01@00Ool007oo00000Woo00L007oo001oo`00Ool00002Ool0
1@00Ool007oo00000Woo00L007oo001oo`00Ool00002Ool01@00Ool007oo00000Woo00L007oo001o
o`00Ool00002Ool01`00Ool007oo001oo`00009oo`05001oo`00Ool00002Ool01`00Ool007oo001o
o`00009oo`05001oo`00Ool00002Ool01@00Ool007oo0000B7oo000SOol00`00Oomoo`0^Ool20000
2Goo001oogoo001oo`00Ool00002Ool01`00Ool007oo001oo`00009oo`05001oo`00Ool00002Ool0
1`00Ool007oo001oo`00009oo`07001oo`00Ool007oo00000Woo00D007oo001oo`00009oo`07001o
o`00Ool007oo00000Woo00D007oo001oo`00009oo`07001oo`00Ool007oo00000Woo00D007oo001o
o`00009oo`07001oo`00Ool007oo00000Woo00L007oo001oo`00Ool00002Ool01@00Ool007oo0000
0Woo00L007oo001oo`00Ool00002Ool01@00Ool007oo00000Woo00<007oo00000P00B7oo000SOol0
0`00Oomoo`0aOol02000Oomoo`00Ool007oo0002Ool01`00Ool007oo001oo`00009oo`05001oo`00
Ool00002Ool01`00Ool007oo001oo`00009oo`07001oo`00Ool007oo00000Woo00D007oo001oo`00
009oo`07001oo`00Ool007oo00000Woo00D007oo001oo`00009oo`07001oo`00Ool007oo00000Woo
00D007oo001oo`00009oo`07001oo`00Ool007oo00000Woo00L007oo001oo`00Ool00002Ool01@00
Ool007oo00000Woo00L007oo001oo`00Ool00002Ool01@00Ool007oo00000Woo00<007oo0000BWoo
000SOol2000bOol02000Oomoo`00Ool007oo0002Ool01`00Ool007oo001oo`00009oo`05001oo`00
Ool00002Ool01`00Ool007oo001oo`00009oo`07001oo`00Ool007oo00000Woo00D007oo001oo`00
009oo`07001oo`00Ool007oo00000Woo00D007oo001oo`00009oo`07001oo`00Ool007oo00000Woo
00D007oo001oo`00009oo`07001oo`00Ool007oo00000Woo00L007oo001oo`00Ool00002Ool01@00
Ool007oo00000Woo00L007oo001oo`00Ool00002Ool01@00Ool007oo00000Woo00<007oo0000BWoo
000SOol00`00Oomoo`0aOol02000Oomoo`00Ool007oo0002Ool01`00Ool007oo001oo`00009oo`05
001oo`00Ool00002Ool01`00Ool007oo001oo`00009oo`07001oo`00Ool007oo00000Woo00D007oo
001oo`00009oo`07001oo`00Ool007oo00000Woo00D007oo001oo`00009oo`07001oo`00Ool007oo
00000Woo00D007oo001oo`00009oo`07001oo`00Ool007oo00000Woo00L007oo001oo`00Ool00002
Ool01@00Ool007oo00000Woo00L007oo001oo`00Ool00002Ool01@00Ool007oo00000Woo00<007oo
0000BWoo000SOol00`00Oomoo`0aOol02000Oomoo`00Ool007oo0002Ool01`00Ool007oo001oo`00
009oo`05001oo`00Ool00002Ool01`00Ool007oo001oo`00009oo`07001oo`00Ool007oo00000Woo
00D007oo001oo`00009oo`07001oo`00Ool007oo00000Woo00D007oo001oo`00009oo`07001oo`00
Ool007oo00000Woo00D007oo001oo`00009oo`07001oo`00Ool007oo00000Woo00L007oo001oo`00
Ool00002Ool01@00Ool007oo00000Woo00L007oo001oo`00Ool00002Ool01@00Ool007oo00000Woo
0`00BWoo000SOol00`00Oomoo`0dOol01@00Ool007oo00000Woo00L007oo001oo`00Ool00002Ool0
1@00Ool007oo00000Woo00L007oo001oo`00Ool00002Ool01`00Ool007oo001oo`00009oo`05001o
o`00Ool00002Ool01`00Ool007oo001oo`00009oo`05001oo`00Ool00002Ool01`00Ool007oo001o
o`00009oo`05001oo`00Ool00002Ool01`00Ool007oo001oo`00009oo`07001oo`00Ool007oo0000
0Woo00D007oo001oo`00009oo`07001oo`00Ool007oo00000Woo00D007oo001oo`00009oo`03001o
ogoo04Yoo`008goo00<007ooOol0=7oo00D007oo001oo`00009oo`07001oo`00Ool007oo00000Woo
00D007oo001oo`00009oo`07001oo`00Ool007oo00000Woo00L007oo001oo`00Ool00002Ool01@00
Ool007oo00000Woo00L007oo001oo`00Ool00002Ool01@00Ool007oo00000Woo00L007oo001oo`00
Ool00002Ool01@00Ool007oo00000Woo00L007oo001oo`00Ool00002Ool01`00Ool007oo001oo`00
009oo`05001oo`00Ool00002Ool01`00Ool007oo001oo`00009oo`05001oo`00Ool00002Ool00`00
Oomoo`1:Ool002=oo`03001oogoo03Aoo`05001oo`00Ool00002Ool01`00Ool007oo001oo`00009o
o`05001oo`00Ool00002Ool01`00Ool007oo001oo`00009oo`07001oo`00Ool007oo00000Woo00D0
07oo001oo`00009oo`07001oo`00Ool007oo00000Woo00D007oo001oo`00009oo`07001oo`00Ool0
07oo00000Woo00D007oo001oo`00009oo`07001oo`00Ool007oo00000Woo00L007oo001oo`00Ool0
0002Ool01@00Ool007oo00000Woo00L007oo001oo`00Ool00002Ool01@00Ool007oo00000Woo00<0
07ooOol0BWoo000SOol00`00Oomoo`0dOol01@00Ool007oo00000Woo00L007oo001oo`00Ool00002
Ool01@00Ool007oo00000Woo00L007oo001oo`00Ool00002Ool01`00Ool007oo001oo`00009oo`05
001oo`00Ool00002Ool01`00Ool007oo001oo`00009oo`05001oo`00Ool00002Ool01`00Ool007oo
001oo`00009oo`05001oo`00Ool00002Ool01`00Ool007oo001oo`00009oo`07001oo`00Ool007oo
00000Woo00D007oo001oo`00009oo`07001oo`00Ool007oo00000Woo00D007oo001oo`00009oo`03
001oogoo04Yoo`008goo0P00=7oo00H007ooOol007oo0002Ool01`00Ool007oo001oo`00009oo`05
001oo`00Ool00002Ool01`00Ool007oo001oo`00009oo`07001oo`00Ool007oo00000Woo00D007oo
001oo`00009oo`07001oo`00Ool007oo00000Woo00D007oo001oo`00009oo`07001oo`00Ool007oo
00000Woo00D007oo001oo`00009oo`07001oo`00Ool007oo00000Woo00L007oo001oo`00Ool00002
Ool01@00Ool007oo00000Woo00L007oo001oo`00Ool00002Ool01`00Ool007oo001oo`0004eoo`00
8goo00<007ooOol0=Woo00<007oo00000Woo00L007oo001oo`00Ool00002Ool01@00Ool007oo0000
0Woo00L007oo001oo`00Ool00002Ool01`00Ool007oo001oo`00009oo`05001oo`00Ool00002Ool0
1`00Ool007oo001oo`00009oo`05001oo`00Ool00002Ool01`00Ool007oo001oo`00009oo`05001o
o`00Ool00002Ool01`00Ool007oo001oo`00009oo`07001oo`00Ool007oo00000Woo00D007oo001o
o`00009oo`07001oo`00Ool007oo00000Woo00D007oo001oo`0004moo`008goo00<007ooOol0=Woo
00<007oo00000Woo00L007oo001oo`00Ool00002Ool01@00Ool007oo00000Woo00L007oo001oo`00
Ool00002Ool01`00Ool007oo001oo`00009oo`05001oo`00Ool00002Ool01`00Ool007oo001oo`00
009oo`05001oo`00Ool00002Ool01`00Ool007oo001oo`00009oo`05001oo`00Ool00002Ool01`00
Ool007oo001oo`00009oo`07001oo`00Ool007oo00000Woo00D007oo001oo`00009oo`07001oo`00
Ool007oo00000Woo00D007oo001oo`0004moo`008goo00<007ooOol0=Woo00<007oo00000Woo00L0
07oo001oo`00Ool00002Ool01@00Ool007oo00000Woo00L007oo001oo`00Ool00002Ool01`00Ool0
07oo001oo`00009oo`05001oo`00Ool00002Ool01`00Ool007oo001oo`00009oo`05001oo`00Ool0
0002Ool01`00Ool007oo001oo`00009oo`05001oo`00Ool00002Ool01`00Ool007oo001oo`00009o
o`07001oo`00Ool007oo00000Woo00D007oo001oo`00009oo`07001oo`00Ool007oo00000Woo00D0
07oo001oo`0004moo`008goo00<007ooOol0=Goo00@007ooOol0009oo`07001oo`00Ool007oo0000
0Woo00D007oo001oo`00009oo`07001oo`00Ool007oo00000Woo00L007oo001oo`00Ool00002Ool0
1@00Ool007oo00000Woo00L007oo001oo`00Ool00002Ool01@00Ool007oo00000Woo00L007oo001o
o`00Ool00002Ool01@00Ool007oo00000Woo00L007oo001oo`00Ool00002Ool01`00Ool007oo001o
o`00009oo`05001oo`00Ool00002Ool01`00Ool007oo001oo`00009oo`04001oo`00001@Ool002=o
o`03001oogoo03Qoo`0:001oogoo001oo`00Ool007oo0002Ool01@00Ool007oo00000Woo00L007oo
001oo`00Ool00002Ool01`00Ool007oo001oo`00009oo`05001oo`00Ool00002Ool01`00Ool007oo
001oo`00009oo`05001oo`00Ool00002Ool01`00Ool007oo001oo`00009oo`05001oo`00Ool00002
Ool01`00Ool007oo001oo`00009oo`07001oo`00Ool007oo00000Woo00D007oo001oo`00009oo`07
001oo`00Ool007oo00000Woo00<007oo0000DGoo000COol00`00Oomoo`02Ool00`00Oomoo`02Ool3
0003Ool00`00Oomoo`0hOol02P00Oomoo`00Ool007oo001oo`000Woo00D007oo001oo`00009oo`07
001oo`00Ool007oo00000Woo00L007oo001oo`00Ool00002Ool01@00Ool007oo00000Woo00L007oo
001oo`00Ool00002Ool01@00Ool007oo00000Woo00L007oo001oo`00Ool00002Ool01@00Ool007oo
00000Woo00L007oo001oo`00Ool00002Ool01`00Ool007oo001oo`00009oo`05001oo`00Ool00002
Ool01`00Ool007oo001oo`00009oo`03001oo`00055oo`004Woo00<007oo00002Goo00<007ooOol0
0Woo00<007ooOol0>7oo00X007ooOol007oo001oo`00Ool0009oo`05001oo`00Ool00002Ool01`00
Ool007oo001oo`00009oo`07001oo`00Ool007oo00000Woo00D007oo001oo`00009oo`07001oo`00
Ool007oo00000Woo00D007oo001oo`00009oo`07001oo`00Ool007oo00000Woo00D007oo001oo`00
009oo`07001oo`00Ool007oo00000Woo00L007oo001oo`00Ool00002Ool01@00Ool007oo00000Woo
00L007oo001oo`00Ool00002Ool00`00Ool0001AOol0019oo`03001oo`0000Moo`@000=oo`<003Mo
o`80009oo`07001oo`00Ool007oo00000Woo00D007oo001oo`00009oo`07001oo`00Ool007oo0000
0Woo00L007oo001oo`00Ool00002Ool01@00Ool007oo00000Woo00L007oo001oo`00Ool00002Ool0
1@00Ool007oo00000Woo00L007oo001oo`00Ool00002Ool01@00Ool007oo00000Woo00L007oo001o
o`00Ool00002Ool01`00Ool007oo001oo`00009oo`05001oo`00Ool00002Ool01`00Ool007oo001o
o`00009oo`<0055oo`004Woo00<007oo00001goo00<007oo000017oo00<007ooOol0>goo00L007oo
001oo`00Ool00002Ool01@00Ool007oo00000Woo00L007oo001oo`00Ool00002Ool01`00Ool007oo
001oo`00009oo`05001oo`00Ool00002Ool01`00Ool007oo001oo`00009oo`05001oo`00Ool00002
Ool01`00Ool007oo001oo`00009oo`05001oo`00Ool00002Ool01`00Ool007oo001oo`00009oo`07
001oo`00Ool007oo00000Woo00D007oo001oo`00009oo`07001oo`00Ool007oo00000Woo00<007oo
Ool0DGoo000BOol00`00Ool00008Ool20004Ool00`00Oomoo`0kOol01`00Ool007oo001oo`00009o
o`05001oo`00Ool00002Ool01`00Ool007oo001oo`00009oo`07001oo`00Ool007oo00000Woo00D0
07oo001oo`00009oo`07001oo`00Ool007oo00000Woo00D007oo001oo`00009oo`07001oo`00Ool0
07oo00000Woo00D007oo001oo`00009oo`07001oo`00Ool007oo00000Woo00L007oo001oo`00Ool0
0002Ool01@00Ool007oo00000Woo00L007oo001oo`00Ool00002Ool00`00Oomoo`1AOol001=oo`03
001oogoo00Qoo`03001oogoo009oo`03001oogoo03]oo`07001oo`00Ool007oo00000Woo00D007oo
001oo`00009oo`07001oo`00Ool007oo00000Woo00L007oo001oo`00Ool00002Ool01@00Ool007oo
00000Woo00L007oo001oo`00Ool00002Ool01@00Ool007oo00000Woo00L007oo001oo`00Ool00002
Ool01@00Ool007oo00000Woo00L007oo001oo`00Ool00002Ool01`00Ool007oo001oo`00009oo`05
001oo`00Ool00002Ool01`00Ool007oo001oo`00009oo`03001oogoo055oo`008goo00<007ooOol0
>goo00L007oo001oo`00Ool00002Ool01@00Ool007oo00000Woo00L007oo001oo`00Ool00002Ool0
1`00Ool007oo001oo`00009oo`05001oo`00Ool00002Ool01`00Ool007oo001oo`00009oo`05001o
o`00Ool00002Ool01`00Ool007oo001oo`00009oo`05001oo`00Ool00002Ool01`00Ool007oo001o
o`00009oo`07001oo`00Ool007oo00000Woo00D007oo001oo`00009oo`07001oo`00Ool007oo0000
0Woo00<007ooOol0DGoo000SOol00`00Oomoo`0jOol02000Oomoo`00Ool007oo0002Ool01@00Ool0
07oo00000Woo00L007oo001oo`00Ool00002Ool01`00Ool007oo001oo`00009oo`05001oo`00Ool0
0002Ool01`00Ool007oo001oo`00009oo`05001oo`00Ool00002Ool01`00Ool007oo001oo`00009o
o`05001oo`00Ool00002Ool01`00Ool007oo001oo`00009oo`07001oo`00Ool007oo00000Woo00D0
07oo001oo`00009oo`09001oo`00Ool007oo001oo`0005Aoo`008goo00<007ooOol0?Goo00D007oo
001oo`00009oo`05001oo`00Ool00002Ool01`00Ool007oo001oo`00009oo`07001oo`00Ool007oo
00000Woo00D007oo001oo`00009oo`07001oo`00Ool007oo00000Woo00D007oo001oo`00009oo`07
001oo`00Ool007oo00000Woo00D007oo001oo`00009oo`07001oo`00Ool007oo00000Woo00L007oo
001oo`00Ool00002Ool01@00Ool007oo00000Woo00L007oo001oo`00Ool0001FOol002=oo`8003io
o`05001oo`00Ool00002Ool01@00Ool007oo00000Woo00L007oo001oo`00Ool00002Ool01`00Ool0
07oo001oo`00009oo`05001oo`00Ool00002Ool01`00Ool007oo001oo`00009oo`05001oo`00Ool0
0002Ool01`00Ool007oo001oo`00009oo`05001oo`00Ool00002Ool01`00Ool007oo001oo`00009o
o`07001oo`00Ool007oo00000Woo00D007oo001oo`00009oo`07001oo`00Ool007oo0000EWoo000S
Ool00`00Oomoo`0mOol01@00Ool007oo00000Woo00D007oo001oo`00009oo`07001oo`00Ool007oo
00000Woo00L007oo001oo`00Ool00002Ool01@00Ool007oo00000Woo00L007oo001oo`00Ool00002
Ool01@00Ool007oo00000Woo00L007oo001oo`00Ool00002Ool01@00Ool007oo00000Woo00L007oo
001oo`00Ool00002Ool01`00Ool007oo001oo`00009oo`05001oo`00Ool00002Ool01`00Ool007oo
001oo`0005Ioo`008goo00<007ooOol0?Goo00D007oo001oo`00009oo`05001oo`00Ool00002Ool0
1`00Ool007oo001oo`00009oo`07001oo`00Ool007oo00000Woo00D007oo001oo`00009oo`07001o
o`00Ool007oo00000Woo00D007oo001oo`00009oo`07001oo`00Ool007oo00000Woo00D007oo001o
o`00009oo`07001oo`00Ool007oo00000Woo00L007oo001oo`00Ool00002Ool01@00Ool007oo0000
0Woo00L007oo001oo`00Ool0001FOol002=oo`03001oogoo03aoo`06001oogoo001oo`000Woo00D0
07oo001oo`00009oo`07001oo`00Ool007oo00000Woo00L007oo001oo`00Ool00002Ool01@00Ool0
07oo00000Woo00L007oo001oo`00Ool00002Ool01@00Ool007oo00000Woo00L007oo001oo`00Ool0
0002Ool01@00Ool007oo00000Woo00L007oo001oo`00Ool00002Ool01`00Ool007oo001oo`00009o
o`05001oo`00Ool00002Ool01`00Ool007oo001oo`0005Ioo`008goo00<007ooOol0?goo00<007oo
00000Woo00D007oo001oo`00009oo`07001oo`00Ool007oo00000Woo00L007oo001oo`00Ool00002
Ool01@00Ool007oo00000Woo00L007oo001oo`00Ool00002Ool01@00Ool007oo00000Woo00L007oo
001oo`00Ool00002Ool01@00Ool007oo00000Woo00L007oo001oo`00Ool00002Ool01`00Ool007oo
001oo`00009oo`05001oo`00Ool00002Ool01@00Ool007oo0000F7oo000SOol00`00Oomoo`0oOol0
0`00Ool00002Ool01@00Ool007oo00000Woo00L007oo001oo`00Ool00002Ool01`00Ool007oo001o
o`00009oo`05001oo`00Ool00002Ool01`00Ool007oo001oo`00009oo`05001oo`00Ool00002Ool0
1`00Ool007oo001oo`00009oo`05001oo`00Ool00002Ool01`00Ool007oo001oo`00009oo`07001o
o`00Ool007oo00000Woo00D007oo001oo`00009oo`05001oo`00Ool0001HOol002=oo`03001oogoo
03moo`03001oo`00009oo`05001oo`00Ool00002Ool01`00Ool007oo001oo`00009oo`07001oo`00
Ool007oo00000Woo00D007oo001oo`00009oo`07001oo`00Ool007oo00000Woo00D007oo001oo`00
009oo`07001oo`00Ool007oo00000Woo00D007oo001oo`00009oo`07001oo`00Ool007oo00000Woo
00L007oo001oo`00Ool00002Ool01@00Ool007oo00000Woo00D007oo001oo`0005Qoo`008goo0P00
@7oo00<007oo00000Woo00D007oo001oo`00009oo`07001oo`00Ool007oo00000Woo00L007oo001o
o`00Ool00002Ool01@00Ool007oo00000Woo00L007oo001oo`00Ool00002Ool01@00Ool007oo0000
0Woo00L007oo001oo`00Ool00002Ool01@00Ool007oo00000Woo00L007oo001oo`00Ool00002Ool0
1`00Ool007oo001oo`00009oo`05001oo`00Ool00002Ool01@00Ool007oo0000F7oo000SOol00`00
Oomoo`0nOol01000Oomoo`000Woo00D007oo001oo`00009oo`07001oo`00Ool007oo00000Woo00L0
07oo001oo`00Ool00002Ool01@00Ool007oo00000Woo00L007oo001oo`00Ool00002Ool01@00Ool0
07oo00000Woo00L007oo001oo`00Ool00002Ool01@00Ool007oo00000Woo00L007oo001oo`00Ool0
0002Ool01`00Ool007oo001oo`00009oo`05001oo`00Ool00002Ool01000Ool00000FGoo000SOol0
0`00Oomoo`11Ool02000Oomoo`00Ool007oo0002Ool01`00Ool007oo001oo`00009oo`07001oo`00
Ool007oo00000Woo00D007oo001oo`00009oo`07001oo`00Ool007oo00000Woo00D007oo001oo`00
009oo`07001oo`00Ool007oo00000Woo00D007oo001oo`00009oo`07001oo`00Ool007oo00000Woo
00L007oo001oo`00Ool00002Ool01@00Ool007oo00000Woo00<007oo0000FWoo000SOol00`00Oomo
o`11Ool02000Oomoo`00Ool007oo0002Ool01`00Ool007oo001oo`00009oo`07001oo`00Ool007oo
00000Woo00D007oo001oo`00009oo`07001oo`00Ool007oo00000Woo00D007oo001oo`00009oo`07
001oo`00Ool007oo00000Woo00D007oo001oo`00009oo`07001oo`00Ool007oo00000Woo00L007oo
001oo`00Ool00002Ool01@00Ool007oo00000Woo00<007oo0000FWoo000SOol00`00Oomoo`11Ool0
2000Oomoo`00Ool007oo0002Ool01`00Ool007oo001oo`00009oo`07001oo`00Ool007oo00000Woo
00D007oo001oo`00009oo`07001oo`00Ool007oo00000Woo00D007oo001oo`00009oo`07001oo`00
Ool007oo00000Woo00D007oo001oo`00009oo`07001oo`00Ool007oo00000Woo00L007oo001oo`00
Ool00002Ool01@00Ool007oo00000Woo00<007oo0000FWoo000SOol00`00Oomoo`10Ool02@00Oomo
ogoo001oo`00Ool00002Ool01`00Ool007oo001oo`00009oo`07001oo`00Ool007oo00000Woo00D0
07oo001oo`00009oo`07001oo`00Ool007oo00000Woo00D007oo001oo`00009oo`07001oo`00Ool0
07oo00000Woo00D007oo001oo`00009oo`07001oo`00Ool007oo00000Woo00L007oo001oo`00Ool0
0002Ool01@00Ool007oo00000Woo0P00Fgoo000SOol00`00Oomoo`14Ool01@00Ool007oo00000Woo
00L007oo001oo`00Ool00002Ool01`00Ool007oo001oo`00009oo`05001oo`00Ool00002Ool01`00
Ool007oo001oo`00009oo`05001oo`00Ool00002Ool01`00Ool007oo001oo`00009oo`05001oo`00
Ool00002Ool01`00Ool007oo001oo`00009oo`07001oo`00Ool007oo00000Woo00D007oo001oo`00
009oo`03001oogoo05Yoo`008goo0P00AGoo00D007oo001oo`00009oo`07001oo`00Ool007oo0000
0Woo00L007oo001oo`00Ool00002Ool01@00Ool007oo00000Woo00L007oo001oo`00Ool00002Ool0
1@00Ool007oo00000Woo00L007oo001oo`00Ool00002Ool01@00Ool007oo00000Woo00L007oo001o
o`00Ool00002Ool01`00Ool007oo001oo`00009oo`05001oo`00Ool00002Ool00`00Oomoo`1JOol0
02=oo`03001oogoo04Aoo`05001oo`00Ool00002Ool01`00Ool007oo001oo`00009oo`07001oo`00
Ool007oo00000Woo00D007oo001oo`00009oo`07001oo`00Ool007oo00000Woo00D007oo001oo`00
009oo`07001oo`00Ool007oo00000Woo00D007oo001oo`00009oo`07001oo`00Ool007oo00000Woo
00L007oo001oo`00Ool00002Ool01@00Ool007oo00000Woo00<007ooOol0FWoo000SOol00`00Oomo
o`14Ool01@00Ool007oo00000Woo00L007oo001oo`00Ool00002Ool01`00Ool007oo001oo`00009o
o`05001oo`00Ool00002Ool01`00Ool007oo001oo`00009oo`05001oo`00Ool00002Ool01`00Ool0
07oo001oo`00009oo`05001oo`00Ool00002Ool01`00Ool007oo001oo`00009oo`07001oo`00Ool0
07oo00000Woo00D007oo001oo`00009oo`03001oogoo05Yoo`008goo00<007ooOol0@goo00H007oo
Ool007oo0002Ool01`00Ool007oo001oo`00009oo`07001oo`00Ool007oo00000Woo00D007oo001o
o`00009oo`07001oo`00Ool007oo00000Woo00D007oo001oo`00009oo`07001oo`00Ool007oo0000
0Woo00D007oo001oo`00009oo`07001oo`00Ool007oo00000Woo00L007oo001oo`00Ool00002Ool0
1`00Ool007oo001oo`0005eoo`008goo00<007ooOol0AWoo00<007oo00000Woo00L007oo001oo`00
Ool00002Ool01`00Ool007oo001oo`00009oo`05001oo`00Ool00002Ool01`00Ool007oo001oo`00
009oo`05001oo`00Ool00002Ool01`00Ool007oo001oo`00009oo`05001oo`00Ool00002Ool01`00
Ool007oo001oo`00009oo`07001oo`00Ool007oo00000Woo00D007oo001oo`0005moo`004goo00<0
07ooOol00Woo00@007ooOomoo`8000Eoo`03001oogoo04Ioo`03001oo`00009oo`07001oo`00Ool0
07oo00000Woo00L007oo001oo`00Ool00002Ool01@00Ool007oo00000Woo00L007oo001oo`00Ool0
0002Ool01@00Ool007oo00000Woo00L007oo001oo`00Ool00002Ool01@00Ool007oo00000Woo00L0
07oo001oo`00Ool00002Ool01`00Ool007oo001oo`00009oo`05001oo`00Ool0001OOol0019oo`03
001oo`0000Moo`03001oo`0000Aoo`03001oogoo04Ioo`03001oo`00009oo`07001oo`00Ool007oo
00000Woo00L007oo001oo`00Ool00002Ool01@00Ool007oo00000Woo00L007oo001oo`00Ool00002
Ool01@00Ool007oo00000Woo00L007oo001oo`00Ool00002Ool01@00Ool007oo00000Woo00L007oo
001oo`00Ool00002Ool01`00Ool007oo001oo`00009oo`05001oo`00Ool0001OOol0019oo`03001o
o`0000Moo`03001oo`0000Aoo`<004Ioo`03001oo`00009oo`07001oo`00Ool007oo00000Woo00L0
07oo001oo`00Ool00002Ool01@00Ool007oo00000Woo00L007oo001oo`00Ool00002Ool01@00Ool0
07oo00000Woo00L007oo001oo`00Ool00002Ool01@00Ool007oo00000Woo00L007oo001oo`00Ool0
0002Ool01`00Ool007oo001oo`00009oo`05001oo`00Ool0001OOol0019oo`03001oo`0000Moo`80
00Eoo`03001oogoo04Eoo`04001oogoo0002Ool01`00Ool007oo001oo`00009oo`07001oo`00Ool0
07oo00000Woo00D007oo001oo`00009oo`07001oo`00Ool007oo00000Woo00D007oo001oo`00009o
o`07001oo`00Ool007oo00000Woo00D007oo001oo`00009oo`07001oo`00Ool007oo00000Woo00L0
07oo001oo`00Ool00002Ool01000Ool00000H7oo000BOol00`00Ool00007Ool00`00Oomoo`04Ool0
0`00Oomoo`18Ool02P00Oomoo`00Ool007oo001oo`000Woo00L007oo001oo`00Ool00002Ool01@00
Ool007oo00000Woo00L007oo001oo`00Ool00002Ool01@00Ool007oo00000Woo00L007oo001oo`00
Ool00002Ool01@00Ool007oo00000Woo00L007oo001oo`00Ool00002Ool01`00Ool007oo001oo`00
009oo`03001oo`00065oo`004goo00<007ooOol01goo0P0017oo00<007ooOol0B7oo00X007ooOol0
07oo001oo`00Ool0009oo`07001oo`00Ool007oo00000Woo00D007oo001oo`00009oo`07001oo`00
Ool007oo00000Woo00D007oo001oo`00009oo`07001oo`00Ool007oo00000Woo00D007oo001oo`00
009oo`07001oo`00Ool007oo00000Woo00L007oo001oo`00Ool00002Ool00`00Ool0001QOol002=o
o`03001oogoo04Qoo`0:001oogoo001oo`00Ool007oo0002Ool01`00Ool007oo001oo`00009oo`05
001oo`00Ool00002Ool01`00Ool007oo001oo`00009oo`05001oo`00Ool00002Ool01`00Ool007oo
001oo`00009oo`05001oo`00Ool00002Ool01`00Ool007oo001oo`00009oo`07001oo`00Ool007oo
00000Woo00<007oo0000HGoo000SOol00`00Oomoo`18Ool02P00Oomoo`00Ool007oo001oo`000Woo
00L007oo001oo`00Ool00002Ool01@00Ool007oo00000Woo00L007oo001oo`00Ool00002Ool01@00
Ool007oo00000Woo00L007oo001oo`00Ool00002Ool01@00Ool007oo00000Woo00L007oo001oo`00
Ool00002Ool01`00Ool007oo001oo`00009oo`03001oo`00065oo`008goo00<007ooOol0Agoo00/0
07ooOomoo`00Ool007oo001oo`00009oo`07001oo`00Ool007oo00000Woo00D007oo001oo`00009o
o`07001oo`00Ool007oo00000Woo00D007oo001oo`00009oo`07001oo`00Ool007oo00000Woo00D0
07oo001oo`00009oo`07001oo`00Ool007oo00000Woo00L007oo001oo`00Ool00002Ool2001ROol0
02=oo`8004aoo`07001oo`00Ool007oo00000Woo00L007oo001oo`00Ool00002Ool01@00Ool007oo
00000Woo00L007oo001oo`00Ool00002Ool01@00Ool007oo00000Woo00L007oo001oo`00Ool00002
Ool01@00Ool007oo00000Woo00L007oo001oo`00Ool00002Ool01`00Ool007oo001oo`00009oo`03
001oogoo065oo`008goo00<007ooOol0Bgoo00L007oo001oo`00Ool00002Ool01`00Ool007oo001o
o`00009oo`05001oo`00Ool00002Ool01`00Ool007oo001oo`00009oo`05001oo`00Ool00002Ool0
1`00Ool007oo001oo`00009oo`05001oo`00Ool00002Ool01`00Ool007oo001oo`00009oo`07001o
o`00Ool007oo00000Woo00<007ooOol0HGoo000SOol00`00Oomoo`1;Ool01`00Ool007oo001oo`00
009oo`07001oo`00Ool007oo00000Woo00D007oo001oo`00009oo`07001oo`00Ool007oo00000Woo
00D007oo001oo`00009oo`07001oo`00Ool007oo00000Woo00D007oo001oo`00009oo`07001oo`00
Ool007oo00000Woo00L007oo001oo`00Ool00002Ool00`00Oomoo`1QOol002=oo`03001oogoo04]o
o`07001oo`00Ool007oo00000Woo00L007oo001oo`00Ool00002Ool01@00Ool007oo00000Woo00L0
07oo001oo`00Ool00002Ool01@00Ool007oo00000Woo00L007oo001oo`00Ool00002Ool01@00Ool0
07oo00000Woo00L007oo001oo`00Ool00002Ool01`00Ool007oo001oo`00009oo`03001oogoo065o
o`008goo00<007ooOol0BWoo00P007ooOol007oo001oo`000Woo00L007oo001oo`00Ool00002Ool0
1@00Ool007oo00000Woo00L007oo001oo`00Ool00002Ool01@00Ool007oo00000Woo00L007oo001o
o`00Ool00002Ool01@00Ool007oo00000Woo00L007oo001oo`00Ool00002Ool02@00Ool007oo001o
o`00Ool0001TOol002=oo`03001oogoo04eoo`05001oo`00Ool00002Ool01`00Ool007oo001oo`00
009oo`05001oo`00Ool00002Ool01`00Ool007oo001oo`00009oo`05001oo`00Ool00002Ool01`00
Ool007oo001oo`00009oo`05001oo`00Ool00002Ool01`00Ool007oo001oo`00009oo`07001oo`00
Ool007oo0000IWoo000SOol00`00Oomoo`1=Ool01@00Ool007oo00000Woo00L007oo001oo`00Ool0
0002Ool01@00Ool007oo00000Woo00L007oo001oo`00Ool00002Ool01@00Ool007oo00000Woo00L0
07oo001oo`00Ool00002Ool01@00Ool007oo00000Woo00L007oo001oo`00Ool00002Ool01`00Ool0
07oo001oo`0006Ioo`008goo0P00CWoo00D007oo001oo`00009oo`07001oo`00Ool007oo00000Woo
00D007oo001oo`00009oo`07001oo`00Ool007oo00000Woo00D007oo001oo`00009oo`07001oo`00
Ool007oo00000Woo00D007oo001oo`00009oo`07001oo`00Ool007oo00000Woo00L007oo001oo`00
Ool0001VOol002=oo`03001oogoo04eoo`05001oo`00Ool00002Ool01`00Ool007oo001oo`00009o
o`05001oo`00Ool00002Ool01`00Ool007oo001oo`00009oo`05001oo`00Ool00002Ool01`00Ool0
07oo001oo`00009oo`05001oo`00Ool00002Ool01`00Ool007oo001oo`00009oo`07001oo`00Ool0
07oo0000IWoo000SOol00`00Oomoo`1<Ool01P00Oomoo`00Ool0009oo`07001oo`00Ool007oo0000
0Woo00D007oo001oo`00009oo`07001oo`00Ool007oo00000Woo00D007oo001oo`00009oo`07001o
o`00Ool007oo00000Woo00D007oo001oo`00009oo`07001oo`00Ool007oo00000Woo00L007oo001o
o`00Ool0001VOol002=oo`03001oogoo04moo`03001oo`00009oo`07001oo`00Ool007oo00000Woo
00D007oo001oo`00009oo`07001oo`00Ool007oo00000Woo00D007oo001oo`00009oo`07001oo`00
Ool007oo00000Woo00D007oo001oo`00009oo`07001oo`00Ool007oo00000Woo00D007oo001oo`00
06Qoo`008goo00<007ooOol0Cgoo00<007oo00000Woo00L007oo001oo`00Ool00002Ool01@00Ool0
07oo00000Woo00L007oo001oo`00Ool00002Ool01@00Ool007oo00000Woo00L007oo001oo`00Ool0
0002Ool01@00Ool007oo00000Woo00L007oo001oo`00Ool00002Ool01@00Ool007oo0000J7oo000S
Ool00`00Oomoo`1?Ool00`00Ool00002Ool01`00Ool007oo001oo`00009oo`05001oo`00Ool00002
Ool01`00Ool007oo001oo`00009oo`05001oo`00Ool00002Ool01`00Ool007oo001oo`00009oo`05
001oo`00Ool00002Ool01`00Ool007oo001oo`00009oo`05001oo`00Ool0001XOol002=oo`03001o
ogoo04ioo`04001oogoo0002Ool01`00Ool007oo001oo`00009oo`05001oo`00Ool00002Ool01`00
Ool007oo001oo`00009oo`05001oo`00Ool00002Ool01`00Ool007oo001oo`00009oo`05001oo`00
Ool00002Ool01`00Ool007oo001oo`00009oo`04001oo`00001YOol002=oo`80059oo`0:001oogoo
001oo`00Ool007oo0002Ool01@00Ool007oo00000Woo00L007oo001oo`00Ool00002Ool01@00Ool0
07oo00000Woo00L007oo001oo`00Ool00002Ool01@00Ool007oo00000Woo00L007oo001oo`00Ool0
0002Ool00`00Ool0001ZOol002=oo`03001oogoo055oo`0:001oogoo001oo`00Ool007oo0002Ool0
1@00Ool007oo00000Woo00L007oo001oo`00Ool00002Ool01@00Ool007oo00000Woo00L007oo001o
o`00Ool00002Ool01@00Ool007oo00000Woo00L007oo001oo`00Ool00002Ool00`00Ool0001ZOol0
02=oo`03001oogoo055oo`0:001oogoo001oo`00Ool007oo0002Ool01@00Ool007oo00000Woo00L0
07oo001oo`00Ool00002Ool01@00Ool007oo00000Woo00L007oo001oo`00Ool00002Ool01@00Ool0
07oo00000Woo00L007oo001oo`00Ool00002Ool00`00Ool0001ZOol002=oo`03001oogoo055oo`0:
001oogoo001oo`00Ool007oo0002Ool01@00Ool007oo00000Woo00L007oo001oo`00Ool00002Ool0
1@00Ool007oo00000Woo00L007oo001oo`00Ool00002Ool01@00Ool007oo00000Woo00L007oo001o
o`00Ool00002Ool00`00Ool0001ZOol002=oo`03001oogoo051oo`0;001oogooOol007oo001oo`00
Ool00002Ool01@00Ool007oo00000Woo00L007oo001oo`00Ool00002Ool01@00Ool007oo00000Woo
00L007oo001oo`00Ool00002Ool01@00Ool007oo00000Woo00L007oo001oo`00Ool00002Ool2001[
Ool001=oo`03001oogoo009oo`03001oogoo009oo`03001oogoo00=oo`03001oogoo05Aoo`07001o
o`00Ool007oo00000Woo00D007oo001oo`00009oo`07001oo`00Ool007oo00000Woo00D007oo001o
o`00009oo`07001oo`00Ool007oo00000Woo00D007oo001oo`00009oo`07001oo`00Ool007oo0000
0Woo00<007ooOol0JWoo000BOol00`00Ool00007Ool00`00Ool00004Ool00`00Oomoo`1DOol01`00
Ool007oo001oo`00009oo`05001oo`00Ool00002Ool01`00Ool007oo001oo`00009oo`05001oo`00
Ool00002Ool01`00Ool007oo001oo`00009oo`05001oo`00Ool00002Ool01`00Ool007oo001oo`00
009oo`03001oogoo06Yoo`004Woo00<007oo00001goo00<007oo000017oo0`00E7oo00L007oo001o
o`00Ool00002Ool01@00Ool007oo00000Woo00L007oo001oo`00Ool00002Ool01@00Ool007oo0000
0Woo00L007oo001oo`00Ool00002Ool01@00Ool007oo00000Woo00L007oo001oo`00Ool00002Ool0
0`00Oomoo`1ZOol0019oo`03001oo`0000Qoo`03001oogoo00=oo`03001oogoo05=oo`08001oogoo
001oo`00Ool0009oo`05001oo`00Ool00002Ool01`00Ool007oo001oo`00009oo`05001oo`00Ool0
0002Ool01`00Ool007oo001oo`00009oo`05001oo`00Ool00002Ool02@00Ool007oo001oo`00Ool0
001]Ool0019oo`03001oo`0000Moo`03001oo`0000Aoo`03001oogoo05Ioo`05001oo`00Ool00002
Ool01@00Ool007oo00000Woo00L007oo001oo`00Ool00002Ool01@00Ool007oo00000Woo00L007oo
001oo`00Ool00002Ool01@00Ool007oo00000Woo00L007oo001oo`00Ool0001_Ool001=oo`03001o
ogoo00Moo`03001oogoo00=oo`03001oogoo05Ioo`05001oo`00Ool00002Ool01@00Ool007oo0000
0Woo00L007oo001oo`00Ool00002Ool01@00Ool007oo00000Woo00L007oo001oo`00Ool00002Ool0
1@00Ool007oo00000Woo00L007oo001oo`00Ool0001_Ool002=oo`03001oogoo05Ioo`05001oo`00
Ool00002Ool01@00Ool007oo00000Woo00L007oo001oo`00Ool00002Ool01@00Ool007oo00000Woo
00L007oo001oo`00Ool00002Ool01@00Ool007oo00000Woo00L007oo001oo`00Ool0001_Ool002=o
o`03001oogoo05Eoo`06001oogoo001oo`000Woo00D007oo001oo`00009oo`07001oo`00Ool007oo
00000Woo00D007oo001oo`00009oo`07001oo`00Ool007oo00000Woo00D007oo001oo`00009oo`04
001oo`00Ool2001`Ool002=oo`03001oogoo05Qoo`03001oo`00009oo`05001oo`00Ool00002Ool0
1`00Ool007oo001oo`00009oo`05001oo`00Ool00002Ool01`00Ool007oo001oo`00009oo`05001o
o`00Ool00002Ool01@00Ool007oo0000LGoo000SOol00`00Oomoo`1HOol00`00Ool00002Ool01@00
Ool007oo00000Woo00L007oo001oo`00Ool00002Ool01@00Ool007oo00000Woo00L007oo001oo`00
Ool00002Ool01@00Ool007oo00000Woo00D007oo001oo`00075oo`008goo0P00FGoo00<007oo0000
0Woo00D007oo001oo`00009oo`07001oo`00Ool007oo00000Woo00D007oo001oo`00009oo`07001o
o`00Ool007oo00000Woo00D007oo001oo`00009oo`05001oo`00Ool0001aOol002=oo`03001oogoo
05Moo`04001oogoo0002Ool01@00Ool007oo00000Woo00L007oo001oo`00Ool00002Ool01@00Ool0
07oo00000Woo00L007oo001oo`00Ool00002Ool01@00Ool007oo00000Woo00@007oo0000079oo`00
8goo00<007ooOol0FWoo00P007ooOol007oo001oo`000Woo00L007oo001oo`00Ool00002Ool01@00
Ool007oo00000Woo00L007oo001oo`00Ool00002Ool01@00Ool007oo00000Woo00<007oo0000Lgoo
000SOol00`00Oomoo`1JOol02000Oomoo`00Ool007oo0002Ool01`00Ool007oo001oo`00009oo`05
001oo`00Ool00002Ool01`00Ool007oo001oo`00009oo`05001oo`00Ool00002Ool00`00Ool0001c
Ool002=oo`03001oogoo05Yoo`08001oogoo001oo`00Ool0009oo`07001oo`00Ool007oo00000Woo
00D007oo001oo`00009oo`07001oo`00Ool007oo00000Woo00D007oo001oo`00009oo`8007Aoo`00
8goo00<007ooOol0GGoo00D007oo001oo`00009oo`07001oo`00Ool007oo00000Woo00D007oo001o
o`00009oo`07001oo`00Ool007oo00000Woo00D007oo001oo`00009oo`03001oogoo07=oo`008goo
00<007ooOol0GGoo00D007oo001oo`00009oo`07001oo`00Ool007oo00000Woo00D007oo001oo`00
009oo`07001oo`00Ool007oo00000Woo00D007oo001oo`00009oo`03001oogoo07=oo`008goo0P00
GWoo00D007oo001oo`00009oo`07001oo`00Ool007oo00000Woo00D007oo001oo`00009oo`07001o
o`00Ool007oo00000Woo00D007oo001oo`00009oo`03001oogoo07=oo`008goo00<007ooOol0G7oo
00H007ooOol007oo0002Ool01`00Ool007oo001oo`00009oo`05001oo`00Ool00002Ool01`00Ool0
07oo001oo`00009oo`07001oo`00Ool007oo0000MWoo000SOol00`00Oomoo`1OOol00`00Ool00002
Ool01`00Ool007oo001oo`00009oo`05001oo`00Ool00002Ool01`00Ool007oo001oo`00009oo`05
001oo`00Ool0001hOol002=oo`03001oogoo05moo`03001oo`00009oo`07001oo`00Ool007oo0000
0Woo00D007oo001oo`00009oo`07001oo`00Ool007oo00000Woo00D007oo001oo`0007Qoo`008goo
00<007ooOol0GWoo00@007ooOol0009oo`07001oo`00Ool007oo00000Woo00D007oo001oo`00009o
o`07001oo`00Ool007oo00000Woo00@007oo000007Uoo`008goo00<007ooOol0HGoo00X007ooOol0
07oo001oo`00Ool0009oo`05001oo`00Ool00002Ool01`00Ool007oo001oo`00009oo`03001oo`00
07Yoo`008goo00<007ooOol0H7oo0P000Woo00L007oo001oo`00Ool00002Ool01@00Ool007oo0000
0Woo00L007oo001oo`00Ool00002Ool3001jOol002=oo`8006Eoo`07001oo`00Ool007oo00000Woo
00D007oo001oo`00009oo`07001oo`00Ool007oo00000Woo00<007ooOol0NWoo000SOol00`00Oomo
o`1TOol01`00Ool007oo001oo`00009oo`05001oo`00Ool00002Ool01`00Ool007oo001oo`00009o
o`03001oogoo07Yoo`008goo00<007ooOol0Hgoo00P007ooOol007oo001oo`000Woo00D007oo001o
o`00009oo`09001oo`00Ool007oo001oo`0007eoo`008goo00<007ooOol0IWoo00D007oo001oo`00
009oo`05001oo`00Ool00002Ool01`00Ool007oo001oo`0007moo`008goo00<007ooOol0IGoo00H0
07ooOol007oo0002Ool01@00Ool007oo00000Woo00@007oo001oo`80081oo`006goo1@000goo00<0
07ooOol0Igoo00@007ooOol0009oo`05001oo`00Ool00002Ool01000Ool00000PWoo000MOol00`00
Oomoo`03Ool00`00Oomoo`1ZOol02000Oomoo`00Ool007oo0002Ool00`00Ool00023Ool001eoo`03
001oogoo00=oo`<006Yoo`09001oo`00001oo`00Ool007oo00<008Aoo`007Goo00<007ooOol00goo
00<007ooOol0KWoo00<007oo0000RGoo000MOol00`00Oomoo`03Ool00`00Oomoo`3jOol001aoo`80
00Eoo`03001oogoo0?Yoo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?mo
ob5oo`00W7oo0P00PWoo002NOol00`00Oomoo`1oOol005Yoo`@0009oo`<0009oo`8000=oo`<0009o
o`<000=oo`8000=oo`8000=oo`80011oo`<0009oo`<000=oo`D0009oo`03001oo`0000<00004Ool0
0000000=Ool30003Ool30003Ool20003Ool2001COol005]oo`04001oogoo0002Ool00`00Oomoo`03
Ool01000Oomoo`001Goo00D007ooOomoo`0000Aoo`06001oogoo001oo`004Woo00<007oo00000goo
00D007ooOomoo`00009oo`03001oo`00009oo`03001oo`00008000=oo`03001oogoo00eoo`03001o
ogoo00=oo`05001oogooOol00002Ool00`00Ool00002Ool00`00Oomoo`1@Ool005]oo`04001oogoo
0002Ool00`00Oomoo`02Ool01@00Oomoogoo00001Goo00@007ooOomoo`<0009oo`03001oogoo009o
o`<0019oo`05001oogooOol00003Ool01P00Oomoo`00Ool0009oo`05001oogooOol00003Ool00`00
Oomoo`0=Ool30003Ool01@00Oomoogoo00000Woo00<007oo0000EGoo001KOol01@00Oomoo`00Ool0
0P0017oo0P000Woo0`000Woo100000Eoo`00000007oo00@0009oo`<0015oo`04001oogooOol20004
Ool70003Ool20003Ool00`00Oomoo`0=Ool01000Oomoo`000Woo00<007ooOol00Woo0P0000=oo`00
00000P00Dgoo001KOol01000Oomoo`006Woo00<007ooOol05Goo00<007oo00005goo00<007ooOol0
3Goo00@007ooOol0009oo`03001oogoo00Ioo`03001oogoo05=oo`00FWoo10000goo00<007ooOol0
;Goo0`000goo00<007ooOol047oo0P003Woo10000Woo0P00GWoo003oOolQOol00?moob5oo`00ogoo
8Goo003oOolQOol00?moob5oo`00\
\>"],
  ImageRangeCache->{{{86.5, 373.5}, {262.375, 85.4375}} -> {-53.504, 0.515608,
   0.438555, 0.00702318}}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Filter design with Kaiser window", "Section",
  TextJustification->0,
  FontFamily->"Arial"],

Cell[TextData[{
  "Window-based FIR filter design generally begins by specifying the desired \
ideal zero-phase frequency response ",
  Cell[BoxData[
      \(TraditionalForm\`\(H\_id\)(\[Omega])\)]],
  ". The corresponding impulse response may be obtained by means of the \
inverse Discrete-Time Fourier Transform:\n\t",
  Cell[BoxData[
      \(TraditionalForm
      \`h\_id\ \((n)\)\ \  = \ \ 
        1\/\(2  \[Pi]\)\ 
          \(\[Integral]\_\(-\[Pi]\)\%\[Pi]\(\( H\_id\)(\[Omega])\)\ 
              \(\[ExponentialE]\^\(j\ \[Omega]\ n\)\) 
              \[DifferentialD]\[Omega]\)\)]],
  "\nIt is infinite in duration. A realizable impulse response ",
  Cell[BoxData[
      \(TraditionalForm\`\(h\_r\)(n)\)]],
  " must be truncated and smoothed according to\n\t",
  Cell[BoxData[
      \(TraditionalForm
      \`\(h\_r\)(n)\ \  = \ \ h\_id\ \((n)\)\ *\ \(w(n)\)\)]],
  "\nwhere ",
  StyleBox["w(n)",
    FontSlant->"Italic"],
  " is the finite length window sequence. We conclude with a lowpass filter \
design example."
}], "Text",
  TextJustification->0,
  FontFamily->"Times New Roman"],

Cell[CellGroupData[{

Cell["Example 2", "Subsubsection",
  TextJustification->0,
  FontFamily->"Times New Roman"],

Cell[TextData[
"Design a half-band (i.e. transition centered at 0.5\[Pi]) lowpass filter of \
length 21 using the Kaiser window. Set the parameter \[Alpha]=6.5."], "Text",
  TextJustification->0,
  FontFamily->"Times New Roman"],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Solution.",
    FontWeight->"Bold"],
  " The window sequence is given by the function KaiserWindow:"
}], "Text",
  TextJustification->0,
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(\({\[Alpha], L} = {6.5, 21}; \)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(w2 = KaiserWindow[\[Alpha], L]\)], "Input",
  TextJustification->0],

Cell[BoxData[
    \({0.00940796979703468849`, 0.0401610925825470488`, 
      0.0975508429073472882`, 0.186403707278319288`, 0.306545456100333302`, 
      0.451477902499260341`, 0.608406310874589451`, 0.759812222876221809`, 
      0.886354021458674168`, 0.970492624014273985`, 1.`, 
      0.970492624014273985`, 0.886354021458674168`, 0.759812222876221809`, 
      0.608406310874589451`, 0.451477902499260341`, 0.306545456100333302`, 
      0.186403707278319288`, 0.0975508429073472882`, 0.0401610925825470488`, 
      0.00940796979703468849`}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(DiscreteSignalPlot[w2]; \)\)], "Input",
  TextJustification->0],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.047619 0.0147151 0.588604 [
[.2619 .00222 -3 -9 ]
[.2619 .00222 3 0 ]
[.5 .00222 -6 -9 ]
[.5 .00222 6 0 ]
[.7381 .00222 -6 -9 ]
[.7381 .00222 6 0 ]
[.97619 .00222 -6 -9 ]
[.97619 .00222 6 0 ]
[.01131 .13244 -18 -4.5 ]
[.01131 .13244 0 4.5 ]
[.01131 .25016 -18 -4.5 ]
[.01131 .25016 0 4.5 ]
[.01131 .36788 -18 -4.5 ]
[.01131 .36788 0 4.5 ]
[.01131 .4856 -18 -4.5 ]
[.01131 .4856 0 4.5 ]
[.01131 .60332 -6 -4.5 ]
[.01131 .60332 0 4.5 ]
[.5 .63053 -62 0 ]
[.5 .63053 62 12.875 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.2619 .01472 m
.2619 .02097 L
s
[(5)] .2619 .00222 0 1 Mshowa
.5 .01472 m
.5 .02097 L
s
[(10)] .5 .00222 0 1 Mshowa
.7381 .01472 m
.7381 .02097 L
s
[(15)] .7381 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(20)] .97619 .00222 0 1 Mshowa
0 .01472 m
1 .01472 L
s
.02381 .13244 m
.03006 .13244 L
s
[(0.2)] .01131 .13244 1 0 Mshowa
.02381 .25016 m
.03006 .25016 L
s
[(0.4)] .01131 .25016 1 0 Mshowa
.02381 .36788 m
.03006 .36788 L
s
[(0.6)] .01131 .36788 1 0 Mshowa
.02381 .4856 m
.03006 .4856 L
s
[(0.8)] .01131 .4856 1 0 Mshowa
.02381 .60332 m
.03006 .60332 L
s
[(1)] .01131 .60332 1 0 Mshowa
.125 Mabswid
.02381 .04415 m
.02756 .04415 L
s
.02381 .07358 m
.02756 .07358 L
s
.02381 .10301 m
.02756 .10301 L
s
.02381 .16187 m
.02756 .16187 L
s
.02381 .1913 m
.02756 .1913 L
s
.02381 .22073 m
.02756 .22073 L
s
.02381 .27959 m
.02756 .27959 L
s
.02381 .30902 m
.02756 .30902 L
s
.02381 .33845 m
.02756 .33845 L
s
.02381 .39731 m
.02756 .39731 L
s
.02381 .42674 m
.02756 .42674 L
s
.02381 .45617 m
.02756 .45617 L
s
.02381 .51503 m
.02756 .51503 L
s
.02381 .54446 m
.02756 .54446 L
s
.02381 .57389 m
.02756 .57389 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -124 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.875 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 62.000000 16.875000 moveto
 460.000000 16.875000 lineto
 460.000000 4.000000 lineto
 62.000000 4.000000 lineto
 62.000000 16.875000 lineto
closepath
clip newpath
64.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
64.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Discrete) show
118.000000 13.000000 moveto
(Signal) show
160.000000 13.000000 moveto
(Plot) show
184.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
.00587 w
.02381 .01472 m
.02381 .02025 L
s
.01762 w
.02381 .02025 Mdot
.00587 w
.07143 .01472 m
.07143 .03835 L
s
.01762 w
.07143 .03835 Mdot
.00587 w
.11905 .01472 m
.11905 .07213 L
s
.01762 w
.11905 .07213 Mdot
.00587 w
.16667 .01472 m
.16667 .12443 L
s
.01762 w
.16667 .12443 Mdot
.00587 w
.21429 .01472 m
.21429 .19515 L
s
.01762 w
.21429 .19515 Mdot
.00587 w
.2619 .01472 m
.2619 .28046 L
s
.01762 w
.2619 .28046 Mdot
.00587 w
.30952 .01472 m
.30952 .37283 L
s
.01762 w
.30952 .37283 Mdot
.00587 w
.35714 .01472 m
.35714 .46194 L
s
.01762 w
.35714 .46194 Mdot
.00587 w
.40476 .01472 m
.40476 .53643 L
s
.01762 w
.40476 .53643 Mdot
.00587 w
.45238 .01472 m
.45238 .58595 L
s
.01762 w
.45238 .58595 Mdot
.00587 w
.5 .01472 m
.5 .60332 L
s
.01762 w
.5 .60332 Mdot
.00587 w
.54762 .01472 m
.54762 .58595 L
s
.01762 w
.54762 .58595 Mdot
.00587 w
.59524 .01472 m
.59524 .53643 L
s
.01762 w
.59524 .53643 Mdot
.00587 w
.64286 .01472 m
.64286 .46194 L
s
.01762 w
.64286 .46194 Mdot
.00587 w
.69048 .01472 m
.69048 .37283 L
s
.01762 w
.69048 .37283 Mdot
.00587 w
.7381 .01472 m
.7381 .28046 L
s
.01762 w
.7381 .28046 Mdot
.00587 w
.78571 .01472 m
.78571 .19515 L
s
.01762 w
.78571 .19515 Mdot
.00587 w
.83333 .01472 m
.83333 .12443 L
s
.01762 w
.83333 .12443 Mdot
.00587 w
.88095 .01472 m
.88095 .07213 L
s
.01762 w
.88095 .07213 Mdot
.00587 w
.92857 .01472 m
.92857 .03835 L
s
.01762 w
.92857 .03835 Mdot
.00587 w
.97619 .01472 m
.97619 .02025 L
s
.01762 w
.97619 .02025 Mdot
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  TextJustification->0,
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo001KOol0
0`00Oomoo`0dOol50002Ool00`00Oomoo`0`Ool50002Ool00`00Oomoo`0bOol30003Ool00`00Oomo
o`0?Ool005Yoo`03001oo`0003Moo`07001oogooOol007oo0000<goo00L007ooOomoo`00Ool0000c
Ool00`00Oomoo`02Ool00`00Ool0000@Ool005aoo`03001oogoo03Eoo`07001oogooOol007oo0000
<goo00<007ooOol00goo00<007ooOol0<Woo00L007ooOomoo`00Ool0000@Ool005Yoo`8003Qoo`07
001oogooOol007oo0000<goo00@007ooOomoo`8003Eoo`07001oogooOol007oo000047oo001JOol0
0`00Oomoo`0gOol01`00Oomoogoo001oo`0003=oo`05001oogooOol0000eOol00`00Ool00002Ool0
0`00Ool0000@Ool005Yoo`<003Ioo`8000Aoo`03001oogoo035oo`8000=oo`<003Aoo`03001oogoo
009oo`03001oogoo00moo`00ogoo8Goo000QOol00`00Oomoo`3lOol0025oo`03001oogoo0?aoo`00
8Goo00<007ooOol0o7oo000QOol00`00Oomoo`3lOol001]oooP000eoo`007goo10002Woo00<007oo
Ool02Goo00<007ooOol027oo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol02Goo00<007oo
Ool027oo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol027oo00<007oo
Ool02Goo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol027oo00<007ooOol02Goo00<007oo
Ool02Goo00<007ooOol02Goo00<007ooOol027oo00<007ooOol01goo10004Woo000OOol4000:Ool0
0`00Oomoo`09Ool00`00Oomoo`08Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`09Ool0
0`00Oomoo`08Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`08Ool0
0`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`08Ool00`00Oomoo`09Ool0
0`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`08Ool00`00Oomoo`07Ool4000BOol0021oo`80
00]oo`03001oogoo00Uoo`03001oogoo00Qoo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo
00Uoo`03001oogoo00Qoo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo
00Qoo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Qoo`03001oogoo
00Uoo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Qoo`03001oogoo00Qoo`8001=oo`00
8Goo00<007ooOol027oo0P002goo00<007ooOol027oo00<007ooOol02Goo00<007ooOol02Goo00<0
07ooOol02Goo00<007ooOol027oo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol02Goo00<0
07ooOol027oo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol027oo00<0
07ooOol02Goo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol027oo0P007Woo000QOol00`00
Oomoo`07Ool4000:Ool00`00Oomoo`08Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`09
Ool00`00Oomoo`08Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`08
Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`08Ool00`00Oomoo`09
Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`07Ool4000MOol0025oo`03001oogoo00Mo
o`@000Yoo`03001oogoo00Qoo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Uoo`03001o
ogoo00Qoo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Qoo`03001o
ogoo00Uoo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Qoo`03001oogoo00Uoo`03001o
ogoo00Uoo`03001oogoo00Uoo`03001oogoo00Moo`@001eoo`008Goo0P002Goo0P002goo00<007oo
Ool027oo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol027oo00<007oo
Ool02Goo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol027oo00<007ooOol02Goo00<007oo
Ool02Goo00<007ooOol02Goo00<007ooOol027oo00<007ooOol02Goo00<007ooOol02Goo00<007oo
Ool02Goo00<007ooOol027oo0P007Woo000QOol00`00Oomoo`0EOol00`00Oomoo`08Ool00`00Oomo
o`09Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`08Ool00`00Oomoo`09Ool00`00Oomo
o`09Ool00`00Oomoo`09Ool00`00Oomoo`08Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomo
o`09Ool00`00Oomoo`08Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomo
o`0XOol0025oo`03001oogoo01Eoo`03001oogoo00Qoo`03001oogoo00Uoo`03001oogoo00Uoo`03
001oogoo00Uoo`03001oogoo00Qoo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Uoo`03
001oogoo00Qoo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Qoo`03
001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo02Qoo`008Goo00<007ooOol0
5Goo00<007ooOol027oo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol0
27oo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol027oo00<007ooOol0
2Goo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol027oo00<007ooOol02Goo00<007ooOol0
2Goo00<007ooOol02Goo00<007ooOol0:7oo000QOol00`00Oomoo`0EOol00`00Oomoo`08Ool00`00
Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`08Ool00`00Oomoo`09Ool00`00
Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`08Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00
Oomoo`09Ool00`00Oomoo`08Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00
Oomoo`0XOol0025oo`03001oogoo01Aoo`8000Yoo`03001oogoo00Uoo`03001oogoo00Uoo`03001o
ogoo00Uoo`03001oogoo00Qoo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Uoo`03001o
ogoo00Qoo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Qoo`03001o
ogoo00Uoo`03001oogoo00Uoo`03001oogoo00Qoo`8002Yoo`008Goo00<007ooOol04goo10002Goo
00<007ooOol02Goo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol027oo00<007ooOol02Goo
00<007ooOol02Goo00<007ooOol02Goo00<007ooOol027oo00<007ooOol02Goo00<007ooOol02Goo
00<007ooOol02Goo00<007ooOol027oo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol01goo
1000:Goo000QOol2000DOol40009Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`09Ool0
0`00Oomoo`08Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`08Ool0
0`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`08Ool00`00Oomoo`09Ool0
0`00Oomoo`09Ool00`00Oomoo`07Ool4000YOol0025oo`03001oogoo01Aoo`8000Yoo`03001oogoo
00Uoo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Qoo`03001oogoo00Uoo`03001oogoo
00Uoo`03001oogoo00Uoo`03001oogoo00Qoo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo
00Uoo`03001oogoo00Qoo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Qoo`8002Yoo`00
8Goo00<007ooOol087oo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol0
27oo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol027oo00<007ooOol0
2Goo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol027oo00<007ooOol02Goo00<007ooOol0
2Goo00<007ooOol0=7oo000QOol00`00Oomoo`0POol00`00Oomoo`09Ool00`00Oomoo`09Ool00`00
Oomoo`09Ool00`00Oomoo`08Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00
Oomoo`08Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`08Ool00`00
Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`0dOol0025oo`03001oogoo021oo`03001oogoo00Uo
o`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Qoo`03001oogoo00Uoo`03001oogoo00Uo
o`03001oogoo00Uoo`03001oogoo00Qoo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Uo
o`03001oogoo00Qoo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo03Aoo`008Goo00<007oo
Ool087oo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol027oo00<007oo
Ool02Goo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol027oo00<007ooOol02Goo00<007oo
Ool02Goo00<007ooOol02Goo00<007ooOol027oo00<007ooOol02Goo00<007ooOol02Goo00<007oo
Ool0=7oo000QOol00`00Oomoo`0POol00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`09Ool0
0`00Oomoo`08Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`08Ool0
0`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`08Ool00`00Oomoo`09Ool0
0`00Oomoo`09Ool00`00Oomoo`0dOol0025oo`80025oo`03001oogoo00Uoo`03001oogoo00Uoo`03
001oogoo00Uoo`03001oogoo00Qoo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Uoo`03
001oogoo00Qoo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Qoo`03
001oogoo00Uoo`03001oogoo00Uoo`03001oogoo03Aoo`008Goo00<007ooOol087oo00<007ooOol0
2Goo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol027oo00<007ooOol02Goo00<007ooOol0
2Goo00<007ooOol02Goo00<007ooOol027oo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol0
2Goo00<007ooOol027oo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol0=7oo000QOol00`00
Oomoo`0POol00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`08Ool00`00
Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`08Ool00`00Oomoo`09Ool00`00
Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`08Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00
Oomoo`0dOol0025oo`03001oogoo021oo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Uo
o`03001oogoo00Qoo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Qo
o`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Qoo`03001oogoo00Uo
o`03001oogoo00Uoo`03001oogoo03Aoo`008Goo00<007ooOol087oo0P002Woo00<007ooOol02Goo
00<007ooOol02Goo00<007ooOol027oo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol02Goo
00<007ooOol027oo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol027oo
00<007ooOol02Goo00<007ooOol027oo0P00=Woo000QOol00`00Oomoo`0OOol40009Ool00`00Oomo
o`09Ool00`00Oomoo`09Ool00`00Oomoo`08Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomo
o`09Ool00`00Oomoo`08Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomo
o`08Ool00`00Oomoo`09Ool00`00Oomoo`07Ool4000eOol0015oo`03001oogoo009oo`04001oogoo
Ool30004Ool00`00Oomoo`0OOol40009Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`08
Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`08Ool00`00Oomoo`09
Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`08Ool00`00Oomoo`09Ool00`00Oomoo`07
Ool4000eOol0011oo`03001oo`0000Moo`03001oogoo00Aoo`03001oogoo021oo`8000Yoo`03001o
ogoo00Uoo`03001oogoo00Uoo`03001oogoo00Qoo`03001oogoo00Uoo`03001oogoo00Uoo`03001o
ogoo00Uoo`03001oogoo00Qoo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Uoo`03001o
ogoo00Qoo`03001oogoo00Uoo`03001oogoo00Qoo`8003Ioo`0047oo00<007oo000027oo00<007oo
Ool00goo0`00;7oo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol027oo00<007ooOol02Goo
00<007ooOol02Goo00<007ooOol02Goo00<007ooOol027oo00<007ooOol02Goo00<007ooOol02Goo
00<007ooOol02Goo00<007ooOol027oo00<007ooOol02Goo00<007ooOol0@7oo000@Ool00`00Ool0
0008Ool00`00Oomoo`03Ool00`00Oomoo`0/Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomo
o`08Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`08Ool00`00Oomo
o`09Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`08Ool00`00Oomoo`09Ool00`00Oomo
o`10Ool0011oo`03001oo`0000Moo`03001oo`0000Aoo`03001oogoo02aoo`03001oogoo00Uoo`03
001oogoo00Uoo`03001oogoo00Qoo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Uoo`03
001oogoo00Qoo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Qoo`03
001oogoo00Uoo`03001oogoo041oo`004Goo00<007ooOol01goo00<007ooOol00goo00<007ooOol0
;7oo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol027oo00<007ooOol02Goo00<007ooOol0
2Goo00<007ooOol02Goo00<007ooOol027oo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol0
2Goo00<007ooOol027oo00<007ooOol02Goo00<007ooOol0@7oo000QOol00`00Oomoo`0/Ool00`00
Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`08Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00
Oomoo`09Ool00`00Oomoo`08Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00
Oomoo`08Ool00`00Oomoo`09Ool00`00Oomoo`10Ool0025oo`03001oogoo02aoo`03001oogoo00Uo
o`03001oogoo00Uoo`03001oogoo00Qoo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Uo
o`03001oogoo00Qoo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Qo
o`03001oogoo00Uoo`03001oogoo041oo`008Goo00<007ooOol0;7oo00<007ooOol02Goo00<007oo
Ool02Goo00<007ooOol027oo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol02Goo00<007oo
Ool027oo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol027oo00<007oo
Ool02Goo00<007ooOol0@7oo000QOol2000]Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomo
o`08Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`08Ool00`00Oomo
o`09Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`08Ool00`00Oomoo`09Ool00`00Oomo
o`10Ool0025oo`03001oogoo02aoo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Qoo`03
001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Qoo`03001oogoo00Uoo`03
001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Qoo`03001oogoo00Uoo`03001oogoo041oo`00
8Goo00<007ooOol0;7oo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol027oo00<007ooOol0
2Goo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol027oo00<007ooOol02Goo00<007ooOol0
2Goo00<007ooOol02Goo00<007ooOol027oo00<007ooOol02Goo00<007ooOol0@7oo000QOol00`00
Oomoo`0/Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`08Ool00`00Oomoo`09Ool00`00
Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`08Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00
Oomoo`09Ool00`00Oomoo`08Ool00`00Oomoo`09Ool00`00Oomoo`10Ool0025oo`03001oogoo02ao
o`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Qoo`03001oogoo00Uoo`03001oogoo00Uo
o`03001oogoo00Uoo`03001oogoo00Qoo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Uo
o`03001oogoo00Qoo`03001oogoo00Uoo`03001oogoo041oo`008Goo00<007ooOol0;7oo00<007oo
Ool02Goo00<007ooOol02Goo00<007ooOol027oo00<007ooOol02Goo00<007ooOol02Goo00<007oo
Ool02Goo00<007ooOol027oo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol02Goo00<007oo
Ool027oo00<007ooOol02Goo00<007ooOol0@7oo000QOol00`00Oomoo`0/Ool00`00Oomoo`09Ool0
0`00Oomoo`09Ool00`00Oomoo`08Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`09Ool0
0`00Oomoo`08Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`08Ool0
0`00Oomoo`09Ool00`00Oomoo`10Ool0025oo`8002aoo`8000]oo`03001oogoo00Uoo`03001oogoo
00Qoo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Qoo`03001oogoo
00Uoo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Qoo`03001oogoo00Qoo`80049oo`00
8Goo00<007ooOol0:Woo10002Woo00<007ooOol02Goo00<007ooOol027oo00<007ooOol02Goo00<0
07ooOol02Goo00<007ooOol02Goo00<007ooOol027oo00<007ooOol02Goo00<007ooOol02Goo00<0
07ooOol02Goo00<007ooOol027oo00<007ooOol01goo1000@Goo000QOol00`00Oomoo`0ZOol4000:
Ool00`00Oomoo`09Ool00`00Oomoo`08Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`09
Ool00`00Oomoo`08Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`08
Ool00`00Oomoo`07Ool40011Ool0025oo`03001oogoo02]oo`8000]oo`03001oogoo00Uoo`03001o
ogoo00Qoo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Qoo`03001o
ogoo00Uoo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Qoo`03001oogoo00Qoo`80049o
o`008Goo00<007ooOol0>7oo00<007ooOol02Goo00<007ooOol027oo00<007ooOol02Goo00<007oo
Ool02Goo00<007ooOol02Goo00<007ooOol027oo00<007ooOol02Goo00<007ooOol02Goo00<007oo
Ool02Goo00<007ooOol027oo00<007ooOol0C7oo000QOol00`00Oomoo`0hOol00`00Oomoo`09Ool0
0`00Oomoo`08Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`08Ool0
0`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`08Ool00`00Oomoo`1<Ool0
025oo`03001oogoo03Qoo`03001oogoo00Uoo`03001oogoo00Qoo`03001oogoo00Uoo`03001oogoo
00Uoo`03001oogoo00Uoo`03001oogoo00Qoo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo
00Uoo`03001oogoo00Qoo`03001oogoo04aoo`008Goo0P00>Goo00<007ooOol02Goo00<007ooOol0
27oo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol027oo00<007ooOol0
2Goo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol027oo00<007ooOol0C7oo000QOol00`00
Oomoo`0hOol00`00Oomoo`09Ool00`00Oomoo`08Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00
Oomoo`09Ool00`00Oomoo`08Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00
Oomoo`08Ool00`00Oomoo`1<Ool0025oo`03001oogoo03Qoo`03001oogoo00Uoo`03001oogoo00Qo
o`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Qoo`03001oogoo00Uo
o`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Qoo`03001oogoo04aoo`008Goo00<007oo
Ool0>7oo00<007ooOol02Goo00<007ooOol027oo00<007ooOol02Goo00<007ooOol02Goo00<007oo
Ool02Goo00<007ooOol027oo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol02Goo00<007oo
Ool027oo00<007ooOol0C7oo000QOol00`00Oomoo`0hOol00`00Oomoo`09Ool00`00Oomoo`08Ool0
0`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`08Ool00`00Oomoo`09Ool0
0`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`08Ool00`00Oomoo`1<Ool0025oo`03001oogoo
03Qoo`03001oogoo00Uoo`03001oogoo00Qoo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo
00Uoo`03001oogoo00Qoo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo
00Qoo`03001oogoo04aoo`004Goo00<007ooOol00Woo00<007ooOol00Woo0`000goo00<007ooOol0
>7oo00<007ooOol02Goo00<007ooOol027oo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol0
2Goo00<007ooOol027oo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol0
27oo00<007ooOol0C7oo000@Ool00`00Ool00009Ool00`00Oomoo`02Ool00`00Oomoo`0hOol00`00
Oomoo`09Ool00`00Oomoo`08Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00
Oomoo`08Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`08Ool00`00
Oomoo`1<Ool0011oo`03001oo`0000Moo`@000=oo`<003Qoo`03001oogoo00Uoo`03001oogoo00Qo
o`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Qoo`03001oogoo00Uo
o`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Qoo`03001oogoo04aoo`0047oo00<007oo
00001goo00<007oo000017oo00<007ooOol0>7oo00<007ooOol02Goo00<007ooOol027oo00<007oo
Ool02Goo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol027oo00<007ooOol02Goo00<007oo
Ool02Goo00<007ooOol02Goo00<007ooOol027oo00<007ooOol0C7oo000@Ool00`00Ool00008Ool2
0004Ool00`00Oomoo`0hOol00`00Oomoo`09Ool00`00Oomoo`08Ool00`00Oomoo`09Ool00`00Oomo
o`09Ool00`00Oomoo`09Ool00`00Oomoo`08Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomo
o`09Ool00`00Oomoo`08Ool00`00Oomoo`1<Ool0015oo`03001oogoo00Qoo`03001oogoo009oo`03
001oogoo03Qoo`03001oogoo00Uoo`03001oogoo00Qoo`03001oogoo00Uoo`03001oogoo00Uoo`03
001oogoo00Uoo`03001oogoo00Qoo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Uoo`03
001oogoo00Qoo`03001oogoo04aoo`008Goo00<007ooOol0>7oo00<007ooOol02Goo00<007ooOol0
27oo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol027oo00<007ooOol0
2Goo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol027oo00<007ooOol0C7oo000QOol00`00
Oomoo`0hOol00`00Oomoo`09Ool00`00Oomoo`08Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00
Oomoo`09Ool00`00Oomoo`08Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00
Oomoo`08Ool00`00Oomoo`1<Ool0025oo`03001oogoo03Moo`8000]oo`03001oogoo00Qoo`03001o
ogoo00Uoo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Qoo`03001oogoo00Uoo`03001o
ogoo00Uoo`03001oogoo00Uoo`03001oogoo00Qoo`8004eoo`008Goo0P00=goo10002Woo00<007oo
Ool027oo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol027oo00<007oo
Ool02Goo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol01goo1000C7oo000QOol00`00Oomo
o`0fOol4000:Ool00`00Oomoo`08Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`09Ool0
0`00Oomoo`08Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`07Ool4
001<Ool0025oo`03001oogoo03Moo`8000]oo`03001oogoo00Qoo`03001oogoo00Uoo`03001oogoo
00Uoo`03001oogoo00Uoo`03001oogoo00Qoo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo
00Uoo`03001oogoo00Qoo`8004eoo`008Goo00<007ooOol0A7oo00<007ooOol027oo00<007ooOol0
2Goo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol027oo00<007ooOol02Goo00<007ooOol0
2Goo00<007ooOol02Goo00<007ooOol0Egoo000QOol00`00Oomoo`14Ool00`00Oomoo`08Ool00`00
Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`08Ool00`00Oomoo`09Ool00`00
Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`1GOol0025oo`03001oogoo04Aoo`03001oogoo00Qo
o`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Qoo`03001oogoo00Uo
o`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo05Moo`008Goo00<007ooOol0A7oo00<007oo
Ool027oo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol027oo00<007oo
Ool02Goo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol0Egoo000QOol20015Ool00`00Oomo
o`08Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`08Ool00`00Oomo
o`09Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`1GOol0025oo`03001oogoo04Aoo`03
001oogoo00Qoo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Qoo`03
001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo05Moo`008Goo00<007ooOol0
A7oo00<007ooOol027oo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol0
27oo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol0Egoo000QOol00`00
Oomoo`14Ool00`00Oomoo`08Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00
Oomoo`08Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`1GOol0025o
o`03001oogoo04Aoo`03001oogoo00Qoo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Uo
o`03001oogoo00Qoo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo05Mo
o`008Goo00<007ooOol0A7oo00<007ooOol027oo00<007ooOol02Goo00<007ooOol02Goo00<007oo
Ool02Goo00<007ooOol027oo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol02Goo00<007oo
Ool0Egoo000QOol00`00Oomoo`14Ool00`00Oomoo`08Ool00`00Oomoo`09Ool00`00Oomoo`09Ool0
0`00Oomoo`09Ool00`00Oomoo`08Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`09Ool0
0`00Oomoo`1GOol0025oo`03001oogoo04Aoo`03001oogoo00Qoo`03001oogoo00Uoo`03001oogoo
00Uoo`03001oogoo00Uoo`03001oogoo00Qoo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo
00Uoo`03001oogoo05Moo`008Goo0P00AGoo00<007ooOol027oo00<007ooOol02Goo00<007ooOol0
2Goo00<007ooOol02Goo00<007ooOol027oo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol0
2Goo00<007ooOol0Egoo000QOol00`00Oomoo`14Ool00`00Oomoo`08Ool00`00Oomoo`09Ool00`00
Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`08Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00
Oomoo`09Ool00`00Oomoo`1GOol0025oo`03001oogoo04Aoo`03001oogoo00Qoo`03001oogoo00Uo
o`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Qoo`03001oogoo00Uoo`03001oogoo00Uo
o`03001oogoo00Uoo`03001oogoo05Moo`008Goo00<007ooOol0A7oo00<007ooOol027oo00<007oo
Ool02Goo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol027oo00<007ooOol02Goo00<007oo
Ool02Goo00<007ooOol02Goo00<007ooOol0Egoo000QOol00`00Oomoo`14Ool00`00Oomoo`08Ool0
0`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`08Ool00`00Oomoo`09Ool0
0`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`1GOol0015oo`03001oogoo009oo`04001oogoo
Ool20005Ool00`00Oomoo`14Ool00`00Oomoo`08Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00
Oomoo`09Ool00`00Oomoo`08Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00
Oomoo`1GOol0011oo`03001oo`0000Moo`03001oo`0000Aoo`03001oogoo04Aoo`03001oogoo00Qo
o`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Qoo`03001oogoo00Uo
o`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo05Moo`0047oo00<007oo00001goo00<007oo
000017oo0`00@goo0P002Woo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol02Goo00<007oo
Ool027oo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol027oo0P00FGoo000@Ool00`00Ool0
0007Ool20005Ool00`00Oomoo`12Ool40009Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomo
o`09Ool00`00Oomoo`08Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`07Ool4001HOol0
011oo`03001oo`0000Moo`03001oogoo00Aoo`03001oogoo049oo`@000Uoo`03001oogoo00Uoo`03
001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Qoo`03001oogoo00Uoo`03001oogoo00Uoo`03
001oogoo00Moo`@005Qoo`004Goo00<007ooOol01goo0P0017oo00<007ooOol0@goo0P002Woo00<0
07ooOol02Goo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol027oo00<007ooOol02Goo00<0
07ooOol02Goo00<007ooOol027oo0P00FGoo000QOol00`00Oomoo`1?Ool00`00Oomoo`09Ool00`00
Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`08Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00
Oomoo`1SOol0025oo`03001oogoo04moo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Uo
o`03001oogoo00Qoo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo06=oo`008Goo00<007oo
Ool0Cgoo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol027oo00<007oo
Ool02Goo00<007ooOol02Goo00<007ooOol0Hgoo000QOol2001@Ool00`00Oomoo`09Ool00`00Oomo
o`09Ool00`00Oomoo`09Ool00`00Oomoo`08Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomo
o`1SOol0025oo`03001oogoo04moo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Uoo`03
001oogoo00Qoo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo06=oo`008Goo00<007ooOol0
Cgoo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol027oo00<007ooOol0
2Goo00<007ooOol02Goo00<007ooOol0Hgoo000QOol00`00Oomoo`1?Ool00`00Oomoo`09Ool00`00
Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`08Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00
Oomoo`1SOol0025oo`03001oogoo04moo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Uo
o`03001oogoo00Qoo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo06=oo`008Goo00<007oo
Ool0Cgoo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol027oo00<007oo
Ool02Goo00<007ooOol02Goo00<007ooOol0Hgoo000QOol00`00Oomoo`1?Ool00`00Oomoo`09Ool0
0`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`08Ool00`00Oomoo`09Ool00`00Oomoo`09Ool0
0`00Oomoo`1SOol0025oo`80051oo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Uoo`03
001oogoo00Qoo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo06=oo`008Goo00<007ooOol0
Cgoo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol027oo00<007ooOol0
2Goo00<007ooOol02Goo00<007ooOol0Hgoo000QOol00`00Oomoo`1?Ool00`00Oomoo`09Ool00`00
Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`08Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00
Oomoo`1SOol0025oo`03001oogoo04moo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Uo
o`03001oogoo00Qoo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo06=oo`008Goo00<007oo
Ool0Cgoo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol027oo00<007oo
Ool02Goo00<007ooOol02Goo00<007ooOol0Hgoo000QOol00`00Oomoo`1?Ool00`00Oomoo`09Ool0
0`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`08Ool00`00Oomoo`09Ool00`00Oomoo`09Ool0
0`00Oomoo`1SOol0025oo`03001oogoo04moo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo
00Uoo`03001oogoo00Qoo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo06=oo`008Goo00<0
07ooOol0Cgoo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol027oo00<0
07ooOol02Goo00<007ooOol02Goo00<007ooOol0Hgoo000QOol2001@Ool2000:Ool00`00Oomoo`09
Ool00`00Oomoo`09Ool00`00Oomoo`08Ool00`00Oomoo`09Ool00`00Oomoo`08Ool2001UOol0025o
o`03001oogoo04ioo`@000Uoo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Qoo`03001o
ogoo00Uoo`03001oogoo00Moo`@006Aoo`008Goo00<007ooOol0CWoo10002Goo00<007ooOol02Goo
00<007ooOol02Goo00<007ooOol027oo00<007ooOol02Goo00<007ooOol01goo1000I7oo000QOol0
0`00Oomoo`1?Ool2000:Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`08Ool00`00Oomo
o`09Ool00`00Oomoo`08Ool2001UOol0025oo`03001oogoo05]oo`03001oogoo00Uoo`03001oogoo
00Uoo`03001oogoo00Qoo`03001oogoo00Uoo`03001oogoo06moo`004Goo00<007ooOol00Woo00<0
07ooOol00Woo00<007ooOol00goo00<007ooOol0Fgoo00<007ooOol02Goo00<007ooOol02Goo00<0
07ooOol027oo00<007ooOol02Goo00<007ooOol0Kgoo000@Ool00`00Ool00007Ool00`00Ool00004
Ool00`00Oomoo`1KOol00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`08Ool00`00Oomoo`09
Ool00`00Oomoo`1_Ool0011oo`03001oo`0000Moo`03001oo`0000Aoo`<005]oo`03001oogoo00Uo
o`03001oogoo00Uoo`03001oogoo00Qoo`03001oogoo00Uoo`03001oogoo06moo`0047oo00<007oo
000027oo00<007ooOol00goo00<007ooOol0Fgoo00<007ooOol02Goo00<007ooOol02Goo00<007oo
Ool027oo00<007ooOol02Goo00<007ooOol0Kgoo000@Ool00`00Ool00007Ool00`00Ool00004Ool0
0`00Oomoo`1KOol00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`08Ool00`00Oomoo`09Ool0
0`00Oomoo`1_Ool0015oo`03001oogoo00Moo`03001oogoo00=oo`03001oogoo05]oo`03001oogoo
00Uoo`03001oogoo00Uoo`03001oogoo00Qoo`03001oogoo00Uoo`03001oogoo06moo`008Goo00<0
07ooOol0Fgoo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol027oo00<007ooOol02Goo00<0
07ooOol0Kgoo000QOol00`00Oomoo`1KOol00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`08
Ool00`00Oomoo`09Ool00`00Oomoo`1_Ool0025oo`03001oogoo05]oo`03001oogoo00Uoo`03001o
ogoo00Uoo`03001oogoo00Qoo`03001oogoo00Uoo`03001oogoo06moo`008Goo0P00G7oo00<007oo
Ool02Goo00<007ooOol02Goo00<007ooOol027oo00<007ooOol02Goo00<007ooOol0Kgoo000QOol0
0`00Oomoo`1KOol00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`08Ool00`00Oomoo`09Ool0
0`00Oomoo`1_Ool0025oo`03001oogoo05]oo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo
00Qoo`03001oogoo00Uoo`03001oogoo06moo`008Goo00<007ooOol0Fgoo00<007ooOol02Goo00<0
07ooOol02Goo00<007ooOol027oo00<007ooOol02Goo00<007ooOol0Kgoo000QOol00`00Oomoo`1J
Ool2000;Ool00`00Oomoo`09Ool00`00Oomoo`08Ool00`00Oomoo`08Ool2001aOol0025oo`03001o
ogoo05Uoo`@000Yoo`03001oogoo00Uoo`03001oogoo00Qoo`03001oogoo00Moo`@0071oo`008Goo
00<007ooOol0FGoo10002Woo00<007ooOol02Goo00<007ooOol027oo00<007ooOol01goo1000L7oo
000QOol2001KOol2000;Ool00`00Oomoo`09Ool00`00Oomoo`08Ool00`00Oomoo`08Ool2001aOol0
025oo`03001oogoo06Moo`03001oogoo00Uoo`03001oogoo00Qoo`03001oogoo07]oo`008Goo00<0
07ooOol0Igoo00<007ooOol02Goo00<007ooOol027oo00<007ooOol0Ngoo000QOol00`00Oomoo`1W
Ool00`00Oomoo`09Ool00`00Oomoo`08Ool00`00Oomoo`1kOol0025oo`03001oogoo06Moo`03001o
ogoo00Uoo`03001oogoo00Qoo`03001oogoo07]oo`008Goo00<007ooOol0Igoo00<007ooOol02Goo
00<007ooOol027oo00<007ooOol0Ngoo000QOol00`00Oomoo`1WOol00`00Oomoo`09Ool00`00Oomo
o`08Ool00`00Oomoo`1kOol0025oo`03001oogoo06Moo`03001oogoo00Uoo`03001oogoo00Qoo`03
001oogoo07]oo`008Goo0P00J7oo00<007ooOol02Goo00<007ooOol027oo00<007ooOol0Ngoo000Q
Ool00`00Oomoo`1VOol2000;Ool00`00Oomoo`08Ool2001lOol0025oo`03001oogoo06Eoo`@000Yo
o`03001oogoo00Moo`@007]oo`008Goo00<007ooOol0IGoo10002Woo00<007ooOol01goo1000Ngoo
000QOol00`00Oomoo`1VOol2000;Ool00`00Oomoo`08Ool2001lOol001Uoo`D000=oo`03001oogoo
07=oo`03001oogoo08Ioo`006goo00<007ooOol00goo00<007ooOol0LWoo0P00R7oo000KOol00`00
Oomoo`03Ool3001aOol40027Ool001]oo`03001oogoo00=oo`03001oogoo075oo`@008Moo`006goo
00<007ooOol00goo00<007ooOol0LWoo0P00R7oo000JOol20005Ool00`00Oomoo`3lOol0025oo`03
001oogoo0?aoo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo002MOol20021Ool009moo`03
001oogoo07ioo`00Fgoo10000Woo0`000Woo0P000goo0`000Woo0`000goo0P000goo0P000goo0P00
47oo0`000Woo0`000goo1@000Woo00<007oo00000`0000Aoo`00000000eoo`<000=oo`<000=oo`80
00=oo`80059oo`00G7oo00@007ooOol0009oo`03001oogoo00=oo`04001oogoo0005Ool01@00Oomo
ogoo000017oo00H007ooOol007oo000BOol00`00Ool00003Ool01@00Oomoogoo00000Woo00<007oo
00000Woo00<007oo00000P000goo00<007ooOol03Goo00<007ooOol00goo00D007ooOomoo`00009o
o`03001oo`00009oo`03001oogoo04moo`00G7oo00@007ooOol0009oo`03001oogoo009oo`05001o
ogooOol00005Ool01000Oomoogoo0`000Woo00<007ooOol00Woo0`004Woo00D007ooOomoo`0000=o
o`06001oogoo001oo`000Woo00D007ooOomoo`0000=oo`03001oogoo00eoo`<000=oo`05001oogoo
Ool00002Ool00`00Ool0001DOol005aoo`05001oogoo001oo`020004Ool20002Ool30002Ool40000
1Goo00000000Ool010000Woo0`004Goo00@007ooOomoo`8000Aoo`L000=oo`8000=oo`03001oogoo
00eoo`04001oogoo0002Ool00`00Oomoo`02Ool200000goo00000002001BOol005aoo`04001oogoo
000JOol00`00Oomoo`0EOol00`00Ool0000GOol00`00Oomoo`0=Ool01000Oomoo`000Woo00<007oo
Ool01Woo00<007ooOol0DWoo001KOol40003Ool00`00Oomoo`0]Ool30003Ool00`00Oomoo`0@Ool2
000>Ool40002Ool2001MOol00?moob5oo`00ogoo8Goo003oOolQOol00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-2.85257, -0.0831908, 
  0.0850925, 0.00688412}}]
}, Open  ]],

Cell["An ideal halfband lowpass filter is given by ", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(InverseDiscreteTimeFourierTransform[\n\t
      ContinuousPulse[\[Pi], \[CapitalOmega] + 0.5  \[Pi]], \[CapitalOmega], 
      n]\)], "Input",
  TextJustification->0],

Cell[BoxData[
    \(1\/2\ E\^\(0.`\ I\ n\)\ Sinc[\(n\ \[Pi]\)\/2]\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(h = 
      \(Table[%, {n, \(-\(\(L - 1\)\/2\)\), \(L - 1\)\/2}]\  // Chop\)\  // N
        \)], "Input",
  TextJustification->0],

Cell[BoxData[
    \({0, 0.0353677651315323027`, 0, \(-0.0454728408833986641`\), 0, 
      0.0636619772367581404`, 0, \(-0.106103295394596885`\), 0, 
      0.318309886183790702`, 0.5`, 0.318309886183790702`, 0, 
      \(-0.106103295394596885`\), 0, 0.0636619772367581404`, 0, 
      \(-0.0454728408833986641`\), 0, 0.0353677651315323027`, 0}\)], "Output"]
}, Open  ]],

Cell["\<\
A product of the two sequences gives the desired impulse response.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(w2*h\)], "Input"],

Cell[BoxData[
    \({0, 0.00142040808988524798`, 0, \(-0.0084763061211426347`\), 0, 
      0.0287419759518072215`, 0, \(-0.0806185807282610511`\), 0, 
      0.308917396692191914`, 0.5`, 0.308917396692191914`, 0, 
      \(-0.0806185807282610511`\), 0, 0.0287419759518072215`, 0, 
      \(-0.0084763061211426347`\), 0, 0.00142040808988524798`, 0}\)], "Output"]
}, Open  ]],

Cell["Verify the frequency domain characteristics of the filter.", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(H = Abs[InverseFourier[\n\t\t\t\t\tJoin[h*w2, Table[0, {256 - L}]]]\ ]; 
    \nListPlot[\n\t20\ Log[10, Drop[H/Max[H], \(-128\)]], PlotJoined -> True\n
      \t]; \)], "Input",
  TextJustification->0],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00744048 0.603319 0.00587725 [
[.17262 .59082 -6 -9 ]
[.17262 .59082 6 0 ]
[.32143 .59082 -6 -9 ]
[.32143 .59082 6 0 ]
[.47024 .59082 -6 -9 ]
[.47024 .59082 6 0 ]
[.61905 .59082 -6 -9 ]
[.61905 .59082 6 0 ]
[.76786 .59082 -9 -9 ]
[.76786 .59082 9 0 ]
[.91667 .59082 -9 -9 ]
[.91667 .59082 9 0 ]
[.01131 .01559 -24 -4.5 ]
[.01131 .01559 0 4.5 ]
[.01131 .13314 -18 -4.5 ]
[.01131 .13314 0 4.5 ]
[.01131 .25068 -18 -4.5 ]
[.01131 .25068 0 4.5 ]
[.01131 .36823 -18 -4.5 ]
[.01131 .36823 0 4.5 ]
[.01131 .48577 -18 -4.5 ]
[.01131 .48577 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.17262 .60332 m
.17262 .60957 L
s
[(20)] .17262 .59082 0 1 Mshowa
.32143 .60332 m
.32143 .60957 L
s
[(40)] .32143 .59082 0 1 Mshowa
.47024 .60332 m
.47024 .60957 L
s
[(60)] .47024 .59082 0 1 Mshowa
.61905 .60332 m
.61905 .60957 L
s
[(80)] .61905 .59082 0 1 Mshowa
.76786 .60332 m
.76786 .60957 L
s
[(100)] .76786 .59082 0 1 Mshowa
.91667 .60332 m
.91667 .60957 L
s
[(120)] .91667 .59082 0 1 Mshowa
.125 Mabswid
.06101 .60332 m
.06101 .60707 L
s
.09821 .60332 m
.09821 .60707 L
s
.13542 .60332 m
.13542 .60707 L
s
.20982 .60332 m
.20982 .60707 L
s
.24702 .60332 m
.24702 .60707 L
s
.28423 .60332 m
.28423 .60707 L
s
.35863 .60332 m
.35863 .60707 L
s
.39583 .60332 m
.39583 .60707 L
s
.43304 .60332 m
.43304 .60707 L
s
.50744 .60332 m
.50744 .60707 L
s
.54464 .60332 m
.54464 .60707 L
s
.58185 .60332 m
.58185 .60707 L
s
.65625 .60332 m
.65625 .60707 L
s
.69345 .60332 m
.69345 .60707 L
s
.73065 .60332 m
.73065 .60707 L
s
.80506 .60332 m
.80506 .60707 L
s
.84226 .60332 m
.84226 .60707 L
s
.87946 .60332 m
.87946 .60707 L
s
.95387 .60332 m
.95387 .60707 L
s
.99107 .60332 m
.99107 .60707 L
s
.25 Mabswid
0 .60332 m
1 .60332 L
s
.02381 .01559 m
.03006 .01559 L
s
[(-100)] .01131 .01559 1 0 Mshowa
.02381 .13314 m
.03006 .13314 L
s
[(-80)] .01131 .13314 1 0 Mshowa
.02381 .25068 m
.03006 .25068 L
s
[(-60)] .01131 .25068 1 0 Mshowa
.02381 .36823 m
.03006 .36823 L
s
[(-40)] .01131 .36823 1 0 Mshowa
.02381 .48577 m
.03006 .48577 L
s
[(-20)] .01131 .48577 1 0 Mshowa
.125 Mabswid
.02381 .04498 m
.02756 .04498 L
s
.02381 .07437 m
.02756 .07437 L
s
.02381 .10375 m
.02756 .10375 L
s
.02381 .16252 m
.02756 .16252 L
s
.02381 .19191 m
.02756 .19191 L
s
.02381 .2213 m
.02756 .2213 L
s
.02381 .28007 m
.02756 .28007 L
s
.02381 .30946 m
.02756 .30946 L
s
.02381 .33884 m
.02756 .33884 L
s
.02381 .39762 m
.02756 .39762 L
s
.02381 .427 m
.02756 .427 L
s
.02381 .45639 m
.02756 .45639 L
s
.02381 .51516 m
.02756 .51516 L
s
.02381 .54455 m
.02756 .54455 L
s
.02381 .57393 m
.02756 .57393 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.03125 .60329 m
.03869 .60329 L
.04613 .60329 L
.05357 .60329 L
.06101 .60329 L
.06845 .60329 L
.07589 .60329 L
.08333 .60329 L
.09077 .60329 L
.09821 .60329 L
.10565 .60329 L
.1131 .6033 L
.12054 .6033 L
.12798 .6033 L
.13542 .6033 L
.14286 .6033 L
.1503 .6033 L
.15774 .6033 L
.16518 .6033 L
.17262 .6033 L
.18006 .6033 L
.1875 .60329 L
.19494 .60329 L
.20238 .60329 L
.20982 .60328 L
.21726 .60328 L
.2247 .60328 L
.23214 .60328 L
.23958 .60328 L
.24702 .60329 L
.25446 .60329 L
.2619 .6033 L
.26935 .60331 L
.27679 .60331 L
.28423 .60332 L
.29167 .60332 L
.29911 .60331 L
.30655 .60329 L
.31399 .60325 L
.32143 .60319 L
.32887 .6031 L
.33631 .60297 L
.34375 .6028 L
.35119 .60257 L
.35863 .60229 L
.36607 .60193 L
.37351 .6015 L
.38095 .60097 L
.38839 .60035 L
.39583 .59961 L
Mistroke
.40327 .59875 L
.41071 .59776 L
.41815 .59662 L
.4256 .59533 L
.43304 .59388 L
.44048 .59225 L
.44792 .59043 L
.45536 .58842 L
.4628 .5862 L
.47024 .58377 L
.47768 .5811 L
.48512 .57819 L
.49256 .57503 L
.5 .57161 L
.50744 .56791 L
.51488 .56392 L
.52232 .55963 L
.52976 .55502 L
.5372 .55008 L
.54464 .54479 L
.55208 .53912 L
.55952 .53308 L
.56696 .52662 L
.5744 .51972 L
.58185 .51236 L
.58929 .5045 L
.59673 .49612 L
.60417 .48715 L
.61161 .47756 L
.61905 .46728 L
.62649 .45623 L
.63393 .44434 L
.64137 .43148 L
.64881 .4175 L
.65625 .40221 L
.66369 .38532 L
.67113 .36643 L
.67857 .34488 L
.68601 .31952 L
.69345 .28798 L
.70089 .24355 L
.70833 .13765 L
.71577 .19129 L
.72321 .21414 L
.73065 .21515 L
.7381 .20465 L
.74554 .18213 L
.75298 .13419 L
.76042 .09212 L
.76786 .15804 L
Mistroke
.7753 .17861 L
.78274 .18663 L
.79018 .1875 L
.79762 .18277 L
.80506 .17245 L
.8125 .15504 L
.81994 .1251 L
.82738 .04823 L
.83482 .08625 L
.84226 .12601 L
.8497 .14237 L
.85714 .14948 L
.86458 .15086 L
.87202 .14772 L
.87946 .14035 L
.8869 .12831 L
.89435 .11009 L
.90179 .08133 L
.90923 .02115 L
.91667 .01472 L
.92411 .06368 L
.93155 .08101 L
.93899 .088 L
.94643 .08936 L
.95387 .08713 L
.96131 .08275 L
.96875 .07768 L
.97619 .07359 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`006goo00<007ooOol0ogoo0goo000KOol0
0`00Oomoo`3oOol3Ool000Uoo`D0009oo`03001oogoo009oo`03001oogoo00=oo`03001oogoo0?mo
o`=oo`002goo00L007ooOomoo`00Ool00002Ool00`00Ool00004Ool00`00Oomoo`3oOol3Ool000Eo
o`<000=oo`07001oogooOol007oo00000Woo00<007oo000017oo0P00jgoo00<007ooOol05Goo000;
Ool01`00Oomoogoo001oo`00009oo`03001oo`0000Aoo`03001oogoo0>Uoo`8001Moo`002goo00L0
07ooOomoo`00Ool00002Ool00`00Ool00004Ool00`00Oomoo`3XOol00`00Ool0000GOol000Yoo`80
00Aoo`03001oogoo009oo`03001oogoo00=oo`03001oogoo0>Qoo`03001oo`0001Moo`006goo00<0
07ooOol0j7oo00@007ooOol001Ioo`006goo00<007ooOol0j7oo00@007ooOol001Ioo`006goo00<0
07ooOol0igoo00D007ooOomoo`0001Ioo`006goo00<007ooOol0igoo00D007ooOomoo`0001Ioo`00
6goo0P00j7oo00D007ooOomoo`0001Ioo`006goo00<007ooOol0dgoo00<007ooOol04Goo00D007oo
Oomoo`0001Ioo`006goo00<007ooOol0dgoo00<007ooOol04Goo00<007ooOol00Woo00<007ooOol0
4goo000KOol00`00Oomoo`3COol00`00Oomoo`0AOol00`00Oomoo`02Ool00`00Oomoo`0COol001]o
o`03001oogoo0==oo`80019oo`03001oogoo009oo`03001oogoo01=oo`006goo00<007ooOol0dgoo
0P004Woo00<007ooOol00Woo00<007ooOol04goo000KOol00`00Oomoo`3BOol00`00Ool0000AOol0
0`00Oomoo`03Ool00`00Oomoo`0COol001]oo`03001oogoo0=9oo`03001oo`00015oo`03001oogoo
00Aoo`03001oogoo019oo`006goo0P00dgoo00<007oo00004Goo00<007ooOol017oo00<007ooOol0
2Woo00<007ooOol01Goo000KOol00`00Oomoo`3BOol01000Oomoo`0047oo00<007ooOol01Goo00<0
07ooOol01goo0P0027oo000KOol00`00Oomoo`3BOol01000Oomoo`0047oo00<007ooOol01Goo00<0
07ooOol01Goo0P002Woo000KOol00`00Oomoo`3BOol01000Oomoo`0047oo00<007ooOol01Woo0P00
0goo0P0037oo000KOol00`00Oomoo`3BOol01000Oomoo`003goo00<007ooOol02Goo0`003Woo000K
Ool00`00Oomoo`31Ool00`00Oomoo`0>Ool01000Oomoo`003goo00<007ooOol06Woo000KOol00`00
Oomoo`31Ool00`00Oomoo`0>Ool01@00Oomoogoo00003Woo00<007ooOol06Woo000KOol00`00Oomo
o`31Ool00`00Oomoo`0>Ool01@00Oomoogoo00003Woo00<007ooOol06Woo000KOol20031Ool2000?
Ool00`00Oomoo`02Ool00`00Oomoo`0;Ool00`00Oomoo`0KOol001]oo`03001oogoo0<1oo`8000mo
o`03001oogoo009oo`03001oogoo00]oo`03001oogoo01]oo`006goo00<007ooOol0`7oo00<007oo
00003Woo00<007ooOol00Woo00<007ooOol02goo00<007ooOol06goo000KOol00`00Oomoo`30Ool0
0`00Ool0000>Ool00`00Oomoo`02Ool00`00Oomoo`0:Ool00`00Oomoo`0LOol001]oo`03001oogoo
0<1oo`03001oo`0000ioo`03001oogoo00=oo`03001oogoo00Uoo`03001oogoo01aoo`0047oo00<0
07ooOol00Woo00<007ooOol00goo00<007ooOol0`7oo00<007oo00003Woo00<007ooOol00goo00<0
07ooOol027oo00<007ooOol07Goo000?Ool00`00Ool00002Ool00`00Ool00004Ool00`00Oomoo`2o
Ool01000Oomoo`003Woo00<007ooOol00goo00<007ooOol027oo00<007ooOol07Goo000:Ool30002
Ool00`00Ool00002Ool00`00Ool00004Ool20030Ool01000Oomoo`003Goo00<007ooOol017oo00<0
07ooOol01goo00<007ooOol07Woo000@Ool01`00Oomoogoo001oo`0000Aoo`03001oogoo0;moo`04
001oogoo000=Ool00`00Oomoo`05Ool00`00Oomoo`06Ool00`00Oomoo`0NOol000moo`03001oo`00
009oo`03001oo`0000Aoo`03001oogoo0;=oo`03001oogoo00Uoo`04001oogoo000=Ool00`00Oomo
o`05Ool00`00Oomoo`05Ool00`00Oomoo`0OOol0011oo`03001oogoo009oo`03001oogoo00=oo`03
001oogoo0;=oo`03001oogoo00Uoo`05001oogooOol0000<Ool00`00Oomoo`06Ool00`00Oomoo`03
Ool00`00Oomoo`0POol001]oo`03001oogoo0;=oo`03001oogoo00Qoo`03001oogoo009oo`03001o
ogoo00Uoo`03001oogoo00Moo`03001oogoo009oo`03001oogoo025oo`006goo00<007ooOol0/goo
00<007ooOol027oo00<007ooOol00Woo00<007ooOol02Goo00<007ooOol027oo100097oo000KOol0
0`00Oomoo`2cOol20009Ool00`00Oomoo`02Ool00`00Oomoo`09Ool00`00Oomoo`0`Ool001]oo`03
001oogoo0;=oo`8000Uoo`03001oogoo009oo`03001oogoo00Uoo`03001oogoo031oo`006goo0P00
]7oo0P002Goo00<007ooOol00Woo00<007ooOol027oo00<007ooOol0<Goo000KOol00`00Oomoo`2b
Ool00`00Ool00009Ool00`00Oomoo`03Ool00`00Oomoo`07Ool00`00Oomoo`0aOol001]oo`03001o
ogoo0;9oo`03001oo`0000Qoo`03001oogoo00Aoo`03001oogoo00Ioo`03001oogoo039oo`006goo
00<007ooOol0/Woo00<007oo000027oo00<007ooOol017oo00<007ooOol01Woo00<007ooOol0<Woo
000KOol00`00Oomoo`2bOol00`00Ool00008Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomo
o`0cOol001]oo`03001oogoo0;9oo`04001oogoo0007Ool00`00Oomoo`05Ool00`00Oomoo`04Ool0
0`00Oomoo`0cOol001]oo`03001oogoo0;9oo`04001oogoo0007Ool00`00Oomoo`06Ool00`00Oomo
o`02Ool00`00Oomoo`0dOol001]oo`03001oogoo0;9oo`04001oogoo0006Ool00`00Oomoo`08Ool4
000gOol001]oo`800;=oo`04001oogoo0006Ool00`00Oomoo`13Ool001]oo`03001oogoo0;9oo`04
001oogoo0006Ool00`00Oomoo`13Ool001]oo`03001oogoo0;9oo`05001oogooOol00004Ool00`00
Oomoo`14Ool001]oo`03001oogoo0;9oo`05001oogooOol00004Ool00`00Oomoo`14Ool001]oo`03
001oogoo0;9oo`05001oogooOol00003Ool00`00Oomoo`15Ool001]oo`03001oogoo0;9oo`03001o
ogoo009oo`04001oogoo0017Ool001]oo`03001oogoo0;9oo`03001oogoo009oo`<004Qoo`006goo
00<007ooOol0/Goo00<007ooOol0CWoo000KOol2002bOol00`00Oomoo`1>Ool001]oo`03001oogoo
0;5oo`03001oogoo04ioo`006goo00<007ooOol0/Goo00<007ooOol0CWoo000KOol00`00Oomoo`2a
Ool00`00Oomoo`1>Ool001]oo`03001oogoo0;5oo`03001oogoo04ioo`006goo00<007ooOol0/Goo
00<007ooOol0CWoo000?Ool20004Ool00`00Oomoo`03Ool00`00Oomoo`2aOol00`00Oomoo`1>Ool0
00moo`03001oo`00009oo`03001oo`0000Aoo`03001oogoo0;5oo`03001oogoo04ioo`002Woo0`00
0Woo00<007oo00000Woo00<007oo000017oo0P00/Woo00<007ooOol0CWoo000?Ool20003Ool00`00
Ool00004Ool00`00Oomoo`2`Ool00`00Oomoo`1?Ool000moo`03001oogoo009oo`03001oo`0000Ao
o`03001oogoo0;1oo`03001oogoo04moo`0047oo0P000goo00<007ooOol00goo00<007ooOol0/7oo
00<007ooOol0Cgoo000KOol00`00Oomoo`2`Ool00`00Oomoo`1?Ool001]oo`03001oogoo0;1oo`03
001oogoo04moo`006goo00<007ooOol0/7oo00<007ooOol0Cgoo000KOol00`00Oomoo`2_Ool00`00
Oomoo`1@Ool001]oo`800;1oo`03001oogoo051oo`006goo00<007ooOol0[goo00<007ooOol0D7oo
000KOol00`00Oomoo`2_Ool00`00Oomoo`1@Ool001]oo`03001oogoo0:moo`03001oogoo051oo`00
6goo00<007ooOol0[Woo00<007ooOol0DGoo000KOol00`00Oomoo`2^Ool00`00Oomoo`1AOol001]o
o`03001oogoo0:ioo`03001oogoo055oo`006goo0P00[goo00<007ooOol0DGoo000KOol00`00Oomo
o`2]Ool00`00Oomoo`1BOol001]oo`03001oogoo0:eoo`03001oogoo059oo`006goo00<007ooOol0
[Goo00<007ooOol0DWoo000KOol00`00Oomoo`2]Ool00`00Oomoo`1BOol001]oo`03001oogoo0:ao
o`03001oogoo05=oo`006goo00<007ooOol0[7oo00<007ooOol0Dgoo000KOol00`00Oomoo`2/Ool0
0`00Oomoo`1COol001]oo`800:eoo`03001oogoo05=oo`006goo00<007ooOol0Zgoo00<007ooOol0
E7oo000KOol00`00Oomoo`2[Ool00`00Oomoo`1DOol001]oo`03001oogoo0:]oo`03001oogoo05Ao
o`006goo00<007ooOol0ZWoo00<007ooOol0EGoo000KOol00`00Oomoo`2ZOol00`00Oomoo`1EOol0
011oo`<0009oo`03001oogoo00=oo`03001oogoo0:Uoo`03001oogoo05Ioo`004Goo00H007ooOol0
07oo0004Ool00`00Oomoo`2YOol00`00Oomoo`1FOol000Yoo`<0009oo`@00004Ool007oo0004Ool2
002ZOol00`00Oomoo`1FOol000moo`03001oo`00009oo`03001oo`0000Aoo`03001oogoo0:Qoo`03
001oogoo05Moo`0047oo0P000Woo00<007oo000017oo00<007ooOol0Z7oo00<007ooOol0Egoo000A
Ool01@00Oomoogoo00001Goo00<007ooOol0Z7oo00<007ooOol0Egoo000KOol00`00Oomoo`2WOol0
0`00Oomoo`1HOol001]oo`03001oogoo0:Moo`03001oogoo05Qoo`006goo00<007ooOol0YWoo00<0
07ooOol0FGoo000KOol00`00Oomoo`2VOol00`00Oomoo`1IOol001]oo`800:Ioo`03001oogoo05Yo
o`006goo00<007ooOol0YGoo00<007ooOol0FWoo000KOol00`00Oomoo`2TOol00`00Oomoo`1KOol0
01]oo`03001oogoo0:Aoo`03001oogoo05]oo`006goo00<007ooOol0Xgoo00<007ooOol0G7oo000K
Ool00`00Oomoo`2SOol00`00Oomoo`1LOol001]oo`03001oogoo0:9oo`03001oogoo05eoo`006goo
00<007ooOol0XWoo00<007ooOol0GGoo000KOol2002ROol00`00Oomoo`1NOol001]oo`03001oogoo
0:5oo`03001oogoo05ioo`006goo00<007ooOol0X7oo00<007ooOol0Ggoo000KOol00`00Oomoo`2P
Ool00`00Oomoo`1OOol001]oo`03001oogoo09moo`03001oogoo061oo`006goo00<007ooOol0WWoo
00<007ooOol0HGoo000KOol00`00Oomoo`2NOol00`00Oomoo`1QOol001]oo`8009ioo`03001oogoo
069oo`006goo00<007ooOol0W7oo00<007ooOol0Hgoo000KOol00`00Oomoo`2LOol00`00Oomoo`1S
Ool001]oo`03001oogoo09]oo`03001oogoo06Aoo`006goo00<007ooOol0VWoo00<007ooOol0IGoo
000KOol00`00Oomoo`2JOol00`00Oomoo`1UOol000moo`<000=oo`03001oogoo00=oo`03001oogoo
09Uoo`03001oogoo06Ioo`003goo00<007ooOol00Woo00<007oo000017oo00<007ooOol0V7oo00<0
07ooOol0Igoo000:Ool30003Ool01`00Oomoogoo001oo`0000Aoo`8009Uoo`03001oogoo06Moo`00
47oo00L007ooOomoo`00Ool00004Ool00`00Oomoo`2GOol00`00Oomoo`1XOol000moo`03001oo`00
009oo`03001oo`0000Aoo`03001oogoo09Ioo`03001oogoo06Uoo`0047oo00<007ooOol00Woo00<0
07ooOol00goo00<007ooOol0UGoo00<007ooOol0JWoo000KOol00`00Oomoo`2DOol00`00Oomoo`1[
Ool001]oo`03001oogoo09=oo`03001oogoo06aoo`006goo00<007ooOol0TWoo00<007ooOol0KGoo
000KOol00`00Oomoo`2AOol00`00Oomoo`1^Ool001]oo`80095oo`03001oogoo06moo`006goo00<0
07ooOol0Sgoo00<007ooOol0L7oo000KOol00`00Oomoo`2>Ool00`00Oomoo`1aOol001]oo`03001o
ogoo08eoo`03001oogoo079oo`006goo00<007ooOol0S7oo00<007ooOol0Lgoo000KOol00`00Oomo
o`2;Ool00`00Oomoo`1dOol001]oo`03001oogoo08Uoo`8007Moo`006goo00<007ooOol0R7oo00<0
07ooOol0Mgoo000KOol20028Ool00`00Oomoo`1hOol001]oo`03001oogoo08Eoo`8007]oo`006goo
00<007ooOol0Q7oo00<007ooOol0Ngoo000KOol00`00Oomoo`23Ool00`00Oomoo`1lOol001]oo`03
001oogoo021oo`<000=oo`03001oogoo021oo`<0009oo`03001oogoo01moo`8000Aoo`03001oogoo
00Qoo`8001Eoo`03001oogoo009oo`03001oogoo01]oo`D0009oo`03001oogoo009oo`03001oogoo
01Uoo`D00004Ool000000003Ool00`00Oomoo`0@Ool001]oo`03001oogoo021oo`03001oogoo009o
o`03001oo`00029oo`06001oogoo001oo`0087oo00<007oo00000Woo00<007oo00001goo0P005Woo
00<007oo00000Woo00<007oo00007Woo00L007ooOomoo`00Ool00002Ool00`00Ool0000LOol01@00
Oomoogoo000017oo00<007oo00004Goo000KOol00`00Oomoo`0QOol01`00Oomoogoo001oo`00021o
o`@00004Ool007oo000POol00`00Ool00002Ool00`00Ool00005Ool2000HOol00`00Ool00002Ool0
0`00Ool0000NOol01`00Oomoogoo001oo`00009oo`03001oo`0001aoo`03001oogoo009oo`07001o
ogooOol007oo00004Goo000KOol00`00Oomoo`0QOol01`00Oomoogoo001oo`00021oo`03001oo`00
009oo`03001oo`00021oo`8000=oo`03001oo`0000=oo`8001]oo`07001oogooOol007oo00007Woo
00L007ooOomoo`00Ool00002Ool00`00Ool0000LOol00`00Oomoo`02Ool01`00Oomoogoo001oo`00
015oo`006goo0P008Goo00<007oo00000Woo00<007oo00008Goo0P000Woo00<007oo000087oo00<0
07ooOol00Woo00<007oo00000Woo00<007ooOol06Woo00<007oo00000Woo00<007oo00007Woo00L0
07ooOomoo`00Ool00002Ool00`00Ool0000LOol01`00Oomoogoo001oo`00009oo`03001oo`00015o
o`006goo00<007ooOol08Goo00<007ooOol00Woo00<007ooOol08Goo00D007ooOomoo`00029oo`80
00=oo`04001oo`00000NOol00`00Oomoo`02Ool00`00Oomoo`0LOol20004Ool00`00Oomoo`02Ool0
0`00Oomoo`0JOol20004Ool00`00Oomoo`02Ool00`00Oomoo`0@Ool001]oo`03001oogoo07Aoo`@0
08Yoo`006goo00<007ooOol0LWoo0P00SWoo000KOol00`00Oomoo`1^Ool4002@Ool001]oo`03001o
ogoo06Qoo`H009Aoo`006goo00<007ooOol0HWoo1P00VWoo000DOooo000=000001]oo`03001oogoo
00Moo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Ioo`03001oogoo00Moo`03001oogoo
00Moo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo
00Moo`03001oogoo00Moo`03001oogoo00Ioo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo
00Moo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo
00Moo`03001oogoo00Moo`03001oogoo00Ioo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo
00Moo`03001oogoo005oo`006goo00<007ooOol097oo00<007ooOol09Goo00<007ooOol09Goo00<0
07ooOol097oo00<007ooOol09Goo00<007ooOol097oo00<007ooOol05Goo000KOol00`00Oomoo`3o
Ool3Ool001]oo`03001oogoo0?moo`=oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003o
OolQOol00?moob5oo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-13.8066, -106.776, 
  0.505252, 0.639638}}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Example 3", "Subsubsection",
  TextJustification->0,
  FontFamily->"Times New Roman"],

Cell[TextData[
"Using the Kaiser window, design a lowpass digital filter with the following \
specification:\npassband=0.4\[Pi], stopband=0.5\[Pi], attenuation 80 dB."], 
  "Text",
  TextJustification->0,
  FontFamily->"Times New Roman"],

Cell[TextData[{
  StyleBox["Solution.",
    FontWeight->"Bold"],
  " From the specification, the transition width is clearly 0.1\[Pi]. Also \
choose the cutoff frequency in the center of the transition region."
}], "Text",
  TextJustification->0,
  FontFamily->"Times New Roman"],

Cell[CellGroupData[{

Cell[BoxData[
    \(InverseDiscreteTimeFourierTransform[\n\t
      ContinuousPulse[0.9  \[Pi], \[CapitalOmega] + 0.45  \[Pi]], 
      \[CapitalOmega], n]\)], "Input",
  TextJustification->0],

Cell["0.45*E^(0.*I*n)*Sinc[1.413716694115406*n]", "Output",
  TextJustification->0]
}, Open  ]],

Cell[BoxData[
    \(\(h = Table[%, {n, \(-\((L - 1)\)\)/2, \((L - 1)\)/2}]; \)\)], "Input",
  TextJustification->0],

Cell["\<\
The Kaiser window was obtained in Example 1. The product of the Kaiser window \
with h will yield the desired FIR filter impulse response. The frequency \
response is as follows.\
\>", "Text",
  TextJustification->0,
  FontFamily->"Times New Roman"],

Cell[CellGroupData[{

Cell[BoxData[
    \(H = Abs[InverseFourier[\n\t\t\t\t\tJoin[h*w, Table[0, {512 - L}]]]\ ]; 
    \nListPlot[\n\t20\ Log[10, Drop[H/Max[H], \(-256\)]], PlotJoined -> True\n
      \t]; \)], "Input",
  TextJustification->0],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00372024 0.603319 0.00415094 [
[.20982 .59082 -6 -9 ]
[.20982 .59082 6 0 ]
[.39583 .59082 -9 -9 ]
[.39583 .59082 9 0 ]
[.58185 .59082 -9 -9 ]
[.58185 .59082 9 0 ]
[.76786 .59082 -9 -9 ]
[.76786 .59082 9 0 ]
[.95387 .59082 -9 -9 ]
[.95387 .59082 9 0 ]
[.01131 .02219 -24 -4.5 ]
[.01131 .02219 0 4.5 ]
[.01131 .10521 -24 -4.5 ]
[.01131 .10521 0 4.5 ]
[.01131 .18822 -24 -4.5 ]
[.01131 .18822 0 4.5 ]
[.01131 .27124 -18 -4.5 ]
[.01131 .27124 0 4.5 ]
[.01131 .35426 -18 -4.5 ]
[.01131 .35426 0 4.5 ]
[.01131 .43728 -18 -4.5 ]
[.01131 .43728 0 4.5 ]
[.01131 .5203 -18 -4.5 ]
[.01131 .5203 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.20982 .60332 m
.20982 .60957 L
s
[(50)] .20982 .59082 0 1 Mshowa
.39583 .60332 m
.39583 .60957 L
s
[(100)] .39583 .59082 0 1 Mshowa
.58185 .60332 m
.58185 .60957 L
s
[(150)] .58185 .59082 0 1 Mshowa
.76786 .60332 m
.76786 .60957 L
s
[(200)] .76786 .59082 0 1 Mshowa
.95387 .60332 m
.95387 .60957 L
s
[(250)] .95387 .59082 0 1 Mshowa
.125 Mabswid
.06101 .60332 m
.06101 .60707 L
s
.09821 .60332 m
.09821 .60707 L
s
.13542 .60332 m
.13542 .60707 L
s
.17262 .60332 m
.17262 .60707 L
s
.24702 .60332 m
.24702 .60707 L
s
.28423 .60332 m
.28423 .60707 L
s
.32143 .60332 m
.32143 .60707 L
s
.35863 .60332 m
.35863 .60707 L
s
.43304 .60332 m
.43304 .60707 L
s
.47024 .60332 m
.47024 .60707 L
s
.50744 .60332 m
.50744 .60707 L
s
.54464 .60332 m
.54464 .60707 L
s
.61905 .60332 m
.61905 .60707 L
s
.65625 .60332 m
.65625 .60707 L
s
.69345 .60332 m
.69345 .60707 L
s
.73065 .60332 m
.73065 .60707 L
s
.80506 .60332 m
.80506 .60707 L
s
.84226 .60332 m
.84226 .60707 L
s
.87946 .60332 m
.87946 .60707 L
s
.91667 .60332 m
.91667 .60707 L
s
.99107 .60332 m
.99107 .60707 L
s
.25 Mabswid
0 .60332 m
1 .60332 L
s
.02381 .02219 m
.03006 .02219 L
s
[(-140)] .01131 .02219 1 0 Mshowa
.02381 .10521 m
.03006 .10521 L
s
[(-120)] .01131 .10521 1 0 Mshowa
.02381 .18822 m
.03006 .18822 L
s
[(-100)] .01131 .18822 1 0 Mshowa
.02381 .27124 m
.03006 .27124 L
s
[(-80)] .01131 .27124 1 0 Mshowa
.02381 .35426 m
.03006 .35426 L
s
[(-60)] .01131 .35426 1 0 Mshowa
.02381 .43728 m
.03006 .43728 L
s
[(-40)] .01131 .43728 1 0 Mshowa
.02381 .5203 m
.03006 .5203 L
s
[(-20)] .01131 .5203 1 0 Mshowa
.125 Mabswid
.02381 .04294 m
.02756 .04294 L
s
.02381 .0637 m
.02756 .0637 L
s
.02381 .08445 m
.02756 .08445 L
s
.02381 .12596 m
.02756 .12596 L
s
.02381 .14672 m
.02756 .14672 L
s
.02381 .16747 m
.02756 .16747 L
s
.02381 .20898 m
.02756 .20898 L
s
.02381 .22973 m
.02756 .22973 L
s
.02381 .25049 m
.02756 .25049 L
s
.02381 .292 m
.02756 .292 L
s
.02381 .31275 m
.02756 .31275 L
s
.02381 .33351 m
.02756 .33351 L
s
.02381 .37502 m
.02756 .37502 L
s
.02381 .39577 m
.02756 .39577 L
s
.02381 .41653 m
.02756 .41653 L
s
.02381 .45804 m
.02756 .45804 L
s
.02381 .47879 m
.02756 .47879 L
s
.02381 .49955 m
.02756 .49955 L
s
.02381 .54105 m
.02756 .54105 L
s
.02381 .56181 m
.02756 .56181 L
s
.02381 .58256 m
.02756 .58256 L
s
.02381 .00143 m
.02756 .00143 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02753 .60332 m
.03125 .60332 L
.03497 .60332 L
.03869 .60332 L
.04241 .60332 L
.04613 .60332 L
.04985 .60332 L
.05357 .60332 L
.05729 .60332 L
.06101 .60332 L
.06473 .60332 L
.06845 .60332 L
.07217 .60332 L
.07589 .60332 L
.07961 .60332 L
.08333 .60332 L
.08705 .60332 L
.09077 .60332 L
.09449 .60332 L
.09821 .60332 L
.10193 .60332 L
.10565 .60332 L
.10937 .60332 L
.1131 .60332 L
.11682 .60332 L
.12054 .60332 L
.12426 .60332 L
.12798 .60332 L
.1317 .60332 L
.13542 .60332 L
.13914 .60332 L
.14286 .60332 L
.14658 .60332 L
.1503 .60332 L
.15402 .60332 L
.15774 .60332 L
.16146 .60332 L
.16518 .60332 L
.1689 .60332 L
.17262 .60332 L
.17634 .60332 L
.18006 .60332 L
.18378 .60332 L
.1875 .60332 L
.19122 .60332 L
.19494 .60332 L
.19866 .60332 L
.20238 .60332 L
.2061 .60332 L
.20982 .60332 L
Mistroke
.21354 .60332 L
.21726 .60332 L
.22098 .60332 L
.2247 .60332 L
.22842 .60332 L
.23214 .60332 L
.23586 .60332 L
.23958 .60332 L
.2433 .60332 L
.24702 .60332 L
.25074 .60332 L
.25446 .60332 L
.25818 .60332 L
.2619 .60332 L
.26563 .60332 L
.26935 .60332 L
.27307 .60332 L
.27679 .60332 L
.28051 .60332 L
.28423 .60332 L
.28795 .60332 L
.29167 .60332 L
.29539 .60332 L
.29911 .60332 L
.30283 .60332 L
.30655 .60332 L
.31027 .60332 L
.31399 .60332 L
.31771 .60332 L
.32143 .60332 L
.32515 .60332 L
.32887 .60332 L
.33259 .60331 L
.33631 .60331 L
.34003 .60332 L
.34375 .60332 L
.34747 .60332 L
.35119 .60332 L
.35491 .60332 L
.35863 .60332 L
.36235 .60331 L
.36607 .60331 L
.36979 .60331 L
.37351 .60332 L
.37723 .60332 L
.38095 .60332 L
.38467 .60332 L
.38839 .60332 L
.39211 .60331 L
.39583 .60331 L
Mistroke
.39955 .60331 L
.40327 .60332 L
.40699 .60332 L
.41071 .6033 L
.41443 .60323 L
.41815 .60308 L
.42188 .60277 L
.4256 .60226 L
.42932 .60144 L
.43304 .60023 L
.43676 .59854 L
.44048 .59628 L
.4442 .59334 L
.44792 .58964 L
.45164 .58508 L
.45536 .57955 L
.45908 .57297 L
.4628 .5652 L
.46652 .55613 L
.47024 .5456 L
.47396 .53343 L
.47768 .51936 L
.4814 .50308 L
.48512 .48413 L
.48884 .46178 L
.49256 .43485 L
.49628 .40097 L
.5 .35387 L
.50372 .24155 L
.50744 .27183 L
.51116 .0597 L
.51488 .26531 L
.5186 .26448 L
.52232 .21672 L
.52604 .24059 L
.52976 .25947 L
.53348 .2512 L
.5372 .20195 L
.54092 .22728 L
.54464 .24864 L
.54836 .24543 L
.55208 .21696 L
.5558 .19315 L
.55952 .23457 L
.56324 .24014 L
.56696 .22686 L
.57068 .16287 L
.5744 .2114 L
.57813 .23088 L
.58185 .22938 L
Mistroke
.58557 .2075 L
.58929 .14468 L
.59301 .2134 L
.59673 .22479 L
.60045 .21859 L
.60417 .18752 L
.60789 .17281 L
.61161 .21136 L
.61533 .21817 L
.61905 .20831 L
.62277 .16614 L
.62649 .17986 L
.63021 .20785 L
.63393 .2116 L
.63765 .19869 L
.64137 .14152 L
.64509 .18146 L
.64881 .20377 L
.65253 .20529 L
.65625 .18974 L
.65997 .10826 L
.66369 .18074 L
.66741 .19947 L
.67113 .1993 L
.67485 .18146 L
.67857 .01472 L
.68229 .17883 L
.68601 .19511 L
.68973 .19364 L
.69345 .17383 L
.69717 .08136 L
.70089 .17621 L
.70461 .19078 L
.70833 .18831 L
.71205 .16685 L
.71577 .0992 L
.71949 .17314 L
.72321 .18649 L
.72693 .18328 L
.73065 .16053 L
.73438 .10518 L
.7381 .16973 L
.74182 .18225 L
.74554 .17852 L
.74926 .15487 L
.75298 .10635 L
.7567 .16605 L
.76042 .17806 L
.76414 .17403 L
.76786 .14989 L
Mistroke
.77158 .10457 L
.7753 .16211 L
.77902 .1739 L
.78274 .16979 L
.78646 .1456 L
.79018 .1004 L
.7939 .1579 L
.79762 .16974 L
.80134 .16577 L
.80506 .14201 L
.80878 .09369 L
.8125 .15336 L
.81622 .16557 L
.81994 .16196 L
.82366 .13911 L
.82738 .08352 L
.8311 .14844 L
.83482 .16135 L
.83854 .15837 L
.84226 .1369 L
.84598 .06702 L
.8497 .14302 L
.85342 .15704 L
.85714 .15497 L
.86086 .13534 L
.86458 .03101 L
.8683 .13693 L
.87202 .15262 L
.87574 .15178 L
.87946 .1344 L
.88318 .02437 L
.8869 .1299 L
.89063 .14801 L
.89435 .14879 L
.89807 .13404 L
.90179 .06771 L
.90551 .12148 L
.90923 .14317 L
.91295 .14601 L
.91667 .1342 L
.92039 .08757 L
.92411 .11082 L
.92783 .13799 L
.93155 .14345 L
.93527 .13483 L
.93899 .10083 L
.94271 .09599 L
.94643 .13239 L
.95015 .14113 L
.95387 .13589 L
Mistroke
.95759 .11091 L
.96131 .07088 L
.96503 .12618 L
.96875 .13908 L
.97247 .13732 L
.97619 .11915 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  TextJustification->0,
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`006goo0P00ogoo17oo000KOol00`00Oomo
o`3oOol3Ool001]oo`03001oogoo0?moo`=oo`006goo00<007ooOol0ogoo0goo0009Ool50002Ool3
0002Ool00`00Oomoo`03Ool00`00Oomoo`2[Ool00`00Oomoo`1DOol000]oo`03001oogoo00=oo`06
001oogoo001oo`0017oo00<007ooOol0Zgoo00<007ooOol0E7oo0005Ool30003Ool01000Oomoogoo
100000Aoo`00Ool000Aoo`800:aoo`03001oogoo03=oo`03001oogoo01ioo`002goo00L007ooOomo
o`00Ool00002Ool00`00Ool00004Ool00`00Oomoo`2[Ool00`00Oomoo`0cOol00`00Oomoo`0NOol0
00]oo`03001oogoo009oo`80009oo`03001oo`0000Aoo`03001oogoo0:]oo`03001oogoo02ioo`03
001oogoo009oo`03001oogoo01ioo`002Woo0P001Goo00D007ooOomoo`0000Eoo`03001oogoo0:]o
o`03001oogoo02ioo`03001oogoo009oo`03001oogoo01ioo`006goo00<007ooOol0Zgoo00<007oo
Ool0;Woo00<007ooOol00Woo00<007ooOol07Woo000KOol2002/Ool00`00Oomoo`0^Ool00`00Oomo
o`02Ool00`00Oomoo`0NOol001]oo`03001oogoo0:]oo`03001oogoo02ioo`03001oogoo009oo`03
001oogoo01ioo`006goo00<007ooOol0Zgoo00<007ooOol0;Woo00<007ooOol00Woo00<007ooOol0
7Woo000KOol00`00Oomoo`2[Ool00`00Oomoo`0^Ool00`00Oomoo`02Ool00`00Oomoo`0NOol001]o
o`03001oogoo0:]oo`03001oogoo02ioo`03001oogoo009oo`03001oogoo01ioo`006goo00<007oo
Ool0OWoo00<007ooOol0:Woo00<007ooOol0;Woo00<007ooOol00Woo00<007ooOol07Woo000KOol2
001oOol00`00Oomoo`0ZOol00`00Oomoo`0^Ool00`00Oomoo`02Ool00`00Oomoo`0NOol001]oo`03
001oogoo07ioo`03001oogoo02Yoo`03001oogoo02Yoo`05001oogooOol00004Ool00`00Oomoo`02
Ool00`00Oomoo`0IOol001]oo`03001oogoo07ioo`03001oogoo02Yoo`03001oogoo02Yoo`05001o
ogooOol00004Ool00`00Oomoo`02Ool00`00Oomoo`0=Ool00`00Oomoo`09Ool001]oo`03001oogoo
07ioo`03001oogoo02Yoo`03001oogoo02Yoo`05001oogooOol00004Ool20003Ool00`00Oomoo`0=
Ool00`00Oomoo`09Ool001]oo`03001oogoo07ioo`03001oogoo02Yoo`03001oogoo009oo`03001o
ogoo02Eoo`05001oogooOol00003Ool00`00Ool00003Ool00`00Oomoo`0=Ool00`00Oomoo`09Ool0
01]oo`8007moo`03001oogoo02Yoo`03001oogoo009oo`03001oogoo021oo`03001oogoo009oo`06
001oogoo001oo`000Woo00<007oo00000goo00<007ooOol03Goo00<007ooOol02Goo000KOol00`00
Oomoo`1nOol00`00Oomoo`0ZOol00`00Oomoo`02Ool00`00Oomoo`0POol00`00Oomoo`02Ool01P00
Oomoo`00Ool0009oo`03001oo`0000=oo`03001oogoo009oo`03001oogoo00Qoo`03001oogoo00Uo
o`006goo00<007ooOol0OWoo00<007ooOol0:Woo00<007ooOol00Woo00<007ooOol087oo00<007oo
Ool00Woo00H007ooOol007oo0002Ool00`00Ool00003Ool00`00Oomoo`02Ool00`00Oomoo`07Ool2
000;Ool001]oo`03001oogoo07ioo`03001oogoo02Yoo`03001oogoo009oo`03001oogoo01]oo`03
001oogoo009oo`03001oogoo009oo`06001oogoo001oo`000Woo00<007oo00000goo0P000goo00<0
07ooOol00goo00@007ooOomoo`8000]oo`002Goo1@0000Aoo`00000000=oo`03001oogoo00=oo`03
001oogoo07ioo`03001oogoo02Uoo`03001oo`0000=oo`03001oogoo009oo`03001oogoo01Ioo`03
001oogoo009oo`03001oogoo009oo`06001oogoo001oo`000Woo00<007oo00000goo0P000goo0P00
0goo0P000goo00<007oo00002Woo000;Ool01@00Oomoogoo000017oo00<007oo000017oo00<007oo
Ool0OWoo00<007ooOol0:Goo00<007oo00000goo00<007ooOol00Woo00<007ooOol04Goo00<007oo
Ool00Woo00<007ooOol00Woo00@007ooOomoo`80009oo`03001oo`00009oo`03001oo`00009oo`03
001oo`0000=oo`8000=oo`8000=oo`03001oo`0000Yoo`001Goo0`000goo00<007ooOol00Woo00L0
07ooOomoo`00Ool00004Ool2001oOol00`00Oomoo`0YOol00`00Ool00003Ool00`00Oomoo`02Ool0
0`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`02Ool0
0`00Oomoo`02Ool02`00Oomoogoo001oo`00Ool007oo00000Woo00<007oo00000Woo00<007oo0000
0goo0P000goo0P000goo00<007oo00002Woo000;Ool00`00Oomoo`02Ool01`00Oomoogoo001oo`00
00Aoo`03001oogoo07ioo`03001oogoo02Eoo`07001oogooOol007oo00000goo00<007ooOol00Woo
00<007ooOol00Woo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol00Woo
00<007ooOol00Woo00/007ooOomoo`00Ool007oo001oo`00009oo`03001oo`00009oo`03001oo`00
00=oo`8000=oo`8000=oo`03001oo`0000Yoo`002goo00L007ooOomoo`00Ool00002Ool00`00Ool0
0004Ool00`00Oomoo`1nOol00`00Oomoo`0UOol01`00Oomoogoo001oo`0000=oo`03001oogoo009o
o`03001oogoo009oo`03001oogoo009oo`03001oogoo009oo`03001oogoo009oo`03001oogoo009o
o`04001oogooOol20003Ool01`00Ool007oo001oo`00009oo`03001oo`00009oo`03001oo`00009o
o`03001oo`0000=oo`03001oo`00009oo`03001oo`0000Yoo`002Woo0P0017oo00<007ooOol00Woo
00<007ooOol00goo00<007ooOol0OWoo00<007ooOol09Goo00L007ooOomoo`00Ool00003Ool00`00
Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00
Oomoo`02Ool01`00Oomoogoo001oo`00009oo`07001oo`00Ool007oo00000Woo00<007oo00000Woo
00<007oo00000Woo00<007oo00000goo00<007oo00000Woo00<007oo00002Woo000KOol00`00Oomo
o`1nOol00`00Oomoo`0UOol01`00Oomoogoo001oo`0000=oo`03001oogoo009oo`03001oogoo009o
o`03001oogoo009oo`03001oogoo009oo`03001oogoo009oo`04001oogooOol20003Ool00`00Ool0
0002Ool01`00Ool007oo001oo`00009oo`03001oo`00009oo`03001oo`00009oo`03001oo`00009o
o`04001oogoo0002Ool00`00Ool00002Ool00`00Oomoo`05Ool001]oo`8007moo`03001oogoo02Eo
o`07001oogooOol007oo00000goo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol00Woo00<0
07ooOol00Woo00@007ooOomoo`8000=oo`03001oo`00009oo`03001oo`00009oo`07001oo`00Ool0
07oo00000Woo00<007oo00000Woo00<007oo00000Woo00H007ooOol007oo0002Ool00`00Ool00002
Ool01000Oomoo`001goo000KOol00`00Oomoo`1nOol00`00Oomoo`0UOol01`00Oomoogoo001oo`00
009oo`03001oo`0000=oo`03001oogoo009oo`03001oogoo009oo`04001oogooOol20003Ool20003
Ool00`00Ool00002Ool00`00Ool00002Ool01`00Ool007oo001oo`00009oo`03001oo`00009oo`03
001oo`00009oo`06001oogoo001oo`000Woo00<007oo00000Woo00<007oo000027oo000KOol00`00
Oomoo`1nOol00`00Oomoo`0UOol01`00Oomoogoo001oo`00009oo`03001oo`00009oo`8000Aoo`04
001oogooOol20003Ool20003Ool00`00Ool00002Ool00`00Ool00002Ool00`00Ool00002Ool01`00
Ool007oo001oo`00009oo`03001oo`00009oo`06001oogoo001oo`000Woo00<007oo00000Woo00<0
07oo00000goo0P0027oo000KOol00`00Oomoo`1nOol00`00Oomoo`0UOol01`00Oomoogoo001oo`00
009oo`03001oo`00009oo`03001oo`00009oo`8000=oo`03001oo`00009oo`03001oo`00009oo`03
001oo`00009oo`03001oo`00009oo`03001oo`00009oo`07001oo`00Ool007oo00000Woo00<007oo
00000Woo00H007ooOol007oo0002Ool00`00Ool00003Ool20003Ool20008Ool001]oo`03001oogoo
07ioo`03001oogoo021oo`03001oogoo009oo`07001oogooOol007oo00000Woo00<007oo00000Woo
00<007oo00000Woo00<007oo00000Woo00<007oo00000Woo00<007oo00000Woo00<007oo00000Woo
00<007oo00000Woo00<007oo00000Woo00L007oo001oo`00Ool00002Ool00`00Oomoo`020003Ool0
0`00Ool00002Ool20004Ool00`00Oomoo`02Ool00`00Oomoo`07Ool001]oo`03001oogoo07ioo`03
001oogoo019oo`03001oogoo00]oo`03001oogoo009oo`07001oogooOol007oo00000Woo00<007oo
00000Woo00<007oo00000Woo00<007oo00000Woo00<007oo00000Woo00<007oo00000Woo00<007oo
00000Woo00<007oo00000Woo00<007oo00000Woo00D007oo001oo`00009oo`8000=oo`8000=oo`80
00Aoo`03001oogoo015oo`006goo0P00Ogoo00<007ooOol04Woo00<007ooOol02goo00<007ooOol0
0Woo0P000Woo00<007oo00000Woo00<007oo00000Woo00<007oo00000Woo00<007oo00000Woo00<0
07oo00000Woo00<007oo00000Woo00<007oo00000Woo00<007oo00000Woo00D007oo001oo`00009o
o`8000=oo`8000=oo`8000Aoo`03001oogoo01Ioo`006goo00<007ooOol0OWoo00<007ooOol04Woo
00<007ooOol02goo00L007ooOomoo`00Ool00002Ool00`00Ool00002Ool00`00Ool00002Ool00`00
Ool00002Ool00`00Ool00002Ool00`00Ool00002Ool00`00Ool00002Ool00`00Ool00002Ool01@00
Ool007oo00000Woo00<007oo00000goo00@007ooOomoo`80029oo`006goo00<007ooOol0OWoo00<0
07ooOol04Woo00<007ooOol02goo00L007ooOomoo`00Ool00002Ool00`00Ool00002Ool00`00Ool0
0002Ool00`00Ool00002Ool00`00Ool00002Ool00`00Ool00002Ool00`00Ool00002Ool01@00Ool0
07oo00000Woo00<007oo00000goo0P000goo00<007ooOol09Goo000KOol00`00Oomoo`1nOol00`00
Oomoo`0BOol00`00Oomoo`0;Ool01`00Oomoogoo001oo`00009oo`03001oo`00009oo`03001oo`00
009oo`03001oo`00009oo`03001oo`00009oo`03001oo`00009oo`05001oo`00Ool00002Ool00`00
Ool00002Ool00`00Ool00003Ool20003Ool00`00Oomoo`0UOol001]oo`03001oogoo07ioo`8000io
o`03001oogoo009oo`03001oogoo00]oo`80009oo`03001oo`00009oo`03001oo`00009oo`03001o
o`00009oo`03001oo`00009oo`03001oo`00009oo`05001oo`00Ool00002Ool00`00Ool00002Ool0
0`00Ool00003Ool20003Ool00`00Oomoo`0ZOol001]oo`8007ioo`03001oo`0000ioo`03001oogoo
009oo`03001oogoo00Ioo`03001oogoo009oo`80009oo`03001oo`00009oo`03001oo`00009oo`03
001oo`00009oo`03001oo`00009oo`05001oo`00Ool00002Ool00`00Ool00002Ool00`00Ool00003
Ool20003Ool00`00Oomoo`0_Ool001]oo`03001oogoo07eoo`03001oo`0000ioo`03001oogoo009o
o`03001oogoo00Ioo`07001oogooOol007oo00000Woo00<007oo00000Woo00<007oo00000Woo00<0
07oo00000Woo00<007oo00000Woo00D007oo001oo`00009oo`03001oo`0000=oo`8000=oo`03001o
ogoo03Aoo`006goo00<007ooOol0OGoo00<007oo00003Woo00<007ooOol00Woo00<007ooOol00Woo
00@007ooOomoo`80009oo`03001oo`00009oo`03001oo`00009oo`03001oo`00009oo`03001oo`00
009oo`05001oo`00Ool00002Ool00`00Ool00003Ool20003Ool00`00Oomoo`0iOol001]oo`03001o
ogoo07eoo`03001oo`0000ioo`04001oogooOol20004Ool01000Oomoogoo0P000Woo00<007oo0000
0Woo00<007oo00000Woo00<007oo00000Woo00D007oo001oo`00009oo`03001oo`0000=oo`8000=o
o`03001oogoo03ioo`002Goo1@000Woo00<007ooOol00Woo00<007ooOol00goo00<007ooOol0OGoo
00<007oo00003Woo00L007ooOomoo`00Ool00002Ool20003Ool20002Ool00`00Ool00002Ool00`00
Ool00002Ool00`00Ool00002Ool01@00Ool007oo00000goo0P000goo00<007ooOol0@goo000;Ool0
1`00Oomoogoo001oo`00009oo`03001oo`0000Aoo`03001oogoo07eoo`03001oo`0000ioo`07001o
ogooOol007oo00000Woo0P000goo0P000Woo00<007oo00000Woo00<007oo00000Woo00D007oo001o
o`0000=oo`8000=oo`8004Uoo`001Goo0`000goo00L007ooOomoo`00Ool00002Ool00`00Ool00004
Ool2001nOol00`00Ool0000>Ool20002Ool00`00Ool00002Ool20002Ool00`00Ool00002Ool00`00
Ool00002Ool00`00Ool00002Ool00`00Oomoo`020003Ool2001>Ool000]oo`07001oogooOol007oo
00000Woo00<007oo000017oo00<007ooOol0OGoo00<007oo00002Woo00@007ooOomoo`80009oo`03
001oo`00009oo`07001oo`00Ool007oo00000Woo00H007ooOol007oo0002Ool20003Ool20003Ool0
0`00Oomoo`1=Ool000]oo`07001oogooOol007oo00000Woo00<007oo000017oo00<007ooOol0OGoo
00<007oo00002Woo00H007ooOol007oo0002Ool00`00Ool00002Ool01@00Ool007oo00000Woo00<0
07oo00000Woo0P000goo0P000goo00<007ooOol0DWoo000:Ool20004Ool00`00Oomoo`02Ool00`00
Oomoo`03Ool00`00Oomoo`1mOol00`00Ool0000:Ool01P00Oomoo`00Ool0009oo`03001oo`00009o
o`05001oo`00Ool00002Ool00`00Ool00002Ool20003Ool2001HOol001]oo`03001oogoo07eoo`03
001oo`0000Eoo`03001oogoo009oo`06001oogoo001oo`000Woo00D007oo001oo`00009oo`03001o
o`00009oo`03001oo`00009oo`8005eoo`006goo0P00OWoo00<007oo00001Goo00@007ooOomoo`80
009oo`03001oo`00009oo`05001oo`00Ool00002Ool00`00Ool00002Ool2001ROol001]oo`03001o
ogoo07eoo`03001oo`0000Eoo`04001oogooOol20002Ool00`00Ool00002Ool01@00Ool007oo0000
0Woo00<007oo00000goo00<007ooOol0H7oo000KOol00`00Oomoo`1mOol01@00Ool007oo00000goo
0P000Woo00L007oo001oo`00Ool00002Ool01@00Ool007oo00000goo00<007ooOol0IGoo000KOol0
0`00Oomoo`1mOol01@00Ool007oo00000goo0P000Woo00T007oo001oo`00Ool007oo00000Woo00<0
07oo00000goo00<007ooOol0IGoo000KOol00`00Oomoo`1mOol01@00Ool007oo00000goo0P000Woo
00D007oo001oo`00009oo`8000=oo`03001oogoo06Yoo`006goo00<007ooOol0OGoo00D007oo001o
o`0000=oo`80009oo`05001oo`00Ool00002Ool20003Ool00`00Oomoo`1ZOol001]oo`8007ioo`04
001oo`00Ool2000017oo001oo`000Woo00D007oo001oo`00009oo`80071oo`006goo00<007ooOol0
OGoo00@007oo001oo`800006Ool007oo001oo`000Woo0P00MGoo000KOol00`00Oomoo`1mOol01000
Ool007oo0P0000Aoo`00Oomoo`8000=oo`03001oogoo07=oo`006goo00<007ooOol0O7oo0P0000Mo
o`00001oo`00Ool00002Ool20003Ool00`00Oomoo`1cOol001]oo`03001oogoo07aoo`800007Ool0
0000Ool007oo00000Woo0P00NGoo000KOol2001mOol200001goo000007oo001oo`00009oo`03001o
ogoo07Qoo`006goo00<007ooOol0O7oo0P0000=oo`0000000Woo0P00OGoo000KOol00`00Oomoo`1l
Ool200000goo00000002Ool00`00Oomoo`1lOol001]oo`03001oogoo07aoo`800003Ool00000009o
o`03001oogoo07aoo`0047oo00<007ooOol00Woo00<007ooOol00goo00<007ooOol0O7oo0P0000=o
o`000000PGoo000?Ool00`00Ool00002Ool00`00Ool00004Ool00`00Oomoo`1lOol20024Ool000Yo
o`<0009oo`03001oo`00009oo`03001oo`0000Aoo`8007eoo`8008Aoo`0047oo00L007ooOomoo`00
Ool00004Ool00`00Oomoo`1lOol00`00Oomoo`23Ool000moo`03001oo`00009oo`03001oo`0000Ao
o`03001oogoo07aoo`03001oogoo08=oo`0047oo00<007ooOol00Woo00<007ooOol00goo00<007oo
Ool0O7oo00<007ooOol0Pgoo000KOol00`00Oomoo`1lOol00`00Oomoo`23Ool001]oo`03001oogoo
07aoo`03001oogoo08=oo`006goo0P00OGoo00<007ooOol0Pgoo000KOol00`00Oomoo`1kOol00`00
Oomoo`24Ool001]oo`03001oogoo07]oo`03001oogoo08Aoo`006goo00<007ooOol0Ngoo00<007oo
Ool0Q7oo000KOol00`00Oomoo`1kOol00`00Oomoo`24Ool001]oo`8007aoo`03001oogoo08Aoo`00
6goo00<007ooOol0Ngoo00<007ooOol0Q7oo000KOol00`00Oomoo`1kOol00`00Oomoo`24Ool001]o
o`03001oogoo07]oo`03001oogoo08Aoo`006goo00<007ooOol0Ngoo00<007ooOol0Q7oo000KOol0
0`00Oomoo`1kOol00`00Oomoo`24Ool001]oo`8007aoo`03001oogoo08Aoo`006goo00<007ooOol0
Ngoo00<007ooOol0Q7oo000KOol00`00Oomoo`1kOol00`00Oomoo`24Ool000moo`8000Aoo`03001o
ogoo00=oo`03001oogoo07]oo`03001oogoo08Aoo`003goo00<007oo00000Woo00<007oo000017oo
00<007ooOol0Ngoo00<007ooOol0Q7oo000:Ool30002Ool00`00Ool00002Ool00`00Ool00004Ool2
001lOol00`00Oomoo`24Ool000moo`8000=oo`03001oo`0000Aoo`03001oogoo07]oo`03001oogoo
08Aoo`003goo00<007ooOol00Woo00<007oo000017oo00<007ooOol0Ngoo00<007ooOol0Q7oo000@
Ool20003Ool00`00Oomoo`03Ool00`00Oomoo`1kOol00`00Oomoo`24Ool001]oo`03001oogoo07]o
o`03001oogoo08Aoo`006goo00<007ooOol0Ngoo00<007ooOol0Q7oo000KOol2001lOol00`00Oomo
o`24Ool001]oo`03001oogoo07]oo`03001oogoo08Aoo`006goo00<007ooOol0Ngoo00<007ooOol0
Q7oo000KOol00`00Oomoo`1kOol00`00Oomoo`24Ool001]oo`03001oogoo07]oo`03001oogoo08Ao
o`006goo0P00O7oo00<007ooOol0Q7oo000KOol00`00Oomoo`1kOol00`00Oomoo`24Ool001]oo`03
001oogoo07]oo`03001oogoo08Aoo`006goo00<007ooOol0Ngoo00<007ooOol0Q7oo000KOol00`00
Oomoo`1kOol00`00Oomoo`24Ool001]oo`03001oogoo07]oo`03001oogoo08Aoo`006goo0P00Ngoo
00<007ooOol0QGoo000KOol00`00Oomoo`1jOol00`00Oomoo`25Ool001]oo`03001oogoo07Yoo`03
001oogoo08Eoo`0047oo0`000Woo00<007ooOol00goo00<007ooOol0NWoo00<007ooOol0QGoo000A
Ool01P00Oomoo`00Ool000Aoo`03001oogoo07Yoo`03001oogoo08Eoo`002Woo0`000Woo100000Ao
o`00Ool000Aoo`8007]oo`03001oogoo08Eoo`003goo00<007oo00000Woo00<007oo000017oo00<0
07ooOol0NWoo00<007ooOol0QGoo000@Ool20002Ool00`00Ool00004Ool00`00Oomoo`1jOol00`00
Oomoo`25Ool0015oo`05001oogooOol00005Ool00`00Oomoo`1jOol00`00Oomoo`25Ool001]oo`03
001oogoo07Uoo`03001oogoo08Ioo`006goo00<007ooOol0NGoo00<007ooOol0QWoo000KOol2001j
Ool00`00Oomoo`26Ool001]oo`03001oogoo07Uoo`03001oogoo08Ioo`006goo00<007ooOol0NGoo
00<007ooOol0QWoo000KOol00`00Oomoo`1iOol00`00Oomoo`26Ool001]oo`03001oogoo07Qoo`03
001oogoo08Moo`006goo0P00NGoo00<007ooOol0Qgoo000KOol00`00Oomoo`1hOol00`00Oomoo`27
Ool001]oo`03001oogoo07Qoo`03001oogoo08Moo`006goo00<007ooOol0N7oo00<007ooOol0Qgoo
000KOol00`00Oomoo`1hOol00`00Oomoo`27Ool001]oo`03001oogoo07Moo`03001oogoo08Qoo`00
6goo0P00N7oo00<007ooOol0R7oo000KOol00`00Oomoo`1gOol00`00Oomoo`28Ool001]oo`03001o
ogoo07Moo`03001oogoo08Qoo`003goo0`000goo00<007ooOol00goo00<007ooOol0MWoo00<007oo
Ool0RGoo000?Ool00`00Oomoo`02Ool00`00Ool00004Ool00`00Oomoo`1fOol00`00Oomoo`29Ool0
00Yoo`<000=oo`07001oogooOol007oo000017oo0P00Mgoo00<007ooOol0RGoo000@Ool01`00Oomo
ogoo001oo`0000Aoo`03001oogoo07Ioo`03001oogoo08Uoo`003goo00<007oo00000Woo00<007oo
000017oo00<007ooOol0MGoo00<007ooOol0RWoo000@Ool00`00Oomoo`02Ool00`00Oomoo`03Ool0
0`00Oomoo`1eOol00`00Oomoo`2:Ool001]oo`03001oogoo07Eoo`03001oogoo08Yoo`006goo00<0
07ooOol0MGoo00<007ooOol0RWoo000KOol2001eOol00`00Oomoo`2;Ool001]oo`03001oogoo07Ao
o`03001oogoo08]oo`006goo00<007ooOol0M7oo00<007ooOol0Rgoo000KOol00`00Oomoo`1cOol0
0`00Oomoo`2<Ool001]oo`03001oogoo07=oo`03001oogoo08aoo`006goo0P00;7oo00<007ooOol0
0Woo00<007ooOol09Goo1@000Woo00<007ooOol00Woo00<007ooOol02goo00<007ooOol05Goo1@00
0Woo00<007ooOol00Woo00<007ooOol08goo0`000goo00<007ooOol00Woo00<007ooOol097oo0`00
0goo00<007ooOol00Woo00<007ooOol01Woo000KOol00`00Oomoo`0ZOol00`00Ool00002Ool00`00
Ool0000XOol01`00Oomoogoo001oo`00009oo`03001oo`0000aoo`03001oogoo01Moo`07001oogoo
Ool007oo00000Woo00<007oo000097oo00<007ooOol00Woo00<007oo00000Woo00<007oo00009Goo
00<007ooOol00Woo00<007oo00000Woo00<007oo00001goo000KOol00`00Oomoo`0/Ool01P00Oomo
o`00Ool002Qoo`07001oogooOol007oo00000Woo00<007oo00002goo00<007ooOol067oo00<007oo
Ool00goo00H007ooOol007oo000UOol01`00Oomoogoo001oo`00009oo`03001oo`0002Ioo`03001o
ogoo00=oo`06001oogoo001oo`001goo000KOol00`00Oomoo`0ZOol20003Ool00`00Ool0000XOol0
1`00Oomoogoo001oo`00009oo`03001oo`0000]oo`03001oogoo01Qoo`04001oogooOol20003Ool0
0`00Ool0000UOol01`00Oomoogoo001oo`00009oo`03001oo`0002Ioo`04001oogooOol20003Ool0
0`00Ool00007Ool001]oo`03001oogoo02Yoo`03001oogoo009oo`03001oo`0002Qoo`07001oogoo
Ool007oo00000Woo00<007oo00002Woo00<007ooOol06Goo00D007ooOomoo`0000Aoo`03001oo`00
02Aoo`03001oo`00009oo`03001oo`00009oo`03001oo`0002Eoo`03001oo`00009oo`03001oogoo
009oo`03001oo`0000Moo`006goo00<007ooOol0:Woo0`000goo00<007ooOol09Woo0P0017oo00<0
07ooOol00Woo00<007ooOol02Goo00<007ooOol067oo0P000goo0`000goo00<007ooOol097oo00<0
07ooOol00Woo00<007ooOol00Woo00<007ooOol09Goo00@007ooOomoo`<000=oo`03001oogoo00Io
o`006goo0P00L7oo00<007ooOol0T7oo000KOol00`00Oomoo`1^Ool00`00Oomoo`2AOol001]oo`03
001oogoo06ioo`03001oogoo095oo`006goo00<007ooOol0K7oo0P00U7oo000KOol00`00Oomoo`1Z
Ool2002FOol001Aoool000d000006goo00<007ooOol01goo00<007ooOol01goo00<007ooOol01goo
00<007ooOol01Woo00<007ooOol01goo00<007ooOol01goo00<007ooOol01goo00<007ooOol01goo
00<007ooOol01goo00<007ooOol01goo00<007ooOol01goo00<007ooOol01goo00<007ooOol01Woo
00<007ooOol01goo00<007ooOol01goo00<007ooOol01goo00<007ooOol01goo00<007ooOol01goo
00<007ooOol01goo00<007ooOol01goo00<007ooOol01goo00<007ooOol01goo00<007ooOol01Woo
00<007ooOol01goo00<007ooOol01goo00<007ooOol01goo00<007ooOol00Goo000KOol00`00Oomo
o`0^Ool00`00Oomoo`0_Ool00`00Oomoo`0^Ool00`00Oomoo`0_Ool00`00Oomoo`0^Ool00`00Oomo
o`0;Ool001]oo`03001oogoo0?moo`=oo`006goo00<007ooOol0ogoo0goo003oOolQOol00?moob5o
o`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo0000\
\>"],
  ImageRangeCache->{{{86.5, 373.5}, {330.125, 153.188}} -> {-115.022,
   -12.2878, 1.0105, 0.905654}}]
}, Open  ]],

Cell["\<\
The passband and stopband edges, in integer units of frequency, should be at \
\
\>", "Text",
  TextJustification->0,
  FontFamily->"Times New Roman"],

Cell[CellGroupData[{

Cell[BoxData[
    \({512/5, \ 512/4}\  // N\)], "Input",
  TextJustification->0],

Cell["{102.4, 128.}", "Output",
  TextJustification->0]
}, Open  ]],

Cell["\<\
From an inspection of the frequency response plot it is clear that the \
passband, stopband and attenuation specifications are all satisfied.\
\>", "Text",
  TextJustification->0,
  FontFamily->"Times New Roman"]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"Microsoft Windows 3.0",
ScreenRectangle->{{0, 1280}, {0, 968}},
WindowToolbars->"EditBar",
CellGrouping->Manual,
WindowSize->{509, 637},
WindowMargins->{{218, Automatic}, {Automatic, 139}},
PrintingCopies->1,
PrintingPageRange->{Automatic, Automatic},
StyleDefinitions -> "ArticleClassic.nb"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1709, 49, 95, 2, 111, "Title"],

Cell[CellGroupData[{
Cell[1829, 55, 78, 2, 57, "Section"],
Cell[1910, 59, 1353, 21, 265, "Text"],
Cell[3266, 82, 66, 1, 31, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3369, 88, 88, 2, 57, "Section"],
Cell[3460, 92, 270, 6, 44, "Text"],
Cell[3733, 100, 252, 5, 109, "Input"],

Cell[CellGroupData[{
Cell[4010, 109, 104, 2, 30, "Input"],
Cell[4117, 113, 32502, 659, 186, 4842, 312, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],
Cell[36634, 775, 298, 5, 71, "Text"],
Cell[36935, 782, 144, 3, 33, "Text"],
Cell[37082, 787, 253, 5, 90, "Input"],
Cell[37338, 794, 153, 4, 33, "Text"],
Cell[37494, 800, 189, 4, 86, "Input"],
Cell[37686, 806, 164, 5, 33, "Text"],

Cell[CellGroupData[{
Cell[37875, 815, 91, 2, 43, "Subsubsection"],
Cell[37969, 819, 176, 4, 33, "Text"],
Cell[38148, 825, 188, 6, 33, "Text"],

Cell[CellGroupData[{
Cell[38361, 835, 77, 2, 30, "Input"],
Cell[38441, 839, 49, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[38527, 845, 79, 2, 30, "Input"],
Cell[38609, 849, 45, 1, 29, "Output"]
}, Open  ]],
Cell[38669, 853, 92, 2, 30, "Input"],

Cell[CellGroupData[{
Cell[38786, 859, 84, 2, 30, "Input"],
Cell[38873, 863, 61433, 1434, 186, 10341, 798, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[100367, 2304, 98, 2, 53, "Section"],
Cell[100468, 2308, 1094, 28, 188, "Text"],

Cell[CellGroupData[{
Cell[101587, 2340, 91, 2, 43, "Subsubsection"],
Cell[101681, 2344, 228, 4, 52, "Text"],

Cell[CellGroupData[{
Cell[101934, 2352, 197, 6, 33, "Text"],
Cell[102134, 2360, 64, 1, 30, "Input"],

Cell[CellGroupData[{
Cell[102223, 2365, 87, 2, 30, "Input"],
Cell[102313, 2369, 556, 8, 86, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[102906, 2382, 85, 2, 30, "Input"],
Cell[102994, 2386, 33734, 684, 186, 4973, 324, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],
Cell[136743, 3073, 61, 0, 33, "Text"],

Cell[CellGroupData[{
Cell[136829, 3077, 184, 4, 50, "Input"],
Cell[137016, 3083, 79, 1, 42, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[137132, 3089, 148, 4, 42, "Input"],
Cell[137283, 3095, 354, 5, 67, "Output"]
}, Open  ]],
Cell[137652, 3103, 90, 2, 33, "Text"],

Cell[CellGroupData[{
Cell[137767, 3109, 37, 1, 30, "Input"],
Cell[137807, 3112, 358, 5, 67, "Output"]
}, Open  ]],
Cell[138180, 3120, 74, 0, 33, "Text"],

Cell[CellGroupData[{
Cell[138279, 3124, 220, 4, 110, "Input"],
Cell[138502, 3130, 16146, 491, 186, 5193, 351, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[154709, 3628, 91, 2, 43, "Subsubsection"],
Cell[154803, 3632, 237, 5, 52, "Text"],
Cell[155043, 3639, 279, 7, 52, "Text"],

Cell[CellGroupData[{
Cell[155347, 3650, 190, 4, 50, "Input"],
Cell[155540, 3656, 83, 1, 29, "Output"]
}, Open  ]],
Cell[155638, 3660, 115, 2, 30, "Input"],
Cell[155756, 3664, 259, 6, 52, "Text"],

Cell[CellGroupData[{
Cell[156040, 3674, 219, 4, 110, "Input"],
Cell[156262, 3680, 24929, 729, 186, 7597, 510, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],
Cell[181206, 4412, 160, 5, 33, "Text"],

Cell[CellGroupData[{
Cell[181391, 4421, 80, 2, 30, "Input"],
Cell[181474, 4425, 55, 1, 29, "Output"]
}, Open  ]],
Cell[181544, 4429, 222, 5, 52, "Text"]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

