(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    444692,      10749]*)
(*NotebookOutlinePosition[    445705,      10783]*)
(*  CellTagsIndexPosition[    445661,      10779]*)
(*WindowFrame->Normal*)



Notebook[{
Cell["DISCRETE COSINE TRANSFORM", "Title"],

Cell["Mariusz Jankowski", "Author"],

Cell["\<\
Department of Electrical Engineering
University of Southern Maine
mjkcc@usm.maine.edu\
\>", "Address"],

Cell[BoxData[
    \(<< ImageProcessing`\)], "Input",
  CellLabel->"In[1]:="],

Cell[CellGroupData[{

Cell["INTRODUCTION", "Section"],

Cell["\<\
The discrete cosine transform (DCT) is an important transform in 2-D signal \
processing. It known to be close to optimal in terms of its energy compaction \
capabilities and can be computed via a fast algorithm. The DCT is used in two \
international image/video compression standards, JPEG and MPEG [Pennebaker, \
1993].\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["ONE-DIMENSIONAL DCT", "Section"],

Cell[CellGroupData[{

Cell["Series Formulation of the DCT", "Subsection"],

Cell["The 1D discrete cosine transform is defined as ", "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm
      \`\(X[k]\  = \ 
        \[Alpha][k]\ \ 
          \(\[Sum]\+\(n = 0\)\%\(N - 1\)x[n]\ \ \ 
              Cos[\(\[Pi]\ \((2  n + 1)\)\ k\)\/\(2\ N\)]\)\ \ \)\)]],
  "\t\tfor \t",
  Cell[BoxData[
      \(TraditionalForm\`k\  = \ 0, 1,  ... , N - 1\)]]
}], "NumberedEquation"],

Cell["The inverse DCT is defined as ", "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm
      \`\(x[n]\  = \ 
        \[Sum]\+\(k = 0\)\%\(N - 1\)\[Alpha][k]\ \ \ X[k]\ \ 
            Cos[\(\[Pi]\ \((2  n + 1)\)\ k\)\/\(2\ N\)]\ \)\)]],
  "\t\tfor\t",
  Cell[BoxData[
      \(TraditionalForm\`n\  = \ 0, 1,  ... , N - 1\)]]
}], "NumberedEquation"],

Cell["where in both (1) and (2) ", "Text"],

Cell[TextData[{
  " ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(\[Alpha][k]\), " ", "=", " ", 
          RowBox[{"{", GridBox[{
                {
                  \(\@\(1\/N\)\ \ \ for\ \ \ \ \ k = 0
                    \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \)},
                {\(\@\(2\/N\)\ \ for\ \ \ \ k\  = \ 1, 2, \( ... , N\) - 1\)}
                }]}]}], TraditionalForm]]]
}], "NumberedEquation"],

Cell["\<\
The cosine transform has the familiar form of the DFT transform with the \
cosine function \
\>", "Text"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm
    \`\(\(c\_N\)(n, k)\  = \ \ Cos[\(\[Pi]\ \((2  n + 1)\)\ k\)\/\(2\ N\)]\ 
    \)\)]]], "NumberedEquation"],

Cell[TextData[{
  "replacing the complex exponentials. Clearly, it is a real transformation, \
i.e. it transforms a real sequence into another real sequence. The discrete \
cosine sequences ",
  Cell[BoxData[
      \(TraditionalForm\`c\_N\)]],
  " form a basis for square-integrable sequences. Therefore any real sequence \
may be represented as a superposition of these basis sequences. Consider a \
few members of the cosine basis family of sequences of length ",
  Cell[BoxData[
      \(TraditionalForm\`N = 32\)]],
  "."
}], "Text"],

Cell[BoxData[
    \(c\_\[ScriptCapitalN]_[n_, k_] := 
      Cos[\(\[Pi]\/\(2\ \[ScriptCapitalN]\)\) \((2  n + 1)\) k]\)], "Input",
  CellLabel->"In[20]:="],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[
      GraphicsArray[
        \(ListPlot[Evaluate[Table[c\_32[n, #], \ {n, 0, 31}]]\ , 
              PlotJoined \[Rule] True, DisplayFunction \[Rule] Identity]\ &
            \)\ /@\ {0, \ 1, \ 2, \ 8}]]; \)\)], "Input",
  CellLabel->"In[22]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .14373 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0.00342212 0.238095 [
[ 0 0 0 0 ]
[ 1 .14373 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .14373 L
0 .14373 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.00342212 0.245293 0.140307 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0297619 0.0147151 0.294302 [
[.17262 .00222 -3 -9 ]
[.17262 .00222 3 0 ]
[.32143 .00222 -6 -9 ]
[.32143 .00222 6 0 ]
[.47024 .00222 -6 -9 ]
[.47024 .00222 6 0 ]
[.61905 .00222 -6 -9 ]
[.61905 .00222 6 0 ]
[.76786 .00222 -6 -9 ]
[.76786 .00222 6 0 ]
[.91667 .00222 -6 -9 ]
[.91667 .00222 6 0 ]
[.01131 .16187 -18 -4.5 ]
[.01131 .16187 0 4.5 ]
[.01131 .30902 -6 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .45617 -18 -4.5 ]
[.01131 .45617 0 4.5 ]
[.01131 .60332 -6 -4.5 ]
[.01131 .60332 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.17262 .01472 m
.17262 .02097 L
s
[(5)] .17262 .00222 0 1 Mshowa
.32143 .01472 m
.32143 .02097 L
s
[(10)] .32143 .00222 0 1 Mshowa
.47024 .01472 m
.47024 .02097 L
s
[(15)] .47024 .00222 0 1 Mshowa
.61905 .01472 m
.61905 .02097 L
s
[(20)] .61905 .00222 0 1 Mshowa
.76786 .01472 m
.76786 .02097 L
s
[(25)] .76786 .00222 0 1 Mshowa
.91667 .01472 m
.91667 .02097 L
s
[(30)] .91667 .00222 0 1 Mshowa
.125 Mabswid
.05357 .01472 m
.05357 .01847 L
s
.08333 .01472 m
.08333 .01847 L
s
.1131 .01472 m
.1131 .01847 L
s
.14286 .01472 m
.14286 .01847 L
s
.20238 .01472 m
.20238 .01847 L
s
.23214 .01472 m
.23214 .01847 L
s
.2619 .01472 m
.2619 .01847 L
s
.29167 .01472 m
.29167 .01847 L
s
.35119 .01472 m
.35119 .01847 L
s
.38095 .01472 m
.38095 .01847 L
s
.41071 .01472 m
.41071 .01847 L
s
.44048 .01472 m
.44048 .01847 L
s
.5 .01472 m
.5 .01847 L
s
.52976 .01472 m
.52976 .01847 L
s
.55952 .01472 m
.55952 .01847 L
s
.58929 .01472 m
.58929 .01847 L
s
.64881 .01472 m
.64881 .01847 L
s
.67857 .01472 m
.67857 .01847 L
s
.70833 .01472 m
.70833 .01847 L
s
.7381 .01472 m
.7381 .01847 L
s
.79762 .01472 m
.79762 .01847 L
s
.82738 .01472 m
.82738 .01847 L
s
.85714 .01472 m
.85714 .01847 L
s
.8869 .01472 m
.8869 .01847 L
s
.94643 .01472 m
.94643 .01847 L
s
.97619 .01472 m
.97619 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02381 .16187 m
.03006 .16187 L
s
[(0.5)] .01131 .16187 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(1)] .01131 .30902 1 0 Mshowa
.02381 .45617 m
.03006 .45617 L
s
[(1.5)] .01131 .45617 1 0 Mshowa
.02381 .60332 m
.03006 .60332 L
s
[(2)] .01131 .60332 1 0 Mshowa
.125 Mabswid
.02381 .04415 m
.02756 .04415 L
s
.02381 .07358 m
.02756 .07358 L
s
.02381 .10301 m
.02756 .10301 L
s
.02381 .13244 m
.02756 .13244 L
s
.02381 .1913 m
.02756 .1913 L
s
.02381 .22073 m
.02756 .22073 L
s
.02381 .25016 m
.02756 .25016 L
s
.02381 .27959 m
.02756 .27959 L
s
.02381 .33845 m
.02756 .33845 L
s
.02381 .36788 m
.02756 .36788 L
s
.02381 .39731 m
.02756 .39731 L
s
.02381 .42674 m
.02756 .42674 L
s
.02381 .4856 m
.02756 .4856 L
s
.02381 .51503 m
.02756 .51503 L
s
.02381 .54446 m
.02756 .54446 L
s
.02381 .57389 m
.02756 .57389 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.05357 .30902 m
.08333 .30902 L
.1131 .30902 L
.14286 .30902 L
.17262 .30902 L
.20238 .30902 L
.23214 .30902 L
.2619 .30902 L
.29167 .30902 L
.32143 .30902 L
.35119 .30902 L
.38095 .30902 L
.41071 .30902 L
.44048 .30902 L
.47024 .30902 L
.5 .30902 L
.52976 .30902 L
.55952 .30902 L
.58929 .30902 L
.61905 .30902 L
.64881 .30902 L
.67857 .30902 L
.70833 .30902 L
.7381 .30902 L
.76786 .30902 L
.79762 .30902 L
.82738 .30902 L
.85714 .30902 L
.8869 .30902 L
.91667 .30902 L
.94643 .30902 L
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.267442 0.00342212 0.488926 0.140307 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0297619 0.309017 0.294657 [
[.17262 .29652 -3 -9 ]
[.17262 .29652 3 0 ]
[.32143 .29652 -6 -9 ]
[.32143 .29652 6 0 ]
[.47024 .29652 -6 -9 ]
[.47024 .29652 6 0 ]
[.61905 .29652 -6 -9 ]
[.61905 .29652 6 0 ]
[.76786 .29652 -6 -9 ]
[.76786 .29652 6 0 ]
[.91667 .29652 -6 -9 ]
[.91667 .29652 6 0 ]
[.01131 .01436 -12 -4.5 ]
[.01131 .01436 0 4.5 ]
[.01131 .16169 -24 -4.5 ]
[.01131 .16169 0 4.5 ]
[.01131 .45635 -18 -4.5 ]
[.01131 .45635 0 4.5 ]
[.01131 .60367 -6 -4.5 ]
[.01131 .60367 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.17262 .30902 m
.17262 .31527 L
s
[(5)] .17262 .29652 0 1 Mshowa
.32143 .30902 m
.32143 .31527 L
s
[(10)] .32143 .29652 0 1 Mshowa
.47024 .30902 m
.47024 .31527 L
s
[(15)] .47024 .29652 0 1 Mshowa
.61905 .30902 m
.61905 .31527 L
s
[(20)] .61905 .29652 0 1 Mshowa
.76786 .30902 m
.76786 .31527 L
s
[(25)] .76786 .29652 0 1 Mshowa
.91667 .30902 m
.91667 .31527 L
s
[(30)] .91667 .29652 0 1 Mshowa
.125 Mabswid
.05357 .30902 m
.05357 .31277 L
s
.08333 .30902 m
.08333 .31277 L
s
.1131 .30902 m
.1131 .31277 L
s
.14286 .30902 m
.14286 .31277 L
s
.20238 .30902 m
.20238 .31277 L
s
.23214 .30902 m
.23214 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.29167 .30902 m
.29167 .31277 L
s
.35119 .30902 m
.35119 .31277 L
s
.38095 .30902 m
.38095 .31277 L
s
.41071 .30902 m
.41071 .31277 L
s
.44048 .30902 m
.44048 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.52976 .30902 m
.52976 .31277 L
s
.55952 .30902 m
.55952 .31277 L
s
.58929 .30902 m
.58929 .31277 L
s
.64881 .30902 m
.64881 .31277 L
s
.67857 .30902 m
.67857 .31277 L
s
.70833 .30902 m
.70833 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.79762 .30902 m
.79762 .31277 L
s
.82738 .30902 m
.82738 .31277 L
s
.85714 .30902 m
.85714 .31277 L
s
.8869 .30902 m
.8869 .31277 L
s
.94643 .30902 m
.94643 .31277 L
s
.97619 .30902 m
.97619 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 .01436 m
.03006 .01436 L
s
[(-1)] .01131 .01436 1 0 Mshowa
.02381 .16169 m
.03006 .16169 L
s
[(-0.5)] .01131 .16169 1 0 Mshowa
.02381 .45635 m
.03006 .45635 L
s
[(0.5)] .01131 .45635 1 0 Mshowa
.02381 .60367 m
.03006 .60367 L
s
[(1)] .01131 .60367 1 0 Mshowa
.125 Mabswid
.02381 .04383 m
.02756 .04383 L
s
.02381 .07329 m
.02756 .07329 L
s
.02381 .10276 m
.02756 .10276 L
s
.02381 .13222 m
.02756 .13222 L
s
.02381 .19115 m
.02756 .19115 L
s
.02381 .22062 m
.02756 .22062 L
s
.02381 .25009 m
.02756 .25009 L
s
.02381 .27955 m
.02756 .27955 L
s
.02381 .33848 m
.02756 .33848 L
s
.02381 .36795 m
.02756 .36795 L
s
.02381 .39741 m
.02756 .39741 L
s
.02381 .42688 m
.02756 .42688 L
s
.02381 .48581 m
.02756 .48581 L
s
.02381 .51528 m
.02756 .51528 L
s
.02381 .54474 m
.02756 .54474 L
s
.02381 .57421 m
.02756 .57421 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.05357 .60332 m
.08333 .60048 L
.1131 .59484 L
.14286 .58645 L
.17262 .57538 L
.20238 .56175 L
.23214 .54569 L
.2619 .52734 L
.29167 .5069 L
.32143 .48454 L
.35119 .4605 L
.38095 .435 L
.41071 .40828 L
.44048 .38061 L
.47024 .35225 L
.5 .32348 L
.52976 .29456 L
.55952 .26578 L
.58929 .23742 L
.61905 .20975 L
.64881 .18303 L
.67857 .15753 L
.70833 .13349 L
.7381 .11114 L
.76786 .09069 L
.79762 .07235 L
.82738 .05628 L
.85714 .04265 L
.8869 .03158 L
.91667 .02319 L
.94643 .01755 L
.97619 .01472 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.511074 0.00342212 0.732558 0.140307 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0297619 0.309017 0.295726 [
[.17262 .29652 -3 -9 ]
[.17262 .29652 3 0 ]
[.32143 .29652 -6 -9 ]
[.32143 .29652 6 0 ]
[.47024 .29652 -6 -9 ]
[.47024 .29652 6 0 ]
[.61905 .29652 -6 -9 ]
[.61905 .29652 6 0 ]
[.76786 .29652 -6 -9 ]
[.76786 .29652 6 0 ]
[.91667 .29652 -6 -9 ]
[.91667 .29652 6 0 ]
[.01131 .01329 -12 -4.5 ]
[.01131 .01329 0 4.5 ]
[.01131 .16115 -24 -4.5 ]
[.01131 .16115 0 4.5 ]
[.01131 .45688 -18 -4.5 ]
[.01131 .45688 0 4.5 ]
[.01131 .60474 -6 -4.5 ]
[.01131 .60474 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.17262 .30902 m
.17262 .31527 L
s
[(5)] .17262 .29652 0 1 Mshowa
.32143 .30902 m
.32143 .31527 L
s
[(10)] .32143 .29652 0 1 Mshowa
.47024 .30902 m
.47024 .31527 L
s
[(15)] .47024 .29652 0 1 Mshowa
.61905 .30902 m
.61905 .31527 L
s
[(20)] .61905 .29652 0 1 Mshowa
.76786 .30902 m
.76786 .31527 L
s
[(25)] .76786 .29652 0 1 Mshowa
.91667 .30902 m
.91667 .31527 L
s
[(30)] .91667 .29652 0 1 Mshowa
.125 Mabswid
.05357 .30902 m
.05357 .31277 L
s
.08333 .30902 m
.08333 .31277 L
s
.1131 .30902 m
.1131 .31277 L
s
.14286 .30902 m
.14286 .31277 L
s
.20238 .30902 m
.20238 .31277 L
s
.23214 .30902 m
.23214 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.29167 .30902 m
.29167 .31277 L
s
.35119 .30902 m
.35119 .31277 L
s
.38095 .30902 m
.38095 .31277 L
s
.41071 .30902 m
.41071 .31277 L
s
.44048 .30902 m
.44048 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.52976 .30902 m
.52976 .31277 L
s
.55952 .30902 m
.55952 .31277 L
s
.58929 .30902 m
.58929 .31277 L
s
.64881 .30902 m
.64881 .31277 L
s
.67857 .30902 m
.67857 .31277 L
s
.70833 .30902 m
.70833 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.79762 .30902 m
.79762 .31277 L
s
.82738 .30902 m
.82738 .31277 L
s
.85714 .30902 m
.85714 .31277 L
s
.8869 .30902 m
.8869 .31277 L
s
.94643 .30902 m
.94643 .31277 L
s
.97619 .30902 m
.97619 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 .01329 m
.03006 .01329 L
s
[(-1)] .01131 .01329 1 0 Mshowa
.02381 .16115 m
.03006 .16115 L
s
[(-0.5)] .01131 .16115 1 0 Mshowa
.02381 .45688 m
.03006 .45688 L
s
[(0.5)] .01131 .45688 1 0 Mshowa
.02381 .60474 m
.03006 .60474 L
s
[(1)] .01131 .60474 1 0 Mshowa
.125 Mabswid
.02381 .04286 m
.02756 .04286 L
s
.02381 .07244 m
.02756 .07244 L
s
.02381 .10201 m
.02756 .10201 L
s
.02381 .13158 m
.02756 .13158 L
s
.02381 .19073 m
.02756 .19073 L
s
.02381 .2203 m
.02756 .2203 L
s
.02381 .24987 m
.02756 .24987 L
s
.02381 .27944 m
.02756 .27944 L
s
.02381 .33859 m
.02756 .33859 L
s
.02381 .36816 m
.02756 .36816 L
s
.02381 .39773 m
.02756 .39773 L
s
.02381 .42731 m
.02756 .42731 L
s
.02381 .48645 m
.02756 .48645 L
s
.02381 .51603 m
.02756 .51603 L
s
.02381 .5456 m
.02756 .5456 L
s
.02381 .57517 m
.02756 .57517 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.05357 .60332 m
.08333 .59201 L
.1131 .56982 L
.14286 .53762 L
.17262 .49662 L
.20238 .44842 L
.23214 .39486 L
.2619 .338 L
.29167 .28003 L
.32143 .22317 L
.35119 .16961 L
.38095 .12141 L
.41071 .08042 L
.44048 .04821 L
.47024 .02602 L
.5 .01472 L
.52976 .01472 L
.55952 .02602 L
.58929 .04821 L
.61905 .08042 L
.64881 .12141 L
.67857 .16961 L
.70833 .22317 L
.7381 .28003 L
.76786 .338 L
.79762 .39486 L
.82738 .44842 L
.85714 .49662 L
.8869 .53762 L
.91667 .56982 L
.94643 .59201 L
.97619 .60332 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.754707 0.00342212 0.97619 0.140307 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0297619 0.309017 0.31855 [
[.17262 .29652 -3 -9 ]
[.17262 .29652 3 0 ]
[.32143 .29652 -6 -9 ]
[.32143 .29652 6 0 ]
[.47024 .29652 -6 -9 ]
[.47024 .29652 6 0 ]
[.61905 .29652 -6 -9 ]
[.61905 .29652 6 0 ]
[.76786 .29652 -6 -9 ]
[.76786 .29652 6 0 ]
[.91667 .29652 -6 -9 ]
[.91667 .29652 6 0 ]
[.01131 .0701 -30 -4.5 ]
[.01131 .0701 0 4.5 ]
[.01131 .14974 -24 -4.5 ]
[.01131 .14974 0 4.5 ]
[.01131 .22938 -30 -4.5 ]
[.01131 .22938 0 4.5 ]
[.01131 .38865 -24 -4.5 ]
[.01131 .38865 0 4.5 ]
[.01131 .46829 -18 -4.5 ]
[.01131 .46829 0 4.5 ]
[.01131 .54793 -24 -4.5 ]
[.01131 .54793 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.17262 .30902 m
.17262 .31527 L
s
[(5)] .17262 .29652 0 1 Mshowa
.32143 .30902 m
.32143 .31527 L
s
[(10)] .32143 .29652 0 1 Mshowa
.47024 .30902 m
.47024 .31527 L
s
[(15)] .47024 .29652 0 1 Mshowa
.61905 .30902 m
.61905 .31527 L
s
[(20)] .61905 .29652 0 1 Mshowa
.76786 .30902 m
.76786 .31527 L
s
[(25)] .76786 .29652 0 1 Mshowa
.91667 .30902 m
.91667 .31527 L
s
[(30)] .91667 .29652 0 1 Mshowa
.125 Mabswid
.05357 .30902 m
.05357 .31277 L
s
.08333 .30902 m
.08333 .31277 L
s
.1131 .30902 m
.1131 .31277 L
s
.14286 .30902 m
.14286 .31277 L
s
.20238 .30902 m
.20238 .31277 L
s
.23214 .30902 m
.23214 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.29167 .30902 m
.29167 .31277 L
s
.35119 .30902 m
.35119 .31277 L
s
.38095 .30902 m
.38095 .31277 L
s
.41071 .30902 m
.41071 .31277 L
s
.44048 .30902 m
.44048 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.52976 .30902 m
.52976 .31277 L
s
.55952 .30902 m
.55952 .31277 L
s
.58929 .30902 m
.58929 .31277 L
s
.64881 .30902 m
.64881 .31277 L
s
.67857 .30902 m
.67857 .31277 L
s
.70833 .30902 m
.70833 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.79762 .30902 m
.79762 .31277 L
s
.82738 .30902 m
.82738 .31277 L
s
.85714 .30902 m
.85714 .31277 L
s
.8869 .30902 m
.8869 .31277 L
s
.94643 .30902 m
.94643 .31277 L
s
.97619 .30902 m
.97619 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 .0701 m
.03006 .0701 L
s
[(-0.75)] .01131 .0701 1 0 Mshowa
.02381 .14974 m
.03006 .14974 L
s
[(-0.5)] .01131 .14974 1 0 Mshowa
.02381 .22938 m
.03006 .22938 L
s
[(-0.25)] .01131 .22938 1 0 Mshowa
.02381 .38865 m
.03006 .38865 L
s
[(0.25)] .01131 .38865 1 0 Mshowa
.02381 .46829 m
.03006 .46829 L
s
[(0.5)] .01131 .46829 1 0 Mshowa
.02381 .54793 m
.03006 .54793 L
s
[(0.75)] .01131 .54793 1 0 Mshowa
.125 Mabswid
.02381 .08603 m
.02756 .08603 L
s
.02381 .10196 m
.02756 .10196 L
s
.02381 .11789 m
.02756 .11789 L
s
.02381 .13381 m
.02756 .13381 L
s
.02381 .16567 m
.02756 .16567 L
s
.02381 .1816 m
.02756 .1816 L
s
.02381 .19752 m
.02756 .19752 L
s
.02381 .21345 m
.02756 .21345 L
s
.02381 .24531 m
.02756 .24531 L
s
.02381 .26123 m
.02756 .26123 L
s
.02381 .27716 m
.02756 .27716 L
s
.02381 .29309 m
.02756 .29309 L
s
.02381 .32494 m
.02756 .32494 L
s
.02381 .34087 m
.02756 .34087 L
s
.02381 .3568 m
.02756 .3568 L
s
.02381 .37273 m
.02756 .37273 L
s
.02381 .40458 m
.02756 .40458 L
s
.02381 .42051 m
.02756 .42051 L
s
.02381 .43644 m
.02756 .43644 L
s
.02381 .45236 m
.02756 .45236 L
s
.02381 .48422 m
.02756 .48422 L
s
.02381 .50015 m
.02756 .50015 L
s
.02381 .51607 m
.02756 .51607 L
s
.02381 .532 m
.02756 .532 L
s
.02381 .05418 m
.02756 .05418 L
s
.02381 .03825 m
.02756 .03825 L
s
.02381 .02232 m
.02756 .02232 L
s
.02381 .00639 m
.02756 .00639 L
s
.02381 .56386 m
.02756 .56386 L
s
.02381 .57978 m
.02756 .57978 L
s
.02381 .59571 m
.02756 .59571 L
s
.02381 .61164 m
.02756 .61164 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.05357 .60332 m
.08333 .43092 L
.1131 .18711 L
.14286 .01472 L
.17262 .01472 L
.20238 .18711 L
.23214 .43092 L
.2619 .60332 L
.29167 .60332 L
.32143 .43092 L
.35119 .18711 L
.38095 .01472 L
.41071 .01472 L
.44048 .18711 L
.47024 .43092 L
.5 .60332 L
.52976 .60332 L
.55952 .43092 L
.58929 .18711 L
.61905 .01472 L
.64881 .01472 L
.67857 .18711 L
.70833 .43092 L
.7381 .60332 L
.76786 .60332 L
.79762 .43092 L
.82738 .18711 L
.85714 .01472 L
.8869 .01472 L
.91667 .18711 L
.94643 .43092 L
.97619 .60332 L
s
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[22]:=",
  ImageSize->{474, 68.0625},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007J0000A1000`40O003h00Oogoofgoo003oOooK
Ool00?moom]oo`00;Woo00<007ooOol01Goo1@000Woo00<007ooOol00goo1@000Woo00<007ooOol0
0goo0`000goo00<007ooOol00goo0`000goo00<007ooOol017oo0P0017oo00<007ooOol0ogooJGoo
000]Ool00`00Ool00008Ool01`00Oomoogoo001oo`0000Ioo`07001oogooOol007oo000017oo00<0
07ooOol00Woo00<007oo000017oo00<007ooOol00Woo00<007oo00001goo00H007ooOol007oo003o
OomZOol002moo`03001oogoo00Ioo`07001oogooOol007oo00001Woo00<007ooOol00goo00<007oo
Ool00goo00L007ooOomoo`00Ool00005Ool00`00Oomoo`03Ool00`00Oomoo`04Ool01`00Oomoogoo
001oo`000?moofYoo`00;Goo0P002Goo00L007ooOomoo`00Ool00006Ool01000Oomoogoo0P001Woo
00L007ooOomoo`00Ool00005Ool01000Oomoogoo0P0027oo00H007ooOol007oo003oOomZOol002eo
o`03001oogoo00Qoo`07001oogooOol007oo00001Woo00D007ooOomoo`0000Ioo`03001oo`00009o
o`03001oo`0000Aoo`03001oo`00009oo`03001oogoo00Eoo`03001oo`00009oo`03001oo`000?mo
ofYoo`00;Goo0`001goo0P0017oo00<007ooOol017oo0P000goo0`001Goo00<007ooOol00Woo00<0
07ooOol017oo00@007ooOomoo`<000Ioo`03001oogoo009oo`03001oogoo021oo`D006eoo`D00=5o
o`00U7oo00D007ooOomoo`0006eoo`05001oogooOol0003?Ool008ioo`<000=oo`04001oogooOol2
001;Ool00`00Oomoo`0HOol30003Ool01000Oomoogoo0P0097oo1000YWoo000ROol00`00Oomoo`1_
Ool01@00Oomoogoo0000Agoo1@008Goo00D007ooOomoo`0002=oo`8000Aoo`8004aoo`03001oogoo
05Eoo`0087ooE@007goo00D007ooOomoo`0004Aoo`<002Ioo`05001oogooOol0000ROol00`00Oomo
o`06Ool2001:Ool00`00Oomoo`06Ool3000>Ool3000?Ool3000?Ool3000GOol0029oo`03001oogoo
00Yoo`03001oogoo00Uoo`03001oogoo00Yoo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo
00Yoo`03001oogoo02=oo`8000=oo`80045oo`8002Qoo`8000=oo`03001oogoo01moo`03001oogoo
00Uoo`03001oogoo04Moo`03001oogoo00Ioo`03001oo`0000ioo`03001oo`0000moo`03001oo`00
00moo`03001oo`0001Moo`008Woo00<007ooOol0Lgoo00<007ooOol0?Woo0P00;goo00<007ooOol0
7Woo00<007ooOol02goo00<007ooOol0<goo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol0
0Woo00D007ooOomoo`0000Qoo`03001oo`0000ioo`03001oo`0000moo`03001oo`0000moo`03001o
o`0001Moo`008Woo00<007ooOol0Lgoo0P00?7oo0`00<Goo00<007ooOol07Goo00<007ooOol037oo
00<007ooOol0<Woo00<007oo000027oo00L007ooOomoo`00Ool00002Ool00`00Oomoo`05Ool01000
Oomoo`003Woo00@007ooOol000ioo`03001oo`0000ioo`04001oogoo000GOol0029oo`03001oogoo
07=oo`03001oogoo03Uoo`8003Aoo`03001oogoo01aoo`03001oogoo00ioo`03001oogoo02aoo`<0
009oo`03001oo`0000Qoo`03001oogoo00=oo`04001oogoo0007Ool01@00Oomoogoo000037oo00D0
07ooOomoo`0000eoo`05001oogooOol0000=Ool01@00Oomoogoo00005Woo000ROol00`00Oomoo`1c
Ool2000iOol00`00Oomoo`0dOol00`00Oomoo`0KOol00`00Oomoo`0@Ool00`00Oomoo`0`Ool00`00
Ool00009Ool00`00Oomoo`020003Ool00`00Oomoo`05Ool01@00Oomoogoo000037oo00D007ooOomo
o`0000eoo`05001oogooOol0000=Ool01@00Oomoogoo00005Woo000ROol00`00Oomoo`1cOol00`00
Oomoo`0gOol00`00Oomoo`0eOol00`00Oomoo`0KOol00`00Oomoo`0@Ool00`00Oomoo`0`Ool00`00
Ool00007Ool00`00Ool00002Ool00`00Oomoo`02Ool00`00Oomoo`05Ool01@00Oomoogoo000037oo
00D007ooOomoo`0000eoo`05001oogooOol0000=Ool01@00Oomoogoo00005Woo000ROol00`00Oomo
o`1cOol00`00Oomoo`0eOol2000hOol00`00Oomoo`0JOol00`00Oomoo`0BOol00`00Oomoo`0`Ool0
0`00Oomoo`06Ool30002Ool30002Ool00`00Oomoo`04Ool00`00Oomoo`02Ool00`00Oomoo`0:Ool0
0`00Oomoo`02Ool00`00Oomoo`0:Ool01@00Oomoogoo000037oo00<007ooOol00Woo00<007ooOol0
57oo000ROol00`00Oomoo`1UOol00`00Oomoo`02Ool00`00Oomoo`02Ool01000Oomoogoo0P00=Goo
00<007ooOol0:Woo00<007ooOol00Woo00<007ooOol00Woo00D007ooOomoo`0001]oo`03001oogoo
01Aoo`03001oogoo03Aoo`03001oogoo009oo`03001oogoo009oo`05001oogooOol00006Ool00`00
Oomoo`02Ool00`00Oomoo`0:Ool00`00Oomoo`02Ool00`00Oomoo`0:Ool01@00Oomoogoo000037oo
00<007ooOol00Woo00<007ooOol057oo000ROol00`00Oomoo`1TOol00`00Ool00007Ool00`00Ool0
0002Ool00`00Oomoo`0cOol00`00Oomoo`0ZOol00`00Ool00007Ool00`00Ool00002Ool00`00Oomo
o`0HOol00`00Oomoo`0EOol00`00Oomoo`0cOol00`00Ool00007Ool00`00Ool00002Ool00`00Oomo
o`04Ool00`00Oomoo`02Ool00`00Oomoo`0:Ool00`00Oomoo`02Ool00`00Oomoo`0:Ool01@00Oomo
ogoo000037oo00<007ooOol00Woo00<007ooOol057oo000DOol00`00Oomoo`02Ool00`00Oomoo`02
Ool01@00Oomoogoo0000HGoo0`000Woo00<007oo00002Goo00<007ooOol00P00<goo00<007ooOol0
9Woo0`000Woo00<007oo00002Goo00<007ooOol00P006Goo00<007ooOol05Woo00<007ooOol0;Goo
0`000Woo00<007oo00002Goo00@007ooOol000Ioo`03001oogoo00=oo`03001oogoo00Qoo`03001o
ogoo00=oo`03001oogoo00Uoo`03001oogoo00=oo`03001oogoo00Uoo`03001oogoo00=oo`03001o
ogoo01=oo`004goo00<007oo00001goo00<007oo00000Woo00<007ooOol0I7oo00<007oo00001goo
0P000goo00<007ooOol0<Goo00<007ooOol0;7oo00<007oo00001goo0P000goo00<007ooOol05goo
00<007ooOol067oo00<007ooOol0<Goo00<007oo00001goo0P000goo00<007ooOol00goo00<007oo
Ool017oo00<007ooOol027oo00<007ooOol017oo00<007ooOol027oo00<007ooOol00goo00<007oo
Ool027oo00<007ooOol017oo00<007ooOol04goo000COol00`00Ool00009Ool00`00Oomoo`02001U
Ool00`00Ool00007Ool00`00Oomoo`02Ool00`00Oomoo`0`Ool00`00Oomoo`0]Ool00`00Ool00007
Ool00`00Oomoo`02Ool00`00Oomoo`0FOol00`00Oomoo`0IOol00`00Oomoo`0aOol00`00Ool00007
Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`04Ool00`00Oomoo`08Ool00`00Oomoo`04
Ool00`00Oomoo`08Ool00`00Oomoo`03Ool00`00Oomoo`08Ool00`00Oomoo`04Ool00`00Oomoo`0C
Ool001=oo`03001oo`0000Moo`8000=oo`03001oogoo06Eoo`03001oogoo00Ioo`<0009oo`8000Yo
o`03001oogoo00Aoo`D0009oo`03001oogoo009oo`D0009oo`03001oogoo00=oo`<0009oo`8000Eo
o`<000=oo`03001oogoo00=oo`8000Aoo`03001oogoo01Moo`03001oogoo00Ioo`<0009oo`03001o
ogoo00Uoo`03001oogoo00Aoo`D00003Ool0000000Aoo`D0009oo`03001oogoo00=oo`<000=oo`06
001oogooOol007oo0`000goo00<007ooOol00goo0P0017oo00<007ooOol07Goo00<007ooOol01Woo
0`000Woo00<007ooOol00goo00D007ooOomoo`00009oo`04001oogooOol50002Ool01000Oomoogoo
1@000Woo00<007ooOol00Woo0`000goo00<007oo00000Woo0`000goo00<007oo00000Woo0P000Woo
00<007oo00004goo000COol00`00Ool00007Ool00`00Oomoo`02Ool00`00Oomoo`1cOol00`00Oomo
o`08Ool00`00Ool00007Ool01`00Oomoogoo001oo`0000Eoo`07001oogooOol007oo000017oo00@0
07ooOomoo`800003Ool007oo00=oo`03001oogoo009oo`03001oo`0000Ioo`06001oogoo001oo`00
9Woo00<007ooOol027oo00<007oo00001goo00<007ooOol00P0000=oo`00Ool017oo00L007ooOomo
o`00Ool00004Ool00`00Oomoo`02Ool00`00Ool00002Ool00`00Ool00004Ool00`00Ool00006Ool0
1P00Oomoo`00Ool001Uoo`03001oogoo009oo`04001oogooOol30003Ool01@00Oomoogoo00001Goo
00P007ooOol007oo001oo`001Goo00@007ooOomoo`<000Aoo`80009oo`03001oo`0000=oo`03001o
o`00009oo`04001oo`000002Ool00`00Oomoo`02Ool01000Ool0000017oo00H007oo000007oo000B
Ool001Aoo`03001oogoo00Ioo`<0009oo`03001oogoo07=oo`8000]oo`03001oogoo00Eoo`07001o
ogooOol007oo00001Goo00<007ooOol00goo00<007ooOol00goo00L007oo001oo`00Ool00005Ool0
0`00Oomoo`03Ool00`00Oomoo`03Ool01`00Oomoogoo001oo`0002Ioo`03001oogoo00Yoo`03001o
ogoo00Eoo`03001oogoo00800003Ool007oo00Aoo`03001oogoo00=oo`03001oogoo00=oo`07001o
ogooOol007oo00000goo00<007oo00001Goo00<007ooOol00goo00L007ooOomoo`00Ool0000HOol0
0`00Ool00007Ool00`00Oomoo`02Ool00`00Ool00002Ool00`00Oomoo`03Ool00`00Oomoo`02Ool0
0`00Ool00005Ool01000Oomoogoo0`0017oo0P0017oo00<007ooOol00Woo0P000Woo00@007oo0000
00=oo`03001oogoo00=oo`8000=oo`03001oogoo00800003Ool007oo015oo`008Woo00<007ooOol0
Lgoo00<007ooOol027oo0P0027oo00L007ooOomoo`00Ool00005Ool01000Oomoogoo0P001Woo0P00
0Woo00<007oo00001Goo00@007ooOomoo`8000Moo`06001oogoo001oo`009Woo00<007ooOol027oo
0P0027oo00<007ooOol00P0000=oo`00Ool017oo00@007ooOomoo`8000Ioo`07001oogooOol007oo
00000goo00<007oo00000goo0P001goo00H007ooOol007oo000COol30002Ool00`00Ool00008Ool0
0`00Oomoo`03Ool01000Oomoo`001Goo00<007ooOol00P000Woo00<007ooOol00goo00@007ooOomo
o`<000Aoo`80009oo`8000Eoo`06001oogooOol007oo0P000goo00@007ooOomoo`800003Ool007oo
00=oo`06001oo`00001oo`004Woo000ROol00`00Oomoo`1cOol20009Ool00`00Oomoo`07Ool01`00
Oomoogoo001oo`0000Eoo`05001oogooOol00006Ool30002Ool00`00Ool00004Ool00`00Ool00002
Ool00`00Oomoo`04Ool00`00Ool00002Ool00`00Ool0000VOol00`00Oomoo`08Ool00`00Oomoo`07
Ool01`00Ool007oo001oo`0000Eoo`05001oogooOol00006Ool00`00Ool00002Ool00`00Ool00004
Ool00`00Ool00002Ool00`00Oomoo`04Ool00`00Ool00002Ool00`00Ool0000HOol00`00Ool00008
Ool01000Oomoogoo0P000goo00<007ooOol00goo00@007ooOol000=oo`03001oogoo00=oo`04001o
ogooOol30004Ool20002Ool00`00Oomoo`03Ool30002Ool01000Ool000000Woo00<007oo00000Woo
00@007ooOol0009oo`04001oo`00Ool200000goo001oo`0AOol0029oo`03001oogoo07=oo`03001o
ogoo00Qoo`<000Ioo`8000Aoo`03001oogoo00=oo`8000=oo`<000Aoo`8000Aoo`03001oogoo00Ao
o`04001oogooOol30005Ool00`00Oomoo`02Ool00`00Oomoo`0UOol00`00Oomoo`08Ool30006Ool2
00001Goo001oogoo00001Goo0P000goo0`001Goo00<007ooOol00Woo00<007ooOol00goo0P000goo
0`001Goo00<007ooOol00Woo00<007ooOol05goo00<007oo00001goo00<007oo00000Woo00<007oo
Ool00Woo00<007ooOol00Woo00@007ooOomoo`<0009oo`04001oogooOol20003Ool20004Ool20000
0goo001oo`030004Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOomoo`<000Aoo`04001o
ogooOol2000COol0029oo`03001oogoo07=oo`03001oogoo02Qoo`03001oogoo04Aoo`03001oogoo
01=oo`03001oogoo021oo`03001oogoo02Uoo`03001oogoo00Moo`04001oogooOol30002Ool00`00
Oomoo`02Ool00`00Oomoo`06Ool00`00Oomoo`06Ool00`00Oomoo`06Ool00`00Oomoo`06Ool00`00
Oomoo`05Ool00`00Oomoo`06Ool00`00Oomoo`06Ool00`00Oomoo`0BOol0029oo`03001oogoo07=o
o`8002Qoo`03001oogoo04Eoo`03001oogoo01=oo`03001oogoo021oo`03001oogoo03aoo`03001o
ogoo009oo`03001oogoo00Ioo`03001oogoo00Ioo`03001oogoo00Ioo`03001oogoo00Ioo`03001o
ogoo00Eoo`03001oogoo00Ioo`03001oogoo00Ioo`03001oogoo019oo`008Woo00<007ooOol0Lgoo
00<007ooOol09Woo00<007ooOol0AWoo00<007ooOol04Woo00<007ooOol08Woo00<007ooOol0>goo
00<007ooOol00Woo00<007ooOol01Woo00<007ooOol01Woo00<007ooOol01Woo00<007ooOol01Woo
00<007ooOol01Goo00<007ooOol01Woo00<007ooOol01Woo00<007ooOol04Woo000ROol00`00Oomo
o`1bOomA000POomB000VOom;000?Ool001aoo`D00003Ool007oo07Aoo`03001oogoo00Uoo`03001o
ogoo00Uoo`03001oogoo00Uoo`04001oogoo0008Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00
Oomoo`0WOol00`00Oomoo`09Ool00`00Oomoo`05Ool01@00Oomoogoo00002goo00<007ooOol02Goo
00<007ooOol027oo0P002goo00<007ooOol0;Goo00<007ooOol00Woo00<007ooOol01Woo00<007oo
Ool01Woo00<007ooOol01Woo00<007ooOol01Goo00<007ooOol01Woo00<007ooOol01Woo00<007oo
Ool01Woo00<007ooOol04Woo000NOol01@00Oomoogoo0000MGoo0P008goo0P00Bgoo00<007ooOol0
47oo00<007ooOol09Woo00<007ooOol0>Goo00<007ooOol00Woo00<007ooOol01Woo00<007ooOol0
1Woo00<007ooOol01Woo00<007ooOol01Goo00<007ooOol01Woo00<007ooOol01Woo00<007ooOol0
1Woo00<007ooOol04Woo000NOol01000Oomoogoo0P0000=oo`000000C0009Goo00<007ooOol08Goo
00<007ooOol0Bgoo00<007ooOol047oo00<007ooOol09Woo00<007ooOol0>Goo00<007ooOol00Woo
00<007ooOol01Woo00<007ooOol01Woo00<007ooOol01Woo00<007ooOol01Goo00<007ooOol01Woo
00<007ooOol01Woo00<007ooOol01Woo00<007ooOol04Woo000NOol01@00Oomoogoo0000MGoo00<0
07ooOol087oo00<007ooOol0C7oo00<007ooOol03goo00<007ooOol0:7oo00<007ooOol09Goo00<0
07ooOol00Woo00@007ooOomoo`<000=oo`05001oogooOol00004Ool00`00Oomoo`06Ool00`00Oomo
o`06Ool00`00Oomoo`06Ool00`00Oomoo`05Ool00`00Oomoo`06Ool00`00Oomoo`06Ool00`00Oomo
o`06Ool00`00Oomoo`0BOol001ioo`05001oogooOol0001eOol2000QOol00`00Oomoo`1<Ool00`00
Oomoo`0?Ool00`00Oomoo`0XOol00`00Oomoo`0TOol00`00Ool00007Ool00`00Oomoo`02Ool00`00
Ool00002Ool01@00Oomoogoo00002Woo00<007ooOol017oo00<007ooOol027oo00<007ooOol017oo
00<007ooOol01goo00<007ooOol017oo00<007ooOol027oo00<007ooOol04Goo000MOol20003Ool0
0`00Oomoo`1cOol00`00Oomoo`0OOol00`00Oomoo`1=Ool00`00Oomoo`0>Ool00`00Oomoo`0ZOol0
0`00Oomoo`0SOol00`00Ool00008Ool00`00Oomoo`03Ool01000Oomoo`000goo00<007ooOol027oo
00<007ooOol017oo00<007ooOol027oo00<007ooOol00goo00<007ooOol027oo00<007ooOol017oo
00<007ooOol027oo00<007ooOol04Goo000ROol00`00Oomoo`1cOol2000OOol00`00Oomoo`1>Ool0
0`00Oomoo`0>Ool00`00Oomoo`0ZOol00`00Oomoo`0SOol00`00Ool00008Ool01000Oomoogoo0P00
0goo00D007ooOomoo`0000Yoo`03001oogoo00Aoo`03001oogoo00Qoo`03001oogoo00=oo`03001o
ogoo00Qoo`03001oogoo00Aoo`03001oogoo00Qoo`03001oogoo015oo`008Woo00<007ooOol0Lgoo
00<007ooOol07Goo00<007ooOol0Cgoo00<007ooOol03Goo00<007ooOol0;7oo00<007ooOol08Woo
00<007oo00001goo00<007oo00000Woo00<007ooOol00Woo00D007ooOomoo`0000Yoo`03001oogoo
00Aoo`03001oogoo00Qoo`03001oogoo00=oo`03001oogoo00Qoo`03001oogoo00Aoo`03001oogoo
00Qoo`03001oogoo015oo`008Woo00<007ooOol0Lgoo0P0077oo0P00DWoo00<007ooOol037oo00<0
07ooOol0;Goo00<007ooOol08goo00<007ooOol01goo00@007ooOomoo`<0009oo`05001oogooOol0
000:Ool00`00Oomoo`04Ool00`00Oomoo`08Ool00`00Oomoo`03Ool00`00Oomoo`08Ool00`00Oomo
o`04Ool00`00Oomoo`08Ool00`00Oomoo`0AOol0029oo`03001oogoo06Eoo`03001oogoo009oo`03
001oogoo009oo`05001oogooOol0000LOol00`00Oomoo`14Ool00`00Oomoo`02Ool00`00Oomoo`02
Ool01@00Oomoogoo00003Woo00<007ooOol0;Woo00<007ooOol09goo00<007ooOol00Woo00<007oo
Ool00Woo00D007ooOomoo`0000=oo`03001oogoo00Qoo`03001oogoo00Aoo`03001oogoo00Qoo`03
001oogoo00=oo`03001oogoo00Qoo`03001oogoo00Aoo`03001oogoo00Qoo`03001oogoo015oo`00
8Woo00<007ooOol0I7oo00<007oo00001goo00<007oo00000Woo00<007ooOol06Goo00<007ooOol0
A7oo00<007oo00001goo00<007oo00000Woo00<007ooOol02goo00<007ooOol0<7oo00<007ooOol0
9Goo00<007oo00001goo00<007oo00000Woo00D007ooOomoo`0000Yoo`03001oogoo00Aoo`03001o
ogoo00Qoo`03001oogoo00=oo`03001oogoo00Qoo`03001oogoo00Aoo`03001oogoo00Qoo`03001o
ogoo015oo`008Woo00<007ooOol0I7oo00<007oo00002Goo00<007ooOol00P006Goo00<007ooOol0
AGoo00<007oo00002Goo00<007ooOol00P002goo00<007ooOol0<Goo00<007ooOol09Goo00<007oo
00002Goo00@007ooOol000=oo`03001oogoo00Qoo`03001oogoo00Aoo`03001oogoo00Qoo`03001o
ogoo00=oo`03001oogoo00Uoo`03001oogoo00=oo`03001oogoo00Qoo`03001oogoo015oo`004Woo
1@000Woo00<007ooOol00Woo00D007ooOomoo`0006Ioo`03001oo`0000Moo`8000=oo`03001oogoo
01Ioo`8004Qoo`03001oo`0000Moo`8000=oo`03001oogoo00Yoo`03001oogoo039oo`03001oogoo
02Aoo`03001oo`0000Moo`8000=oo`04001oogoo000<Ool00`00Oomoo`02Ool00`00Oomoo`0:Ool0
1@00Oomoogoo000037oo00<007ooOol00Woo00<007ooOol02Woo00<007ooOol047oo000DOol00`00
Oomoo`06Ool00`00Ool00002Ool00`00Oomoo`1TOol00`00Ool00007Ool00`00Oomoo`02Ool2000F
Ool00`00Oomoo`18Ool00`00Ool00007Ool00`00Oomoo`02Ool00`00Oomoo`09Ool00`00Oomoo`0c
Ool00`00Oomoo`0TOol00`00Ool00007Ool00`00Oomoo`02Ool01000Oomoo`0037oo00<007ooOol0
0Woo00<007ooOol02Woo00D007ooOomoo`0000aoo`03001oogoo009oo`03001oogoo00Yoo`03001o
ogoo011oo`0057oo00<007ooOol027oo00<007ooOol00P00IWoo00<007ooOol01Woo0`000Woo00<0
07ooOol057oo00<007ooOol0BWoo00<007ooOol01Woo0`000Woo00<007ooOol02Goo00<007ooOol0
=7oo00<007ooOol097oo00<007ooOol01Woo0`000Woo00@007ooOol000aoo`03001oogoo009oo`03
001oogoo00Yoo`05001oogooOol0000<Ool00`00Oomoo`02Ool00`00Oomoo`0:Ool00`00Oomoo`0@
Ool001Aoo`03001oogoo00Ioo`8000=oo`03001oogoo07=oo`03001oogoo01=oo`03001oogoo05Uo
o`03001oogoo00Qoo`03001oogoo03Ioo`03001oogoo01ioo`03001oogoo009oo`03001oogoo009o
o`03001oogoo009oo`05001oogooOol00002Ool00`00Oomoo`0:Ool00`00Oomoo`02Ool00`00Oomo
o`0:Ool01@00Oomoogoo00003Goo00D007ooOomoo`0000aoo`03001oogoo011oo`0057oo00<007oo
Ool01Woo00<007ooOol00Woo00<007ooOol0Lgoo0P004goo00<007ooOol0FWoo00<007ooOol027oo
00<007ooOol0=Woo00<007ooOol07Goo00<007oo000027oo00L007ooOomoo`00Ool00002Ool01000
Oomoo`0037oo00<007ooOol00Woo00<007ooOol02Woo00D007ooOomoo`0000eoo`05001oogooOol0
000<Ool00`00Oomoo`0@Ool001=oo`8000Qoo`<0009oo`03001oogoo07=oo`03001oogoo011oo`80
05eoo`03001oogoo00Moo`03001oogoo03Qoo`03001oogoo01aoo`03001oo`0000Qoo`03001oogoo
00=oo`04001oogoo0002Ool00`00Oomoo`0:Ool00`00Oomoo`02Ool00`00Oomoo`0:Ool01@00Oomo
ogoo00003Goo00D007ooOomoo`0000aoo`03001oogoo011oo`008Woo00<007ooOol0Lgoo0P003goo
0P00Ggoo00<007ooOol01Woo00<007ooOol0>Woo00<007ooOol06goo00<007oo00002Goo00<007oo
Ool00P000goo00<007oo00003Woo00@007ooOol000ioo`03001oo`0000ioo`04001oogoo000>Ool0
0`00Oomoo`0?Ool0029oo`03001oogoo07=oo`03001oogoo00]oo`<0065oo`03001oogoo00Eoo`03
001oogoo03aoo`03001oogoo01Yoo`03001oo`0000Moo`03001oo`00009oo`03001oogoo009oo`03
001oo`0000ioo`04001oogoo000>Ool00`00Ool0000?Ool00`00Ool0000>Ool00`00Oomoo`0?Ool0
029oo`03001oogoo07=oo`8000Yoo`8006Aoo`03001oogoo00Aoo`03001oogoo03ioo`03001oogoo
01Yoo`03001oogoo00Ioo`<0009oo`<0009oo`03001oo`0000ioo`04001oogoo000>Ool00`00Ool0
000?Ool00`00Ool0000>Ool00`00Oomoo`0?Ool0029oo`03001oogoo06eoo`D00003Ool007oo00Qo
o`80061oo`D00003Ool007oo00Aoo`03001oogoo041oo`03001oogoo02aoo`03001oo`0000ioo`@0
00ioo`<000moo`<000ioo`03001oogoo00moo`008Woo00<007ooOol0Kgoo00D007ooOomoo`0000Ao
o`D006Aoo`05001oogooOol00004Ool00`00Oomoo`12Ool2000/Ool00`00Oomoo`1EOol0029oo`03
001oogoo06moo`04001oogooOol200000goo0000001YOol01000Oomoogoo0P0000=oo`000000Agoo
0P00PWoo000MOol30002Ool00`00Oomoo`1_Ool01@00Oomoogoo0000KGoo00D007ooOomoo`000<mo
o`007Goo00<007ooOol00Woo00<007ooOol0Kgoo00<007ooOol0Kgoo00<007ooOol0dGoo000NOol0
1000Oomoogoo0P00Kgoo0P00L7oo0P00dgoo000NOol01@00Oomoogoo0000ogoo^7oo000MOol00`00
Ool00002Ool00`00Oomoo`3oOonfOol001ioo`03001oogoo0?mookYoo`00ogoofgoo003oOooKOol0
0?moom]oo`00\
\>"],
  ImageRangeCache->{{{0, 473}, {67.0625, 0}} -> {-0.128886, -0.0143759, 
  0.00900164, 0.00900164}, {{14.3125, 117.625}, {65.4375, 
  1.5625}} -> {-13.8677, -0.473263, 0.400936, 0.0405455}, {{127.938, 
  231.313}, {65.4375, 1.5625}} -> {-64.0096, -1.4188, 0.418524, 0.0422731}, {{
  241.625, 345}, {65.4375, 1.5625}} -> {-111.591, -1.41367, 0.418524, 
  0.0421203}, {{355.313, 458.625}, {65.4375, 1.5625}} -> {-175.018, -1.42091, 
  0.453133, 0.0423359}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Fast Cosine Transform", "Subsection"],

Cell[TextData[{
  "The most straigthforward way to implement the DCT is to follow the \
defining equations (1) and (2). However, for a general length ",
  Cell[BoxData[
      \(TraditionalForm\`N\)]],
  " real sequence, the number of muliplications is of the order of ",
  Cell[BoxData[
      \(TraditionalForm\`N\^2\)]],
  ". In the more important 2D case, with arrays of dimensions ",
  Cell[BoxData[
      \(TraditionalForm\`N\ x\ N\)]],
  ", the number of multiplications is on the order of ",
  Cell[BoxData[
      \(TraditionalForm\`2  N\^3\)]],
  " using a separable approach of computing 1D row and column DCTs (see \
below). Specifically, for an 8-by-8 array, we have 1024 multiplications and \
896 additions. This by far exceeds the computational complexity of an \
FFT-like algorithm with number of multiplications on the order of ",
  Cell[BoxData[
      \(TraditionalForm\`2\ N\^2\ log\_2\ N\)]],
  ". Here we explore the connection between the DCT and DFT and derive a fast \
DCT implementation [Ahmed et al., 1974; Chen et al, 1977; Narasimha and \
Peterson, 1978; Tseng and Miller, 1978; Makhoul, 1980]."
}], "Text"],

Cell[TextData[{
  "Given ",
  Cell[BoxData[
      \(TraditionalForm\`x\&~[n]\)]],
  ", a ",
  Cell[BoxData[
      \(TraditionalForm\`2  N\)]],
  "-point even extension of an ",
  Cell[BoxData[
      \(TraditionalForm\`N\)]],
  "-point sequence ",
  Cell[BoxData[
      \(TraditionalForm\`x[n]\)]],
  ", that is,"
}], "Text"],

Cell[TextData[Cell[BoxData[
    FormBox[
      RowBox[{\(x\&~[n]\), "  ", "=", "  ", 
        RowBox[{"{", GridBox[{
              {\(x[n]\ , \), \(n = \ 0, \ 1, \ \( ... \ N\) - 1\)},
              {\(x[2  N\  - \ n - 1]\ , \), \(n = \ N, \ N + 1, \ 
                \( ... \ 2  N\) - 1\)}
              },
            ColumnAlignments->{Left}]}]}], TraditionalForm]]]], 
  "NumberedEquation"],

Cell["For example,", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[
      GraphicsArray[
        \(DiscretePlot[#1, DisplayFunction -> Identity]\ &\)\ /@
          \ {Range[0, 8], \ Join[Range[0, 8], Reverse[Range[0, 8]]]}]]; 
    \)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .2943 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.00700719 0.47619 [
[ 0 0 0 0 ]
[ 1 .2943 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .2943 L
0 .2943 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.00700719 0.477324 0.287295 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.119048 0.0147151 0.0735755 [
[.2619 .00222 -3 -9 ]
[.2619 .00222 3 0 ]
[.5 .00222 -3 -9 ]
[.5 .00222 3 0 ]
[.7381 .00222 -3 -9 ]
[.7381 .00222 3 0 ]
[.97619 .00222 -3 -9 ]
[.97619 .00222 3 0 ]
[.01131 .16187 -6 -4.5 ]
[.01131 .16187 0 4.5 ]
[.01131 .30902 -6 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .45617 -6 -4.5 ]
[.01131 .45617 0 4.5 ]
[.01131 .60332 -6 -4.5 ]
[.01131 .60332 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.2619 .01472 m
.2619 .02097 L
s
[(2)] .2619 .00222 0 1 Mshowa
.5 .01472 m
.5 .02097 L
s
[(4)] .5 .00222 0 1 Mshowa
.7381 .01472 m
.7381 .02097 L
s
[(6)] .7381 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(8)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.08333 .01472 m
.08333 .01847 L
s
.14286 .01472 m
.14286 .01847 L
s
.20238 .01472 m
.20238 .01847 L
s
.32143 .01472 m
.32143 .01847 L
s
.38095 .01472 m
.38095 .01847 L
s
.44048 .01472 m
.44048 .01847 L
s
.55952 .01472 m
.55952 .01847 L
s
.61905 .01472 m
.61905 .01847 L
s
.67857 .01472 m
.67857 .01847 L
s
.79762 .01472 m
.79762 .01847 L
s
.85714 .01472 m
.85714 .01847 L
s
.91667 .01472 m
.91667 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02381 .16187 m
.03006 .16187 L
s
[(2)] .01131 .16187 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(4)] .01131 .30902 1 0 Mshowa
.02381 .45617 m
.03006 .45617 L
s
[(6)] .01131 .45617 1 0 Mshowa
.02381 .60332 m
.03006 .60332 L
s
[(8)] .01131 .60332 1 0 Mshowa
.125 Mabswid
.02381 .0515 m
.02756 .0515 L
s
.02381 .08829 m
.02756 .08829 L
s
.02381 .12508 m
.02756 .12508 L
s
.02381 .19865 m
.02756 .19865 L
s
.02381 .23544 m
.02756 .23544 L
s
.02381 .27223 m
.02756 .27223 L
s
.02381 .3458 m
.02756 .3458 L
s
.02381 .38259 m
.02756 .38259 L
s
.02381 .41938 m
.02756 .41938 L
s
.02381 .49296 m
.02756 .49296 L
s
.02381 .52974 m
.02756 .52974 L
s
.02381 .56653 m
.02756 .56653 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.00741 w
.02381 .01472 m
.02381 .01472 L
s
.14286 .01472 m
.14286 .08829 L
s
.2619 .01472 m
.2619 .16187 L
s
.38095 .01472 m
.38095 .23544 L
s
.5 .01472 m
.5 .30902 L
s
.61905 .01472 m
.61905 .38259 L
s
.7381 .01472 m
.7381 .45617 L
s
.85714 .01472 m
.85714 .52974 L
s
.97619 .01472 m
.97619 .60332 L
s
.02224 w
.02381 .01472 Mdot
.14286 .08829 Mdot
.2619 .16187 Mdot
.38095 .23544 Mdot
.5 .30902 Mdot
.61905 .38259 Mdot
.7381 .45617 Mdot
.85714 .52974 Mdot
.97619 .60332 Mdot
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.00700719 0.97619 0.287295 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0560224 0.0147151 0.0735755 [
[.16387 .00222 -9 -9 ]
[.16387 .00222 9 0 ]
[.30392 .00222 -3 -9 ]
[.30392 .00222 3 0 ]
[.44398 .00222 -9 -9 ]
[.44398 .00222 9 0 ]
[.58403 .00222 -6 -9 ]
[.58403 .00222 6 0 ]
[.72409 .00222 -12 -9 ]
[.72409 .00222 12 0 ]
[.86415 .00222 -6 -9 ]
[.86415 .00222 6 0 ]
[.01131 .16187 -6 -4.5 ]
[.01131 .16187 0 4.5 ]
[.01131 .30902 -6 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .45617 -6 -4.5 ]
[.01131 .45617 0 4.5 ]
[.01131 .60332 -6 -4.5 ]
[.01131 .60332 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.16387 .01472 m
.16387 .02097 L
s
[(2.5)] .16387 .00222 0 1 Mshowa
.30392 .01472 m
.30392 .02097 L
s
[(5)] .30392 .00222 0 1 Mshowa
.44398 .01472 m
.44398 .02097 L
s
[(7.5)] .44398 .00222 0 1 Mshowa
.58403 .01472 m
.58403 .02097 L
s
[(10)] .58403 .00222 0 1 Mshowa
.72409 .01472 m
.72409 .02097 L
s
[(12.5)] .72409 .00222 0 1 Mshowa
.86415 .01472 m
.86415 .02097 L
s
[(15)] .86415 .00222 0 1 Mshowa
.125 Mabswid
.05182 .01472 m
.05182 .01847 L
s
.07983 .01472 m
.07983 .01847 L
s
.10784 .01472 m
.10784 .01847 L
s
.13585 .01472 m
.13585 .01847 L
s
.19188 .01472 m
.19188 .01847 L
s
.21989 .01472 m
.21989 .01847 L
s
.2479 .01472 m
.2479 .01847 L
s
.27591 .01472 m
.27591 .01847 L
s
.33193 .01472 m
.33193 .01847 L
s
.35994 .01472 m
.35994 .01847 L
s
.38796 .01472 m
.38796 .01847 L
s
.41597 .01472 m
.41597 .01847 L
s
.47199 .01472 m
.47199 .01847 L
s
.5 .01472 m
.5 .01847 L
s
.52801 .01472 m
.52801 .01847 L
s
.55602 .01472 m
.55602 .01847 L
s
.61204 .01472 m
.61204 .01847 L
s
.64006 .01472 m
.64006 .01847 L
s
.66807 .01472 m
.66807 .01847 L
s
.69608 .01472 m
.69608 .01847 L
s
.7521 .01472 m
.7521 .01847 L
s
.78011 .01472 m
.78011 .01847 L
s
.80812 .01472 m
.80812 .01847 L
s
.83613 .01472 m
.83613 .01847 L
s
.89216 .01472 m
.89216 .01847 L
s
.92017 .01472 m
.92017 .01847 L
s
.94818 .01472 m
.94818 .01847 L
s
.97619 .01472 m
.97619 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02381 .16187 m
.03006 .16187 L
s
[(2)] .01131 .16187 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(4)] .01131 .30902 1 0 Mshowa
.02381 .45617 m
.03006 .45617 L
s
[(6)] .01131 .45617 1 0 Mshowa
.02381 .60332 m
.03006 .60332 L
s
[(8)] .01131 .60332 1 0 Mshowa
.125 Mabswid
.02381 .0515 m
.02756 .0515 L
s
.02381 .08829 m
.02756 .08829 L
s
.02381 .12508 m
.02756 .12508 L
s
.02381 .19865 m
.02756 .19865 L
s
.02381 .23544 m
.02756 .23544 L
s
.02381 .27223 m
.02756 .27223 L
s
.02381 .3458 m
.02756 .3458 L
s
.02381 .38259 m
.02756 .38259 L
s
.02381 .41938 m
.02756 .41938 L
s
.02381 .49296 m
.02756 .49296 L
s
.02381 .52974 m
.02756 .52974 L
s
.02381 .56653 m
.02756 .56653 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.00605 w
.02381 .01472 m
.02381 .01472 L
s
.07983 .01472 m
.07983 .08829 L
s
.13585 .01472 m
.13585 .16187 L
s
.19188 .01472 m
.19188 .23544 L
s
.2479 .01472 m
.2479 .30902 L
s
.30392 .01472 m
.30392 .38259 L
s
.35994 .01472 m
.35994 .45617 L
s
.41597 .01472 m
.41597 .52974 L
s
.47199 .01472 m
.47199 .60332 L
s
.52801 .01472 m
.52801 .60332 L
s
.58403 .01472 m
.58403 .52974 L
s
.64006 .01472 m
.64006 .45617 L
s
.69608 .01472 m
.69608 .38259 L
s
.7521 .01472 m
.7521 .30902 L
s
.80812 .01472 m
.80812 .23544 L
s
.86415 .01472 m
.86415 .16187 L
s
.92017 .01472 m
.92017 .08829 L
s
.97619 .01472 m
.97619 .01472 L
s
.01815 w
.02381 .01472 Mdot
.07983 .08829 Mdot
.13585 .16187 Mdot
.19188 .23544 Mdot
.2479 .30902 Mdot
.30392 .38259 Mdot
.35994 .45617 Mdot
.41597 .52974 Mdot
.47199 .60332 Mdot
.52801 .60332 Mdot
.58403 .52974 Mdot
.64006 .45617 Mdot
.69608 .38259 Mdot
.7521 .30902 Mdot
.80812 .23544 Mdot
.86415 .16187 Mdot
.92017 .08829 Mdot
.97619 .01472 Mdot
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{417.25, 122.75},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006Q0000NQ000`40O003h00OogooXWoo003oOonR
Ool00?mooj9oo`00ogooXWoo0010Ool3000WOol3000UOol2000WOol00`00Oomoo`0kOol30003Ool0
0`00Oomoo`02Ool00`00Oomoo`0@Ool00`00Oomoo`0@Ool00`00Oomoo`02Ool00`00Oomoo`02Ool0
0`00Oomoo`0;Ool50002Ool00`00Oomoo`09Ool5000017oo000000000goo00<007ooOol00Woo00<0
07ooOol02Goo1@000Woo00<007ooOol09Goo0010Ool00`00Oomoo`0XOol00`00Oomoo`0TOol00`00
Ool0000UOol00`00Ool0000lOol00`00Oomoo`07Ool00`00Ool0000@Ool00`00Ool0000AOol00`00
Oomoo`06Ool00`00Ool0000>Ool01`00Oomoogoo001oo`0000aoo`05001oogooOol00009Ool00`00
Ool0000<Ool01`00Oomoogoo001oo`0002Ioo`00@Goo00<007ooOol09Goo10009Goo00<007oo0000
9Goo00<007oo0000?Goo00<007ooOol027oo00<007ooOol047oo00<007ooOol03goo00<007ooOol0
27oo00<007ooOol037oo00L007ooOomoo`00Ool0000<Ool00`00Oomoo`02Ool00`00Oomoo`08Ool0
0`00Oomoo`0:Ool00`00Oomoo`03Ool00`00Oomoo`0TOol0045oo`03001oogoo02Eoo`03001oo`00
02Ioo`8002Moo`03001oogoo03aoo`03001oogoo00Ioo`80015oo`8001=oo`03001oogoo00Eoo`80
00moo`07001oogooOol007oo000037oo00<007ooOol00Woo00<007ooOol01Woo0P003Goo00@007oo
Oomoo`8002Moo`00@7oo00<007oo00009goo0P009Woo00<007ooOol09Goo00<007oo0000?7oo00<0
07oo00001goo00<007ooOol047oo00<007ooOol047oo00<007oo00001goo00<007ooOol03Woo00L0
07ooOomoo`00Ool0000<Ool01`00Oomoogoo001oo`0000Moo`03001oogoo00aoo`05001oogooOol0
000XOol0045oo`03001oogoo02Moo`03001oogoo02Eoo`8002Ioo`03001oogoo03aoo`03001oogoo
00Ioo`<0011oo`<0011oo`<000Moo`<000eoo`8000Aoo`03001oogoo00Yoo`8000Aoo`03001oogoo
00Ioo`<000]oo`8000=oo`<002Ioo`00ogooXWoo000IOol00`00Oomoo`3<Ool00`00Oomoo`2fOol0
01Uoo`03001oogoo0<aoo`03001oogoo0;Ioo`006Goo00<007ooOol0c7oo00<007ooOol0Wgoo00<0
07ooOol057oo000EOon/000SOon[000BOol001Uoo`03001oogoo019oo`03001oogoo015oo`03001o
ogoo015oo`03001oogoo015oo`03001oogoo019oo`03001oogoo015oo`03001oogoo015oo`03001o
ogoo019oo`03001oogoo02Uoo`03001oogoo00Ioo`03001oogoo00Moo`03001oogoo009oo`05001o
ogooOol00009Ool00`00Oomoo`06Ool00`00Oomoo`07Ool00`00Oomoo`06Ool00`00Oomoo`02Ool0
0`00Oomoo`02Ool00`00Oomoo`07Ool00`00Oomoo`06Ool00`00Oomoo`07Ool00`00Oomoo`06Ool0
0`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`06Ool00`00Oomoo`07Ool00`00Oomoo`06Ool0
0`00Oomoo`07Ool00`00Oomoo`0DOol001Uoo`03001oogoo019oo`03001oogoo015oo`03001oogoo
015oo`03001oogoo015oo`03001oogoo019oo`03001oogoo015oo`03001oogoo015oo`03001oogoo
019oo`03001oogoo02Uoo`03001oogoo00Ioo`03001oogoo00Moo`03001oogoo00Ioo`03001oogoo
00Moo`03001oogoo00Ioo`03001oogoo00Moo`03001oogoo00Ioo`03001oogoo00Moo`03001oogoo
00Moo`03001oogoo00Ioo`03001oogoo00Moo`03001oogoo00Ioo`03001oogoo00Moo`03001oogoo
00Ioo`03001oogoo00Moo`03001oogoo00Ioo`03001oogoo01ioo`006Goo00<007ooOol04Woo00<0
07ooOol04Goo00<007ooOol04Goo00<007ooOol04Goo00<007ooOol04Woo00<007ooOol04Goo00<0
07ooOol04Goo00<007ooOol04Woo00<007ooOol0:Goo00<007ooOol01Woo00<007ooOol01goo00<0
07ooOol01Woo00<007ooOol01goo00<007ooOol01Woo00<007ooOol01goo00<007ooOol01Woo00<0
07ooOol01goo00<007ooOol01goo00<007ooOol01Woo00<007ooOol01goo00<007ooOol01Woo00<0
07ooOol01goo00<007ooOol01Woo00<007ooOol01goo00<007ooOol01Woo00<007ooOol07Woo000I
Ool00`00Oomoo`0BOol00`00Oomoo`0AOol00`00Oomoo`0AOol00`00Oomoo`0AOol00`00Oomoo`0B
Ool00`00Oomoo`0AOol00`00Oomoo`0AOol00`00Oomoo`0BOol00`00Oomoo`0YOol00`00Oomoo`06
Ool00`00Oomoo`07Ool00`00Oomoo`06Ool00`00Oomoo`07Ool00`00Oomoo`06Ool00`00Oomoo`07
Ool00`00Oomoo`06Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`06Ool00`00Oomoo`07
Ool00`00Oomoo`06Ool00`00Oomoo`07Ool00`00Oomoo`06Ool00`00Oomoo`07Ool00`00Oomoo`06
Ool00`00Oomoo`0NOol001Uoo`03001oogoo019oo`03001oogoo015oo`03001oogoo015oo`03001o
ogoo015oo`03001oogoo019oo`03001oogoo015oo`03001oogoo015oo`03001oogoo019oo`03001o
ogoo02Uoo`03001oogoo00Ioo`03001oogoo00Moo`03001oogoo00Ioo`03001oogoo00Moo`03001o
ogoo00Ioo`03001oogoo00Moo`03001oogoo00Ioo`03001oogoo00Moo`03001oogoo00Moo`03001o
ogoo00Ioo`03001oogoo00Moo`03001oogoo00Ioo`03001oogoo00Moo`03001oogoo00Ioo`03001o
ogoo00Moo`03001oogoo00Ioo`03001oogoo01ioo`006Goo0P004goo00<007ooOol04Goo00<007oo
Ool04Goo00<007ooOol04Goo00<007ooOol04Woo00<007ooOol04Goo00<007ooOol04Goo00<007oo
Ool04Woo00<007ooOol0:Goo00<007ooOol01Woo00<007ooOol01goo00<007ooOol01Woo00<007oo
Ool01goo00<007ooOol01Woo00<007ooOol01goo00<007ooOol01Woo00<007ooOol01goo00<007oo
Ool01goo00<007ooOol01Woo00<007ooOol01goo00<007ooOol01Woo00<007ooOol01goo00<007oo
Ool01Woo00<007ooOol01goo00<007ooOol01Woo00<007ooOol07Woo000IOol00`00Oomoo`0BOol0
0`00Oomoo`0AOol00`00Oomoo`0AOol00`00Oomoo`0AOol00`00Oomoo`0BOol00`00Oomoo`0AOol0
0`00Oomoo`0AOol00`00Oomoo`0BOol00`00Oomoo`0YOol00`00Oomoo`06Ool00`00Oomoo`07Ool0
0`00Oomoo`06Ool00`00Oomoo`07Ool00`00Oomoo`06Ool00`00Oomoo`07Ool00`00Oomoo`06Ool0
0`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`06Ool00`00Oomoo`07Ool00`00Oomoo`06Ool0
0`00Oomoo`07Ool00`00Oomoo`06Ool00`00Oomoo`07Ool00`00Oomoo`06Ool00`00Oomoo`0NOol0
01Uoo`03001oogoo019oo`03001oogoo015oo`03001oogoo015oo`03001oogoo015oo`03001oogoo
019oo`03001oogoo015oo`03001oogoo015oo`03001oogoo019oo`03001oogoo02Uoo`03001oogoo
00Ioo`03001oogoo00Moo`03001oogoo00Ioo`03001oogoo00Moo`03001oogoo00Ioo`03001oogoo
00Moo`03001oogoo00Ioo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Ioo`03001oogoo
00Moo`03001oogoo00Ioo`03001oogoo00Moo`03001oogoo00Ioo`03001oogoo00Moo`03001oogoo
00Ioo`03001oogoo01ioo`006Goo00<007ooOol04Woo00<007ooOol04Goo00<007ooOol04Goo00<0
07ooOol04Goo00<007ooOol04Woo00<007ooOol04Goo00<007ooOol04Goo00<007ooOol04Woo00<0
07ooOol0:Goo00<007ooOol01Woo00<007ooOol01goo00<007ooOol01Woo00<007ooOol01goo00<0
07ooOol01Woo00<007ooOol01goo00<007ooOol01Woo00<007ooOol01goo00<007ooOol01goo00<0
07ooOol01Woo00<007ooOol01goo00<007ooOol01Woo00<007ooOol01goo00<007ooOol01Woo00<0
07ooOol01goo00<007ooOol01Woo00<007ooOol07Woo000IOol00`00Oomoo`0BOol00`00Oomoo`0A
Ool00`00Oomoo`0AOol00`00Oomoo`0AOol00`00Oomoo`0BOol00`00Oomoo`0AOol00`00Oomoo`0A
Ool00`00Oomoo`0BOol00`00Oomoo`0YOol00`00Oomoo`06Ool00`00Oomoo`07Ool00`00Oomoo`06
Ool00`00Oomoo`07Ool00`00Oomoo`06Ool00`00Oomoo`07Ool00`00Oomoo`06Ool00`00Oomoo`07
Ool00`00Oomoo`07Ool00`00Oomoo`06Ool00`00Oomoo`07Ool00`00Oomoo`06Ool00`00Oomoo`07
Ool00`00Oomoo`06Ool00`00Oomoo`07Ool00`00Oomoo`06Ool00`00Oomoo`0NOol001Uoo`03001o
ogoo019oo`03001oogoo015oo`03001oogoo015oo`03001oogoo015oo`03001oogoo019oo`03001o
ogoo015oo`03001oogoo015oo`03001oogoo019oo`03001oogoo02Uoo`03001oogoo00Ioo`03001o
ogoo00Moo`03001oogoo00Ioo`03001oogoo00Moo`03001oogoo00Ioo`03001oogoo00Moo`03001o
ogoo00Ioo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Ioo`03001oogoo00Moo`03001o
ogoo00Ioo`03001oogoo00Moo`03001oogoo00Ioo`03001oogoo00Moo`03001oogoo00Ioo`03001o
ogoo01ioo`006Goo0P004Woo0P004goo00<007ooOol04Goo00<007ooOol04Goo00<007ooOol04Woo
00<007ooOol04Goo00<007ooOol04Goo00<007ooOol04Woo00<007ooOol0:Goo00<007ooOol01Goo
0`0027oo00<007ooOol01Woo00<007ooOol01goo00<007ooOol01Woo00<007ooOol01goo00<007oo
Ool01Woo00<007ooOol01goo00<007ooOol01goo00<007ooOol01Woo00<007ooOol01goo00<007oo
Ool01Woo00<007ooOol01goo00<007ooOol01Woo00<007ooOol01goo00<007ooOol01Goo0`007goo
000IOol00`00Oomoo`0@Ool3000COol00`00Oomoo`0AOol00`00Oomoo`0AOol00`00Oomoo`0BOol0
0`00Oomoo`0AOol00`00Oomoo`0AOol00`00Oomoo`0BOol00`00Oomoo`0YOol00`00Oomoo`06Ool0
0`00Oomoo`07Ool00`00Oomoo`06Ool00`00Oomoo`07Ool00`00Oomoo`06Ool00`00Oomoo`07Ool0
0`00Oomoo`06Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`06Ool00`00Oomoo`07Ool0
0`00Oomoo`06Ool00`00Oomoo`07Ool00`00Oomoo`06Ool00`00Oomoo`07Ool00`00Oomoo`06Ool0
0`00Oomoo`0NOol001Uoo`03001oogoo015oo`03001oogoo019oo`03001oogoo015oo`03001oogoo
015oo`03001oogoo019oo`03001oogoo015oo`03001oogoo015oo`03001oogoo019oo`03001oogoo
02Uoo`03001oogoo011oo`03001oogoo00Ioo`03001oogoo00Moo`03001oogoo00Ioo`03001oogoo
00Moo`03001oogoo00Ioo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Ioo`03001oogoo
00Moo`03001oogoo00Ioo`03001oogoo00Moo`03001oogoo00Ioo`03001oogoo00Moo`03001oogoo
02Moo`006Goo00<007ooOol09Woo00<007ooOol04Goo00<007ooOol04Goo00<007ooOol04Woo00<0
07ooOol04Goo00<007ooOol04Goo00<007ooOol04Woo00<007ooOol0:Goo00<007ooOol047oo00<0
07ooOol01Woo00<007ooOol01goo00<007ooOol01Woo00<007ooOol01goo00<007ooOol01Woo00<0
07ooOol01goo00<007ooOol01goo00<007ooOol01Woo00<007ooOol01goo00<007ooOol01Woo00<0
07ooOol01goo00<007ooOol01Woo00<007ooOol01goo00<007ooOol09goo000IOol00`00Oomoo`0V
Ool00`00Oomoo`0AOol00`00Oomoo`0AOol00`00Oomoo`0BOol00`00Oomoo`0AOol00`00Oomoo`0A
Ool00`00Oomoo`0BOol00`00Oomoo`0YOol00`00Oomoo`0@Ool00`00Oomoo`06Ool00`00Oomoo`07
Ool00`00Oomoo`06Ool00`00Oomoo`07Ool00`00Oomoo`06Ool00`00Oomoo`07Ool00`00Oomoo`07
Ool00`00Oomoo`06Ool00`00Oomoo`07Ool00`00Oomoo`06Ool00`00Oomoo`07Ool00`00Oomoo`06
Ool00`00Oomoo`07Ool00`00Oomoo`0WOol001Uoo`03001oogoo02Ioo`03001oogoo015oo`03001o
ogoo015oo`03001oogoo019oo`03001oogoo015oo`03001oogoo015oo`03001oogoo019oo`03001o
ogoo02Uoo`03001oogoo011oo`03001oogoo00Ioo`03001oogoo00Moo`03001oogoo00Ioo`03001o
ogoo00Moo`03001oogoo00Ioo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Ioo`03001o
ogoo00Moo`03001oogoo00Ioo`03001oogoo00Moo`03001oogoo00Ioo`03001oogoo00Moo`03001o
ogoo02Moo`006Goo00<007ooOol09Woo00<007ooOol04Goo00<007ooOol04Goo00<007ooOol04Woo
00<007ooOol04Goo00<007ooOol04Goo00<007ooOol04Woo00<007ooOol0:Goo00<007ooOol047oo
00<007ooOol01Woo00<007ooOol01goo00<007ooOol01Woo00<007ooOol01goo00<007ooOol01Woo
00<007ooOol01goo00<007ooOol01goo00<007ooOol01Woo00<007ooOol01goo00<007ooOol01Woo
00<007ooOol01goo00<007ooOol01Woo00<007ooOol01goo00<007ooOol09goo000IOol2000WOol0
0`00Oomoo`0AOol00`00Oomoo`0AOol00`00Oomoo`0BOol00`00Oomoo`0AOol00`00Oomoo`0AOol0
0`00Oomoo`0BOol00`00Oomoo`0YOol00`00Oomoo`0@Ool00`00Oomoo`06Ool00`00Oomoo`07Ool0
0`00Oomoo`06Ool00`00Oomoo`07Ool00`00Oomoo`06Ool00`00Oomoo`07Ool00`00Oomoo`07Ool0
0`00Oomoo`06Ool00`00Oomoo`07Ool00`00Oomoo`06Ool00`00Oomoo`07Ool00`00Oomoo`06Ool0
0`00Oomoo`07Ool00`00Oomoo`0WOol001Uoo`03001oogoo02Ioo`03001oogoo015oo`03001oogoo
015oo`03001oogoo019oo`03001oogoo015oo`03001oogoo015oo`03001oogoo019oo`03001oogoo
02Uoo`03001oogoo011oo`03001oogoo00Ioo`03001oogoo00Moo`03001oogoo00Ioo`03001oogoo
00Moo`03001oogoo00Ioo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Ioo`03001oogoo
00Moo`03001oogoo00Ioo`03001oogoo00Moo`03001oogoo00Ioo`03001oogoo00Moo`03001oogoo
02Moo`006Goo00<007ooOol09Woo00<007ooOol04Goo00<007ooOol04Goo00<007ooOol04Woo00<0
07ooOol04Goo00<007ooOol04Goo00<007ooOol04Woo00<007ooOol0:Goo00<007ooOol047oo00<0
07ooOol01Woo00<007ooOol01goo00<007ooOol01Woo00<007ooOol01goo00<007ooOol01Woo00<0
07ooOol01goo00<007ooOol01goo00<007ooOol01Woo00<007ooOol01goo00<007ooOol01Woo00<0
07ooOol01goo00<007ooOol01Woo00<007ooOol01goo00<007ooOol09goo000IOol00`00Oomoo`0V
Ool00`00Oomoo`0AOol00`00Oomoo`0AOol00`00Oomoo`0BOol00`00Oomoo`0AOol00`00Oomoo`0A
Ool00`00Oomoo`0BOol00`00Oomoo`0YOol00`00Oomoo`0@Ool00`00Oomoo`06Ool00`00Oomoo`07
Ool00`00Oomoo`06Ool00`00Oomoo`07Ool00`00Oomoo`06Ool00`00Oomoo`07Ool00`00Oomoo`07
Ool00`00Oomoo`06Ool00`00Oomoo`07Ool00`00Oomoo`06Ool00`00Oomoo`07Ool00`00Oomoo`06
Ool00`00Oomoo`07Ool00`00Oomoo`0WOol001=oo`<000=oo`03001oogoo02Ioo`03001oogoo015o
o`03001oogoo015oo`03001oogoo019oo`03001oogoo015oo`03001oogoo015oo`03001oogoo019o
o`03001oogoo02=oo`<000=oo`03001oogoo011oo`03001oogoo00Ioo`03001oogoo00Moo`03001o
ogoo00Ioo`03001oogoo00Moo`03001oogoo00Ioo`03001oogoo00Moo`03001oogoo00Moo`03001o
ogoo00Ioo`03001oogoo00Moo`03001oogoo00Ioo`03001oogoo00Moo`03001oogoo00Ioo`03001o
ogoo00Moo`03001oogoo02Moo`004goo00<007ooOol00goo00<007ooOol09Goo0P004goo00<007oo
Ool04Goo00<007ooOol04Woo00<007ooOol04Goo00<007ooOol04Goo00<007ooOol04Woo00<007oo
Ool08goo00<007ooOol00goo00<007ooOol047oo00<007ooOol01Woo00<007ooOol01goo00<007oo
Ool01Woo00<007ooOol01goo00<007ooOol01Woo00<007ooOol01goo00<007ooOol01goo00<007oo
Ool01Woo00<007ooOol01goo00<007ooOol01Woo00<007ooOol01goo00<007ooOol01Woo00<007oo
Ool01goo00<007ooOol09goo000DOol00`00Oomoo`02Ool2000UOol3000COol00`00Oomoo`0AOol0
0`00Oomoo`0BOol00`00Oomoo`0AOol00`00Oomoo`0AOol00`00Oomoo`0BOol00`00Oomoo`0TOol0
0`00Oomoo`02Ool2000@Ool30007Ool00`00Oomoo`07Ool00`00Oomoo`06Ool00`00Oomoo`07Ool0
0`00Oomoo`06Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`06Ool00`00Oomoo`07Ool0
0`00Oomoo`06Ool00`00Oomoo`07Ool00`00Oomoo`06Ool00`00Oomoo`06Ool3000XOol001Aoo`03
001oogoo009oo`03001oogoo02Eoo`03001oogoo019oo`03001oogoo015oo`03001oogoo019oo`03
001oogoo015oo`03001oogoo015oo`03001oogoo019oo`03001oogoo02Aoo`03001oogoo009oo`03
001oogoo011oo`03001oogoo00Ioo`03001oogoo00Moo`03001oogoo00Ioo`03001oogoo00Moo`03
001oogoo00Ioo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Ioo`03001oogoo00Moo`03
001oogoo00Ioo`03001oogoo00Moo`03001oogoo00Ioo`03001oogoo00Moo`03001oogoo02Moo`00
4goo00<007oo00000goo00<007ooOol0>Woo00<007ooOol04Goo00<007ooOol04Woo00<007ooOol0
4Goo00<007ooOol04Goo00<007ooOol04Woo00<007ooOol08goo00<007oo00000goo00<007ooOol0
6Goo00<007ooOol01goo00<007ooOol01Woo00<007ooOol01goo00<007ooOol01Woo00<007ooOol0
1goo00<007ooOol01goo00<007ooOol01Woo00<007ooOol01goo00<007ooOol01Woo00<007ooOol0
1goo00<007ooOol01Woo00<007ooOol0<Goo000DOol00`00Oomoo`02Ool00`00Oomoo`0jOol00`00
Oomoo`0AOol00`00Oomoo`0BOol00`00Oomoo`0AOol00`00Oomoo`0AOol00`00Oomoo`0BOol00`00
Oomoo`0TOol00`00Oomoo`02Ool00`00Oomoo`0IOol00`00Oomoo`07Ool00`00Oomoo`06Ool00`00
Oomoo`07Ool00`00Oomoo`06Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`06Ool00`00
Oomoo`07Ool00`00Oomoo`06Ool00`00Oomoo`07Ool00`00Oomoo`06Ool00`00Oomoo`0aOol001Uo
o`03001oogoo03Yoo`03001oogoo015oo`03001oogoo019oo`03001oogoo015oo`03001oogoo015o
o`03001oogoo019oo`03001oogoo02Uoo`03001oogoo01Uoo`03001oogoo00Moo`03001oogoo00Io
o`03001oogoo00Moo`03001oogoo00Ioo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Io
o`03001oogoo00Moo`03001oogoo00Ioo`03001oogoo00Moo`03001oogoo00Ioo`03001oogoo035o
o`006Goo00<007ooOol0>Woo00<007ooOol04Goo00<007ooOol04Woo00<007ooOol04Goo00<007oo
Ool04Goo00<007ooOol04Woo00<007ooOol0:Goo00<007ooOol06Goo00<007ooOol01goo00<007oo
Ool01Woo00<007ooOol01goo00<007ooOol01Woo00<007ooOol01goo00<007ooOol01goo00<007oo
Ool01Woo00<007ooOol01goo00<007ooOol01Woo00<007ooOol01goo00<007ooOol01Woo00<007oo
Ool0<Goo000IOol2000kOol00`00Oomoo`0AOol00`00Oomoo`0BOol00`00Oomoo`0AOol00`00Oomo
o`0AOol00`00Oomoo`0BOol00`00Oomoo`0YOol00`00Oomoo`0IOol00`00Oomoo`07Ool00`00Oomo
o`06Ool00`00Oomoo`07Ool00`00Oomoo`06Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomo
o`06Ool00`00Oomoo`07Ool00`00Oomoo`06Ool00`00Oomoo`07Ool00`00Oomoo`06Ool00`00Oomo
o`0aOol001Uoo`03001oogoo03Yoo`03001oogoo015oo`03001oogoo019oo`03001oogoo015oo`03
001oogoo015oo`03001oogoo019oo`03001oogoo02Uoo`03001oogoo01Uoo`03001oogoo00Moo`03
001oogoo00Ioo`03001oogoo00Moo`03001oogoo00Ioo`03001oogoo00Moo`03001oogoo00Moo`03
001oogoo00Ioo`03001oogoo00Moo`03001oogoo00Ioo`03001oogoo00Moo`03001oogoo00Ioo`03
001oogoo035oo`006Goo00<007ooOol0>Woo00<007ooOol04Goo00<007ooOol04Woo00<007ooOol0
4Goo00<007ooOol04Goo00<007ooOol04Woo00<007ooOol0:Goo00<007ooOol06Goo00<007ooOol0
1goo00<007ooOol01Woo00<007ooOol01goo00<007ooOol01Woo00<007ooOol01goo00<007ooOol0
1goo00<007ooOol01Woo00<007ooOol01goo00<007ooOol01Woo00<007ooOol01goo00<007ooOol0
1Woo00<007ooOol0<Goo000IOol00`00Oomoo`0jOol00`00Oomoo`0AOol00`00Oomoo`0BOol00`00
Oomoo`0AOol00`00Oomoo`0AOol00`00Oomoo`0BOol00`00Oomoo`0YOol00`00Oomoo`0IOol00`00
Oomoo`07Ool00`00Oomoo`06Ool00`00Oomoo`07Ool00`00Oomoo`06Ool00`00Oomoo`07Ool00`00
Oomoo`07Ool00`00Oomoo`06Ool00`00Oomoo`07Ool00`00Oomoo`06Ool00`00Oomoo`07Ool00`00
Oomoo`06Ool00`00Oomoo`0aOol001Uoo`03001oogoo03Yoo`03001oogoo015oo`03001oogoo019o
o`03001oogoo015oo`03001oogoo015oo`03001oogoo019oo`03001oogoo02Uoo`03001oogoo01Uo
o`03001oogoo00Moo`03001oogoo00Ioo`03001oogoo00Moo`03001oogoo00Ioo`03001oogoo00Mo
o`03001oogoo00Moo`03001oogoo00Ioo`03001oogoo00Moo`03001oogoo00Ioo`03001oogoo00Mo
o`03001oogoo00Ioo`03001oogoo035oo`006Goo00<007ooOol0>Woo00<007ooOol04Goo00<007oo
Ool04Woo00<007ooOol04Goo00<007ooOol04Goo00<007ooOol04Woo00<007ooOol0:Goo00<007oo
Ool06Goo00<007ooOol01goo00<007ooOol01Woo00<007ooOol01goo00<007ooOol01Woo00<007oo
Ool01goo00<007ooOol01goo00<007ooOol01Woo00<007ooOol01goo00<007ooOol01Woo00<007oo
Ool01goo00<007ooOol01Woo00<007ooOol0<Goo000IOol2000kOol00`00Oomoo`0AOol00`00Oomo
o`0BOol00`00Oomoo`0AOol00`00Oomoo`0AOol00`00Oomoo`0BOol00`00Oomoo`0YOol00`00Oomo
o`0HOol30008Ool00`00Oomoo`06Ool00`00Oomoo`07Ool00`00Oomoo`06Ool00`00Oomoo`07Ool0
0`00Oomoo`07Ool00`00Oomoo`06Ool00`00Oomoo`07Ool00`00Oomoo`06Ool00`00Oomoo`07Ool0
0`00Oomoo`05Ool3000bOol001Uoo`03001oogoo03Uoo`<0019oo`03001oogoo019oo`03001oogoo
015oo`03001oogoo015oo`03001oogoo019oo`03001oogoo02Uoo`03001oogoo01Uoo`03001oogoo
00Moo`03001oogoo00Ioo`03001oogoo00Moo`03001oogoo00Ioo`03001oogoo00Moo`03001oogoo
00Moo`03001oogoo00Ioo`03001oogoo00Moo`03001oogoo00Ioo`03001oogoo00Moo`03001oogoo
00Ioo`03001oogoo035oo`006Goo00<007ooOol0>Woo00<007ooOol04Goo00<007ooOol04Woo00<0
07ooOol04Goo00<007ooOol04Goo00<007ooOol04Woo00<007ooOol0:Goo00<007ooOol08goo00<0
07ooOol01Woo00<007ooOol01goo00<007ooOol01Woo00<007ooOol01goo00<007ooOol01goo00<0
07ooOol01Woo00<007ooOol01goo00<007ooOol01Woo00<007ooOol01goo00<007ooOol0>Woo000I
Ool00`00Oomoo`1>Ool00`00Oomoo`0BOol00`00Oomoo`0AOol00`00Oomoo`0AOol00`00Oomoo`0B
Ool00`00Oomoo`0YOol00`00Oomoo`0SOol00`00Oomoo`06Ool00`00Oomoo`07Ool00`00Oomoo`06
Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`06Ool00`00Oomoo`07Ool00`00Oomoo`06
Ool00`00Oomoo`07Ool00`00Oomoo`0jOol001Uoo`03001oogoo04ioo`03001oogoo019oo`03001o
ogoo015oo`03001oogoo015oo`03001oogoo019oo`03001oogoo02Uoo`03001oogoo02=oo`03001o
ogoo00Ioo`03001oogoo00Moo`03001oogoo00Ioo`03001oogoo00Moo`03001oogoo00Moo`03001o
ogoo00Ioo`03001oogoo00Moo`03001oogoo00Ioo`03001oogoo00Moo`03001oogoo03Yoo`006Goo
00<007ooOol0CWoo00<007ooOol04Woo00<007ooOol04Goo00<007ooOol04Goo00<007ooOol04Woo
00<007ooOol0:Goo00<007ooOol08goo00<007ooOol01Woo00<007ooOol01goo00<007ooOol01Woo
00<007ooOol01goo00<007ooOol01goo00<007ooOol01Woo00<007ooOol01goo00<007ooOol01Woo
00<007ooOol01goo00<007ooOol0>Woo000IOol00`00Oomoo`1>Ool00`00Oomoo`0BOol00`00Oomo
o`0AOol00`00Oomoo`0AOol00`00Oomoo`0BOol00`00Oomoo`0YOol00`00Oomoo`0SOol00`00Oomo
o`06Ool00`00Oomoo`07Ool00`00Oomoo`06Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomo
o`06Ool00`00Oomoo`07Ool00`00Oomoo`06Ool00`00Oomoo`07Ool00`00Oomoo`0jOol001Uoo`80
04moo`03001oogoo019oo`03001oogoo015oo`03001oogoo015oo`03001oogoo019oo`03001oogoo
02Uoo`03001oogoo02=oo`03001oogoo00Ioo`03001oogoo00Moo`03001oogoo00Ioo`03001oogoo
00Moo`03001oogoo00Moo`03001oogoo00Ioo`03001oogoo00Moo`03001oogoo00Ioo`03001oogoo
00Moo`03001oogoo03Yoo`006Goo00<007ooOol0CWoo00<007ooOol04Woo00<007ooOol04Goo00<0
07ooOol04Goo00<007ooOol04Woo00<007ooOol0:Goo00<007ooOol08goo00<007ooOol01Woo00<0
07ooOol01goo00<007ooOol01Woo00<007ooOol01goo00<007ooOol01goo00<007ooOol01Woo00<0
07ooOol01goo00<007ooOol01Woo00<007ooOol01goo00<007ooOol0>Woo000IOol00`00Oomoo`1>
Ool00`00Oomoo`0BOol00`00Oomoo`0AOol00`00Oomoo`0AOol00`00Oomoo`0BOol00`00Oomoo`0Y
Ool00`00Oomoo`0SOol00`00Oomoo`06Ool00`00Oomoo`07Ool00`00Oomoo`06Ool00`00Oomoo`07
Ool00`00Oomoo`07Ool00`00Oomoo`06Ool00`00Oomoo`07Ool00`00Oomoo`06Ool00`00Oomoo`07
Ool00`00Oomoo`0jOol001Uoo`03001oogoo04ioo`03001oogoo019oo`03001oogoo015oo`03001o
ogoo015oo`03001oogoo019oo`03001oogoo02Uoo`03001oogoo02=oo`03001oogoo00Ioo`03001o
ogoo00Moo`03001oogoo00Ioo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Ioo`03001o
ogoo00Moo`03001oogoo00Ioo`03001oogoo00Moo`03001oogoo03Yoo`0057oo0`000Woo00<007oo
Ool0CWoo00<007ooOol04Woo00<007ooOol04Goo00<007ooOol04Goo00<007ooOol04Woo00<007oo
Ool097oo0`000Woo00<007ooOol08goo00<007ooOol01Woo00<007ooOol01goo00<007ooOol01Woo
00<007ooOol01goo00<007ooOol01goo00<007ooOol01Woo00<007ooOol01goo00<007ooOol01Woo
00<007ooOol01goo00<007ooOol0>Woo000EOol01@00Oomoogoo0000D7oo00<007ooOol04Woo00<0
07ooOol04Goo00<007ooOol04Goo00<007ooOol04Woo00<007ooOol09Goo00D007ooOomoo`0002Eo
o`03001oogoo00Ioo`03001oogoo00Moo`03001oogoo00Ioo`03001oogoo00Moo`03001oogoo00Mo
o`03001oogoo00Ioo`03001oogoo00Moo`03001oogoo00Ioo`03001oogoo00Moo`03001oogoo03Yo
o`004goo10000Woo0P00CWoo0`004goo00<007ooOol04Goo00<007ooOol04Goo00<007ooOol04Woo
00<007ooOol08goo10000Woo0P008goo0`001goo00<007ooOol01goo00<007ooOol01Woo00<007oo
Ool01goo00<007ooOol01goo00<007ooOol01Woo00<007ooOol01goo00<007ooOol01Woo00<007oo
Ool01Woo0`00>goo000COol00`00Ool00003Ool00`00Oomoo`1>Ool00`00Oomoo`0BOol00`00Oomo
o`0AOol00`00Oomoo`0AOol00`00Oomoo`0BOol00`00Oomoo`0SOol00`00Ool00003Ool00`00Oomo
o`0SOol00`00Oomoo`06Ool00`00Oomoo`07Ool00`00Oomoo`06Ool00`00Oomoo`07Ool00`00Oomo
o`07Ool00`00Oomoo`06Ool00`00Oomoo`07Ool00`00Oomoo`06Ool00`00Oomoo`07Ool00`00Oomo
o`0jOol001Aoo`8000=oo`03001oogoo06=oo`03001oogoo015oo`03001oogoo015oo`03001oogoo
019oo`03001oogoo02Aoo`8000=oo`03001oogoo02aoo`03001oogoo00Moo`03001oogoo00Ioo`03
001oogoo00Moo`03001oogoo00Moo`03001oogoo00Ioo`03001oogoo00Moo`03001oogoo00Ioo`03
001oogoo04Aoo`005Goo00D007ooOomoo`0006Eoo`03001oogoo015oo`03001oogoo015oo`03001o
ogoo019oo`03001oogoo02Eoo`05001oogooOol0000^Ool00`00Oomoo`07Ool00`00Oomoo`06Ool0
0`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`06Ool00`00Oomoo`07Ool00`00Oomoo`06Ool0
0`00Oomoo`14Ool001Uoo`03001oogoo06=oo`03001oogoo015oo`03001oogoo015oo`03001oogoo
019oo`03001oogoo02Uoo`03001oogoo02aoo`03001oogoo00Moo`03001oogoo00Ioo`03001oogoo
00Moo`03001oogoo00Moo`03001oogoo00Ioo`03001oogoo00Moo`03001oogoo00Ioo`03001oogoo
04Aoo`006Goo00<007ooOol0Hgoo00<007ooOol04Goo00<007ooOol04Goo00<007ooOol04Woo00<0
07ooOol0:Goo00<007ooOol0;7oo00<007ooOol01goo00<007ooOol01Woo00<007ooOol01goo00<0
07ooOol01goo00<007ooOol01Woo00<007ooOol01goo00<007ooOol01Woo00<007ooOol0A7oo000I
Ool2001TOol00`00Oomoo`0AOol00`00Oomoo`0AOol00`00Oomoo`0BOol00`00Oomoo`0YOol00`00
Oomoo`0/Ool00`00Oomoo`07Ool00`00Oomoo`06Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00
Oomoo`06Ool00`00Oomoo`07Ool00`00Oomoo`06Ool00`00Oomoo`14Ool001Uoo`03001oogoo06=o
o`03001oogoo015oo`03001oogoo015oo`03001oogoo019oo`03001oogoo02Uoo`03001oogoo02ao
o`03001oogoo00Moo`03001oogoo00Ioo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Io
o`03001oogoo00Moo`03001oogoo00Ioo`03001oogoo04Aoo`006Goo00<007ooOol0Hgoo00<007oo
Ool04Goo00<007ooOol04Goo00<007ooOol04Woo00<007ooOol0:Goo00<007ooOol0;7oo00<007oo
Ool01goo00<007ooOol01Woo00<007ooOol01goo00<007ooOol01goo00<007ooOol01Woo00<007oo
Ool01goo00<007ooOol01Woo00<007ooOol0A7oo000IOol00`00Oomoo`1SOol00`00Oomoo`0AOol0
0`00Oomoo`0AOol00`00Oomoo`0BOol00`00Oomoo`0YOol00`00Oomoo`0/Ool00`00Oomoo`07Ool0
0`00Oomoo`06Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`06Ool00`00Oomoo`07Ool0
0`00Oomoo`06Ool00`00Oomoo`14Ool001Uoo`03001oogoo06=oo`03001oogoo015oo`03001oogoo
015oo`03001oogoo019oo`03001oogoo02Uoo`03001oogoo02aoo`03001oogoo00Moo`03001oogoo
00Ioo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Ioo`03001oogoo00Moo`03001oogoo
00Ioo`03001oogoo04Aoo`006Goo00<007ooOol0Hgoo00<007ooOol04Goo00<007ooOol04Goo00<0
07ooOol04Woo00<007ooOol0:Goo00<007ooOol0;7oo00<007ooOol01goo00<007ooOol01Woo00<0
07ooOol01goo00<007ooOol01goo00<007ooOol01Woo00<007ooOol01goo00<007ooOol01Woo00<0
07ooOol0A7oo000IOol00`00Oomoo`1ROol2000COol00`00Oomoo`0AOol00`00Oomoo`0BOol00`00
Oomoo`0YOol00`00Oomoo`0/Ool00`00Oomoo`07Ool00`00Oomoo`06Ool00`00Oomoo`07Ool00`00
Oomoo`07Ool00`00Oomoo`06Ool00`00Oomoo`07Ool00`00Oomoo`06Ool00`00Oomoo`14Ool001Uo
o`80069oo`<001=oo`03001oogoo015oo`03001oogoo019oo`03001oogoo02Uoo`03001oogoo02]o
o`<000Qoo`03001oogoo00Ioo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Ioo`03001o
ogoo00Moo`03001oogoo00Eoo`<004Eoo`006Goo00<007ooOol0HWoo00<007ooOol04Woo00<007oo
Ool04Goo00<007ooOol04Woo00<007ooOol0:Goo00<007ooOol0;7oo00<007ooOol01goo00<007oo
Ool01Woo00<007ooOol01goo00<007ooOol01goo00<007ooOol01Woo00<007ooOol01goo00<007oo
Ool01Woo00<007ooOol0A7oo000IOol00`00Oomoo`1gOol00`00Oomoo`0AOol00`00Oomoo`0BOol0
0`00Oomoo`0YOol00`00Oomoo`0fOol00`00Oomoo`06Ool00`00Oomoo`07Ool00`00Oomoo`07Ool0
0`00Oomoo`06Ool00`00Oomoo`07Ool00`00Oomoo`1=Ool001Uoo`03001oogoo07Moo`03001oogoo
015oo`03001oogoo019oo`03001oogoo02Uoo`03001oogoo03Ioo`03001oogoo00Ioo`03001oogoo
00Moo`03001oogoo00Moo`03001oogoo00Ioo`03001oogoo00Moo`03001oogoo04eoo`006Goo00<0
07ooOol0Mgoo00<007ooOol04Goo00<007ooOol04Woo00<007ooOol0:Goo00<007ooOol0=Woo00<0
07ooOol01Woo00<007ooOol01goo00<007ooOol01goo00<007ooOol01Woo00<007ooOol01goo00<0
07ooOol0CGoo000IOol00`00Oomoo`1gOol00`00Oomoo`0AOol00`00Oomoo`0BOol00`00Oomoo`0Y
Ool00`00Oomoo`0fOol00`00Oomoo`06Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`06
Ool00`00Oomoo`07Ool00`00Oomoo`1=Ool001Uoo`8007Qoo`03001oogoo015oo`03001oogoo019o
o`03001oogoo02Uoo`03001oogoo03Ioo`03001oogoo00Ioo`03001oogoo00Moo`03001oogoo00Mo
o`03001oogoo00Ioo`03001oogoo00Moo`03001oogoo04eoo`006Goo00<007ooOol0Mgoo00<007oo
Ool04Goo00<007ooOol04Woo00<007ooOol0:Goo00<007ooOol0=Woo00<007ooOol01Woo00<007oo
Ool01goo00<007ooOol01goo00<007ooOol01Woo00<007ooOol01goo00<007ooOol0CGoo000IOol0
0`00Oomoo`1gOol00`00Oomoo`0AOol00`00Oomoo`0BOol00`00Oomoo`0YOol00`00Oomoo`0fOol0
0`00Oomoo`06Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`06Ool00`00Oomoo`07Ool0
0`00Oomoo`1=Ool001Uoo`03001oogoo07Moo`03001oogoo015oo`03001oogoo019oo`03001oogoo
02Uoo`03001oogoo03Ioo`03001oogoo00Ioo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo
00Ioo`03001oogoo00Moo`03001oogoo04eoo`004goo0P0017oo00<007ooOol0Mgoo00<007ooOol0
4Goo00<007ooOol04Woo00<007ooOol08goo0P0017oo00<007ooOol0=Woo00<007ooOol01Woo00<0
07ooOol01goo00<007ooOol01goo00<007ooOol01Woo00<007ooOol01goo00<007ooOol0CGoo000C
Ool00`00Ool00003Ool00`00Oomoo`1gOol00`00Oomoo`0AOol00`00Oomoo`0BOol00`00Oomoo`0S
Ool00`00Ool00003Ool00`00Oomoo`0fOol00`00Oomoo`06Ool00`00Oomoo`07Ool00`00Oomoo`07
Ool00`00Oomoo`06Ool00`00Oomoo`07Ool00`00Oomoo`1=Ool001=oo`03001oo`0000=oo`8007Mo
o`<0019oo`03001oogoo019oo`03001oogoo02=oo`03001oo`0000=oo`8003Ioo`<000Moo`03001o
ogoo00Moo`03001oogoo00Moo`03001oogoo00Ioo`03001oogoo00Ioo`<004ioo`004goo0P0017oo
00<007ooOol0Mgoo00<007ooOol04Goo00<007ooOol04Woo00<007ooOol08goo0P0017oo00<007oo
Ool0=Woo00<007ooOol01Woo00<007ooOol01goo00<007ooOol01goo00<007ooOol01Woo00<007oo
Ool01goo00<007ooOol0CGoo000COol00`00Oomoo`03Ool00`00Oomoo`2;Ool00`00Oomoo`0BOol0
0`00Oomoo`0SOol00`00Oomoo`03Ool00`00Oomoo`0oOol00`00Oomoo`07Ool00`00Oomoo`07Ool0
0`00Oomoo`06Ool00`00Oomoo`1GOol001Aoo`8000=oo`03001oogoo08]oo`03001oogoo019oo`03
001oogoo02Aoo`8000=oo`03001oogoo03moo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo
00Ioo`03001oogoo05Moo`006Goo00<007ooOol0Rgoo00<007ooOol04Woo00<007ooOol0:Goo00<0
07ooOol0?goo00<007ooOol01goo00<007ooOol01goo00<007ooOol01Woo00<007ooOol0Egoo000I
Ool00`00Oomoo`2;Ool00`00Oomoo`0BOol00`00Oomoo`0YOol00`00Oomoo`0oOol00`00Oomoo`07
Ool00`00Oomoo`07Ool00`00Oomoo`06Ool00`00Oomoo`1GOol001Uoo`8008aoo`03001oogoo019o
o`03001oogoo02Uoo`03001oogoo03moo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Io
o`03001oogoo05Moo`006Goo00<007ooOol0Rgoo00<007ooOol04Woo00<007ooOol0:Goo00<007oo
Ool0?goo00<007ooOol01goo00<007ooOol01goo00<007ooOol01Woo00<007ooOol0Egoo000IOol0
0`00Oomoo`2;Ool00`00Oomoo`0BOol00`00Oomoo`0YOol00`00Oomoo`0oOol00`00Oomoo`07Ool0
0`00Oomoo`07Ool00`00Oomoo`06Ool00`00Oomoo`1GOol001Uoo`03001oogoo08]oo`03001oogoo
019oo`03001oogoo02Uoo`03001oogoo03moo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo
00Ioo`03001oogoo05Moo`006Goo00<007ooOol0Rgoo00<007ooOol04Woo00<007ooOol0:Goo00<0
07ooOol0?goo00<007ooOol01goo00<007ooOol01goo00<007ooOol01Woo00<007ooOol0Egoo000I
Ool00`00Oomoo`2;Ool00`00Oomoo`0BOol00`00Oomoo`0YOol00`00Oomoo`0oOol00`00Oomoo`07
Ool00`00Oomoo`07Ool00`00Oomoo`06Ool00`00Oomoo`1GOol001Uoo`03001oogoo08]oo`03001o
ogoo019oo`03001oogoo02Uoo`03001oogoo03moo`03001oogoo00Moo`03001oogoo00Moo`03001o
ogoo00Ioo`03001oogoo05Moo`006Goo0P00Rgoo0`004goo00<007ooOol0:Goo00<007ooOol0?Woo
0`0027oo00<007ooOol01goo00<007ooOol01Goo0`00F7oo000IOol00`00Oomoo`2;Ool00`00Oomo
o`0BOol00`00Oomoo`0YOol00`00Oomoo`0oOol00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomo
o`06Ool00`00Oomoo`1GOol001Uoo`03001oogoo0:1oo`03001oogoo02Uoo`03001oogoo04Uoo`03
001oogoo00Moo`03001oogoo061oo`006Goo00<007ooOol0X7oo00<007ooOol0:Goo00<007ooOol0
BGoo00<007ooOol01goo00<007ooOol0H7oo000IOol00`00Oomoo`2POol00`00Oomoo`0YOol00`00
Oomoo`19Ool00`00Oomoo`07Ool00`00Oomoo`1POol001Uoo`03001oogoo0:1oo`03001oogoo02Uo
o`03001oogoo04Uoo`03001oogoo00Moo`03001oogoo061oo`006Goo0P00XGoo00<007ooOol0:Goo
00<007ooOol0BGoo00<007ooOol01goo00<007ooOol0H7oo000IOol00`00Oomoo`2POol00`00Oomo
o`0YOol00`00Oomoo`19Ool00`00Oomoo`07Ool00`00Oomoo`1POol001Uoo`03001oogoo0:1oo`03
001oogoo02Uoo`03001oogoo04Uoo`03001oogoo00Moo`03001oogoo061oo`006Goo00<007ooOol0
X7oo00<007ooOol0:Goo00<007ooOol0BGoo00<007ooOol01goo00<007ooOol0H7oo000DOol00`00
Oomoo`02Ool00`00Oomoo`2POol00`00Oomoo`0TOol00`00Oomoo`02Ool00`00Oomoo`19Ool00`00
Oomoo`07Ool00`00Oomoo`1POol001=oo`03001oo`0000=oo`03001oogoo09moo`8002Eoo`03001o
o`0000=oo`03001oogoo04Uoo`03001oogoo00Moo`03001oogoo061oo`004goo00<007oo00000goo
0P00Wgoo0`009Goo00<007oo00000goo0P00BGoo0`001goo0`00HGoo000DOol00`00Oomoo`02Ool0
0`00Oomoo`2OOol00`00Oomoo`0UOol00`00Oomoo`02Ool00`00Oomoo`19Ool00`00Oomoo`07Ool0
0`00Oomoo`1POol001=oo`03001oo`0000=oo`03001oogoo0<Ioo`03001oo`0000=oo`03001oogoo
0;Ioo`0057oo00<007ooOol00Woo00<007ooOol0agoo00<007ooOol00Woo00<007ooOol0]Woo003o
OonROol00?mooj9oo`00ogooXWoo003oOonROol00001\
\>"],
  ImageRangeCache->{{{93.5, 509.75}, {236.188, 114.438}} -> {-0.531131, 
  0.566198, 0.00507628, 0.00507628}, {{104.625, 292.188}, {233.25, 
  117.313}} -> {-5.88008, 8.00504, 0.0492913, 0.0797552}, {{311, 498.563}, {
  233.25, 117.313}} -> {-34.1118, 8.00504, 0.104744, 0.0797552}}]
}, Open  ]],

Cell[TextData[{
  "It can be shown using some straightforward algebra, that ",
  Cell[BoxData[
      \(TraditionalForm\`X\_C[k]\)]],
  " the ",
  Cell[BoxData[
      \(TraditionalForm\`N\)]],
  "-point DCT can be obtained from ",
  Cell[BoxData[
      \(TraditionalForm\`\(X\_F\)\&~[k]\)]],
  " the ",
  Cell[BoxData[
      \(TraditionalForm\`2  N\)]],
  "-point DFT of the sequence ",
  Cell[BoxData[
      \(TraditionalForm\`x\&~[n]\)]],
  ". The relationship between the two transforms is given by "
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm
      \`X\_C[k]\  = 
        \[Alpha][k]\/2\ \ \[ExponentialE]\^\(\ \(-\ j\)\ \(\[Pi]\/N\) k\/2\)\ 
          \(X\_F\)\&~[k]\)]],
  ",\t\t",
  Cell[BoxData[
      \(TraditionalForm\`k = 0, 1,  ... , N - 1\)]]
}], "NumberedEquation"],

Cell["where ", "Text"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm
    \`\(X\_F\)\&~[k]\  = \ \ 
      \[Sum]\+\(n = 0\)\%\(2  N - 1\)x\&~[n]\ 
          \[ExponentialE]\^\(\(-j\)\ \(\(2  \[Pi]\)\/\(2  N\)\) k\ n\ 
            \)\)]]], "NumberedEquation"],

Cell[TextData[{
  "In words, the cosine coefficients of a sequence ",
  Cell[BoxData[
      \(TraditionalForm\`x[n]\)]],
  " may be obtained from the appropriately scaled first ",
  Cell[BoxData[
      \(TraditionalForm\`N\)]],
  " coefficients of a ",
  Cell[BoxData[
      \(TraditionalForm\`2  N\)]],
  "-point DFT (using FFT) of an even extension of ",
  Cell[BoxData[
      \(TraditionalForm\`x[n]\)]],
  ". In fact, this result can be extended [Tseng, 1978] by noting that the \
cosine transform is real and therefore the right hand side of (6) must also \
be real. With some basic trigonometric manipulation we get"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm
      \`X\_C[k]\  = 
        \[Alpha][k]\/2\ \ Re[\ \(X\_F\)\&~[k]\ ] 
          1\/Cos[\(\[Pi]\/N\) k\/2]\)]],
  ",\t\t",
  Cell[BoxData[
      \(TraditionalForm\`k = 0, 1,  ... , N - 1\)]]
}], "NumberedEquation"],

Cell[TextData[{
  "Consider a unit pulse sequence ",
  Cell[BoxData[
      \(TraditionalForm\`x[n]\)]],
  " of length ",
  Cell[BoxData[
      \(TraditionalForm\`N = 3\)]],
  ":"
}], "Text"],

Cell[TextData[Cell[BoxData[
    FormBox[
      RowBox[{\(x[n]\), " ", "=", " ", 
        RowBox[{"{", GridBox[{
              {\(1, \), \(for\ \ 0 \[LessEqual] n \[LessEqual] 2\)},
              {\(0, \), "otherwise"}
              }]}]}], TraditionalForm]]]], "NumberedEquation"],

Cell[TextData[{
  "The ",
  Cell[BoxData[
      \(TraditionalForm\`N = 8\)]],
  " point DCT of this sequence reduces to the following summation"
}], "Text"],

Cell[BoxData[
    \(\[Alpha][0] := 1\/\@8; \ \[Alpha][k_] := 1\/2\  /; \ k > 0; \n
    X\_C[k_] := 
      \[Alpha][k]\ 
        \(\[Sum]\+\(n = 0\)\%2 Cos[\(\[Pi]\ \((2  n + 1)\)\ k\)\/16]\)\)], 
  "Input",
  CellLabel->"In[2]:="],

Cell[TextData[{
  "Evaluating ",
  Cell[BoxData[
      \(TraditionalForm\`X\_C[k]\)]],
  " for ",
  Cell[BoxData[
      \(TraditionalForm\`k = 0, 1,  ... , 7\)]],
  " we get"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Table[X\_C[k], \ {k, 0, 7}]\  // N\)], "Input",
  CellLabel->"In[3]:="],

Cell[BoxData[
    \({1.06066017177982119`, 1.18391256286268898`, 0.461939766255643391`, 
      \(-0.172202995058406704`\), \(-0.35355339059327373`\), 
      \(-0.115062362683749919`\), 0.191341716182544772`, 
      0.235494850649535791`}\)], "Output",
  CellLabel->"Out[3]="]
}, Open  ]],

Cell["\<\
While the DFT/FFT-based computation on the right-hand side of (8), results \
in:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(x = ZeroPad[{1, 1, 1}, {0, 5}]; \ x\&~\  = \ Join[x, \ Reverse[x]]; \n
    Drop[Re[16\ DFT[x\&~]], \(-8\)]\/Table[
        \(\(2\ \)\/\[Alpha][k]\) Cos[\(\[Pi]\/16\) k], {k, 0, 7}]\)], "Input",\

  CellLabel->"In[29]:="],

Cell[BoxData[
    \({1.06066017177982119`, 1.18391256286268875`, 0.461939766255643391`, 
      \(-0.172202995058406793`\), \(-0.35355339059327373`\), 
      \(-0.115062362683750007`\), 0.191341716182544825`, 
      0.235494850649535081`}\)], "Output",
  CellLabel->"Out[29]="]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["TWO-DIMENSIONAL DCT", "Section"],

Cell["The series form of the 2-D DCT pair is", "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm
      \`X[k\_1, \ k\_2]\  = \ 
        \[Alpha][k\_1]\ \ \[Alpha][k\_2]\ \ 
          \(\[Sum]\+\(n\_1 = 0\)\%\(N - 1
                \)\(\[Sum]\+\(n\_2 = 0\)\%\(N - 1\)x[n\_1, \ n\_2]\ \ \ 
                Cos[\(\[Pi]\ \((2  n\_1 + 1)\)\ k\_1\)\/\(2\ N\)]\ \ 
                Cos[\(\[Pi]\ \((2  n\_2 + 1)\)\ k\_2\)\/\(2\ N\)]\)\)\)]],
  " \tfor \t",
  Cell[BoxData[
      \(TraditionalForm\`k\_1, \ k\_2\  = \ 0, 1,  ... , N - 1\)]]
}], "NumberedEquation"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm
      \`x\ [n\_1, \ n\_2]\  = \ 
        \[Sum]\+\(k\_1 = 0\)\%\(N - 1
              \)\(\[Sum]\+\(k\_2 = 0\)\%\(N - 1\)\[Alpha][k\_1]\ 
              \[Alpha][k\_2]\ \ X[k\_1, k\_2]\ \ 
              Cos[\(\[Pi]\ \((2  n\_1 + 1)\)\ k\_1\)\/\(2\ N\)]\ \ 
              Cos[\(\[Pi]\ \((2  n\_2 + 1)\)\ k\_2\)\/\(2\ N\)]\)\)]],
  " \tfor\t",
  Cell[BoxData[
      \(TraditionalForm\`n\_1, \ n\_2\  = \ 0, 1,  ... , N - 1\)]]
}], "NumberedEquation"],

Cell[TextData[{
  "with ",
  Cell[BoxData[
      \(TraditionalForm\`\[Alpha][ . ]\)]],
  " defined as in (3). Note that the DCT is separable and so may be computed \
using 1D DCT row and column operations. In analogy with the 1D case, any \
finite length sequence ",
  Cell[BoxData[
      \(TraditionalForm\`x[n, m]\)]],
  " may be represented by a superposition of ",
  Cell[BoxData[
      \(TraditionalForm\`N\^2\)]],
  " distinct, separable, bi-variate sequences (called ",
  StyleBox["basis images",
    FontSlant->"Italic"],
  "). Assuming same dimension ",
  Cell[BoxData[
      \(TraditionalForm\`N\)]],
  " for  each of the two spatial variables ",
  Cell[BoxData[
      \(TraditionalForm\`m\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  ", we obtain the following family of basis images:"
}], "Text"],

Cell[TextData[{
  "\n",
  Cell[BoxData[
      FormBox[
        RowBox[{"(", GridBox[{
              {"1", \(c\_N[n\_1, 1]\), \(c\_N[n\_1, 2]\), ".", 
                \(c\_N[n\_1, N - 1]\)},
              {\(c\_N[n\_2, 1]\), \(c\_N[n\_1, 1]\ \ \ c\_N[n\_2, 1]\), 
                \(c\_N[n\_1, 2]\ \ c\_N[n\_2, 1]\), ".", 
                \(c\_N[n\_1, N - 1]\ \ c\_N[n\_2, 1]\)},
              {".", ".", ".", ".", "."},
              {\(c\_N[n\_2, N - 1]\), \(c\_N[n\_1, 1]\ \ c\_N[n\_2, N - 1]\), 
                \(c\_N[n\_1, 2]\ \ c\_N[n\_2, N - 1]\), ".", 
                \(c\_N[n\_1, N - 1]\ \ c\_N[n\_2, N - 1]\)}
              }], ")"}], TraditionalForm]]],
  "\n"
}], "NumberedEquation"],

Cell[TextData[{
  "Here is a plot of the real part of the 2D DCT basis images of order ",
  Cell[BoxData[
      \(TraditionalForm\`N = 4\)]],
  ". "
}], "Text"],

Cell[BoxData[
    \(\(cbasis = 
      Table[Table[c\_4[m, k]\ \ c\_4[n, l], {m, 0, 3}, {n, 0, 3}], 
        \ {k, 0, 3}, {l, 0, 3}]; \)\)], "Input",
  CellLabel->"In[28]:="],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[
      GraphicsArray[
        Map[ListDensityPlot[#, Mesh \[Rule] False, 
              PlotRange \[Rule] {\(-1\), 1}, FrameTicks \[Rule] None, 
              DisplayFunction \[Rule] Identity]\ &, cbasis, {2}]]]; \)\)], 
  "Input",
  CellLabel->"In[29]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0.0238095 0.238095 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0238095 0.245293 0.245293 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.240385 0.0192308 0.240385 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
B0B0B0B0
09090909
F6F6F6F6
4F4F4F4F
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.267442 0.0238095 0.488926 0.245293 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.240385 0.0192308 0.240385 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
AD926D52
1252ADED
EDAD5212
526D92AD
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.511074 0.0238095 0.732558 0.245293 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.240385 0.0192308 0.240385 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
A25D5DA2
2CD3D32C
D32C2CD3
5DA2A25D
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.754707 0.0238095 0.97619 0.245293 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.240385 0.0192308 0.240385 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
9252AD6D
52ED12AD
AD12ED52
6DAD5292
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.267442 0.245293 0.488926 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.240385 0.0192308 0.240385 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
DADADADA
25252525
25252525
DADADADA
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.267442 0.267442 0.488926 0.488926 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.240385 0.0192308 0.240385 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
D3A25D2C
2C5DA2D3
2C5DA2D3
D3A25D2C
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.511074 0.267442 0.732558 0.488926 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.240385 0.0192308 0.240385 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
C04040C0
40C0C040
40C0C040
C04040C0
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.754707 0.267442 0.97619 0.488926 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.240385 0.0192308 0.240385 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
A22CD35D
5DD32CA2
5DD32CA2
A22CD35D
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.511074 0.245293 0.732558 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.240385 0.0192308 0.240385 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
F6F6F6F6
B0B0B0B0
4F4F4F4F
09090909
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.267442 0.511074 0.488926 0.732558 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.240385 0.0192308 0.240385 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
EDAD5212
AD926D52
526D92AD
1252ADED
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.511074 0.511074 0.732558 0.732558 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.240385 0.0192308 0.240385 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
D32C2CD3
A25D5DA2
5DA2A25D
2CD3D32C
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.754707 0.511074 0.97619 0.732558 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.240385 0.0192308 0.240385 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
AD12ED52
9252AD6D
6DAD5292
52ED12AD
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.754707 0.245293 0.97619 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.240385 0.0192308 0.240385 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFF
FFFFFFFF
FFFFFFFF
FFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.267442 0.754707 0.488926 0.97619 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.240385 0.0192308 0.240385 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
F6B04F09
F6B04F09
F6B04F09
F6B04F09
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.511074 0.754707 0.732558 0.97619 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.240385 0.0192308 0.240385 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
DA2525DA
DA2525DA
DA2525DA
DA2525DA
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.754707 0.754707 0.97619 0.97619 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.240385 0.0192308 0.240385 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
B009F64F
B009F64F
B009F64F
B009F64F
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[29]:=",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo0006Oom10005Oom10005Oom1
0005Oom10007Ool000Ioo`03001oogoo03eoo`03001oogoo00=oo`03001oogoo03eoo`03001oogoo
00=oo`03001oogoo03eoo`03001oogoo00=oo`03001oogoo03eoo`03001oogoo00Eoo`001Woo00<0
07ooOol0?Goo00<007ooOol00goo00<007ooOol0?Goo00<007ooOol00goo00<007ooOol0?Goo00<0
07ooOol00goo00<007ooOol0?Goo00<007ooOol01Goo0006Ool00`00OomJeP0lF]H00goo001oo`04
Ool00`00OomF]@0>E[D?BU8@=Jd?:DX00goo001oo`04Ool00`00DYABU00=DY@O;F/?DY@2Ool00`00
Oomoo`03Ool00`00BU9:DP0=BU8?:DX@E[D?=Jd2Ool00`00Oomoo`05Ool000Ioo`03001ooe[F03aJ
eP03Ool007oo00Aoo`03001ooeJe00iF]@m:DQ0e[@lYBP03Ool007oo00Aoo`03001BU5:D00eBU1l]
J`mBU09oo`03001oogoo00=oo`03001:DTYB00e:DPlYBQ1F]@le[@9oo`03001oogoo00Eoo`001Woo
00<007ooF]H0?5[F00=oo`00Ool017oo00<007ooE[D03UJe3dYB43F]3bU:00=oo`00Ool017oo00<0
05:DDY@03E:D7be[3e:D0Woo00<007ooOol00goo00<004YBBU803DYB3bU:45Je3cF]0Woo00<007oo
Ool01Goo0006Ool00`00OomJeP0lF]H00goo001oo`04Ool00`00OomF]@0>E[D?BU8@=Jd?:DX00goo
001oo`04Ool00`00DYABU00=DY@O;F/?DY@2Ool00`00Oomoo`03Ool00`00BU9:DP0=BU8?:DX@E[D?
=Jd2Ool00`00Oomoo`05Ool000Ioo`03001ooe[F03aJeP03Ool007oo00Aoo`03001ooeJe00iF]@m:
DQ0e[@lYBP03Ool007oo00Aoo`03001BU5:D00eBU1l]J`mBU09oo`03001oogoo00=oo`03001:DTYB
00e:DPlYBQ1F]@le[@9oo`03001oogoo00Eoo`001Woo00<007ooF]H0?5[F00=oo`00Ool017oo00<0
07ooE[D03UJe3dYB43F]3bU:00=oo`00Ool017oo00<005:DDY@03E:D7be[3e:D0Woo00<007ooOol0
0goo00<004YBBU803DYB3bU:45Je3cF]0Woo00<007ooOol01Goo0006Ool00`00OomJeP0lF]H00goo
001oo`04Ool00`00OomF]@0>E[D?BU8@=Jd?:DX00goo001oo`04Ool00`00DYABU00=DY@O;F/?DY@2
Ool00`00Oomoo`03Ool00`00BU9:DP0=BU8?:DX@E[D?=Jd2Ool00`00Oomoo`05Ool000Ioo`03001o
oe[F03aJeP03Ool007oo00Aoo`03001ooeJe00iF]@m:DQ0e[@lYBP03Ool007oo00Aoo`03001BU5:D
00eBU1l]J`mBU09oo`03001oogoo00=oo`03001:DTYB00e:DPlYBQ1F]@le[@9oo`03001oogoo00Eo
o`001Woo00<007ooF]H0?5[F00=oo`00Ool017oo00<007ooE[D03UJe3dYB43F]3bU:00=oo`00Ool0
17oo00<005:DDY@03E:D7be[3e:D0Woo00<007ooOol00goo00<004YBBU803DYB3bU:45Je3cF]0Woo
00<007ooOol01Goo0006Ool00`00OomJeP0lF]H00goo001oo`04Ool00`00OomF]@0>E[D?BU8@=Jd?
:DX00goo001oo`04Ool00`00DYABU00=DY@O;F/?DY@2Ool00`00Oomoo`03Ool00`00BU9:DP0=BU8?
:DX@E[D?=Jd2Ool00`00Oomoo`05Ool000Ioo`03001ooe[F03aJeP03Ool007oo00Aoo`03001ooeJe
00iF]@m:DQ0e[@lYBP03Ool007oo00Aoo`03001BU5:D00eBU1l]J`mBU09oo`03001oogoo00=oo`03
001:DTYB00e:DPlYBQ1F]@le[@9oo`03001oogoo00Eoo`001Woo00<007ooF]H0?5[F00=oo`00Ool0
17oo00<007ooE[D03UJe3dYB43F]3bU:00=oo`00Ool017oo00<005:DDY@03E:D7be[3e:D0Woo00<0
07ooOol00goo00<004YBBU803DYB3bU:45Je3cF]0Woo00<007ooOol01Goo0006Ool00`00OomJeP0l
F]H00goo001oo`04Ool00`00OomF]@0>E[D?BU8@=Jd?:DX00goo001oo`04Ool00`00DYABU00=DY@O
;F/?DY@2Ool00`00Oomoo`03Ool00`00BU9:DP0=BU8?:DX@E[D?=Jd2Ool00`00Oomoo`05Ool000Io
o`03001ooe[F03aJeP03Ool007oo00Aoo`03001ooeJe00iF]@m:DQ0e[@lYBP03Ool007oo00Aoo`03
001BU5:D00eBU1l]J`mBU09oo`03001oogoo00=oo`03001:DTYB00e:DPlYBQ1F]@le[@9oo`03001o
ogoo00Eoo`001Woo00<007ooF]H0?5[F00=oo`00Ool017oo00<007ooE[D03UJe3dYB43F]3bU:00=o
o`00Ool017oo00<005:DDY@03E:D7be[3e:D0Woo00<007ooOol00goo00<004YBBU803DYB3bU:45Je
3cF]0Woo00<007ooOol01Goo0006Ool00`00Ool48@0l12400goo001oo`04Ool00`00Ool8@P0>248?
:DX@E[D?Mkd00goo001oo`04Ool00`005:DDY@0=5:DOJeX?5:D2Ool00`00Oomoo`03Ool00`00:DXY
BP0=:DX?Mkd@248?E[D2Ool00`00Oomoo`05Ool000Ioo`03001oo`@Q03`48@03Ool007oo00Aoo`03
001oo`Q200h8@PlYBQ1F]@mg_@03Ool007oo00Aoo`03000DYABU00dDYAm[FPlDY@9oo`03001oogoo
00=oo`03000YBRU:00dYBPmg_A08@PmF]@9oo`03001oogoo00Eoo`001Woo00<007oo1240?0@Q00=o
o`00Ool017oo00<007oo24803PQ23bU:45Je3gNm00=oo`00Ool017oo00<001BU5:D03ABU7f]J3aBU
0Woo00<007ooOol00goo00<002U::DX03BU:3gNm40Q23eJe0Woo00<007ooOol01Goo0006Ool00`00
Ool48@0l12400goo001oo`04Ool00`00Ool8@P0>248?:DX@E[D?Mkd00goo001oo`04Ool00`005:DD
Y@0=5:DOJeX?5:D2Ool00`00Oomoo`03Ool00`00:DXYBP0=:DX?Mkd@248?E[D2Ool00`00Oomoo`05
Ool000Ioo`03001oo`@Q03`48@03Ool007oo00Aoo`03001oo`Q200h8@PlYBQ1F]@mg_@03Ool007oo
00Aoo`03000DYABU00dDYAm[FPlDY@9oo`03001oogoo00=oo`03000YBRU:00dYBPmg_A08@PmF]@9o
o`03001oogoo00Eoo`001Woo00<007oo1240?0@Q00=oo`00Ool017oo00<007oo24803PQ23bU:45Je
3gNm00=oo`00Ool017oo00<001BU5:D03ABU7f]J3aBU0Woo00<007ooOol00goo00<002U::DX03BU:
3gNm40Q23eJe0Woo00<007ooOol01Goo0006Ool00`00Ool48@0l12400goo001oo`04Ool00`00Ool8
@P0>248?:DX@E[D?Mkd00goo001oo`04Ool00`005:DDY@0=5:DOJeX?5:D2Ool00`00Oomoo`03Ool0
0`00:DXYBP0=:DX?Mkd@248?E[D2Ool00`00Oomoo`05Ool000Ioo`03001oo`@Q03`48@03Ool007oo
00Aoo`03001oo`Q200h8@PlYBQ1F]@mg_@03Ool007oo00Aoo`03000DYABU00dDYAm[FPlDY@9oo`03
001oogoo00=oo`03000YBRU:00dYBPmg_A08@PmF]@9oo`03001oogoo00Eoo`001Woo00<007oo1240
?0@Q00=oo`00Ool017oo00<007oo24803PQ23bU:45Je3gNm00=oo`00Ool017oo00<001BU5:D03ABU
7f]J3aBU0Woo00<007ooOol00goo00<002U::DX03BU:3gNm40Q23eJe0Woo00<007ooOol01Goo0006
Ool00`00Ool48@0l12400goo001oo`04Ool00`00Ool8@P0>248?:DX@E[D?Mkd00goo001oo`04Ool0
0`005:DDY@0=5:DOJeX?5:D2Ool00`00Oomoo`03Ool00`00:DXYBP0=:DX?Mkd@248?E[D2Ool00`00
Oomoo`05Ool000Ioo`03001oo`@Q03`48@03Ool007oo00Aoo`03001oo`Q200h8@PlYBQ1F]@mg_@03
Ool007oo00Aoo`03000DYABU00dDYAm[FPlDY@9oo`03001oogoo00=oo`03000YBRU:00dYBPmg_A08
@PmF]@9oo`03001oogoo00Eoo`001Woo00<007oo1240?0@Q00=oo`00Ool017oo00<007oo24803PQ2
3bU:45Je3gNm00=oo`00Ool017oo00<001BU5:D03ABU7f]J3aBU0Woo00<007ooOol00goo00<002U:
:DX03BU:3gNm40Q23eJe0Woo00<007ooOol01Goo0006Ool00`00Ool48@0l12400goo001oo`04Ool0
0`00Ool8@P0>248?:DX@E[D?Mkd00goo001oo`04Ool00`005:DDY@0=5:DOJeX?5:D2Ool00`00Oomo
o`03Ool00`00:DXYBP0=:DX?Mkd@248?E[D2Ool00`00Oomoo`05Ool000Ioo`03001oo`@Q03`48@03
Ool007oo00Aoo`03001oo`Q200h8@PlYBQ1F]@mg_@03Ool007oo00Aoo`03000DYABU00dDYAm[FPlD
Y@9oo`03001oogoo00=oo`03000YBRU:00dYBPmg_A08@PmF]@9oo`03001oogoo00Eoo`001Woo00<0
07oo1240?0@Q00=oo`00Ool017oo00<007oo24803PQ23bU:45Je3gNm00=oo`00Ool017oo00<001BU
5:D03ABU7f]J3aBU0Woo00<007ooOol00goo00<002U::DX03BU:3gNm40Q23eJe0Woo00<007ooOol0
1Goo0006Ool00`00Ool48@0l12400goo001oo`04Ool00`00Ool8@P0>248?:DX@E[D?Mkd00goo001o
o`04Ool00`005:DDY@0=5:DOJeX?5:D2Ool00`00Oomoo`03Ool00`00:DXYBP0=:DX?Mkd@248?E[D2
Ool00`00Oomoo`05Ool000Ioo`03001oog_N03akgP03Ool007oo00Aoo`03001oogNm00ig_@mF]A0Y
BPl8@P03Ool007oo00Aoo`03001[FV]J00e[FQlDY@m[FP9oo`03001oogoo00=oo`03001F]EJe00eF
]@l8@Q1g_@lYBP9oo`03001oogoo00Eoo`001Woo00<007ooNmh0?7_N00=oo`00Ool017oo00<007oo
Mkd03WNm3eJe42U:3`Q200=oo`00Ool017oo00<006]JJeX03F]J7aBU3f]J0Woo00<007ooOol00goo
00<005JeE[D03EJe3`Q247Nm3bU:0Woo00<007ooOol01Goo0006Ool00`00OomkgP0lNmh00goo001o
o`04Ool00`00Oomg_@0>Mkd?E[D@:DX?24800goo001oo`04Ool00`00JeY[FP0=JeXO5:D?JeX2Ool0
0`00Oomoo`03Ool00`00E[EF]@0=E[D?248@Mkd?:DX2Ool00`00Oomoo`05Ool000Ioo`03001oog_N
03akgP03Ool007oo00Aoo`03001oogNm00ig_@mF]A0YBPl8@P03Ool007oo00Aoo`03001[FV]J00e[
FQlDY@m[FP9oo`03001oogoo00=oo`03001F]EJe00eF]@l8@Q1g_@lYBP9oo`03001oogoo00Eoo`00
1Woo00<007ooNmh0?7_N00=oo`00Ool017oo00<007ooMkd03WNm3eJe42U:3`Q200=oo`00Ool017oo
00<006]JJeX03F]J7aBU3f]J0Woo00<007ooOol00goo00<005JeE[D03EJe3`Q247Nm3bU:0Woo00<0
07ooOol01Goo0006Ool00`00OomkgP0lNmh00goo001oo`04Ool00`00Oomg_@0>Mkd?E[D@:DX?2480
0goo001oo`04Ool00`00JeY[FP0=JeXO5:D?JeX2Ool00`00Oomoo`03Ool00`00E[EF]@0=E[D?248@
Mkd?:DX2Ool00`00Oomoo`05Ool000Ioo`03001oog_N03akgP03Ool007oo00Aoo`03001oogNm00ig
_@mF]A0YBPl8@P03Ool007oo00Aoo`03001[FV]J00e[FQlDY@m[FP9oo`03001oogoo00=oo`03001F
]EJe00eF]@l8@Q1g_@lYBP9oo`03001oogoo00Eoo`001Woo00<007ooNmh0?7_N00=oo`00Ool017oo
00<007ooMkd03WNm3eJe42U:3`Q200=oo`00Ool017oo00<006]JJeX03F]J7aBU3f]J0Woo00<007oo
Ool00goo00<005JeE[D03EJe3`Q247Nm3bU:0Woo00<007ooOol01Goo0006Ool00`00OomkgP0lNmh0
0goo001oo`04Ool00`00Oomg_@0>Mkd?E[D@:DX?24800goo001oo`04Ool00`00JeY[FP0=JeXO5:D?
JeX2Ool00`00Oomoo`03Ool00`00E[EF]@0=E[D?248@Mkd?:DX2Ool00`00Oomoo`05Ool000Ioo`03
001oog_N03akgP03Ool007oo00Aoo`03001oogNm00ig_@mF]A0YBPl8@P03Ool007oo00Aoo`03001[
FV]J00e[FQlDY@m[FP9oo`03001oogoo00=oo`03001F]EJe00eF]@l8@Q1g_@lYBP9oo`03001oogoo
00Eoo`001Woo00<007ooNmh0?7_N00=oo`00Ool017oo00<007ooMkd03WNm3eJe42U:3`Q200=oo`00
Ool017oo00<006]JJeX03F]J7aBU3f]J0Woo00<007ooOol00goo00<005JeE[D03EJe3`Q247Nm3bU:
0Woo00<007ooOol01Goo0006Ool00`00OomkgP0lNmh00goo001oo`04Ool00`00Oomg_@0>Mkd?E[D@
:DX?24800goo001oo`04Ool00`00JeY[FP0=JeXO5:D?JeX2Ool00`00Oomoo`03Ool00`00E[EF]@0=
E[D?248@Mkd?:DX2Ool00`00Oomoo`05Ool000Ioo`03001oog_N03akgP03Ool007oo00Aoo`03001o
ogNm00ig_@mF]A0YBPl8@P03Ool007oo00Aoo`03001[FV]J00e[FQlDY@m[FP9oo`03001oogoo00=o
o`03001F]EJe00eF]@l8@Q1g_@lYBP9oo`03001oogoo00Eoo`001Woo00<007ooNmh0?7_N00=oo`00
Ool017oo00<007ooMkd03WNm3eJe42U:3`Q200=oo`00Ool017oo00<006]JJeX03F]J7aBU3f]J0Woo
00<007ooOol00goo00<005JeE[D03EJe3`Q247Nm3bU:0Woo00<007ooOol01Goo0006Ool00`00Oomk
gP0lNmh00goo001oo`04Ool00`00Oomg_@0>Mkd?E[D@:DX?24800goo001oo`04Ool00`00JeY[FP0=
JeXO5:D?JeX2Ool00`00Oomoo`03Ool00`00E[EF]@0=E[D?248@Mkd?:DX2Ool00`00Oomoo`05Ool0
00Ioo`03001oobDY03`U:@03Ool007oo00Aoo`03001oobU:00hYBPle[A1:DPmF]@03Ool007oo00Ao
o`03000]Jbe[00d]JamBU0l]J`9oo`03001oogoo00=oo`03000e[CF]00de[@mF]A0YBPm:DP9oo`03
001oogoo00Eoo`001Woo00<007oo9BT0?2DY00=oo`00Ool017oo00<007oo:DX03RU:3cF]44YB3eJe
00=oo`00Ool017oo00<002e[;F/03Be[7e:D3be[0Woo00<007ooOol00goo00<003F]=Jd03CF]3eJe
42U:3dYB0Woo00<007ooOol01Goo0006Ool00`00OolU:@0l9BT00goo001oo`04Ool00`00OolYBP0>
:DX?=Jd@BU8?E[D00goo001oo`04Ool00`00;F/]J`0=;F/ODY@?;F/2Ool00`00Oomoo`03Ool00`00
=Jde[@0==Jd?E[D@:DX?BU82Ool00`00Oomoo`05Ool000Ioo`03001oobDY03`U:@03Ool007oo00Ao
o`03001oobU:00hYBPle[A1:DPmF]@03Ool007oo00Aoo`03000]Jbe[00d]JamBU0l]J`9oo`03001o
ogoo00=oo`03000e[CF]00de[@mF]A0YBPm:DP9oo`03001oogoo00Eoo`001Woo00<007oo9BT0?2DY
00=oo`00Ool017oo00<007oo:DX03RU:3cF]44YB3eJe00=oo`00Ool017oo00<002e[;F/03Be[7e:D
3be[0Woo00<007ooOol00goo00<003F]=Jd03CF]3eJe42U:3dYB0Woo00<007ooOol01Goo0006Ool0
0`00OolU:@0l9BT00goo001oo`04Ool00`00OolYBP0>:DX?=Jd@BU8?E[D00goo001oo`04Ool00`00
;F/]J`0=;F/ODY@?;F/2Ool00`00Oomoo`03Ool00`00=Jde[@0==Jd?E[D@:DX?BU82Ool00`00Oomo
o`05Ool000Ioo`03001oobDY03`U:@03Ool007oo00Aoo`03001oobU:00hYBPle[A1:DPmF]@03Ool0
07oo00Aoo`03000]Jbe[00d]JamBU0l]J`9oo`03001oogoo00=oo`03000e[CF]00de[@mF]A0YBPm:
DP9oo`03001oogoo00Eoo`001Woo00<007oo9BT0?2DY00=oo`00Ool017oo00<007oo:DX03RU:3cF]
44YB3eJe00=oo`00Ool017oo00<002e[;F/03Be[7e:D3be[0Woo00<007ooOol00goo00<003F]=Jd0
3CF]3eJe42U:3dYB0Woo00<007ooOol01Goo0006Ool00`00OolU:@0l9BT00goo001oo`04Ool00`00
OolYBP0>:DX?=Jd@BU8?E[D00goo001oo`04Ool00`00;F/]J`0=;F/ODY@?;F/2Ool00`00Oomoo`03
Ool00`00=Jde[@0==Jd?E[D@:DX?BU82Ool00`00Oomoo`05Ool000Ioo`03001oobDY03`U:@03Ool0
07oo00Aoo`03001oobU:00hYBPle[A1:DPmF]@03Ool007oo00Aoo`03000]Jbe[00d]JamBU0l]J`9o
o`03001oogoo00=oo`03000e[CF]00de[@mF]A0YBPm:DP9oo`03001oogoo00Eoo`001Woo00<007oo
9BT0?2DY00=oo`00Ool017oo00<007oo:DX03RU:3cF]44YB3eJe00=oo`00Ool017oo00<002e[;F/0
3Be[7e:D3be[0Woo00<007ooOol00goo00<003F]=Jd03CF]3eJe42U:3dYB0Woo00<007ooOol01Goo
0006Ool00`00OolU:@0l9BT00goo001oo`04Ool00`00OolYBP0>:DX?=Jd@BU8?E[D00goo001oo`04
Ool00`00;F/]J`0=;F/ODY@?;F/2Ool00`00Oomoo`03Ool00`00=Jde[@0==Jd?E[D@:DX?BU82Ool0
0`00Oomoo`05Ool000Ioo`03001oobDY03`U:@03Ool007oo00Aoo`03001oobU:00hYBPle[A1:DPmF
]@03Ool007oo00Aoo`03000]Jbe[00d]JamBU0l]J`9oo`03001oogoo00=oo`03000e[CF]00de[@mF
]A0YBPm:DP9oo`03001oogoo00Eoo`001Woo00<007oo9BT0?2DY00=oo`00Ool017oo00<007oo:DX0
3RU:3cF]44YB3eJe00=oo`00Ool017oo00<002e[;F/03Be[7e:D3be[0Woo00<007ooOol00goo00<0
03F]=Jd03CF]3eJe42U:3dYB0Woo00<007ooOol01Goo0006Ool00`00OolU:@0l9BT00goo001oo`04
Ool00`00OolYBP0>:DX?=Jd@BU8?E[D00goo001oo`04Ool00`00;F/]J`0=;F/ODY@?;F/2Ool00`00
Oomoo`03Ool00`00=Jde[@0==Jd?E[D@:DX?BU82Ool00`00Oomoo`05Ool000Iood4000Eood4000Eo
od4000Eood4000Moo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol000Iood40
00Eood4000Eood4000Eood4000Moo`001Woo00<007ooOol0?Goo00<007ooOol00goo00<007ooOol0
?Goo00<007ooOol00goo00<007ooOol0?Goo00<007ooOol00goo00<007ooOol0?Goo00<007ooOol0
1Goo0006Ool00`00Oomoo`0mOol00`00Oomoo`03Ool00`00Oomoo`0mOol00`00Oomoo`03Ool00`00
Oomoo`0mOol00`00Oomoo`03Ool00`00Oomoo`0mOol00`00Oomoo`05Ool000Ioo`03001oofmk03a_
N`03Ool007oo00Aoo`03001oof]J00i[FPmBU10]J`lDY@03Ool007oo00Aoo`03001S66<H00eS61lQ
20mS609oo`03001oogoo00=oo`03001BU5:D00eBU0lDYA1[FPl]J`9oo`03001oogoo00Eoo`001Woo
00<007ooKg/0?6mk00=oo`00Ool017oo00<007ooJeX03V]J3e:D42e[3aBU00=oo`00Ool017oo00<0
06<HHaP03F<H7b483f<H0Woo00<007ooOol00goo00<005:DDY@03E:D3aBU46]J3be[0Woo00<007oo
Ool01Goo0006Ool00`00Oom_N`0lKg/00goo001oo`04Ool00`00Oom[FP0>JeX?DY@@;F/?5:D00goo
001oo`04Ool00`00HaQS600=HaPO8@P?HaP2Ool00`00Oomoo`03Ool00`00DYABU00=DY@?5:D@JeX?
;F/2Ool00`00Oomoo`05Ool000Ioo`03001oofmk03a_N`03Ool007oo00Aoo`03001oof]J00i[FPmB
U10]J`lDY@03Ool007oo00Aoo`03001S66<H00eS61lQ20mS609oo`03001oogoo00=oo`03001BU5:D
00eBU0lDYA1[FPl]J`9oo`03001oogoo00Eoo`001Woo00<007ooKg/0?6mk00=oo`00Ool017oo00<0
07ooJeX03V]J3e:D42e[3aBU00=oo`00Ool017oo00<006<HHaP03F<H7b483f<H0Woo00<007ooOol0
0goo00<005:DDY@03E:D3aBU46]J3be[0Woo00<007ooOol01Goo0006Ool00`00Oom_N`0lKg/00goo
001oo`04Ool00`00Oom[FP0>JeX?DY@@;F/?5:D00goo001oo`04Ool00`00HaQS600=HaPO8@P?HaP2
Ool00`00Oomoo`03Ool00`00DYABU00=DY@?5:D@JeX?;F/2Ool00`00Oomoo`05Ool000Ioo`03001o
ofmk03a_N`03Ool007oo00Aoo`03001oof]J00i[FPmBU10]J`lDY@03Ool007oo00Aoo`03001S66<H
00eS61lQ20mS609oo`03001oogoo00=oo`03001BU5:D00eBU0lDYA1[FPl]J`9oo`03001oogoo00Eo
o`001Woo00<007ooKg/0?6mk00=oo`00Ool017oo00<007ooJeX03V]J3e:D42e[3aBU00=oo`00Ool0
17oo00<006<HHaP03F<H7b483f<H0Woo00<007ooOol00goo00<005:DDY@03E:D3aBU46]J3be[0Woo
00<007ooOol01Goo0006Ool00`00Oom_N`0lKg/00goo001oo`04Ool00`00Oom[FP0>JeX?DY@@;F/?
5:D00goo001oo`04Ool00`00HaQS600=HaPO8@P?HaP2Ool00`00Oomoo`03Ool00`00DYABU00=DY@?
5:D@JeX?;F/2Ool00`00Oomoo`05Ool000Ioo`03001oofmk03a_N`03Ool007oo00Aoo`03001oof]J
00i[FPmBU10]J`lDY@03Ool007oo00Aoo`03001S66<H00eS61lQ20mS609oo`03001oogoo00=oo`03
001BU5:D00eBU0lDYA1[FPl]J`9oo`03001oogoo00Eoo`001Woo00<007ooKg/0?6mk00=oo`00Ool0
17oo00<007ooJeX03V]J3e:D42e[3aBU00=oo`00Ool017oo00<006<HHaP03F<H7b483f<H0Woo00<0
07ooOol00goo00<005:DDY@03E:D3aBU46]J3be[0Woo00<007ooOol01Goo0006Ool00`00Oom_N`0l
Kg/00goo001oo`04Ool00`00Oom[FP0>JeX?DY@@;F/?5:D00goo001oo`04Ool00`00HaQS600=HaPO
8@P?HaP2Ool00`00Oomoo`03Ool00`00DYABU00=DY@?5:D@JeX?;F/2Ool00`00Oomoo`05Ool000Io
o`03001oofmk03a_N`03Ool007oo00Aoo`03001oof]J00i[FPmBU10]J`lDY@03Ool007oo00Aoo`03
001S66<H00eS61lQ20mS609oo`03001oogoo00=oo`03001BU5:D00eBU0lDYA1[FPl]J`9oo`03001o
ogoo00Eoo`001Woo00<007ooKg/0?6mk00=oo`00Ool017oo00<007ooJeX03V]J3e:D42e[3aBU00=o
o`00Ool017oo00<006<HHaP03F<H7b483f<H0Woo00<007ooOol00goo00<005:DDY@03E:D3aBU46]J
3be[0Woo00<007ooOol01Goo0006Ool00`00Oom_N`0lKg/00goo001oo`04Ool00`00Oom[FP0>JeX?
DY@@;F/?5:D00goo001oo`04Ool00`00HaQS600=HaPO8@P?HaP2Ool00`00Oomoo`03Ool00`00DYAB
U00=DY@?5:D@JeX?;F/2Ool00`00Oomoo`05Ool000Ioo`03001ooa2403`@Q003Ool007oo00Aoo`03
001ooaBU00hDY@l]Ja1BU0m[FP03Ool007oo00Aoo`03000Q224800dQ21mS60lQ209oo`03001oogoo
00=oo`03000]Jbe[00d]J`m[FQ0DY@mBU09oo`03001oogoo00Eoo`001Woo00<007oo48@0?12400=o
o`00Ool017oo00<007oo5:D03QBU3be[45:D3f]J00=oo`00Ool017oo00<002488@P03B487f<H3b48
0Woo00<007ooOol00goo00<002e[;F/03Be[3f]J41BU3e:D0Woo00<007ooOol01Goo0006Ool00`00
Ool@Q00l48@00goo001oo`04Ool00`00OolDY@0>5:D?;F/@DY@?JeX00goo001oo`04Ool00`008@PQ
200=8@POHaP?8@P2Ool00`00Oomoo`03Ool00`00;F/]J`0=;F/?JeX@5:D?DY@2Ool00`00Oomoo`05
Ool000Ioo`03001ooa2403`@Q003Ool007oo00Aoo`03001ooaBU00hDY@l]Ja1BU0m[FP03Ool007oo
00Aoo`03000Q224800dQ21mS60lQ209oo`03001oogoo00=oo`03000]Jbe[00d]J`m[FQ0DY@mBU09o
o`03001oogoo00Eoo`001Woo00<007oo48@0?12400=oo`00Ool017oo00<007oo5:D03QBU3be[45:D
3f]J00=oo`00Ool017oo00<002488@P03B487f<H3b480Woo00<007ooOol00goo00<002e[;F/03Be[
3f]J41BU3e:D0Woo00<007ooOol01Goo0006Ool00`00Ool@Q00l48@00goo001oo`04Ool00`00OolD
Y@0>5:D?;F/@DY@?JeX00goo001oo`04Ool00`008@PQ200=8@POHaP?8@P2Ool00`00Oomoo`03Ool0
0`00;F/]J`0=;F/?JeX@5:D?DY@2Ool00`00Oomoo`05Ool000Ioo`03001ooa2403`@Q003Ool007oo
00Aoo`03001ooaBU00hDY@l]Ja1BU0m[FP03Ool007oo00Aoo`03000Q224800dQ21mS60lQ209oo`03
001oogoo00=oo`03000]Jbe[00d]J`m[FQ0DY@mBU09oo`03001oogoo00Eoo`001Woo00<007oo48@0
?12400=oo`00Ool017oo00<007oo5:D03QBU3be[45:D3f]J00=oo`00Ool017oo00<002488@P03B48
7f<H3b480Woo00<007ooOol00goo00<002e[;F/03Be[3f]J41BU3e:D0Woo00<007ooOol01Goo0006
Ool00`00Ool@Q00l48@00goo001oo`04Ool00`00OolDY@0>5:D?;F/@DY@?JeX00goo001oo`04Ool0
0`008@PQ200=8@POHaP?8@P2Ool00`00Oomoo`03Ool00`00;F/]J`0=;F/?JeX@5:D?DY@2Ool00`00
Oomoo`05Ool000Ioo`03001ooa2403`@Q003Ool007oo00Aoo`03001ooaBU00hDY@l]Ja1BU0m[FP03
Ool007oo00Aoo`03000Q224800dQ21mS60lQ209oo`03001oogoo00=oo`03000]Jbe[00d]J`m[FQ0D
Y@mBU09oo`03001oogoo00Eoo`001Woo00<007oo48@0?12400=oo`00Ool017oo00<007oo5:D03QBU
3be[45:D3f]J00=oo`00Ool017oo00<002488@P03B487f<H3b480Woo00<007ooOol00goo00<002e[
;F/03Be[3f]J41BU3e:D0Woo00<007ooOol01Goo0006Ool00`00Ool@Q00l48@00goo001oo`04Ool0
0`00OolDY@0>5:D?;F/@DY@?JeX00goo001oo`04Ool00`008@PQ200=8@POHaP?8@P2Ool00`00Oomo
o`03Ool00`00;F/]J`0=;F/?JeX@5:D?DY@2Ool00`00Oomoo`05Ool000Ioo`03001ooa2403`@Q003
Ool007oo00Aoo`03001ooaBU00hDY@l]Ja1BU0m[FP03Ool007oo00Aoo`03000Q224800dQ21mS60lQ
209oo`03001oogoo00=oo`03000]Jbe[00d]J`m[FQ0DY@mBU09oo`03001oogoo00Eoo`001Woo00<0
07oo48@0?12400=oo`00Ool017oo00<007oo5:D03QBU3be[45:D3f]J00=oo`00Ool017oo00<00248
8@P03B487f<H3b480Woo00<007ooOol00goo00<002e[;F/03Be[3f]J41BU3e:D0Woo00<007ooOol0
1Goo0006Ool00`00Ool@Q00l48@00goo001oo`04Ool00`00OolDY@0>5:D?;F/@DY@?JeX00goo001o
o`04Ool00`008@PQ200=8@POHaP?8@P2Ool00`00Oomoo`03Ool00`00;F/]J`0=;F/?JeX@5:D?DY@2
Ool00`00Oomoo`05Ool000Ioo`03001ooa2403`@Q003Ool007oo00Aoo`03001ooaBU00hDY@l]Ja1B
U0m[FP03Ool007oo00Aoo`03000Q224800dQ21mS60lQ209oo`03001oogoo00=oo`03000]Jbe[00d]
J`m[FQ0DY@mBU09oo`03001oogoo00Eoo`001Woo00<007oo48@0?12400=oo`00Ool017oo00<007oo
5:D03QBU3be[45:D3f]J00=oo`00Ool017oo00<002488@P03B487f<H3b480Woo00<007ooOol00goo
00<002e[;F/03Be[3f]J41BU3e:D0Woo00<007ooOol01Goo0006Ool00`00Ool@Q00l48@00goo001o
o`04Ool00`00OolDY@0>5:D?;F/@DY@?JeX00goo001oo`04Ool00`008@PQ200=8@POHaP?8@P2Ool0
0`00Oomoo`03Ool00`00;F/]J`0=;F/?JeX@5:D?DY@2Ool00`00Oomoo`05Ool000Ioo`03001ooa24
03`@Q003Ool007oo00Aoo`03001ooaBU00hDY@l]Ja1BU0m[FP03Ool007oo00Aoo`03000Q224800dQ
21mS60lQ209oo`03001oogoo00=oo`03000]Jbe[00d]J`m[FQ0DY@mBU09oo`03001oogoo00Eoo`00
1Woo00<007oo48@0?12400=oo`00Ool017oo00<007oo5:D03QBU3be[45:D3f]J00=oo`00Ool017oo
00<002488@P03B487f<H3b480Woo00<007ooOol00goo00<002e[;F/03Be[3f]J41BU3e:D0Woo00<0
07ooOol01Goo0006Ool00`00Ool@Q00l48@00goo001oo`04Ool00`00OolDY@0>5:D?;F/@DY@?JeX0
0goo001oo`04Ool00`008@PQ200=8@POHaP?8@P2Ool00`00Oomoo`03Ool00`00;F/]J`0=;F/?JeX@
5:D?DY@2Ool00`00Oomoo`05Ool000Ioo`03001ooa2403`@Q003Ool007oo00Aoo`03001ooaBU00hD
Y@l]Ja1BU0m[FP03Ool007oo00Aoo`03000Q224800dQ21mS60lQ209oo`03001oogoo00=oo`03000]
Jbe[00d]J`m[FQ0DY@mBU09oo`03001oogoo00Eoo`001Woo00<007oo48@0?12400=oo`00Ool017oo
00<007oo5:D03QBU3be[45:D3f]J00=oo`00Ool017oo00<002488@P03B487f<H3b480Woo00<007oo
Ool00goo00<002e[;F/03Be[3f]J41BU3e:D0Woo00<007ooOol01Goo0006Ool00`00Ool@Q00l48@0
0goo001oo`04Ool00`00OolDY@0>5:D?;F/@DY@?JeX00goo001oo`04Ool00`008@PQ200=8@POHaP?
8@P2Ool00`00Oomoo`03Ool00`00;F/]J`0=;F/?JeX@5:D?DY@2Ool00`00Oomoo`05Ool000Ioo`03
001ooa2403`@Q003Ool007oo00Aoo`03001ooaBU00hDY@l]Ja1BU0m[FP03Ool007oo00Aoo`03000Q
224800dQ21mS60lQ209oo`03001oogoo00=oo`03000]Jbe[00d]J`m[FQ0DY@mBU09oo`03001oogoo
00Eoo`001Woo00<007oo48@0?12400=oo`00Ool017oo00<007oo5:D03QBU3be[45:D3f]J00=oo`00
Ool017oo00<002488@P03B487f<H3b480Woo00<007ooOol00goo00<002e[;F/03Be[3f]J41BU3e:D
0Woo00<007ooOol01Goo0006Ool00`00Ool@Q00l48@00goo001oo`04Ool00`00OolDY@0>5:D?;F/@
DY@?JeX00goo001oo`04Ool00`008@PQ200=8@POHaP?8@P2Ool00`00Oomoo`03Ool00`00;F/]J`0=
;F/?JeX@5:D?DY@2Ool00`00Oomoo`05Ool000Ioo`03001ooa2403`@Q003Ool007oo00Aoo`03001o
oaBU00hDY@l]Ja1BU0m[FP03Ool007oo00Aoo`03000Q224800dQ21mS60lQ209oo`03001oogoo00=o
o`03000]Jbe[00d]J`m[FQ0DY@mBU09oo`03001oogoo00Eoo`001Woo00<007oo48@0?12400=oo`00
Ool017oo00<007oo5:D03QBU3be[45:D3f]J00=oo`00Ool017oo00<002488@P03B487f<H3b480Woo
00<007ooOol00goo00<002e[;F/03Be[3f]J41BU3e:D0Woo00<007ooOol01Goo0006Ool00`00Ool@
Q00l48@00goo001oo`04Ool00`00OolDY@0>5:D?;F/@DY@?JeX00goo001oo`04Ool00`008@PQ200=
8@POHaP?8@P2Ool00`00Oomoo`03Ool00`00;F/]J`0=;F/?JeX@5:D?DY@2Ool00`00Oomoo`05Ool0
00Ioo`03001ooa2403`@Q003Ool007oo00Aoo`03001ooaBU00hDY@l]Ja1BU0m[FP03Ool007oo00Ao
o`03000Q224800dQ21mS60lQ209oo`03001oogoo00=oo`03000]Jbe[00d]J`m[FQ0DY@mBU09oo`03
001oogoo00Eoo`001Woo00<007ooKg/0?6mk00=oo`00Ool017oo00<007ooJeX03V]J3e:D42e[3aBU
00=oo`00Ool017oo00<006<HHaP03F<H7b483f<H0Woo00<007ooOol00goo00<005:DDY@03E:D3aBU
46]J3be[0Woo00<007ooOol01Goo0006Ool00`00Oom_N`0lKg/00goo001oo`04Ool00`00Oom[FP0>
JeX?DY@@;F/?5:D00goo001oo`04Ool00`00HaQS600=HaPO8@P?HaP2Ool00`00Oomoo`03Ool00`00
DYABU00=DY@?5:D@JeX?;F/2Ool00`00Oomoo`05Ool000Ioo`03001oofmk03a_N`03Ool007oo00Ao
o`03001oof]J00i[FPmBU10]J`lDY@03Ool007oo00Aoo`03001S66<H00eS61lQ20mS609oo`03001o
ogoo00=oo`03001BU5:D00eBU0lDYA1[FPl]J`9oo`03001oogoo00Eoo`001Woo00<007ooKg/0?6mk
00=oo`00Ool017oo00<007ooJeX03V]J3e:D42e[3aBU00=oo`00Ool017oo00<006<HHaP03F<H7b48
3f<H0Woo00<007ooOol00goo00<005:DDY@03E:D3aBU46]J3be[0Woo00<007ooOol01Goo0006Ool0
0`00Oom_N`0lKg/00goo001oo`04Ool00`00Oom[FP0>JeX?DY@@;F/?5:D00goo001oo`04Ool00`00
HaQS600=HaPO8@P?HaP2Ool00`00Oomoo`03Ool00`00DYABU00=DY@?5:D@JeX?;F/2Ool00`00Oomo
o`05Ool000Ioo`03001oofmk03a_N`03Ool007oo00Aoo`03001oof]J00i[FPmBU10]J`lDY@03Ool0
07oo00Aoo`03001S66<H00eS61lQ20mS609oo`03001oogoo00=oo`03001BU5:D00eBU0lDYA1[FPl]
J`9oo`03001oogoo00Eoo`001Woo00<007ooKg/0?6mk00=oo`00Ool017oo00<007ooJeX03V]J3e:D
42e[3aBU00=oo`00Ool017oo00<006<HHaP03F<H7b483f<H0Woo00<007ooOol00goo00<005:DDY@0
3E:D3aBU46]J3be[0Woo00<007ooOol01Goo0006Ool00`00Oom_N`0lKg/00goo001oo`04Ool00`00
Oom[FP0>JeX?DY@@;F/?5:D00goo001oo`04Ool00`00HaQS600=HaPO8@P?HaP2Ool00`00Oomoo`03
Ool00`00DYABU00=DY@?5:D@JeX?;F/2Ool00`00Oomoo`05Ool000Ioo`03001oofmk03a_N`03Ool0
07oo00Aoo`03001oof]J00i[FPmBU10]J`lDY@03Ool007oo00Aoo`03001S66<H00eS61lQ20mS609o
o`03001oogoo00=oo`03001BU5:D00eBU0lDYA1[FPl]J`9oo`03001oogoo00Eoo`001Woo00<007oo
Kg/0?6mk00=oo`00Ool017oo00<007ooJeX03V]J3e:D42e[3aBU00=oo`00Ool017oo00<006<HHaP0
3F<H7b483f<H0Woo00<007ooOol00goo00<005:DDY@03E:D3aBU46]J3be[0Woo00<007ooOol01Goo
0006Ool00`00Oom_N`0lKg/00goo001oo`04Ool00`00Oom[FP0>JeX?DY@@;F/?5:D00goo001oo`04
Ool00`00HaQS600=HaPO8@P?HaP2Ool00`00Oomoo`03Ool00`00DYABU00=DY@?5:D@JeX?;F/2Ool0
0`00Oomoo`05Ool000Ioo`03001oofmk03a_N`03Ool007oo00Aoo`03001oof]J00i[FPmBU10]J`lD
Y@03Ool007oo00Aoo`03001S66<H00eS61lQ20mS609oo`03001oogoo00=oo`03001BU5:D00eBU0lD
YA1[FPl]J`9oo`03001oogoo00Eoo`001Woo00<007ooKg/0?6mk00=oo`00Ool017oo00<007ooJeX0
3V]J3e:D42e[3aBU00=oo`00Ool017oo00<006<HHaP03F<H7b483f<H0Woo00<007ooOol00goo00<0
05:DDY@03E:D3aBU46]J3be[0Woo00<007ooOol01Goo0006Ool00`00Oom_N`0lKg/00goo001oo`04
Ool00`00Oom[FP0>JeX?DY@@;F/?5:D00goo001oo`04Ool00`00HaQS600=HaPO8@P?HaP2Ool00`00
Oomoo`03Ool00`00DYABU00=DY@?5:D@JeX?;F/2Ool00`00Oomoo`05Ool000Ioo`03001oofmk03a_
N`03Ool007oo00Aoo`03001oof]J00i[FPmBU10]J`lDY@03Ool007oo00Aoo`03001S66<H00eS61lQ
20mS609oo`03001oogoo00=oo`03001BU5:D00eBU0lDYA1[FPl]J`9oo`03001oogoo00Eoo`001Woo
@@001Goo@@001Goo@@001Goo@@001goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?mo
ob5oo`001Woo@@001Goo@@001Goo@@001Goo@@001goo0006Ool00`00Oomoo`0mOol00`00Oomoo`03
Ool00`00Oomoo`0mOol00`00Oomoo`03Ool00`00Oomoo`0mOol00`00Oomoo`03Ool00`00Oomoo`0m
Ool00`00Oomoo`05Ool000Ioo`03001oog_N03akgP03Ool007oo00Aoo`03001oogNm00ig_@mF]A0Y
BPl8@P03Ool007oo00Aoo`03001[FV]J00e[FQlDY@m[FP9oo`03001oogoo00=oo`03001F]EJe00eF
]@l8@Q1g_@lYBP9oo`03001oogoo00Eoo`001Woo00<007ooNmh0?7_N00=oo`00Ool017oo00<007oo
Mkd03WNm3eJe42U:3`Q200=oo`00Ool017oo00<006]JJeX03F]J7aBU3f]J0Woo00<007ooOol00goo
00<005JeE[D03EJe3`Q247Nm3bU:0Woo00<007ooOol01Goo0006Ool00`00OomkgP0lNmh00goo001o
o`04Ool00`00Oomg_@0>Mkd?E[D@:DX?24800goo001oo`04Ool00`00JeY[FP0=JeXO5:D?JeX2Ool0
0`00Oomoo`03Ool00`00E[EF]@0=E[D?248@Mkd?:DX2Ool00`00Oomoo`05Ool000Ioo`03001oog_N
03akgP03Ool007oo00Aoo`03001oogNm00ig_@mF]A0YBPl8@P03Ool007oo00Aoo`03001[FV]J00e[
FQlDY@m[FP9oo`03001oogoo00=oo`03001F]EJe00eF]@l8@Q1g_@lYBP9oo`03001oogoo00Eoo`00
1Woo00<007ooNmh0?7_N00=oo`00Ool017oo00<007ooMkd03WNm3eJe42U:3`Q200=oo`00Ool017oo
00<006]JJeX03F]J7aBU3f]J0Woo00<007ooOol00goo00<005JeE[D03EJe3`Q247Nm3bU:0Woo00<0
07ooOol01Goo0006Ool00`00OomkgP0lNmh00goo001oo`04Ool00`00Oomg_@0>Mkd?E[D@:DX?2480
0goo001oo`04Ool00`00JeY[FP0=JeXO5:D?JeX2Ool00`00Oomoo`03Ool00`00E[EF]@0=E[D?248@
Mkd?:DX2Ool00`00Oomoo`05Ool000Ioo`03001oog_N03akgP03Ool007oo00Aoo`03001oogNm00ig
_@mF]A0YBPl8@P03Ool007oo00Aoo`03001[FV]J00e[FQlDY@m[FP9oo`03001oogoo00=oo`03001F
]EJe00eF]@l8@Q1g_@lYBP9oo`03001oogoo00Eoo`001Woo00<007ooNmh0?7_N00=oo`00Ool017oo
00<007ooMkd03WNm3eJe42U:3`Q200=oo`00Ool017oo00<006]JJeX03F]J7aBU3f]J0Woo00<007oo
Ool00goo00<005JeE[D03EJe3`Q247Nm3bU:0Woo00<007ooOol01Goo0006Ool00`00OomkgP0lNmh0
0goo001oo`04Ool00`00Oomg_@0>Mkd?E[D@:DX?24800goo001oo`04Ool00`00JeY[FP0=JeXO5:D?
JeX2Ool00`00Oomoo`03Ool00`00E[EF]@0=E[D?248@Mkd?:DX2Ool00`00Oomoo`05Ool000Ioo`03
001oog_N03akgP03Ool007oo00Aoo`03001oogNm00ig_@mF]A0YBPl8@P03Ool007oo00Aoo`03001[
FV]J00e[FQlDY@m[FP9oo`03001oogoo00=oo`03001F]EJe00eF]@l8@Q1g_@lYBP9oo`03001oogoo
00Eoo`001Woo00<007ooNmh0?7_N00=oo`00Ool017oo00<007ooMkd03WNm3eJe42U:3`Q200=oo`00
Ool017oo00<006]JJeX03F]J7aBU3f]J0Woo00<007ooOol00goo00<005JeE[D03EJe3`Q247Nm3bU:
0Woo00<007ooOol01Goo0006Ool00`00OomkgP0lNmh00goo001oo`04Ool00`00Oomg_@0>Mkd?E[D@
:DX?24800goo001oo`04Ool00`00JeY[FP0=JeXO5:D?JeX2Ool00`00Oomoo`03Ool00`00E[EF]@0=
E[D?248@Mkd?:DX2Ool00`00Oomoo`05Ool000Ioo`03001oog_N03akgP03Ool007oo00Aoo`03001o
ogNm00ig_@mF]A0YBPl8@P03Ool007oo00Aoo`03001[FV]J00e[FQlDY@m[FP9oo`03001oogoo00=o
o`03001F]EJe00eF]@l8@Q1g_@lYBP9oo`03001oogoo00Eoo`001Woo00<007ooNmh0?7_N00=oo`00
Ool017oo00<007ooMkd03WNm3eJe42U:3`Q200=oo`00Ool017oo00<006]JJeX03F]J7aBU3f]J0Woo
00<007ooOol00goo00<005JeE[D03EJe3`Q247Nm3bU:0Woo00<007ooOol01Goo0006Ool00`00Oomk
gP0lNmh00goo001oo`04Ool00`00Oomg_@0>Mkd?E[D@:DX?24800goo001oo`04Ool00`00JeY[FP0=
JeXO5:D?JeX2Ool00`00Oomoo`03Ool00`00E[EF]@0=E[D?248@Mkd?:DX2Ool00`00Oomoo`05Ool0
00Ioo`03001ooe[F03aJeP03Ool007oo00Aoo`03001ooeJe00iF]@m:DQ0e[@lYBP03Ool007oo00Ao
o`03001BU5:D00eBU1l]J`mBU09oo`03001oogoo00=oo`03001:DTYB00e:DPlYBQ1F]@le[@9oo`03
001oogoo00Eoo`001Woo00<007ooF]H0?5[F00=oo`00Ool017oo00<007ooE[D03UJe3dYB43F]3bU:
00=oo`00Ool017oo00<005:DDY@03E:D7be[3e:D0Woo00<007ooOol00goo00<004YBBU803DYB3bU:
45Je3cF]0Woo00<007ooOol01Goo0006Ool00`00OomJeP0lF]H00goo001oo`04Ool00`00OomF]@0>
E[D?BU8@=Jd?:DX00goo001oo`04Ool00`00DYABU00=DY@O;F/?DY@2Ool00`00Oomoo`03Ool00`00
BU9:DP0=BU8?:DX@E[D?=Jd2Ool00`00Oomoo`05Ool000Ioo`03001ooe[F03aJeP03Ool007oo00Ao
o`03001ooeJe00iF]@m:DQ0e[@lYBP03Ool007oo00Aoo`03001BU5:D00eBU1l]J`mBU09oo`03001o
ogoo00=oo`03001:DTYB00e:DPlYBQ1F]@le[@9oo`03001oogoo00Eoo`001Woo00<007ooF]H0?5[F
00=oo`00Ool017oo00<007ooE[D03UJe3dYB43F]3bU:00=oo`00Ool017oo00<005:DDY@03E:D7be[
3e:D0Woo00<007ooOol00goo00<004YBBU803DYB3bU:45Je3cF]0Woo00<007ooOol01Goo0006Ool0
0`00OomJeP0lF]H00goo001oo`04Ool00`00OomF]@0>E[D?BU8@=Jd?:DX00goo001oo`04Ool00`00
DYABU00=DY@O;F/?DY@2Ool00`00Oomoo`03Ool00`00BU9:DP0=BU8?:DX@E[D?=Jd2Ool00`00Oomo
o`05Ool000Ioo`03001ooe[F03aJeP03Ool007oo00Aoo`03001ooeJe00iF]@m:DQ0e[@lYBP03Ool0
07oo00Aoo`03001BU5:D00eBU1l]J`mBU09oo`03001oogoo00=oo`03001:DTYB00e:DPlYBQ1F]@le
[@9oo`03001oogoo00Eoo`001Woo00<007ooF]H0?5[F00=oo`00Ool017oo00<007ooE[D03UJe3dYB
43F]3bU:00=oo`00Ool017oo00<005:DDY@03E:D7be[3e:D0Woo00<007ooOol00goo00<004YBBU80
3DYB3bU:45Je3cF]0Woo00<007ooOol01Goo0006Ool00`00OomJeP0lF]H00goo001oo`04Ool00`00
OomF]@0>E[D?BU8@=Jd?:DX00goo001oo`04Ool00`00DYABU00=DY@O;F/?DY@2Ool00`00Oomoo`03
Ool00`00BU9:DP0=BU8?:DX@E[D?=Jd2Ool00`00Oomoo`05Ool000Ioo`03001ooe[F03aJeP03Ool0
07oo00Aoo`03001ooeJe00iF]@m:DQ0e[@lYBP03Ool007oo00Aoo`03001BU5:D00eBU1l]J`mBU09o
o`03001oogoo00=oo`03001:DTYB00e:DPlYBQ1F]@le[@9oo`03001oogoo00Eoo`001Woo00<007oo
F]H0?5[F00=oo`00Ool017oo00<007ooE[D03UJe3dYB43F]3bU:00=oo`00Ool017oo00<005:DDY@0
3E:D7be[3e:D0Woo00<007ooOol00goo00<004YBBU803DYB3bU:45Je3cF]0Woo00<007ooOol01Goo
0006Ool00`00OomJeP0lF]H00goo001oo`04Ool00`00OomF]@0>E[D?BU8@=Jd?:DX00goo001oo`04
Ool00`00DYABU00=DY@O;F/?DY@2Ool00`00Oomoo`03Ool00`00BU9:DP0=BU8?:DX@E[D?=Jd2Ool0
0`00Oomoo`05Ool000Ioo`03001ooe[F03aJeP03Ool007oo00Aoo`03001ooeJe00iF]@m:DQ0e[@lY
BP03Ool007oo00Aoo`03001BU5:D00eBU1l]J`mBU09oo`03001oogoo00=oo`03001:DTYB00e:DPlY
BQ1F]@le[@9oo`03001oogoo00Eoo`001Woo00<007ooF]H0?5[F00=oo`00Ool017oo00<007ooE[D0
3UJe3dYB43F]3bU:00=oo`00Ool017oo00<005:DDY@03E:D7be[3e:D0Woo00<007ooOol00goo00<0
04YBBU803DYB3bU:45Je3cF]0Woo00<007ooOol01Goo0006Ool00`00OomJeP0lF]H00goo001oo`04
Ool00`00OomF]@0>E[D?BU8@=Jd?:DX00goo001oo`04Ool00`00DYABU00=DY@O;F/?DY@2Ool00`00
Oomoo`03Ool00`00BU9:DP0=BU8?:DX@E[D?=Jd2Ool00`00Oomoo`05Ool000Ioo`03001ooe[F03aJ
eP03Ool007oo00Aoo`03001ooeJe00iF]@m:DQ0e[@lYBP03Ool007oo00Aoo`03001BU5:D00eBU1l]
J`mBU09oo`03001oogoo00=oo`03001:DTYB00e:DPlYBQ1F]@le[@9oo`03001oogoo00Eoo`001Woo
00<007oo9BT0?2DY00=oo`00Ool017oo00<007oo:DX03RU:3cF]44YB3eJe00=oo`00Ool017oo00<0
02e[;F/03Be[7e:D3be[0Woo00<007ooOol00goo00<003F]=Jd03CF]3eJe42U:3dYB0Woo00<007oo
Ool01Goo0006Ool00`00OolU:@0l9BT00goo001oo`04Ool00`00OolYBP0>:DX?=Jd@BU8?E[D00goo
001oo`04Ool00`00;F/]J`0=;F/ODY@?;F/2Ool00`00Oomoo`03Ool00`00=Jde[@0==Jd?E[D@:DX?
BU82Ool00`00Oomoo`05Ool000Ioo`03001oobDY03`U:@03Ool007oo00Aoo`03001oobU:00hYBPle
[A1:DPmF]@03Ool007oo00Aoo`03000]Jbe[00d]JamBU0l]J`9oo`03001oogoo00=oo`03000e[CF]
00de[@mF]A0YBPm:DP9oo`03001oogoo00Eoo`001Woo00<007oo9BT0?2DY00=oo`00Ool017oo00<0
07oo:DX03RU:3cF]44YB3eJe00=oo`00Ool017oo00<002e[;F/03Be[7e:D3be[0Woo00<007ooOol0
0goo00<003F]=Jd03CF]3eJe42U:3dYB0Woo00<007ooOol01Goo0006Ool00`00OolU:@0l9BT00goo
001oo`04Ool00`00OolYBP0>:DX?=Jd@BU8?E[D00goo001oo`04Ool00`00;F/]J`0=;F/ODY@?;F/2
Ool00`00Oomoo`03Ool00`00=Jde[@0==Jd?E[D@:DX?BU82Ool00`00Oomoo`05Ool000Ioo`03001o
obDY03`U:@03Ool007oo00Aoo`03001oobU:00hYBPle[A1:DPmF]@03Ool007oo00Aoo`03000]Jbe[
00d]JamBU0l]J`9oo`03001oogoo00=oo`03000e[CF]00de[@mF]A0YBPm:DP9oo`03001oogoo00Eo
o`001Woo00<007oo9BT0?2DY00=oo`00Ool017oo00<007oo:DX03RU:3cF]44YB3eJe00=oo`00Ool0
17oo00<002e[;F/03Be[7e:D3be[0Woo00<007ooOol00goo00<003F]=Jd03CF]3eJe42U:3dYB0Woo
00<007ooOol01Goo0006Ool00`00OolU:@0l9BT00goo001oo`04Ool00`00OolYBP0>:DX?=Jd@BU8?
E[D00goo001oo`04Ool00`00;F/]J`0=;F/ODY@?;F/2Ool00`00Oomoo`03Ool00`00=Jde[@0==Jd?
E[D@:DX?BU82Ool00`00Oomoo`05Ool000Ioo`03001oobDY03`U:@03Ool007oo00Aoo`03001oobU:
00hYBPle[A1:DPmF]@03Ool007oo00Aoo`03000]Jbe[00d]JamBU0l]J`9oo`03001oogoo00=oo`03
000e[CF]00de[@mF]A0YBPm:DP9oo`03001oogoo00Eoo`001Woo00<007oo9BT0?2DY00=oo`00Ool0
17oo00<007oo:DX03RU:3cF]44YB3eJe00=oo`00Ool017oo00<002e[;F/03Be[7e:D3be[0Woo00<0
07ooOol00goo00<003F]=Jd03CF]3eJe42U:3dYB0Woo00<007ooOol01Goo0006Ool00`00OolU:@0l
9BT00goo001oo`04Ool00`00OolYBP0>:DX?=Jd@BU8?E[D00goo001oo`04Ool00`00;F/]J`0=;F/O
DY@?;F/2Ool00`00Oomoo`03Ool00`00=Jde[@0==Jd?E[D@:DX?BU82Ool00`00Oomoo`05Ool000Io
o`03001oobDY03`U:@03Ool007oo00Aoo`03001oobU:00hYBPle[A1:DPmF]@03Ool007oo00Aoo`03
000]Jbe[00d]JamBU0l]J`9oo`03001oogoo00=oo`03000e[CF]00de[@mF]A0YBPm:DP9oo`03001o
ogoo00Eoo`001Woo00<007oo9BT0?2DY00=oo`00Ool017oo00<007oo:DX03RU:3cF]44YB3eJe00=o
o`00Ool017oo00<002e[;F/03Be[7e:D3be[0Woo00<007ooOol00goo00<003F]=Jd03CF]3eJe42U:
3dYB0Woo00<007ooOol01Goo0006Ool00`00OolU:@0l9BT00goo001oo`04Ool00`00OolYBP0>:DX?
=Jd@BU8?E[D00goo001oo`04Ool00`00;F/]J`0=;F/ODY@?;F/2Ool00`00Oomoo`03Ool00`00=Jde
[@0==Jd?E[D@:DX?BU82Ool00`00Oomoo`05Ool000Ioo`03001oobDY03`U:@03Ool007oo00Aoo`03
001oobU:00hYBPle[A1:DPmF]@03Ool007oo00Aoo`03000]Jbe[00d]JamBU0l]J`9oo`03001oogoo
00=oo`03000e[CF]00de[@mF]A0YBPm:DP9oo`03001oogoo00Eoo`001Woo00<007oo1240?0@Q00=o
o`00Ool017oo00<007oo24803PQ23bU:45Je3gNm00=oo`00Ool017oo00<001BU5:D03ABU7f]J3aBU
0Woo00<007ooOol00goo00<002U::DX03BU:3gNm40Q23eJe0Woo00<007ooOol01Goo0006Ool00`00
Ool48@0l12400goo001oo`04Ool00`00Ool8@P0>248?:DX@E[D?Mkd00goo001oo`04Ool00`005:DD
Y@0=5:DOJeX?5:D2Ool00`00Oomoo`03Ool00`00:DXYBP0=:DX?Mkd@248?E[D2Ool00`00Oomoo`05
Ool000Ioo`03001oo`@Q03`48@03Ool007oo00Aoo`03001oo`Q200h8@PlYBQ1F]@mg_@03Ool007oo
00Aoo`03000DYABU00dDYAm[FPlDY@9oo`03001oogoo00=oo`03000YBRU:00dYBPmg_A08@PmF]@9o
o`03001oogoo00Eoo`001Woo00<007oo1240?0@Q00=oo`00Ool017oo00<007oo24803PQ23bU:45Je
3gNm00=oo`00Ool017oo00<001BU5:D03ABU7f]J3aBU0Woo00<007ooOol00goo00<002U::DX03BU:
3gNm40Q23eJe0Woo00<007ooOol01Goo0006Ool00`00Ool48@0l12400goo001oo`04Ool00`00Ool8
@P0>248?:DX@E[D?Mkd00goo001oo`04Ool00`005:DDY@0=5:DOJeX?5:D2Ool00`00Oomoo`03Ool0
0`00:DXYBP0=:DX?Mkd@248?E[D2Ool00`00Oomoo`05Ool000Ioo`03001oo`@Q03`48@03Ool007oo
00Aoo`03001oo`Q200h8@PlYBQ1F]@mg_@03Ool007oo00Aoo`03000DYABU00dDYAm[FPlDY@9oo`03
001oogoo00=oo`03000YBRU:00dYBPmg_A08@PmF]@9oo`03001oogoo00Eoo`001Woo00<007oo1240
?0@Q00=oo`00Ool017oo00<007oo24803PQ23bU:45Je3gNm00=oo`00Ool017oo00<001BU5:D03ABU
7f]J3aBU0Woo00<007ooOol00goo00<002U::DX03BU:3gNm40Q23eJe0Woo00<007ooOol01Goo0006
Ool00`00Ool48@0l12400goo001oo`04Ool00`00Ool8@P0>248?:DX@E[D?Mkd00goo001oo`04Ool0
0`005:DDY@0=5:DOJeX?5:D2Ool00`00Oomoo`03Ool00`00:DXYBP0=:DX?Mkd@248?E[D2Ool00`00
Oomoo`05Ool000Ioo`03001oo`@Q03`48@03Ool007oo00Aoo`03001oo`Q200h8@PlYBQ1F]@mg_@03
Ool007oo00Aoo`03000DYABU00dDYAm[FPlDY@9oo`03001oogoo00=oo`03000YBRU:00dYBPmg_A08
@PmF]@9oo`03001oogoo00Eoo`001Woo00<007oo1240?0@Q00=oo`00Ool017oo00<007oo24803PQ2
3bU:45Je3gNm00=oo`00Ool017oo00<001BU5:D03ABU7f]J3aBU0Woo00<007ooOol00goo00<002U:
:DX03BU:3gNm40Q23eJe0Woo00<007ooOol01Goo0006Ool00`00Ool48@0l12400goo001oo`04Ool0
0`00Ool8@P0>248?:DX@E[D?Mkd00goo001oo`04Ool00`005:DDY@0=5:DOJeX?5:D2Ool00`00Oomo
o`03Ool00`00:DXYBP0=:DX?Mkd@248?E[D2Ool00`00Oomoo`05Ool000Ioo`03001oo`@Q03`48@03
Ool007oo00Aoo`03001oo`Q200h8@PlYBQ1F]@mg_@03Ool007oo00Aoo`03000DYABU00dDYAm[FPlD
Y@9oo`03001oogoo00=oo`03000YBRU:00dYBPmg_A08@PmF]@9oo`03001oogoo00Eoo`001Woo00<0
07oo1240?0@Q00=oo`00Ool017oo00<007oo24803PQ23bU:45Je3gNm00=oo`00Ool017oo00<001BU
5:D03ABU7f]J3aBU0Woo00<007ooOol00goo00<002U::DX03BU:3gNm40Q23eJe0Woo00<007ooOol0
1Goo0006Ool00`00Ool48@0l12400goo001oo`04Ool00`00Ool8@P0>248?:DX@E[D?Mkd00goo001o
o`04Ool00`005:DDY@0=5:DOJeX?5:D2Ool00`00Oomoo`03Ool00`00:DXYBP0=:DX?Mkd@248?E[D2
Ool00`00Oomoo`05Ool000Ioo`03001oo`@Q03`48@03Ool007oo00Aoo`03001oo`Q200h8@PlYBQ1F
]@mg_@03Ool007oo00Aoo`03000DYABU00dDYAm[FPlDY@9oo`03001oogoo00=oo`03000YBRU:00dY
BPmg_A08@PmF]@9oo`03001oogoo00Eoo`001Woo00<007ooOol0?Goo00<007ooOol00goo00<007oo
Ool0?Goo00<007ooOol00goo00<007ooOol0?Goo00<007ooOol00goo00<007ooOol0?Goo00<007oo
Ool01Goo0006Oom10005Oom10005Oom10005Oom10007Ool00?moob5oo`00ogoo8Goo003oOolQOol0
0?moob5oo`00ogoo8Goo0006Oom10005Oom10005Oom10005Oom10007Ool000Ioo`03001oogoo03eo
o`03001oogoo00=oo`03001oogoo03eoo`03001oogoo00=oo`03001oogoo03eoo`03001oogoo00=o
o`03001oogoo03eoo`03001oogoo00Eoo`001Woo00<007ooOol0?Goo00<007ooOol00goo00<007oo
Nmh03W_N3e[F42DY3`@Q00=oo`00Ool017oo00<006mkKg/03Fmk7a243fmk0Woo00<007ooOol00goo
00<005[FF]H03E[F3`@Q47_N3bDY0Woo00<007ooOol01Goo0006Ool00`00Oomoo`0mOol00`00Oomo
o`03Ool00`00OomkgP0>Nmh?F]H@9BT?12400goo001oo`04Ool00`00Kg]_N`0=Kg/O48@?Kg/2Ool0
0`00Oomoo`03Ool00`00F]IJeP0=F]H?124@Nmh?9BT2Ool00`00Oomoo`05Ool000Ioo`03001oogoo
03eoo`03001oogoo00=oo`03001oog_N00ikgPmJeQ0U:@l48@03Ool007oo00Aoo`03001_Nfmk00e_
Nal@Q0m_N`9oo`03001oogoo00=oo`03001JeU[F00eJePl48A1kgPlU:@9oo`03001oogoo00Eoo`00
1Woo00<007ooOol0?Goo00<007ooOol00goo00<007ooNmh03W_N3e[F42DY3`@Q00=oo`00Ool017oo
00<006mkKg/03Fmk7a243fmk0Woo00<007ooOol00goo00<005[FF]H03E[F3`@Q47_N3bDY0Woo00<0
07ooOol01Goo0006Ool00`00Oomoo`0mOol00`00Oomoo`03Ool00`00OomkgP0>Nmh?F]H@9BT?1240
0goo001oo`04Ool00`00Kg]_N`0=Kg/O48@?Kg/2Ool00`00Oomoo`03Ool00`00F]IJeP0=F]H?124@
Nmh?9BT2Ool00`00Oomoo`05Ool000Ioo`03001oogoo03eoo`03001oogoo00=oo`03001oog_N00ik
gPmJeQ0U:@l48@03Ool007oo00Aoo`03001_Nfmk00e_Nal@Q0m_N`9oo`03001oogoo00=oo`03001J
eU[F00eJePl48A1kgPlU:@9oo`03001oogoo00Eoo`001Woo00<007ooOol0?Goo00<007ooOol00goo
00<007ooNmh03W_N3e[F42DY3`@Q00=oo`00Ool017oo00<006mkKg/03Fmk7a243fmk0Woo00<007oo
Ool00goo00<005[FF]H03E[F3`@Q47_N3bDY0Woo00<007ooOol01Goo0006Ool00`00Oomoo`0mOol0
0`00Oomoo`03Ool00`00OomkgP0>Nmh?F]H@9BT?12400goo001oo`04Ool00`00Kg]_N`0=Kg/O48@?
Kg/2Ool00`00Oomoo`03Ool00`00F]IJeP0=F]H?124@Nmh?9BT2Ool00`00Oomoo`05Ool000Ioo`03
001oogoo03eoo`03001oogoo00=oo`03001oog_N00ikgPmJeQ0U:@l48@03Ool007oo00Aoo`03001_
Nfmk00e_Nal@Q0m_N`9oo`03001oogoo00=oo`03001JeU[F00eJePl48A1kgPlU:@9oo`03001oogoo
00Eoo`001Woo00<007ooOol0?Goo00<007ooOol00goo00<007ooNmh03W_N3e[F42DY3`@Q00=oo`00
Ool017oo00<006mkKg/03Fmk7a243fmk0Woo00<007ooOol00goo00<005[FF]H03E[F3`@Q47_N3bDY
0Woo00<007ooOol01Goo0006Ool00`00Oomoo`0mOol00`00Oomoo`03Ool00`00OomkgP0>Nmh?F]H@
9BT?12400goo001oo`04Ool00`00Kg]_N`0=Kg/O48@?Kg/2Ool00`00Oomoo`03Ool00`00F]IJeP0=
F]H?124@Nmh?9BT2Ool00`00Oomoo`05Ool000Ioo`03001oogoo03eoo`03001oogoo00=oo`03001o
og_N00ikgPmJeQ0U:@l48@03Ool007oo00Aoo`03001_Nfmk00e_Nal@Q0m_N`9oo`03001oogoo00=o
o`03001JeU[F00eJePl48A1kgPlU:@9oo`03001oogoo00Eoo`001Woo00<007ooOol0?Goo00<007oo
Ool00goo00<007ooNmh03W_N3e[F42DY3`@Q00=oo`00Ool017oo00<006mkKg/03Fmk7a243fmk0Woo
00<007ooOol00goo00<005[FF]H03E[F3`@Q47_N3bDY0Woo00<007ooOol01Goo0006Ool00`00Oomo
o`0mOol00`00Oomoo`03Ool00`00OomkgP0>Nmh?F]H@9BT?12400goo001oo`04Ool00`00Kg]_N`0=
Kg/O48@?Kg/2Ool00`00Oomoo`03Ool00`00F]IJeP0=F]H?124@Nmh?9BT2Ool00`00Oomoo`05Ool0
00Ioo`03001oogoo03eoo`03001oogoo00=oo`03001oog_N00ikgPmJeQ0U:@l48@03Ool007oo00Ao
o`03001_Nfmk00e_Nal@Q0m_N`9oo`03001oogoo00=oo`03001JeU[F00eJePl48A1kgPlU:@9oo`03
001oogoo00Eoo`001Woo00<007ooOol0?Goo00<007ooOol00goo00<007ooNmh03W_N3e[F42DY3`@Q
00=oo`00Ool017oo00<006mkKg/03Fmk7a243fmk0Woo00<007ooOol00goo00<005[FF]H03E[F3`@Q
47_N3bDY0Woo00<007ooOol01Goo0006Ool00`00Oomoo`0mOol00`00Oomoo`03Ool00`00OomkgP0>
Nmh?F]H@9BT?12400goo001oo`04Ool00`00Kg]_N`0=Kg/O48@?Kg/2Ool00`00Oomoo`03Ool00`00
F]IJeP0=F]H?124@Nmh?9BT2Ool00`00Oomoo`05Ool000Ioo`03001oogoo03eoo`03001oogoo00=o
o`03001oog_N00ikgPmJeQ0U:@l48@03Ool007oo00Aoo`03001_Nfmk00e_Nal@Q0m_N`9oo`03001o
ogoo00=oo`03001JeU[F00eJePl48A1kgPlU:@9oo`03001oogoo00Eoo`001Woo00<007ooOol0?Goo
00<007ooOol00goo00<007ooNmh03W_N3e[F42DY3`@Q00=oo`00Ool017oo00<006mkKg/03Fmk7a24
3fmk0Woo00<007ooOol00goo00<005[FF]H03E[F3`@Q47_N3bDY0Woo00<007ooOol01Goo0006Ool0
0`00Oomoo`0mOol00`00Oomoo`03Ool00`00OomkgP0>Nmh?F]H@9BT?12400goo001oo`04Ool00`00
Kg]_N`0=Kg/O48@?Kg/2Ool00`00Oomoo`03Ool00`00F]IJeP0=F]H?124@Nmh?9BT2Ool00`00Oomo
o`05Ool000Ioo`03001oogoo03eoo`03001oogoo00=oo`03001oog_N00ikgPmJeQ0U:@l48@03Ool0
07oo00Aoo`03001_Nfmk00e_Nal@Q0m_N`9oo`03001oogoo00=oo`03001JeU[F00eJePl48A1kgPlU
:@9oo`03001oogoo00Eoo`001Woo00<007ooOol0?Goo00<007ooOol00goo00<007ooNmh03W_N3e[F
42DY3`@Q00=oo`00Ool017oo00<006mkKg/03Fmk7a243fmk0Woo00<007ooOol00goo00<005[FF]H0
3E[F3`@Q47_N3bDY0Woo00<007ooOol01Goo0006Ool00`00Oomoo`0mOol00`00Oomoo`03Ool00`00
OomkgP0>Nmh?F]H@9BT?12400goo001oo`04Ool00`00Kg]_N`0=Kg/O48@?Kg/2Ool00`00Oomoo`03
Ool00`00F]IJeP0=F]H?124@Nmh?9BT2Ool00`00Oomoo`05Ool000Ioo`03001oogoo03eoo`03001o
ogoo00=oo`03001oog_N00ikgPmJeQ0U:@l48@03Ool007oo00Aoo`03001_Nfmk00e_Nal@Q0m_N`9o
o`03001oogoo00=oo`03001JeU[F00eJePl48A1kgPlU:@9oo`03001oogoo00Eoo`001Woo00<007oo
Ool0?Goo00<007ooOol00goo00<007ooNmh03W_N3e[F42DY3`@Q00=oo`00Ool017oo00<006mkKg/0
3Fmk7a243fmk0Woo00<007ooOol00goo00<005[FF]H03E[F3`@Q47_N3bDY0Woo00<007ooOol01Goo
0006Ool00`00Oomoo`0mOol00`00Oomoo`03Ool00`00OomkgP0>Nmh?F]H@9BT?12400goo001oo`04
Ool00`00Kg]_N`0=Kg/O48@?Kg/2Ool00`00Oomoo`03Ool00`00F]IJeP0=F]H?124@Nmh?9BT2Ool0
0`00Oomoo`05Ool000Ioo`03001oogoo03eoo`03001oogoo00=oo`03001oog_N00ikgPmJeQ0U:@l4
8@03Ool007oo00Aoo`03001_Nfmk00e_Nal@Q0m_N`9oo`03001oogoo00=oo`03001JeU[F00eJePl4
8A1kgPlU:@9oo`03001oogoo00Eoo`001Woo00<007ooOol0?Goo00<007ooOol00goo00<007ooNmh0
3W_N3e[F42DY3`@Q00=oo`00Ool017oo00<006mkKg/03Fmk7a243fmk0Woo00<007ooOol00goo00<0
05[FF]H03E[F3`@Q47_N3bDY0Woo00<007ooOol01Goo0006Ool00`00Oomoo`0mOol00`00Oomoo`03
Ool00`00OomkgP0>Nmh?F]H@9BT?12400goo001oo`04Ool00`00Kg]_N`0=Kg/O48@?Kg/2Ool00`00
Oomoo`03Ool00`00F]IJeP0=F]H?124@Nmh?9BT2Ool00`00Oomoo`05Ool000Ioo`03001oogoo03eo
o`03001oogoo00=oo`03001oog_N00ikgPmJeQ0U:@l48@03Ool007oo00Aoo`03001_Nfmk00e_Nal@
Q0m_N`9oo`03001oogoo00=oo`03001JeU[F00eJePl48A1kgPlU:@9oo`03001oogoo00Eoo`001Woo
00<007ooOol0?Goo00<007ooOol00goo00<007ooNmh03W_N3e[F42DY3`@Q00=oo`00Ool017oo00<0
06mkKg/03Fmk7a243fmk0Woo00<007ooOol00goo00<005[FF]H03E[F3`@Q47_N3bDY0Woo00<007oo
Ool01Goo0006Ool00`00Oomoo`0mOol00`00Oomoo`03Ool00`00OomkgP0>Nmh?F]H@9BT?12400goo
001oo`04Ool00`00Kg]_N`0=Kg/O48@?Kg/2Ool00`00Oomoo`03Ool00`00F]IJeP0=F]H?124@Nmh?
9BT2Ool00`00Oomoo`05Ool000Ioo`03001oogoo03eoo`03001oogoo00=oo`03001oog_N00ikgPmJ
eQ0U:@l48@03Ool007oo00Aoo`03001_Nfmk00e_Nal@Q0m_N`9oo`03001oogoo00=oo`03001JeU[F
00eJePl48A1kgPlU:@9oo`03001oogoo00Eoo`001Woo00<007ooOol0?Goo00<007ooOol00goo00<0
07ooNmh03W_N3e[F42DY3`@Q00=oo`00Ool017oo00<006mkKg/03Fmk7a243fmk0Woo00<007ooOol0
0goo00<005[FF]H03E[F3`@Q47_N3bDY0Woo00<007ooOol01Goo0006Ool00`00Oomoo`0mOol00`00
Oomoo`03Ool00`00OomkgP0>Nmh?F]H@9BT?12400goo001oo`04Ool00`00Kg]_N`0=Kg/O48@?Kg/2
Ool00`00Oomoo`03Ool00`00F]IJeP0=F]H?124@Nmh?9BT2Ool00`00Oomoo`05Ool000Ioo`03001o
ogoo03eoo`03001oogoo00=oo`03001oog_N00ikgPmJeQ0U:@l48@03Ool007oo00Aoo`03001_Nfmk
00e_Nal@Q0m_N`9oo`03001oogoo00=oo`03001JeU[F00eJePl48A1kgPlU:@9oo`03001oogoo00Eo
o`001Woo00<007ooOol0?Goo00<007ooOol00goo00<007ooNmh03W_N3e[F42DY3`@Q00=oo`00Ool0
17oo00<006mkKg/03Fmk7a243fmk0Woo00<007ooOol00goo00<005[FF]H03E[F3`@Q47_N3bDY0Woo
00<007ooOol01Goo0006Ool00`00Oomoo`0mOol00`00Oomoo`03Ool00`00OomkgP0>Nmh?F]H@9BT?
12400goo001oo`04Ool00`00Kg]_N`0=Kg/O48@?Kg/2Ool00`00Oomoo`03Ool00`00F]IJeP0=F]H?
124@Nmh?9BT2Ool00`00Oomoo`05Ool000Ioo`03001oogoo03eoo`03001oogoo00=oo`03001oog_N
00ikgPmJeQ0U:@l48@03Ool007oo00Aoo`03001_Nfmk00e_Nal@Q0m_N`9oo`03001oogoo00=oo`03
001JeU[F00eJePl48A1kgPlU:@9oo`03001oogoo00Eoo`001Woo00<007ooOol0?Goo00<007ooOol0
0goo00<007ooNmh03W_N3e[F42DY3`@Q00=oo`00Ool017oo00<006mkKg/03Fmk7a243fmk0Woo00<0
07ooOol00goo00<005[FF]H03E[F3`@Q47_N3bDY0Woo00<007ooOol01Goo0006Ool00`00Oomoo`0m
Ool00`00Oomoo`03Ool00`00OomkgP0>Nmh?F]H@9BT?12400goo001oo`04Ool00`00Kg]_N`0=Kg/O
48@?Kg/2Ool00`00Oomoo`03Ool00`00F]IJeP0=F]H?124@Nmh?9BT2Ool00`00Oomoo`05Ool000Io
o`03001oogoo03eoo`03001oogoo00=oo`03001oog_N00ikgPmJeQ0U:@l48@03Ool007oo00Aoo`03
001_Nfmk00e_Nal@Q0m_N`9oo`03001oogoo00=oo`03001JeU[F00eJePl48A1kgPlU:@9oo`03001o
ogoo00Eoo`001Woo00<007ooOol0?Goo00<007ooOol00goo00<007ooNmh03W_N3e[F42DY3`@Q00=o
o`00Ool017oo00<006mkKg/03Fmk7a243fmk0Woo00<007ooOol00goo00<005[FF]H03E[F3`@Q47_N
3bDY0Woo00<007ooOol01Goo0006Ool00`00Oomoo`0mOol00`00Oomoo`03Ool00`00OomkgP0>Nmh?
F]H@9BT?12400goo001oo`04Ool00`00Kg]_N`0=Kg/O48@?Kg/2Ool00`00Oomoo`03Ool00`00F]IJ
eP0=F]H?124@Nmh?9BT2Ool00`00Oomoo`05Ool000Ioo`03001oogoo03eoo`03001oogoo00=oo`03
001oog_N00ikgPmJeQ0U:@l48@03Ool007oo00Aoo`03001_Nfmk00e_Nal@Q0m_N`9oo`03001oogoo
00=oo`03001JeU[F00eJePl48A1kgPlU:@9oo`03001oogoo00Eoo`001Woo00<007ooOol0?Goo00<0
07ooOol00goo00<007ooNmh03W_N3e[F42DY3`@Q00=oo`00Ool017oo00<006mkKg/03Fmk7a243fmk
0Woo00<007ooOol00goo00<005[FF]H03E[F3`@Q47_N3bDY0Woo00<007ooOol01Goo0006Ool00`00
Oomoo`0mOol00`00Oomoo`03Ool00`00OomkgP0>Nmh?F]H@9BT?12400goo001oo`04Ool00`00Kg]_
N`0=Kg/O48@?Kg/2Ool00`00Oomoo`03Ool00`00F]IJeP0=F]H?124@Nmh?9BT2Ool00`00Oomoo`05
Ool000Ioo`03001oogoo03eoo`03001oogoo00=oo`03001oog_N00ikgPmJeQ0U:@l48@03Ool007oo
00Aoo`03001_Nfmk00e_Nal@Q0m_N`9oo`03001oogoo00=oo`03001JeU[F00eJePl48A1kgPlU:@9o
o`03001oogoo00Eoo`001Woo00<007ooOol0?Goo00<007ooOol00goo00<007ooNmh03W_N3e[F42DY
3`@Q00=oo`00Ool017oo00<006mkKg/03Fmk7a243fmk0Woo00<007ooOol00goo00<005[FF]H03E[F
3`@Q47_N3bDY0Woo00<007ooOol01Goo0006Ool00`00Oomoo`0mOol00`00Oomoo`03Ool00`00Oomk
gP0>Nmh?F]H@9BT?12400goo001oo`04Ool00`00Kg]_N`0=Kg/O48@?Kg/2Ool00`00Oomoo`03Ool0
0`00F]IJeP0=F]H?124@Nmh?9BT2Ool00`00Oomoo`05Ool000Ioo`03001oogoo03eoo`03001oogoo
00=oo`03001oog_N00ikgPmJeQ0U:@l48@03Ool007oo00Aoo`03001_Nfmk00e_Nal@Q0m_N`9oo`03
001oogoo00=oo`03001JeU[F00eJePl48A1kgPlU:@9oo`03001oogoo00Eoo`001Woo00<007ooOol0
?Goo00<007ooOol00goo00<007ooNmh03W_N3e[F42DY3`@Q00=oo`00Ool017oo00<006mkKg/03Fmk
7a243fmk0Woo00<007ooOol00goo00<005[FF]H03E[F3`@Q47_N3bDY0Woo00<007ooOol01Goo0006
Ool00`00Oomoo`0mOol00`00Oomoo`03Ool00`00OomkgP0>Nmh?F]H@9BT?12400goo001oo`04Ool0
0`00Kg]_N`0=Kg/O48@?Kg/2Ool00`00Oomoo`03Ool00`00F]IJeP0=F]H?124@Nmh?9BT2Ool00`00
Oomoo`05Ool000Ioo`03001oogoo03eoo`03001oogoo00=oo`03001oog_N00ikgPmJeQ0U:@l48@03
Ool007oo00Aoo`03001_Nfmk00e_Nal@Q0m_N`9oo`03001oogoo00=oo`03001JeU[F00eJePl48A1k
gPlU:@9oo`03001oogoo00Eoo`001Woo00<007ooOol0?Goo00<007ooOol00goo00<007ooNmh03W_N
3e[F42DY3`@Q00=oo`00Ool017oo00<006mkKg/03Fmk7a243fmk0Woo00<007ooOol00goo00<005[F
F]H03E[F3`@Q47_N3bDY0Woo00<007ooOol01Goo0006Ool00`00Oomoo`0mOol00`00Oomoo`03Ool0
0`00OomkgP0>Nmh?F]H@9BT?12400goo001oo`04Ool00`00Kg]_N`0=Kg/O48@?Kg/2Ool00`00Oomo
o`03Ool00`00F]IJeP0=F]H?124@Nmh?9BT2Ool00`00Oomoo`05Ool000Ioo`03001oogoo03eoo`03
001oogoo00=oo`03001oog_N00ikgPmJeQ0U:@l48@03Ool007oo00Aoo`03001_Nfmk00e_Nal@Q0m_
N`9oo`03001oogoo00=oo`03001JeU[F00eJePl48A1kgPlU:@9oo`03001oogoo00Eoo`001Woo00<0
07ooOol0?Goo00<007ooOol00goo00<007ooNmh03W_N3e[F42DY3`@Q00=oo`00Ool017oo00<006mk
Kg/03Fmk7a243fmk0Woo00<007ooOol00goo00<005[FF]H03E[F3`@Q47_N3bDY0Woo00<007ooOol0
1Goo0006Ool00`00Oomoo`0mOol00`00Oomoo`03Ool00`00OomkgP0>Nmh?F]H@9BT?12400goo001o
o`04Ool00`00Kg]_N`0=Kg/O48@?Kg/2Ool00`00Oomoo`03Ool00`00F]IJeP0=F]H?124@Nmh?9BT2
Ool00`00Oomoo`05Ool000Ioo`03001oogoo03eoo`03001oogoo00=oo`03001oog_N00ikgPmJeQ0U
:@l48@03Ool007oo00Aoo`03001_Nfmk00e_Nal@Q0m_N`9oo`03001oogoo00=oo`03001JeU[F00eJ
ePl48A1kgPlU:@9oo`03001oogoo00Eoo`001Woo00<007ooOol0?Goo00<007ooOol00goo00<007oo
Nmh03W_N3e[F42DY3`@Q00=oo`00Ool017oo00<006mkKg/03Fmk7a243fmk0Woo00<007ooOol00goo
00<005[FF]H03E[F3`@Q47_N3bDY0Woo00<007ooOol01Goo0006Ool00`00Oomoo`0mOol00`00Oomo
o`03Ool00`00Oomoo`0mOol00`00Oomoo`03Ool00`00Oomoo`0mOol00`00Oomoo`03Ool00`00Oomo
o`0mOol00`00Oomoo`05Ool000Iood4000Eood4000Eood4000Eood4000Moo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-0.100021, -0.100021, 0.0146343, 
  0.0146343}, {{6.8125, 70.375}, {280.125, 
  216.563}} -> {-0.535859, -0.539965, 0.0657064, 0.0657064}, {{76.75, 
  140.313}, {280.125, 216.563}} -> {-5.1312, -0.539965, 0.0657064, 
  0.0657064}, {{146.625, 210.188}, {280.125, 
  216.563}} -> {-9.72243, -0.539965, 0.0657064, 0.0657064}, {{216.563, 
  280.125}, {280.125, 216.563}} -> {-14.3178, -0.539965, 0.0657064, 
  0.0657064}, {{6.8125, 70.375}, {210.188, 146.625}} -> {-0.535859, -5.13531, 
  0.0657064, 0.0657064}, {{76.75, 140.313}, {210.188, 
  146.625}} -> {-5.1312, -5.13531, 0.0657064, 0.0657064}, {{146.625, 
  210.188}, {210.188, 146.625}} -> {-9.72243, -5.13531, 0.0657064, 
  0.0657064}, {{216.563, 280.125}, {210.188, 
  146.625}} -> {-14.3178, -5.13531, 0.0657064, 0.0657064}, {{6.8125, 
  70.375}, {140.313, 76.75}} -> {-0.535859, -9.72654, 0.0657064, 
  0.0657064}, {{76.75, 140.313}, {140.313, 76.75}} -> {-5.1312, -9.72654, 
  0.0657064, 0.0657064}, {{146.625, 210.188}, {140.313, 
  76.75}} -> {-9.72243, -9.72654, 0.0657064, 0.0657064}, {{216.563, 
  280.125}, {140.313, 76.75}} -> {-14.3178, -9.72654, 0.0657064, 
  0.0657064}, {{6.8125, 70.375}, {70.375, 6.8125}} -> {-0.535859, -14.3219, 
  0.0657064, 0.0657064}, {{76.75, 140.313}, {70.375, 
  6.8125}} -> {-5.1312, -14.3219, 0.0657064, 0.0657064}, {{146.625, 
  210.188}, {70.375, 6.8125}} -> {-9.72243, -14.3219, 0.0657064, 
  0.0657064}, {{216.563, 280.125}, {70.375, 6.8125}} -> {-14.3178, -14.3219, 
  0.0657064, 0.0657064}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["DCT AS A MATRIX OPERATION", "Section"],

Cell[TextData[{
  "We begin with an evaluation of the cosine kernel matrix of order 8. A plot \
of the ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalC]\)]],
  " quickly reveals that the cosine kernel matrix is not symmetric."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[ScriptCapitalC] = CosineKernel[8]\  // N; \n
    Show[GraphicsArray[{
          ListPlot3D[\[ScriptCapitalC], DisplayFunction \[Rule] Identity], 
          ListDensityPlot[\[ScriptCapitalC], Mesh \[Rule] False, 
            DisplayFunction \[Rule] Identity]}]]; \)], "Input",
  CellLabel->"In[36]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .38626 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.00919655 0.47619 [
[ 0 0 0 0 ]
[ 1 .38626 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .38626 L
0 .38626 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.00919655 0.477324 0.377059 MathSubStart
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1.04977 -0.0679587 1.04977 [
[.11158 .21312 -6 -8.95035 ]
[.11158 .21312 0 .04965 ]
[.28836 .14356 -5.67606 -9 ]
[.28836 .14356 .32394 0 ]
[.47788 .06904 -5.31864 -9 ]
[.47788 .06904 .68136 0 ]
[.68156 -0.01098 -4.96123 -9 ]
[.68156 -0.01098 1.03877 0 ]
[.74908 .0689 0 -6.18931 ]
[.74908 .0689 6 2.81069 ]
[.83635 .20254 0 -6.06047 ]
[.83635 .20254 6 2.93953 ]
[.9134 .32052 0 -5.94988 ]
[.9134 .32052 6 3.05012 ]
[.98191 .42546 0 -5.85393 ]
[.98191 .42546 6 3.14607 ]
[.02444 .26307 -24 -2.7406 ]
[.02444 .26307 0 6.2594 ]
[.01585 .3169 -30 -2.7861 ]
[.01585 .3169 0 6.2139 ]
[.00696 .37264 -6 -2.83339 ]
[.00696 .37264 0 6.16661 ]
[-0.00226 .4304 -24 -2.88257 ]
[-0.00226 .4304 0 6.11743 ]
[-0.01181 .49029 -18 -2.93376 ]
[-0.01181 .49029 0 6.06624 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.03716 .25514 m
.68874 0 L
s
.12091 .22234 m
.12558 .22696 L
s
[(2)] .11158 .21312 1 .98897 Mshowa
.2971 .15335 m
.30147 .15825 L
s
[(4)] .28836 .14356 .89202 1 Mshowa
.4859 .07942 m
.48992 .08461 L
s
[(6)] .47788 .06904 .77288 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(8)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.16384 .20553 m
.1666 .20834 L
s
.20751 .18843 m
.21022 .19129 L
s
.25192 .17104 m
.25459 .17394 L
s
.34306 .13535 m
.34564 .13834 L
s
.38984 .11704 m
.39236 .12006 L
s
.43745 .0984 m
.43991 .10147 L
s
.53524 .06011 m
.53759 .06327 L
s
.58547 .04044 m
.58776 .04364 L
s
.63663 .0204 m
.63885 .02365 L
s
.07869 .23888 m
.08153 .2416 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.7368 .07352 m
.73065 .07582 L
s
[(2)] .74908 .0689 -1 .3754 Mshowa
.82395 .20683 m
.81775 .20898 L
s
[(4)] .83635 .20254 -1 .34677 Mshowa
.90091 .32455 m
.89466 .32656 L
s
[(6)] .9134 .32052 -1 .3222 Mshowa
.96935 .42924 m
.96306 .43113 L
s
[(8)] .98191 .42546 -1 .30087 Mshowa
.125 Mabswid
.75965 .10848 m
.75596 .10983 L
s
.78177 .14231 m
.77807 .14365 L
s
.8032 .17508 m
.79948 .1764 L
s
.84407 .23761 m
.84035 .23888 L
s
.86359 .26746 m
.85986 .26871 L
s
.88252 .29643 m
.87878 .29766 L
s
.91876 .35185 m
.915 .35304 L
s
.9361 .37838 m
.93234 .37955 L
s
.95296 .40417 m
.94919 .40532 L
s
.71317 .03738 m
.7095 .03879 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03666 .2583 m
.04277 .25591 L
s
[(-0.5)] .02444 .26307 1 -0.39098 Mshowa
.02811 .31223 m
.03424 .30989 L
s
[(-0.25)] .01585 .3169 1 -0.38087 Mshowa
.01926 .36808 m
.02541 .3658 L
s
[(0)] .00696 .37264 1 -0.37036 Mshowa
.01009 .42596 m
.01626 .42374 L
s
[(0.25)] -0.00226 .4304 1 -0.35943 Mshowa
.00058 .48598 m
.00677 .48382 L
s
[(0.5)] -0.01181 .49029 1 -0.34805 Mshowa
.125 Mabswid
.03497 .26893 m
.03864 .26751 L
s
.03328 .27964 m
.03695 .27822 L
s
.03157 .29043 m
.03524 .28902 L
s
.02985 .30129 m
.03352 .29988 L
s
.02637 .32324 m
.03005 .32185 L
s
.02461 .33433 m
.02829 .33294 L
s
.02284 .3455 m
.02653 .34412 L
s
.02106 .35675 m
.02475 .35538 L
s
.01745 .37949 m
.02115 .37813 L
s
.01563 .39098 m
.01933 .38963 L
s
.0138 .40256 m
.0175 .40121 L
s
.01195 .41422 m
.01565 .41288 L
s
.00822 .43779 m
.01192 .43646 L
s
.00633 .4497 m
.01004 .44839 L
s
.00442 .46171 m
.00814 .4604 L
s
.00251 .4738 m
.00622 .4725 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.5 Mabswid
.909 .795 .723 r
.35377 .70217 .40099 .72205 .47859 .62368 .43575 .54451 Metetra
.766 .368 0 r
.43575 .54451 .47859 .62368 .55696 .74748 .5127 .71673 Metetra
.912 .793 .715 r
.5127 .71673 .55696 .74748 .63352 .53519 .59441 .55138 Metetra
.59441 .55138 .63352 .53519 .72586 .71964 .67807 .52635 Metetra
.324 .3 .678 r
.67807 .52635 .72586 .71964 .79812 .5013 .7747 .64507 Metetra
0 0 .118 r
.7747 .64507 .79812 .5013 .89999 .62428 .84752 .41717 Metetra
.381 .334 .68 r
.84752 .41717 .89999 .62428 .98128 .51655 .9557 .53098 Metetra
.913 .782 .703 r
.30349 .67936 .35377 .70217 .43575 .54451 .39033 .49391 Metetra
.631 .146 0 r
.39033 .49391 .43575 .54451 .5127 .71673 .46717 .59209 Metetra
.405 .419 .761 r
.46717 .59209 .5127 .71673 .59441 .55138 .55209 .63829 Metetra
.795 .845 .386 r
.55209 .63829 .59441 .55138 .67807 .52635 .63482 .43093 Metetra
.389 .46 .812 r
.63482 .43093 .67807 .52635 .7747 .64507 .72571 .47109 Metetra
.316 .314 .699 r
.72571 .47109 .7747 .64507 .84752 .41717 .82917 .57721 Metetra
0 0 .221 r
.82917 .57721 .84752 .41717 .9557 .53098 .90691 .37483 Metetra
.907 .782 .712 r
.24996 .65257 .30349 .67936 .39033 .49391 .34068 .47462 Metetra
.622 .872 .989 r
.34068 .47462 .39033 .49391 .46717 .59209 .42177 .44803 Metetra
0 .122 .639 r
.42177 .44803 .46717 .59209 .55209 .63829 .50443 .57634 Metetra
.65 .704 .886 r
.50443 .57634 .55209 .63829 .63482 .43093 .59485 .54926 Metetra
.59485 .54926 .63482 .43093 .72571 .47109 .68058 .36316 Metetra
.64 .588 .781 r
.68058 .36316 .72571 .47109 .82917 .57721 .77245 .33303 Metetra
.344 .294 .658 r
.77245 .33303 .82917 .57721 .90691 .37483 .88495 .46235 Metetra
.887 .793 .751 r
.19302 .6208 .24996 .65257 .34068 .47462 .28542 .47953 Metetra
.914 .934 .808 r
.28542 .47953 .34068 .47462 .42177 .44803 .37338 .36808 Metetra
.438 .543 .866 r
.37338 .36808 .42177 .44803 .50443 .57634 .45694 .38391 Metetra
.291 .281 .675 r
.45694 .38391 .50443 .57634 .59485 .54926 .54622 .47902 Metetra
.379 .563 .907 r
.54622 .47902 .59485 .54926 .68058 .36316 .64312 .49996 Metetra
.068 0 .134 r
.64312 .49996 .68058 .36316 .77245 .33303 .73692 .37583 Metetra
.739 .888 .488 r
.73692 .37583 .77245 .33303 .88495 .46235 .82606 .22815 Metetra
.835 .808 .825 r
.13254 .58304 .19302 .6208 .28542 .47953 .22418 .49243 Metetra
.911 .957 .808 r
.22418 .49243 .28542 .47953 .37338 .36808 .31702 .3775 Metetra
.853 .988 .849 r
.31702 .3775 .37338 .36808 .45694 .38391 .40716 .28842 Metetra
.645 .621 .812 r
.40716 .28842 .45694 .38391 .54622 .47902 .49639 .25643 Metetra
.488 .395 .677 r
.49639 .25643 .54622 .47902 .64312 .49996 .58987 .28262 Metetra
.426 .362 .683 r
.58987 .28262 .64312 .49996 .73692 .37583 .69186 .33723 Metetra
.074 .523 .9 r
.69186 .33723 .73692 .37583 .82606 .22815 .80141 .36896 Metetra
.725 .802 .912 r
.06842 .53837 .13254 .58304 .22418 .49243 .15815 .49115 Metetra
.762 .968 .928 r
.15815 .49115 .22418 .49243 .31702 .3775 .2513 .42774 Metetra
.447 .82 .569 r
.2513 .42774 .31702 .3775 .40716 .28842 .34639 .35351 Metetra
.34639 .35351 .40716 .28842 .49639 .25643 .44239 .27526 Metetra
.667 .968 .79 r
.44239 .27526 .49639 .25643 .58987 .28262 .53903 .19981 Metetra
.743 .716 .826 r
.53903 .19981 .58987 .28262 .69186 .33723 .63687 .13297 Metetra
.628 .502 .69 r
.63687 .13297 .69186 .33723 .80141 .36896 .73719 .07886 Metetra
.639 .655 .85 r
.00619 .45055 .06842 .53837 .15815 .49115 .0948 .41912 Metetra
.647 .708 .892 r
.0948 .41912 .15815 .49115 .2513 .42774 .18663 .38654 Metetra
.64 .826 .972 r
.18663 .38654 .2513 .42774 .34639 .35351 .28183 .35276 Metetra
.464 .886 .909 r
.28183 .35276 .34639 .35351 .44239 .27526 .38062 .31772 Metetra
.38062 .31772 .44239 .27526 .53903 .19981 .48319 .28133 Metetra
.175 0 0 r
.48319 .28133 .53903 .19981 .63687 .13297 .58977 .24352 Metetra
.262 0 .051 r
.58977 .24352 .63687 .13297 .73719 .07886 .70059 .2042 Metetra
0 g
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.12091 .22234 m
.12558 .22696 L
s
[(2)] .11158 .21312 1 .98897 Mshowa
.2971 .15335 m
.30147 .15825 L
s
[(4)] .28836 .14356 .89202 1 Mshowa
.4859 .07942 m
.48992 .08461 L
s
[(6)] .47788 .06904 .77288 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(8)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.16384 .20553 m
.1666 .20834 L
s
.20751 .18843 m
.21022 .19129 L
s
.25192 .17104 m
.25459 .17394 L
s
.34306 .13535 m
.34564 .13834 L
s
.38984 .11704 m
.39236 .12006 L
s
.43745 .0984 m
.43991 .10147 L
s
.53524 .06011 m
.53759 .06327 L
s
.58547 .04044 m
.58776 .04364 L
s
.63663 .0204 m
.63885 .02365 L
s
.07869 .23888 m
.08153 .2416 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.00919655 0.97619 0.377059 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.120192 0.0192308 0.120192 [
[.01923 -0.0125 -3 -9 ]
[.01923 -0.0125 3 0 ]
[.25962 -0.0125 -3 -9 ]
[.25962 -0.0125 3 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.74038 -0.0125 -3 -9 ]
[.74038 -0.0125 3 0 ]
[.98077 -0.0125 -3 -9 ]
[.98077 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01923 -6 -4.5 ]
[-0.0125 .01923 0 4.5 ]
[-0.0125 .25962 -6 -4.5 ]
[-0.0125 .25962 0 4.5 ]
[-0.0125 .5 -6 -4.5 ]
[-0.0125 .5 0 4.5 ]
[-0.0125 .74038 -6 -4.5 ]
[-0.0125 .74038 0 4.5 ]
[-0.0125 .98077 -6 -4.5 ]
[-0.0125 .98077 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.01923 0 m
.01923 .00625 L
s
[(0)] .01923 -0.0125 0 1 Mshowa
.25962 0 m
.25962 .00625 L
s
[(2)] .25962 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(4)] .5 -0.0125 0 1 Mshowa
.74038 0 m
.74038 .00625 L
s
[(6)] .74038 -0.0125 0 1 Mshowa
.98077 0 m
.98077 .00625 L
s
[(8)] .98077 -0.0125 0 1 Mshowa
.125 Mabswid
.07933 0 m
.07933 .00375 L
s
.13942 0 m
.13942 .00375 L
s
.19952 0 m
.19952 .00375 L
s
.31971 0 m
.31971 .00375 L
s
.37981 0 m
.37981 .00375 L
s
.4399 0 m
.4399 .00375 L
s
.5601 0 m
.5601 .00375 L
s
.62019 0 m
.62019 .00375 L
s
.68029 0 m
.68029 .00375 L
s
.80048 0 m
.80048 .00375 L
s
.86058 0 m
.86058 .00375 L
s
.92067 0 m
.92067 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01923 m
.00625 .01923 L
s
[(0)] -0.0125 .01923 1 0 Mshowa
0 .25962 m
.00625 .25962 L
s
[(2)] -0.0125 .25962 1 0 Mshowa
0 .5 m
.00625 .5 L
s
[(4)] -0.0125 .5 1 0 Mshowa
0 .74038 m
.00625 .74038 L
s
[(6)] -0.0125 .74038 1 0 Mshowa
0 .98077 m
.00625 .98077 L
s
[(8)] -0.0125 .98077 1 0 Mshowa
.125 Mabswid
0 .07933 m
.00375 .07933 L
s
0 .13942 m
.00375 .13942 L
s
0 .19952 m
.00375 .19952 L
s
0 .31971 m
.00375 .31971 L
s
0 .37981 m
.00375 .37981 L
s
0 .4399 m
.00375 .4399 L
s
0 .5601 m
.00375 .5601 L
s
0 .62019 m
.00375 .62019 L
s
0 .68029 m
.00375 .68029 L
s
0 .80048 m
.00375 .80048 L
s
0 .86058 m
.00375 .86058 L
s
0 .92067 m
.00375 .92067 L
s
.25 Mabswid
0 0 m
0 1 L
s
.01923 .99375 m
.01923 1 L
s
.25962 .99375 m
.25962 1 L
s
.5 .99375 m
.5 1 L
s
.74038 .99375 m
.74038 1 L
s
.98077 .99375 m
.98077 1 L
s
.125 Mabswid
.07933 .99625 m
.07933 1 L
s
.13942 .99625 m
.13942 1 L
s
.19952 .99625 m
.19952 1 L
s
.31971 .99625 m
.31971 1 L
s
.37981 .99625 m
.37981 1 L
s
.4399 .99625 m
.4399 1 L
s
.5601 .99625 m
.5601 1 L
s
.62019 .99625 m
.62019 1 L
s
.68029 .99625 m
.68029 1 L
s
.80048 .99625 m
.80048 1 L
s
.86058 .99625 m
.86058 1 L
s
.92067 .99625 m
.92067 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .01923 m
1 .01923 L
s
.99375 .25962 m
1 .25962 L
s
.99375 .5 m
1 .5 L
s
.99375 .74038 m
1 .74038 L
s
.99375 .98077 m
1 .98077 L
s
.125 Mabswid
.99625 .07933 m
1 .07933 L
s
.99625 .13942 m
1 .13942 L
s
.99625 .19952 m
1 .19952 L
s
.99625 .31971 m
1 .31971 L
s
.99625 .37981 m
1 .37981 L
s
.99625 .4399 m
1 .4399 L
s
.99625 .5601 m
1 .5601 L
s
.99625 .62019 m
1 .62019 L
s
.99625 .68029 m
1 .68029 L
s
.99625 .80048 m
1 .80048 L
s
.99625 .86058 m
1 .86058 L
s
.99625 .92067 m
1 .92067 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
DCDCDCDCDCDCDCDC
FFECC89966371300
F8B14E07074EB1F8
EC660037C8FF9913
DC2323DCDC2323DC
C80099EC1366FF37
B107F84E4EF807B1
9937EC00FF13C866
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[36]:=",
  ImageSize->{216, 83.375},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003H0000Da000`40O003h00Of7oo003HOol00=Qo
o`00Pgoo00<007ooOol02goo0`003Woo0`0037oo0P003goo00<007ooOol04goo0022Ool00`00Ool0
000<Ool00`00Oomoo`0?Ool00`00Oomoo`0;Ool00`00Ool0000=Ool00`00Ool0000DOol0089oo`03
001oo`0000eoo`03001oogoo00aoo`@000aoo`03001oo`0000eoo`03001oo`0001Aoo`00PWoo00<0
07oo00003Goo00<007ooOol037oo00<007oo00003Goo0P003goo00<007ooOol04goo0022Ool00`00
Ool0000<Ool00`00Ool0000>Ool2000=Ool00`00Oomoo`0=Ool00`00Ool0000DOol008=oo`03001o
ogoo00aoo`03001oogoo00ioo`03001oogoo00aoo`8000ioo`03001oogoo01=oo`00f7oo003HOol0
07ioo`03001oogoo05Moo`00Bgoo00<007ooOol0;goo00<007oo00000Woo@P0057oo001:Ool00`00
Ool0000`Ool00`00Ool00002Ool00`00Oomoo`0nOol00`00Oomoo`0BOol004Yoo`03001oo`00031o
o`03001oo`00009oo`03001_Nfmk03e_N`03Ool007oo01=oo`00Bgoo00<007ooOol0;goo00<007oo
00000Woo00<006mkKg/0?Fmk00=oo`00Ool04goo001:Ool00`00Ool0000aOol01@00Oomoogoo0000
?fmk00=oo`00Ool04goo000mOol2000<Ool00`00Oomoo`0dOol00`00Kg]_N`0mKg/00goo001oo`0C
Ool003eoo`03001oo`00049oo`03001_Nfmk03e_N`03Ool007oo01=oo`00?Goo00<007oo0000@Woo
00<006mkKg/0?Fmk00=oo`00Ool04goo000mOol20013Ool00`00Kg]_N`0mKg/00goo001oo`0COol0
03eoo`03001oogoo00eoo`8000Aoo`<002aoo`03001_Nfmk03e_N`03Ool007oo01=oo`00<Woo0`00
2Goo0P002Woo0`0000=oo`0000000goo00<007ooOol0;7oo00<007ooOol01Woo27Nm26Li1dic236<
21S620Q2200000=oo`00Ool04goo000cOol00`00Oomoo`0AOol40003Ool20004Ool00`00Oomoo`0[
Ool00`00Oomoo`06Ool8Mkd8IcT7CW<8<H`86<H8248800000goo001oo`0COol0035oo`@000moo`04
001oo`000006Ool00`00Ool00003Ool00`00Oomoo`0[Ool00`00Oomoo`06Ool8Mkd8IcT7CW<8<H`8
6<H8248800000goo001oo`0COol0035oo`03001oo`0000moo`<000Qoo`08001oo`00001oo`00Ool0
02aoo`03001oogoo00Ioo`Qg_@QW>@M>L`PaS0PHaPP8@PP00003Ool007oo01=oo`009Goo0`002Woo
0P0037oo0`002goo00@007oo0000009oo`03001oogoo02]oo`03001oogoo00Ioo`Qg_@QW>@M>L`Pa
S0PHaPP8@PP00003Ool007oo01=oo`009Goo00<007ooOol02goo00<007ooOol027oo0P003Woo0P00
00<P0@000000:Woo0`000Woo00<007ooOol01Woo27Nm26Li1dic236<21S620Q2200000=oo`00Ool0
4goo000VOol00`00Oomoo`0BOol3000>Ool30000120100000000:Woo00<007ooOol00Woo00<007oo
Ool01Woo27Nm26Li1dic236<21S620Q2200000=oo`00Ool04goo000VOol00`00Oomoo`0?Ool3000?
Ool20003804200000e8F00000005Ool3000ROol01@00Oomoogoo000027oo27Nm26Li1dic236<21S6
20Q2200000=oo`00Ool04goo000UOol00`00Ool0000=Ool4000?Ool3000480400`00DQIB5P030005
Ool00`00Oomoo`0QOol01@00Oomoogoo000027oo25[F22DY3`0022DY25[F2Goo00<007ooOol04Woo
000VOol00`00Oomoo`09Ool01000Ool000004Goo00<001@000001B0100H0058FDQH007oo0003Ool4
000QOol00`00Ool00002Ool00`00Oomoo`06Ool8F]H89BT?00089BT8F]H9Ool00`00Oomoo`0BOol0
035oo`<0015oo`80008D0003000P0B0100<P0@04001B5U8F0002Ool01P00Oomoo`00Ool002=oo`05
001oogooOol00008Ool8F]H89BT?00089BT8F]H9Ool00`00Oomoo`0BOol002ioo`<001=oo`05000D
01@05000000580420003DQH01000Oomoo`000Woo0P009goo00<007ooOol01Woo25[F22DY3`0022DY
25[F2Goo00<007ooOol04Woo000/Ool2000EOol00`00500D000250000`00804P0@0280430003DQH0
1000Oomoo`000goo00<007ooOol09Goo00<007ooOol01Woo25[F22DY3`0022DY25[F2Goo00<007oo
Ool04Woo000YOol3000FOol2000350000`00804000030002DQH01@00DQIB5U8F00000Woo0P00:Woo
00<007ooOol01Woo25[F22DY3`0022DY25[F2Goo00<007ooOol04Woo000WOol2000GOol300035003
0003G]X01000DQH000000e8F00<007oo00000P00:Woo00<007ooOol01Woo25[F22DY3`0022DY25[F
2Goo00<007ooOol04Woo000UOol2000HOol80004G]X30002DQH01@00DQIB5P00Ool0100017oo0P00
8goo00<007ooOol01Woo25[F22DY3`0022DY25[F2Goo00<007ooOol04Woo000GOol00`00Oomoo`02
Ool00`00Oomoo`02Ool01000Oomoogoo0P005goo1@000SfE1P000UkJ00@0058FDQH000=B5P03000:
700000<000=oo`03001oo`00029oo`03001g_GNm00Ig_@PaS0P000LHaPQW>@Qoo`Q>L`P8@P03Ool0
07oo01=oo`005Woo00<007oo00001goo00@007oo001oo`800003Ool007oo01=oo`@0009BN@03000m
UCfE00D000=NfP05001B5U8FDQH00002DQH01@002Q`00000Ool00P000Woo00<007oo00008Woo00<0
07NmMkd01WNm236<20001aS626Li27oo24ic20Q200=oo`00Ool04goo000AOol30002Ool00`00Ool0
0009Ool01000Ool000000Woo00<007ooOol047oo0`00159i0`000cfE00H003Ee000005kJ0004DQH0
1P00DQH00000Ghl0009oo`03001oogoo008002=oo`03001g_GNm00Ig_@PaS0P000LHaPQW>@Qoo`Q>
L`P8@P03Ool007oo01=oo`004Goo00<007ooOol00Woo00@007oo001oo`<000=oo`80009oo`03001o
ogoo009oo`03001oogoo00eoo`<00003Ko/0059i00<00003DWT003fE00<mU@04000eMCEe=GD30003
DQH01000DQH000000Un?00H007ooOol007oo000TOol00`00Mkeg_@06Mkd8<H`800076<H8IcT8Ool8
CW<824800goo001oo`0COol0011oo`03001oo`0000=oo`05001oo`00Ool00004Ool30002Ool00`00
Oomoo`03Ool2000:Ool40002Ko/30004DWT00`00?IDmU@02?ID00`00=GDeM@03=GD20003DQH00`00
DQH00002Ghl01000Oomoo`000Woo0P008Woo00<007NmMkd01WNm236<20001aS626Li27oo24ic20Q2
00=oo`00Ool04goo000;Ool30002Ool00`00Ool00004Ool01@00Oomoogoo000017oo0`0000=oo`00
Ool01Woo00<007ooOol017oo2@000Vok00<0059iDWT00U9i00<003fE?ID00SfE00<003Ee=GD013Ee
1`000Un?00D007ooOomoo`00025oo`<00003Ool007Nm00Mg_@PaS0P000LHaPQW>@Qoo`Q>L`P8@P03
Ool007oo01=oo`0047oo00<007oo000027oo00@007ooOomoo`80009oo`8000Qoo`03001oogoo00<0
00=CG`L00003Ko/0059i00=BN@03000mUCfE00<mU@03000eMCEe00DeM@03001BF59H0080009OS`03
001oogoo00<000Aoo`03001oogoo01Yoo`04001oogoo0008Mkd8<H`800076<H8IcT8Ool8CW<82480
0goo001oo`0COol0011oo`03001oo`0000Moo`03001oo`00009oo`04001oo`00Ool20008Ool30003
Del40002MmT01000MkT003Xk0`00159i00<003fE?ID00SfE00<003Ee=GD013Ee00@0059HDUQBF0<0
009OS`05001oo`00Ool00003Ool00`00Ool0000IOol400000goo001g_@07Mkd8<H`800076<H8IcT8
Ool8CW<824800goo001oo`0COol0015oo`03001oogoo00Moo`04001oogooOol300000goo00000005
Ool30002D]`400000e=O00000002MmT01000MkUg^@000cXk0P000e9i00<003fE?ID00SfE00<003Ee
=GD00cEe00<0059HDUP00U9H00<002de00000Un?100000Moo`00Oomoo`00Ool0000IOol00`00Ool0
0002Ool00`00Kg]_N`06Kg/@48@?Kg/@48@8Kg/00goo001oo`0COol001moo`05001oo`00Ool00003
Ool30003D]`500000e=O00000002MmT00`00MkUg^@02MkT01P00>S/j>`009AD0009BN@03000mUCfE
00<mU@03000eMCEe008eM@03001BF59H009BF005000]=Bde001OS`0200001007001oo`000goo00<0
07ooOol06Goo0P000Woo00<006mkKg/01Vmk41243fmk412426mk00=oo`00Ool04goo000@Ool00`00
Oomoo`02Ool01000Oomoogoo0`000goo00H007oo001oo`00Ool20002DY/40005D]`20003MmT00`00
MkUg^@02MkT02@00>S/j>cXk000U5@00DWT00005?ID01000=GDeMCEe0P001E9H00<002de00000`00
00<01`00Ool00P0000Aoo`00Ool001]oo`04001oogoo0008Kg/@48@?Kg/@48@8Kg/00goo001oo`0C
Ool000moo`03001oo`0000Moo`03001oogoo009oo`04001oo`00Ool30002DY/40005D]`200001F?M
001gfGOI00001GNi0P000SXk00H002DE9AD0059i0004?ID00`00=GDeM@030005DUP00`00;CD]=@03
00001@07000007oo00000Woo00<007ooOol07Goo00<006mkKg/01Vmk41243fmk412426mk00=oo`00
Ool04goo000?Ool00`00Ool00008Ool00`00Oomoo`03Ool00`00Ool000040003DY/00`00D]aBg002
D]`01000HmeSg@000WOI00<007NiMkT00WNi0P0000E?O`00000j>`0000<U5@8000@mU@03000eM@00
008af@8000ABF004000]=Bde;CD300001007001oo`008Woo00<006mkKg/01Vmk41243fmk412426mk
00=oo`00Ool04goo000?Ool00`00Ool00008Ool01000Oomoogoo0P000Woo0`001U:K00@005;L0000
00=Sg@P000A?O`03000j>`0000@U5@<000<mU@8000<af@8000=BF00;000]=Bde;CD0035E00001`00
Ool0000ROol00`00Kg]_N`06Kg/@48@?Kg/@48@8Kg/00goo001oo`0COol000moo`03001oo`0000=o
o`04001oogooOol30002Ool20003Ool00`00Ool00006DY/80003LcP00`00McIg=P020002Cgl20000
0cXk000U5@039AD00`00<Ud000040004<MT20003DUP00`00;CD]=@0200000c5E00000002Ool00`00
Oomoo`0OOol00`00Kg]_N`06Kg/@48@?Kg/@48@8Kg/00goo001oo`0COol0011oo`07001oogooOol0
07oo00000goo00@007ooOomoo`<000=oo`03001oo`0000=BV`8000AO?@04001[>V/j0003LcP01000
McIg=WLf0P0000E?O`00000j>`0000@U5@04000bGC9M0002If`00`00<MTaf@02<MT00`00:EH00002
DUP01`00;CD00000<ED0035E00800003Ool007oo021oo`03001W>FLi00IW>@P000Q>L`Mg_@P8@PPa
S0Qoo`PHaP03Ool007oo01=oo`0057oo00<007oo00002Goo00<007ooOol00Woo0P0000=BV`000000
1Elm00@006/jJcX000=c>005001g=WLfMcH00002McH00`00Cgl0000200059AD20002If`30003<MT0
2@00:EHYEP00DUP002de00000`020002<ED3000QOol00`00IcUW>@06IcT80008CW<7Mkd82488<H`8
Ool86<H00goo001oo`0COol001Aoo`03001oo`0000Moo`8000Moo`03001O?Elm00=O?@8000=[>P05
001c>7<hLcP00003McH02000McIg=P00Cgl0001d00059AD80002<MT01000:EHYERUF0P0000H]=@00
00<0035E0002<ED2000QOol00`00IcUW>@06IcT80008CW<7Mkd82488<H`8Ool86<H00goo001oo`0C
Ool001Aoo`03001oo`0000Moo`03001oogoo00Moo`80009O?@03001[>V/j009[>P05001c>7<hLcP0
0003McH01000McIg=WLf0`0000@0M000000U5@H00006Ool00000000Y=@000S7I00<002UF:EH01000
00@00`00<EDaE@800003Ool007oo021oo`03001W>FLi00IW>@P000Q>L`Mg_@P8@PPaS0Qoo`PHaP03
Ool007oo01=oo`005Goo00<007ooOol01Woo0`0027oo0`001F/j00D007<hLcQc>00000=g=P06001g
=WLfMcH007Lg0P0000<0M00000000e;L00@007Lf001oo`@00006:CD0037I000YEP000Woo00@007oo
0000008aE@800003Ool007oo021oo`03001W>FLi00IW>@P000Q>L`Mg_@P8@PPaS0Qoo`PHaP03Ool0
07oo01=oo`00:Woo00<007oo00000f/j00D007<hLcQc>00000=g=P05001g=WLfMcH00002McL20002
07@00`00D]aBg002000017Lf001oogoo0`0000HY=@00<MT002UF0004Ool0200000<00000Ool007oo
000LOol20003Ool00`00IcUW>@06IcT80008CW<7Mkd82488<H`8Ool86<H00goo001oo`0COol002]o
o`@00003JcX007<h009c>005001g=WLfMcH00003McH01000McMg=gLg10000U;L00<007Lf00000goo
0`000RTe0P0000<YEP00Ool017oo0`000Woo00<007oo00006goo00<007oo00000Woo00<006LiIcT0
1VLi200024ic1gNm20Q2236<27oo21S600=oo`00Ool04goo000]Ool00`00Ool00003LcP01@00McIg
=WLf00000gLf00<007LgMcL00WLg0P0000<a^00000000P0000=g=P00Ool00goo0P000bTe0P001goo
00<007ooOol00Woo0P006goo00<007oo00000Woo00<006LiIcT01VLi200024ic1gNm20Q2236<27oo
21S600=oo`00Ool04goo000^Ool01P00Ool00000LcP000=g=P05001g=WLfMcH00004McL20003<KP0
0`00McH00005Ool30002:CD2000<Ool2000KOol20003Ool00`00F]IJeP06F]H80008Ool?9BT8Ool8
0008F]H00goo001oo`0COol002moo`03001oogoo0080009g=P05001g=WLfMcH00004McL00`00Ool0
0003<KP00`00McH00006Ool200000bTe001oo`0=Ool2000KOol00`00Oomoo`02Ool00`00F]IJeP06
F]H80008Ool?9BT8Ool80008F]H00goo001oo`0COol0031oo`04001oogooOol30003McH01@00McMg
=gLg00000goo00<0036h00000WLf00<007ooOol017oo0P0000<Y=@00Ool02Goo10007Woo0P000Woo
00<005[FF]H01U[F200027oo3bDY27oo200025[F00=oo`00Ool04goo000aOol20004Ool30004McL0
2@00Oomoogoo000a^000McH00008Ool00`00:CD00006Ool4000VOol00`00F]IJeP06F]H80008Ool?
9BT8Ool80008F]H00goo001oo`0COol003=oo`03001oogoo00=oo`80009g=`03001oogoo00=oo`04
001g=WLf0008Ool20003Ool4000ZOol00`00F]IJeP06F]H80008Ool?9BT8Ool80008F]H00goo001o
o`0COol003Aoo`03001oogoo00Aoo`8000Ioo`04001g=WLf0009Ool4000^Ool00`00F]IJeP06F]H8
0008Ool?9BT8Ool80008F]H00goo001oo`0COol003Eoo`03001oogoo00=oo`03001oogoo00Ioo`80
00Moo`<0039oo`03001JeU[F00IJePP000Qoo`lU:@Qoo`P000QJeP03Ool007oo01=oo`00=Woo00<0
07ooOol00Woo00<007ooOol01goo00@007ooOomoo`@003Eoo`03001JeU[F00IJePP000Qoo`lU:@Qo
o`P000QJeP03Ool007oo01=oo`00=goo0P000Woo00<007ooOol01goo1000>Goo00<004icCW<01Tic
21S627Nm1`0027oo20Q226Li236<00=oo`00Ool04goo000iOol00`00Ool00005Ool4000mOol00`00
CW=>L`06CW<86<H8Mkd70008Ool82488IcT8<H`00goo001oo`0COol003Yoo`800003Ool000000080
045oo`03001>Ldic00I>L`PHaPQg_@L000Qoo`P8@PQW>@PaS003Ool007oo01=oo`00>goo0P00AGoo
00<004icCW<01Tic21S627Nm1`0027oo20Q226Li236<00=oo`00Ool04goo0022Ool00`00CW=>L`06
CW<86<H8Mkd70008Ool82488IcT8<H`00goo001oo`0COol007ioo`05001oogooOol00008CW<86<H8
Mkd70008Ool82488IcT8<H`00goo001oo`0COol007eoo`03001oo`00009oo`03001>Ldic00I>L`PH
aPQg_@L000Qoo`P8@PQW>@PaS003Ool007oo01=oo`00OGoo00<007oo00000Woo00<004icCW<01Tic
21S627Nm1`0027oo20Q226Li236<00=oo`00Ool04goo001nOol01000Oomoogoo@P0057oo001mOol0
0`00Ool0001HOol007ioo`03001oogoo05Moo`00f7oo003HOol00=Qoo`00\
\>"],
  ImageRangeCache->{{{0, 215}, {82.375, 0}} -> {-0.0585623, -0.0193168, 
  0.0098471, 0.0098471}, {{5.9375, 102.625}, {80.375, 
  1.9375}} -> {-0.529864, -0.247432, 0.015164, 0.015164}, {{112.313, 209}, {
  80.375, 1.9375}} -> {-16.7684, -1.66393, 0.127263, 0.127263}}]
}, Open  ]],

Cell[TextData[
"Here we test the unitarity and orthogonality of the cosine kernel matrix \
\[ScriptCapitalC]. "], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\({Chop[\[ScriptCapitalC] . Transpose[Conjugate[\[ScriptCapitalC]]]] == 
        IdentityMatrix[8],  (*\ unitary\ *) \n
      Chop[\[ScriptCapitalC] . Transpose[\[ScriptCapitalC]]] == 
        IdentityMatrix[8]}\ \ \ \ \ \ \ \ \  (*\ orthogonal\ *) \)\)], "Input",\

  CellLabel->"In[37]:="],

Cell[BoxData[
    \({True, True}\)], "Output",
  CellLabel->"Out[37]="]
}, Open  ]],

Cell[TextData[{
  "Given an ",
  Cell[BoxData[
      \(TraditionalForm\`N\)]],
  " by ",
  Cell[BoxData[
      \(TraditionalForm\`N\)]],
  " cosine matrix and an  ",
  Cell[BoxData[
      \(TraditionalForm\`N\)]],
  "-point vector ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  ",  the ",
  Cell[BoxData[
      \(TraditionalForm\`N\)]],
  "-point forward and inverse DCTs (1) and (2) can be computed using matrix \
multiplication."
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(X\_C\ \  = \ \ \[ScriptCapitalC]\  . \ x\ \)\)]],
  "\t\t\t\t(* analysis *)"
}], "NumberedEquation"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(x\ \  = \ \ \[ScriptCapitalC]\  . \ X\_C\ \)\)]],
  "\t\t\t\t(* synthesis *)"
}], "NumberedEquation"],

Cell[TextData[{
  "where ",
  StyleBox["x",
    FontSlant->"Italic"],
  " is the time-domain sequence (i.e. the signal), ",
  Cell[BoxData[
      \(TraditionalForm\`X\_C\)]],
  " a vector of DCT coefficients and \[ScriptCapitalC] is the cosine kernel \
matrix. Rows and columns of the matrix \[ScriptCapitalC] are sampled discrete \
cosines. As a simple example, consider calculating the DCT of the signal \
defined in (9) using the matrix formulation in (13)."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[ScriptCapitalC] . ZeroPad[{1, 1, 1}, {0, 5}]\)], "Input",
  CellLabel->"In[38]:="],

Cell[BoxData[
    \({1.06066017177982119`, 1.18391256286268898`, 0.461939766255643391`, 
      \(-0.172202995058406704`\), \(-0.35355339059327373`\), 
      \(-0.115062362683749919`\), 0.191341716182544772`, 
      0.235494850649535791`}\)], "Output",
  CellLabel->"Out[38]="]
}, Open  ]],

Cell["\<\
The 2D DCT may be computed using a sequence of row and column 1D \
transformations (the transform is separable). Thus the analysis and synthesis \
equations may be compactly written as\
\>", "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm
      \`X\_C\  = \ \[ScriptCapitalC] . \ x . \ \[ScriptCapitalC]\^T\)]],
  "\t\t\t(* analysis *)"
}], "NumberedEquation"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm
      \`\(x\  = \ \[ScriptCapitalC] . \ X . \ \[ScriptCapitalC]\^T\ \)\)]],
  "\t\t\t(* synthesis *)"
}], "NumberedEquation"]
}, Open  ]],

Cell[CellGroupData[{

Cell["EXAMPLES", "Section"],

Cell[TextData[{
  "In this final section we will show examples of computing the 2D DCT of a \
\"box\" sequence and later of a real image. We first consider the direct \
approach of using (10) to compute the DCT of a unit pulse signal ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " defined as"
}], "Text"],

Cell[TextData[{
  "\t",
  Cell[BoxData[
      FormBox[
        RowBox[{\(x[n\_1, \ n\_2]\), " ", "=", " ", 
          RowBox[{"{", GridBox[{
                {"1", \(for\ \ \ \ \ \ 0 \[LessEqual] n\_1, 
                  n\_2 \[LessEqual] 2\ \)},
                {"0", "otherwise"}
                }]}]}], TraditionalForm]]]
}], "Text"],

Cell["\<\
For this particular example we use an 8-point DCT. (10) reduces to the  \
following expression:\
\>", "Text"],

Cell[BoxData[
    \(X\_C[k_, l_] := 
      \(X\_C[k, \ l] = 
        \[Alpha][k]\ \[Alpha][l] 
          \(\[Sum]\+\(n\_1 = 0\)\%2\(\[Sum]\+\(n\_2 = 0\)\%2\ 
              Cos[\(\[Pi]\/16\) \((2  n\_1 + 1)\) k] 
                Cos[\(\[Pi]\/16\) \((2  n\_2 + 1)\) l]\)\)\)\)], "Input",
  CellLabel->"In[4]:="],

Cell["The algebraic form of the 2D DCT is", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(X\_C[k, \ l]\)], "Input",
  CellLabel->"In[5]:="],

Cell[BoxData[
    \(\((Cos[\(k\ \[Pi]\)\/16]\ Cos[\(l\ \[Pi]\)\/16] + 
          Cos[\(3\ k\ \[Pi]\)\/16]\ Cos[\(l\ \[Pi]\)\/16] + 
          Cos[\(5\ k\ \[Pi]\)\/16]\ Cos[\(l\ \[Pi]\)\/16] + 
          Cos[\(k\ \[Pi]\)\/16]\ Cos[\(3\ l\ \[Pi]\)\/16] + 
          Cos[\(3\ k\ \[Pi]\)\/16]\ Cos[\(3\ l\ \[Pi]\)\/16] + 
          Cos[\(5\ k\ \[Pi]\)\/16]\ Cos[\(3\ l\ \[Pi]\)\/16] + 
          Cos[\(k\ \[Pi]\)\/16]\ Cos[\(5\ l\ \[Pi]\)\/16] + 
          Cos[\(3\ k\ \[Pi]\)\/16]\ Cos[\(5\ l\ \[Pi]\)\/16] + 
          Cos[\(5\ k\ \[Pi]\)\/16]\ Cos[\(5\ l\ \[Pi]\)\/16])\)\ \[Alpha][k]\ 
      \[Alpha][l]\)], "Output",
  CellLabel->"Out[5]="]
}, Open  ]],

Cell[TextData[{
  "We now evaluate ",
  Cell[BoxData[
      \(TraditionalForm\`X\_C[k, l]\)]],
  " over all values of the frequency variables ",
  Cell[BoxData[
      \(TraditionalForm\`k\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`l\)]],
  ". This gives the 2D DCT of the unit pulse. "
}], "Text"],

Cell[BoxData[
    \(\(Table[X\_C[k, l], {k, 0, 7}, {l, 0, 7}]; \)\)], "Input",
  CellLabel->"In[8]:="],

Cell[TextData[{
  "Here we plot ",
  Cell[BoxData[
      \(TraditionalForm\`X\_C[k, l]\)]],
  ". Note particularly, the concentration of large DCT coefficients in a \
single low-frequency zone. The DCT is known to have excellent energy \
compaction properties."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[
      GraphicsArray[{
          ListPlot3D[%, PlotRange \[Rule] All, 
            DisplayFunction \[Rule] Identity], \ 
          ListDensityPlot[%, Mesh -> False, \ PlotRange \[Rule] All, 
            DisplayFunction \[Rule] Identity]}]]; \)\)], "Input",
  CellLabel->"In[9]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .38626 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.00919655 0.47619 [
[ 0 0 0 0 ]
[ 1 .38626 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .38626 L
0 .38626 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.00919655 0.477324 0.377059 MathSubStart
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1.04977 -0.0679587 1.04977 [
[.11158 .21312 -6 -8.95035 ]
[.11158 .21312 0 .04965 ]
[.28836 .14356 -5.67606 -9 ]
[.28836 .14356 .32394 0 ]
[.47788 .06904 -5.31864 -9 ]
[.47788 .06904 .68136 0 ]
[.68156 -0.01098 -4.96123 -9 ]
[.68156 -0.01098 1.03877 0 ]
[.74908 .0689 0 -6.18931 ]
[.74908 .0689 6 2.81069 ]
[.83635 .20254 0 -6.06047 ]
[.83635 .20254 6 2.93953 ]
[.9134 .32052 0 -5.94988 ]
[.9134 .32052 6 3.05012 ]
[.98191 .42546 0 -5.85393 ]
[.98191 .42546 6 3.14607 ]
[.01637 .31365 -6 -2.78335 ]
[.01637 .31365 0 6.21665 ]
[.00679 .37367 -18 -2.83427 ]
[.00679 .37367 0 6.16573 ]
[-0.00316 .43605 -6 -2.88739 ]
[-0.00316 .43605 0 6.11261 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.03716 .25514 m
.68874 0 L
s
.12091 .22234 m
.12558 .22696 L
s
[(2)] .11158 .21312 1 .98897 Mshowa
.2971 .15335 m
.30147 .15825 L
s
[(4)] .28836 .14356 .89202 1 Mshowa
.4859 .07942 m
.48992 .08461 L
s
[(6)] .47788 .06904 .77288 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(8)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.16384 .20553 m
.1666 .20834 L
s
.20751 .18843 m
.21022 .19129 L
s
.25192 .17104 m
.25459 .17394 L
s
.34306 .13535 m
.34564 .13834 L
s
.38984 .11704 m
.39236 .12006 L
s
.43745 .0984 m
.43991 .10147 L
s
.53524 .06011 m
.53759 .06327 L
s
.58547 .04044 m
.58776 .04364 L
s
.63663 .0204 m
.63885 .02365 L
s
.07869 .23888 m
.08153 .2416 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.7368 .07352 m
.73065 .07582 L
s
[(2)] .74908 .0689 -1 .3754 Mshowa
.82395 .20683 m
.81775 .20898 L
s
[(4)] .83635 .20254 -1 .34677 Mshowa
.90091 .32455 m
.89466 .32656 L
s
[(6)] .9134 .32052 -1 .3222 Mshowa
.96935 .42924 m
.96306 .43113 L
s
[(8)] .98191 .42546 -1 .30087 Mshowa
.125 Mabswid
.75965 .10848 m
.75596 .10983 L
s
.78177 .14231 m
.77807 .14365 L
s
.8032 .17508 m
.79948 .1764 L
s
.84407 .23761 m
.84035 .23888 L
s
.86359 .26746 m
.85986 .26871 L
s
.88252 .29643 m
.87878 .29766 L
s
.91876 .35185 m
.915 .35304 L
s
.9361 .37838 m
.93234 .37955 L
s
.95296 .40417 m
.94919 .40532 L
s
.71317 .03738 m
.7095 .03879 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.02863 .30897 m
.03476 .30663 L
s
[(0)] .01637 .31365 1 -0.38148 Mshowa
.0191 .36912 m
.02525 .36684 L
s
[(0.5)] .00679 .37367 1 -0.37016 Mshowa
.00919 .43162 m
.01537 .42941 L
s
[(1)] -0.00316 .43605 1 -0.35836 Mshowa
.125 Mabswid
.02675 .32082 m
.03043 .31942 L
s
.02486 .33276 m
.02854 .33137 L
s
.02295 .34478 m
.02664 .3434 L
s
.02103 .3569 m
.02472 .35553 L
s
.01715 .38143 m
.02084 .38007 L
s
.01518 .39383 m
.01888 .39248 L
s
.0132 .40633 m
.0169 .40498 L
s
.0112 .41893 m
.01491 .41759 L
s
.03049 .29721 m
.03417 .2958 L
s
.03234 .28554 m
.03601 .28412 L
s
.03418 .27396 m
.03785 .27253 L
s
.036 .26246 m
.03967 .26103 L
s
.00716 .44442 m
.01087 .4431 L
s
.00512 .45731 m
.00883 .456 L
s
.00306 .47031 m
.00678 .46901 L
s
.00098 .48341 m
.0047 .48212 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.5 Mabswid
.647 .722 .903 r
.35729 .62956 .40262 .67524 .47815 .65676 .43404 .60931 Metetra
.718 .738 .867 r
.43404 .60931 .47815 .65676 .55578 .61569 .51321 .57033 Metetra
.715 .751 .881 r
.51321 .57033 .55578 .61569 .63485 .57617 .59402 .53243 Metetra
.678 .755 .909 r
.59402 .53243 .63485 .57617 .7161 .5476 .67702 .50337 Metetra
.635 .744 .927 r
.67702 .50337 .7161 .5476 .80042 .52926 .76299 .48256 Metetra
.628 .736 .925 r
.76299 .48256 .80042 .52926 .88778 .5121 .85203 .46252 Metetra
.656 .74 .912 r
.85203 .46252 .88778 .5121 .97728 .48729 .9435 .43598 Metetra
.654 .626 .81 r
.31162 .55077 .35729 .62956 .43404 .60931 .38908 .5248 Metetra
.618 .601 .811 r
.38908 .5248 .43404 .60931 .51321 .57033 .46858 .50892 Metetra
.625 .671 .875 r
.46858 .50892 .51321 .57033 .59402 .53243 .55093 .49132 Metetra
.646 .769 .938 r
.55093 .49132 .59402 .53243 .67702 .50337 .63605 .46714 Metetra
.67 .808 .949 r
.63605 .46714 .67702 .50337 .76299 .48256 .72361 .43661 Metetra
.678 .77 .92 r
.72361 .43661 .76299 .48256 .85203 .46252 .8137 .40427 Metetra
.663 .719 .891 r
.8137 .40427 .85203 .46252 .9435 .43598 .90687 .37447 Metetra
.669 .651 .824 r
.26383 .47726 .31162 .55077 .38908 .5248 .34225 .4465 Metetra
.534 .583 .85 r
.34225 .4465 .38908 .5248 .46858 .50892 .42176 .44817 Metetra
.531 .645 .907 r
.42176 .44817 .46858 .50892 .55093 .49132 .50521 .44635 Metetra
.619 .754 .942 r
.50521 .44635 .55093 .49132 .63605 .46714 .59228 .4257 Metetra
.703 .803 .927 r
.59228 .4257 .63605 .46714 .72361 .43661 .68174 .3869 Metetra
.712 .777 .903 r
.68174 .3869 .72361 .43661 .8137 .40427 .77334 .34427 Metetra
.668 .727 .894 r
.77334 .34427 .8137 .40427 .90687 .37447 .86841 .3114 Metetra
.663 .842 .969 r
.20947 .45015 .26383 .47726 .34225 .4465 .28971 .42045 Metetra
.516 .812 .999 r
.28971 .42045 .34225 .4465 .42176 .44817 .37155 .40646 Metetra
.581 .762 .965 r
.37155 .40646 .42176 .44817 .50521 .44635 .45681 .39014 Metetra
.643 .726 .909 r
.45681 .39014 .50521 .44635 .59228 .4257 .54548 .36397 Metetra
.678 .725 .885 r
.54548 .36397 .59228 .4257 .68174 .3869 .63701 .32834 Metetra
.685 .746 .897 r
.63701 .32834 .68174 .3869 .77334 .34427 .73124 .29023 Metetra
.664 .763 .924 r
.73124 .29023 .77334 .34427 .86841 .3114 .82884 .25633 Metetra
.14472 .47737 .20947 .45015 .28971 .42045 .22749 .45587 Metetra
.59 .926 .716 r
.22749 .45587 .28971 .42045 .37155 .40646 .31643 .3866 Metetra
.802 .908 .914 r
.31643 .3866 .37155 .40646 .45681 .39014 .40591 .3215 Metetra
.692 .711 .863 r
.40591 .3215 .45681 .39014 .54548 .36397 .49618 .2799 Metetra
.604 .636 .856 r
.49618 .2799 .54548 .36397 .63701 .32834 .5894 .25998 Metetra
.585 .682 .908 r
.5894 .25998 .63701 .32834 .73124 .29023 .68688 .24298 Metetra
.643 .8 .959 r
.68688 .24298 .73124 .29023 .82884 .25633 .78767 .21037 Metetra
.203 0 0 r
.07098 .51957 .14472 .47737 .22749 .45587 .15616 .50916 Metetra
.883 .985 .71 r
.15616 .50916 .22749 .45587 .31643 .3866 .25616 .37002 Metetra
.906 .884 .8 r
.25616 .37002 .31643 .3866 .40591 .3215 .35235 .24736 Metetra
.735 .719 .836 r
.35235 .24736 .40591 .3215 .49618 .2799 .44471 .18838 Metetra
.516 .583 .86 r
.44471 .18838 .49618 .2799 .5894 .25998 .53897 .18639 Metetra
.434 .603 .917 r
.53897 .18639 .5894 .25998 .68688 .24298 .63919 .19417 Metetra
.619 .8 .969 r
.63919 .19417 .68688 .24298 .78767 .21037 .74337 .16328 Metetra
.561 .672 .913 r
.00666 .44763 .07098 .51957 .15616 .50916 .09293 .43322 Metetra
.837 .735 .752 r
.09293 .43322 .15616 .50916 .25616 .37002 .19547 .30263 Metetra
.839 .759 .775 r
.19547 .30263 .25616 .37002 .35235 .24736 .29457 .18635 Metetra
.745 .774 .876 r
.29457 .18635 .35235 .24736 .44471 .18838 .38936 .12746 Metetra
.491 .69 .956 r
.38936 .12746 .44471 .18838 .53897 .18639 .48536 .12004 Metetra
.437 .649 .948 r
.48536 .12004 .53897 .18639 .63919 .19417 .58718 .12113 Metetra
.633 .728 .916 r
.58718 .12113 .63919 .19417 .74337 .16328 .69378 .08694 Metetra
0 g
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.12091 .22234 m
.12558 .22696 L
s
[(2)] .11158 .21312 1 .98897 Mshowa
.2971 .15335 m
.30147 .15825 L
s
[(4)] .28836 .14356 .89202 1 Mshowa
.4859 .07942 m
.48992 .08461 L
s
[(6)] .47788 .06904 .77288 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(8)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.16384 .20553 m
.1666 .20834 L
s
.20751 .18843 m
.21022 .19129 L
s
.25192 .17104 m
.25459 .17394 L
s
.34306 .13535 m
.34564 .13834 L
s
.38984 .11704 m
.39236 .12006 L
s
.43745 .0984 m
.43991 .10147 L
s
.53524 .06011 m
.53759 .06327 L
s
.58547 .04044 m
.58776 .04364 L
s
.63663 .0204 m
.63885 .02365 L
s
.07869 .23888 m
.08153 .2416 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.00919655 0.97619 0.377059 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.120192 0.0192308 0.120192 [
[.01923 -0.0125 -3 -9 ]
[.01923 -0.0125 3 0 ]
[.25962 -0.0125 -3 -9 ]
[.25962 -0.0125 3 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.74038 -0.0125 -3 -9 ]
[.74038 -0.0125 3 0 ]
[.98077 -0.0125 -3 -9 ]
[.98077 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01923 -6 -4.5 ]
[-0.0125 .01923 0 4.5 ]
[-0.0125 .25962 -6 -4.5 ]
[-0.0125 .25962 0 4.5 ]
[-0.0125 .5 -6 -4.5 ]
[-0.0125 .5 0 4.5 ]
[-0.0125 .74038 -6 -4.5 ]
[-0.0125 .74038 0 4.5 ]
[-0.0125 .98077 -6 -4.5 ]
[-0.0125 .98077 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.01923 0 m
.01923 .00625 L
s
[(0)] .01923 -0.0125 0 1 Mshowa
.25962 0 m
.25962 .00625 L
s
[(2)] .25962 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(4)] .5 -0.0125 0 1 Mshowa
.74038 0 m
.74038 .00625 L
s
[(6)] .74038 -0.0125 0 1 Mshowa
.98077 0 m
.98077 .00625 L
s
[(8)] .98077 -0.0125 0 1 Mshowa
.125 Mabswid
.07933 0 m
.07933 .00375 L
s
.13942 0 m
.13942 .00375 L
s
.19952 0 m
.19952 .00375 L
s
.31971 0 m
.31971 .00375 L
s
.37981 0 m
.37981 .00375 L
s
.4399 0 m
.4399 .00375 L
s
.5601 0 m
.5601 .00375 L
s
.62019 0 m
.62019 .00375 L
s
.68029 0 m
.68029 .00375 L
s
.80048 0 m
.80048 .00375 L
s
.86058 0 m
.86058 .00375 L
s
.92067 0 m
.92067 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01923 m
.00625 .01923 L
s
[(0)] -0.0125 .01923 1 0 Mshowa
0 .25962 m
.00625 .25962 L
s
[(2)] -0.0125 .25962 1 0 Mshowa
0 .5 m
.00625 .5 L
s
[(4)] -0.0125 .5 1 0 Mshowa
0 .74038 m
.00625 .74038 L
s
[(6)] -0.0125 .74038 1 0 Mshowa
0 .98077 m
.00625 .98077 L
s
[(8)] -0.0125 .98077 1 0 Mshowa
.125 Mabswid
0 .07933 m
.00375 .07933 L
s
0 .13942 m
.00375 .13942 L
s
0 .19952 m
.00375 .19952 L
s
0 .31971 m
.00375 .31971 L
s
0 .37981 m
.00375 .37981 L
s
0 .4399 m
.00375 .4399 L
s
0 .5601 m
.00375 .5601 L
s
0 .62019 m
.00375 .62019 L
s
0 .68029 m
.00375 .68029 L
s
0 .80048 m
.00375 .80048 L
s
0 .86058 m
.00375 .86058 L
s
0 .92067 m
.00375 .92067 L
s
.25 Mabswid
0 0 m
0 1 L
s
.01923 .99375 m
.01923 1 L
s
.25962 .99375 m
.25962 1 L
s
.5 .99375 m
.5 1 L
s
.74038 .99375 m
.74038 1 L
s
.98077 .99375 m
.98077 1 L
s
.125 Mabswid
.07933 .99625 m
.07933 1 L
s
.13942 .99625 m
.13942 1 L
s
.19952 .99625 m
.19952 1 L
s
.31971 .99625 m
.31971 1 L
s
.37981 .99625 m
.37981 1 L
s
.4399 .99625 m
.4399 1 L
s
.5601 .99625 m
.5601 1 L
s
.62019 .99625 m
.62019 1 L
s
.68029 .99625 m
.68029 1 L
s
.80048 .99625 m
.80048 1 L
s
.86058 .99625 m
.86058 1 L
s
.92067 .99625 m
.92067 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .01923 m
1 .01923 L
s
.99375 .25962 m
1 .25962 L
s
.99375 .5 m
1 .5 L
s
.99375 .74038 m
1 .74038 L
s
.99375 .98077 m
1 .98077 L
s
.125 Mabswid
.99625 .07933 m
1 .07933 L
s
.99625 .13942 m
1 .13942 L
s
.99625 .19952 m
1 .19952 L
s
.99625 .31971 m
1 .31971 L
s
.99625 .37981 m
1 .37981 L
s
.99625 .4399 m
1 .4399 L
s
.99625 .5601 m
1 .5601 L
s
.99625 .62019 m
1 .62019 L
s
.99625 .68029 m
1 .68029 L
s
.99625 .80048 m
1 .80048 L
s
.99625 .86058 m
1 .86058 L
s
.99625 .92067 m
1 .92067 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
D9EB7F210629575D
EBFF871E00275A62
7F87582F2333474A
211E2F3F433D3635
060023434C40312F
2927333D403C3737
575A473631374041
5D624A352F374142
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[9]:=",
  ImageSize->{288, 111.188},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000Ka000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo002/Ool00`00Oomoo`0BOol3000EOol3000BOol2000EOol00`00Oomo
o`0HOol00:]oo`03001oo`0001=oo`03001oogoo01Ioo`03001oogoo015oo`03001oo`0001=oo`03
001oo`0001Uoo`00Zgoo00<007oo000057oo00<007ooOol04goo10004Woo00<007oo00004goo00<0
07oo00006Goo001POol00`00Oomoo`18Ool00`00Ool0000DOol00`00Oomoo`0COol00`00Ool0000C
Ool2000EOol00`00Oomoo`0HOol005moo`03001oo`0004Uoo`03001oo`0001=oo`03001oo`0001Eo
o`8001=oo`03001oogoo01=oo`03001oo`0001Uoo`00Ggoo00<007oo0000BWoo00<007ooOol04goo
00<007ooOol05Goo00<007ooOol04Woo0P0057oo00<007ooOol067oo001POol00`00Oomoo`2mOol0
05moo`03001oo`000;ioo`00H7oo00<007ooOol0_Goo002WOol01000OomoogooG@0067oo002VOol0
0`00Ool00002Ool00`00Ool0000EOol00`00Oomoo`0COol00`00Oomoo`0COol00`00Oomoo`0COol0
0`00Ool0000HOol00:Ioo`03001oo`00009oo`8005Yoo`03001oogoo01Ioo`00BGoo0P00Fgoo00<0
07oo00000Woo00<007ooKg/02Vmk2gNm2cg_2a242`002aBU2bU:2be[0Woo00<007ooOol05Woo0019
Ool00`00Ool0000FOol20012Ool00`00Ool00002Ool00`00Oom_N`0:Kg/;Mkd;?Nl;48@;000;5:D;
:DX;;F/2Ool00`00Oomoo`0FOol004Uoo`03001oo`0001Aoo`800003Ool00000049oo`06001oogoo
Ool007oo2fmk2gNm2cg_2a242`002aBU2bU:2be[0Woo00<007ooOol05Woo0019Ool2000BOol30003
Ool20016Ool00`00Oom_N`0:Kg/;Mkd;?Nl;48@;000;5:D;:DX;;F/2Ool00`00Oomoo`0FOol004Uo
o`03001oogoo00ioo`<000Ioo`03001oo`0000Aoo`<003ioo`03001oofmk00Y_N`]g_@/mk`/@Q0/0
00/DY@/YBP/]J`9oo`03001oogoo01Ioo`00BWoo0P0037oo0P002Goo00@007oo000000=oo`03001o
ogoo03ioo`03001oofmk00Y_N`]g_@/mk`/@Q0/000/DY@/YBP/]J`9oo`03001oogoo01Ioo`00EGoo
0`002goo00@007ooOol000Aoo`03001oogoo03eoo`03001oofmk00Y_N`]g_@/mk`/@Q0/000/DY@/Y
BP/]J`9oo`03001oogoo01Ioo`00DWoo0`003Woo00D007ooOomoo`0000=oo`03001oogoo03eoo`03
001oofmk00Y_N`]g_@/mk`/@Q0/000/DY@/YBP/]J`9oo`03001oogoo01Ioo`00=Goo0`0067oo0`00
47oo00<007ooOol00Woo00D007oo001oo`0003ioo`03001oofmk00Y_N`]g_@/mk`/@Q0/000/DY@/Y
BP/]J`9oo`03001oogoo01Ioo`00=Woo00<007ooOol057oo0`004goo00@007ooOomoo`80009oo`03
001oogoo03eoo`03001oofmk00Y_N`]g_@/mk`/@Q0/000/DY@/YBP/]J`9oo`03001oogoo01Ioo`00
=7oo10004goo0`0057oo0P001Goo00<007ooOol0?goo00<007ooKg/02Vmk2gNm2cg_2a242`002aBU
2bU:2be[0Woo00<007ooOol05Woo000dOol00`00Ool0000AOol3000DOol300000e;m00000005Ool0
0`00Oomoo`0nOol00`00Oomg_@0:Mkd;Ool;@Q0;36<;000;48@;;F/;<H`2Ool00`00Oomoo`0FOol0
03Eoo`8000ioo`@001Aoo`8000ABo@8000Eoo`03001oogoo03ioo`03001oogNm00Yg_@]oo`]240/<
H`/000/@Q0/]J`/aS09oo`03001oogoo01Ioo`00=Woo00<007ooOol02Woo0P005Goo0`001U;m00<0
05;m000017oo0P00?goo00<007ooMkd02WNm2goo2d8@2`aS2`002a242be[2c6<0Woo00<007ooOol0
5Woo0010OolJ0009D_d01000D_eBo@0017oo00<007ooOol0?Goo00<007ooMkd02WNm2goo2d8@2`aS
2`002a242be[2c6<0Woo00<007ooOol05Woo000mOol500000elL000ngP09?]h00`00=YhfWP08=Yh0
0`00D_eBo@08D_d01000D_eBo@0017oo00<007ooOol0?7oo00<007ooMkd02WNm2goo2d8@2`aS2`00
2a242be[2c6<0Woo00<007ooOol05Woo000POol3000HOol200000goo00000004Ga`00`00?]hngP08
?]h00`00=YhfWP07=Yh00`00D_eBo@08D_d01000D_eBo@0017oo0P00?Goo00<007ooMkd02WNm2goo
2d8@2`aS2`002a242be[2c6<0Woo00<007ooOol05Woo000POol00`00Oomoo`0EOol30003Ool00`00
GaaO7004Ga`00`00?]hngP08?]h00`00=YhfWP07=Yh00`00D_eBo@07D_d01@00D_eBoE;m000017oo
00<007ooOol0>goo00<007ooMkd02WNm2goo2d8@2`aS2`002a242be[2c6<0Woo00<007ooOol05Woo
000QOol00`00Oomoo`0AOol3000017oo001oogoo0P001elL00<003kN?]h023kN00<003JN=Yh01cJN
00<005;mD_d01e;m00@005;mD_eBo@8000Aoo`03001oogoo00Aoo`<003=oo`03001oogNm00Yg_@]o
o`]240/<H`/000/@Q0/]J`/aS09oo`03001oogoo01Ioo`008Goo00<007ooOol03goo0P001Woo00<0
05lLGa`025lL00<003kN?]h023kN00<003JN=Yh01cJN00<005;mD_d01U;m10000Tlo00<007ooOol0
0Woo00<007ooOol017oo00<007ooOol0;Goo0`000Woo00<007ooMkd02WNm2goo2d8@2`aS2`002a24
2be[2c6<0Woo00<007ooOol05Woo000POol00`00Ool0000=Ool30006Ool2000<Ga`00`00?]hngP08
?]h00`00=YhfWP07=Yh00`00D_eBo@03D_d30006Ccl01@00Oomoogoo000017oo1000;Woo00<007oo
Ool00Woo00<007ooMkd02WNm2goo2d8@2`aS2`002a242be[2c6<0Woo00<007ooOol05Woo000QOol0
0`00Oomoo`0:Ool20008Ool00`00GaaO700=Ga`@0004=Yh00`00D_eBo@030002Ccl00`00Ccm??`05
Ccl01@00Oomoogoo00000goo00<007oo0000<7oo00@007ooOomoo`8000]g_@]oo`]240/<H`/000/@
Q0/]J`/aS09oo`03001oogoo01Ioo`00:goo0`002Goo00<006/H000035lL0P0000=NnP00@U/02D9K
00@003Im=WdfO@L000E??`03001??dlo00I??`05001oogooOol00003Ool2000`Ool01P00Oomoogoo
001oo`/mk`]240/]J`/DY@/@Q0/HaP/Q20/U:@9oo`03001oogoo01Ioo`00:7oo0`002goo00D006/H
JaQ[600000UO708000=NnP030012Fd9K00Q2F`03000fOCIm00LfO@03001??dlo00=??`03001??dlo
00I??`80009oo`03001oogoo009oo`03001oogoo02eoo`03001oo`00009oo`03001oocg_00Xmk`]2
40/]J`/DY@/@Q0/HaP/Q20/U:@9oo`03001oogoo01Ioo`009Woo0P003Goo00<006/HJaP00f/H00<0
05lLGa`01ElL00<005kjG_X015kj00<0049K@U/0249K00<003Im=Wd01cIm00<004loCcl00Tlo00<0
04loCcl00dlo0`000U<n00@007ooOol003Aoo`06001oogooOol007oo2cg_2d8@2be[2aBU2a242aS6
2b482bDY0Woo00<007ooOol05Woo000SOol4000>Ool00`00JaQ[6004JaP00`00GaaO7002Ga`20007
G_X00`00@U]2F`08@U/00`00=WdfO@08=Wd20002Ccl01000Ccm??dlo0P001U<n00@007ooOol003Mo
o`03001oocg_00Xmk`]240/]J`/DY@/@Q0/HaP/Q20/U:@9oo`03001oogoo01Ioo`0087oo0`004Goo
00<006/HJaP01V/H00@005lL000000YNnP030012Fd9K00Q2F`03000fOCIm00TfO@03001??`0000<0
00QC?P03001oogoo008003Ioo`03001oocg_00Xmk`]240/]J`/DY@/@Q0/HaP/Q20/U:@9oo`03001o
ogoo01Ioo`007Woo0P0000=oo`00Ool047oo00<006/HJaP026/H00<005kjG_X02ekj00<0049K@U/0
249K00<003Im=Wd01cIm100035<n00@007ooOol003Ioo`03001oocg_00Xmk`]240/]J`/DY@/@Q0/H
aP/Q20/U:@9oo`03001oogoo01Ioo`0077oo0P0057oo00<006/HJaP026/H00<007>I000035kj00<0
049K@U/0249K00@003Im=WdfO@P00003B[d0000000]C?P80009oo`03001oogoo03=oo`03001oocg_
00Xmk`]240/]J`/DY@/@Q0/HaP/Q20/U:@9oo`03001oogoo01Ioo`0077oo0P004goo00<006/HJaP0
2F/H00<007>I00003Ekj00<0049K@U/01T9K1@000TZm0`001DZm00<005<nDch01U<n0`000ULM00<0
07oo0000=Goo00<007oo?Nl02Sg_2d8@2be[2aBU2a242aS62b482bDY0Woo00<007ooOol05Woo000L
Ool00`00Ool0000AOol00`00JaQ[6009JaP01@00LiUcVG>I000035kj00@0049K@U]2F`D000=>V`04
001:_@000008B[d20005Dch20005Ead01000Ool00000=7oo00<007oo?Nl02Sg_2d8@2be[2aBU2a24
2aS62b482bDY0Woo00<007ooOol05Woo000LOol01000Oomoo`0047oo00<006/HJaP026/H00<007>I
LiT00g>I00<005kjG_X02Ekj10001djK0`002dZm0P0000AC?P00000000QG7@04001oogoo0004Ool2
000]Ool00`00Oolmk`0:?Nl;@Q0;;F/;5:D;48@;6<H;8@P;9BT2Ool00`00Oomoo`0FOol001]oo`80
00=oo`03001oogoo00aoo`03001[66/H00Q[6003001cVG>I00EcV@03001NnUkj00INnP80009Jf`03
001>VdjK00=>V`<0009>V`03001:_DZm00U:_@<000aG7@03001oo`0000Aoo`03001oo`0002aoo`03
001oocg_00Xmk`]240/]J`/DY@/@Q0/HaP/Q20/U:@9oo`03001oogoo01Ioo`006goo0P0017oo00<0
07ooOol02Woo00<006/HJaP02F/H00<007>ILiT01G>I00<005kjG_X00ekj0`0015[K00<004jKCY/0
0`001TjK00<004ZmB[d01TZm0P000UKl00<005LMEad02ULM00@007oo000000=oo`03001oo`0002ao
o`03001ooa2400X@Q0/<H`/DY@/Li`/Q20/LiaHHaP9oo`03001oogoo01Ioo`006goo0P001Goo0P00
2Goo00<006[h00002F/H00<007>ILiT01g>I00<005kjG_X00P001e[K0`002TjK00<004ZmB[d00TZm
0`001EKl00<005LMEad02ELM0P000Woo00<007ooOol00P00;Goo00<007oo48@02Q242`aS2aBU2acW
2b482acW5QS60Woo00<007ooOol05Woo000GOol01000Oomoogoo0P001goo00<007ooOol01Goo00@0
06[hJ_P000Q[6003001cVG>I00UcV@8000MJf`800003F]/004jK00Y>V`03001:_DZm008000QFo080
00QG7@80009Fo003001oo`00009oo`03001oogoo02aoo`03001ooa2400X@Q0/<H`/DY@/Li`/Q20/L
iaHHaP9oo`03001oogoo01Ioo`005Woo00<007oo00000Woo00<007ooOol01goo00<007ooOol00goo
00<006[hJ_P00V[h00<006/HJaP01F/H00<007>ILiT027>I00<006Nm000015[K0`0015[K00<004jK
CY/024jK0`002eKl0P0015LM0`0015Kl00@007oo0000009oo`8002aoo`03001ooa2400X@Q0/<H`/D
Y@/Li`/Q20/LiaHHaP9oo`03001oogoo01Ioo`005Woo00<007oo00000Woo00<007ooOol027oo00<0
07ooOol00Woo00<006[hJ_P00f[h00<006/HJaP00f/H00<007>ILiT01g>I0P000VNm00<005[K0000
0P001e[K00<004jKCY/01TjK0P000UKl00<005KlE_`02UKl00<005LMEad00P0025Kl00<007oo0000
<7oo00<007oo48@02Q242`aS2aBU2acW2b482acW5QS60Woo00<007ooOol05Woo000FOol01000Ool0
07oo0P002goo00@007ooOol000MZn005001[66/HJaP00009LiT01000IkeW_FNm0`002e[K00<004jK
CY/00TjK0`001EKl00<005KlE_`02EKl0`002UKl00@007ooOol002moo`03001ooa2400X@Q0/<H`/D
Y@/Li`/Q20/LiaHHaP9oo`03001oogoo01Ioo`005Woo00@007oo001oo`8000aoo`8000QZn004001[
66/H0009LiT00`00Ikd000020003Ikd00`00F]]Jf`08F]/00`00CY]>V`020008E_`00`00E_aFo007
E_`20002Fa`00`00E_aFo009E_`01000Ool00000;Woo00<007oo48@02Q242`aS2aBU2acW2b482acW
5QS60Woo00<007ooOol05Woo000GOol00`00Oomoo`02000<Ool00`00J_QZn008J_P00`00JaP00007
LiT40007Ikd00`00F]]Jf`07F]/3000;E_`00`00E_aFo003E_`30004Fa`00`00E_aFo009E_`01000
Oomoo`00;Woo00<007oo48@02Q242`aS2aBU2acW2b482acW5QS60Woo00<007ooOol05Woo000<Ool0
0`00Oomoo`02Ool00`00Oomoo`02Ool01@00Oomoogoo000037oo00<006[hJ_P02V[h100017>I0`00
2FNm00<005[KF]/015[K0`000U;m00<005KlE_`02UKl00<005KlE_`00P0025/L00<005KlE_`025Kl
0P000Woo00<007ooOol09goo0`0000=oo`00Ool02a242`aS2aBU2acW2b482acW5QS60Woo00<007oo
Ool05Woo000;Ool00`00Ool00007Ool00`00Ool00002Ool2000:Ool00`00J_QZn00:J_P00`00LoIc
mP02LoH4000=Ikd00`00F]]Jf`030005D_d00`00E_aFo00;E_`2000;Fa`00`00E_aFo004E_`30002
E_`01000Ool00000:Goo00D007ooOol007oo00/@Q0/<H`/DY@/Li`/Q20/LiaHHaP9oo`03001oogoo
01Ioo`002goo00<007oo00002Goo00@007ooOol000Yoo`03001Zn6[h00]Zn003001cmW?f00<00003
LoH004^f008000YW_@@000UBo@03001Fo5Kl00QFo0800003Fcd005/L00YK70800003E_`000000080
00EFo004001oogoo0006Ool00`00Oomoo`0NOol400000goo0000000;48@;36<;5:D;7>L;8@P;7>LF
6<H2Ool00`00Oomoo`0FOol000]oo`03001oo`0000Moo`8000=oo`03001oogoo00Qoo`03001Zn6[h
00YZn0@0009cmP8000A;]P8000AW_@@000=;7P03001BoE;m00QBo@03001Fo5Kl00EFo08000AK?@03
001K75/L00QK70<000YFo004001oogoo0004Ool00`00Ool0000OOol00`00Ool00002Ool00`00Ool0
000E000;48@;8@P;9BT;8@P;6<H;5:D2Ool00`00Oomoo`0FOol000]oo`03001oo`0000Moo`04001o
ogooOol20009Ool00`00J_QZn009J_P30004LoH00`00BkI;]P03BkH70008Bah00`00D_eBo@08D_d0
0`00E_aFo002E_`20006Fcd00`00FaaK7006Fa`20002Ead00`00E_aFo008E_`01@00Oomoogoo0000
0goo00<007oo000087oo0P000Woo00<007oo00005@002a242b482bDY2b482aS62aBU0Woo00<007oo
Ool05Woo000<Ool00`00Oomoo`06Ool300000goo00000008Ool00`00J_QZn008J_P30005LoH00`00
BkH000040005@cl00`00Bai;7P07Bah00`00D_eBo@08D_d00`00E_aFo0020009Fcd00`00FaaK7003
Fa`20004Ead2000:E_`01000Oomoo`0017oo00<007ooOol087oo00D007ooOol007oo01H000/@Q0/Q
20/U:@/Q20/HaP/DY@9oo`03001oogoo01Ioo`006Goo0P001Goo0`0026[h0`000V[h00<007?fLoH0
0W?f0`0000=GG`00000024<o0P0024/N00<005;mD_d01U;m100035/m00<005/LFa`00P001eLM0P00
2EKl00<007ooOol00P000Woo00<007oo000097oo00<007oo00005@002a242b482bDY2b482aS62aBU
0Woo00<007ooOol05Woo000COol5000017oo001oogoo10000dJm00<006[hJ_P00V[h0`0016[h00@0
07?fLoIcmP<000EGG`8000Q3?`03001;7T/N00I;7P04001BoE;mD_d40003Cah00`00FceK?@0:Fcd3
0009Ead20009E_`300000goo001oo`02Ool00`00Oomoo`0SOol00`00Ool0000E000;48@;8@P;9BT;
8@P;6<H;5:D2Ool00`00Oomoo`0FOol001Eoo`04001oogooOol30008A[d40006J_P01000LoIcmW?f
0P0025MO5P0024lN0P001e/m0`000ULn00<005LMEad025LM0P001EKl0`000U;m00<007oo0000:Goo
00<007oo00005@002a242b482bDY2b482aS62aBU0Woo00<007ooOol05Woo000EOol01000Oomoogoo
0P001dJm0`0026[h00D007?fLoIcmP0000QGG`80009FVP030016FdIK00I6F`030012WD:M00I2W@03
001?7TlN00U?7P03001K?E/m00@000IG?P03001G7ELM00MG7@03001Fo00000@000IBo@8002Uoo`03
001oo`0001D000/@Q0/Q20/U:@/Q20/HaP/DY@9oo`03001oogoo01Ioo`005Goo00<007ooOol00P00
00=oo`00A[d00dJm0P000dJm00<006[hJ_P01F[h00D007?fLoH007oo008000=GG`<000AFVP030016
FdIK00I6F`030012WD:M00M2W@03001?7TlN00Q?7P<000YG?P03001G7ELM00IG7@@000YBo@8002Uo
o`03001oo`0001D000/@Q0/Q20/U:@/Q20/HaP/DY@9oo`03001oogoo01Ioo`005Goo00@007ooOol0
00=oo`@000I6_@03001Zn6[h00=Zn004001cmP000004Ool30008EYX00`00AU]6F`06AU/00`00@Ye2
W@07@Yd00`00Cai?7P04Cah30002Dah00`00EciG?P09Ech01000EaeG7ELM10000e;m0P002U;m0P00
:7oo00<007oo00005@002a242b482bDY2b482aS62aBU0Woo00<007ooOol05Woo000DOol20002Ool5
000:A[d01`00J_QZn6[h001cmP0000Qoo`03001FVUJJ00IFVP030016FdIK00M6F`030012WD:M00M2
W@03001?7TlN00<000IC7P8000QG?PD000QBo@8000UBo@8002Qoo`03001oo`0001D000/@Q0/Q20/U
:@/Q20/HaP/DY@9oo`03001oogoo01Ioo`0067oo0P000goo00<004JmA[d01dJm00H006[hJ_P007?f
0009Ool00`00EYYFVP07EYX00`00AU]6F`07AU/00`00@Ye2W@05@Yd4000;Dah01000EciG?ULn1000
0e;m00<005;mD_d01e;m00<005;m00001E;m0`0000=oo`00Ool09goo00<007oo00005@002a242b48
2bDY2b482aS62aBU0Woo00<007ooOol05Woo000IOol00`00Oomoo`02Ool00`00A[e6_@07A[d01000
J_P000002goo00<005JJEYX01eJJ00<004IKAU/01TIK00@004:M@Ye2W@@000=>^`03001C7U<N00UC
7P@000QBo@03001BoE;m00MBo@800003D_d00000008000Aoo`03001oogoo02Ioo`03001ooaBU00XD
Y@/@Q0/HaP/Li`/Q20/LiaHHaP9oo`03001oogoo01Ioo`006Woo0P000goo00<004JmA[d00dJm1@00
3Goo00<005JJEYX01eJJ00<004IKAU/00dIK1`0024jk0P001U<N0`000ULM00<005;mD_d01e;m00<0
05;mD_d01U;m100027oo00<007ooOol09Woo00<007oo5:D02QBU2a242aS62acW2b482acW5QS60Woo
00<007ooOol05Woo000LOol01000Oomoogoo1@004goo00<005JJEYX01UJJ1P001Dii00<004jkC[/0
2Djk00<005<NDah00`001ULM00<005;mD_d01e;m00@005;mD_eBo@@000Aoo`03001oogoo00Eoo`03
001oogoo02Ioo`03001ooaBU00XDY@/@Q0/HaP/Li`/Q20/LiaHHaP9oo`03001oogoo01Ioo`007Goo
00<007ooOol06Goo00<005JJEYX00eJJ0P0000=BV@00CWT02Dii00<004jkC[/024jk0`002ELM00<0
05;mD_d01U;m1@002Goo00<007ooOol017oo00<007ooOol09Woo00<007oo5:D02QBU2a242aS62acW
2b482acW5QS60Woo00<007ooOol05Woo000NOol00`00Oomoo`0HOol00`00EYYFVP030004DYT00`00
CWU>N@07CWT00`00C[]>^`06C[/20002Fa`00`00EaeG7@08Ead01000D_eBoE;m10003Woo00<007oo
Ool017oo00<007ooOol09Woo00<007oo5:D02QBU2a242aS62acW2b482acW5QS60Woo00<007ooOol0
5Woo000OOol2000IOol20007DYT00`00CWU>N@08CWT00`00C[]>^`03C[/20005Fa`00`00EaeG7@07
Ead4000COol00`00Oomoo`04Ool00`00Oomoo`0UOol00`00OolDY@0:5:D;48@;6<H;7>L;8@P;7>LF
6<H2Ool00`00Oomoo`0FOol0025oo`03001oogoo01Moo`03001BVE:I00IBV@03001>NDii00Q>N@03
001>^djk008000MK7003001G7ELM00AG7@<001Qoo`03001oogoo00=oo`03001oogoo02Eoo`03001o
oaBU00XDY@/@Q0/HaP/Li`/Q20/LiaHHaP9oo`03001oogoo01Ioo`008Woo00<007ooOol05Woo00<0
05:IDYT01U:I00<004iiCWT02Dii0P002U/L00<005LMEad00`006goo00<007ooOol00goo00<007oo
Ool09Goo00<007oo5:D02QBU2a242aS62acW2b482acW5QS60Woo00<007ooOol05Woo000SOol2000G
Ool00`00DYUBV@06DYT00`00CWU>N@06CWT200000e[k001K7009Fa`3000OOol00`00Oomoo`02Ool0
0`00Oomoo`0POol20003Ool00`00OolDY@0:5:D;48@;6<H;7>L;8@P;7>LF6<H2Ool00`00Oomoo`0F
Ool002Eoo`03001oogoo01Aoo`03001BVE:I00IBV@03001>NDii00A>N@8000AJn`03001K75/L00EK
708002=oo`05001oogooOol0000ROol00`00Ool00002Ool00`00OolDY@0:5:D;48@;6<H;7>L;8@P;
7>LF6<H2Ool00`00Oomoo`0FOol002Ioo`03001oogoo01Aoo`03001BVE:I00IBV@04001>NDiiCWT2
0006F_/00`00FaaK7003Fa`2000VOol01000Oomoo`008Woo00<007oo00000Woo0P002aBU2a242aS6
2acW2b482acW5QS60Woo00<007ooOol05Woo000WOol00`00Oomoo`0COol00`00DYUBV@06DYT01000
CWT000002E[k00<005/LFa`00P00:7oo00@007ooOol0029oo`8000=oo`03001oobU:00XYBP/]J`/Q
224HaQHQ209oo`03001oogoo01Ioo`00:7oo0P0057oo00<005:IDYT01E:I0P0035[k0P00:goo00<0
07oo00008Woo00<007ooOol00Woo00<007oo:DX02RU:2be[2b488AS65R480Woo00<007ooOol05Woo
000ZOol00`00Oomoo`0AOol01000DYUBVE:I10000U;l00<005[kF_/01e[k0P00;Woo00<007oo0000
8Woo0P000Woo00<007oo:DX02RU:2be[2b488AS65R480Woo00<007ooOol05Woo000[Ool00`00Oomo
o`0AOol30007D_`00`00F_]Jn`05F_/00`00Oomoo`0_Ool2000VOol00`00OolYBP0::DX;;F/;8@PQ
6<HF8@P2Ool00`00Oomoo`0FOol002aoo`03001oogoo015oo`03001Bo5;l00MBo003001Jne[k009J
n`80039oo`8002Ioo`03001oobU:00XYBP/]J`/Q224HaQHQ209oo`03001oogoo01Ioo`00;Goo0P00
4Woo00<005;lD_`01e;l00@005[k000003Aoo`8002Ioo`03001oobU:00XYBP/]J`/Q224HaQHQ209o
o`03001oogoo01Ioo`00;goo00<007ooOol047oo00<005;lD_`01U;l0P00<Woo1000:7oo00<007oo
:DX02RU:2be[2b488AS65R480Woo00<007ooOol05Woo000`Ool00`00Oomoo`0@Ool01000D_aBo5;l
1000<7oo1000;7oo00<007oo:DX02RU:2be[2b488AS65R480Woo00<007ooOol05Woo000aOol00`00
Oomoo`0@Ool3000`Ool4000`Ool00`00OolYBP0::DX;;F/;8@PQ6<HF8@P2Ool00`00Oomoo`0FOol0
039oo`80011oo`03001oogoo02aoo`@003Aoo`03001oobU:00XYBP/]J`/Q224HaQHQ209oo`03001o
ogoo01Ioo`00=7oo00<007ooOol03Goo00<007ooOol0:7oo1000>7oo00<007oo:DX02RU:2be[2b48
8AS65R480Woo00<007ooOol05Woo000eOol00`00Oomoo`0;Ool00`00Oomoo`0VOol3000lOol00`00
Ool]J`0:;F/;<H`;9BT;6<H;5:D;6<HF8@P2Ool00`00Oomoo`0FOol003Ioo`03001oogoo00Yoo`03
001oogoo029oo`@003moo`03001oobe[00X]J`/aS0/U:@/HaP/DY@/HaQHQ209oo`03001oogoo01Io
o`00=goo0P002Woo00<007ooOol07Woo1000@goo00<007oo;F/02Re[2c6<2bDY2aS62aBU2aS65R48
0Woo00<007ooOol05Woo000iOol00`00Oomoo`07Ool00`00Oomoo`0JOol40017Ool00`00Ool]J`0:
;F/;<H`;9BT;6<H;5:D;6<HF8@P2Ool00`00Oomoo`0FOol003Yoo`03001oogoo00Ioo`03001oogoo
01Ioo`@004]oo`03001oobe[00X]J`/aS0/U:@/HaP/DY@/HaQHQ209oo`03001oogoo01Ioo`00>goo
0P001Woo00<007ooOol04goo0`00Cgoo00<007oo;F/02Re[2c6<2bDY2aS62aBU2aS65R480Woo00<0
07ooOol05Woo000mOol00`00Oomoo`03Ool00`00Oomoo`0?Ool4001BOol00`00Ool]J`0:;F/;<H`;
9BT;6<H;5:D;6<HF8@P2Ool00`00Oomoo`0FOol003ioo`03001oogoo009oo`03001oogoo00]oo`@0
05Ioo`03001oobe[00X]J`/aS0/U:@/HaP/DY@/HaQHQ209oo`03001oogoo01Ioo`00?goo00D007oo
Oomoo`0000Uoo`@005Ioo`06001oogooOol007oo2be[2c6<2bDY2aS62aBU2aS65R480Woo00<007oo
Ool05Woo0010Ool200000goo001oo`04Ool4001IOol00`00Ool00002Ool00`00Ool]J`0:;F/;<H`;
9BT;6<H;5:D;6<HF8@P2Ool00`00Oomoo`0FOol0049oo`800003Ool00000008005eoo`03001oo`00
009oo`8000/]J`/aS0/U:@/HaP/DY@/HaQHQ209oo`03001oogoo01Ioo`00@goo0P00HWoo00D007oo
Oomoo`0005]oo`03001oogoo01Ioo`00YWoo00<007oo00000WooG@0067oo002WOol00`00Oomoo`1f
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {110.188, 0}} -> {-0.0563868, -0.0193168, 
  0.00736159, 0.00736159}, {{7.625, 137}, {107.563, 
  2.625}} -> {-0.219425, -0.0794802, 0.00881517, 0.00881517}, {{149.938, 
  279.313}, {107.563, 2.625}} -> {-15.6653, -1.31471, 0.0903799, 0.0903799}}]
}, Open  ]],

Cell[TextData[{
  "In the second example we compute the forward and inverse 2D DCTs of one of \
the example images. Here we use the function ",
  StyleBox["DCT", "Program"],
  ", a fast implementation of the cosine transform."
}], "Text"],

Cell[BoxData[
    \(A = 
      ReadImage["\<head.tif\>", "\<TIFF\>", ImageOutput -> RawImageData] // 
        Reverse\ ; \n\[ScriptCapitalA] = DCT[A]; \)], "Input",
  CellLabel->"In[10]:="],

Cell["\<\
We now retain cosine coefficients located in a low-frequency zone of \
dimensions 64 x 64, for a total of 25% all coefficients and discard the \
remaining ones. We then use the inverse DCT to calculate an approximation to \
the original image. \
\>", "Text"],

Cell[BoxData[
    \(M = ZeroPad[Table[1, {64}, {64}], {0, 64}, {0, 64}]; \n
    \(A\&~\)\  = \ InverseDCT[\[ScriptCapitalA]\ M]; \)], "Input",
  CellLabel->"In[11]:="],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[
      GraphicsArray[{
          ListDensityPlot[A, Mesh -> False, FrameTicks -> None, 
            DisplayFunction \[Rule] Identity], 
          ListDensityPlot[Abs[\[ScriptCapitalA]], Mesh -> False, 
            FrameTicks -> None, DisplayFunction \[Rule] Identity, 
            Epilog -> {RGBColor[1, 0, 0], 
                Line[{{1, 1}, {1, 64}, {64, 64}, {64, 1}, {1, 1}}]}], 
          ListDensityPlot[\(A\&~\), Mesh -> False, FrameTicks -> None, 
            DisplayFunction \[Rule] Identity]}]]; \)\)], "Input",
  CellLabel->"In[14]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .3125 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.31746 0.00744048 0.31746 [
[ 0 0 0 0 ]
[ 1 .3125 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .3125 L
0 .3125 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.00744048 0.321429 0.30506 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00751202 0.0192308 0.00751202 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
128 string
128 128 8 [128 0 0 128 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
020201000501010300040302040201050503020101030500
000000020002040005020304040103040401010401030200
000300020200040003040000040004010202020000040004
020000010403020402010301000100040106020200000201
040100000204010200020201040100030200010002040201
0003020004020101
010101040400000203020203030201040004020003020104
000300010004000204040101010202030300030202020202
040103000404010200020401020502030402040103030402
020100010201070201010100000202010201030002030001
020303010200060802050204010300020201000402060302
0202020400020202
020000000004020000020200010103010002060000030202
010304030102030201000302010004020001000202020200
020204020402030803000402000102040403010000000101
000001010002020000040100020003020102000000040001
010101050201020403040101040000040001040102000404
0103020303000200
020202000601000001030204010201000004000304040400
010200020203010004000201010304040201020101000400
010202000001050202030000020003000301030100040001
040001020000030200000601070300030200010400000000
010002000004010002010000040003020000020003020605
0900050202020000
040302000104010000040000030204020401040201040403
000002050304010404000003040502000102000207030203
000202030001040002020004040101000101000402030204
000003040500020102000002040007040003030100010202
010002000300020103010300010300000200000404010006
0400000203020000
030408030300010403030200040003020101020102030400
000502010002010004020405000001020400000100010404
000401010000000002040002000100020000010200000204
020102030204000202020400020202040100000200010300
040200020202000000000002000400010301040404000301
0402000200000200
020201040004040304010103010004000203000001000303
000100010104000201030400010304000102010102000000
020301000001040400010300040104000402030300000402
040000030200020101000300000200040404040001040202
030000040204000100020100000100020102010201000002
0304050700000204
000002000002070101030002030200000105000302000000
000003040300050406000300030501000003000301050305
000004000301000000040003020101010301000000020201
030001020304010202040203030000010404030000020401
020002020302020401010300030400050101020401040304
0100030202000001
020201030402050000010204020000000300020102020204
010001020103020401000001040103020104010003050402
020201020202020605010200020002010402040000020303
030000020301030404000403020201020302020204000305
040000010000000000020004030003000101000504010100
0303010300020104
020001020402010400020201020400040401000102040401
020101030201040004010402040102000300000200000300
000301030001010002030003020301030404020001020000
000206000104020400000202030000020001000304020201
030104030101010003020401040104020200010000040201
0104030100040204
040300030001000005020004000002020101000400030101
040202040303020100000202010206000004010103000302
030201040302030304000001010400010200010101020403
040304000003010004020002010203060104010402010302
020006020602020301020403030100030203020102020003
0200000004000102
010303040400020204020002000202020400030703030102
000302000104020000040400000308000202040301020001
020000000200000502000304010400070001010002000302
000A03000303000100000102020104020402000100010001
000109010101040304020401000001000001000200020402
0204000200020300
020402060004010204020102000302000300000103000400
020201010200020001040100040102020103020102010100
010502030001010002030300050204010200000104040002
020400010104000400010004020000020004040006000102
080000040004000000000203000200010000020301010101
0203020003000101
010402000300040202010100040202020300040303000003
030103040400000103000302050100000002010403010201
030005040404000201000302020001020000030303000102
000101020002000203000000040402040202010201010300
020200040000020000030603000400040405010000000201
0004020001060000
000100020404010002000002040200020204010402010201
010200030400000002020101010003020404000200010002
020201040102060001040004000402040003000000010303
010102040000010403030001000400010401020100020002
020200040003020400020102010101030102040204000300
0301020100000603
000103010405000200010101000404000401000003010003
000001040301000402030202010001030404000102010301
000200000100040302000200000201000002040400050002
000400000202000303000100020000010000010200030100
040105040202030403030202010002030301020104020004
0104020000020200
000005020504000100000203000104000202030203030002
020002000403010102010404020001040003050100030502
020203000004040104000302020600000000020000000001
040202020202040207070300030200000204010300010000
000504020404020100000407060402000400020002010002
0400020002000304
020200010200020204010000040000020002000002000508
040303030304030202000102020102040300000102000401
020303030002020203000201030002040200000101000200
020000050503020003020001000400000200020100000403
020001030000040208000102000203000004020000030303
0000020004020404
040003020300010103040004030402000203020401000401
010100000200000200060000050402010203000205000001
010204030103030100020405000200040400020204020502
040002000000010402040100020200010004010101000102
000400030102020302040302020400020200040200000205
0000000106020104
050303010B05040904041105060600040513146958363748
1C192B0E18304253565E535E55504E3D47433A353624483F
4859441E10046C364C73697279311B292F596056625A270F
191C2B292D49454234513229352531371E24242C2B162D04
0B03070804040D02040404080400020406000B0401031303
0402020909080502
000A05070B00040C0506030A030A0C090604326F4B3D3C1B
0D0610113C3F554E68525D535252483D5345323D37253252
2A667F5E260C3C42291B1F1B1B161238375161525C523713
112B2E37444F42423C3C46151C1D2D3F2E35172533232714
01030700090300040204070507020000050A050502060A0A
0203060405040802
00060C04010E0F0A02010808080F0E0B0B13596242503109
12281801041F474D635B59594F442F2A374C3C3D322F1132
4F4A6931210624581B21101D1016232235426966594C480B
1C38453A3944544D2E3D4C1E2D0B36383D21312E27402830
0B04090003040A0604020403020205090D0B0402000E0504
0B06040606070404
030905010517050C0D08070202030A040A125F38515C4411
1F271900050B195B6955545B4D41373D4048403C20292028
5E5A5A7F1F0B1054281916141E172823312A696C5C605825
2B2A23323F533C3736424C232C102C3241261B302F451735
070A0E04000712040304040308020B080104020C0B06010A
0600040103050207
0002040603100D0A0F030A0004090B0209136653645E4F1C
11310606111215446563605D544D4E41363D39370F162438
4067672B2525051C4F1019221921281B3231646C5B646459
413F423D292524262C22224222151E3B4244281D4141422D
3210110404050B0D0404040204020404080A06050F04010C
07000A0302010108
0203020D04040D040A060B0A040E0F060D105063576B5843
2A21210608130B646B6F4E5F584C4E39212F383F17222A2A
4D64412006111B146611141D1B1C131B3727487363585F44
6141524E372420120A021D301525202E484823263D334519
311005090102060A02040A06030A060903010A070B040606
09040501050C0206
0A02080A07040304040A0202080E070D0D0454715F646557
1B2D29040A03044C36394148524D5446292E4130382D2D12
42644D1B0904210D481D110A0A0F18091626367C7C667142
595F0D211B221E2019131C471C3D362936473926313C5E37
2C23050302020A0A0806030B040206020C0A040D04050407
0404010309020608
0806080D0E040906010A090C0C1104010A05366F56616E4E
2139282C170C3F3330313B4547575348383130523B21231B
566F67161B120A126F210A0D1F130C0A202D3C696F6B7253
470E1B1C18152529202B1F42303A32194A5355393A495A45
123C1411000106110B0B08050D0707020606060505020509
0E10000109020301
04030A070E0909020A08050F03080A0204061086676F6C56
143B3C383A2175424F504A4E666D6C68543A2D4038273334
675E595B1106190A5E475F83828A6D64712E2C3E6F7A6F64
3A120B0C1828312C1C252F422C1B41254646443320475066
4937220B000506000910050A0B08080C10040A0C04020800
0B0F0A0808040806
0601030F0C0B0F0A0B040A080B070B0D0A0A054D61596363
1931133D0E5B61536F534D607373797953402B3B53373746
6669764E1D060B14551E48877B6C6D0D23252A267C7B6868
4256121312261E2D341C4E43453D3848294641432F3C4662
5621430E0A090D04020207070203050A0503120F04070201
0F03080A00040706
07000A0A0A0D0C0805040C08100A040F0B0704265E39765B
101E1321168D72616058525466726F6949341B42603C4444
71719390210E040C22301112200B1B1D1C331D207777686F
6F38462B190F2B363A41421B4C53264E4337473C36365566
584936330200070605040A0909020007050C0F0600060F15
06030F0404040104
080A0D010D0E060004110A010A0C000508051429594A7771
1F1D0C0E5DAC745B585663586F72755D38312653523F3238
6763857610100B15182B201B0E1021140545252B5A7B6F73
7C2547421E251F2A312E412F3F4A363C4F132040563A5B51
5B5F19360D0206090E080606020F05010808090A050E0411
090B0D0308000504
04040F0400050906020E04040511060A0F091C2368316E68
0317060C9E9F5E66635D6E66686D5D5D583F3C524A454044
615F68450A0C0B052536191B151F202C29302027327B7A7D
7841546B20112137262D202E413C4D4A50282B564B44365A
5C6E4D3F340A0806000907040900080009080A050A12010A
03050C0207010401
08090A0510080E040B0E0B0A101212224C376848918B786F
080F0567B0856E575C7961745C6A59514E5652524F59424D
5A6C634C11090F1D2263481915060A28241F2B22257D7F6E
817330486041512920191B3D3E2F525440472D39513E4847
6B6E691B650D04080B0D0E0A070E0A15050A06011606010C
0E0C0B0606000A0F
01101106040A06080A000602001805254E4C53364DAF702E
11041B909A8768657B6567676B6761604D46735341524940
5D714C1901160A13103C2305381E2638222138202A4A8874
7D822C307C312837443B434D583C4C3D4E4B2B37594B604C
6958595244200F03060A0D0A010E04030710090508010400
050C090A0602080A
01040F010A08080C060C020A050314586C6A665C7FB29027
051B3E88837D55686A66676E6E60725D4C59635E544F566A
565F3D71222423180A0F28452C36313434362C2E2D3D788D
7A8843425464727E7368646A6B444559475B3F3F56595054
625A6279285B04060702030609090404000C0606010A0101
080F040A08050B02
040301060C030A02070A0D0A0A0A0B5C7579908C8A7C7436
0C177962495C6460756F76636B78586F63767180726C4D4D
6C514D8E3C31330A2652631C192107072A14344238207B73
6D7F6C2F3450683D5D765E3649465A585E67211E42445153
57543E7A5D4219020A03050204121406100403040C0E1504
06070C0407050E06
0F02050B050805070B0F0C050B0E084241756C6F9C625919
365082535C7289907C736A4D676450715E71856E6844496F
706E5378617552271D246C321E3116242B241D2423344E83
777A852A2E41091909232335363D567A4043523D413D5A4D
4B1E53AC892E51040700030A0A040A0208070409060B0D11
0E0D0E0A0B020305
0709060910060409060F0606020707190F748AA3220E4520
3A56744587827C756D6877697B72785F69717A6352416A8E
6D60537A7F857A392226413B2B2112191915123C28353385
84766D4339671B3332234F6F3B416D6251596F5E3C484F61
50426EB097524727160B040A10130404040A090C0C09090F
061001020A070F06
1708060C03130C080B050E140B0C061F0A42754730330F6F
6E6C7466849B8D948C70787A7A5E5D686E727F7A5A467984
6D65718C7F96AA69221C32253C2A251C3F1B062E34282984
8E686B79383F6F103D1D2D37293655556C545A602B283241
5254438088802C560F110E0C0B040E040A0708050F110F06
020A0A030F150901
0E0A10090F011308080709170C0F123066227B7D43173057
86725C9084A7A48179796A6D795D72746A6C736B655D876B
6D5C808D808B967D1521860D5D46101C220F092E3830225E
838779842437427F32496B352C5748412B65617384372B45
4D58504872904F30470504080901060800040A070E07120A
040E06090E080204
0C06030D06070A0A02040B0E080510694F688F6745293305
5CA5747F8C8589736C7565778D796D67695B6B5A736D6E5D
65566C7E8B779B902612700C4C401F101F2B0829132A2429
8B8F82804A3E3162822758435F6A36472C6E797974843B44
3F5557425388962D532C1309090309090305130510070E09
0315030A0D040F01
0C090300000107060A04000A020C66A56E796D816C152C0F
25596A8274767B69647E877478777663625E60636C80727A
587C766F907A904E14132B0B5E3D1618191929130E3F2720
958A8B986830333B4D5F392F5B6746754C584C4671645F3B
54485C4C4D5383702645220C0E040C08040B0A0F09110C02
110702090B0A0B06
0B0A0B0A04030F07040C080D0A1B636F755F5985573D2D27
0A184D6B7E6A7C857172807A66837F828265585E72787469
69778B84A6968A3A1E297B192E0B831619200223131C2221
9885878E8B293D3E2D3D6E33412E555652493B4948915258
404D425A58494E995927522B0505060A0903030C0B110A07
0A00030A09130A10
0D0F090604050710090804031206594E5E68698D64692420
0E09163E81937E6E898E6F8177707A7873705D6B7F6C6E55
7896699B8A9590171B17753C160F596821202E33191C2E32
7F8A8A9383323231391B5D6D3752643C203E53382C673B6E
6E3D484C5350486B9553285C161609060E0A0406040A090A
0F100F0700000F0A
08060A00050E0E0B0A0B03091003455D62616A77736F3719
08162A062779A58094A19A7A776C7B716E666979877A606D
96678E9E8592501C0F0C531D260B2C7A13443130051C2F26
778A898D864D3E37323142557F46080A0B15113940293A52
546755585451483B8D8A4E3A55190C050501000403050F02
0F150C060C090B04
0A0C06050E050C06120D0504080B237C6A665F718B585720
0A0A5019164271917A8E888D83727D73756563716E5D6672
707F9D88814E1B010A0C05520E16063E570A0F091F183532
7D99879386833A2F2535402E256F1820181F2F191C0B1808
355D745852694D4A79B0923B4A360706000B0402070A0B08
121B02060D0A0001
0E0B0F08090C150212150A010A0C1C987266687A8D6C704B
11214E2B19034B7194857470846E7980857D6D755A64766A
7A969B9CAB260F0F0616396E2026162F2E1519293F222B31
7096868C829F322E2222262D302836321B2A1E2925161123
0F1D193D6661697462583D69385102080502070406030E0A
1915050607040206
1105090F040B100F140F00030E03259C6962645D90897B59
192F5817172405404F5C768B686869906F7455515F8B726A
9489A1C05A0E0E1329132F704136453966104A2A2225222F
5689988A86954135303520201D2E3B2852410A133A1C3B29
342F1B080E3D6859533D2172444F2702050004060B0D0C0B
130A0F040A080A10
1B04060416050D0A100C070B0B0C30866B53676E918D8068
263C5F200B4139122831545C69748770666F617C9F6E5A98
8CB6D064210D10041B122E756F2626233A603B592C2B2D3D
4C918588828983372A21272B2A23373736584B5828251B05
17081F1F130C0B08181C0F727F4350080606010301060D0C
05060E050B0D0305
070D0906100D060C0A050C0A04052A485244526195858A6E
422C51210B5841061F1E242C36698D83755064536F4E8494
AAB74207130F010F050F206E714730294D7F3265162E2A10
5A8C85868680952E2D2C3C3A3D3130383B3D374227271623
362B22101D1621152F0B066185516411060A070505030B11
0A04100804120407
070A0F02101004040A0115000D041F2F162C40194E865D7A
7A0F30341D2B0B17371B0B09141C3D51B69D7E74928AA3B1
481B1C1B021B0D0A0B0E078C695A2102327F263932332C43
968E8F978D82713225384A44382F1B3366675D543B2D320F
2D463D15302F331603110D12885D6621140B040F040C0E0A
1408100B190D040A
0A070207040A0C01090305050C2E325E582C1B498870402E
6832642E2C09292D0C0F171B1916031C2E181B3C39203B15
0512080B0005171E050D176A5B5B3A5C787E22143C2E5D3D
92838B8D87804E222738473C3C81757F8C6F75716934322B
3D2142414F2613211C1803197C64523F06060C040200040A
0F03020102040202
040B030203080A0C060E0404110F251B170E1033401E451F
431E2C5E3A303A1F32233E1F242105151918373220130931
1719120C0F0C09050E0C122F6F444239822D161D2A56594D
99858388817B352522455B5974787B768A7D7B64876B4348
475930484E64490B231411197A873F580C030A0904040B04
0D050C0C08070802
0B0309060A0E0E435E55180F041E290416212B2821170B25
2B342516443E6968685558656F6A59533D3C14314D5B2D24
320A052302120B0609081D4F6356484F221B00223D302D58
A8858B887F853D282C5058776E739181747E82697A715C46
375552543D755E2415300500769336564011010A010A0A0A
060C060009050504
020A100310062F5B403F2A0E291301070F0A131D0B0F192B
2A190C467432485B554B4950503134463B4521204F3F3C28
372F141F0008051116140A4F595448341643183C302C3D63
8E93808B837A4D36154A64717F718F8A798482826F746E47
3C36596F7957414B242A1F0737A6565D6B1709040608090B
0A0B0F0A0A020C0C
0A050D0B0A05394616090E10090F1353381B231F18052234
4DFFA5453C7B4E481D3745414A2C47444356513E40384830
32100E0907080C080C0A05216E3B390B281928352D31375D
93877A82877E5C293C3B6E807D888B7F6A7D86776C76676F
6B3557644E46625E36293411088E963E5243090104060707
03070F0504060103
0A01040B03093853595A1F08081B2119214619180C2D7B8A
90656548152208330B444037444C3055515459603E3B4D42
291B130E0F0E051E0D1024437251091932432E1436353058
8B8084888E89772A3D54747E7986858071867F8D70737A83
6F53355E5354793D181533260C08A08540592609060E1406
0405000610030605
030F07040A040E54534E49192D180E2419424E412A759088
A1957A603E648164170F265043787C80695E454B29202623
2B1724152B4236414B3A442D4E161C325A3126362D38526A
89858E8B868D902721457A646E7B857979857C72846D6F83
765E2E41404C56511D182C301C070CB2682B540D01080503
0400030A06020A04
090F060309040828415D454531342F415E674A34219EA890
B2A0B1A9B6715E3F12001B2C2B594A6E672542544249461C
2D1F25264F805A443456542829202C2C243635313D778F8B
7B6F94958C80902A303F6D7A7A747E7584798A7A73897E7F
887E634D445D554C1035350D32160505A15E436F12040207
0704060606000500
01050A091607071118375A3F1D3F201B253D494F296AAC9C
B7AC9D8A835E2419210D161D2F37571631533053745E6965
350F03172E3216112739052E22152B4B201E313144A67F82
848D878189898E293231575A7D76908E886B7F856A7C7F76
6E825A2C453F4C5F616C471B2419220B1D8F4B5A2D090804
0208040404000A09
060C08030F0F0C0B0B142A33271F092143614D4042408B79
74747A62592C1D2B2D1924814F513741371647284F5A521E
173915293C2005040D1307350B402C344E231921AC96848D
8A8592868E94902B1C333027397F9A82728A877987687E5E
747E644C533C428083747B7E75483114077465435C080503
0409090B0A010406
0F000A0404080E080208212F28262B52594C48424F696457
4B475672646E4D343F648070346F1E0A434E776F4B3D7161
5D231715110009090B0F1F12282C302F422E2E4E8E898993
8E8A908B878E89321D20162B7F838C7C877B5E6E738F7F74
63843C3E264B838C8769799896822B2B0F0CA05463310D0D
0B15060909020011
05090602050B04040B00112B373E4D435A6446535E606D59
524F5E687A5A395B6E5D2D3D4B5B3244163D64421908293C
210F1B08040D04050E1712180D21260438332990818F928E
8D93929090878D4726252D8B9677819E7F648B7E42897284
824319484D708592A18F748F9E68633A1919298153580C09
0B13080D02090307
06020002010D05050A0606152E574F645B3D325B4C1C652D
2B0A233B5569622F48677C73762D4D1F42461124223A3F4E
210D0F190F0B0507070E13051329190C2E371E8982988B89
8A8E8A8C83898B4423328B6B7D85818292757D84854B6785
8458684C7A7D878B9D938694855E8D681B0E19A6595C0F07
0305030200050804
050105020A0007050F0D08051B41462A484C0F4A5C1F3547
38425F33132148482D13266474695058321132120B306114
1B0A170A070306100D09020B071210123D25328A88938C8B
8B968B8A7F8E7D543137857F80698687949881656E7E5C8A
785F4A677A7D8194A290949B81618B86421B16647256280C
08110A0808020E03
05060B0E100504080C100C0F1520495B405E25211C393237
2B3339592C376026232A50597C7F867938452D3229471016
052B0F000606030B020403101E110E0E2923388E8B8F9691
909299968A958B673C645582755F7669828283818C7F4A85
5E5152708281889191768B905A74968D5E1F09137561450E
0C080B040D0F0508
070B0906040E0A0C030D15090614174452434D1F26313838
29331C31655D4B104D4D6E4347391B230D2C312B0C470B29
1E19040F0607040402150C1B19140728351D5AA18F939193
959896A68F8A8A6F487A777C77567D698590688D61818B38
3D4975677E8D9080717A95857D858A8E731B1609875E3707
070403030F080A08
050500040706090B0B061604070912494F576B4C4C3C3C2E
5038312F547798522321045E0E0C2C203831346042364825
09040009060410061405102A211116543A274D9293929694
9E9A939790858677534E757F8153686D758E62786D845E3E
38686F76798A8F846983965A83907E7E6220240A51515904
0F0D000B02050303
080806080A060D050A110B160D0C0C1B3D545E685E4D3622
2F39457E8053732A0B4312291B2C2E142947232B3B352124
0F040A040506082D415921151C3413583D3465989C968E95
98959BA08A848F8558424D7572505C837A84815B82794E42
7A797B808B8988807A7F90567F8C9485791C29035B536A0A
0D0406050E0B0A02
0414020C0B0404090413160D0F0E170E22493F4F6E81482B
23444F777A2659642B112C1247263B0C2B3D45371B213209
070A0B0815031E2854385E629B267B55393E529692979991
96969880858D83825E492D47715E836B5D827F746C6C4D68
74726E7D8F8C8986598996608B947F9B971C21254D665F26
0604070402030604
000402081B030807100D000609111E0A040E42464D6C5C4A
37321F323A4E182C4B584E363153190922426A231224302E
040F0511250B1258AA655747550B5A473E3232999797A397
9B8D87878A8D96895D463D3637725F8553857C6E62645F79
76767A9285726F63789083507E89838D8A54242227665B2B
030107000E130F04
00050A0A10140A09150F0C0A14110F0D0A101B4243324667
2E38402C2A092C30175E2C3522211E0629290A08161B0B28
0B0A1B080F13616146455972322D5D2B272D3D92A5A19795
91868B88808A947D7A94433934598C7C598569635E6C5A71
6D74838B7464667B908D7B4C6884917D905F1B15285A5A32
0A0D02081004140B
081306100A050A16110F0B0E0F1019070808031B29263330
38192C4A211F0F13243631170B1D2D0F1612120B1B121816
000A0402043E4128373643614773312331303A71475F8B85
848F848B8286888A87907C383E3981834F735947475A6778
7D888D908A7B7A8A7F687A597B958683A15D1E10108F6329
060A09020A040A0A
090C040D0204070F0701030C03070208020A050F260E0721
142E1739441E0B1313421C262119030421353216200E3709
070B1104050A082A2B34343B454031363B3B84834779887C
8B98958A83858A79949B4239473D27273259536F6570627E
7F8C86898770787A7A797C809A888C79906A2A160C7F5627
0D060D0C05030804
04000607060A04040604010705080A040D03020A19071515
0B211C2C4543352F2612192C01181E252C19111B0C29190D
1905050512344A59A6A99A755D56323C3C33342E4C646D85
94978B978C8F7A7095992B37442C2B4252677F878A98938B
8E7F7569656885787E9992959C9F8C99A89912200A7B6324
0B0E0A080A090102
0602020A090C050D0C0C0D0A080B041102060407150F1303
202E3B2D3B3C3F06200F03103928110C10150F151B0D102E
53639A44354C527369676D718793BC84524D3D6C86748799
A2A0A1A6988F6D8F9B732F2B2F3B1D265D6478707989938F
855960475087885C6B868A79938D98959D8D0E0F09686819
0B07060A01070702
0407040404070C1203090F09150C040E060A0B0107111920
23534315290E19200F271E0F121F151F27263D2419237A8D
6374B2A889847C88877E8444264B499B8B718A8F8E98959B
A39B949090827D9984352A282728415669666A6764777B6F
7C878883808D8D53696C889585808A899476220B016B6311
0E0404050C070808
00070A02080803040604040003040406050A0A01082B5179
712C1E2D2318474709050D1C2F283110165DA09D55686A8F
8F90A6AB9D87847E908F743D464A457884858E77908B9397
9B9297958E8E785C462536353F35515D6F717C78817D839D
A38E7990A08F7F8A7E7D8E8F7D918D857E2915140F80630F
0507070604080902
0C080C02080A030703060206040304010411050A06532F9E
5B271E161E101B2E353D39150C1B3C60918B728479695C69
7D7B74838A8C7B76838E7D6727497F837F88898A8D819C97
A19B8E84686F4B404D60455558497B7D7F8D8D70767B797B
7E616381A191989A9D868178767B83745912150E27857718
0C050C010A0A0206
04040100040A06080704040002020205060A0A061640796F
2E2407231E14160F0B141C186D8895C39B958B715D797D7C
7B83808F9186808775837F636F7F919279898B90907A8F8F
80787578607649323F3696A59C697E86929595877E786971
707B68849A9595999E888273737A836251030E073F796E19
090D070504080204
0203040305060304040002060102010404080A082E428471
0704030E15130411041943928E8DACAC9E90798C8C8C8F8F
857F7E8283878895827C727E8787888F85928985837D9684
8A8C847E737B363D2CA18F969D89819B888F9591847A757D
81826C73878F829897756F736D776F4A3D0F1B103C74780A
0702080304030503
020304040002010100040103030202060202030657659333
040E190F0F040F172369AF90837884A0AD828A9F9D8F8284
7B767E828D9493958E7D777A7E7B86A0938D8A8D84858B7E
87837E7E7A783A3C4CA4939A9B95849184747F93928D8B9F
A18F7F64908B7A8790786269707170591C1C0C0A506A6F0F
080B090504010003
0200040806040403040204040802020502080406746F7C19
0909040C00041037929EA08D958F9D958A82989D917A7275
7A888A8B8C90979B9A8A84867983828A898E8B8A89828A84
87848280836A4A373F9C9A95999C899F80656D6D8F8B8896
A0A67F6C7C69647988795A6E758274770212011C5359540A
060D0A0708040502
0000030403000003030501040006070306070107736A6906
00020403040D164785BBC2B0AC9A959EA7A2967E7377758B
93898683959DA49B8B8A7F644F4A4C6D80738F948C878A8D
81848783836448335F879EA29B968B9B90786869766F6877
85A6937353766C767474706F74867B6D0E100A315B68340A
0406080704060700
0102040301010105020307020106040203000A0967536C14
1405020806085D8593AEB7B6B6B59A90897F7270747B8E91
817B8BA4A2A6A096857F70554D3B383D4F5C6F8E83858A8A
8C848981686266878B8EA3A7AA7E8F9D9595765566776C6D
6A8F88666E7C7568775B646773786F390F180B3B5C6A1D09
090C0A0700030201
03040006000406010202060101090002040009042A675A37
080604040A09A38C9592A0A1A5897E606E6F69687B938F81
7B989B9AA9AEA38A6E565E5A5645382A32444984877B8A8A
848284807D9874607190A9AC957E9497886F746E858E837A
6D8C8F797D79755066664254696A5A0F170D0F3E6F620C0E
0807060503020002
00070001000402020004060000040200000401000D74484B
0C0706050C0C72868895999A876B606A6A787E899A8D8076
859AA2B7BBAF855A3B53645C574B3D33312C386F6E85878D
878F7E73744A464D7099AFAD8A919B98725B6E85847E988F
8B9195978E7B6856747A807C3D606D031B13193C72630A05
090C010A08030104
00040204000205030200040304050206000603040D4A7F77
2805040109063C67696A92968449667E8A95A5AB90817276
9C9EA6B3B3A15B2136494C5354463D4131263143587A8783
8475736F5F423D669DA5B392809E9F9B736E7891696F9490
847F7574685D727B919D8F8A7144460F010A2A596D3D0D01
0804070800010303
03030402060104000002000300050502050303040A1B8343
6E160D080B034F7A8C9BAA976C59778C8A736FA389747593
9A9AA2AAB19457252C393C464741383C3229202F302F4189
8F7D5323212E6D8CA5A88882959791887761728C6A718C8F
7974756E6E7B889A8A848B8472592908110B545671180404
0205070600030000
040404010203000108010603040404000102070104074BA1
552C100202026387999F9687696D8BA0775F73837E717F9A
9AA5AAA9B1A56E37282E2F373D3F3C352E2E29201C212B2A
1E2932332A6493ACA48581979A968D786A62798E6C72737A
6F6C738F8BA1867354525D66483F1F04292B3D816C0A0603
0105020404030002
04030003020101000406010004020204040401080A0B1974
566E0B0B0718878B95959C985B70AC8A63687A8477849E96
A09DA1A8A5B4A88B622C2528303737302F2C262722202226
29353649728EA996747F9C9C938F876C5E607A9677635455
544B6F798CA0906C65613C42350F0D02175847674D0D0904
020604040A000201
040104020303020600030402040202030500020001040962
9C2F17070C12848CABA9A3996B85A17D306C84888798A199
999B95A2A4A0A8B2AE8B6B37232528252825202022202C31
2C4D77889BA6937E949A9B9A9C90917B7167769893807562
6F6E63596A7E958A8984714F32070907193B957F0F030203
0105000404020204
000106000202030002040201010604060001040406060813
8C6072160614AA907E8698A58494956D3C73887D7375869C
A39E9B9EA1A9A0A5B0B7AB9D90644D34211B26262B2D4865
859D9D9A9788879E9A9C958D8E8A7D7F685072689A997B76
72707B817D667F838A7A6F56100108095E2F696E0A060504
0405070707000605
080104010200020303030203000404010104020700020100
84614B11110D3276704C8DB0A8A69B7A2C5D61676969769D
A6A69DA99E978F9B9FA6ACAFBABBB0A0998784808A8F9BA1
A19B8F88848E9C999A939D8F917E6F6F6B735C63818F8C8F
5E5E5D74908476717A5D405805060C0C3B8C812D09020202
0009040304020400
05010300020400020001000201020404020000000304040D
3D8575311F280D3B5D8588AFB2A0A77C6371708069687E95
7C7996A19D9B9596A08F91939A9BA4B1ADAEAFABA8ABA79B
937E859591999C9A978186938B8A7D927F856E4C618B8A8B
84693D5C6C8C745D50686E230B06071E3B695F0A02040006
0206040101040104
040404020103020300030203010000010303020705050404
0D967A43091916378D9EB69995989A6F708E9882646E8873
666C7681919298A1A2939D999B98929497949B97928A8A8F
9196929995958A8A71647584859681828DA17C5B6672829E
9C86784B517E7F79827C3C09050C16468B61350704030003
0202050400030506
020005020203020501040104020602040202030200040604
0C547E58190A0B2A7F8A917E9AA39F857A91997B4964735F
6E696F766E798CA0A09B939AA0A09E9D9A9B9E9D9696969A
9A989A9C9590727171595F65727C9784799685727B748AA8
9A8F766457768E847D70280D14111F4F716E100700010204
0704040001020204
000002000702040401020300030100040304000006010506
0A1B96693742230B52786B6B93A8AB9F899697867E56576A
7E735D675A63769895796E6E777E9098989A95A09D9F999C
959D998C807A6A4C616E74693C6A867F7A8B86868B806E85
868B786E686B8982784A0E0D07094874664A030201030008
0604020001050004
030104010002000004010302000400020302020302020402
0C0C7995603B420C4B4E5A52909FAAA19D9D9AA08A756F81
8B73656E616F7278796C616D685E6C6F8891959A94908B80
7D83947A6C6E50787B80858174616D6F77667584936B5971
7B846E676C64847F5F150C09041B3684822D030407030607
0600020105040406
040104030100040006000402020202040305000001030400
010918925235261501624132849497A796A2A49997A09995
8D79847F6652646D6E546E7E756B635E6B6B6D68828B6966
6B6280826C62626E88828591775E5965646050686D4B4B72
74766E6D6B69807E4A0F0A1E135B35777916020404020207
0201030100000100
000403000802030203020004060002010104000204040001
0A060A75906125260532413D748B7E84948D97A59A979592
9A949781626E7A75636D81898B81745B525A53556D7C6369
7A5E728B6C3B769085747D8F907564373C46503B323D6184
8B787472685C62442A0A1D1314339D6D420A030400040304
0300010401040604
080300020402000001030500020202060200040702000402
020007169A636C240E1E4E35555E6F84A590929598958A88
9EA39C7F61788A8E7E79949890917F6B61684E5664716071
8A735A6D5966798A827962758A8F7977696C737733497489
8C958B8B6F514169180C150D2944866F1106040002010006
0204010205030203
020404000100020002010100030100000204000304020200
0004020132AF29461C071E4B4D5274A08E929189828A8C8D
A29D8A88718B8D9A9D9F989E9C9A99877D7776614E4F5871
8B81702F6D7990898C836F6E8784858C8A848069355B7590
8B827F766C35554202160F143F5F63460305020503080204
0104020101020105
040206050103090403010400000301000403010402040000
030005060951B01623160905745E707F8588947D818B9AA2
9E9691968C9B9E9B96929596998B929695937F7E6F3D7183
90867058748B8C878A8B727182838A9389817A5D46548486
818F796248555F1B1C12194C2C7C74100300030106040400
0402010006060703
020203020402000302020104010000030304000103000305
03080804041089B31F210C08113B8A7C7C908B738596A89C
96939594959AA1999098938E948B867F7F968F8D7A5E7284
919285727D8E8F86746F547E87878990918B7C5E41578587
74757754426A1F0D0B061B327D5E3F050403070404050A07
0201040004030201
050301040104010002010003040000020706020301010004
0104050202051972D0271E11190C1D488479837492A0838F
92888287A191A198949E9D9AA08783826E7E8C8F7F667082
92938E8C8C8F8879757A65758686836F7D8487713E497D8B
6472734D583912211E055C4475710E020201000003030304
0500010400030003
060000040002000305030503020000000000030202020104
010001020201081D77C63719051015164B5D5E6585897083
7D6E7278969F9B9793929A8B898F9D8D7E7E959086796485
908884868585736E7386806A7A8A855F6474887C4D3B7986
675A484D59080D1B192E349A742202040800040202000405
0207000203030202
020000010002040104020707020300000001040300030401
01000402040602071789BD1D09201C000A4B216C79826775
7B666772948C808DA097786F72868F887F7D89999287808A
8F90908E8A776E71798F887A829486764A5C778759486373
6C3C5A69130F180C2042907F59070B020201030702010304
0403020101020204
050104000002040400010902030302060305030403000000
0200010103020402021790D0142C270C1213404C7E84575F
55494E718C8167808B906E6D6B809385807F898F907D8685
848B8486846E6A6972858A7F7E878878424B7584654A4357
3E4B4A19071B1B0C6B50887E060102000003000403040302
0100010402000203
050706020009010200050203000102000104000002060301
020404020000020000041B5EDD1E4A15131E00154C42583D
373B3B6F7F817E7E957B6B3574748F8B7F83878C8480796E
767E8085755C5D667383868F7D86867B5E3D74817B452D23
3C642610161B1078317A6E16050405030500000207010103
0403040101040000
000501000504040001020404010004040402000300040500
02040306010204020402041172BB28630922151013533B48
37372D6E7A8B8686867F6E397371858682897F88807E7570
6E75828571646173797E7E807983847A69376F8277292F37
6C190F17110A4E1B9C85210804030404060B040502020102
0000060400040102
010201040000000402040104010400020503030201060400
0200020402020003020309060F64A6592C2B1C0C423D3F69
3A3442526C73746B707B77376A738A8478867E7878766453
59697C836E605B68676F767A8073776E5A38636726433065
02071C1910661D868F260306000202010002020405010002
0203020203010200
0A0000090702020000030302000104020002030203060603
01040803000200020102000401063F8E901B4816150E374D
534B41342F535E657278722C696D818483807E6D69645741
5B65768B6F62595F5466767D7F717A703B3327324A56160B
121B20197118857F55000105020304000304040204000104
0309000200040403
000404050004020404050700020201000000050301020204
020102020104010108010401030407268CB84A49180E0F0D
1308090E0F15192045562A275C64717C887B7F6A5D504732
57657E7C7266544D26747A7D7461512A32474C5516161342
777F186F138887620A040305020104040000070100040805
0305030006010404
040402060200030502000302000404020100040600000202
0403040104000302000504000300030514778779255F1617
0C260B0B05180F0E070E0B0A1B5A747E766F7A553C3F3225
51687C85756B403D262C797273485352375E1B1515110775
1E354D2E8B934D0700040502090402000000000204000004
0101000A02030002
050201000002020602010404070202010401020400000702
02040301020005030401000405040205030D457B974D1931
281914261E1F161C1F1914140F0A113A3735372B3236482F
29637D787E533C3D3A32304933284B481B180F0319231726
69074863872E080000040205030403070003010303040102
0102040501090404
030205020402060401060500030203000400000300050802
06010300020304010403010000040001060604165E878566
0F372E190F0C1626191910142812070D043C553A06120E2E
2F3542452E5236533549474C3D22150E04132B0312206012
1C8794730F00030102000401040201010302020300010904
0304040000050102
020104000002030100040203020005000004010104000301
01040202000303010404020004030203000108030516738E
997525282F363518111D051F24250A040B1D131211060402
090C050D1208334B274A21010300142219091C3441190E89
8A8334100004030400020205000102020203020304030401
0201010904000200
050402000101020302020100010005000100060102000301
030100030400030002030402010203020200020300060A14
5B80967A685C210C19273E32180F08030D140B130D061311
191B21131B12110817170D0F141B080B1B3C2508307C7E7C
4B0D07020204000504020201000303000101020004020002
0404000300020204
020102020203010304000000000008000003010202010002
010004010002020401020203040500020103000400040504
020E114D7F8077896D602A0D0E212D21303D3B322C18191C
101B170B1412090611111921191D183B182A6A8B717F4C0B
010005060101000202020103020300000105030402000400
0104020203010203
040000010201020003020002040308030202010000020000
000102010002010407030004020002020302040203030002
0002020B0F05364C7C807E91866F5E5F2F30180F1E1B0F24
2C32323837362D2A202C282B352413187A6C8A7F3E0C0700
070201010404040006040200000205030405020201020000
0401010002000100
000201040002010000050000020202060201020001020002
040204040402000001040000020000040402000007000404
0B000500040307000C0B2B537A7489747C6872817B73735E
694E443149181B211416253040576E7E7A732A13030B0403
050002050404030200000202000001000304000004000200
0403030100040202
020201000100030002060201000103040005030002000004
070404060002030200020400020000010305030201000008
02060202010504060102050A10070403132D3050546A606D
6F85817E64807C796D6976847C7E74592A09040407040102
000106040000020402050004000001020401000302020503
0401000400010000
020401030403000204000500000202020401020002030400
000100000102020304030203000001000202010402020104
03030303030201040401030002020400040002040105070C
0504080F2633323A4E483229150603050203040202000206
020104020201020401030403040200030200000002020300
0202000001000200
010002010000050200020203000200030000040303040206
020002020204030102040103020000040004020004040100
030207000000020301000002000000040000040302030401
020304050400040405070404020401000302030409000203
040404010404000202010501040304020400040000020102
0000000100040002
040101020202020004000300000002020204000200010400
000004040000040000020000000003020201010405000402
040102040003020106000101000403000400000202040003
040001040100040307030202020103020200010103040301
020203000003000404010200030304020005010503010004
0100020400020000
000302010100060000010305020501020006010303040000
020302000402000104000304020003040500000303000104
000403020200030102010800020100040200040200040005
050200000600020001040200020200010207030002010800
020202040305040001010100000200000202000001000303
0100020204010001
040002000000010404060101000003010001020402000403
010004020104040203000202000202000300000200050301
010002030102020102000001020401020403080200050204
000000010002010003020004040401030204040203000002
040301040001030105020002020404040100000604000000
0202020300000200
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.35119 0.00744048 0.64881 0.30506 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00751202 0.0192308 0.00751202 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
128 string
128 128 8 [128 0 0 128 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFC915FFFFFFFFFFFF6EFFFFFF68FFFFFFFFD8FF
FF6EFF181BFFFF057F8B83FFFFFFFF6597DB368FAC50FF3C
FF0FB8FF2B70FF6CFF38FFFF030AFF46386957B4C5000D33
3BE8501E6D040D20AB0F226C055F7D39292682C52F5B1344
9F646C9B8E2A66127B145A87B291733B2D6E2A48382AAD27
3D6A6A592E17533C
FFFFFFFFFFFFFFC875FF41FF774CFFFFC5EDFFFFFF36EAF8
A9FFFF579449043DEF4C1BA6FFB329743C215B03587E58A2
B6455492D6829354673853682D15423939046D340E563A4B
56A56424553D5B187F32102233243F362813114F015F086A
03300751081B1E1E1A1D04551B38212B190C240F11112808
0D373A070841343A
FFFFFFFFFFFFFFFFFFFFFFFF8EE8FFFFFFFF0BFF76FFADCF
9A9D57E9FFDAFF628BFF33FFFFFFFF4CF8FF787FB1ADB473
CE1C64FF8400FB29B707BACB6348FF79364B5B27690C6C02
53611B0F5124082E1E6E7B002429622B07106E6405701B50
60523F5324137E0C412F30183427150C37142162183E2B6C
250D39121330030A
FFFFFF14F1FFF7FF72FFFFFF2903F122FFFF31FF599AFFFF
18FFFFFFFF080256FF35FF1EC7FFD8604DFF323998205EC8
BEB162EA9F05A04273866B180D7E59507673500E25765A69
CAC8380B814B672083484721191F281C591E03841C570057
1A052147691A04410A4F23751E16141E26197B2E220E0300
041D0A0F04501C1D
FFFFFFFFFFFFFFFFFFFDF1FFFFFF71FFFFFFFFFFFF7877FF
EDFF2D4EFF50FFB771FF2073BEFFEC24B25B31DBF71C19FF
230F8BA3273A3F7C511139420D0302C52E2C427B4B059D0D
BD55171B3D033967335DA221530B69550304542306264811
271D08256B3A40372B974E6F233C471F2B0B123E290D1055
0B420422071B3D42
FFFFFF26CDFFFFFFFFE88FFFFF60FFFFFFFFFFFFFFFFFFFF
54ABFFFFFFFFFFCF238FFFFFFFFFFF59BBFFFF60AE2CFFCF
41AF52D420618C84237D557697D7AE06626D171E4314110D
86181D6C6A0D2F1347121F134B3C490D0755189220040321
1C1A1702A71346432266320428520F2121225B2B203C0F0C
0D085F383606191F
FFFFFFFFFFFFFFFFFF35FFFFFFFF7EFF5E2BFFFFFF65C8FF
FFFFFFFFD20521FF5E3F8FCDC2FFFFBA72F4881BB9A550FF
6F29311D5B0F5CFF093F5C321475EE280C43CA25620F5C10
7A184A2B003B061703074B98532A3E264B3A134C433C8E21
1E251A27362E4C22333C1F5A0628110A07044C07033D240F
1D30062103365F0E
FFFFFFFFFFFFFF24C1FFFFA9FF617AF87BFFFFFFFFFFFF82
5D04FF8DFFB1FFFF0CFF19FF4CDBF0B8FFB2D523D6FF50FF
FF8A40AC0C4CFB9F2D8F7494C4FF371437225B363D335602
428B5C1048313B305E62250E563951052E413C7038023A76
1C3C093240330F143B23204A323C27221A5B1D017B553B24
27212A44612A0729
FFFFFFFFFFFF2CFFFFB8DAFFFFFF453B0EFFFF51284DFFFF
FFFFD0FFFFFF41FF6636C390FFC7A9797D6F9B6A521B926B
101EFF21305311FF883C27169C0C58D1322D3013074F6264
6F461868694C097909580E2110160F3D462431054C1D4B4A
25495B04213E602C2D0C47080F253A79155E3F220F0E4D1F
174315070F234001
FFC1FFFFFFFFFFFFCC9AFFFFFFFF69DAFFFFFFFF7CFFFF3A
FF38FF4DFF8DE2F586FF471B9F3BBDFFFFF3232DAD3B6FC0
FF062023E1447E114D2BFFF78FFF4924016E261E0B6C244F
7F26420520160E4B32AB045B633619491016862701152123
11080D17072A0D00290144130B11573E19043C0A3239400B
1C07170E75013B16
2070FFE1FFFFFF48B31BFFFFFF5CC4FFB15FFFCEFFFFFFFF
FF97FFC21DFF5CD0FFFF11FF37FFE71D2B66C75DFF50D775
8DD7B74B6BFFA11F6715AD03590F8CFF1A305C001D676A8D
61244C3E4A4C798D272A6E5F72135E548B571E0D3DA60361
1C2C682C1B4F103D220E120D0800283A2C5D753C12059A17
66265A2A0F1F2222
FF38FF23E9FFFFFFFFEDFFFF1AFFBCFFFF94FFDEFFFFFF69
FF16ACDEFF2DFFCF16FF29F91809D96B57FF1FFFFF399D0C
5C9C8D96DB790E76657F4D4E2C3D7E16334C712DAC039547
296E316454AC1DB26B061608141A667115894D2A22004226
2D5D174000571E092B281553035B295F18272A460A364606
1A24117141092D00
FFFFFFFFFF71FF48FFFF6BFFD7FFFFFF986DFF45FFFFFFCA
FFFF0AA4D9848CFFFFFF0326FF22DF537FD2D1E9FF141F75
2CFA405606D3FF2413C70D442C874FE83D59130A571D1614
0C04114B0C810D7B697973627367310774670C16513E1516
2210330D2F401505332607140D29045A15203A101C236708
570217392E0C396B
FFFFFFFFA8FF67FFFF720CFFFF4FFAFFFFA2FFFFFFECFF01
FF4CFFFFFF40FFFDDFFF8786BBF63D25456508FF41943221
5C4D2FC1170346762B092146064B234E9B252D04908D89A9
16C43D472E3302481D55404F0D10BE57495847082D533B37
6C56594012131B013F643728052412161118045B15141115
01080B2326701101
FFFFFFFFD1FF3BABD8FFFFFFFF5AFFFF314AFF85FBFF5CFF
FF52FF40FFFF5BC0FF0C99FF31FFFFE498FF55FF9825FF59
516574255449FFB35D5C023A271E171F6054090840733628
645908927266BB01B63A6334151C5745180F851525611B2D
2C432A5C10031800252F3E08163F25208F1D2839061E3C15
094A08030112250B
FF96FF80C8B6FF4DD128FFBEFF106091FF6CFFF8FFFFFFFF
1C76FFFFFFFFBD10FFF171FF55B20604FFFF6B16E8B8FF71
960B5B6A364BB142643B4825510C03484D395B760E292764
0E3C3B81530874104D350D273C311B0E4716403C20627427
6A47442C0A1430783582040A1A0E18003A193C280E0A4815
2119642308E00B3F
D22756FFFF5BFFFF1CFFFF33FFCF05FFFF4AFF3CFF8E4CFF
2DFF71FF7BEF2A8D68878676FFFFFF8B54EBFF87E296BADE
9B1C35A32F316C7645BF597F2CA01701419D502F95935C0C
5E510D42A50B84031718D5243657814652011B4A5F35152D
1E471708200E2C361D0E512C0B340A0093203D203B043441
1D0229344F712352
FF34FFFF5DFF3EFFFFFFFF1DFFFF56D2FFFFFF891A92FFFF
FF5128CEFFFFFFFAD2FFB94DFFFF7576EA51008120FFF519
1B3166565D23ABF76367114710633833143F426572460676
375104262E1B7A197B7301A52B1B5448042246125437433A
2F231D31581C16634D0B4F5F2F1A534F324D2F123A4D0557
4049425510632119
FF10FF08FF42B7FFFFA828BCBAFFFFE4A7FFFF2858A3FF9F
49FF7DCEB52D35FF7DB4FF6D83FFA94CBD0239FFB94C3506
26D31A3C05092412209119782A09312A30103814A038621D
3F533F3F6DCC1E58243F544D0F12727809610C473B2A0D82
214B683E11370710344A1A14220E4C0135042D1971152124
2B383C584CC33418
FFFFFFFFFF1B8DFFFFFFFFFF14FFFF9BFF5621117E12CE0A
9F97FF30FF64D64F0C486BFFFF832BF114FF090AD5CA0CFF
1D36972632770031572D00144F0D6E3F2205793E94346667
0B16651657224D1B35441C0701111B1B3A190E3629380F8B
146315515A3E0E183B5E4360131481300E15106138051454
62000D7D790F0834
FFEBFFDFFFFFFFDAFFD9FFFF4296FFFCFFFFCA70A403FF29
7C84FFFF61FF34DF10FFFFB9FFC974D0E933FFFFC35F34C8
764DA3C878352964102F2018279523248B66378068A35483
1D49144255421C183276228D03252E1337532926460F4B93
1F410C0204310E2D461D09051734151F20082D072A014113
052410380C480F02
FF61FFFFFFFFFFEE0861FFC4FF38FF8BFFA7FF0D1B24FF23
A1DA297885FF0577BCFF95917CFFFF3351778AD604381BFF
B96817ECB880315F683734B83B1B1404017C2054816C0826
2A078E17262B184F2B1D02AC5B557A290B881C33164613EA
1703240F1A6B0E105729740A1A455E5A5A3545520C1E1249
103B4C5E19014505
FFFFA4FFB96421FFFFFFEFFF4FFF3F6F7EFFAEFFFF315EFF
FFE9A579F0073FFF3A799EA9ACE9300A8201EFC8EF579D65
05ED0DB6316D04A13B216F4588234A1BDA4E166C39D64F7F
C1BC3EFF3A056C24980B4F14122304080F0A591A3F4B6903
0E860C102A087D0E00140E19591E5A1A470F38025102621A
210C474D152B1636
FF4827FFFFC5FFFFFFB128FFCD838FFF316C0122F1FFFFFF
5BFF698FB8FFBA2A873CAAD06C12FF1EA7765144FF0F84ED
1B6C424C11BE8752524A81585A0B05997C1C37436F1D2E3B
284835565A707A486C081102D712776F4F3314171A0A4E2A
321140212F4E6551372652231D2544414E4A3835190C205F
2C133D412416710C
19FF33FF494003FFFF4A96FCFFFFFFFFFFFAFF0AFF278F0F
F2FFB45C1AB2183B83F020705DC4FF465843D7B1137E201B
242A900C303D09075552718F0DBF1D6E458F186E0543A804
46121E273B1C1D122538AB08000B3A078711124C01162F4B
0B192816050A65013C0D2B011C0C25330937620649072340
4840376084192C05
FF16FF6F44FFB71644FFD5FFFFFFFF739799FF50B7351A4A
260F8BA760FFFFFF05FF483D277D2DC02F7AFF695362FFB8
FF3006E3A41C4E2D5DFF3F5F07574B85230A4A34FA0C237F
582D774607A354287452128B17435F345D000C1010006559
1D283C0C8607931B2E4E2B0C5733230026332B473C422272
3002042736053F3A
1DFF50FF74FF28FF6C96FFFF70FFA3FFEB67B2FFFF46FF20
AA153B4926C4560B5317A45A00B9BA239710675BA9FF5E21
1DFF2007515B11B02957246D5FBF2681664E0831383D1E02
8C5A0085102E45307C1D7056190D2F0E213F30AF235A0F1B
0433000F160526022D15000A1E0F1A1B245E34141605361C
00772E0581436425
FF3AFF03FFAB58FF15028B794053C2E5015CAE235F57FF73
AD82DF6E8893FFF7C5074D02FFFB0F1BCDCE0AFFFFC319DB
819CCB5A40CFBC341E330795A10A591D816B323C9A02742B
30A485216A27198A410B5D1C47027239090F28661A2B7407
24180F067712040619112507291F4B14522B30213A2B4F22
1A1B1D434B150B20
FF69FFFFFFFFFF192EFFD8FFA5BDFFFF4FABFF1E4CB2FFFF
FF4F4D898F1D06835213C000066337BD220F248F20A62658
450D04A1457E07C0101D386D40503C0986420C854F2D5A76
0D2E0E587902555D098D03032A05321422028680500B6928
3F5604205A26345A883F552B1D360800173D282F453C2625
1D4D523701515E45
FFFFFFFF8A64CDF289FFA298FF15FFC53FDBEDFFFF2CAF96
FF3C20FFABBD47407802EA586762C43F6ACCC9280D31784F
8E89FFDD8938AF6FBCB56334A55C0E204D05613988117A44
836308142281165B5490290C49252F1F6450353B30227A04
40490D0B05235B460323160876261B673019175E241B2143
370318234D3B0A00
2031FF96FF03FFFF60FF28F6823CFFDA62A988A2188F0EBE
693667FF6B55FFFF3A19104E7D7B9E470C1E0B165F386033
66FF4846438705177942C5BA326D60AEA65E0C2000CA2482
768460942F159168235B34385625910738430615211E5C34
0D050B4675271C4E342B0A1161441046A3004B3E0A2A221A
010A46211D073093
FF39FFC1E2FFFFAEFFC6CC9E12FFCBFFFF4D809D6B037E92
AFFBFF9CFF2127A5495B8F612C74313DD36583034697C7D8
34FF5D298324509EEE2E3E6E14139517085C344051297B26
743B43350D071E7B22713A3B6F1413194B6192265B401073
38221A060C4D3539108105000919003C0C103C0A4B1F3A3D
1B103D123A3F2808
25822B5C1BA82443F21DFF12FF06BC00FF4D5755FF2F37A7
8A633C498BE59D29FF70468DFF7C1B060E9EAE1B5811704E
5D3D27169507312D4F15082649110A2101043935150B0037
4F746668263760A90A015B0B295D18077F020F051D6A682A
041F8A1D1D202B3A62010E277911236449003D1774610006
2A3F4C2C4C3F064A
FF0DE0FA69723CFFA084FF0CFFFF24FFBB1450FFF7C08453
45FB225503F35703FB382225E54C7A4013FFC123A50B97ED
25530B4C6947155016C7146863844418652FBC081639181E
250C6E1A8B451D3544067026210902123F3B030122285B52
830B504F51651C1F945D17250A100143281312033237230F
26294E0C301F0024
10926F1311347C92FF6D656ECCD2427118C8226765FFFFE0
FFFF5174118426B81327FCFF07252C04FF1C3B3F0888B15B
2122168F610B59121004352A055A763E545B0ABF270E3D01
3F6A7F78083B3F2F0415285E074A2F1F355A0C8D26161701
72198F42278B3F0B0349124A364C3E32482D753B4F0D7A02
372C430A544E6109
B945254B3A5AC9734A601B313EAB991C55FF53DA1AF97BFF
4544121502E9FFE64931FF816FC2585D7B0A61BED3A80327
2C3C1C8D262A25D73E59748E8B3C1246701D2B4B1B58792B
163552090C0B102B56091A5B49230639341D4E2122102310
2000560F3A1B0C168D2E212A3A20180D300012161C110C02
2F2380152B482F39
FF99FF00B4CB2A55AC11690BBE8D3E553506CC41477F46D5
101520629CFFA8D22319390849798F462124A442939D8038
47250708150A3C56050137591753E1EC142F157E72BA674F
4D62F66B0B01546935480F551A3C2115286B0D59744B2B0E
0B3B236E08707C1A1B3239646A3060085628133A520BD24A
4208221726504B3A
FFFF0CFFBBAB4FF08F986735042AB915FF0EFF8D37B3045D
FF39FFFF873E15ACE41CDDA433505B660C42ADFFD60F2E81
26B1571F55BF3C20544B0B0990072F224032383B26075B1E
690468043B2B2A3F3B5C2D1E211A011020623A2C4B690160
64271035075249182C40205E01124A2D0110311F46080030
140A320511653B47
FF8DFFFF9EFFA7F1982CFF94FF50F9725CFF00C894956AEF
574E2A9EB9FFBB2AFF912343FF403BD4681E660B43FF700F
438C2B5B3C7336381C3A1E6F3B615CFF172A10033A38693A
1F1C00774D0E254A7CA600233152814213383D1D4A053525
3D17320C5A546B47455B2A085210190CD4521223481B4146
3303173F3F110655
9A81C4A4FF7F9BB4108EFF12FF0D625AFFA84FB3B4E19187
8B4C1A7316CD8B1B90CF6CC0AC846955603B122E447670AB
17021071030C1866A6314D2C8B0E38551507C16A379DBE1B
295F1B454A380C55153E2A72B1220C686D42BE4060184807
09010D1128260D03570B3E4E6836123015088004710C2747
0C2A075D21230C00
DD28A09C69CAEB5FE115441D390F060FADADA0732C4781FF
F2FF3F3721679F21484F2D4CDC4FC655102950B93E4F46FF
705B497D42E93B44367C1F034F41175310081F060D54558D
0020450C3154428A1916190D3C3F1041142C38511F363A28
19291B506B0C24661B14730429263A1B6A641B39333E040D
13083D5612083B19
FF0E93FF53FF8F3B02242397180C1AEB50870878F53532FF
7ED231654AFF2B79382B361F11678F20176231A20A342126
1C5B9D0843429B6A46320C0547285E3D66695E93712C1086
4E901C215403100A5E88699A3E001C42263D444201263D1A
18144E032A0000420243282B261811496A297B2707181E7F
003D373A522F0B19
FF75639460BBFFFF8DC9105C1C9B007E76AD7BBA08093E4D
2AF2209A9235450C2C7FDB4CACA54F0E46A7B916749F1058
F56F2A4979171E6C25071218622B33286D33073A700C1186
13082028175A2FB9187122682947A10906090F40302C1329
4D0CA90D69583C3F0C064A0D186D30222C2733360B0B0416
080400010B2A561D
FF60E0981EFF00F415012D0FAD4CADB829F297139C67350D
130178CD63B3FF426266F9290D0D97281B36F18900C33119
27233A1F5A37542159613F0F40196A053401140C1645222A
1D300918AA2F16542003314A5528090D574452014B663802
2C122C3B3E0F217C07290D320A462B225D330C1530141C14
11001744436D2530
BC51B2FFC1F37E22810D053A4A6823072C1E4D2F14D869FF
986E013B30837BA51215C081439E0C1D4574B7DA4C2F3879
CA729014E4A96F71620E8C232A21B6368731304751150E1B
2971703F0F41365D3B44057F4C2E1E266C2F07620D70215D
5A054D1D1C365E2E07610E7B367D0D2516482C2924044154
4A9B2A001F012F48
FF43FF5FCA006771B0B041E22DF11E9234E34B2A01FF7A3F
6793B373755F2C9C1A23165E3EB655270DC6679D2B422767
040E91267416912566815811AE383D513B150D0F0E0E062E
111801122B472446106A17B2214146490487361C044B5940
312554013537037B23041553041541632A494F2E1C47153E
6E1419230E062B1A
700D2B455A4672FFD89CED6CF66CFF1EFF76610D828C0441
1C5476C7B1671A399A383E86B90980B443B2915B0318654F
0212E7122644980336557408296B1C0735186559061A537E
0B3C452901422F245D702037390C1839082B5322401A4D0D
330401224F924E0D1D353C0155240B075338181146651927
409B001B1C2D4535
AF26988574FF3851FF018D57473A90EE52455C02722E0235
0B1A1B07595174579D5F410FFB3AB0B616DB1B27504B4D47
5609491E0B6C5097843E264532173645451031087414042A
1D6635833C423E282423532F1C28A3472B430D27343C2C2A
30191B2A36010F36580F019E202E5718156221004D3B4F34
11034536192A2611
814C070161107E8A2EB20D88DF1B1E502F3B3D0419012635
260BFFFF426449BC1E74147706842C0A593E6E39264D4548
7A50230076424F21229548017C36A47D042516131A041E24
3C430C1F273130094D0B484A573A3A0B40781D2704223B0C
4003121B0810675F0176269C457477066E306E0A260B911C
3616315E25381C11
384B8E322061A7343044BE4DBD3B56B2A718773E6FD5BD85
631B5833902C6542523148FF177D0E3A762D711401724C10
454C2230150C168839025D4757350A1E7B3B2B0B4C102416
2A060833492745004533400E240F8F2A3383162C6542214E
24500420311B1351171F151D095848493B4C0F095C2D0C2A
694829165F0F1719
7A6928923B3D350ED5BAFF9E502D546838015106861E780C
536E9D4AB52CD89586C6B03131116806D74A186C7E096697
14426A411421247261377870E4AD050584161DA5133F1260
2BDB14324C2748432127062106134979212808851F482850
0D67170429451370482D2C1F244F375923561A268A516F4D
1541404613343715
353A5E8C02378C703D3646104B4A1655322918293B524EDD
C27D1C03670C56547FB2E5AE7C6B458619673D529F3C5439
5B581FA865E51F3385632648107F759B44102B4773436F12
29015F324E17833D3C341E2815533F500E04493219273439
354A413239202B13310118942C50083E015128711C0C2325
51294D1E722D340A
FF3847138D8054CD274619044705B7215DCE2DC5522467D2
0DAAA9730995D94A2845036A0D360C0C3A7B904D2458285D
34250F226859540E5F18B1105B061931060C1E23150D592A
13322C2E1A201F221A2020720B305526183D3E234490801B
2A3B012809411A1819A64F4A050A235324184B0134320C36
126D1A2D1507490D
FF97C82E3A0D55AA7586314DCC464A2A1C8F4FC5B812078C
D927050B34103817080A770B082434290606261F250E6B69
2A7FB635397461422E166C021D8C668E5B0B041D4A1B3797
570E10374048075F49214B14135508273B193C1A012D3437
2E1F0E650E024D085D0D230F2D563405665A372D470F3A0A
3011462B19124406
3A2C480A552B431C26664F603E145B7C5CC1B30CE134394F
4A2F14184007C28D01805144284F3CC422363ECC3B053B26
4204695410216B7E4D161834501F692515491B330068070D
44221E1F1D3327002C1F27733112371F04201E150D291B14
013E3307084F39582C50310929282816364B13322923007D
02060E912DA7201C
29AF130D859EFF02F40BFF2CFF7069CDF5FF5FE429D85597
DA324058096440306949664D041B7CA52732597B60212F56
1055210834106F1630316E462FA34D21615D768367381853
690257540D752D33620738112A0223081E4A5062143A122B
003C2E2739372B59554B52300859144248232B761F403C36
14691D1107010F44
FF37FF0CBE98051F6095F45E4A3E705D324FDC2E6B476C2F
D43293091B37A1408A4E29783A3D256C4E2114034388390E
5E60403AD9130E16625D793687021E952B1E021D077F102B
207703053D2C2B1624362E1F2D225B0600323A3D34181E41
3B2342AF6B161D81264502351A1B512D11060B0509350A20
5904198023860D09
24875907BB5707352F183200204FFF92C7A5160A1E020131
C123C0568C249A3904A12E541B5A16081E21384616310314
78340A0BD0093113B8098E6320454A4B5245066DAD03481D
8E1891714C45141C401D172906030E10087A185E0A3A421C
0416010F6F19270A6C0B03042C42522D2340191405100878
0D16050D08882E2C
C8138D02290B1A010E9345AB6338FF6B5E1F87B350513063
61BE2D2E0B341F3F1A4933B08D40A67C0D844A3C593A091D
922F7E140C3546311A62073D145F440A2856316C369F193B
420655090DA67C10323C3B5B1666282E04023E330363085A
6B27106C493A0D06097021223E0D93201C002E08042B5F36
7D45368362083B16
FFA54C84050537433A7113ACAB155F1E350032550D2E1728
68B5531B64476702126F0D460161580A201F083130653803
03419F123A276508100E1A124E1A4A39002B2B365512A507
9234990B152414003F43355B46010D4C34170524250B1F1B
161E1E2F1D045013245410142A1B70241C2051190C7F065A
22701B2D2DC3042C
FF5F58C218175B7A7719CBBF658474844D8409AFFF93447C
5A3AB57ACB7B2F972F740F2725715108434C54032117621F
6F64130721222F3D7830624175060C39322504033D1C3E17
066D532204541B732040253112786302121F0A0D1F60120B
0D030A46364302393816220D000B6A012B00003E22023707
061B124D6E062C1F
89020B4939683D9A5F3E373C1E6D05464D6DAA8E2D7C18A8
07415835AD235515AB2A2D658288593469604F3020242222
5862183D14260948277A08A3025310390345380E19A67446
0F24330A942A05160F3B7C853449074C7413311B371B6103
2D0B5F08421A45061541570D1312833D222B25054B00072E
00092F521C2F3E04
7C9B3AFF954083500C0A32636F1EB9352F4F160A89D614B0
810C257459BF0F4C857C223A683E3711063A7D0332237A48
1D6689421A6B61044105466D5C10270E4388074B3C0D2E53
2EB1412C2A15236C096A581D1F70283D333E240D031D0821
40231F6043263D462F0E35191B181A001454276072540340
4D2955004227611E
FF028B150A415850DE8C8C6B07362E47AA568A9818E9814B
1802B70C09191E0A2F1F4442282F0A061A0DCA3BE23A5810
9318402F0750873F5F1139201A49065E014242273216531C
4024072158370E3F24166E2D203741076202031267540A55
244B87042600043607312534160F224A0006251B16190206
202B04323D2C1A2C
6D4B4D5E41555EB272AC0E82684A7044575D314C2A2F7B24
606920293A2E4C0B205E3D1F0F04077F4B2D2795800F401A
3715209F5A3129305B531D0850201650197D1E4F000D1606
6F3D38316F230721402C7F3E4339416730180A4A248E7730
1B184A0D69000B0407002A4B43125E012F13395D1C203452
053053172C7F4A59
FF3CFF5264C690729E696B4B57244A14151957201F610E12
6364384FB60E6F2E1F343F18209F2E5829408039650F1B1A
34002402269A1F285C8864729CA8865A342943B0094C611B
0559400E5944665B0911302B0116570D1809182332241086
081E1D5B1C515F5E392E17231A3B1A330B2D24365B3D4641
0426280626510229
FFAC51FF086B3D0482411E777BD33AD0096D432D4F4C7D7A
6B637A2E0B7E32040F55043601530A36528004102535191C
460D29500058334C536A190F4A46273F726B30393067722A
524E31131A715E196535BA592337201A008D520851415C0C
1E3E871F18093C05092807770256303451061A2E583C384A
34223304240C6D03
844855122D08FFFFC5871445403A077A49CB93378A694567
2A0E5F6014601A403317144A5F1936410E0A21534F371542
4627258B271E2D690A010206540B3C411F53256A2C0A7A13
0C260A60420C1B812A7220432134341323300D2827112253
0D54170717150E6C13240505184005022204111D56270F20
3C5E58342B29202C
FF785F6C293F1C5C692D75086B01481D3934431310011501
8B0B2E38621165450E4F3FEF2B727C2817545A1D0E3B0523
8707567D30066A183C4E5405488E486E29174C1509124C08
1D522D58162144481E454B8B3A1D1F5E3F0D3E9E5E060A2A
6B58454753333A100B31373A666625194E6F071C1F1D2208
26250E6D05012803
E39073E6527A0A368702E1A08B89295042115F548C044539
585CEF0C1126A2106B065E6E7597160B1D68230019353507
422B9482030D7D9A5F43027E54301D46656506664E035275
3A972D03141B44334E510547050C0CA0375F4F472E666B1C
082C042F041571410502020B6B0B143014223D2B42310434
27782204162F2308
CF19BE153B501F6E13063F295103201C4940837027721638
2344191D52093C6419B21D11027F101E00CE56012D8D2A0D
3A2576647779122B231F165516536A1B17394067453E8128
1E664756381622017029021CA73074318125142D04020F3D
3C142334422521081160140292125D0E13060418182E1C10
050E211629091815
443C0636C3002D475E731B285E2743388C674203450E9B35
359C1942106083940DA613154584390B33A8925108117727
1203511E5A0166633A8426003E045D36196E3C442F3C542E
3F01FF0F325835300A3526A80A355D1A18432D3F5F1C311C
5104070830461B233C221102543A313E018F3E420E1F3018
313E061D23142511
DF2BAD504EAE0C05590C4E8B07A725C60CAE57FF732A7C60
222D236A6D2A6046D0382B09B11F070513223F2C0936827E
0213335D186F3559B31257291D450556283C11022B3E712A
37790C8B0B319D2B73440C212B171D22190F1206180F7636
43122C0D1232070804101F12301B030550112F09160A1F03
410B1E4154130200
5405152E3899748FDC578E2F025D246B1911272A1D3E1A53
1C975614111D0F286B1111299025210F401C3811771A0405
290A182921352D272E6A1E4E17954A0E188E08160D171E1D
46051D8440070D8906722BA23B480D7750221C03275B0712
2123052A7A161422488F41131706735B012B47366D23291C
333C0A0A0509451B
110114378C40FF4CC51E98115722C31CE90D2003E6F9F7E7
5301703B268722683D0803170AA92432060F0E1EBC596B6F
A328252654012B1B4C9A0E1805DF0F556825154E6A025340
262C576308183C6A0D420A26050D0D522240575B0D04A115
322761150B3F080329050D152B0B1B5E070C32502609872A
1F27581908392D2D
CE0B2C39645A404410C048959B3C794626581A5B5C910C17
452A7B4C551F181A2408081A163409620F08076F36080140
9E2A4E3974B5342D62993513010F340A58150B593120403A
1216590C0905390D1F71C4482536243F8C51262913083C0B
35403411163F03321A34222A1D0D146E171A242E61361E5C
190F1552413B0B1E
A50994971376305876888B8655730B1802229B532D271444
4B19204D0C05571922042D33070529A6431918B14D116580
1A47412A0A3B5100202B060E5508440B1B060925141F4901
03434B23527C595B2D735774771501401B1A214507100B1B
13095528632C451919241E343C16164F37380E141D4B0D57
001811251D12032C
3A122A14144F43231A113A5C1A82360B01AD2C0A11085013
457A1C0333A8345E682D2D5B12191862343F14071A121B02
0904269D4D0E4684461F5C2F150979192128784A0005584F
0E17226314790020443D2D0A5E1F23251A241447847B5F04
4B4C18343F6B21340D45283C3A184C0F142017167715173E
1C0C3244100C0A17
9882251B656A22570059447A1C9A192D5B8056142F29145F
1E294E00AA0C903D2D4E6F73350941222A56415960088E58
711B8212455E14A3270F56012418001C26278657123E4519
1D173533410E401A0B011D1313422A1E41233D6835125C57
371705137C203905084714192C1350101002230F150A3332
1537223028342154
932E111B07562845880C4F170A2B7002513D45E0428F3B5B
609B231E3C0BA63C082E1214A421871503221C1C1217422E
102C824C0B34284A0628020D0F2C0D52313A454305084644
0089039173200A18540C284836465D0236081B3C00150F14
593045061B050C26280B1E061F0F015D140E290848262E02
3A1F457C072F1906
250756594F7F17103C77510B002D5072423811C30D5F4066
2D46424B664A574F39030A38397213361637291C37380841
2A45373228685A2B0430194008422B0D66236F3548093218
522E4224471840313A1E56623E0C2147226D69005D87711E
5D27032D032C0914051B42131A3E2F0A22614B2F1D0D5D1D
2237181600450024
083F15700C13813B0B1B3ABD0498556A56224F2747147743
041235514D26160E3E1D3D46AA453C513886520A367C324E
2741352368470E8C412822434101200A442473034E2B512D
5662002E12AC2958062C0634505E13050F0E6252152C2234
43004E48031B321B320A3E2B1403541218283A2E21055122
493E3D3B11810448
0734483071202419320C26137D3448347609101131534A86
1C4D7E2D0103A7810046310F78184F680A02081C1A121520
133E7613301B370823381E126806343C28106740291C8F28
16015D9C3940446C2859341022605F4D3A232A420224413B
382E1A220725221E4D0E194C321B09453A0B0C2D5E090F0B
4C120C442B3B0326
6D26752AB338117257582A01215D3996346C813C4019161B
4A1D07452439654F0F031F8F192C3E23104B884159396108
745C113A03121521315C2241074A0A8C27161C612048041B
0C5F0F21530E2503511F05420B7C4E115420053A689C3F20
5F70202E0B17054640042B242E03402F130B423947314C30
24390C461F3E2154
FB0136369F57C3467217032C2CCB4BAB16272833522AA54C
671612101808261D41324024B95B0D26236745453F2C1041
2B37011A250B4C55160124122813580E002D29420D46596F
18A809132F961E27314A3D6537496B42A165281067151B23
0D080F150102060A3C38233220241C0C0E3B650B0D072106
0220071F182723B7
FF14920662502B1A132765720841055232A887995F230433
0B5F2595013B3F07364A1C311045102D092862030A013B20
1A69152D140420533E3F09434B260B08270A4705295B5124
413722642B853812118D424001365C083402201D15386B0D
393F5214222230101341400E0E200B0C2633402A0634212E
0B280E22590A3409
150573085B188B304E8852858F4D4F196F637F4E5D1F2352
81704F4E253D24073B2E3E242F326262281829405B0B1F11
410F0A0810041D90180E503407112A222C380C3925340051
2354048A7B1780324A205D603C9C10030420211669035E2D
464312214A03345B0216262C2A1A1B6C681A0285622D102D
142912272B3B4133
7C3B36751C47510382854C4F410168184401473F1A3C1614
2A542B1F04240E08680D61111C331B68A05312492848181E
1756213C0D0D792F49742A334270733203100D35093E5C35
42155567020A271D1B1535051434321F4E326E2F1924171D
02066104040E521B190C800B0B0A331A130B1C3857211B63
1D79252919441014
956A519B1E740819290D2944243200AA146C4A4904385B39
1B400D162820190D3E09191C180455192E473A000D46271E
0A0A392E31680D3E5F35212102092422310312155F111703
2A4C3B1D211C10244A1241584A765700392E1E1A5712260C
0C413A191006235438060361171E0B391533040033131E1D
1D0B0001220B3003
070D1814454B0A612DB0088E24137703071C443E3F251C44
6C2C96131D18311E523B0A3D46053535315209022A31252F
48885B3402695A524134141135463015580C100F3B23332D
1C6333371740164D181323162844480E4D3C3B71043C3E82
403129500C371A25040541431523475A3F0E3C0F15010930
0C30003B2B40501F
BD16B9862B4C633F075F53004413210575671C34193E5339
1E0C042B1D404B2D125A536B2668427D0A0410382824171C
8135242D2F3243588E3A5A180D0C2E040765200110741B08
106B312A1955200C294A0712961A09141A3757270B382A13
031A0A04450812502A0D1D3F3A4316020C41203A1112023D
070D2C3E110B03BA
439429D322231C142C041E2840459E76142D126B0C674327
0381067553174E1C3C1D0C014910600D1F1133062438210C
2C1012262911110C281A2D1E4D415013140C020F370A5701
0B1C130D17640F860209060A3418121C1D0D640E1D232F2B
04551A0F1E4A1965220E5B0A2E5307123E0D002715320703
3F0323117C1B1A4C
EE1968642300242E1A441B21112F444D4742430A892B5D13
6C4F8700021C22101E4C141E555253522D66252718031C31
09086B191D3B370F3D0E21363C3B28336B190F040E371A36
0F383B4B25494223032B506564313015106862396B043E5B
5A030F951F1905392B0B1C16100E0D130F0B0C0D105C212A
26150A1B11201E1F
52222F5E5337CB4783611A381006802506051E0820102700
36187951863E19181C06430C16081F296037041407171E56
0B0603002B063347150A1F464F012C0B3D7A65383541642B
32310F232B231D4B194A051C613D8C540331200E583E0C0C
510E1C133F2434000C0119161B160C073027134825593547
1B14041C4102475E
14210C4C129C0B174E0C2334371A173C2F61192D0557218B
153706464C27080D03603A3A2F0F26690E4018122112014C
621B3A06242A070326180B1C30211E560D00201235393020
35141C5A6102072A541D610F27072D272F3A590C14480C1C
4B282A68160B4C330D09492A4012235E182E23261B380D0A
2246471A1C061135
2504363410230721293552383105043E144736610D231A1F
281B172A113B271803590A52115528274A2741161F08210E
060B382B080F380849341C231F28214C01425F4A14151909
1E1C11092F0A502D3337671560251E4C1511255025081742
2C302E1F60035D1B221E520B021C0702210008133850027B
1021143715342328
574A10523B277531883F4A185D130A361C4E421A20132703
4B182D05822B520514513E331A040D0B404B5D2A040A4728
1725333A0E161D42260816242614152C3418350C415C0F41
2F0207451A4746100E4428030E372F2B433013402B0A2E3A
0E1B81563212033C250B2B3923243007502B0E0900483D1D
1E0530200B1D5725
D53474185C3E163C4B7A2D2666250C26223D399E0616474B
060806440E3E1843326121121A242A4A1535530985630564
2117062307410D0495182F491B0F0F022D02280E731B0E1C
1447270E38250C0144380A172D2C180B3A30132C1E006F04
64080D682C192D6C33421B1412273A5920230E1900262B03
123236470F115607
FF4D495F1121284008272E1B1D42025B071A28265406291C
2143421808724E0A654B6027212531370E451F382E41321C
043F150219301C391370372D664719156640014F5A300E29
6F21134101220C1D541822380210082F2D4D2F4E623D2A6D
013C1D2B1B140E0A340D1A10162A0605010D2B05230E390E
080545001C082535
F9186003480F661F56005E595554500A101E12540B4C343E
7E6B4D04180432820D335E5E0D1C2D27002C442697A14622
090A010D173B3D0E15414E10141C3C13070A0C0136443F16
308210522E0B1217291C02073113213C10441B201B423D20
2A0E17660E20332E240A2F420C270C011A152A1D0E1D2D1A
2C052A211F027005
3D013C002029542A925D1537300C23172D133B1F140C212C
3E415B001B2B233204171509310F3D151404412936000028
3D2F10121E38171A1F06340A05100318201911254D033C01
2B2B121F03634514145B580F1717362408833F3F02354D27
0544521529063A6D48333A0407364E143422110F2A220832
270019290B2A5110
411420440318197965885C53144F118F2C630D4123510B19
13313A1750871E183A260A0E00011B1F1A4B5B0C55921948
A81D4C010904111C2B644C6A67191C4E820E072C380D5608
4F10161207712819083F17431C407C21251E330529181E17
05252E320D0B132D481B0246580C3B1F2C2B15092E0B0E3A
1211710604190E17
6B2A344F34352A1A5C38B66521C338D01A3D0B31080F0284
29455A073B08033D0B4010131B2EAF174B463C1A0F32102C
1B161A18311F330B5F242449162C753932182411173D1E33
2C432F177A0D101471253C1A15080122132E2D107B0D2B46
1A501A1426073A481E03272B0D2648022307183B28051018
2F3B3F13090C432C
AA274E200518418B2C531D09880754131050561D09060626
3C0E384D2779394E266A0606355518273D014B012B2A010B
014E0A68000E067124320D031727306900445F27203F3703
563B352640070C1D0D133837470C4D2B254F2624422C2866
24002079282744291F257C0E1E0C01481519164C2258271F
313002222732692A
B7094D2258123B181B1D09445A0C1622960A4C7640018435
1B020006221231670B60360A4D373D2F23753712283C3A2A
3D21413829260B2B161926210102140F59063914424A027F
1622206C613C23011E4B191A0D0D63497B2F2D31003A032A
3308057A36263C440B0005110C3E5C3C0119350D39470C0B
1F190B380A800C07
9C96642C0F4607101B394848294E0C591E1C064030085946
122C1D3F48080D1C3872111E352826368730402E271E0250
270B2C331D16072A140A03351E19580F15151C232D16140B
05163F3218205225212C251C0952131233091A0318281063
193F20390130107334081D06230E4221045C485612123F07
4704150E3D132D3B
6E27084294132B1023240E3B08632891657338270418130E
20152B43501918271507833246427011853B1B276B201B0C
65260D5C2564100E0028002C0B130806090F3E331F4A0F51
620B2120100136021F31432B294F5C0B302D050A252D1E36
1D432D021B282A1E0938332332043504262009283003040E
3C0C0F033B4E3004
306214081410133D2C3D26292B7D0525871A671D161B283F
1F24684B3A3745225D22768232137352473E5316013D1502
261C14310217480A190C431C100737211509313E0C27313B
66250D440D23290F11000B011E162A1D0113121138701035
2F12201536120856351E2E28316017093746232247052A0A
230119151E2C4459
D94933342E1137181234100912283A3730154648180C620B
08070A141D0F29211C8B2E350A6117570D0F011D3A275933
6D0B260600144333314021473226260E693C430726682F59
523B1B16381020110054001C170E18374B3C19073E0A0209
06202F220235221759223A42022E080F1A09160430260208
285806192D4C1205
6917074B022F0447371A2E532745482F556121053E092E25
1940103D1C0D0C4A2E3C2433471131423805231718300C29
07493C371D8E3E2A0962761094170F11201C0C362A110D1D
004325021928221E232A0569633F0B292A0F0624211C301E
09313DA92E186C19304718430031420628153B14054A2423
0E620B28137E2B27
284D73082C02594F100B2B3B047530130004451C0A036060
50501C263C1D211618205D0F4D810584693554044711353E
2C6E230E7435476A045A2C552B20105944163C0C1355110C
321E022E400609162E02171E3A583017051D252E390F0858
2A142617010F31573D17471307223C100342373C0B260D0F
10300C020614392C
661E1C2D1482061C4E2A586821482C04552817551630320E
05122C1D334416110404222F0B082D2F040B2E0312218A08
5B07421B0C204A30602F45260316293F5307193A06381712
51180F07232E23031F3212254E560108271F29170B102D04
300A372D4E320D0D39493F356042240B023A3100032E364D
29253D1E22212944
B33614383B4604242E161C75337D97088A06593C324D2601
5B2727200715302E0D230B485332245B0E071F100D135F37
312D451B2D1E9BA72E2E459E390123571C3E3B25120C0920
11010506123B2D19163F2E1E2121071816163A0B26140D22
431816411E2D16453A1E062D2746164938231B0C42451224
14162302233E0419
6F5A311C2971401902211D2B830011201F40333D200E4E24
4F021715121167215D070A155E6C2B01436B601253450E1E
13620C110735290E074D2A781A174509282C3117051D1811
2A0B1F53155C1427062F18383B122403172822211C1B1B21
19480B210C0F090A482D5F001202242A290E623D15263147
220E190550042126
6A0A3316332754263828293C1B251C4E02263A45801D540D
1B2D0E0E0C131913295A02220E51290A08456B324B190E52
04061B251B744A3511C1343D1A2015060D37002049362E08
2830321825592A2C3A7E291F2C2F090A32622F0A3E53123C
0B190212052D004B1B0523110233223C400B4822100F3D32
2E36680309121150
09210B2C218307480B2323261D0F3111092818290104352B
2C071423060F44411F1728136E4045119099634B8D02101C
3C3A1C1329202234021B0C16340D07062911081E3C3B210B
160A0F091A1C1933150A343434100D1717031A2204170504
1D243F012A254536051C62184B0426111F090001452D033B
236009270A680D0C
433E2C8B51435706061504362C4E020F102030193D3F253F
282510072A30130F2B0A2716082B1308541B471C07582C15
734C4839086039232F4E1510153635242A4A18568E30070D
3343240E2E2306291C2620172C0C2E455319161F350C3103
310B6A5C04105C4071351E2804043B115F310B0D6E463711
0334320300340F2D
BB10601C1826AB05890E171D3A7712521F2B77328C10754F
2F1A440F4B673C4A40262F201A1E04043481085757550500
29734711001E415E1020013C3370232814330C21130B1839
060104152F102E4C3A491D532A1C35482B1E763F1A304315
0E1D1B0C09203211381C511300224A0D207D1B6423352765
0D29262C18011E19
9D0F27096718A144530C7131631E034A0E2054290C0B1016
112C00141752013D0F322B050E1E3B1848042E080A021C63
0B5C121F0E032D0F4B01020D2B110517363F5B5163382F0F
072E581C270C29055A360D4C1506271E350C061B29042D0E
5A0617022B2C181C2A2D4F5223031333365536382D288B1B
2C476B480400502F
DF052B79198B8E2A0C4481470553171A310E3E171F792376
08111759060C321427280D1B1C1428172B292D1D834B3119
50520A38135D650D02392A0F3F404616340E412126443100
0B0E17132148034B43460E00221D011F03233D2E0F004F2E
142F45504021182A0821071E130E20671801074A3E150801
1E00131E0C1B271D
38590E760A1B3E4A80506D05180D2A10082C112924590D5F
256A264B0B0C653F9429652101151D1229091D1713197A03
442823242F4C0D5858443D5E172B0434053E19482321061E
281C1639193F08365B110E114C28173949203322262C003A
2F23351405060B0D230A1B050B0B1A0C00230C272901253C
13421E08184C4C0B
6106642B0C17765023280A29121913381B7A41654F183601
0967234A013A043900210B170A470247130C081508181A3C
3443032E5443020F00231E42320E0E20370C022002494423
281F0A3A2A410317155140180D011F002901551D1B0A4B1F
1C282319201E25045418030027074B411C0E270B4F207D27
1B10133D330D421A
8A21143A36471609466E33880A41471123410E7C011C252C
07591C642041111B641E2804181D21474A06372A1D210A0E
615D18237B17222E441636255B24230F500E0C0330170602
093F0C3B00255618180230121B07240419072816033E1F30
641D0415132E100F343155364C2A24122D2C0B033F3B250E
0C23581A12164433
81A81CAF270B3409771E14110714130A0C39091921300711
0C281D2D190809520A320C121A071D4248147E0E52305513
642C4F220C1E6E48202F333C2F01312A2C0958162A6D744F
3A1746250B2B531409476A422520145317434F0716358357
421B6456245D351C302159054F4C232402270E352D1F540D
16563A1E15584429
C615A827500D2B052B1307492B2045721408320503122B03
0866012942577F389F282A06340426231314146F3A06872B
01194904035A004926460E57291603391C1D65024D460225
244403050F0F32134C183A3F0127193D431B350B14244E0D
106904360D0C9206452B09361B100E370C1C084B18035846
040A310718255019
5B8D263F24681D3832022C0B0F1442022C5A1C073B2B3C8E
23241414031A27472C3E1F013228220724085C184E391414
1A484C6F2D16504224051310762A424216204D05154C0C23
063E0D0E432B2E4F1A3B1D3E2D0B2021161A23381C001D03
0F0C2C41320C3A3264230524293124461508414940130025
1A20441C281B8902
6D1446101666010E2149327403450922130F41244B490871
1837155F1A1A370C5B5E392E25426A6214282F201B0A1F50
030A0A2248030756260E0F13101109114B1536283A284329
211B343209231300611156231D0E4C22651823133906182D
0102471F472C061607052E4521100D3A0A09073A451D7D0E
0D30790A062F8710
4B2F160A562A212F3352890B7D1A4329781E470F0F20167E
00150D51122B01701C0B47130B624F5E021B8E4C0026A205
010B46642F25455F091C120734190E09320217434B8E3080
09194C3F120C1A235214640D05120A35104D2D2847471D41
1C33505B06142A2A0629000731500404380500360D021853
22181A1D0F50634A
pop
P
% End of image
1 0 0 r
.5 Mabswid
.02674 .02674 m
.02674 .5 L
.5 .5 L
.5 .02674 L
.02674 .02674 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.678571 0.00744048 0.97619 0.30506 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00751202 0.0192308 0.00751202 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
128 string
128 128 8 [128 0 0 128 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19181819191716181A1A19191919181A1C1B181516191917
1414151716171A1C1B18191B1C1A19191918181919171617
1A1917161717151515141213161717161819181718181819
191917171A1C1B181616161516181817181919181616181A
1A191817191B1A171516191A1A171718191816161A1B1916
1718181718191917
171616181919181717181919191818191919181819191919
1919181818181716171A1A171516191A1917171819191917
161718191A1B1B1B1C1D1D1B1A1A1B1B1A19181717181A19
161415171718191A1A1A1918161617191A19181717171716
1617171716171A1C1C1A18181818181818171718191A1919
1818191918171718
171616171919181616181918181818171718191A1A1A1919
1A1A1A19191917161719191614171A1A1817171818191A18
1617191A1A1B1D1D1D1D1E1D1A1A1B1C1B19181717181918
151516171616181919191A1A1817181A1918171718171615
151618181616191D1D1A1817171818181717181918191A1B
1A18191A19161617
1A18171819181616181918171718181617191A1818191A17
1516181918181A1B191717191B1B1A181717181918181718
191A19171517191916131315161616171919181818181717
1819191818191917151517181A1A1A181616171817171718
181819191918181716161819191818171717181918191B1D
1B19181919181616
1B1A19191917161719191817181919181819191617191A17
141418191817191B191616191B1A18171717171818181717
191918161415161614111113141514141517181818171718
191919191919181615151618191B1A181616181816161819
19181718191917151415171818181717171718191818191B
1B19171719191715
191A1A1918181919181818181819191918171717181A1A19
181919191918161517191A181516181818171616181A1A17
16161717171819191A1C1C1B191919181516181816171A1A
1714171A191716181A1A19181717191B1A19171717171718
171616171817171819181716161718171717191A19171719
1A19181818171717
17191A1818191B1A1817181818181818181718191A191819
1A1A191819191716191C1B181617191918181717181A1B19
1717181818191A1B1C1E201F1C1B1B1B1918181816181B1B
17151619191717191A1B1A191716181B1C1B181717181918
17161718181718191A191716161718181718191A18171718
18191A1A17151619
1618181818191B1A18171819181716161819191817171716
1515171818181B1D1C1817191C1C19171718181818181919
1A1A19171616171816141416171616181A1A191717171819
1A191818191A19171617171818171717191A191717191B1B
191818191A19181615161819191818181818181919181818
18191A1A18161719
181717171919191817171819191716161819181514161816
1314171817171A1C191413181C1A17151617171718181818
181818171615161614110F10131414151819181616161717
18191817181A1A1816161718191816161718191817181A1B
1A181818191817151416191A1A1918181817171819191818
1819191818181919
1917171819191817161718191817181919171616181A1A19
1919191919181615151717161616171718171616171A1A17
151517191A19191A1B1C1A19181919181818171515181A18
161618181617191A1A191A1A181717191817171919181817
17171717171617191A1A1918181818181817171819181717
1818171717181919
1918181919181717181818181718191A1916171B1E1C191A
1C1C19181B1B1814171C1C1816191B1B1919181818191A19
1717191A1A1A1B1D1F2020201F1D1C1B1B1A1817181A1B19
18191A191717191A1A1A1A1917171A1C1B1818191A181716
17181A191817181A1C1B1918171718181717171818181818
1818171717171819
19191A1A181616191B1A1716171818181818191B1B191716
18181717191B1A1A1A1A1A1A1B1D1C1917181B1A18161719
1B1B191816161718171415181A1918191A1817181A191618
1D1F1C18181A19161415161718191A191919191818181818
191B1C1B1A1A191716171A1A181616171818171717181819
1918181818181717
19191A1A1817171A1B191716181817171819181615151515
151516171616171817151416191917151416191A17141415
1718181716151413110E0D0F111314151513141718161417
1B1B18161719181513131416181917161718181616171819
191A1919191A18151416191A181616171818171717171818
1918171718191816
181818181919191817161718191918181817171616161719
191919191815121215161615141414151717171717181715
141517191A1A1817181B1B19171819181514161716171818
15131416161516191A181718191716171918171717171717
1817161516171718191A1817171718181818181818171617
1819171617191817
161617181A1A191715161819191919191817191D1E1C1A1B
1C1B1A1B1C1A16161B1E1E1B19191A1C1D1C1917191C1C1A
191A1B1B1C1D1D1D1F242625221F1E1C1B1C1C1B1A1B1C19
1515181A1816191D1E1C19191919191B1B1918191A191716
18181817171718191A1B1917171819191919191919181617
1819181617181919
1616181A1A191817171717171819191918191B1C1C1A1817
1616171A1C1C1C1D1E1D1C1D1D1C1B1B1D1C1A181919191B
1D1D1B1816181B1B181515181A1917181A1C1B1B1A191818
1B1D1C1B1A1A1A1A19181616181919181819191818181818
191B1C1B1B1A1A1816171A1B1A1717191A19181819181818
1919181716181919
1717191A1A1817171817161618181717181916100E111413
1112151615141615120F1012131212121314151514131213
14131313131313110D060204090E101110101112110F1116
1A1916151717151414141313151513111216161413151718
18191B1B1A1A1A181615191B1B1817181918171717181818
1918171617181919
181817181918181717171718181816161717130F1014181A
1A1918161412100E0E1011110F0F12141413131415161513
11101114171816151618191615161815110F111211121618
15101014151413161A1A1716171513121416161514151616
161717171617191B1B191818191A18171617181716171819
171616171819191A
1918171819191919191A1B1B1918191816192430342F2B2B
2B251E1F2527282B3235343131312F2E2E2C2723252A2B2B
2E312B221E242D3236404C4F433026272E3131323431291F
1A1C20242627292B2D2D2925232526252322232322201D1A
181818171717191B1D1C1A181819191716191B1917181B1B
1714171B1C1A191B
191B1B1B1A1B1B1B1C1E201D1B1D1F1A152345646855433C
362A242B3B4A57656D6B65666A66595355554C434347484D
5D6B6140272F4B5A56546270613F2B395462646A6E5F3E27
2B3A41424853554E4A4B463A343B45443B36383A39373026
1D1A1C1E1D1B1B1918191C1E1B1716191B1D1D1A181B2020
1A15191F201C1A1B
181F211D1B1F211D1B1F211D1C23261C17306085856C5140
352C29304059758A8F888487877B6B656C71695D5757555B
74939366363358706149495852382C42667C8894977D4E30
354B565A6676786C6467624D3B42575E5246454B4E4C4534
20181C211F1B1C1C18161C211E16151C211F1C1A1B1D2223
1E18191F211D1A1B
1720221C1C2528201A1E1F1B1C26271C1C3A69878670533A
3033322A2B456B848A8989867A6B605F68726F5F514E4E53
6B94A47F442F4C685C3B2B31373537475E768A9998825E3F
384555606A7579726A6E6D5638344F665F4A444E57574E3D
2719191D1B181D221E17181E1D171920221D1A1D1E1D1E21
1F1B191C1D1B1A1C
171C1D191D272A231E1F1D181B23221A2141698083745739
3038382313244E728389887D6D615A565B6666543D37404E
6585957944283853533C2A2B3741454750657F8D8B817059
4747555E5D5C5F5C55575F5537283F60634C3E48585B5144
34251C19191B20231F19181A1A1A1E221F1A1B21211C1A1D
1F1C1A1B1A181A1E
18191A1A1E24252323231D171B22201922446B8389806A4B
383635230D143E718F92887E79746858535B5F4F372D3B56
70837F5F3521314A4F4032333D43403B425B7B8E8F877E73
6863635F544A453E3639484F41303A57655641435560594B
3F33241A1A21231E19191C1C1A1B1F201C1A1E23211D1B1D
1D1B1A1A1A191B1E
191C1D1D1E201F1E21241F191C2625191C3F6E8C928D8167
4735322A19183B708F8C7E7C8485755E51535A5848383C57
7987744A241D344E52402C26292C2B2B36537C9BA0928582
8078695B4F443B322B2D3C4C4F43405369654F4555696753
4135281C181F231F191A1E1F1C1B1C1C1C1D20211F1D1E1F
1E1B191A1C1C1C1C
1A20221F1E1F1D171921221C1E2A2A1A15356B9098958D76
55403C3727233C61726C67707B7D7464534C55635E45374B
72867446211B34525B482D1D1E262B2C344C7499A79C8B80
7765524643413D3835353E4D564E455069715E4D566D735E
4434281B13162025221F1E1E1E1C1C1C1D1F1F1E1C1B1D1F
201D1A191C1E1D1A
1B20232020221F17171F231E1F282919112C5F8B9D9B8B70
574F50463332495D5B525A6D77787974614E536765483447
71897A522918294E655E4B4650565048464D60809EA6967A
5F442D27323F433F3C3F46515852474C63756A55546A796D
533F302114131E2626211F1F1F1F1F201F1E1F1F1C19191E
22221D1A1B1D1D1A
1A1E20212325221D1C21231F1E23241B14254D7B9BA18B66
4E4F5750444D6B7A6D5D667B898F959175575464634B415C
84988C6737171E45656A6F879F9678635C524D6595B0A17D
5E4023182B444A403D4752585C594E4C5E7470584F647D7F
6B55412D1D1A1E201D1E22221F1E2122201F21221E18181E
2324211D1B1B1C1D
191C1F21252726211F2223201E20231F191D355E889D906C
4B3F42495775949C8B7A7C8A9AA9B2A47D585361665C5B71
92AAA884481B1C3E575C6C93AC9B745E594C435C91B2A78A
745D3C2730464D464957616162625B555E6D6C584F627F89
7C654D36241E1E1C191B21221F1B1C1E202225231E1A1C21
232121201D1A1B1E
1A1D20202326251E1B1F23221F2024231B172546708E937C
563121376A9CAC9D8985888B93A6B19D704E4F647370676C
88AEBD99541F1B3546454959645A4942413F425D89A9AB98
85745F46373946535D636462626668645E5D5D5B5A647887
826D5138251B1A1E201D1B1C1E1B18191E2425211D1E2224
211E1F201D19191C
1E1F1F1F2022201C1A1D2222202023231E1C2B496A848F85
5D270E3585BAB08775818C8888959C87614B536C7B74605C
7AA8B7914E1F182C40433623191D272F353C4555749DB3A4
857673613F2C3B545B5451565C646E6E5D4B4F626C696C7E
887A5D432E1E171D25221A181E1F1A181D23211E1E232523
2120201E1A18191A
211F1E21201D1B1E21201F21212022262C3446617B8D9482
4E17155AB1CEAA7F798A928E8F948F7C68606773776A5A5F
82A19A6B381B192A45544627141B2C38404746466094BBB1
8B75776F523C3F4741373E4F5A626F7260494D68776D6678
908F765B452F1B172026211C1F22201D1F211F1D2125231F
2024231C181A1B1B
201F2124211B1D2425201D21232126384D5A627491ABAA7B
30063093DAD19F8693A09B959B9C8E7D7A7C7B76716A6774
8E997E4D281C2231485A5947383A444C4E4B43405688B7BF
A28073737066594A3C3A4A5D64646C756E5A556575726A78
939B8A715B4123141B2727201F22221F2022211F21221D19
1F27251C191D2120
1C1F2424201D2125211A1C23232030587D82747AA4CEC070
1A0A54B5DCBC908B9FA79B93999A8D808187857E7978787D
888C795332262B35414F575248464E524D4744475476A6C5
B98F706F7E837B6F68687179756968767C6D5B5E7078757B
8C948976644A2A171C26241C1D22211D1E23221E1D1E1A16
1C25251D1A1F2321
1A1D21211F1E21221D191E231F1C3570A2A48889B9DEB85A
192D76ADB1998A8E9799948F90928D837E848E928B817A79
7E848270543C2F2F3948514C403C424746464C50526592BB
BE9A74686F7C8892948F8B877D6E6B7880725C5A6C7C7F7E
7F82817F71522D1A1C211C171D24211B1D21201A1B1F1E1A
1C22241F1C1E201F
1C1A1B1E1F1E1C1D202222201A1B346BA1B2A5A7C2C99242
28568C97858395A0989192949394938C848DA1A7937B7681
8A8886877E623E2D38515E5440343339404A514F4D5D84AB
B9A581645B65757F8182807A71717B837E6E605B64768580
706F88A09465351E1A19181C2325211F1F1E1B1B1F232422
212222211E1C1C1D
1F1C1A1C21201A1A242C261B1A22304A77A5BBB7A9906742
4670928F8390ADB7A99C9A9A999A9B9594A3B4A98772819C
A18F8593A3976B413E5B7166493634373B42484849587BA2
B9B08D685A5E59463F546863596B8B9482736E6458658283
656094CABE7D442E231616232A221E22231C192026252528
27211F21211E1C1F
2224211D2026221A1F2A281C1E2B2B264486B6A873505060
73848F96A1B5C2BCAFA7A299959898929AB0B79A767797AE
A6928D9FBBC6A66A45516E6B4B394042362E39464951719F
BCB693726766532F213F605D4E618B99867D857957517282
685C91D2CF8E5846371E15232C21191F241E1B2329252226
27201C1F24221F20
242A271D1F2A2A1C182228222129271F3673A18F522F487C
9E9F939BBAD4D0B5A3A4A49B9596928990A7AC907785A3A9
9A939DACC0D6CC904C3B5865503D454A372734484B496293
B8B79C7C6C6A66584B5364665D6277817B819797704E5977
796C7FADBF9E7056452C191C27241A191F201E2025252120
21201D1E2325211B
2427241D1D26291F181F28261F2130455E7E978E60373E75
AAB4A3A1BDD7D0B29D9DA4A5A4A2988C8C999E938B94A09C
9195A4AFB8C9CB9F57314667654A3C403D3336454A46527C
ABC0B08C6B61748A8770616A767265616A7E9AAA96684E62
8183737EA2AE8D604639281B1D2521181920211E2228251E
1D22221F23262014
2222201C1B1F23201C2129241925538497979DA0834C3251
8AAAAEAFBAC0BBB1A7A1A2ABB3AEA299979592949DA39F96
91959FABB5BFBA975F3A476D775938313837343B44424668
A2CBCAA4755A6688957B5D637D826C606D7F8FA1A9906356
7185756A89B0A97750433823171D241F1A1E242324272721
1F21222122252017
1F232119171D221D1921261C16387CAFB2A0A1AA925A3034
567C9CB4B9AB9EA1A9A7A2A6ADA9A2A2A2948489A1AFA494
9198A0ADC2CBB3805448566565594A3C302A2F393B374066
9ECBD6BC8B5D4D6077776661717F807E81807B849CA68B66
6072786E7597AE9A6E4F41311D161E241F1C222928232225
231E1D2023222222
202724171420251C171F2216184688AAA2959CA592653E2C
30446995B0AD9C96A1ABAAA4A0A0A2A49F8E7E86A1AF9F8D
96AAB0B5CEDDB361364D69573B496A6439253745362A3F6E
9ABDD1C79B66494A5B6D75716B7180877E6E676D7F969D87
6B6877786B7194A991664E44321C1823251C1B2528201E23
241D1A1F2220232A
22272419172126211E2221171C406F898A8A96A39C7B5131
2324365E93B8BBADAAB6BBAEA1A5ADAA9A8C8B99A8A5928E
A7C0BEB8CCD9A3441C497455253875825536455038253F71
98B4CAC6A0725952525E76857B6A625E524C5663656C8190
8777798174637196A48C6D5C4B301C1D241F161821231F1F
2425211E1F212324
2222201D1D2125262626241D1C2E53798B8D94A6AF966135
26272A3A67A4CBD0C8C7C6B8A9AAB4B2A2969EACAC9B909B
B2BEBCBBC3B67B2F16406B5D302C597A684740473E2E3C6C
9EBCC8C5AB8565554E516681876C442A2633485651454D6D
858580888A766881ADB6956E594528161B231B121A26241F
26302A1C1B242217
2021211F1F2326252325271E1524568DA49990A2B7A8713C
2F40493E3C62A0CBD2C8C1B8A89EA5AEABA1A0A29F999BA2
A4ABC0D1BD8448241E345460472A365D65422835463D3A65
A5C6C5C4C09C6545474F5361736A442628373F4140362E3D
5E7578808E8C7E88AFC2A3745D5133131222231617232622
2A342B1919252212
2126241D1D272A221C2427190D2769A6B69F8B97B4B78A4E
39546A5125255C95ABACB1B3A59597A4A79B8F8B8E979E9C
99B3E0EAAE552420262E49675C373153613E21365247385E
A1C2BEC2CCAF6C3F4351483E4B5C584C4C4C40363A3D322C
3B50585D6F85909398998A786D5C38160F1D231B19202425
292E251819232218
2729251C1D272B24222A28160C2A69A1AF9B8794B9CBA769
495869532C24415F70839CABA7A3A9ADA290888B92989A9F
B6E2FEDC83341C232833587D7751435A685545505B493754
90B7BBBDC6B88654454A4638374A5E6562594D434245423A
363736333F5E7C7C635261828C6F401F171A1A1A1D222525
2625211D1D20211F
2A252120232626272C2F291C16295583978B8096C1D6B984
60575147454E5249485E7B8B94A9C1C3AB9494A3AAA5A6BC
E2F9DF974A25262B27366797966B49516E7B756A5B45384D
83B4C2BBBABCA36F443F4D4F44404C595E60615B4D434243
40382F2524344C4D32224483A58B542C201C18171D242624
2222232222222120
26201E2327252221222325231F26456D7C6F6B8AB7C8B494
7A624C45515D5440363E4A505C7DA6BAB1A09DA8B0B1BCD1
DABF844623202E302328599AAA753A3C7092856653474053
8ABDC8BBB9BFA76E41425C67574645516271776C553E353A
434744392C272D312820366FA2A26F382021211A1A202524
222324242425211C
211E1E21242520170F121C211F294967654F4E7199A69C8E
81705E50463E38332D262324293A5B8297958C898F9DAEAE
8C562E201C1E282D1D113A89AA7435427F926B484C555368
9EC7C6BAC0BD925741556B6A615E6470818F8C7B624A3938
48585951483F3733312B2E528EAB85421D21281F161C2424
2223222022252118
201E1D1D1E201F1B18191C1C1E31506050383D5D7C837C72
6B676457402D2F3B3A2D29302F252A46636C666161686D60
3C1A1624261D222B1D0D307C9E754D6A978547314F676980
B1CCC0B7C1B377414465726A6E8497A0A6A89F90816D554D
5A65605B6366553C2E27274784AA8D4A2222251B161F2420
1F24211A1C242015
231D1A1D1D1A2336433C2A1F243748493A313E576560564F
4A495058585358626056555F5E4C3C3C4242454D4F43342C
2825292E2A23262C262240768E7A6D8491683331566C718D
BACCBCB5BDA7683A45697A7D8DA7B7B8B7B2A9A6A4927564
696C646679816841291F244987AB8F55332B21131726261A
1C27241717232214
211C1C211F1E33586A58382A2E3637322D30404E48352F3A
4341465D778283848078777E7D7061594D3B394D5D533D38
414235292627282A292D43688280756E5F423140585F678E
BECBBAB3BAA4683C456C8A9AABB8B9B5B4B1ABACB0A4856B
666C727E8C866A4F3F2F254284AF9A67483C261016272618
1B2A281816232317
1B1F23221F294B6D6F53372E2E2D2C2E3030363829171E44
666D6566727B7E7C7773777D786A656D6C5849556D756A5E
52412E231F1B1C21201B2B598283614233313A4B544E5888
C0CCB5ADBBAE7543497497A6B1B9B5AEAEB1ADA7A6A18E74
656B7E9296856E67634B29316EABAE855F482D151422261C
1B25271E1A20211C
1A24281E1A30587268472F2726262D3B433D312925283E6B
9BAE966B52576360545568756C5C5E717E7A6E66676F7469
4C3129291D101625200F215E8C7B49303A474A4C4D485383
BDCBB2A9BEBE874E4D78999FA7B7BAADA7B1B5A89B9C9F91
7A7078878E897E72654E332D508DB3A87C4E2F1D171D2524
1D1B2124201A1B20
1D23241B17294E6E735B3A29292F3746585A4533406487A4
C2D1B478525B6B5A3F415D6F6A68747F8286887859495258
46302E342E2734443C2E417085653C3C5A66564749536488
B4C4B6B0C3C697594C7399A3A6B5BCAEA3AEBCB39FA0B1B2
9A7A6767788D8B694338413C365494B7995C362A211A2027
1F13192624171620
201F1E1C1A1E3561847F5B3F3E4441466175664C5D98CBD9
D6D3BF9A838A8B673B324A5D677C969984767C795E43424E
4B38303C515F64645F5F686E62483B4A62655245516D869A
ADBABBBCC7C69E61486CA1B5AEACB3B1A7ABB8B7A8A3B3BC
AC89675A6884896133304B49251F5A9CA37954422E191722
201314222318161E
201C1D22221B22467486745D544F42415E7C765B63A0E1F1
DED0CFC7B29E8861331D2D4B62789199805E576A776E615B
4F362B436E817260626C67503D39424E544D42486A95ADAF
AFB6BBBFC7C5A16546649AB1A6A0AFB9B2AAAEB3ABA2A6B1
B09C806A66727A6D564E554C2B142B618C948260391B141B
1D19181D1E1A191D
1F1E1F2527211E29445F6C67574439425E75715C5F8ECAE2
D5CCD7D6B07D5C482E1B2B536A6969716B554E6A8D95836C
4F322A4769684B3A434C443838414D575442375491C0C6BA
B8BCB8B8C6CAA466455373838CA1B9C1B5AAABAFACA4A0A7
AEAA9579656475898E7F6C61563E242D6097A27B47261A19
1B1F201D191A1C1E
201F20222526221B1C304D5B4D36354F6C766C606786AAB9
B2AEB8B99762423F464B5A737C684C434E60707E85858174
5737304147321B1B272C2D3A474B526163483B67B1D6C8B8
C0C6B9B4C7CEA566413D455780B0C7BEADA9ACADADACAAA6
A6A18C6D5A6485A6B0A29395997C421D397AA08D5E39251C
1C2326211A1A1D20
211F1C1B1F24251D151C354A4B4249657E80726D798C9691
8278809091785B58718A8F88806F5036416E908563586B75
5F3F32342A17101B25272F3E46454B5B5D4C4D7EBDD3C1B6
C2CBC0BAC8CCA7693C32416393BDC8B8A9A8A9A5A5ADB1A8
9A8971585676A4BEBBB1B5C5C7A76A332851879B7F4D291E
212525211D1B1D21
1E1D1916191F24221E202C3F53626D78807F78757E888674
5E545F7C95947F74839794837A7560464A6D7F6440436471
58382B2A261F1F25292C2F3131363F4443486492BAC8C0B9
C0CAC6BDC0C6AD6F3A3C6D9CB1B7BDBDB4AAA59E979BAAAE
9D7E655D6D94BDCEC4BBC3CDC7B18D5A2E316BA49E612A1C
2526211D1C1B1D1F
1B1C1B18191D1E1E212326335173837D716D6C6B6F757160
525665757E827E746C6D75808883705D5B5E5138334E685F
3E28272A282423232425242024303633344B739DBBC9C5BC
BEC9C7B8B6C4B577405399C3B7A7B5C5BDAFADA792899FB9
AE87707B97B2C5CDCBC8C5BBADA9A8874826509BAE77341C
23261E191B1D1D1D
1A1C1E1E1F1E1B1A1F2320243E637875675D565257605E53
53626C62555964604E4C688FA39B836F61503A2F3D565C45
2A242C2B1E181B1F1D1B1F252A2F31333A4F74A0C5D2C7BB
C0CCC6B6B8C7B77D5269A4BCA89CAEBFBAB5BCB99F8FA0B6
AB8B7F94AFBCBFC2C7CDCAB59EA2BBB26E2A347CAA8A4620
1F241F1A1D211F1B
1B1D1F2123211D1D2226211C27415B6C7066514245525754
565C584B4B5A6254465377959E9A8B735A4A45464A4F4937
2A2C312513111E231B1927332E272E3B404A6EA6CFD3C2BC
C7CFC9C1C6C9B1866E7F9FAB9E969FAEB5B9BBB7AEA7A397
847B869AAAB5BBBAB9C2CBBEA4A3C1CA8D371E5796925827
1C22211D2025221C
1D1F1F1F20232322252A2A231E2843667E7D664F484F5659
57504750708C815A485D77796C6B6D614E49545A544C463D
332E2A1F161C2926191B2E3528223242414975B3D3CCBFC4
D1D2CDCED0C7B095878CA0AFA68F8AA2BBB8A5A0B1B5976D
5F738F9DA6B4C0BAADAFBCBDADA9BFC7964219408190622D
1A1F211E1F25231C
1F211F1B1B21242221272E2B211F34597B898272655D5855
55545A729AB29C68454956503D363C42454E5B5F5A565143
2F211E1F1F222726242B35352D3145514F5B88BED4CAC1CA
D5D5D0CECAC2B7A58C8298B4AE8A7E9FBFB39393ADAC8361
6B8BA0A8B5C4C5B5A8A6ABACADB4C0BA8E4A213A76906B32
181D211C1B212019
201F1E1D1D1F1F1D1D22292A25212A426079888F8D7D624D
4C5F7990A0A4936E473538403E332C31445B645F5758553F
20111A241E16213B5057544F4C536169666C8EBDD7D2C6C8
D2D5CEC3BEBFBFAB8469779AA58F849BB4AE9DA1AC9B7C78
94AAAAAFC4CEBDA7A7B1ACA2A9BDC9BB8F542D3B7293773B
191B211C1A1F1E16
1E1B1C2226201A1C232522222628272C3E58738C9B967753
475C7B8A83776F665847404B5A58443646656E5842454C39
1912252C1A133469898C82786E6D777B6B5F7BB5DEDBC8C6
D0D0C4BBBCC0BEAC8760546C8C98969AA5ACAFAFA6918491
A8ADA6ACBFBFA89DAEBFB6A3A5BCCFCAA46736386B938047
1E181D1D1E232019
1A191D272B241D212B2D231F27312D232539546E838E8468
5150606B6250475366695B55616752383F5E64432631463D
23213233222A5A8A9B97938B786E7675584468B2E0DBC9CA
D1C8B8B8C1C3BCB3A07B56517197A7A4A1A6ABA391868D9B
A09FA4B2B4A496A2B8BDAC9C9FB2C6D0B97C3D305D8B834F
23161A1F22262520
1A1D2226272524272C2C2521283231241B253A4E5C697573
614C4952503C2D3D6172624D49493A2A3349482E2031453E
2B262D2C2D456A7C7570797B6E62625C484670ADCECAC3CB
CFC1B2B5C1C3BCBCBBA578565D85A8AD9E94928A7C7C8E9F
A1A3B6C7BA9A92ACBFAE918D9FAEB8C4BE89402651888652
23161D2021242625
1F2123242120242826212023262829251C1B2A3C43444E5E
5C4B434F523B252F4F5E513D32271E22333C352C323C3A2E
221C1617284356575255626D6C6150454A61819AA5A9B3C1
C6BEB6B8BEBBB6BCC7BE9463567090978B828486808194AA
B3B8C5CFC0A29BB2BFA88C93AFB9B4BABD90411E4E8F8E51
1F1A24221C1E2222
231F1F22201A1E2623191821231B1C2321171D323B302935
403E435760492E2F41473C35322A2632413E30313D3C291C
1C190E0C1C3142546876797C7F755C4A5269797D7F8BA1B8
C2C1C1C5C1B1A7B7CBBD8D635A626666708291989B9EA6B2
BCBDB7B2AEA7A5B1BAB3A9B4C8C8BCC2CA9D44194D96944F
1C1E2B23191C1F1A
20191921221A1B24241B1922231A18222318162632281A1C
2934435A685A42383836313740403B3F453E2E292F312C2D
373E3A312F3A567FA1ACA39995918573625C67778089A0BF
CDC9CAD4CCAEA2BDD1AD6E525D5B43426A94A2A5B2BDB9B2
B4AE988992A4AAA9AEB9C3CFD6CBC1D1E0B04C154490914C
1B1E2A21191E1F15
1B17181F221F1E222320202425211F22231B171D27282327
37464E53595B524131292D394343372E323A382C27375064
73859188706B87AEC1BCAE9E9297A8A887697194A7A8B4D0
DDD2CFD9D2B6AFC9CC93504054533F4D7EA0A0A0B4C4BFB7
B5A88C8297ADA89A9CADBFCBCDC2BDD3E4B44D113B848849
191A251F1A202018
191B1C1C1E2122201F2022232323222020211D1B22314253
62675A443E495147342B2D323735281B284D665C49567D9C
AABDD5D6BAA4AABCBDAF9D85727DA6C3B59A9DBACAC6C9D9
DED5CFD2CCBCB7BCA772433C4A515976959E969AAAB3B7C1
C5B49EA2BBC1AA9497A5B0B9BDB9B8C8CC963B103F838447
171521201B1F201C
1C20201C1B1F211E1C1D1E1D1D1E1D1A1E24231C23436D88
866E4F3731394347443C30292F3B3D3D5586AAA1827D97B3
BDC6DAE7DBC0AFB0B7B49A7154608FB9C6C0C0C7C9C8CDD3
D3CDC9C5BBAEA291745B525659617998A6A19DA1A3A2ACC0
C6B6ADBFD5D0B7A9AEB4B3B3B7B8B9BAA465201755918748
181521221D1D1E1E
1E201F1B1B1E1F1D1B1C1B17171A19171C25241A245694AA
854E3133393737404842343449678094AAC1CBBDA4979FAF
B5B2B7C7CFC0AAA8BCC7AB7A5F6E91AAB5BDC3BFB7B8C3CD
CBC3BDB5A99780675A647D8C888290A9B9BAB6B1A79EA3AF
AEA3A5BCD0D0C9CBD0C9B9B2B4B7B4A7824210216BA18D4A
1B1721221D1D1D1C
1C1D1B191B1F1F1A1A1C1B16151A1B171B24231A2B6AA8A7
66281E343F37303233354563829EC0DFE6D1B7ACABA9A8AC
AFA8A3ACBABBB0AFBBC1B09792A3B4B4AEB0B8BBB4B2BCC8
C8BAADA7A18D6F596187B3C7BAA6A4B7C9CECAC0B2A5A3A6
A29596ACC5CED0D7D9C5A9A0AAAFA38D6B39132771A7904A
1B19221F1A1B1C19
191A19171A1E1D18181B1B17181B1B171B211E204586A985
3E182234322A2827274074A2B3BCD6F0E5BDA3AAB9BBB4B2
B2AFADB2B9BDC0BFB5A7A2AEBFCBD0CEC5BBBAC0C1BBB9C0
C1B3A5A7AB966D5670A9D9E3D0BCBBC4C7C3C4C9C1B0ABB7
BAA798A7C2C9C2C3C6B2928A9EA995775B3819296EA48D46
1719241E17191B18
1818191A1A1A19191918181A1C1A16191F1C152C6CA7A25F
21172B2E1E171E2E4D85BDD0C2BDD0DDCCB6BBCDD0C1B6B5
B5B4B9C1C2C3CBCEBEA6A1B1BDBEC3D2D8CCC0C1C4BDB6B8
B9B0AAB6BB9B644F76B9E1DECBC6CDC9B4A4ADC3C6B8B6CD
DBC9ACA6B4B6ACAEB8AD92899EAE9B754F2D19306F9B813E
1519252017181B19
1816191F1D15141B1D17151C1F17131D23150E3888B79648
151527261711235298DBF7E2C3BECDD2C9C9D9E0CDB3ACB3
B6B2B5BEC5C9CFD4D0C2B4A89A929DB5C5C3BDBCBBB5B4BA
BBB4B4BFBA915E5481BBD7D2C7C8CEC7B19A99ABB9B6B5C7
DDDABB9F979BA2ACB7B2A098A8B9AD80471D18417A906D34
171D25201A1B1B18
1915181F1E15131B1F18151D2018162023120E3D88AB8641
16141F1F19204689D0FDFFE9D7D2D3D2CFCEC9BAA8A2A9B4
B8B5B3BBC8D2D5D2CFC8B6997E747E8E9AA6B5BEBBB3B6C1
C3BAB5B6AB8D737898BBD1D8D1C5C2CAC7AD9291A4ACA5A9
C1D0BE9B8B94A4ABAAA29899AABBAF7E3E16215586875827
1922251D1A1E1C16
1916171B1B17161A1D19171B1D1A181E1F15143672947B41
1B19201A183879B8D9E1E7F0F0E0CCC2BEB39D8E94A9B9BB
BABCC3CCD7E1E0CCB3A2998B776A6A6F7688A7C1C5BDBBBF
BFB7B0ADA69C969AA7BEDAE9DBBFBBD0D8B9938EA1A79896
ABBFBAA9A1A2A1998F847F889DA99768341A2D618C834D1D
17252519161D1D13
1919181717191918191A19181A1B17161B1B16255687844E
201C2316134597C9C7BED2EDE9C8ACA3A19A959CAFC2C5BC
B6C1D7E7EDEADBB9927D8184776258585B6989AEC1C1BCBA
B7B3B2B4B1A69894A5C8E8ECD2BCC2D1C9A997A2B2AFA3A4
B0B7B9BCB9A9948A8A8882859090784E281B356A90804719
15252518151C1C14
171B1B16161B1B17171B1A16181C1813191F15123C829B6C
2E1A201814408DBAB9B7CEDBC09789949FA6B7CED5C7B7B1
B8C6DCF2F8E2B68A747886887661554D45486084A1B0B9BE
BEB9B5B3A78C757CA9DBECD7C0C4D2CAA9939CB2BBBABDC4
C1B9B9BDB39B8E98ACB3AB9E928267421F183D7792753C17
1723231A171B1B17
141D1D16161D1D15141C1D15161F1E1416201A0C2671A890
4A211F1D16306FA2B3BCCECAA17B82A6B9BCCADED5AF9AAC
C9D4D9EBF5D1864E4F728A8678706756443E4A5F7891ABBF
C6BBA48972616589C2E8DFBFB8D0DCC09992A5B1AEB5C9D2
C4B4B2B0A2959CB2C6CDC9B89C7D5F3C1B1C4E8891622A14
1B221F1B1A1A1918
151E1E15141D1E13121D1F141320231511202411165399A3
703B251A142B6399B6C4CEC19D89A1C4C6B3B3C3BC9D95B8
DDE2DAE6F2CC7A3A3452686C7077746557514F4F586D869B
A599764E415C90C0DBDDCBBBC1D5D4B69B9DADAB9D9FB5BF
B2A2A2A8A9ACB5B8B1AEB4B298714E301E3167958A4E1B11
1C211C191A191716
161E1D14131C1D14131E1F14121F22140F2028170E3579A0
905F2E0E113C78A9C7D8D6BA9DA5C5CEB0949AB1B4ABB4CE
DFDBDAE9F1D9A26C4B3F3F48555E5F5C5B59514440464F57
5E5E5142538DCCE4D5C1BFC8CFCEC3AB989CB0B4A191949C
978E94A9BFCAC5AC8E818A907C573524294C809A7C3E1512
1C1D19191B181616
171D1C15151B1B15161E1E15141C1E15121D23170E23578D
9F7D370512569BC5E0EEDDB19AB1CEBD9185A1BBBEC0D0DB
D4CBD5E5EAE4D8BF95694E464442404041403C342D2C2D2F
3749607A9CC5DED5BBB3C4D4D2C7B9A38B8DACC4B99A8889
8B8B93A8BFCBC5AD92827E73573723213562929A6B2D1219
1F18161D1E17151A
171B1B17171A1A17181C1C18161B1D1916181C1912183A73
A0914A0B1661ACD2DFE3D3B5A9BAC0A2818AB0C3BAB8CBDA
D5CCD1DADDE0EAEDDBB9967A65574D413530323536394452
637B9CBDD2D5CABBB7C3D1D2C9C2BBA48985A3C5CAB39A8F
90969DA3ABB4BBBAB2A6916B40231B254174A09554191021
221515222116151F
181919181819191817191A18171A1D1C1816191E19122056
96A46B2318559CBBB9B7C1CBD2D1BC957B87A8B5A59DB5D6
E1DAD4D8D8D4D7E4EEE9D7C1AE9E8C78655B5C626973859E
B4C2CCD1CFC6BEC2CED8D6CBC0BCB8AB988D96AEC4C7B7A2
98999C9FA3AAB0B5B9B59A6B3A1C1627528AA4813B0D1022
211517222015151F
1B1A1817171818181817171718191A1B1916181F1F120F39
84B08D3F193B738D8F9DC0E0EEE8CB9C797D9BA69792B0D3
DBD2D4E0E0D0C6D0DEE4E5E7E4D9CBC0B6ADA7A8ACB3BFCF
D9D7CDC3BCBECCDBDDD3CBCAC5B5AAACAD9D8A8FACC5C6B4
9F8E8A98ADB3A69C9FA08A62381A122D699C985F240E161E
1B181B1E1A16181C
1E1A1719191716191A1715181A1815181C18131A22190B25
6DAA9F59232446698BB3D3E1E6E8D4A7858CA6A8969AB7C6
B8AFC4DEDDCDCAD2D3CED4E4EAE4E1E4E5DED9D9D6D3D3D5
CCBFBBC0C4C9D4DACAB1B0C5CDB7A2ACBCAF8D7F94B2C4C5
B2917B8AACB7A491918F744D2C181C4482A07D3B14151E1A
161B1E1916191B19
1D18171A1B1816191B1815191D1813181F191015221F0F19
5395A37436192A60A3D3DDD1CFD7CCAEA2B5C3AF9295ACAD
9691ABC1C0BECFDFD8C8C6D1D6D5D9E0DFDBDDE2DCD2CFCF
C5B9BED0D8CDC0B6A59295B0C4BDAFB5C4BFA58E8EA0BDD5
D2AE877F95A8AAA8A69266361A19356895925C210E191F19
161C1D17151A1C19
1917171A1B1918191A1816191B1916181D1B13151F211312
3A7CA48F5120265FA4CAC8BDC5D4CEBAB9CFD5B38A819199
9290999D9BA6C4DCD9C7BEBFC3C6CDD2CFCDD2D8D3CACAD1
D4D1D0D4D1BDA494908E8E93A2B3C0C4C4C4C0B2A1A0B8D6
DFC9A3878397B5C7B98C542813204F889F7E4015101A1C19
1A1D1B16161A1C1A
15181917171A1A18181A1916171B1916191D1A151A21190D
22629FA4713B2F517F9AA0A7C1E1E8D1BFC9D5C096818C9F
A49D968E8994AFC5C6B6AAAAAEB4BBC4CACED0D0CECAC8CB
D3D8D3C3B2A2948C93A1A18E8397B6C0B4B2C1C8B9A8AAB9
C3C0B1988897BCCBA66839241B2A5F9BA46E2B10161E1A18
1C1E1914161B1B19
141B1C15151A1B16161C1B15151B1B14151E1D1212202110
11438BAD935C3839546F7D8CB1E3F8E1C2C4D7D4B8A6ADB7
B3A8A0978C8D9EACA79A94989B9B9EAABAC4C5C4C7C9C0B0
ACB8C1B49C8F9096A1B3BCA8898395A19690A1B6B49F9195
A0A9A89B92A1BAB27C3E2425283B6FA4A05E1D0D1C231B17
1C1D1714181C1B17
171C1C17161A1B16161B1D17151A1C17151B1C13101B2419
0C2365A4AC793E2D435D67759CCADED4CCD5DEDAD1D0CFC5
BAB9B5A3908E9A9B908A949F9F948B8C949EA3A9B3BCB296
8798B3B1968691A4ADB5C0C1AD91827E7B7B838B887F808F
A2A9A09391A1AB925D302125315389A98C4715101E201A19
1C1A1616191B1A18
1A1A19191919181717181A1A18171A1B18161A1B16141C20
14103986B2924E2D3E565F6D8DAAB2BACFE1DBCDD0D9D1C1
C4D3CBA88F96A5A09297ADBEBCAC99877C7B808896A3A293
8B9AACA68E869AB3B7AEAEBCC3B39076758486715D6488AC
BFBCAC998F929079533426253A6DA2A56C2A10181E17151C
1D16151A1B17171C
1D18161A1B1716191916171A1A16171B1A1518201F13121D
1E0F18559EAA72362B435B6C8096A5B3C5CFCAC3C5C7C0BF
D1E2D3AC97A6BBBBB1B5C8D6D5C9B7A28D817D7D808793A0
ABAC9D898393AEBFBDAC9DA3BAC5AF8E8A9F9F7957699FC5
CAC2BBAC938075654A31252B4A80A69049110F221F10121F
1F13141D1D14151F
1C1817191A17171A1B1715181A1714181B18161B20191116
20180B2571AF9E511A234B64718CB0C4BFB8BCC2C0BBBFCD
D9D9CBB7AEB9CDD7D2CCCFD5D4CDC6C0B4A79C90807888AD
C4B38A7687AAC0C3BDAF9D98AAC0C0B1AEB8AD886E81AAC0
BDB8B9AD917869573A24233B628A956D2C08122621121420
1E13131E1E15161F
1A1A1A19191919191A181717181815171B1B1614191D1713
1B20130E3989B289391225496380A8C6C9BFBBBCBAC0D0DC
D7C8C2C4C5C7D1DBD8CDC9CCCAC3C1C5C7C3BDAE927B88B3
CCB78E84A0BDC5BFB6ABA0A1AEBBBFC4CCC6A8867B8BA3B3
B9B4A5918378674A2C1E2A4F7C927D47180D19221D181C1F
1A14161B1C19191C
191A1B1A19191A1918181818171717181B1B1915161A1A16
18202012124595B988330B24506A7EA2C6CEBBACB3C8D6D6
CDC4C2C7CFD2D1CDC8C6C9CDCBC2B9B8BBC3C9C1A68C92B5
CEC4ACA8B7C2BFB7ADA19BA7BAC0B9BCCAC8A88070809FB9
C0AE917D7870593B27263C69959562270F181F1A161C211C
17181918181B1B17
1A1817191A1818191817181A181516191A191A1B1815181A
191A211E0E1453AAC4852F132B45516E9AB2ABA4B4C9CAC0
BEC1BEBFCDDCD9C8C3CCD3CFCAC7BEAFA8B3C4C4AF9B9EB4
CACEC4BEBFBEB6ADA79F999FB5C4B7A3A7BDB98C6473A7C4
B19187887654392E2B33588EA7834014121F1D14151C1E19
181B1A17171A1A16
1B161517191716191B19191B1B1614171918181B1A16161B
1B14151F1E0F195CB0C88A340B19364B5D748DA6BAC0B8AF
ADADA9AFC5D9D7CCCED8D2BFB9C5C8B4A3ACC1C6B6A6A6B3
C1C7C3BDBCB8AA9FA5B0A99BA6C1BA8F7EA4C4A46E74A8B6
8D7184916932212B33477FB2A1571A121E1C15171B19161A
1D1A16181917171A
1B181616171818181A1C1C1C1B1815161818161719191718
1A150F17252009125DB8CA81290E263938436C9AAEACA5A0
978B8DA2BAC2BDC1D0D3BB9FA2BECDBEACB1C4CBC0B2AEB4
BCBEB9B6B7AF9C92A6C3C0A8A6C0C0916E89B6B186768A92
7D737C7246242635436BA8BA7B25081B2415101D2115131E
2016131B1C15151E
191B1A16171A1B18171B1D1B1818191818191917181A1816
171A171419211704145DAEBE8541272C2F344D738D918D87
796D799DB5AFA2ABC0BC9A8394B9CAC0B4B8C4CAC5BBB4B4
BABEBCB7AFA2918FA7C3C7B7B3C3C4A077799EB39B705F71
8886643B282D39446397B591430E0F221E11141F1F15161E
1C14151C1C14151C
1A1B1B17171B1C1815181C1A16171A1B19191B1A18181917
161B20190F15221C060F55AAC59554322C2B30496A7D7A6B
5C59709BBAB6A6A9B8AF8B768BB1C1B8B1B6BCBCBAB9B2A9
AAB8C2B9A4928D95A5B4BAB6B4BEC2AA817492B4A269485F
8072412329363F5B90AF914B1A141E1E17171B1B19181918
16181A1A18171717
1A191919191A191817181A191716191B1A191819191A1B19
16181D1D15111B261A061355A0BA986138231F30516F7668
5652668FB4C1BAB9C1B7947783A7BAB2AAB1B5AEA8AAA593
8DA2BAB59A8A8F99A0A7AEABA7AFB9A67D6F8FAD98644C55
543C2A3239354781B19B501610201F16171F1D16171C1913
151C1C16161B1A14
1A18181A1B191617191A1919191817191A191515191C1C1A
1815171C1E18111824200D10428AAF9B69412D2A39567179
6A595A7291A5AAB0BBB6987B83A6BCB6ADB2B7ADA09C9480
7990ADAE978B8E9296A2AFABA1A7AF9A736780907A5B5351
3B272F41424671A9A9641C091A2016131C201A171A1B1715
1A1D1916171B1A16
1A19191B1B1916171A1B1A1818181817181918171A1B1A19
191918191C1B13101A241D0B0D3776A2A5875E3B2932516E
715E4C4E5E686D7C91947F6F80A7BFBDB7B9B7AA9C908172
7895AFAE9D90887E8097B1B6ABA5A08A6B5E666857484D57
554A4342527BAAAD752D0E17211912171C19171A1B18171B
1D1A17191A18181A
1A1A1A1B1B1918191A1A19181818181716181B1D1A171718
1A1B1C1915161A1A14131D23160A2568A6B59668412A293A
4A473934383838475F63524C6893AEB5B6B3A796887B6A62
779FB9B7A6947D64607DA4B6AA958575645956504135415F
736B53547EAFB37B351316201E17181A1714181C1916191D
1C18181B1B17181C
1B1A1A1A1918191B1B1818191919181817171A1C1916171B
1B19191A171419201B101323261104226094A59A7F572F1A
1C232425292B2D374342312A4168859299988A75655D5552
6893B6BAA88F73554A638C9E8D7365615A534F47362A395A
6C656280A8A9763412141D1D191A1C191516191918181A1A
1818191B1B19191A
1A19191817181A1B1A19191B1B1918181817161717181A1C
1B1615191D19151A201D13111C21150918437598A2926D45
2D262624252C3336342F27242F42515A6673705C4946494B
567698A2937E6D5B515C7378655251544D423D362A293C55
5F657E9C98652A0F121A1B181A1B191819191818191A1918
1818191A1B1B1A19
1919191717191A19191A1A1A1A19181819181715171A1B1A
1A1917171A1B17151A1F1A10111E2317090F2E577D969E93
7C634D3B3232332D242229333731252334505B4D3A373F45
4A586A6E645F6468645F5C54464145463B2B222127385168
79899280501F0C131B19171A1B1716191B1817191B19191A
1A18181B1B191819
191A191718191918181919181718181817181A1A19191918
191B1B1715171B1914151B1E181419211E100815345C85A4
AD9A7D685F544231292B3239392911071936433828242930
363B3B35333C4E5D605646373030312D2723253147607688
96957740120817211B15171C1A15171A1916181B1A18191C
1A17181B1A16161A
1B1918181817181919181616171718181716191C1A161618
191718191715191D1913162020151019231E10090D1C3962
8189858990866C5A5A5A4D3D342D211B222F31271A141419
20221F1B1E262E353C3C3226201E1C1D2A425A6C7C898E88
775933140C161F1E17161919181819181617191A18181919
1818191918171719
1B171618181717191A17151618191A1A1816161817151619
1813141A1C18151A1F1C15151A1C1713151C222015090918
2D4159778C8E84848D8B745B515558544D463F372F282426
2A2C2C2E302B20181D272D2D2B282936557B959A92867456
2E0E051120211814181B1815171A1916181B1A1817191715
171A1A1717191A18
181717171818171818181716181B1C1A1917171616161718
171718191A1816171B1D191313191D1811131E242017100B
080F233A49536176858885868C908E86796D676868625C5D
61605D5A554A3A2E2C34404E575A5F718C9F9C876C51361A
06020D1C221C14141A1C1815171918171A1C1A1717191716
181A1916171A1917
171818171819181617191917161A1C1B1819191816171817
181D1E1914161B1914141B1D1713181E1D16121319202522
18100E0C0A11253B464F64859A988A7F7A787B858E8D8889
8F8E8579726F6A645E5D657482888C92948567462E1A0905
1324271D14151A1B19181818171618191A19181718181819
191A181717181716
1818181818181717181A1A1715171A1A1819191917171819
1A1B1C1916171B1B1614191D1A1413191E1C151012192025
251F170D07080D1011162A44535248444A535D6A75797879
7E807A73737A80807C7A7B7D7E7F7D735E412717100D0E16
2329231813171C1B1817191A181618191917161718191919
1918171717171716
19181818181717181A1A191716161719191717171718191B
191615191C1A16181C1D181315181613151B201E18121013
1A1F212122211B110A08070504060B1017202931373D3F3F
3F42474D545D63656769665A4D4743351F0E0C11171D2425
1B100F171D1B1716191A1919191817181917161618191918
1817171617181717
181818181818181818181818171717181918171718191A19
171515181B1A16161A1D191313181A1613171D201D171210
13171D202323211E1B170F050002080B0C0C0F1011121515
14141A22282A2C30343631271D1714100C0D141B2022211C
130D10191D1A1516191A1918191918181919181717181818
1716161718181717
1718181717191A17161719181718181818191A19191A1916
16191B1814161B191414191C1814181D1C1612141A1E1F1E
1B1815120E0E151D202022262826221F1B171413110F0F11
110E0C0D0C0A0A0F120E0A0A0D0D0B101A21201D1A161010
1923221914171A1A18181818181A1A1817181A1916161819
1716171918171617
1818181616181918171919181718191817191A1A19191816
161A1B1915171B1A1513191D1A15171C1D171212171C1E1E
1C1916120E0D1217191B1F262A2823211F1E1C1B1A19191A
1A171412100E0E10110E0D101517161920221E1815131113
1C24211814171B1B1817171718191A191717191918171718
1817181918171617
191817161616171A1B1B1917171818171717181818181819
181616191C1A17181B1C17141519191614171B1C19161312
14171B1F22211C1713120F0A080A0F1215191B1B1A1B1E1E
1B191B1F2121201E1E212322201F1D1A15141517181C201F
160F10181D1A17171919171617191919171617191A181616
1819191818171717
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[14]:=",
  ImageSize->{466, 145.625},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007B0000TA000`40O003h00Oogoodgoo003oOooC
Ool00?moom=oo`0037ooRP003GooR`003GooRP003Goo000<Ool00`00Oomoo`26Ool00`00Oomoo`0;
Ool00`00Oomoo`27Ool00`00Oomoo`0;Ool00`00Oomoo`26Ool00`00Oomoo`0;Ool000aoo`03001o
ogoo08Ioo`03001oogoo00]oo`03001oogoo08Moo`03001oogoo00]oo`03001oogoo08Ioo`03001o
ogoo00]oo`0037oo00<007ooOol0QWoo00<007ooOol02goo00<007ooOol0Qgoo00<007ooOol02goo
00<007ooOol0QWoo00<007ooOol02goo000<Ool00`00Ool000240002Ool00`00Oomoo`0;Ool01000
Oomoogoo@W`000le[BU:F]IS6000124HaQcWMkdYBPaS=Jd000@Q48@00UJe01l48A24=Jd002e[?NlL
iaBU48A246<H5:D]J`Q28@Q>Lc6<=Je>LdHa5:DaS0Q2?Nl8@Re[@Q1JeTYB>LhLi`025:D023F]5:DU
:AcW5:EF]A247>L2=Jd01Be[5:D8@RU:7>L00goo00<007ooOol02goo00<007oo36<010aS0PQ23@aS
0PQ20PaS1`Q240aS0`Q20PaS3PQ210aS00<8@PaS36<010aS0PQ210aS1@Q20PaS00<8@PaS36<00`aS
0PQ21@aS00@8@PaS36<<H`<8@P<<H`88@P<<H`<8@P<<H`88@P8<H`05248<H`aS36<8@P02Ool00`00
Oomoo`0;Ool000aoo`03001oo`0006X000031240000001L0009oo`03001oogoo00]oo`05001oogoo
Ooml0005Ool01fLi>Lioob48OolicRDY009oo`9S6008MkeoogooOolHaWNmOomF]@9oo`0E:DY:DRDY
000LigNm9BT<He:DOomJeQBU>LhLia24;F/002e[?Nl]Je:D009JeP0O8@PYBTYBJeY244YB:DXaS1cW
:DXe[ABU248Q21cWO00003F]6<H48BU:7>LU:BU:DY@aS124:DXLibe[36<00Sg_00PHaPQ248@HaQ24
7>LHaQBU0PQ200XU:@00;F/48CF]000HaP00:DX48@D<H`06000YBPaS7>L@Q1BU0PaS00<48A241240
0PQ200XDY@@Q124HaQcW00048B486<HLi`=oo`03001oogoo00]oo`03001oo`Q20088@P@<H`88@QH<
H`<8@P8<H`<8@P@<H`88@P@<H`<8@Q8<H`88@P<<H`D8@PL<H`<8@PD<H`/8@P/<H`88@P/<H`88@P04
36=oogoo000=Ool000aoo`03001oo`0003P000031240000004T0009oo`03001oogoo00]oo`05001o
ogooOoml000:Ool00dHaMkeoo`04Ool01P@QOolicWooE[EW>@9>L`09:DYg_GooKg]ooc6<AS5ooaS6
00Aoo`039BUoogoo008mk`04F]IF]E[F>Lh2IcT07`aS<Haood8@001ooaBUF]H005kgIcTaS2DYOolm
kg`09BT]Ja24=Jd48CF]000YBS6<36<48BU:48@48ABU008<H`0O=Jdmk`0048@DYC6<5:D000Q2=Jda
S000>Lh<HbU:<H`YBQcW:DX@Q0Q2?Nl48B485:DHaPaS6<H@Q0Q212400QS600X8@Q24<H`<HacW5:De
[A24124Li`88@P036<H000@Q00=oo`03001oogoo00]oo`03001oo`Q200<8@P<<H`88@PL<H`88@Pd<
H`<8@P8<H`<8@P@<H`88@PD<H`88@Q8<H`88@P<<H`H8@PL<H`03248<H`aS00<<H`88@P0336<8@PQ2
00<8@P8<H`88@PD<H`88@P<<H`88@P`<H`<8@P9oo`03001oogoo00]oo`0037oo00<007oo0000O000
00<48@0000001@000Woo00<007ooOol02goo00`007ooOomoog`0Ool8@W_NOomkgWoo>Lh3Ool011BU
001kgQ240goo00@HaWoo;F]>L`9oo`0336=oogoo009oo`0C124002U:OolHaWoo36=S67ooKg/aS2DY
OolHaQcWCW<@Q2e[IcT00Ukg01MJeS6<Mke>L`00DY@Q23W>@Q0e[@aS124mkbe[:DYl03W>:DX48A24
>Lh]JcF]009W>@067>L48D8@9BTaS1240T8@00<U:B4848@00PaS01LDY@aS;F/<H`00@Q0<HbU:000Y
BPaS000@Q248=Jd<H`008@P48BDY48@icPaS0088@P0836<@Q12436<mkaBU48@48@<0000536<48@@Q
000YBP0236<3Ool00`00Oomoo`0;Ool01@00Ool<H`aS24800`aS0PQ20`aS0`Q20PaS0PQ21PaS0`Q2
1`aS0PQ21PaS0PQ210aS00<8@PaS36<00PaS0`Q20PaS20Q21`aS0PQ21`aS10Q21@aS10Q200@<H`Q2
2488@PP<H`<8@PD<H`<8@Pd<H`88@P9oo`03001oogoo00]oo`0037oo00<007oo0000Q0000Woo00<0
07ooOol02goo00D007ooOomoog`000Qoo`05NmioogooOolicP07Ool063g_>LioogNmOolDYBDYOolY
BWooF]HicWoo48@icUkgOomg_A24F]H]JaS6Kg]kgP8<H`07Ool@Q1241256<E:D48@00QcW00HmkbU:
248Lib48124200004F<HO00DYB48?NlU:@00CW<48Ekg:DX8@PaS7>L001cW<H`00QS600L]Je:D48@Y
BP@Q=JdYBP0200005RU:48@001249BT8@Q2436<48A24=JdLib486<HDYDYB9BTe[A247>LQ20aS0QBU
00l48@Q27>LDY@@Q248YBP@Q8@P00124000<HacW8@P00goo00<007ooOol02goo00<007oo36<010aS
0`Q20`aS00<8@PaS36<01PaS0PQ20PaS0`Q20`aS00@8@PaS36<<H`88@PD<H`@8@P<<H`88@P<<Ha08
@P<<H`88@PP<H`@8@PD<H`<8@P8<H`88@P@<H`04248<H`aS36<5248336<4248936<2248236<22482
Ool00`00Oomoo`0;Ool000aoo`05001oo`0000048@220002Ool00`00Oomoo`0;Ool02000Oomoogoo
O01ooa24IcT4Ool01GNmAS5oogoo<H`02goo00<YBUJeOol017oo00=W>A24AS401Goo00T]JekgOomo
oc6<E[DDYGooIcT00R4801AF]BU:JeX@Q36<AS524124?NlYBSW>BU9[FUJe001l03F]248<Hb480PQ2
00@48D8@36<<H`8e[@03124DY@Q2008Q200<248<H`Q29BTLibDY124002U:36=:DQ240P0000L@Q0aS
36<8@P00DY@8@P028@P01a24<H`HaP005:DYBP@Q00@@Q004;F/DYA247>L4124012e[7>LHaP000PaS
0goo00<007ooOol02goo00<007oo36<04@aS0`Q22PaS0`Q20`aS0PQ210aS0`Q20`aS1PQ22`aS0`Q2
0PaS0PQ20PaS0`Q20PaS0PQ21@aS0PQ21@aS1@Q200<<H`Q224800PQ200<<H`Q224800`aS10Q200@<
H`Q22488@P@<H`88@PH<H`<8@P9oo`03001oogoo00]oo`0037oo00<007oo0000Q0000Woo00<007oo
Ool02goo00D007ooOomoog`000Moo`036<Ioogoo009oo`05?Nmoobe[;F/DY@03Ool00c6<IcUoo`04
Ool02F]J000@Q7oo;F/LidHaIcUS6002Ool02Ekg>LikgTHa36=Nme:D:DYoo`02=Jd07aBU6<H<Hbe[
124]Jgoo124Libe[6<H8@SW>MkdDYG`08@QW>A24<H`48Be[248mk`aS9BTDY@007>L000Q200<0000N
9BU>LbU:5:DLia249BTLi`Q29BTQ21cWAS4@Q0aS48@<Ha246<HDYBDY48@HaQcW36<]J`005:D8@P@Q
0`0000hU:@00000Lia24124<HaS6000@Q0006<H]J`@Q0goo00<007ooOol02goo00<007oo248020aS
00<8@PaS36<01PaS00<8@PaS36<02PaS0PQ210aS0PQ21@aS0PQ210aS0PQ220aS00<@Q0aS36<020aS
00@8@PaS36<<H`<8@P8<H`88@PD<H`88@PH<H`88@P<<H`<8@P8<H`03248<H`aS008<H`@8@P8<H`03
248<H`aS00<<H`88@PD<H`<8@P0436=oogoo000=Ool000aoo`03001oo`0008@0009oo`03001oogoo
00]oo`05001oogooOoml0005Ool02A24HaQoogooE[Eooc6<?Nmoo`02?Nl6Ool01d8@;F/007ooAS5o
oe[F009oo`0?125oo`aSOolU:FmkNmiNmgooF]I[FQ24JeYoobU:00=oo`0OAS4Q25Je124U:GooCW<D
YDHa>Li:DV<HOolHaPQ2O00@Q2e[6<HLiaS6:DX00248AS4]J`Q29BTHaQcW6<H00Re[01PaS124124Y
BQcW:DX001BU8@PLicW>7>L001cW>Lh<HacW124HaR486<H48@Q27>L248@00bDY6<HLi`0248@236<0
1Re[36<003g_:DXLi`<@Q0065:DQ236<5:D001BU0goo00<007ooOol02goo00<007oo248020aS00<8
@PaS36<00PaS0`Q210aS1`Q21`aS00<8@PaS36<00`aS0PQ22PaS10Q200<<H`Q224801@Q21@aS0`Q2
2@aS10Q20PaS0`Q210aS0PQ22PaS0`Q250aS0PQ200@<HgooOol000eoo`0037oo00<007oo0000Q000
0Woo00<007ooOol02goo00D007ooOomoog`000Aoo`055:EoogooG_M_N`03Ool012487>L48@@Q0Woo
00<YBQBU9BT017oo00e[FWooOomoob48OolaS1S6HaQ:DWooHaQF]@02?Nl01cF]CW<e[BU:36=:DSF]
0088@P0E36=ooa246<HYBPQ2Oom6<AcW48@8@Tic124]Jf]JO00DYAS6248002DY008aS003=JdQ20aS
008e[@039BT48Cg_00848@03;F/48A240088@P08124Lib4848@HaP009BT<H`8U:@0748@U:Be[000@
Q1cW<H`00QBU00L48B4812448A247>Lmk`0224800be[7>L@Q00212402RDY36<8@R48248000@Q48@Q
20000goo00<007ooOol02goo00<007oo36<00`Q210aS0PQ210aS0`Q20`aS0`Q200<<H`Q224800PQ2
00<<H`Q224800`aS0PQ20`aS1`Q21`aS1`Q200<48@Q224800`Q210aS1@Q20`aS00<8@PaS36<00PaS
0`Q20`aS0`Q210aS00<8@PaS36<01`aS10Q21`aS0PQ23PaS0Woo00<007ooOol02goo000<Ool00`00
Ool000240002Ool00`00Oomoo`0;Ool01@00OomoogooO0001Woo00=W>DicOol00goo00<e[FmkOol0
17oo01<mkgooOolLigoo7>MoobDYOom6<G>LNmi247oo8@P<Hdic7>MNm`02Ool01g_N48@DYEJe7>Le
[F<H009oo`0O000@Q124Li`Q23g_248U:ABUOomkgTHaOolU:A24O00e[A2436<48CF]48@U:Cg_48@Q
200048@8@P@Q9BT00QS600MF]@00;F/aS1S636<U:@022480148@48@000Q20Q240108@P@Q1248@P00
5:D48@005:D0024824848@Q2:DXLi`8<H`0?000Li`@Q6<HLib48124<H`0024848CW>000Li`Q200=o
o`03001oogoo00]oo`03001oo`aS0088@P@<H`<8@P@<H`04248<H`aS36<3248:36<;24800`aS2488
@P02248236<4248@36<3248336<2248236<2248736<2248236<3248436<8248:36<2248436<22482
36<3248336<2Ool00`00Oomoo`0;Ool000aoo`03001oo`0008@0009oo`03001oogoo00]oo`07001o
ogoo48Al07ooLi`00goo00<U:E[F36<00goo00<]Jf<HOol00U[F00<]JgooIcT01Goo00M:DWooHaP<
Hgoo;F][FP02Ool03PQ2OolHaWooLi`<HaBU<HaS62e[OolYBV]J>Lh2AS406f]JF]HU:CF]OomBU0aS
<H`8@UJe000]J`@QAS5oog`06<H]J`0036<aS3F]AS4aS1249BTLi`029BT07Sg_AS4@Q1245:De[Be[
>Lh8@Re[:DY6<BU:36<48AcWDY@0036<36<DYCF]5:D<HbDY248Lia241248@P848@03000DYAcW008D
Y@0=;F/icQcW248004ic248aS124;F/DY@@Q36<00Q240goo00<007ooOol02goo00<007oo36<01@aS
0PQ210aS0PQ210aS0PQ230aS0PQ20`aS00<8@PaS36<02PaS0PQ21`aS0a2420aS00<8@PaS36<01PaS
0PQ21PaS0PQ22@aS0`Q210aS00<8@PaS36<010aS0PQ20PaS0`Q220aS10Q20PaS0Woo00<007ooOol0
2goo000<Ool00`00Ool0000V0002124S00000`@Q0000000G00000`@Q0000000L0002Ool00`00Oomo
o`0;Ool02000OomoogooO01ooa24Mkd4Ool01WNmOomoo`aSOomNm`=oo`03BU9oofmk00=oo`0D=Jeo
o`Q2E[E_Ngoo5:EoofLi249ooaBUOol<H`@QKg/e[BU:Ool<H`9oo`037>M>L`@Q008]J`09CW=6<DYB
Kg/mk`@Q>LhaS3g_008U:@0D5:DLicg_249l02DY>LhDYEJe001:DR485:De[AS6<H`YBUJe36=JeP8e
[@0G0008@P@Q248<Hc6<>Lh8@THa9BTDYA24000Q21245:D]J`Q28@P002U:36<48@025:D01PQ2:DX0
02e[5:D]J`8<H`0?48@DYB48124HaR48000<Ha24248icR48124DY@0000=oo`03001oogoo00]oo`03
001oo`aS00@<H`88@P<<H`@8@PT<H`88@P8<H`88@Pd<H`03248<H`aS008<H`88@PD<H`<8@P0436<8
@PQ2248836<01@Q236<<H`aS248020aS1@Q250aS0`Q20`aS0`Q20PaS10Q22@aS0PQ20Woo00<007oo
Ool02goo000<Ool00`00Ool0001S00000`@Q0000000N0002Ool00`00Oomoo`0;Ool01@00Oomoogoo
O0000goo00<icWoo9BT00Woo00<e[GooJeX00goo0Tic00<e[Goo8@P00goo00QW>GooOol48E:DKg]2
44Ha0goo00L00124Ool@Q6mk:DXmk`02JeX01GNmOol8@PaS>Lh00QBU01Eoob48:DX006]JOol@Q0Q2
HaP48B485:E242DYMkel02e[24848BU:36<00PQ200P48@00248U:@@Q@Q048Cg_0SF]00dmkcW><H`i
cS6<6<H003W><H`48@Q2:DXLi`0224804124248HaP@Q5:DQ20Q2000HaQ240008@P@Q5:D002e[0PQ2
00l@Q1cW248<Ha24<H`48BU:0008@QcW5:D48AcW=Jd00goo00<007ooOol02goo00<007oo36<010aS
0PQ20`aS0PQ20`aS0PQ20`aS30Q200<<H`Q224800PQ20PaS1@Q20PaS1@Q20PaS1PQ20`@Q2@Q200@<
H`Q22488@P<<H`88@P8<H`D8@P8<H`<8@P<<H`<8@PT<H`<8@P<<H`<8@P8<H`D8@P@<H`88@P<<H`04
249oogoo000=Ool000aoo`03001oo`0008@0009oo`03001oogoo00]oo`05001oogooOoml0002Ool0
0eJeOolaS002Ool01CW>125oogoo9BT017oo00UBU7ooOomoogNmOol007oo9BT00goo00DQ27ooOom_
Ngoo0092400<G_MkgQcW48@Q236<125oob48BU8HaQ240Re[01@U:ABUHaP8@P008@PicQBU124@Q248
000U:A249BUl01245:D004YB0THa00UF]@Q2HaPLib485:DHaP009BT00PaS01<YBR489BT48@Q2G_LY
BRDY;F/Q20@Q5:DYBQcW6<He[BU:;F/Q2002248020aS000Lic6<6<HDY@0048@424800`aS000]J`04
24800`0012448@0248@00cW>24800003Ool00`00Oomoo`0;Ool00`00Ool<H`0736<3248736<62486
36<A24800`aS2488@P03248436<00`Q236<<H`0236<010Q236<<H`aS1`Q20PaS1`Q20`aS00<8@PaS
36<00`Q20`aS1PQ200<<H`Q2248010Q210aS0`Q220aS0`Q20PaS0`Q20PaS00@8@WooOol000eoo`00
37oo00<007oo0000Q0000Woo00<007ooOol02goo00D007ooOomoog`0009oo`05JeYooacWE[E_N`04
Ool00be[Oomoo`026<H00bDYOom24002Ool01Re[OomoobU:OolQ209oo`07;F]S67oo125>Lgoo6<H0
0Woo00UcW4icOolYBWooCW<@Q7oo;F/00RU:00LaS3W>48@YBRDYOomJeP02;F/020007>L@Q0aS248<
Hg`0:DX212403248>LhHaQBU<H`]J`@QBU8icS6<G_L0009JeP0>7>LaS1S6248<HbU:8@P<H`@Q@Q08
@Q24<H`<H`8DY@0=8@PDYBe[248000aS000@Q1BU7>L48@Q27>L00Q240THa00X<HaBU7>L000aS7>L8
@P@Q9BT48@800003248@Q0@Q00=oo`03001oogoo00]oo`03001oo`Q20088@P@<H`<8@PP<H`03248<
H`aS00X<H`88@P`<H`03248<H`aS00/<H`@@Q0`<H`88@P<<H`03248<H`aS00l<H`88@P<<H`<8@PD<
H`88@PX<H`88@P<<H`88@P<<H`9oo`03001oogoo00]oo`0037oo00<007oo0000Q0000Woo00<007oo
Ool02goo01<007ooOomoog`0Oom246LiF]IoobDYJeXDYGooG_Moo`Q2<Ha:DP02Ool00cF]Oomoo`04
Ool00`aS>Lioo`03Ool025kg249oog_N>LioobU:F]H20002Ool01SF]249g_EkgOolicP9:DP0H124]
JcF]6<HU:E[F8@PaS1cW9BT@Q2U:124002DYO00Libe[>Lh48ABU48@aS0@Q0QcW00E242U:124icPQ2
008U:@0@6<H48A247>LHaPaS124Q20Q28@PLia24<H`icQ24=Jd28@P03ABU1248@QS6?NlHaT8@0004
8@aS124<H`00008Li`0336<LiaBU00848@0:9BT8@Q2436<aS124125cW0@Q7>L3Ool00`00Oomoo`0;
Ool01000Ool8@PQ21@aS1@Q230aS10Q26PaS00<8@PaS36<00PaS0PQ20`aS00<8@PaS36<04PaS0PQ2
5@aS0PQ20`aS0PQ23@aS0PQ20`aS0Woo00<007ooOol02goo000<Ool00`00Ool000240002Ool00`00
Oomoo`0;Ool04`00OomoogooO01ood8@IcUJeWoo9BU[FQBUOomNmgoo248aS4YB009oo`03=Jeoogoo
00Aoo`0336<icWoo00=oo`08G_L8@WooNmhicWoo:DYJeP80009oo`06=Jd8@WNmG_MoocW>0TYB01P4
8Be[=JdHaRDYF]HQ236<7>LU:A24:DX48@009BUl01cW;F/icP@Q5:D@Q36<12427>L01D8@:DX48CW>
24800RDY010HaP@Q48@LiaS636<48B48248Q21cW48@aS3W>48@e[@8Q200=5:D48@Q26<HmkaS6@Q00
00@Q36<48@aS00000QcW00<<HacW5:D00P@Q00XU:@Q248@<Hc6<48@48G>L124Li`=oo`03001oogoo
00]oo`04001oo`Q2248536<5248<36<4248J36<00`Q236<<H`0236<2248336<00`Q236<<H`0B36<2
248E36<2248336<2248=36<2248336<2Ool00`00Oomoo`0;Ool000aoo`03001oo`0008@0009oo`03
001oogoo00]oo`06001oogooJeYl02U:0Woo00@]JgooOol<H`9oo`046<IoofLi0003Ool042DYOolL
igooAS4U:Goo5:EoocW>OolmkgNm5:E6<CF]0T8@00dicWooOomoodHa:DYg_Goo@Q1cW4YBG_M_N`02
CW<04`aS6<IBU1BU6<He[CW>8@QNmbe[?NlDYE:D248007`0CW<YBQBU009:DP0:;F/48Be[:DX48B48
DY@48D8@000224807`aSJeX@Q1S6:DY24248:DX000aS9BT]JaS6248DY@aS8@P8@P@Q48@48ABU6<H<
H`@Q:DXDY@@Q6<H48@00009:DP0?48@Lia247>L001S68@P<H`005:DHaRDY>Lh@Q2U:00=oo`03001o
ogoo00]oo`04001oo`Q2248436<2248010aS2488@PQ20`aS0PQ20PaS0PQ200<48@Q224802PQ200<4
8@Q224805@Q200@48@00000000848@P8@P031248@PQ2008<HaH8@PT<H`88@P@<H`04248<H`aS36<4
248536<3248336<2Ool00`00Oomoo`0;Ool000aoo`03001oo`0001L0000312400000054000031240
000001H0009oo`03001oogoo00]oo`05001oogooOoml0002Ool00be[OolLi`04Ool01@aSOomoobU:
JeX017oo00=6<@aSBU800goo00<YBQBUIcT017oo00A[FWooG_LU:@9oo`8icP07MkdYBP00@Q0@Q7oo
Nmh00`aS00LHaS6<:DX]Ja24E[EkgP02<H`05PQ28@P8@S6<7>LHaW`07>LQ236<>LhQ2000>LhHaRU:
000@Q1BU36<mk`aS0Sg_01licP00DY@DY@aS:DXU:@0048@Q20Q2:DXHaR487>LDYA2436<HaRe[36<8
@S6<9BT48BDY;F/DY@aS:DXU:@026<H03bDY5:D8@QcW9BT002U:8@PU:B48:DX8@S6<48@<H`03Ool0
0`00Oomoo`0;Ool01@00Ool<H`aS248010aS10Q210aS1@Q200<48@Q224801@aS10Q20P@Q0`Q20P@Q
40Q200@<H`Q22488@P8<H`<8@P0536<8@PQ224848@0524800`aS2488@P06248236<E248936<32480
0`aS2488@P02248236<4248436<2Ool00`00Oomoo`0;Ool000aoo`03001oo`0008@0009oo`03001o
ogoo00]oo`0:001oogooOoml07oo125oob48F]H2Ool015Je5:ENmekg0Woo00=cW5:DDY@00Woo01dD
YBe[DYAoodic9BUoocg_IcUJeQBU6<Ioocg_F]IoocF]@Q1ooeJe9BUNm`007>Mooekg9BTHaP00008@
Q00IJeX<HacW00048A24248@Q4YB36<mkaBU124HaQBUO008@QcW249BU1cW<H`<HacW:DX00QcW00@e
[FLi36<]J`8@Q00O7>LYBRDY1248@SW>?Nl48C6<124Q21cW5:D48D8@48@U:CF]7>L8@QS60008@QS6
9BT<H`Q248@48BDY00000QS600D001BU36<icPQ2008@Q0085:DLiacW;F/U:F<H6<H<H`=oo`03001o
ogoo00]oo`05001oo`aS36<8@P0>36<00`Q236<@Q0026<H45:D00a2436<<H`0248@25:D66<H55:D3
48@45:D01QS65:D@Q0aS48@DY@8HaP058@PU:BDY8@PHaP0248@25:D56<H011BU36<<H`aS11241ABU
31241@aS0`Q22@aS0PQ210aS00@8@PaS36<<H`<8@PD<H`9oo`03001oogoo00]oo`0037oo00<007oo
00000`0000@48@0000048@8000032480000000D00088@P05=Jd]JaS66<HU:@0236<01ABU124<HaS6
8@P00RU:00<]JbU:;F/00RU:0RDY00@Lib488@PLi`8HaP0B48@U:AcW9BT]Jb4836<8@P00=JdHaRDY
>Lhe[CW>?NlHaPaS0aBU00L]Jc6<:DXaS2e[48@48@0236<35:D02BDY8@PQ21S6:DXHaQBU6<H@Q002
6<H010aS48@@Q1240QBU00@8@QBU00048@80000412400000124400000`@Q0000000400000`@Q0000
000200000`Q200000002000312420002Ool00`00Oomoo`0;Ool01@00OomoogooO0000goo00<<HdHa
Ool017oo00@8@WooOom>L`9oo`0B:DX@Q0Q2?Nl8@VLi125>LdYBOolHaWoo<Ha[FRDY124U:CF]0Woo
00E241BUNmh8@Woo00848@04JeYW>@@QOol236<05AS6BU8@Q1S6>Lh001S6:DXDY@00248U:@@Q=JdL
ig`0000mkacWBU8HaP02<H`020@Q248aS0Q2:DX@Q2DY36<26<H01B4836<0000024800PaS01@Li`aS
124HaQBU7>L48DHa248aS0Q2:DX]JacW124<HacW;F/Q236<0PQ200A241S612448@88@P08<H`Li`00
248YBS6<00048@8mk`848@056<IoogooOol0000=Ool00`00Ool<H`0936<00a2436<<H`0436<040Q2
48@Q236<=JdYBR487>LHaQBU48@DYAcW9BTYBS6<0SF]0S6<00@e[C6<;F/]J`<YBP049BTQ22488@P2
9BT022e[=JdaS24848@DYBDY;F/2:DX01S6<>LhaS1cW5:DLi`8YBP8aS08e[@05;F/Lia245:DLi`02
8@P00bDY:DXYBP039BT012487>LHaQcW0R4800<LiaS66<H00acW0QS600<@Q0aS36<02`aS0PQ220aS
0Q2400D<H`Q236<<Ha2400<<H`9oo`03001oogoo00]oo`0037oo00@007oo00048@80000412400000
124300000`@Q00000003124200000aS6=JdU:@027>L00`aS1240000224827>L01BU:9BTe[BU:;F/0
0bU:0RDY018LibU:8@PHaQcW6<H@Q1S6:DXDYC6<?Nl]Ja24124Lib485:D436<224802AcW6<HHaRU:
<H`YBRe[:DXHaP0224825:D00aS68@PU:@028@P27>L01b48248<H`aS5:DLiaBU008HaP03248@Q1S6
008@Q00324800000008000031240000000X000031240000000<000848@H00005124007ooOol0000=
Ool01`00OomoogooO01oofmk00=oo`03Kg]oofmk009oo`038@Q:DWoo00Aoo`08IcTicU:D001ooaBU
?Nm2409oo`05<HaooaS6Kg/8@P02Ool01ekgOomW>CW>JeYg_AS6009oo`04HaP]JaS6IcT2>Lh03BDY
DYAW>Cg_6<HDYC6<248DYA2436<@Q4YB008@Q00>O00aS1S6@Q0e[E:D:DY240aS9BT8@R48:DXQ208<
H`8HaP0B>Lh@Q4Ha000@Q1BU248HaRU:5:D@Q248124U:DYB36<Q20@Q0P0000/HaP@Q5:DQ20aS1240
00Q26<H8@PaS008@Q00?124DY@005:D0024824800124248Li`@Q9BT48@0000=oo`03001oogoo00]o
o`05001oo`aS36<@Q00336<01A2436<<H`aS48@00`aS0Q2400@<H`Q26<HaS0924004=JdYBR486<H2
5:D011S68@P]JcW>0dHa0d8@00PmkcF]=JdaS3F]>Lhe[Be[0bU:00D]JcW>BU9:DS6<008HaP03;F/i
cS6<008U:@05;F/YBQcW5:DQ2002<H`01Sg_AS5:DTYB?NlU:@8HaP079BTYBRe[<H`icSg_=Jd00c6<
00HU:AcW8@PYBRe[:DX38@P39BT00b486<H@Q00236<00a2436<<H`0336<010Q236<@Q0aS0PQ200<<
Ha2436<01@aS0Q2410aS00@@Q0aS36<<H`9oo`03001oogoo00]oo`0037oo00D007oo000000@Q0080
00<48@8000P48@0:248]Jc6<8@PYBQS61248@QBU36<2000010aS8@PU:C6<0be[00<U:B485:D00QBU
00PHaRDY7>LLiaS65:D8@QS60RDY00Xe[AS648@00124;F/<Ha24248<H`88@P8@Q08HaP048@Pe[C6<
;F/29BT010@Q36<Lib480QcW00XQ22U:9BTDYAcW9BT<HaBU124HaP8Li`8@Q0096<HDYA248@PDYAS6
124000@Q00<000031240000000H000<48@@000041240000012470002Ool00`00Oomoo`0;Ool01@00
OomoogooO0001Goo00Ug_@@Q<Haoof<HOolLigooAS400Woo015BU7oo124<Ha24Ool@Q5:DKg/DYCg_
@Q1oo`00>LiNmgoo009:DP0<?Nmoogoo6<HYBSW>AS5[FP007>L<Hgoo0Ukg00Pe[@Q2MkeNmd8@6<H]
JcF]0QS601ENmacW36<8@P00O00mka24:DY243F]124@Q1BU0016<@Q248@DY@aS9BT00QBU01d<H`00
E[D]JbU:?NlDY@@QAS4<HaS6248Q20Q2Mkd8@P0048@48@aS=Jd48@Q2:DXDYCW>124<Hb4800@]J`0?
6<HQ22U:124<H`Q29BT8@QcW9BT]J`aS000Q200000=oo`03001oogoo00]oo`03001oo`Q2008@Q08<
H`0348@DYA2400H<H`8@Q08<H`077>Le[D8@@Q0icRU:7>L00aS60QBU00<Q23F]@Q000dHa00=243g_
=Jd00S6<00H]JcF]>Lhe[Be[:DX29BT032U:=Je:DU:D?NlQ21BU9BTe[Be[7>LDY@@HaP058@P]Jbe[
>Li6<@02CW<02d8@;F/LiacW8@PYBS6<=JdicSg_>Lh00cF]00HYBQcW6<HU:C6<;F/29BT01b489BTY
BRU:9BTLia2400H<H`0348@<H`Q200<<H`04248<Ha2448@736<00a2436<<H`0636<2Ool00`00Oomo
o`0;Ool000aoo`04001oo`00124300000`Q200048@02124500003@@Q00048@Q2;F/LibU:;F/Q20Q2
36<@Q0aS00800004124<Hbe[=Jd2:DX00be[9BTQ20026<H02AcW8@PU:B487>L@Q1BU48@DY@03;F/0
1cg_36<48@Q2:DXDY@aS0088@P0436<8@QBU48@26<H01aBU=Jde[Be[<H`]Ja24008DY@0548@HaQcW
:DXLi`026<H022489BT@Q1BU248DYAS68@P248@01`aS6<HDYB48248HaP0000848@<0000324800000
00<00004124000@Q12430003124200000`@Q000000060002Ool00`00Oomoo`0;Ool02P00Oomoogoo
O01BU7ooG_LaS1240goo00Ig_Goo9BUooacW=Jd2?Nl01WooE[Eoogoo6<H]J`9oo`0:MkeBU3g_Nmh0
01cWOolLicg_CW<2E[D02gNm6<H48D8@001g_FLiMkdYBTic<H`00P0001mg_@@QF]HHaSF]001BU1cW
48@e[B48AS4@Q2DY36=l02DY248e[AcWJeXU:Cg_HaQNmacWOolLi`00=Jd@Q002CW<01P@Q9BT8@PQ2
48@000<48@0F;F/<HacW9BTe[@00125240@Q248DY@@Q?Nl48@0024848@aS;F/<Hbe[36<28@P03`@Q
7>L002U:000aS0aS48@48B489BT8@QBU248HaP03Ool00`00Oomoo`0;Ool00`00Ool8@P0436<00a24
5:D@Q00636<248@010aS48@Q23F]0T8@00@icRU:7>LHaP8Li`0648@8@Q249BTicT8@0THa00<mkcF]
<H`00Re[010YBRe[<H`aS2U:7>LHaR489BTaS48@BU8mkb485:DLi`8YBP047>LDYABU6<H38@P2:DX0
1c6<?Nm6<DHa@Q0icRe[008Q2003:DX]Jbe[00<]J`8YBP05;F/YBQS65:DLi`02<H`29BT021cW9BT]
Jbe[:DXQ21S648@436<248@736<0112436<<H`aS0a242`aS0Woo00<007ooOol02goo000<Ool00`00
Ool0000400001PQ212448@@Q00048@<000848@0;00048@Q2<H`YBS6<;F/U:@aS248HaP0200032480
1R48<H`aS36<;F/YBP<U:@0:8@PHaQcW7>LHaP@Q248@Q1cW8@P2<H`03ABU48@@Q00036<U:@Q236<@
Q0aS48@DY@aS00<HaP03<H`e[Be[008aS006;F/Q21cW8@PLiaBU0a2400PDYA2448@Q2124248<HacW
0b4800<DY@aS8@P00R4800@DYAS62488@P<000848@P000848@<0000412400000124200000`@Q0000
0002000010@QOomoo`003Goo00H007ooOomoog`048@2Ool02f<HOomoogooF]HDYGooIcU244HaOol0
0QS600@e[@0048AkgP=oo`0H;F]oocF]AS5NmgooG_LDYD8@7>MF]F]J=Jd8@Woo36=BU3W>:DXQ27oo
125247Nm0PaS00He[B489BT8@Ukg@Q02:DX05bDY@Q0]Jbe[124004icO00<HaS68@Pe[@aS5:DLiaBU
9BTHaRU:;F/icSg_9BT00SF]00T48@Q2001[FPQ2>Lhe[BDY6<H00PQ2018<H`@Q9BTDYAS6248Q2124
5:DU:C6<:DXHaQ24:DX@Q0aS48@28@P39BT03QcW6<H<H`@Q48@]JaBU248Lib4848@8@SW>1243Ool0
0`00Oomoo`0;Ool00`00Ool<H`0436<548@010aS248<H`aS0Q2400X<Ha248@Pe[D8@AS5243F]9BTL
i`8HaP0848@48@Q27>LicTHaBU96<@8mk`05>Lhe[CF];F/YBP02;F/032DY6<HDYAcW:DXicT8@?Nl]
JaS648@HaP8U:@048@PHaQS67>L28@P01AcW8@PQ22e[?Nl00THa00A243g_>Lhe[@8aS007;F/YBRDY
8@PLiaS67>L00RDY00DQ21S67>LYBS6<008YBP8Q2007:DXaS2e[9BTLiaS648@00PaS0Q2420aS00@@
Q0aS36<<H`<@Q0/<H`9oo`03001oogoo00]oo`0037oo00<007oo00000P0000L48@0000048@001240
00021242000212402P001248@RU:<H`YBSF];F/Q21BU0Q2400D000@Q24848C6<008e[@039BT]Jbe[
00<U:@037>L@Q1BU008Li`0=248@Q1BU5:DU:C6<8@P@Q000248<H`Q2<H`00PQ20`aS00P8@PaS6<HH
aQ249BTicS6<0Re[00HQ236<8@PYBRDY6<H248@01PQ2124000aS6<H8@P8@Q0045:DU:BDY9BT248@0
21cW6<HQ20aS6<H8@P001243000010@Q000000@Q0P0000<48@0012400P0000@48@0000048@<00003
124000000080000312400000009oo`03001oogoo00]oo`0:001oogoo36=l01S6OolU:B480002Ool0
0bDYBU9oo`08Ool07@@QOol@Q4Ha125kgWooF]H]J`aSF]H<HacW@Q1kgQ24>Lh]Jf<HOolQ22e[8@Q[
FU[F248mka2436<00Q2400LDYDYB124HaQcW12400002:DX04cW>AS448Ekg36<e[G`0AS4<HcF]000Q
25Je000Q20Q236<@Q1cW008<H`0;248@Q1247>MF]@@Q00048AcW0012400224805BDY0008@QBU9BT4
8@aS5:D8@P00124aS0007>L48ABU000<H`@Q48@HaP0212403aS6<H`002DY000@Q2489BTQ21S6<Ha2
40aS5:D00003Ool00`00Oomoo`0;Ool00`00Ool<H`0436<00a2436<<H`0248@436<248@236<021cW
=Je6<DYBAS52436<8@P26<H01ABU36<<HacW>Lh00THa0Sg_0T8@0SW>00<]JbU::DX00Re[010U:AcW
7>LYBSg_@Q0icRDY48@<HaS69BTYBR485:D@Q0@DY@8HaP05:DXmkdicDYA:DP03@Q001cg_=Jd]JbDY
8@PLiaS6008DY@037>LU:BDY008Q200=:DXe[C6<<H`U:B48:DXe[C6<:DXQ21S65:D00`aS00<@Q0aS
36<02@aS0a2430aS0Woo00<007ooOol02goo000<Ool01000Ool48@000P@Q1@0000<48@0000000`@Q
00L000@Q124002U:>Lh]J`02<H`01RU:36<DYABU00048@8000079BTHaQcW8@PU:BU:9BT00RU:00HQ
21BU5:DQ21S67>L25:D030Q28@PaS2DY36<48@0048@48BDY36<8@P<48@0636<48@Q2248@Q1S60Sg_
00<aS3W>8@P00Re[00l48A2436<@Q0aS48@<H`Q236<Q20aS7>LHaQBU6<H00R4800PLia246<HLibe[
6<HDYA2410000`@Q0P0000<48@0000000P000P@Q00<000@Q1240200000@48@0000048@9oo`03001o
ogoo00]oo`0>001oogooOoml07oo=JdQ27ooF]H8@R48Oom[FPAoo`0?>Li:DTYBCW=oobU:F]HHaPaS
9BT@Q0@QAS5BU36<00=oo`0@001oobDY7>L@Q3g_5:ES61BU?NmoocF]:DXaS7ooG_L2Ool07aS6001c
W5:D36<U:ABU;F]ooacW;F/002U:9BU247`0124U:AS6Ool48A24?Nl]JaBU>LhQ2000DY@YBQBU008i
cP0::DX8@THa248Q22e[6<H]J`00124224804`00<H`]J`aS5:DLi`@Q@Q0004YB36<DYBDY5:D48BU:
6<H@Q000008@Q0086<HDYB487>LQ2124>LhHaP80000348@HaP00008Li`=oo`03001oogoo00]oo`03
001oo`aS008@Q0@<H`04248<Ha2448@336<25:D03@aS248HaSF]BU9>LdYBAS4icRU:8@PLiaS6008@
Q0067>LaS3W>=JdaS3W>0Sg_0SW>01@aS2U:9BTYBS6<;F/Q21S69BTicT8@>LhQ212436<HaRU:;F/U
:ABU0PaS00<@Q1BU5:D00QS600XU:CW>CW=BU4icAS5243W><H`YBP<Q208Li`8HaP077>LU:BU:9BTQ
22U:=Jd00SW>00X]JbDY:DXe[CW>;F/Q21S65:D<H`88@P<@Q10<H`0348@<H`aS00D<H`9oo`03001o
ogoo00]oo`0037oo00@007oo124000<48@0400048@00000512403@Q2000000@Q000HaSF]:DXaS3F]
9BT@Q1cW008DY@0324848AcW00<HaP037>LQ224800<YBP069BTLiaS66<HYBQcW0Q2400/<HbU:=Jda
S0Q236<8@P@Q248e[A2400848@0436<8@P@Q124248@00aBU7>Le[@02=Jd013W>:DXQ20@Q0`aS00`8
@Q245:D@Q1BU36<Q21S67>LHaPaS9BT3:DX27>L01BDY;F/Q20Q27>L00PQ20`0000H8@P@Q12448@00
124;0002124010Q2000000@Q0`000Woo00<007ooOol02goo00d007ooOol<Hg`0:DYoocW>OolDYGoo
=Je:DP02Ool013W>OomBU7oo0WNm01@aS5[FOomoob48Ool@Q5Je248LibDY48AS62U:124YBPQ2DY@]
J`000Ukg00T@Q4YB248aS2e[E[Eoobe[48@00PaS01=ooa24000YBRe[249JeQBU:DX@Q3F];F]Nma24
@Q1l02DY124HaP027>L02PaS0016<Be[001240Q25:DQ21S60Sg_01d<HcW>:DX<H`@Q5:D48A247>LH
aUJe48@]J`@Q36<001S600048@Q2000@Q0005:D8@P00124<H`@Q008<H`8@Q00?;F/HaPQ2248001S6
36<003W>5:D0048@8@PaS12400=oo`03001oogoo00]oo`03001oo`aS00D@Q00536<8@PQ236<@Q003
36<25:D01@aS248DYBe[AS400Tic00I6<CW>:DXU:BU:8@P26<H01bDY;F/]JbU:;F/e[CW>00<mk`04
>LhaS2DY:DX2<H`03bDY6<HQ23W>AS4mkbU:5:D<HaBU9BTaS2e[9BTQ2003:DX04BDY8@PQ22DY<Ha2
44icDYA:DSg_;F/Q21BU48@HaQcW8@P00acW00LQ22U:;F/YBR489BTaS002>Lh02SF]:DXYBSF]?Nle
[BU:7>LHaQ240PQ200@<Ha2448@@Q0D<H`0348@<H`aS00L<H`8@Q0H<H`9oo`03001oogoo00]oo`00
37oo00H007oo000000@Q000312401@0012448@0012400P000P@Q0`0000<8@T8@<H`00SF]00<YBPQ2
7>L00acW00D@Q3W>8@PU:BU:008U:@03<H`e[CF]008e[@06:DXLiaBU8@PLia240QS600/aS2e[;F/]
J`Q2000<H`@Q;F/Q22e[00924003AS4e[C6<008icP8DY@077>Le[Cg_=JdaS1cW24800P@Q00`<HaBU
6<HDY@aS48@DYB485:D<Hb4848@48@P02AS648@Q22U:<H`U:AS648@48@0400000`@Q248000051240
0`Q200048@02124200000`@Q00048@0412400`0012400002Ool00`00Oomoo`0;Ool04`00Oomoogoo
O01oo`00OomF]Be[Ool8@P00AS4mkb48:DYS67>L0080000C;F]F]A24;F/YBWoo>LiF]D8@Kg/e[DHa
BU9oog_NHaP002DY00000Woo00D48@aSIcUW>@@Q009oo`03HaP<Hfmk0092400OCW=W>Be[8@QW>Ekg
6<H<HaS6001:DU:D124]J`aSO00e[AS67>M>L`00>LhDYAS6DYA24124=Jd@Q0aSAS400R4800L48Be[
36<Q2000>LhLi`02124031BU<H`<HaBU>Lh0012436<48@00>Lh8@P80000836<8@Q24000DY@aS9BT8
@P8YBP075:DHaQ247>LDYBDY48@00`aS00DQ22DY24848A2400=oo`03001oogoo00]oo`04001oo`aS
36<548@236<248@336<248@02@aS248@Q2DY?Nm>Le:DAS4aS0029BT2:DX022489BTe[Cg_=Jd]Jc6<
?Nl2AS43BU800cW>:DXYBP02<H`032DY8@P]Jd8@CW=6<C6<6<H8@PaS8@PaS08e[@05@Q1>LdYB?Nla
S002;F/04RU:9BTaS4YBF]IBU3g_;F/Q212436<DYB489BTQ21cW8@PYBP<]J`8U:@07;F/icSW>>Lh]
JbDY<H`00Sg_00@e[BU:8@PDY@<<H`0348@<H`aS008@Q08<H`<@Q00436<@Q12448@436<348@536<2
Ool00`00Oomoo`0;Ool000aoo`03001oo`00008000H48@0300048@@Q00848@0300048@@Q00848@04
000U:C6<;F/2<H`030aS6<H8@QcW124]Jc6<:DXe[BU:9BTaS08icP<mk`05:DXQ21BU7>LYBP026<H0
3R48<H`e[CW>9BT<H`001248@RU:36<U:D8@?Nl2=Jd01P@Q48@@Q1245:D@Q08mk`8e[@038@PYBPQ2
0088@P0648@<HaBU6<H<HbDY0R480QcW00<U:ABU8@P00b4800LDYAcW8@PaS2U:48@Q200412480000
10@Q000000Q20P@Q100000@48@0012448@@0009oo`03001oogoo00]oo`05001oogooOoml0005Ool0
1`aS5:EoofmkOomBU5kg009oo`8U:@05E[Eoo`aS9BUJeP03Ool29BT2AS401PaS001242U:249S6080
000;<H`HaUkg48@48A24AS4@Q5:D48@]J`028@P07`@Q001BU248?Nl006<H248<HacW=JdQ22U:7>L4
8G`08@P48D8@9BTDYBe[>Lh48ABU124]Jcg_000YBRe[00848@09AS4000005:D001S6248@Q0000092
400D:DX48CF]5:DLibU:000@Q2e[48@HaRe[AS4LibU:5:D<HaS612400088@P057>LDYABU8@PLi`02
48@020aS9BTYBQS6000YBRe[8@P3Ool00`00Oomoo`0;Ool00`00Ool<H`0236<548@010aS48@@Q124
0PaS0Q240`aS00lHaRe[AS5>LdYB=JdU:AcW8@PU:BU:>Li:DTicAS400Sg_00=6<DicE[D00U[F00AB
U3g_;F/YBP8aS08]J`06>Li:DUJeE[E242DY0PaS00PLibU:;F/e[DYBE[E>LcW>0be[014U:B48;F]:
DU[FDYA6<CW>;F/Lia246<HQ22DY8@PU:BU:00@aS003;F/YBRe[00<e[@0:;F/U:C6<?Nm6<Cg_<H`U
:AS648@536<248@436<548@336<548@436<2Ool00`00Oomoo`0;Ool000aoo`04001oo`0000061242
00021242248010@Q00048@@Q0P0000`@Q2e[7>LicRe[248<H`Q248@8@THa>Lh2<H`01Be[:DXYBS6<
>Lh00cF]00HU:AS636<Q236<7>L28@P2>Lh2BU801Q24124000@Q48@HaP88@P0348@48@aS00<<H`03
6<H<Ha24008icP<e[@087>LQ21BU36<48ABU6<HLi`8Q200636<U:BU:48@U:B480QS600PQ21cW6<HH
aRU:<H`]JbDY0QS61P000`@Q10000P@Q100000D48@Q2000000@Q00D0009oo`03001oogoo00]oo`05
001oogooOoml0002Ool034Ha<HaW>G_NAS5ooe:DCW=oo`Q2OomS608Li`0=Kg]g_GooOolDYEJeBU9o
oacW48AooeJeG_L00R4800@mk`00Mkd]J`8aS003HaPLicF]009W>@055:D48AS6?NlU:@03AS407Woo
Kg]6<AcWE[De[EkgF]HaS1S6DY@]J`@Q48Al0000<H`LidHa248mkb48@Q0aS0@Q248@Q48@248]J`8Y
BP0ABU8DY@@Q9BT@Q1BU36<aS2U:6<HLiaS648@mk`008@PU:@021240300048@]Jb48000@Q0Q2124i
cQ2436<aS08HaP0?36<8@Re[48@<Ha248@PHaP0036<@Q2DY7>L48@0000=oo`03001oogoo00]oo`04
001oo`aS36<548@336<248@236<348@04PaS248@Q248>Li6<DYB?NlYBQS648@HaSF]CW=F]DicAS52
4096<@06BU9BU5[FF]I>LcW>0RDY00XaS3W>>LhaS3F]AS5F]EkgCW<YBP8<H`086<HQ22489BT]Jc6<
;F/U:@<Q20047>LQ22e[AS42E[D02Tic@Q0icRe[8@PHaQcW8@PYBRe[1C6<00<e[C6<;F/01Be[00Pa
S3g_@Q1243F]:DXLia240`aS00<@Q0aS36<01PaS11240PaS0a240PaS00<@Q0aS36<00PaS0Woo00<0
07ooOol02goo000<Ool00`00Ool48@0212400`0012448@0300000`Q212400003124200001P@Q0008
@QBU;F/U:@8icP8<H`848@03;F]F]CW>008]J`04:DXaS2e[=Jd3>Lh012e[7>LHaQ240RU:00<LiaS6
7>L00S6<00i243W>2488@P@Q248<HaBU48@<H`@Q248@Q0Q20P0000TQ21245:D]Jcg_=JdicSg_48@0
0R4800d<Ha2436<DYAS65:DQ21BU7>LU:AS67>LU:@0224801Q248@PYBQcW;F/YBP8]J`0336<HaP@Q
008000<48@<000031240000000D48@0400048@00248312400`00124000020002Ool00`00Oomoo`0;
Ool02@00Oomooa24O01oodYBOol00002Ool0236<OolDYG_N@Q0LigooKg/2<H`03EJeAS5BU0aSAS44
8Ekg=JdHaS6<Oole[BU:009oo`047>L<H`Q29BT2?Nl02Tic8@P48@aS1248@Re[7>LaS1S60S6<01mo
obDY8@PQ248@0008@Sg_8@QS65kg6<He[C6<E[El02e[124@Q000IcT@Q48@>Li2436<BU8DY@Q2BU8e
[@0248@07be[6<HLibU:48A:DP007>LQ2000248@Q0aS;F/HaP@Q00048B48>Lh@Q0aS9BTHaQBU1248
@S6<8@P8@R48009BU00?000U:AcW124DYA2436<000@Q8@P@Q0aS000HaTYB00=oo`03001oogoo00]o
o`03001oo`aS00<<H`<@Q0<<H`L@Q08<H`0@5:DU:CF]@Q16<D8@;F/@Q0@Q6<I245kgF]I243W>@Q03
AS404DYBCW=>Ld8@<H`U:BU:=JdmkcW><H`]Jcg_E[EJeTYB9BT00PaS00DDYB488@PHaQ24008<H`0<
48@DYAS66<HLib48:DXicTicF]IBU48@0SW>00HaS1cW5:DLibU:;F/3:DX01Be[<H`e[CF];F/00bDY
00daS3F]=Jde[Cg_AS4mkbe[8@PDY@aS248<H`0248@736<248@336<648@536<2Ool00`00Oomoo`0;
Ool000aoo`05001oo`0000048@03000010@Q000000@Q100000<8@P0012400P@Q00@<Ha24=JdHaP8e
[@040008@P001242CW<01Re[<H`aS2e[=JdaS08e[@@]J`8Li`03:DXU:B48008Q2004<H`]JcF]8@P3
12400`0048@HaP0236<00`Q236<@Q0035:D011S648@@Q1S613g_00dQ22U:=Jd@Q0Q248@HaQ245:D@
Q1BU8@PLi`029BT022U:5:DDYABU:DXU:B486<H2;F/013F]9BTLiaS60P@Q0P0000L48@0000048@00
124000031242000010@Q248000@Q0P0000<48@0000000`000Woo00<007ooOol02goo00P007ooOomo
og`0OomS67>L0Woo00QF]GooHaQW>Dic249oofLi0goo00PU:D8@CW<e[@00?Nm:DUJe0Woo01E>Lgoo
48@@Q5:D9BT]JdHa<H`DYCW>6<HLif]J<Ha240008@Q:DV<HKg/00QS600]oobe[5:E24124:DY>LgNm
5:DLicF]0088@P0BBU88@W`0;F/HaR48:DXDYCg_48@icQcW8@PHaP@Q000<Hcg_0Q2400@icQcW7>Le
[@88@P0C36<U:C6<BU8@Q2e[8@P8@SW>7>L@Q0aS00048BDY6<HLi`Q2@Q000P0000@48@aS000Li`84
8@05248Li`@Q9BT<H`027>L010aS248Li`Q20QcW00<DY@@QOol00Woo00<007ooOol02goo00<007oo
48@00PaS0Q240`aS0Q2400<<Ha2448@0112400TDYAS68@PaS3g_AS5:DT8@9BT00PQ200@]Je[FIcUF
]@8mk`05AS5:DTHaAS5:DP02AS4013g_=JdaS36<0SW>00Pe[Be[;F]245:DCW<e[AcW0PaS00TDYB48
:DXQ2124248<HaBU7>L01B4800DaS4YBG_MJeTHa008icP04=JdYBQcW7>L28@P021S67>LU:Be[<H`e
[CW><H`39BT03CF]>Lhe[C6<?Nm:DTHa>Lh]Jb485:D<H`Q200<@Q08<H`8@Q08<H`0448@<H`aS36<3
48@010aS48@@Q1241@aS0Woo00<007ooOol02goo000<Ool00`00Ool48@0212401@0024848@@Q0000
10@Q10Q200T@Q2DY6<He[BDYBU96<Cg_=Jd00P@Q00`0036<F]I243F]:DX]Jcg_<H`icRe[=Jd2;F/0
0bU:9BTYBP02:DX02BDY;F/Q22DY;F/e[C6<9BT8@P0212402@aS48@aS2DY36<8@P00124DY@0248@0
10aS5:D@Q1240Sg_00Xe[D8@>LhHaRDY<H`Q22U:5:D@Q08<H`8Li`035:DYBRU:00<Q20065:DLibU:
7>LU:B480cF]00@<Hc6<124000D48@0600048@@Q248000@Q0`0000<8@P00000010@Q0`000P@Q0Woo
00<007ooOol02goo01<007ooOol@Q7`05:D]J`aSE[D@Q248Nmh<Hgoo249oo`00G_L00002Ool07bDY
:DXYBWoo5:DHaU:DAS4aS1cW9BU6<G>LCW<DYGoo>LhQ24HaOolmk`aS00048DicE[D<Hbe[248icRDY
008]J`0O7>L@Q0Q2BU8001S65:DU:@Q2124@Q2DY24848A24O00001cW6<H8@P@Q000HaRDY>LhaS3F]
48@HaS6<E[D00P@Q00`002e[124DYBe[36<003g_00048@0036<2=Jd011BU000<HdHa0PaS00/@Q1BU
7>LaS000124@Q3g_248@Q36<008U:@05000Li`Q2>LhaS002000021BU7>LU:ABU9BTLi`009BT3Ool0
0`00Oomoo`0;Ool01000Ool@Q0aS0a240PaS0a2400<<Ha2448@00a2400HLibDY;F/aS3W>BU82E[D0
3Cg_6<H001S6BU9_Nf]JCW=244YBDYA>LdYB009>L`96<@@mk`8icP0<=JdaS3W>AS5>Lcg_9BTDY@aS
48@HaRDY0Re[00@Q21cW7>LQ20@U:@8Q2006:DY6<E[FG_MBU48@0cW>00<aS2e[9BT00QcW00LU:Be[
<H`aS3F]>Lhe[@02;F/03bU:<H`icSW>=JdmkdYBCW=6<CW>;F/Q2124248<H`0348@010aS48@@Q0aS
0a240PaS0Q240`aS0Q240`aS0Q240Woo00<007ooOol02goo000<Ool00`00Ool000022482000010@Q
00048@@Q1@0000<<H`0048@00RDY00lYBQS69BUF]CW>5:D8@P0036=:DTic@Q0e[C6<?Nl00c6<00<e
[C6<<H`00S6<00lU:B48>LhYBR48:DXU:B48;F/icRDY36<000Q212400PQ200LLia24000Li`aS48@L
i`0348@05QcW48@DYBDYAS4icSg_@Q0DYAS6?NlHaQBU6<HQ21cW8@PU:Be[7>LU:AcW0bDY00LDYAS6
;F/U:C6<9BTe[@02;F/012U:8@P@Q0@Q0P000`@Q00<000@Q00000P0000D8@P@Q000000@Q00@000<4
8@8000848@9oo`03001oogoo00]oo`0?001oogooOoml07>LOole[CW>7>Mooe:D@Q1oo`@Q009oo`0E
48AooekgG_L8@RU:OomkgV<H@Q0YBR48Ool@Q2U:001kgRU:001ooacW008@Q00<Li`U:Cg_8@P8@Woo
HaP@Q5:D125:DWNm0Q2401DYBP@Q9BTe[B48248YBPQ2HaP8@SF]<Ha2424836=l01BUG_L48@Q27>L0
0PaS00P@Q0@Q=Jd<HdHa8@P<HaS60R4800L003W>48@@Q0@Q0008@P027>L200002Q245:D]JbU:@Q04
8BU:9BTYBS6<0PaS00Q:DRe[248@Q0@Q248002480QBU0PQ200d001S66<H@Q0@Q48@DYBDY124HaPaS
000@Q003Ool00`00Oomoo`0;Ool01000Ool<H`aS0a2400@<Ha2448@@Q08<H`@@Q00F6<H]Jcg_@Q0i
cSg_DYAW>F<H>Lh<H`@Q:DYJeVmkG_M:DTHaCW=BU4icBU82CW<2AS44@Q05?Nl2AS4023g_:DXHaQ24
5:DHaR489BT2:DX012DY8@PU:BU:0RDY0b4800/YBSW>DYAS65kgAS4icSF]?Nm243g_00<e[@03>Lhm
kcW>008e[@04>LhmkcF]=Jd2;F/03CW>?NlicSg_AS5:DTHa>LhaS2DY5:D8@PaS008@Q08<H`8@Q08<
H`8@Q0D<H`04248<Ha2448@336<248@2Ool00`00Oomoo`0;Ool000aoo`06001oo`0000048@0010@Q
00@000@Q00048@<0000A248]JcF]=JdaS2e[?NmJeTYB48@000aS7>M6<D8@?NlYBP02=Jd2<H`2=Jd0
436<>LhicRe[9BT]Jc6<;F/YBRDY:DXe[BU:;F/LicW>0a2400H<H`@Q124DYB485:D66<H35:D01AcW
?Nm6<Cg_AS400R4800LYBS6<>LhmkcW>=JdaS002=Jd28@P012e[8@P]Jbe[0QcW00XYBRe[:DXYBS6<
;F/aS3g_5:D]J`H000848@<0000312400000008000031240000000848@0600048@@Q00048@000Woo
00<007ooOol02goo00H007ooOol8@W`0=Jd224802aS6?Nm:DWoo=JdaS3F]IcU[FR48>Lh00PaS00AW
>A24<H`aS09oo`0;Liaoogoo:DXicPQ2@Q0@Q5kg248@Q002Ool01P0048@DY@00Ool<H`8Li`041256
<E[F;F/348@01@Q2AS4aS0@Q;F/00PQ2014001S65:D002e[>LhLig`0;F/48Ekg48@48AcW000LicF]
008mk`04124LiacW5:D2000030Q25:D]J`009BTDY@aS6<H]J`@QAS4@Q088@P0A000icPaSAS4Q2124
AS4Li`@Q000U:@Q29BTHaRDY7>LHaP029BT03aBU>LhLibDY124mk`006<HDYB48124YBRDY<H`48@03
Ool00`00Oomoo`0;Ool01000Ool<H`aS0Q240PaS0Q240`aS00H@Q0aS36<<HaS6>Lh2DY@2AS402Ukg
Kg]Nmbe[36<DYCW>E[EJeTic0THa00A:DTicBU96<@9:DP96<@07@Q0mkd8@AS5:DTHa@Q000cg_0T8@
00<icRU:7>L00QBU00HLibDY:DXU:B487>L58@P01BDY:DXYBS6<BU800Ukg00I>LcW>=Jde[Cg_AS42
BU82AS401T8@?Nle[CF]?Nm2408icP8]J`03=Jdmkcg_008mk`924004?NlicRU:5:D236<0112436<8
@PaS0Q240PaS0Q241`aS0Q240`aS00D@Q0aSOomoo`0000eoo`0037oo00<007oo00000`0000<48@00
12400P001`@Q00@]JcW>?Nm:DP96<@09?NlicQS61248@Sg_<H`U:Be[008aS006>Lhe[CW><H`e[Cg_
0Re[00Le[C6<>LhicT8@>Lhe[@029BT01CF]:DXU:DHa7>L00QS600@48A24:DXaS08<H`0348@00000
008DY@0E248HaR487>L@Q3g_>Lhe[Cg_=JdDYAS6:DXe[AcW;F/icRe[6<HU:B4800<]J`8aS00448@<
Hb488@P4:DX01acW?Nl]Jb4836<000@Q00@00088@P030008@P0000<000848@052480000000048@03
00001@@Q001oogoo00003Goo01<007ooOomNmg`048@U:AcW;F]W>CW>9BTaS0aS6<HLieJeCW<<H`02
:DX01goo:DY_N`aSOolmkgoo008Q2088@P0:001g_GooLi`U:AS6Oom243F]HaP2;F/023g_124aS5kg
JeYF]@0048@25:D02QcW36=6<A245:D@Q6]J7>L]JcW>0THa00hLi`Q28@Ql00aS5:DU:@aS;F/mkaBU
248HaRU:0`@Q00h8@QBU:DXYBP@Q36<]JbDY48@001cW6<H<HbDY0Q2401<8@Q24248@Q000:DX48AcW
36<48@Q2AS4DYA245:DLia2436<48@026<H03`002488@PaS24848@005:D@Q48@248DYBDY5:DLi`03
Ool00`00Oomoo`0;Ool00`00Ool<H`0736<448@336<011S6=JeBU5[F0U:D00QS66LiBU8Q21BU:DY6
<DYB0T8@00=:DU:DCW<01dYB00=6<D8@AS400U:D00A:DSg_>Li24096<@924009?NlaS1cW5:DLibU:
;F/YBR48008HaP057>LQ22489BTYBP029BT02be[@Q1F]EkgDYA2436<;F/aS3W>?Nl00d8@00HmkcW>
>Lhmkd8@?Nl2=Jd0136<;F/aS3W>0T8@00LicSF]AS5BU4YB<H`HaP0536<348@736<748@436<2Ool0
0`00Oomoo`0;Ool000aoo`03001oo`@Q00800003124000@Q008000<48@0300048@@Q00848@8Q200C
>Lhe[CF]CW<aS2e[36<HaRU:@Q0YBRe[>Li6<DYB?NlicSF]9BT00S6<0RU:00@icRe[>Li2408e[@0C
8@PU:CF]>Lhe[BU:?NlaS3W>:DX@Q0aS48@e[AS636<HaPQ248@00QBU00X@Q0aS48@@Q1S69BU243W>
?Nm2408DY@048@P48@aS124248@26<H00acW:DXmk`038@P01BU:7>LQ21cW;F/00RDY00H<HbU:E[E6
<ABU:DX4000212401000124000@Q0P000P@Q00@000@Q1248@PD48@<0009oo`03001oogoo00]oo`0C
001oogooOoml07oo001JeVLi5:DYBUJe248e[@@QG_M6<AcW:DX00QS600L006Li8@PQ23g_8@Q[FP02
24803Q24<Ha>LgooE[E[FQ2436<Li`@Q9BTmkdHa8@P248@01U:D8@Q:DTic@Q0Li`8Q200748@000@Q
24848AcW:DX00P0000dHaRe[248YBW>LMkel01BU248mkcW>G_LaS0029BT01c6<Nmhe[@@Q000YBSF]
008HaP0>9BT48BU:36<Lia24248DYCF]124]JcW>9BTDY@848@067>L@Q3F]124icSg_0PaS00LHaQcW
<H`e[AS6<H`48@02:DX03aBU248LibU:125[FRDY8@P48A24248@Q2U:9BTLi`03Ool00`00Oomoo`0;
Ool00`00Ool<H`0336<248@236<00a245:D@Q00336<02Q246<HU:CW>DYANme[FE[E:DS6<0R4800Pi
cTYBAS5244YBE[EJeUJe1dic0TYB01ABU5[FE[E243W>@Q1>Le:DAS5244YBDYA:DSF]8@PLibe[>Lha
S2DY0aS60QcW00/Q22DY9BTU:Be[?NmBU5kgF]I6<CF]00<]J`0:8@PLibU:=JdaS2e[=Je6<DYB@Q02
>Lh013F]<H`]Jc6<0T8@0S6<00M:DVLiG_Lmkb485:D@Q002248011245:D@Q0aS0Q240PaS1A2400@D
YA2448@<H`8@Q0<<H`9oo`03001oogoo00]oo`0037oo00L007oo00048@001248@P0200000`@Q0004
8@0600003@aS124icTHaDY@@Q0@Q8@P@Q1cW:DXicR4800924008?NlicSF]=JdicSF]?NlicP8mk`0<
;F/e[CW>?NlaS2U:8@Pe[DHa=JdaS2U:0Sg_00=243g_7>L00Q2400DQ21cW5:D@Q0Q200<<H`88@P04
7>LDYAS66<H2@Q001SW>=JdQ21cW<H`<H`8HaP0848@U:CF]7>LQ23F]<H`YBP8]J`03=Jd]JacW008U
:@0=<H`YBR48=JeJeTYB:DXQ212424848@0012400PQ20`0020@Q00P000Q2000000@Q00048@000Woo
00<007ooOol02goo01<007ooOomoog`0125ooekgE[DU:G_NAS5>Lc6<6<H001BUG_L8@P02Ool02@@Q
Oom6<AS6F]H002e[OolLi`02Ool0548@7>L8@UJeLi`<HfmkDY@HaRU:;F/aS0@Q8@QF]GooJeX48ABU
@Q0248@02E[F:DX<HbU:G_LLia24:DXU:@0212401TYB000DYA24O00HaP8Li`0948@002e[36<e[@00
=Jd001cW008DY@<Li`0>;F/DY@aS48@<H`00248@Q36<7>LDYBDY=Jd0008aS00?48@8@QS6000YBRDY
36<DYB4848@]J`00248U:ABU0080000?248HaPaS8@P48@006<H8@P@Q6<H000Q2<H`Lib4800=oo`03
001oogoo00]oo`03001ooa24008@Q00436<@Q12448@236<25:D336<25:D01Q248@Q245[FE[DicP8Y
BP0:<H`icT8@AS5:DU:DF]IS65kgE[D2DY@00dicBU9>L`02CW<01DYBCW=JeU[FCW<00SW>00a:DUJe
DYA:DTHaCW=Nmf<HDY@e[B48:DX2=Jd012DY7>LQ22480QS600/DYAcW8@PU:BU:>Li>LekgF]I:DSW>
008aS00;:DXDYA247>LaS2e[9BTaS4HaCW=24002?Nl0548@?NlYBRU:>Li243F];F]:DV]JIcU6<Be[
8@PHaPaS248@Q1BU48@236<00a2436<<H`0248@00aBU48@@Q00348@236<248@01@aS48Aoogoo0000
3Goo000<Ool02000Ool8@P@Q00048@00248312400`001248@P0312401P0036<48B48>LhQ208HaP0<
124e[CF]=JdicS6<@Q1>LdHaBU96<CW>0cg_0be[0SF]01LicSg_?Nl]Jb48?Nm243F]<H`icTHa?Nm:
DUJe=Jd@Q0aS6<H@Q1cW5:D@Q0aS008Li`0436<001BU6<H25:D01D8@AS4e[CF]?Nl00QcW00Pe[@Q2
7>L<HaBU6<HDYAS60RU:00De[BU::DX]Jc6<008DY@0<6<HQ22U::DXQ248@AS5241BU:DX48@Q20`@Q
00H000@Q00048@00124200000`@Q24848@02000212401@001248@P@Q00000Woo00<007ooOol02goo
00D007ooOomoog`0009oo`0<CW=ooe:DNmi>LaBUOom:DWoo:DYoocW>0Re[00=oo`00IcT00TYB01Xe
[GNm:DXU:ABUCW=NmgooG_LDYGooBU8@Q248OolQ21cWJeXe[@aS<H`48B48OolicP@Q0R4801=6<ABU
;F/LicW>6<HLi`aS7>L<HcF]7>LaS2e[Ooml01BU248000027>L02SF]7>L<H`aS000icRDY124@Q2DY
0Sg_00QBU00048@HaRU:@Q0Q20Q20QcW00`<HbDY000HaQ247>L8@QS6124]JbU:=Jd28@P01be[5:D4
8BU:248<H`@Q009[FP05:DX8@Q249BT<H`028@P00aS60008@P027>L00`Q2000YBP03Ool00`00Oomo
o`0;Ool01@00Ool@Q1BU48@00PaS0QBU0PaS00<@Q1BU48@00Q2400/DYA2436<HaSW>DYA6<BU:5:DU
:Cg_009>L`03BU9>Lekg009[FP05F]IBU5:DDYA>L`04BU806DHaBU9BU5JeBU8icT8@DYAF]DicBU9>
LeJeHaQ[FVLiBU8U:AcW;F/aS2U:7>LQ22DY008HaP0348@HaRDY008U:@06<Ha:DUkgF]I>Lcg_0SF]
00@aS2e[9BTYBP8aS005;F/aS3W>@Q0mk`02@Q02BU803SW>9BT]JcW>?Nle[Cg_E[ENmdic>LhYBR48
5:D236<248@336<00a2436<@Q00748@236<348@010aSOomoo`003Goo000<Ool01@00Ool48@@Q2480
0P@Q00L000Q212448@001248@P03124010Q26<HaS1240Sg_00TQ20Q26<HYBT8@>Lh]JdYB@Q000U:D
00=243g_?Nl00SF]00<mkbe[>Lh00SW>0SF]00DicSF]<H`]Jd8@008e[@0?;F]244Ha@Q16<DYB?Nl8
@Q24@Q048Be[8@P8@PaS008@Q0848@055:DLiaS648@]J`02@Q003cg_@Q0@Q1S68@PmkaS69BTe[AS6
5:DYBRDY8@PDY@03<H`03SW>@Q0HaQBU8@PU:Be[:DXU:CW>BU8U:AS68@P200021242000010@Q0000
00@Q0P0000L48@0024848@001240000312420002Ool00`00Oomoo`0;Ool04`00OomoodicO01S65:D
OolmkdicF]H8@THaOol8@Woo124aS2e[009oo`0LE[DU:E[FF]IcW4YB@Q16<BDY36<icPQ2IcU6<@aS
BU9W>CF]HaQF]D8@=JdYBS6<7>L8@QBU8@P2>Lh08UJe2488@P00248icP00124<Hc6<DY@HaRDY5:E6
<@@Q7>LYBW`0001S63F]6<I>Lekg36<DYBe[36<Q22DY7>L48BU:0PQ200HLiaBU>LiJeQ241242=Jd0
5b48G_LQ236<36<U:@00124000@Q248DYA24124002U:124LibDY=JdHaPQ26<H00PQ200/48D8@000i
cP@Q48@Q20@Q5:D002e[008@Q003124007oo009oo`03001oogoo00]oo`03001ooa24008@Q08<H`03
48@DY@aS008<H`0A5:D@Q0aS36<@Q1S68@P]Jcg_BU96<C6<6<HLicW>E[EJeP02DY@015kgJeY[FU[F
0Tic15:D0Tic0THa0Tic00E:DTHaBU9BU4ic009:DP03DYAF]Ekg009W>@04CW<YBQS68@P2<H`00bDY
7>LQ20027>L26<H04B489BTQ22U:?NmF]F<HF]I6<CF]<H`icTHa@Q0icS6<=Jd00SW>0S6<00Te[Cg_
?Nm>LeJeBU8e[BDY<H`00T8@00TicSg_DYAF]DHa<H`Q21cW5:D00PaS0Q240PaS0Q240PaS00<@Q1BU
48@00PaS0Q2400D<Ha2448@@Q0Q2009oo`03001oogoo00]oo`0037oo00<007oo12400P0000<48@00
00000P@Q0P0010@Q01T000Q2=JdU:CF]AS4aS2485:DHaP00;F]BU3W>?Nm6<D8@AS4icSF]>LhaS3W>
AS4mk`02=Jd01S6<=Jd]JcF];F/icP8e[@0A;F/aS2U:=JdmkdHa>Li>LdYB48@8@SW>124U:B4836<8
@P0236<01aBU124DY@Q25:D@Q1BU0096<@92400=9BTLiaS6<Ha24124;F/Q22e[=JdHaR485:D00SF]
0Sg_00DicT8@7>LQ21cW008YBP088@PYBTHaBU8DYBU:5:D8@P848@0300048@@Q0080000524800000
2480000212400`002480000212400`0012400002Ool00`00Oomoo`0;Ool04`00OomoofmkO01BU4ic
=JeW>GNm;F]cW0Q28@P<HacW124000@Q00=F]@0>DY@icQBU8@Q247ooNmiooacW6<H@Q36<CW<@Q08U
:@0>5:DU:Fmk9BUS62U:248DYBU:G_LLibDY8@Qoo`8icP0D;F/U:Cg_8@Qg_AcW8@PHaSg_36<002DY
8@P8@RU:O0048@aS00048@8YBP09AS4001248@P48AS6:DXQ24Ha008<H`03248<H`@Q008Li`0J248Q
20Q25:DLibU:36<HaQcW5:D<HaBU36<YBSF]124@Q36<36<8@SW>000DYA247>L<H`8e[@0?<H`<HacW
6<HLi`001248@P@Q7>LYBPQ2124Li`aS00=oo`03001oogoo00]oo`03001ooa24008@Q0<<H`8@Q004
36<@Q1BU48@236<00a24:DY24002BU801dicDYA242DY6<HYBTHa00=F]@04G_MS65kgF]H3DY@00eJe
F]IF]@02DY@00dicBU9:DP02BU800dicDYA>L`03BU800dicE[EJeP02G_L02DYB;F/Lib48=JdicRe[
7>LHaP027>L26<H01QcW8@PQ2248=JeBU09W>@0>DY@icRe[<Ha6<DYB?Nl]Jc6<?Nm243F]<H`e[@8m
k`0EAS5BU5JeBU8aS2U:>Li243W>=Je6<E[FE[DicRU:8@PLia24248<Ha2400<<H`L@Q00336<@Q124
00@@Q004249oogoo000=Ool000aoo`04001oo`@Q1246000010@Q000000@Q0P0000l48C6<DY@e[Cg_
=Je243F]248DY@@Q48@]JcF]@Q000SW>00LmkcF]<H`mkd8@>Lhmk`03>Lh2<H`03be[<H`aS3F]@Q0i
cSg_;F/mkcW>=Je:DSg_BU8U:@0224801ABU124]JacW248010aS00@DY@Q2124Li`8@Q005BU96<DHa
CW<e[@026<H02QcW9BT]JacW5:D]Jc6<8@PicRDY0Re[00TU:B48>LhaS2e[7>LYBRDY;F/00RDY00HY
BT8@>Lh@Q24848@21240100012448@001@@Q00@8@P@Q0008@P8000@48@04001oogoo000=Ool03000
OomoogooO01:DWoo:DYoodHa7>L0008@Q005BU8<H`@Q36=g_@02:DX0148@124mkg_N0QS601Moocg_
JeXHaS6<9BUooaBU?NlLiaBU6<H<H`Q2<Ha6<A24248aS1S6DY@48AS6008@Q08<H`03;F]>L`@Q008Q
200JCW<e[B486<H48@008@PDYBe[7>Ml03F];F]:DSW>5:D8@T8@9BU:DPaS48@YBP0024848@8]J`09
AS4e[Dic7>L000aS8@P@Q1cW008Q2003000@Q1cW008<H`04248U:@005:D200000b48000Q20025:D0
112436<8@RDY0SF]00@DYCg_48@0008<H`09?Nl001cW6<HLibU:5:D48@aS00=oo`03001oogoo00]o
o`03001oo`aS008@Q00436<8@PaS48@236<248@01`aS2488@QcW?NmF]E[F009BU003E[E:DRe[008H
aP09:DXmkdicF]INmeJeCW=BU5Je00=BU09F]@ABU006BU9244HaDYAF]E:D0TYB00Y>Le:DE[ES66Li
F]I242U:9BTYBP8aS003;F/U:AcW008HaP8DY@8Li`0;6<HQ236<CW=W>F]JG_M6<Be[9BTaS002>Lh2
<H`013W>?Nm243g_0d8@00Dmkd8@CW=BU4Ha008aS00?>LhmkcF]>Li:DUJeCW<e[BDY8@PHaPaS248<
Ha24008<H`0448@DYABU5:D448@236<548@2Ool00`00Oomoo`0;Ool000aoo`03001oo`@Q00<48@80
00031240000000D48@0436<aS3F]>Lh2;F/03D8@:DXLiaBU48@48@aS9BTe[Cg_=Jdmkd8@008icP04
@Q0mkc6<@Q02?Nl2@Q001S6<;F/]JcW>?NlicP8e[@0?>Li6<D8@DYA:DTHa7>L<HaBU?Nl<HaBU1252
40Q2008<H`0548@00124248<H`0248@00dic@Q124002AS402ABU7>LLiaBU7>Le[AS68@PDY@03:DX2
9BT02AcW9BTU:DYB:DX]Jb489BTQ2002;F/29BT01Dic;F/@Q2U:5:D00`000P@Q0P000`@Q00@8@P@Q
00048@8000848@0324848@Q2009oo`03001oogoo00]oo`09001oogooOoml036<BU8aS5kg009oo`08
AS5W>@Q2;F/<Hdic000mk`8icP03E[Dmkekg00848@0J7>LU:ABUNmh@Q4icBU8HaR48124DYCg_Kg/U
:EJeDY@U:@@Q8@QBU5kg248icTic248]J`9kgP0O=JdDYBDY?Nl8@PaS=Jd@Q000248<Hc6<5:DHaQBU
O00HaP007>LicP@Q249240Q2124@Q1BU248]JaBUG_L00PaS00PicQ24=JdDYB48DY@48@000P@Q00/Q
21S65:D8@QBU9BT48EJe124e[Be[008Li`08124002DY124<HcF]6<H@Q08DY@0348@HaQS600848@03
0008@P@Q00<00004124DYBU:36<3Ool00`00Oomoo`0;Ool00`00Ool@Q00248@2248248@01@aS248<
Ha2424800PaS01@Q24HaE[EBU4YBCW=BU4YB<H`LiaBU6<HQ23F]BU9JeUJeCW=:DU:D0UJe1U:D00Y>
LdHa?Nm245:DE[E>LdHaBU9F]@9JeP0<IcU_Ne[F<H`HaRDY=JdYBQcW9BTe[C6<0QcW00d@Q1S68@PH
aQBU7>Le[DicG_M[FV<HCW<aS0029BT01Re[=JdicSW>=JdicP924009?Nle[CF]<H`e[Cg_BU9>Ld8@
008e[@0;>LhmkcF]>Li:DUJeBU8aS2DY8@PHaP0236<248@236<248@00aBU48@<H`0248@336<348@0
11BUOomoo`003Goo000<Ool00`00Ool48@02124400000`Q212448@02000224801000;F/U:Be[0SF]
00=6<C6<=Jd00Q240P@Q00H8@QcW@Q1:DSg_=Jd2AS4013F]@Q0icSW>0cg_0SW>00<]JcF]?Nl00SF]
00HYBSg_BU8e[DicAS42BU802@Q236<8@SW>7>L8@P@Q;F/e[@0348@01aBU6<H<H`aS5:DHaSg_0096
<@03BU9241S6008HaP097>L<Hbe[=JdHaRU:<H`Lia24008Li`05:DXLiaBU<H`Li`02=Jd00acW9BTU
:@02:DX01RDY=Je:DRU:5:D]J`88@P04124000@Q1244000412400`Q21240000200021242Ool00`00
Oomoo`0;Ool04`00OomoogooO01cW4ic36=oo`00Nmh8@P005:D48EJe9BUF]Ekg008DY@0?Nmi:DPQ2
CW<aS1S61248@P00?NmW>C6<F]Ioob48008aS00>OolDY@@Q125:DQBU36<HaW_NAS4006<H6<H<H`<@
Q00N7>L<Hbe[6<HYBQ24;F/aS1cW124Q20aS=Jd007`00008@P@Q248Q21245:D<HaS6124<HeJe5:D8
@RU:0Q2400D001S69BTYBQBU00848@0;:DXQ22U:000U:C6<7>L001BU248DY@027>L02`@Q48@mk`00
5:D48AS6124Q21BU48@00Re[00HHaP@Q248HaPQ236<224801`00248Q2248=Jd@Q1S600=oo`03001o
ogoo00]oo`03001ooa24008@Q00336<8@Q24008@Q00436<@Q124248236<00b48=Je6<@02AS401TYB
DYA>Lcg_:DXHaP8@Q0036<H]JdYB009Nm`9F]@03F]INmeJe009BU0=F]@0:CW=6<DHaCW=F]E:DBU96
<E:DHaP2G_L036LiKg]BU24836<U:CW>:DX@Q1cW>Li2408YBP0>6<HQ22U:7>L@Q1cW>Li>Le[FIcUS
65:D>Lh]J`8YBP08;F/icT8@?Nle[C6<;F/YBP8U:@0D:DXaS36<=Je244YB@Q0icSg_@Q0icS6<>Li:
DU:DAS4e[Be[9BTHaP8<H`0348@<H`Q2008<H`8@Q08<H`<@Q08<H`<@Q09oo`03001oogoo00]oo`00
37oo00D007oo124000@Q008000D48@0700048@Q224800248;F/00S6<01@e[CW>>Lhe[AS636<48@Q2
5:D00124?NmBU48@BU9BU4ic?NlicSF]0Sg_014icSF]<H`e[Cg_@Q0mkc6<=Je:DS6<AS5>Ld8@BU8Y
BPaS00848@06:DX<Ha24124DYCg_0PQ200PQ21S66<H000aS5:D@Q3W>0dHa00=242DY7>L00aS600@Q
22U:?NlQ20<48@<8@P047>LQ21BU7>L2:DX00c6<:DX]J`02:DX02BDY7>M6<DHa9BTLibU:36<48@08
00001P@Q00048@Q2124000<48@04001oogoo000=Ool04`00OomooekgO01JeWooHaQkgSg_48A240@Q
000LibDY=Jd@Q000008DY@0?36<U:ABU249_NcF]Oom>LcF]000LiaS6@Q0mke:D0088@P0>HaQ24248
CW<48@aS8@PicU[FKg/U:ABU7>Lmk`9W>@0@>Li:DPQ2LiaF]CF]>LhaS0@QAS4@Q1BU48AJeQS6O002
6<H01R48:DX8@P@Q36<DY@8icP057>L48B486<H]J`027>L03R48000mkbDY5:D<Ha24=JdDY@00<H`4
8CW>48@2;F/03`009BT<H`aS6<H]JaBU000aS0@Q?NlHaSg_124@Q00224803bDY5:DDYA24000Q22U:
9BU>LaBU000<H`005:DU:@03Ool00`00Oomoo`0;Ool00`00Ool@Q00248@236<648@336<00aBU:DXm
k`02AS401TYBDYAF]DYB<H`HaP8@Q0075:DLic6<DYAW>F]JIcT00V<H00=NmeJeE[D00e[F00=BU4YB
CW<00UJe00A>LdYBCW=JeP=Nm`0<HaQJeSg_5:D8@R48=Jd]JaS65:D]Jcg_0SF]0b4800lLiaBU7>Le
[DicG_MW>F<HE[E2436<:DXU:BU:<H`00T8@00@e[B485:D@Q08HaP069BTYBRU:8@PU:CF]0d8@0THa
00hicSF]@Q1F]E[FBU8e[Be[8@PDY@Q236<@Q0aS0PQ200L<Ha2448@<Ha246<HDY@0236<248@010Q2
Oomoo`003Goo000<Ool01000Ool48@@Q0P0000H48@00124000Q21242000312402Q24?Nle[C6<;F/i
cTHa;F/YBQ240P@Q00LYBPaS248Q23W>BU8mk`03AS40148@>Lhmkcg_0SW>0S6<00@icSF];F/aS08i
cP07?Nm>LdHa@Q0U:@aS00000P@Q00H002U:1248@P007>L2:DX3124236<26<H013g_CW=244YB0T8@
00XLiaBU48@HaR485:D@Q3F]36<@Q0<<H`0<5:D<H`aS124<H`@Q6<H]JcW>;F/YBSF]0RDY00Hmke[F
BU8LibDY6<H300000`@Q000000020003124010Q236<000000P@Q0P000Woo00<007ooOol02goo00/0
07ooOomoog`0Ool]JfLi000aS3W>009JeP068@QcW1BUNmh<HdYB0QS600YcW2DY5:D007oo?NlLic6<
BU9JeP8icP0C;F/DYDic36<@Q0Q2;F/Lie[F:DX@Q0@QHaPaS4ic5:DQ2124<H`00P0000`48DYB48@i
cPQ2BU8@Q36<@Q0]J`Q2E[D27>L00bU:O008@P0412402P005:D8@PaS0008@QBU8@P@Q2480PQ200@e
[@Q2F]H@Q08Q200=9BT0048@6<H<H`009BT]Jb486<H@Q2U:00000QS600X003g_48@000Q2:DX000Q2
8@PaS08DY@8U:@0=5:D<Hb48248LicF]248<Ha24124001BU36<00goo00<007ooOol02goo00<007oo
48@00Q240PaS1Q24014<H`Q2248@Q2U:AS5BU4icBU9BU5[FE[DicQcW5:DQ22DY008Li`09<HaBU6Li
JeYW>F<HG_MF]Dic009BU09F]@=BU0=>L`9BU00?E[ES66]JG_M242DY48@<HaS6:DXaS2485:DHaRe[
008aS0048@PDYAS68@P27>L00c6<DYAS6003HaP034ic<H`Q22489BTYBS6<>Lhe[B4848@DY@8HaP0:
7>LQ22486<HDYAcW;F/icSg_@Q02AS402Cg_AS5F]F<HDY@icRe[:DXHaP02248248@3248348@00aBU
6<HDY@0236<248@010Q2Oomoo`003Goo000<Ool00`00Ool48@0512401PQ20008@PQ2124000<48@0D
36=>LcW><H`e[Cg_AS4e[CW>9BT8@Q249BTDY@aS000U:CW>BU92408icP04@Q0e[Cg_?Nl2@Q002Cg_
=JdicRe[<H`icSF]?Nm:DP02CW<025Je48@48@@Q0008@QcW=Jd248@04`Q25:DDYABU248<HaBU7>L@
Q1BU6<HicTYB@Q16<D8@CW<HaQBU00<@Q0035:DHaQBU008HaP0636<DYABU36<DYA240PQ200D@Q0@Q
36<<HacW008aS00:=JdicS6<;F/LicF]7>LYBP001247000212400`aS248000050002Ool00`00Oomo
o`0;Ool04`00OomoocW>O00DYB48;F/Q23W>Oom_NdicMkde[G_N=Jeoo`aS009oo`0@>LhaS0@Q@Q16
<@008@P<HbU:>LiS65[F<H`<HacWCW<27>L03D8@G_L48D8@F]HQ25[FBU8]J`0036<aS2DY0080000O
249cW0Q248@Q24ic000HaRU:>Lh48ABU=Jd<H`00O00<Hc6<;F/000aS:DXmk`@Q7>LQ21BU000Q21BU
48@00Re[010icQ246<HLi`@Q36<Li`@Q5:DYBQ248@P<HbDY124HaP80000=48@U:DYB9BT48@aS6<HL
i`00:DX@Q0@Q00000RU:00XLi`aS248Q236<36<@Q248CW<0008<H`035:DQ21S600=oo`03001oogoo
00]oo`03001ooa24008@Q08<H`0448@DYA2436<248@02PaS12448A24=JeBU5[FCW=6<DYB0U[F00I6
<BDY7>LYBSF]:DX248@012e[BU9F]EJe0U[F00ABU4YBBU9:DP9BU005CW=6<DHaAS5:DP03CW<01E[F
Liag_EJe:DX00a2400@DYBDY<H`]J`8HaP0G:DXaS36<7>L@Q1S6:DXQ21cW;F]BU6<HG_MS66LiE[De
[AcW8@PYBRDY7>LU:@02;F/49BT022486<HLiacW6<HDYAcW:DX2;F/013F]@Q1:DTYB0Tic00U6<Cg_
=Jd]JacW24848@aS48@00`aS0a240QBU00<@Q0aS36<00Q2400@<HgooOol000eoo`0037oo00@007oo
248000848@0600048@Q21248@P@Q0P000P@Q00@00124CW<e[@8aS008;F]:DTHa?Nl]J`aS5:D]J`88
@P0748@002489BT]JcW>AS4013F]00=:DSF]>Lh00RU:00T]JdHa>Lhe[DYBAS5BU6<H;F/00P@Q00T8
@QBU248DYCW>8@PHaR487>L00S6<00<8@RDY5:D00a2400PDYBU:AS5>LdHa@Q1:DR480aS60Q2400D<
HaBU7>LDYBU:008Q20091248@QcW36<LiaBU6<HDY@aS00848@0:7>Le[Be[:DXLia24>LhQ22DY48@6
0004124010Q212448@000`@Q00@8@WooOol000eoo`0C001oogooE[El04ic@Q0icWoo7>LYBWoo0016
<BU:8@PLidYBMkd00RU:00PQ22e[000icQBU000HaP@Q0PaS00/002e[:DXicRU:CW<]Jb48125ooacW
009JeP05249_N`aS48@YBP029BT08R48:DXYBP@Q9BT<H`@Q=JdYBTYB@Q0Lia248@PHaPQ26<HQ27`0
248HaP@Q>Lh8@P005:D<Hc6<6<I241cW8@PLiaBU0a2400`YBQBU36<DYE:D8@PDYB48124@Q1S67>L2
5:D041S636<<HaBU6<H000@Q6<H]J`@Q001>La245:DYBPaS0PQ200laS124000U:AcW9BTHaPQ2000Q
21S636<DYA2424800goo00<007ooOol02goo00D007oo48@DYA24008<H`0448@DYA2448@25:D06PQ2
12448ABU=JeBU5JeCW=244YBG_MW>E:D=JdU:Be[=JdYBQBU48@Q22e[>Li244icE[D2DY@3E[D01E:D
BU96<DHaBU800dic011JeW>LOom_Nd8@6<H<Ha245:DHaRe[?NlicRU:8@P]J`8e[@09:DXQ22U:;F/U
:AS6:DY:DU[F009Nm`0;HaQNmd8@:DXQ22DY8@PLiaS69BT]J`02<H`2;F/00bDY8@PQ20028@P00acW
6<HHaP026<H03AcW;F/mkcg_<H`YBS6<@Q16<CF]8@P<H`Q200D<H`H@Q08<H`8@Q00436=oogoo000=
Ool000aoo`04001oo`Q2000212401P001248@P@Q24848@8000848@04000@Q4ic=Jd2<H`022e[BU96
<Cg_;F/<HaBU;F/224801a24000Q22DY;F/icTHa00@e[@03BU8e[CW>008YBP09;F]6<CW>=Je:DTHa
DYAS62e[00848@09248DY@Q25:DicR486<HQ21cW008aS003248U:ABU00<@Q0085:DYBTHaCW=6<D8@
BU8Q20<HaP8@Q00536<DYAcW5:DYBP028@P02@@Q248Li`aS7>LDYAS65:D<H`0212402QcW=Jd]JbU:
7>L@Q3W>8@PU:A241P0010@Q00@8@P@Q124000<48@04249oogoo000=Ool04`00OomooeJeO01>Ld8@
>LiooacW:DYoo`00AS4YBR487>M:DWNm008YBP088@P]J`00>LhDY@006<H48@8<H`0;000]JbU:>LhY
BTic;F/Q20@QOolLi`02F]H01@Q2Kg/<Ha24:DX00RDY028Q22U::DX48BDY36<48CF]:DY:DT8@7>L@
Q2486<H8@QS68@Ql00Q26<H48CW>248001BU36<aS1S6@Q0Lib487>LDY@<@Q00<:DXDY@aS5:EBU248
5:DQ20@Q48@HaQcW0QBU010HaPaS36<DYAS600048AS6;F/48@00CW<@Q1BU:DX<H`88@P0?<H`@Q000
9BTLibDY6<H8@P008@PHaPaS5:D@Q0Q200=oo`03001oogoo00]oo`05001ooa245:D@Q00236<01124
5:D@Q1240QBU01X8@P@Q124DYCF]DYAF]Dic@Q1:DUkgIcUBU3F]9BT]JcF]:DXDYA248@P]JcW>@Q1>
LeJe0U:D0eJe00EBU4YBAS56<DYB00=>L`0@F]IcW7ooKg]241S636<@Q1BU6<H]Jcg_>LhYBR48;F/2
=Jd02BU:8@PYBRe[9BTHaRU:BU9JeP02G_L02f<HG_M242U:8@PU:B487>LHaRDY;F/00S6<0Re[00<U
:B488@P00R4800<LiaS66<H00QS600dLibe[?Nlmkc6<:DXaS48@AS4e[B4836<8@P0536<648@236<2
48@010aSOomoo`003Goo000<Ool00`00Ool<H`0300001`Q200048@@Q24848@0000@48@0H6<I243F]
:DXaS3F]BU96<D8@=Jd@Q1cW;F/@Q0@Q8@PLi`Q25:DHaRU:;F/e[CW>0T8@01HicS6<=JdaS3g_CW<e
[Be[CW=6<E[FJeXaS1241248@P0036<8@QBU>Lhe[@<@Q08Li`03<H`Libe[00<DY@0:7>LU:DYB@Q16
<D8@AS5241S65:D248@25:D011246<HHaQS60Re[00PU:Be[5:D@Q0aS0008@P@Q0PaS00@8@P@Q1244
8@8<H`06124icSg_8@PYBP@Q1`000P@Q0P0000@48@0012448@80009oo`03001oogoo00]oo`05001o
ogoo@Q1l000200002C6<248mkdHa5:EJeP@QAS5_N`0236<00bU:5:DDY@027>L01`0036<001246<H@
Q0@Q009oo`0D8@PaS2DYG_L<HcW>248icP00@Q0DY@@Q;F/LicF]7>L@Q2DY8@PU:@8mk`06:DX@Q000
>LhQ22DY0Q2400U:DRDY000mkaS6DY@mkg`048@00PQ200T<H`0036<@Q1cW8@P48@aS48@00QS600@4
8BDY9BT48@8U:@0I:DXLiacW124Q23g_36<@Q00048@Li`@Q8@P000Q236<48@Q2<H`]J`00>Lh@Q4ic
8@P00SW>018003F]=JdHaSF]124@Q0@QBU8<HaS6248HaRe[48@Li`aS2483Ool00`00Oomoo`0;Ool0
0`00OolDY@0748@35:D03`aS2488@QBU:DY244YBAS5244YBHaQ[FUkg@Q0aS002:DX28@P02BDY:DXU
:BDY;F/mkdHaBU9F]@03HaP01EJeBU9:DU:DE[D00U:D00INmg>LOom_NdYB9BT248@011BU48@HaS6<
0TYB00<e[BDY:DX00SF]00XmkcW>=Jd]Jb487>LU:D8@F]IS60=Nm`04DY@e[B487>L29BT28@P00bDY
;F/]J`03<H`00be[9BTQ20038@P01AcW5:D@Q1246<H00RDY00THaQ248@Q245:DAS4YBQBU48@00PaS
0PQ200<<Ha2448@02A240Woo00<007ooOol02goo000<Ool00`00Ool000021240100024848@000P@Q
00<000@Q12400`00018DYBDY:DXQ22U:<Ha:DT8@AS4e[B485:DYBQ24124]Jb48000236<011245:DH
aSF]0THa01U243W>:DXaS2U:=JdU:D8@BU9F]E[F8@P000Q2124000@Q00048A24=JdicR486<HDY@02
9BT013g_6<HaS0Q20QBU00<8@Re[AS40148@00A:DQBU5:DDY@<Li`8HaP@Li`0H6<HQ212448@8@Q24
6<HDYA24248<H`Q248@8@QBU1240036<@Q0YBS6<248000@Q1@0000P48@Q2124000Q2124000Q20P00
0Woo00<007ooOol02goo00X007ooOolLig`0AS4HaQ24<HaBU08HaP078@QNmbDYG_LLibU:F]H00U:D
01l<HcW>7>Le[F]JG_M2436<36<]JaS6BU8DYC6<8@PYBQS69BUoo`Q2?Nl48AcW>LhDYCW>248003W>
9BT8@P028@P07bDY48@HaPQ21248@THa7>L002e[8@PYBQS6124<Hg`07>LDY@@Q9BT8@Q24248DY@00
124HaRDY48@Q2000008Q200M6<HQ20@Q48@48DHa5:DHaT8@248DYC6<8@P@Q2DY48@YBP0048@HaPaS
248YBPQ236<8@PaS124]J`029BT27>L03bDY12448Be[5:D48ABU=JdU:ABU248]J`@Q248<H`03Ool0
0`00Oomoo`0;Ool01@00Ool@Q12436<02A240PaS00@@Q248=Jdmk`8e[@0CAS5JeVLiF]I:DSg_<H`U
:B48:DX]JbU:8@PHaQcW9BTYBRe[?Nl00U:D00ENme[FDYA>LeJe009JeP06G_M[FVmkG_M242480Q24
00PDYAS648@DYBe[CW=F]CW>0QcW0SW>00A:DT8@<H`YBP8Q2004:DY6<EkgIcT3G_L01e:D=JdQ2248
;F/aS2U:008Q2003:DXaS3W>008icP05=JdYBQcW6<HLi`038@P02AcW5:D@Q1BU6<HDYA246<He[@02
DY@00cF]7>L@Q00248@336<:48@010aSOomoo`003Goo000<Ool00`00Ool0000212400`002488@P02
000010@Q0008@P000P@Q00X000aS5:D8@QBU8@P<HbDY@Q0]J`8mk`09124HaQS636<DY@@Q248HaPaS
00848@0>248<HacW7>LYBU[FCW<mkcW>BU96<E:DF]HU:@<<H`03000<H`@Q00<48@060016<CF];F/@
Q0000QS600<mka247>L00QS600<DYB48BU800THa00e:DTHa@Q0icQS648@LibDY8@PLiaBU36<HaP03
<H`06Be[:DXLiaBU6<H48ABU8@PLi`Q26<HDYAS6248000Q21248@THa;F/aS12424848@0000848@0<
00048@@Q1248@P@Q24848@aS124000@Q0Woo00<007ooOol02goo00L007ooOolmkg`05:E:DP027>L0
2QS6125[FUkgOom>LbU:5:DYBSF]0QcW018002U:001240aS?Nl48BU:=Je>LbDYF]HDYFmkBU9246<H
F]H26<H02`Q2=Jd006]J9BT<HcF]?Nl48C6<BU800PQ200@Q23F]8@P8@P8@Q007>LhaS1S6?NlicW>L
E[D00P00011l00Q236=BU0Q27>L8@S6<5:E_N`Q26<HU:A249BTQ20<@Q00G000@Q000248U:Cg_48@D
Y@@Q@Q0<HbDY5:DYBP@Q<H`8@P005:DQ20Q2>LhU:@025:D01@aS48@U:AS6;F/00Q2400PYBPaS48A6
<BU:=JdU:@Q20b4800@8@QS66<H8@P=oo`03001oogoo00]oo`03001ooa24008<H`@@Q00524848@Q2
36<@Q00236<011BU9BTaS36<0RDY00XicTicDYA>LdHa@Q0icRe[:DXQ208Li`036<HDYA24008@Q005
5:DLibe[;F]24002BU83AS401dicE[EF]DHa:DXDYA24008<H`8DY@0836<8@QcWAS5F]CW>6<HQ208m
k`04BU8e[BDY9BT2:DX02cF]CW=S66<HG_MS65kgBU8YBR48:DX00SF]00DaS2e[<H`icT8@00=6<@03
?NlaS2DY008Li`069BT]Jbe[:DXU:AcW0aS60QBU00PYBTHaE[E2424836<@Q1BU0PaS00<8@PaS48@0
212400@<HgooOol000eoo`0037oo00<007oo124010000P@Q00<000@Q00000P000P@Q00hDYAS6;F/]
JaBU36<U:DHa>LhQ21BU=JdHaS6<0QBU00<48ABU5:D00P@Q00@8@PaS36<8@P80000436<DY@aS36<2
7>L01A247>L8@P0024800P@Q0P0000H8@PaS00048@Q2=Jd2;F/00acW;F/mk`02?Nl02124248LiaBU
;F/LidYB@Q02AS42@Q001BDY48@@Q1cW8@P00QcW00A243W>?Nm6<@8e[@8icP06=JdHaQS65:DLia24
0R4800@U:A24248@Q08<H`06000<Hcg_<H`YBQcW0P0000<48@0000000`000P@Q1`000Woo00<007oo
Ool02goo00l007ooOolHaW`0;F]6<@006<I6<CW>7>LHaR4824800RDY0148@RU:6<HHaQBU36<DYAcW
:DXU:FmkHaPmk`aS000aS0@Q008YBP0@?NmJeW>LE[DmkcF]8@Q240aS<H`LibU:CW<LibU:7>L3;F/0
7@aSE[DaS7>L36<HaT8@<H`@Q2DY248mkcW>CW=l00Q25:DQ23W>8@Pe[@Q25:D002e[6<HU:@Q2@Q00
0acW01lHaPaS5:D8@RU:7>LYBP@Q000U:AS636<@Q1S67>LHaRDY8@PHaQcW48@DY@Q26<H000aSBU8D
YBU:124Li`0200001BU:5:DicPaS12400Q2400PYBQBU9BT<HcW>5:DHaP@Q0goo00<007ooOol02goo
00<007oo48@010aS00<@Q0aS36<01PaS00@HaRU:<H`YBP8Li`06;F/mkd8@?NlicSF]0S6<00@YBR48
5:DDY@8Li`8DY@036<HDYA24008DY@038@PaS3F]00<aS08e[@04<H`Li`aS248248@02`aS48@DY@aS
124HaSg_CW<icRDY=Jd00TYB00i242486<HU:C6<=Je245[FIcUS65[FHaQJeSW>0R4800HaS3W>=Jde
[D8@BU82DY@2E[D01dicBU9243F]:DXU:Be[008aS006;F/aS36<:DXLiaBU0Q2400DQ248@E[E6<BDY
00<@Q08<H`05248<Ha2448@<H`0248@236<248@010Q2Oomoo`003Goo000<Ool01000Ool000@Q0`00
0`@Q00@000@Q00000088@P0G124@Q0aS24848@Q26<HQ20aS8@P<Hb4836<DYBe[7>LHaQcW36<HaQ24
7>L<H`0248@200000`Q236<<H`026<H01a2424848AS6248<H`Q200@48@0600048@@Q248DYCF]0R48
00/Lid8@@Q0DY@Q236<DYBU:;F/U:Dic00924004AS5243g_6<H248@01248;F/]JcW>0Sg_00<icTHa
?Nl00Sg_00PaS48@=JdQ22DY8@P]JaS60RDY00@aS2DY124@Q088@P0736<mkd8@7>L]J`@Q00000`@Q
0P0000@48@00124000<48@0300048@00009oo`03001oogoo00]oo`0C001oogooOoml02482496<D8@
:DYW>A248@P<H`008@P005[F48@00Re[00QW>ABUHaPYBQ24<Ha[FP@Q0UJe00/icP@QBU9_NbDY5:DQ
2000=Jd48AS600848@087>LmkdYB9BT@Q2e[5:D]J`8HaP0I48@48A24=Jd]JbU:124]J`aSF]H8@Re[
000<HaS6O0048@aS48@8@P@Q;F/DY@Q26<H00QBU00@<Ha2436<@Q08<H`8@Q006>Lh48AS6:DX@Q0aS
0QcW00/@Q248BU9240aS5:DLi`005:D48B4800<<H`07DY@U:BDY00048A24:DX00Q2400<<HbDY0000
0QS600X48AS6248e[@aS5:D8@P009BT48@=oo`03001oogoo00]oo`03001ooa2400D<H`0648@HaR48
7>LDY@aS0Q2400LHaRDY9BTLiaS67>LYBP02<H`01BU:9BTU:BDY:DX00Re[00@YBRe[<H`aS08YBP8]
J`049BTLiacW7>L38@P29BT01B486<HDYABU48@00aBU0Q2400TDYA2448@Q23W>AS4mkcF]@Q000TYB
014e[AS66<HYBSF]>Li6<EkgIcUNme[FG_MBU3F]7>LQ23F]008mk`04AS5BU5[FG_L3F]H01UJeDYAB
U4YB>LhaS08e[@8aS00??Nm243F]8@PDY@aS48@U:D8@E[E6<BU:6<HDYA2400<8@P8@Q08<H`8@Q088
@P8@Q004249oogoo000=Ool000aoo`06001oo`@Q00048@000`@Q00DQ22e[:DX<H`@Q0080000536<D
Y@00248@Q0025:D02Q2424848A245:DHaQ24248Q21cW0cF]00<YBRe[<H`00SF]0Re[014YBQcW7>L8
@QS69BT]JaBU48@HaP@Q000@Q00024848@0000848@0436<U:C6<:DX29BT248@02@aS000@Q1cW6<HD
YBe[E[E24002AS400cg_@Q0Li`025:D022U:;F/icSF]>Li:DT8@>Lh2?Nl01d8@=JdmkcW>;F/Q21S6
00<YBP067>LicRe[48@8@QS60P0000LicTYB6<HYBR482480000212401P0012448@@Q00048@800004
124000000002Ool00`00Oomoo`0;Ool04`00OomoogooO01W>ABU7>L48BU:E[DicT8@6<HU:FLi8@PU
:ABU008<H`0?AS4U:F<HG_L8@P00AS5_Na2400048AS6248Li`Q200848@06>Lh48@@Q48@HaQBU0P00
00@@Q0aS48@48@8e[@8DY@0O?NmJeQS67>LicS6<8@PDY@Q2=Jd000aSAS4aS4HaO0048@0036<U:@aS
6<I:DRU:1248@QS68@PU:@00;F/00RDY00d@Q2DY2488@RU:124@Q1cW36<Li`aS000DY@026<H041BU
36<48C6<124002DY124]J`@Q48@48ABU:DXHaP000S6<00l]JaS65:DQ20@Q7>L48AS6248Q21BU36<8
@R4800000goo00<007ooOol02goo00<007oo48@00PaS00P@Q0aS36<HaRe[=Jd]JacW0aBU0aS600<D
YAS68@P00RDY00<HaQBU7>L00b4800<]JcW>@Q000d8@00DmkcW>?NlmkcW>008aS007;F/U:AcW7>LU
:Be[:DX00QcW0R4800@HaQBU48@@Q0@DY@068@Pe[D8@@Q0icSF]0Re[00<Q21S68@P00Re[00laS4Ha
G_MW>EkgF]INme:D=JdLib48=Je6<DicE[D00Ukg15[F0UJe01MJeU:D@Q0e[C6<=JdicSg_AS5243F]
9BTLiaBU48@Q248@E[E>Lc6<9BTLia2400<8@P8@Q08<H`8DY@0536<8@Q2448@8@P02Ool00`00Oomo
o`0;Ool000aoo`0>001oo`001248@P00248001BU;F/Q21cW5:D48@8DY@032480000000848@05248<
H`@Q124<H`025:D020aS124Q23W>6<HU:Be[:DX29BT2:DX36<H00b487>LQ200248@02bDY7>LLiaBU
6<HDY@Q236<000@Q00000`Q200H48BDY;F/YBRDY6<H224805B4836<LiaS65:DLic6<AS5:DT8@AS52
43g_9BTHaPQ29BTaS3W>?NlicP02AS400cg_@Q124002@Q005cF]>Lhe[B487>LHaRe[=JdmkbU:8@PU
:A245:D<H`006<IBU2U:;F/e[@Q212400`0020@Q00<000@Q12400Woo00<007ooOol02goo01<007oo
OolLig`09BT48BU:5:DQ20aS48@aS2DY<H`Li`Q2;F/mk`02;F/01V<HF]H48G>L6<HLi`8U:@0G5:D8
@PaS8@P006<HAS40048@:DXQ21BU9BTLif<H48@HaQcWIcTLi`007>L@Q0028@P06@00=JdYBPQ248@e
[Cg_9BT8@PaS6<HYBPaS=Jd@Q7`09BT<HaS6000e[@00124Q212400<<H`036<H@Q000008DY@0K36<@
Q3W>6<H8@QS636<0012436<8@P@Q5:D<H`Q2000LiaS600048BDY7>L]JaBU:DXHaP@Q00<DY@0:248H
aQS69BT8@QS65:D@Q000?Nl200001P@QBU8DYE:D48@<H`=oo`03001oogoo00]oo`04001oo`aS36<2
48@00`aS5:DU:@02=Jd00bU:6<HDY@055:D36<H01acW5:D8@PaS8@PaS3F]008aS004>Lhmkcg_?Nl3
>Lh2?Nl00cF]<H`aS002=Jd02be[9BTYBSF]>Lhe[Be[:DXQ21BU48@00`aS0Q2400<<HaBU;F/00T8@
00<aS2486<H00QS601DLibDY:DXU:Be[AS5S66LiF]IF]EkgE[DicR489BTicTYBDYAJeUkgF]H00UJe
0U[F00UF]E:DDYABU4Ha>LhaS3F]?Nl00TYB00Q243F]<H`aS2DY5:DHaSF]0UJe00A242e[9BTDY@<8
@P8@Q08<H`8@Q08<H`8@Q00436=oogoo000=Ool000aoo`04001oo`@Q0003124010007>LQ20Q20P@Q
00T8@P@Q12448@Q2:DXLi`aS48@00PaS00T001246<HU:GooDY@Q21cW?Nl00RDY00H<HaS68@PQ22DY
5:D48@P2:DX011cW8@PLibDY0QS600@8@P@Q124000D48@03000@Q3F]008Li`07124DYABU36<DYAS6
5:D00QS600@]JdYB@Q0mk`924003?Nl]JaBU008Li`03=Je243g_0096<@09?Nle[Cg_?Nm243W>=Jdi
cS6<008e[@0B6<HYBS6<9BTQ236<;F/HaQBU6<H8@P@QAS5:DQcW:DXQ20@Q200000<48@0000000`00
0Woo00<007ooOol02goo01<007ooOolDYG`024848D8@CW=oo`00Nmh48Goo5:EoocW>=JeW>@02Nmh0
7goo;F]cW1BUKg/YBTYBKg/HaR48;F/48C6<8@PHaSF]9BTaS2DY000<Hcg_DY@@Q1S6;F/mkc6<48@D
YBU:0088@P07:DX@Q0@Q6<H8@SF]24800QS6010e[B485:EBU2DY48Al02e[>Li2436<7>L<HbU:=Jd0
008YBP04124icQBU6<H2<H`07`007>L8@QBU000@Q0@Q36<U:BU:<H`8@QcW248DY@007>LDYA247>LH
aQBU;F/YBRDY:DXHaP@Q;F/8@R48008U:@0;48@DYCW>36<Q21cW6<H8@SF]36<8@P0200000`@Q8@Qo
o`02Ool00`00Oomoo`0;Ool01@00Ool<Ha245:D00PaS00HHaRe[>Lhe[B485:D448@03QBU7>LQ21cW
6<HDYA245:DLicF]CW=F]DYB=Jd2:DX2<H`2:DX00cF]>Lhe[@03;F/013W>?NlmkcF]0S6<00De[CW>
=JdU:AS6008DY@0336<8@PQ2008@Q007124@Q2e[AS4mkbDY6<H00QcW00<Q22DY9BT00RDY00HYBT8@
G_MW>E[FE[D2G_L0148@9BTU:Cg_0Tic00EBU5[FG_MF]E:D00=JeP09E[E>LdicCW=:DSg_>Lhmkd8@
0096<@0=?NlicS6<9BTHaQBU:DY6<E[FE[DmkbDY5:D00PaS00@8@PaS48@@Q08<H`<@Q08<H`0448Ao
ogoo000=Ool000aoo`03001oo`@Q00800005124000@Q7>LYBP02;F/02@aS12448@@Q36<@Q0aS48@Q
200236<01@@Q5:DmkdHaBU800S6<00HU:@Q248@48AS612428@P00aS68@PU:@026<H3:DX02Be[<H`L
iacW9BTQ21BU36<8@P0312402P0036<48@Q248@Q23W>:DX48@aS0QS600<Q21BU24800aS600@]JdHa
@Q1240=6<@05>LhDYAcW:DXicP02?Nl3@Q001CW>@Q1243g_AS400SW>00Hmkd8@=JdYBQS6;F/2:DX0
1Sg_7>L<H`Q26<H@Q0848@05DYA24248;F/@Q00212400`001248@P05000010Q2000000000Woo00<0
07ooOol02goo01<007ooOomoog`0Ool48EkgCW<000aS<Ha:DW_N;F/U:AcW>Lh]J`026<H04bDYKg/D
YCF]8@Pe[ABUJeXHaTYB124<HaS6DY@Q24Ha9BTDYCg_008Li`0:48@e[BDY48@8@P008@Q6<AcW1242
;F/06C6<8@PLifmk24848@Q2<H`]Jcg_6<I2400036=:DW`036<000aS000mk`Q25:D@Q3W>00800004
7>LDYABU248248@01QS65:D<HaBU48@]J`8000046<HLiacW6<H236<03B487>L@Q248E[De[@Q236=2
41248@P001S6008<H`0A:DXDY@Q2248000@Q00048AS6124@Q2e[000<Hd8@48A240021243Ool00`00
Oomoo`0;Ool00`00Ool<H`0248@020aS248DYBDY=JdicRe[7>L45:D05AS68@P]Jbe[8@PHaR48<Ha2
45:DHaQ[FU[F?NlYBRe[=Jd]JacW8@P]J`03=Jd2>Lh05cg_@Q1244Ha?Nl]JbDY:DX]Jb486<HDYAS6
5:D@Q1S68@PLiaBU8@PicT8@<H`00QcW0Re[00TaS2U:8@PU:BU:<Ha6<E[FHaP00U[F0V<H00E:DRe[
9BTicTic009BU004F]INmeJeDY@2E[D015kgF]I>Le:D0U[F00E>Lcg_<H`aS3g_0096<@0<=JdQ21cW
8@PLiaS6:DY:DU[FCW<]JaS60QBU00L@Q0aS48@@Q0aS248<H`0248@224801124Oomoo`003Goo000<
Ool01000Ool000@Q0P0000<48@0012400RU:0RDY01/<HaBU5:D<H`@Q48@<Hb489BTQ21BU>Li:DTHa
DYA:DSg_<H`Lic6<@Q0aS0Q2124@Q2U:8@P00cg_00I243F];F/Q22DY5:D348@041BU248@Q0Q25:DQ
21S68@PU:AcW8@PDYBDY248<HaS60Re[00THaQ246<HDYAcW:DXe[DHa@Q000THa00=244HaBU800Q24
00HQ23g_<H`e[Cg_@Q02?Nl2@Q000cg_>Li24002=Jd0148@>Lh]JaBU0R4800<U:BU::DX00PaS00TD
YAS636<000@QF]He[ABU:DX00P@Q00<000@Q0000100000D48@0000048@00009oo`03001oogoo00]o
o`0C001oogoo48Al02e[001NmbU:000HaQBU36<HaP0048@U:GooBU800V<H00ABU0Q2124<H`80000I
6<IS6124HaPYBTHa48A>LacW001BU1BU:DX<Hbe[24848@aS48@Lib48248HaP0024800Sg_00dHaP@Q
125[FP@Q6<H8@Ukg1256<C6<48@Q20029BT047`08@P003F]E[D002DY36=6<@aSBU8icRDY8@P8@PaS
0R4800<<H`Q25:D00P0001@48@Q2124mk`aS;F/48AcW8@P<H`00248000@Q=Jd<Ha24124e[@@Q0P00
00@DYB48:DXDY@8@Q00:8@P<H`Q20008@P@Q?Nl48@Q2000212400dHa5:DDY@03Ool00`00Oomoo`0;
Ool00`00Ool@Q00536<01AS6<Ha243g_;F/00acW0b4800PaS3W><H`U:Be[CW=W>Fmk0V]J00=Nmdic
@Q000THa00LaS1cW6<HU:Be[<H`mk`02BU800dic@Q0icP02?Nl00be[8@PQ20029BT01AcW6<HLibU:
;F/00S6<0Re[0SF]00@aS2DY7>LU:@<aS007:DXQ22U:=Je244icE[D00ekg0V<H00I>Lc6<9BTe[E:D
F]H2E[D2F]H04E:DE[EF]EkgF]IF]E:DF]INmeJeAS4aS2e[=Je244Ha<H`00QS60RDY00L@Q0aS;F]>
Le:D?NlYBP028@P00aBU36<8@P0248@2248248@00`aS248<H`02Ool00`00Oomoo`0;Ool000aoo`04
001oo`@Q124200001P@Q00048ABU8@P]J`8Q20<HaP0E5:DQ22e[<H`U:AS648A>LeJeBU9JeU:DF]IF
]E[F>Lh]JacW248000aS008DY@0>;F/U:BDY=JdaS1248@PYBR489BTQ20aS5:D<H`8@Q0059BU242e[
8@PHaP02:DX25:D00a245:DDY@0248@36<H01QcW>Li6<DHa?Nle[@9:DP07AS5244YB5:DHaQcW=Jd0
0Sg_00@icSg_>Li2408mk`04AS4mkcW>AS42?Nl02DHa?NlaS2DY8@P]JbU:9BT8@P026<H00`@Q6<H8
@P0200000e:D;F/Q2002=Jd00`Q2000000090002Ool00`00Oomoo`0;Ool04`00OomoofLiO016<@00
5:D48@aS00048DYB8@QF]C6<7>MoocF]008]J`0336=245[F008YBP046<HaS36<G_L25:D050@Q6<H<
HacW36<U:AS6F]I6<B48DY@mk`@Q@Q0U:AcW;F/Li`@Q36<2BU806QBU?Nl8@P@Q6<HQ21S636<aS000
7>L8@Re[8@P48G`0:DXHaSF]6<I>L`aS7>LQ2000:DX212400e:D?Nl8@P026<H27>L00be[248aS002
5:D2000041cW6<H0036<124]JcF]48@8@SF]9BTLi`@Q00048CW>0Q2400@Li`@QBU8@Q08<H`0?000D
Y@@Q000DYBe[6<Hmkb486<I2436<124Li`Q200=oo`03001oogoo00]oo`03001ooa24008<H`8@Q007
36<@Q248>Li243W>;F/00RU:01TU:B488@P]Jcg_>Lh]Jc6<DYAcW7_NKg][FVLiHaQJeTicAS4aS1S6
36<DYBDY<H`mk`02BU8044ic@Q0]JbU:=JdicSF]<H`]JbDY6<HDYB48=Je243W>0S6<00<e[C6<:DX0
0QcW00TQ22DY:DXYBRDY8@PU:CF]BU800eJe00=JeUkgG_L00V<H00IBU36<8@PaS4icF]H2DY@00eJe
G_MJeP03E[D015[FE[EBU5:D0U[F019>Ld8@=JdaS3W>?Nle[BU:9BTYBRDY5:D8@QBU<Ha6<DYB@Q02
<H`00acW36<8@P0936<2Ool00`00Oomoo`0;Ool000aoo`04001oo`000002124020Q2000000Q236<H
aRe[7>L236<01AcW48@<Ha247>L00RDY018DYCF]E[E>Le[FE[E>LdHa@Q0]Ja2436<@Q0@Q248<HaBU
6<H2:DX03`Q26<HYBQS6:DXicRe[=JdaS1S6124000Q25:DHaP02248021247>L001BU48@8@QBU9BT2
48@01PaS6<HHaR48DY@mk`924003AS52448@00=6<@085:DHaQS6:DX]Jcg_>Li:DP96<@8e[@03?Nm2
43F]008mk`0D>Lhe[D8@;F/DYB487>LU:Be[<H`e[B4836<@Q0aS48@48@aSAS4U:@8]J`035:D48@@Q
0080000312400000008000848@9oo`03001oogoo00]oo`07001oogooOoml02DY@Q000P0000DHaR48
7>LicPQ2009F]@03248]J`aS008HaP0J000HaRU:124DY@Q25:De[E[F:DX<Hc6<8@PaS000248e[@@Q
8@P0036<;F/48A2436<48@8HaP03<H`Li`000080000@8@Q>L`Q27>L@Q36<1248@P@Q36<8@RDY36<U
:AcWO0025:D03AS6:DX8@U:D001:DQS6CW<48@Q248@8@P00008Li`0:8@PHaRe[8@P000@Q9BTHaPQ2
000248@010@Q36<<H`Q20PaS00LDY@aS000YBPQ248@YBP02248011BU36<icQ240PaS00X@Q2U:36<4
8Cg_000]Ja24>Lh<H`8DY@03HaP001BU00=oo`03001oogoo00]oo`03001oo`aS008<H`<@Q00636<D
YB48;F/e[C6<0RU:00@Q21cW8@P]J`8icP8]J`05AS5W>G>LJeYW>@02JeX025[F?Nl]JbDY5:D<HaBU
:DX4=Jd03CW>=JdYBRDY=Je6<DYB@Q0e[BDY6<HDYB48008e[@059BTLib489BTQ20027>L00b489BTY
BP02:DX012486<HYBTYB0V<H1Ekg00eS66LiDY@aS248:DXicT8@AS5BU5kgHaQJeP05E[D3DY@2E[D0
1DYB?NlaS36<>Lh00THa00XmkcF]<H`YBQcW48@DYC6<BU9BU08mk`038@P@Q0aS00<<H`0348@<H`aS
00<<H`9oo`03001oogoo00]oo`0037oo00<007oo00000P@Q00<000@Q12400`@Q00<8@QBU6<H00Q24
00H<H`@Q48@Q236<9BT38@P02DHa?NlicSW>?NlaS2e[5:D<H`025:D01@aS48A242DY:DX00QS600lQ
21S6248Q21BU9BT]JbU:36<8@QcW248DYAcW48@00P0000P48@Q2000HaP@Q8@PDYAS60RDY00H@Q0aS
48AF]DYB@Q02AS40148@BU9244Ha0TYB00XDY@aS6<HHaQ247>Lmkdic@Q0icP96<@0=@Q0mkd8@=Jdm
kbe[>Lhmkc6<9BTYBQcW8@P00T8@00XicSg_?NlicRDY6<H8@P00>LhaS08Q2003;F/48@00008000@4
8@<0009oo`03001oogoo00]oo`0C001oogooOoml02e[HaP<H`Q2;F/mkcW>36=W>Ekg<Ha243W>@Q00
0RDY019240@QE[EoodYB8@Pmkbe[7>MJeSg_IcTmkaBUBU8DYCW>124248@02cW>:DX48B489BTYBP00
48@8@S6<36<00SF]00<aS0Q200000Q2400`DYAcW?NlHaS6<8@PicP00124Lig`048@2000031cW36<L
i`Q2000e[BU:48@002U:36<icP8@Q0098@P@Q1S6248mkc6<0008@PaS00848@0336<aS0Q200848@06
00048B486<HQ20000QcW00L8@Q24124000@Q=Jd000025:D2000011cW48@001S60P0000L<H`Q29BTe
[@005:D<H`03Ool00`00Oomoo`0;Ool01000Ool@Q0aS1A240PaS00<HaRDY;F/00RDY0QS600@U:CF]
>Lhe[@8aS005@Q1F]EkgF]IF]@02G_L02TYB<H`Q21cW8@PU:Be[>LhmkcF]0RDY00DQ22DY<H`icSg_
00=24004>LhYBQS66<H28@P011S636<<Ha240QBU00@Lib489BTYBP<aS0079BTLic6<F]I[FVLiG_L0
0V<H00iNme[FHaQW>E:D<H`Q21cW8@PYBT8@F]IS65kg25Je0e:D00Q6<CF];F/aS48@DYAJeU:D0TYB
00M>Lcg_8@P<HacW?NmBU002AS400be[7>L@Q00236<348@336<01124Oomoo`003Goo000<Ool01@00
Ool48@0012400P000`@Q00<000@Q48@00aBU00@@Q1BU:DX]J`8U:@0C8@PU:CF]<H`YBRDY8@PYBSW>
<H`e[BDY6<HLic6<@Q0icQS6=Jd00PaS00/48B489BTicSF]9BTLicW><H`]Ja2400<8@P0300048@@Q
00848@0636<8@QBU5:DHaQBU0R480QBU00DU:DHaAS56<DYB0096<@03BU96<D8@0096<@0:6<H<Ha24
248DYCg_@Q16<Cg_@Q02?Nl022e[=JdicTHa?NlicS6<@Q027>L02Q249BU244Ha@Q0e[Cg_CW=:DT8@
0QBU0P@Q00EBU2U::DXaS1S600<48@04248000@Q1242000010Q2Oomoo`003Goo01<007ooOom6<G`0
124U:AcW=JdLidic;F/LiaS67>L<HcF]000Q20029BT043F]E[E6<ABU?Nl<HeJe000Q22e[6<IF]A24
:DX8@UJe0QBU00TaS48@AS4]JaS6=JdaS2DY6<H011240Re[01laS0aS7>L8@Q24124U:A24?Nl48E:D
000YBPQ27>Ml02487>L48@aSDY@icR48124@Q1S6125:DQBU0008@P0212406acW?Nm241S69BT002DY
>Lh8@QS636<HaPaS<H`001BU124]J`@Q8@P<Hb480008@R48:DX48@022480248@7>L@Q1245:D@Q000
9BT200002ABU00048ABU:DX<HaBU7>L00003Ool00`00Oomoo`0;Ool00`00Ool@Q00436<248@010aS
248<HaS60bDY00TQ22DY<H`mkd8@>Lhe[Cg_AS400TYB00=243g_@Q000TYB00@mkbe[;F/icP=6<@0?
@Q0e[BU::DXHaR48=Je:DT8@<H`]JcF]>Lh]JacW008HaP045:D8@PQ236<248@01ABU7>LQ22489BT0
0be[0RDY00TmkekgJeYS65[FHaQW>F<HG_L00VLi00YBU3F]7>LHaR48<Ha:DUkgIcUNm`AF]@9BU00:
E[EJeUJeCW=6<CW>;F/YBSW>DY@2G_L2F]H2HaP01U:D=JdHaQBU:DY2409>L`04?NlU:ABU36<448@3
36<01124Oomoo`003Goo000<Ool01000Ool000@Q0`0000L48@0000048@00248DY@026<H06AcW9BTQ
22e[<H`Q22U:;F/aS3F];F/YBRDY;F/e[Cg_;F/Libe[=Jd]JaBU7>LU:Be[008HaP0?8@P8@QcW<H`Q
20aS124DYAcW48@48@aS124000@Q008000051248@PQ236<48@0248@02@007>LLiaS65:E:DT8@AS5:
DP02AS44BU800d8@AS4Q200248@01aBUAS5:DSW>@Q1>Lcg_008aS005AS4mkb48AS4icP02@Q003b48
36<U:BDY>Li244YBDYA6<CW>AS5>LcF]<H`Li`0236<01ABU@Q1242U:;F/00`@Q00D8@P@Q124000@Q
0080009oo`03001oogoo00]oo`0;001oogoo?Nml01cWOom:DR48@Q0YBP0212401QS6<H`e[@aSG_LH
aP8DY@0O9BT8@P@QAS5[FPQ2F]I240@Q48@icRe[G_L48BDY@Q0mka247>Le[AcW6<H8@P007>Lmk`00
6<H@Q3g_9BT00PaS01XaS4Ha8@P<HcF]<H`00248000Q23F];F/8@Q24125l04Ha000U:AcW124DYBU:
5:EJeR480QBU00<8@Q24=Jd00P@Q01Xe[Be[36<<HcW>5:DLiaS67>L@Q0@Q000<H`@Q48@Q212436<a
S24848@Lib485:D48AS610aS018000Q2248YBQ24<H`icRU:000Q22DY5:DYBP008@P@Q36<36<3Ool0
0`00Oomoo`0;Ool00`00Ool<H`0236<00`Q236<<H`0248@010aS48@DYAcW0RU:00@aS3F]?Nm2408m
k`09>LhmkdHa@Q0icRe[:DX]Jcg_009:DP03?NlicT8@009:DP03@Q0mkcW>008aS0058@PU:CF]?Nla
S0028@P0136<>Lh]JacW0QBU00@@Q0aS36<@Q0<DY@<HaP0?7>LQ22488@PU:C6<BU9NmfLiHaQNmf<H
IcUS65kg009S6006E[De[AcW7>Le[Dic0U[F0Ukg00MJeUJeE[EBU4icBU9>L`02E[D04dic?NlaS2e[
=Je:DUkgIcUS65kgHaQW>F<HF]I6<Be[5:DHaSF]009BU004CW<aS1BU36<348@536<2Ool00`00Oomo
o`0;Ool000aoo`03001oo`0000@0000412400000124200003@Q25:DDYBU:9BTaS2e[7>LHaRe[9BT<
Hc6<008DY@0:124@Q1cW:DXe[C6<5:DU:C6<?Nl2>Lh011BU9BTU:@aS0R4800<8@Q2448@00QcW00DU
:A2412448@aS00848@<000071248@P00248DY@aS12400QBU00DHaPaSAS5244ic00I6<@09@Q16<DHa
8@P@Q1S6AS4e[Cg_00=24004BU8icSW>?Nl2@Q001bDY<Ha2448@;F/e[BDY008mk`0=@Q16<DicBU92
44YB@Q0]JdHa=Jd<H`@Q36<00U:D0Re[00<48@0000001@0000D48@00Oomoo`0000eoo`04001oogoo
Oom2O0028@P03A246<H8@RU:36<Q2124000@Q2e[6<H48AcW008@Q008248e[ABU48@HaR48000aS080
000:248aS2U:124YBQ249BU2400048@200002AS6000HaQ246<H8@P@Q48@U:@030000112436<8@PaS
0P0000P@Q1BU000HaQcW5:D<HaBU0goo00<007ooOol02goo00<007oo36<01`aS0a2400LHaRU::DXi
cT8@?NlicP04=Jd2>Lh02C6<:DXYBS6<>Lhmkd8@?NlicP02=Jd013W>@Q16<D8@0SW>0be[00TYBQcW
6<HU:CF];F/LiaBU48@00QBU21241AS600HU:CW>CW=NmfLiHaP2G_L046LiHaQNme[FHaQJeSW>8@PY
BTicHaQJeU:DF]IS65kg0eJe00aBU4YBAS5>LekgE[E243W>?Nm:DU[FHaP3IcT00f<HG_MF]@02E[D0
148@9BT@Q2U:0Tic00AF]CW>6<H<H`8@Q0H<H`9oo`03001oogoo00]oo`0037oo00<007oo00000`00
00@48@00000000<48@03000<H`aS008Q200?5:DU:BDY124U:Be[36<HaR487>LQ22e[6<H8@Q24008U
:@065:D8@Q24<H`icSF]0RU:00d]JaS6248HaPQ2124HaS6<248<H`@Q24848@0300001PQ212448@00
124000<8@P8Li`0548@HaTHaAS5:DP03AS401dYBAS56<Cg_AS4mkbU:008HaP04@Q0mkd8@=Jd2@Q00
3DYBCW=>Ld8@<H`e[Cg_;F]6<Cg_;F/U:C6<008mk`03@Q1:DU:D009:DP08CW=2436<AS52424836<8
@P8aS003>LhYBQBU00848@0724848@@Q124000@Q00000Woo00<007ooOol02goo00@007ooOole[@8U
:@0=;F/Q22U:;F]JeSW>E[D48D8@=JdU:CW>8@P00RU:00<]JaS69BT00QBU00lmka24<H`e[A245:DL
iaBU9BT48A24;F/Li`aS12400P0000TmkbDY5:D@Q4YB@Q048B4836<00QS601P8@Q24CW<]JaS65:DH
aRe[:DX<H`@Q:DX@Q0Q2:DX<Hcg_36<U:@001248@P00=Jd27>L01AS6=Jd@Q00048@00R4800lDYCg_
7>LQ21cW8@PaS1S636<48BDY48A6<CW>6<H00PaS00DU:@@Q=Jd000@Q00<000065:DU:B48248]J`00
0QBU00l8@QcW;F/<Ha246<HYBP006<HYBPQ25:DmkbDY;F/00goo00<007ooOol02goo00<007oo36<0
20aS0a240QcW00DaS3g_>LhaS2e[00<YBP09<H`]JbU::DXaS3F]<H`YBRe[008aS08U:@04=Je6<E:D
CW<2@Q002cF]<H`YBQcW5:DLibU:;F/Q21BU48@00QBU1`aS00<@Q1BU5:D00QS60QcW01HU:CW>DYAS
66]JHaQNmf<HIcUS65[FG_MS65[F?NlYBSF]DYANmeJeCW=F]@9Nm`9JeP9Nm`09CW=6<E:DF]IF]DHa
?Nm:DUJe009Nm`9S609W>@08F]I>Le:DG_MJeSF]5:DHaP8mk`06E[E6<B4848@<Ha240`aS00<@Q0aS
36<00Woo00<007ooOol02goo000<Ool01000Ool000000P@Q00<8@P0000000P@Q00<8@P@Q12400PQ2
00D@Q2DY;F/Q22e[008@Q00;36<LiaS66<HDYAS67>L]JaBU6<HaS00248@00aBU:DX]J`02?Nl2@Q00
1cg_7>LQ21BU6<HDYB480088@P03000DY@@Q00@00007124000000008@PaS24800P@Q0QBU00<@Q1cW
AS400THa14YB00i>LdYBAS5:DTHa<H`Lic6<:DY243W>;F/icSF]1D8@00E6<Cg_9BU242e[008YBP04
>Li2448@AS42BU802SW>AS5:DRe[>Li:DTHa;F/<H`@Q0PQ200<icS6<8@P010@Q00D000@Q124000@Q
009oo`03001oogoo00]oo`0<001oogooOolLigoo:DXaS6<HBU8icTic0SF]00@U:BU:48@U:@<8@P07
36<YBQ2436<aS0@Q24800S6<01@LibDYF]H48CF]5:D<HaS67>L<Ha24CW<DYBe[5:DQ248@7>LaS0@Q
0PaS0QS601l00124000@Q4ic36<DYBe[AS4aS3W>CW=F]D8@;F/HaQBU8@QJeP@Q9BTaS0aS000]Jb48
124]Jb48<H`]J`02124040Q26<HDY@00248YBP@Q36<48@aS48@HaQ24249240@Q0PaS00<]J`aS:DX0
0Re[00PLiaBU248@Q0aS7>L<HaS60P@Q00DDYA246<H]JacW008Q2008000@Q1BU000@Q2U:000DY@=o
o`03001oogoo00]oo`03001oo`aS008<H`<@Q08<H`<@Q00936<@Q1248@P]JcF]>LhaS2U:008Q20@Y
BP8]J`8U:@07;F/aS2U:8@PYBSW>BU800Tic0THa00<icRe[9BT00R480bDY00DHaQBU5:DHaQ240088
@P0:36<@Q0aS36<@Q1S65:D@Q1BU7>L28@P022DY=JeBU6LiJeYS65kgHaP2IcT2HaP036LiF]I243F]
?Nm>LeJeCW=:DTicE[EJeP=Nm`0;F]IF]E:DDYA:DT8@?Nm244icE[EJeP03G_L00f<HIcUNm`02DY@0
1F<HIcU6<AS636<00RU:0TYB00<]Ja2436<00Q2400D<Ha2448@@Q0aS009oo`03001oogoo00]oo`00
37oo00<007oo00000P@Q0P000`@Q00@000@Q24848@800088@P078@PYBR489BT<Ha246<H00QcW00PD
YAS636<HaS6<;F/U:@Q20RDY00@e[B488@PLi`8<H`0948@48ABU6<HDY@@Q8@P48ABU008<H`030004
8@0000@0000724848@aS36<8@P005:D00QS600@<Hbe[DYA6<@A:DP03CW=:DU:D00=6<@0:=JdU:Cg_
>LhmkcW>:DXmkcF]@Q02BU801CF]AS4aS48@AS400QcW00dU:CW><H`mkdHaBU9243W>?Nm:DT8@?Nm2
4002AS400cW>36<8@P0212400d8@;F/HaP0500041242Ool00`00Oomoo`0;Ool04`00OomoogooE[DY
BWoo124e[AcW0012424836<icSg_JeXLif]J00848@03=JdQ21BU008U:@8mk`0F=JdaS3g_5:D48Cg_
6<H000@Q:DX001S6000YBP@Q6<HYBT8@0008@Q246<H236<28@P07`@Q5:DYBP00;F/HaRDY:DXe[@aS
124U:B4848@LicW>=JdHaQcW6<HaS3W>5:DYBRDY6<H8@PaS>Lh]J`aS008aS00B6<INmbe[48@HaQ24
36<004Ha:DX48BU:8@P]J`@Q36<Lid8@0PaS00T48AcW00048ABU000icP00:DX00QS60RU:00@000aS
5:D]J`8Li`099BTHaQ246<H00124124e[@0000=oo`03001oogoo00]oo`03001oo`aS00<<H`D@Q08D
Y@0648@<H`aS5:DQ236<0Sg_00HaS2DY9BTU:BU:;F/2:DX02R48:DXicTHa@Q0]JbDY;F/icSg_13F]
00XaS2DY9BTYBRe[:DXU:B487>LHaP8DY@0536<8@PaS5:D@Q00236<01ABU6<HDYA246<H00b4800LU
:CW>F]I[FVLiG_MS6002JeX2IcT02F]JHaQJeTYB@Q16<E:DE[EBU002AS4015:DG_MNmekg0U:D0U[F
00Y:DSF];F/icTHaCW=BU5[FHaQNm`9F]@9Nm`9F]@05G_MS64YB8@P<H`028@P0148@BU8aS1BU0PaS
00<@Q0aS36<00Q2400@<HgooOol000eoo`0037oo00<007oo00001@000`@Q00<000Q200000P0000H4
8@Q29BTU:BU:=Jd29BT27>L02ABU:DXLiaS65:DYBSW>CW<YBP0248@01000;F/48@@Q0QBU00X@Q1cW
6<HHaS6<8@PHaRDY48@48@80000:12400000248000Q20008@QBU48@224801BU:7>LLia249BT01DYB
0Tic0dYB0T8@00LicRU:9BTicSg_@Q0YBP02=Jd023W>AS56<C6<?Nle[D8@;F/27>L2=Jd02cW>?Nm6
<DHa@Q0e[D8@BU8]Jd8@BU800Sg_00<aS12448@00P@Q0RU:00H]J`0012448@0012440002Ool00`00
Oomoo`0;Ool02@00Oomood8@9BTYBPQ25:D48@02Ool00f<H@Q08@P028@P00acW000mk`029BT046Li
BU8HaTHa=JdQ236<5:D48Be[<H`8@S6<36<Q21S60PQ200DU:Be[36<HaR4800848@0548@YBRDY6<H8
@P038@P248@01THa48@<HaBU=Jd48@<0000D:DX48AcW8@P<HbU:48@e[ABU124mk`Q2124@Q0@Q<H`Q
20@Q36=2408DY@04>Lh@Q24848@26<H03@Q248@HaP@Q5:D@Q0Q248@YBP@Q:DX8@P000088@P04124e
[@Q248@2000010aS8@P000000Q2400P000Q236<YBQ24124@Q1cW0Re[00DHaQBU5:D@Q1BU00=oo`03
001oogoo00]oo`04001oo`aS48@336<548@25:D248@020aS6<H]Jcg_AS5243W><H`2;F/3:DX022e[
>Li>Le[FCW<e[B489BT2:DX011cW6<HLiacW0R4800@U:Be[;F/]J`8YBP038@PDYA2400<<H`@@Q007
5:DHaQS65:DHaR48:DX00RDY00L]JdHaG_M[FVLiHaQW>@03JeX2IcT036<HF]IBU4Ha@Q1>Le[FE[E6
<Cg_CW=Nm`9JeP9:DP9F]@07@Q0aS3F]AS5BU5JeF]H00V<H00=JeUJeDY@00eJe00IJeV<HG_M6<BDY
48@27>L013W>BU8e[AS60PaS00<@Q0aS36<00Q2400@<HgooOol000eoo`0037oo00D007oo12448@00
00848@0700048@001248@P@Q248010@Q01H<HacW:DX]JcF];F/U:AS648@DYAcW8@Pmkd8@:DXicQBU
124Q20Q25:D<H`<DY@07248DYB4848@DYAcW6<H00Q2400<48@0012400`0000X48ABU8@P]Ja24248<
HaS6248]J`8Li`0B6<HaS4icCW=:DTHaBU9>LdYBCW=BU4Ha@Q16<D8@;F/Q22DY0SW>00@YBRe[@Q0m
k`=24005;F]243g_9BTQ2003?Nl01D8@AS56<DHa@Q000Sg_00U:DRU:?Nm6<DYB@Q0mk`aS5:D00P00
00<]JbU:=Jd00P@Q0`000`@Q00@007ooOol000eoo`0C001oogooOolmkbe[=JdDYAcW36<]JcF]5:Di
cP@Q=Jd002DY36<00QcW01lHaR482488@P00248004Ha124DYAcW<H`8@S6<8@P48BDY7>Mg_ABU>Lhm
kaBU248YBRe[36<48AcW000@Q002@Q007`00:DXmkaS6000e[@aS7>LU:BU:000U:DHa9BTe[ABU248U
:@Q21248@RDY124<HbU:5:D]J`Q248@Q22DY008<H`048@PU:DHa7>L236<02be[7>L48AcWCW<]J`00
124DYCF];F/00R4800DYBQS67>L8@P@Q008HaP057>LaS36<48@<H`029BT00cF]000<H`0236<01Q24
124@Q124124e[@8000035:D007oo009oo`03001oogoo00]oo`03001ooa2400P<H`0348@DYABU00<@
Q0045:DQ236<?Nl3AS401cg_<H`U:BDY;F/mkdYB009BU008BU8e[B486<HLib487>LHaP8DY@0A6<HQ
22e[<H`]JbU:;F/YBQcW48@8@PaS48@<H`Q248@Li`03:DX29BT00bU:<H`e[@02<H`00cF]AS5Nm`02
JeX01V<HIcU[FV]JIcUS60=Nm`0:E[E243F]>Li>Le:DAS5244icF]H2E[D014icDYAF]Dic0Sg_00M:
DUJeE[EF]F<HIcUNm`02DY@02U[FE[EBU5JeG_MW>EkgAS4YBQBU0QcW00@icTYB>LhLi`8<H`0348@<
H`aS008<H`04249oogoo000=Ool000aoo`05001oo`00248000021242000010@Q0008@PQ210@Q01P8
@P@Q48@U:AcW9BTe[D8@9BTDYA248@PU:CW>?Nl@Q2e[<H`DY@Q25:D8@R4848@27>L02P@Q5:DLib48
6<H<Ha246<H48@000`@Q00`8@P0036<DYBU:7>L]Jc6<CW<@Q3g_:DX37>L01BU:BU9:DTYBCW<00dYB
00A>Ld8@@Q16<@924009;F/U:ABU8@PicRe[@Q0e[Be[00924006?NlicSF]=JdU:CF]0SW>00<e[Cg_
AS400THa00]242e[AS5:DS6<AS5:DSg_CW=:DPaS00<@Q0049BTaS2e[48@80002Ool00`00Oomoo`0;
Ool03`00Oomoog>LBU8icW>L:DXmk`@Q6<I24000LiaBU002AS402aBU:DXQ2248248]JbU:AS400248
7>L00Re[01=g_@@Q248@Q5:D248e[@00;F/e[CW>BU88@P@Q36<e[A24000<H`026<H04P008@PQ21BU
BU924000124mkdic;F/Q2000?NlYBQS636<Q208aS00>000aS2DY000YBSW>7>M:DQBU0008@PaS8@PH
aP8U:@04:DX00248000212404E:D6<H]JbDY8@PDYC6<=Jd<H`@Q5:D001BU0008@SW>8@P00`0000D4
8CF]1248@QS60088@P0?48@LiaBU8@PHaP006<H@Q3g_48@000Q25:D@Q0@Q00=oo`03001oogoo00]o
o`03001oo`aS008<H`<@Q08<H`H@Q00D5:D@Q1BU7>L]JcW>AS5>LdYB>LhYBR48;F/mkdHa@Q0icSF]
<H`]J`8Q20039BT]Jbe[008Q20056<HQ236<=Jd]J`028@P02RDY7>L<H`Q248@DY@aS248HaSF]0THa
00I243g_=Jde[CW>?Nl2=Jd00be[?NmJeP02Kg/01FLiHaQ[FV]JHaP00Ukg00aS65kgE[E2436<:DXe
[DHaCW=:DTicDY@4E[D015:DBU9244YB0UJe00UBU5JeG_MNmeJeCW=F]EkgF]H00U:D00INmfLiIcUB
U36<6<H27>L013F]BU9242481@aS0Q2400@<HgooOol000eoo`0037oo00<007oo00000P0000L48@aS
00048@0024848@02000212401@Q236<48@0012400R4800@U:CF];F/U:@8HaP0936<HaQcW9BT<HaBU
9BT]JbDY008HaP0L:DX<H`aS124@Q248=Jd@Q0Q248@HaQBU00048@00248@Q0@Q248]JeJe<H`YBR48
:DX48Be[8@P27>L26<H01dicBU9:DU:DBU9>LdHa00924096<@05BU96<Be[8@PLi`026<H013W>;F]2
42U:0T8@00HmkcF]<H`aS2e[?Nl2>Lh03Cg_BU9243W>=JdaS3g_BU9242U:?Nm6<D8@0096<@03:DX@
Q124008@Q003<H`]JaBU00@000041248@P@Q0002Ool00`00Oomoo`0;Ool04`00OomoofLi36=Nm`Q2
7>LYBPaS=Jd8@P007>LDYBU:000@Q0aS008U:@098@Q243W>48@icPQ27>L@Q248008<H`0D:DX48AcW
<H`<He[F36<8@P00?Nl8@PaS001W>BU:000DYDHa5:D48@8Li`0O48@icS6<>Lhmk`Q25:D@Q0aS248Y
BPQ2:DXe[@aS248Lib48<H`Q21cW@Q0DY@aS<H`Q22U:7>L8@Q2400000SW>00/DY@0036=BU1S6>LhH
aT8@48@8@QBU00800007124LiacW248@Q1S68@P00Q2400T48@Q2<H`8@P00BU88@Re[12400PQ20P00
0PaS00/DY@aS248000@Q48@8@QBU124<H`Q200=oo`03001oogoo00]oo`03001oo`aS008<H`0548@D
YA2436<@Q0025:D01Q2436<@Q1246<HDY@8@Q0077>LYBSF]@Q16<D8@=Jd00RU:00XaS3F]<H`YBR48
:DXaS3F];F/YBP8aS08YBP8Li`07;F/aS24848@HaR487>L00Q240QS600D@Q1BU;F]6<Dic009:DP03
AS4mkcF]008icP8]J`058@Pe[E[FLia_N`02IcT016]JIcUNmekg0V<H00ANme[FDY@mk`8YBP03>Li:
DU:D00ABU009E[EBU4YB@Q16<DicDYA>Le:D009JeP03DYA:DU:D009Nm`09E[E>LdicF]IS66]JG_Lm
kacW008HaP06;F]6<D8@9BT@Q0Q20PaS11240Woo00<007ooOol02goo000<Ool01000Ool000000P@Q
0PQ20P@Q00@8@P@Q12448@<8@P<48@0:248<Hb488@PHaR48<H`DYAcW8@P25:D01`@Q5:DHaPQ2;F/D
YAS6008@Q08<H`03000DYABU00848@04248<H`@Q5:D2124010aS12448@Q20S6<0R4800H]JcW>6<HD
YBe[5:D248@00aBU7>M:DP02DY@3BU801T8@AS56<D8@AS5:DP8mk`08BU8Q21cW6<H]JdHa?Nl]J`92
400;=JdaS2e[=Jd]JcW>=JdicT8@AS4icP02<H`033g_BU96<Cg_9BTe[D8@BU8mkdYB;F/<H`88@P04
5:D]Jbe[6<H212401P001248@P0024848@9oo`03001oogoo00]oo`0C001oogoo8@PLi`006<IS6000
5:DQ22e[>Lh<HaBU;F/@Q2487>L00THa00HaS248000Q20@QCW<26<H02Dic36<Q20Q2<Ha244YB125B
U00224803248@Q0Li`@Q6<IF]DYB:DX48@Q2>Lh@Q088@P05000YBPaS;F/00002<H`05QcW@Q0@Q000
7>L002e[6<H<HcF]7>LQ21BU7>LYBQBU7>L007oo124HaRe[0QS60P@Q00HHaQ24E[D48AS6;F/236<0
22485:DLibe[36<HaPaS:DX200003@@Q6<HQ20aS48@Lia24248002U:7>LHaQcW0080000?AS4Lib48
124<HaS636<HaQcW000<Ha24248@Q0Q200=oo`03001oogoo00]oo`04001oo`aS36<648@25:D248@2
5:D26<H01a2436<@Q1cW9BT]JcF]008icP03<H`U:BDY008YBP067>LDYAcW<H`icS6<0bDY0QcW00/D
YAS69BTU:ABU48@HaR487>LDYA2400<DY@038@Pe[Cg_008icP8mk`04=JdaS36<;F/29BT00b48>LiF
]@02IcT016<HIcUW>F<H0U[F0V<H0ekg00EBU3g_:DX]Jd8@009F]@05CW=:DTYBBU96<@02?Nl05DHa
CW=BU5:DF]IS65kgCW=:DUJeG_MF]DYBAS5>LeJeG_MS65kgAS4Q200248@01bU:AS5242U:48@8@PaS
00D@Q09oo`03001oogoo00]oo`0037oo00T007oo1248@P0024848@0012400PQ21@@Q00<8@PaS0000
0P@Q00@000aS5:D@Q08HaP097>L<HaBU9BT@Q0aS1248@Q24008HaP0324848@aS008DY@0;1248@PQ2
24848@aS248<H`Q200048@0300000acW8@PDY@026<H01R48<H`Q23W>6<H@Q0<HaP057>LicR48;F]6
<@02@Q000dHa@Q16<@02@Q02AS400d8@BU8mk`037>L2@Q0012DY>LhicRe[0R4800@]Jc6<?Nlmk`96
<@0;BU96<Cg_?Nm6<Cg_=Jdmkbe[?Nm:DP02@Q000e:D;F/<H`03248014Ha<H`DY@000P@Q00<000@Q
00000P@Q0Woo00<007ooOol02goo01<007ooOom_NaBUE[DYBRDYE[D48@00;F/48BDYAS4005:D48AS
600212402UJe:DYoocW>5:Dmkc6<48@DYA240SF]00TDYC6<8@Q[FQcW5:D48E[F36<00P0000P8@Q24
7>LDY@@Q6<I243g_0P0001l8@QS6;F/<HcF]6<H]Je[F248YBQBU36<Q2000:DXDYAcW248001BU7>Li
cQBU6<Hmk`@QAS448AS6CW<DY@02>Lh07B48124@Q1BU248<Ha2436<48@Q2000<H`@Q>LhHaR48248D
Y@@Q248HaP00124000Q236<8@QS636<00P000RU:00d8@QBU1248@P@Q36<00248124<Hb48:DX8@P02
0003Ool00`00Oomoo`0;Ool00`00Ool<H`0648@00aBU48@@Q00448@25:D01A2436<<HaBU7>L00R48
010U:Be[;F/U:B489BTYBQcW48@DYBDY;F/YBQcW6<H@Q08<H`0648@HaQcW6<HDYAS60QcW00<DYA24
36<00PQ200<DYB48:DX00bU:00HaS3F]=JdaS2U:8@P29BT01S6<@Q1>Le:DE[EJeP9S6003G_MJeUkg
009Nm`08F]INmf<HG_M:DS6<:DXicP9:DP03AS52448@00A2400ABU9F]E[FG_MS66LiHaQBU4icF]IN
meJeAS5:DUJeG_MJeP02G_L01DYB8@P<H`aS9BT00THa00<YBPaS36<00Q240PaS0Q240Woo00<007oo
Ool02goo000<Ool01P00Ool48@@Q00048@<000051240000000048@04000040@Q00048@00124@Q0@Q
000@Q0Q25:D8@QcW8@P<H`@Q0PQ200DQ20aS48@@Q0aS00<0000;48@HaQS6248@Q0@Q6<H48@001248
@P02000212425:D26<H00acW8@PQ20026<H37>L2@Q002248?Nm6<Cg_AS5>LdYBAS42@Q0024Ha?Nm:
DTic8@PLib487>L248@021S6;F/]JbU:=JdaS3W><H`2?Nl01DHa@Q16<D8@>Lh01Cg_00Q244icAS56
<Cg_BU8e[ABU0PQ200H48Cg_:DX@Q0@Q0002124200001@@Q001oogoo00003Goo01<007ooOolYBP00
248DYAcWCW<icTHaKg/YBTHa5:D002e[48@e[@0236<02PQ248@DY@aS7>L<HbU:36=:DRU:0PQ200@<
H`@Q5:De[@88@P0;5:E:DQ2448@48B4836<Li`Q2>Lh<H`0200025:D05@@Q36<DYA246<HDYA245:De
[@aS9BT8@TYB9BT48@aSAS448@Q21248@P0236<02248000<Hd8@8@P000@QAS4200003cW>5:EBU1cW
9BT48CW>:DX@Q0aS000@Q2e[0008@P0248@00`005:Dmk`02248011249BU6<B480PQ200<003W>;F/0
0P0000TDYB486<He[A245:D<HaS67>L00P@Q00@000@Q8@P<H`=oo`03001oogoo00]oo`03001ooa24
008<H`8@Q08<H`8@Q08<H`<@Q08<H`8@Q00=248<HaS67>LHaQBU6<HQ21cW8@PYBS6<9BT00QBU0R48
00@LiaS66<HDY@8@Q0036<HQ21cW008HaP8Li`045:D<H`aS36<212401PaS6<HQ22U:=JdicP<mk`03
>Lh]JbDY008YBP07=Jdmkcg_?Nm6<E:DG_L01F<H00QJeU:DF]IW>EkgAS4aS2e[0c6<00@icT8@@Q1:
DP=>L`04DYAJeUkgG_L2F]H025JeDYABU5[FG_MJeUJeF]H2IcT01EkgHaQW>Dic8@P00PaS00@U:DYB
BU8U:@8<H`035:D@Q0aS00<<H`9oo`03001oogoo00]oo`0037oo00<007oo0000100000<48@000000
1P000P@Q00L000@Q000000@Q36<00002248010@Q48@<HaBU0R4800LHaQBU48@8@PaS5:D0000336<0
2Q245:D<H`Q236<48ABU36<48@aS0`0000/8@QS69BT]Je:DE[E>LcW>;F/YBQS600<Li`8HaP055:DU
:C6<=Je24002BU802dHaBU96<DHa?NlicTYBCW<DYAS68@P00QBU00TQ22U:<H`aS3g_@Q16<DicBU80
0THa00HmkcW>=JdaS3F]@Q02?Nl00dicBU9:DP02CW<01DHaCW=F]Dic24800Q2400@48Cg_<H`@Q0H4
8@80009oo`03001oogoo00]oo`0C001oogoo248000Q26<I6<B48OolU:F<H36=>L`Q2:DX@Q6<H36<0
0WNm01P48A24001cW7ooNmicW2U:000icQcW48A24124=JdLi`@Q0008@P@QE[D@Q1S6000212400`aS
G_L]J`02=Jd2DY@07aBU48@@Q2U:000DY@aS9BU>L`@Q36<006mk124YBSF]48@8@RDY=Jd002U:8@P@
Q1BU:DXaS0@Q36<LicF]00848@048@P48A24000212406BU:48@Q22U:;F/48@00DY@8@QS648@aS0Q2
124Li`@Q000DY@001248@QBU124<Hbe[0080000=124HaRU:48@48D8@5:D<Ha24;F/<H`@Q7>L00QBU
0goo00<007ooOol02goo00<007oo48@00PaS0Q240PaS0Q240PaS0a240PaS0Q2400D<H`Q248@HaQBU
008<H`075:DHaR48;F/e[Be[8@P00QcW0aS60R480acW00<Q21cW5:D00QBU00@HaQBU5:DHaP8Li`09
6<HDYAcW:DXmke:DE[EBU4ic009:DP0;@Q0icS6<<H`]Jc6<>Li244HaDYANm`03IcT02F]JIcUF]E:D
G_M[FUJe=JdYBP02;F/28@P00cF]BU9:DP02DY@00e[FG_MNm`02F]H01EJeCW=6<DYBDY@00eJe00YN
mf<HIcU[FVLiHaQ[FW>LF]HU:@88@P048@Q:DTYB9BT236<00aBU48@<H`0236<010Q2Oomoo`003Goo
000<Ool00`00Ool00002000312400`0012448@0612400`0024800003000020Q21248@P0048@DYAcW
5:D37>L01`0048@48@00248LiaBU0088@P0I1248@PQ21248@PaS1248@QBU:DXaS4ic8@PHaRDY:DXi
cSF]<H`e[CW>@Q1:DUkg@Q000RU:00LU:AcW=Je243W>@Q1>L`04DY@01TicAS4e[DHaCW<icP<DY@04
7>L<Ha24;F/2<H`063g_>LhmkdHaBU96<D8@;F/aS248:DY244Ha;F/e[D8@AS4mkdYBAS5>LdYBCW=6
<@@48@8e[@0536<48@0000048@040002Ool00`00Oomoo`0;Ool02@00OomoofLi124DYAcW<H`]J`02
8@P020Q2HaPU:DYBCW<Licg_8@P248@032e[36<]Jbe[BU848@Q28@PDYCg_9BTYBP<<H`0848@48@@Q
36<8@QS6124aS0848@06000e[AS6124002480Tic01LDYBDY7>LicU[F6<HDYC6<CW<HaPQ200048AS6
124]J`Q2124]JaS648@Q21cW0088@P06;F/48@@Q000Li`@Q0PaS018icV<H9BT@Q1S648@LidHa:DX@
Q1BU24848AcW124HaR486<H224802acW000HaPaS6<H@Q1BU36<48@Q2=Jd00PQ200l<Ha245:DaS1S6
36<]J`aS1248@RU:8@PLi`@Q36<00goo00<007ooOol02goo00@007oo36<8@P8<H`0348@<H`aS00P@
Q00836<@Q12436<8@PaS48@DY@8@Q0046<HQ22DY:DX2;F/00bU:8@PHaP025:D00acW8@PQ20026<H0
5ABU6<HLiacW5:D@Q1S6:DXaS3W>@Q1:DTHa>Lhe[D8@E[ES65kgE[E>L`02BU82E[D2@Q003SF]>Li:
DU:DE[EJeV]JKg][FVLiKg][FU[FE[D2IcT00dYB:DXQ2002:DX00acW9BTmk`04DY@00e[FHaQNm`02
F]H015JeAS5244YB0UJe0Tic00YF]EkgIcUW>F<HG_M[FW>LF]HU:@88@P047>M244Ha9BT236<00a24
36<<H`0248@010aSOomoo`003Goo000<Ool00`00Ool0000500000`@Q248000031242248010@Q0004
8@000P@Q0P000148@PaS48@@Q2U:8@P8@QBU124<Ha24124@Q0aS1248@PaS0088@P0F36<@Q1247>L@
Q0aS48@mkdHa<H`icU[FE[E6<D8@?Nm6<D8@?Nm2424848@29BT014icAS56<CW>0dHa00E>LdYBCW=B
U4ic00=:DP05@Q0mkdic@Q0HaP025:D01A245:DQ22U:=Jd00S6<00Te[C6<<H`icSg_=Jdmkd8@AS40
0T8@0THa00DYBSF]=Je6<DYB00924096<@03BU8icQ2400848@05000e[C6<24848@03000010@Q0004
8@@Q0Woo00<007ooOol02goo00D007ooOomBU0@Q009:DP05248icQS6;F/icP02AS401D8@:DXicP@Q
36<00P0001<@Q4ic:DXDYA24248Q22DY36<@Q2DY124002U:36<@Q0005:DHaP0200000aBUDY@Q2002
36<01E[F9BT8@S6<@Q000PaS0R4801@DY@@Q7>LYBP0048@DY@00124YBP@Q8@P48@aS00048A24248<
HbDY0P0000DQ22DY48@YBSg_008]J`8DY@07>LhYBSW>>Lh8@P008@P00PaS00d@Q2480008@P@Q36<8
@P@Q:DXDYC6<5:DQ200236<0112436<HaQcW0PQ2018U:AS66<HLi`@Q248<HbDY124YBP0036<8@Q24
36<8@P005:D3Ool00`00Oomoo`0;Ool00`00Ool<H`0436<348@00`aS48@@Q00848@236<011246<HQ
22U:0S6<00L]Jb487>LU:BU:8@PHaP025:D36<H25:D02`aS5:DU:C6<;F/U:BU:?Nm>LeJeG_L00V]J
00=Nme:DE[D00Ukg00MF]Dic@Q0icSg_DYAS6002F]H2CW<015kgIcUS66Li0Vmk011[FVLiJeYW>Ekg
F]INme:D>LhQ21cW9BTYBRe[>Li:DP9>L`03BU9>LeJe009JeP9S6006F]I>Le:DG_MS65Je0TYB00=B
U5[FG_L00ekg0VLi00E:DQcW2488@QcW009240038@P8@PQ2008@Q08<H`0548@<HgooOol0000=Ool0
00aoo`06001oo`0000048@000P@Q30000P@Q00/000@Q5:DYBSg_>LhDY@aS5:D@Q0aS008Q20041240
00@Q36<25:D26<H2248012e[DYA>LbU:0SF]0THa00A:DU:DE[E>L`924009?Nm:DTHa>LhLib489BTQ
23g_00=24004AS4icTYBAS42BU8014icBU9:DTYB0THa00@mkbe[8@P@Q08HaP057>LHaRU:;F/e[@02
>Lh2?Nl0348@?Nm244icDYA6<Cg_BU9BU4Ha?Nm6<@8mk`96<@06?Nm:DTHa@Q0mkaBU0`Q200@48D8@
<H`48@D000848@04001oogoo000=Ool01P00OomooacW248DY@88@P0;9BTQ212436<8@QcW;F/<Hd8@
6<H48@02000045Je5:D48@Q2124YBPQ28@Pmk`aS000HaUJe6<H]JcF]0QBU00d]J`Q236<<Hc6<6<HL
i`Q2000<H`Q236<0000212404`0048A>LbDY124Q248@8@P<Hbe[5:D8@P@Q?Nl<Ha245:DmkbDY0080
000:;F/U:@@Q248@Q36<248mk`0048@28@P01AcW5:D48Be[36<00Q2400P<Ha24248Q248@?Nl]J`00
0RDY00T<HaS67>Le[A246<H48B485:D00QcW00<<HbDY12400PQ200@@Q0Q2248icP88@P067>L<H`@Q
6<HQ20Q20P@Q00D8@WooOomoo`0000eoo`03001oo`aS008@Q0<<H`0348@<H`aS00T<H`8@Q00836<@
Q248=Je6<D8@=JdU:@8HaP067>LQ22488@PLiaS60QBU11cW00lYBT8@E[EBU48@?Nm:DU[FG_MS66mk
Lia_Nf<HE[D00e[F00I>LcW>:DXaS4HaG_L5HaP3IcT2JeX2IcT01f<HG_MF]E:DBU8icRe[008YBP04
;F/aS3g_CW<3DY@01DicDYABU5:DE[D00V<H00=JeUJeG_L00V]J00=JeUJeE[D015[F0ekg00=BU36<
48@00PQ200HYBTYB@Q0U:@aS248248@436<2Ool00`00Oomoo`0;Ool000aoo`03001oo`@Q00848@03
00048@@Q00`0000@248000@Q000YBQBUCW<]Ja2436<8@PaS248<HaBU6<H27>L00`Q2124<H`027>L0
2C6<BU96<CW>@Q0mkcF];F/e[@02?Nl03SW>@Q16<DHa?NlicT8@AS4mkc6<48@U:Cg_@Q02?Nl4AS40
1d8@CW=:DU:DCW=6<D8@008e[@089BTQ22DY<H`Q22U:;F/U:@<mk`=6<@8icP@mk`8aS003@Q1BU4YB
00=>L`924006?NlicSg_@Q0icRe[0PQ20P@Q00P@Q48@>Lh<H`@Q00048@000P@Q0P000Woo00<007oo
Ool02goo01<007ooOom>Ld8@48@<Hc6<=Jd@Q2U:000]Jb48?Nl<Hdic36<DY@02;F/00d8@:DX8@P02
5:D06PQ2;F/<HaBU9BT005Je125:DQcW5:DU:CF]>LhHaP@Q8@P@Q1BU:DXQ22e[<H`48DHa;F/2>Lh0
3`aS@Q08@R48;F/8@U:D48@48BU:000@Q0aS000<H`0248@01D8@:DX8@QcW8@P00PaS00L8@QS66<HQ
20@Q8@P<H`0212407P0036<8@PQ28@PDY@aS8@P@Q1cW=JdHaPQ2;F/YBQS6248000Q2?Nl@Q1cW0004
8B48248<HaBU248YBP<8@P05000@Q0@Q24848@026<H020Q26<H@Q1S65:DHaQ24:DX3Ool00`00Oomo
o`0;Ool01000Ool<Ha242@aS0`Q20PaS00/8@PaS48@@Q0aS48@YBTYBE[E242DY008HaP067>LHaQS6
8@PU:B480QS600dU:C6<@Q1244YBE[ES66LiG_MBU4YBCW=F]@03F]H00f<HIcUS6002E[D025kgHaQF
]Cg_;F/e[DYBE[D2F]H01UkgHaQNme[FG_MS609W>@0:HaQNme[FE[E:DT8@<H`]Jc6<?Nl2AS400d8@
BU9F]@03G_L2F]H00e:DCW=BU002E[D2DY@00ekgJeY[FP02IcT00f]JIcUNm`04F]H015:D@Q0Q20Q2
0Q2400He[E:DAS4U:@aS248248@436<2Ool00`00Oomoo`0;Ool000aoo`03001oo`0000@000031240
00@Q00X000848@0:0008@R48?Nle[ABU48@0012436<2248212401@Q236<<HcF]AS400TYB00IS64ic
BU96<CW>;F/4?Nl2@Q000dHaBU924002@Q001SW>@Q0mkc6<=Jdmk`9:DP8mk`96<@9:DP0C?Nm6<DHa
@Q0mkcW>?NlaS3W>9BTHaQcW6<I:DU:DCW<e[Cg_@Q0014YB00A243g_?Nle[@8icP04?Nle[D8@CW<2
BU82CW<02THa@Q0icSW>?Nm2436<:DX000@Q0P0000@Licg_=Jd<H`848@<0000312400000009oo`03
001oogoo00]oo`0C001oogooBU8DY@Q236<002U:5:DQ24Ha124U:@Q2124DYCW>00000RU:014Lib48
Li`Q24Ha7>L]Jc6<CW<@Q0aS7>L48E:D7>L48ABU0088@P06DY@@Q48@248001240PaS0PQ200hQ21BU
2488@QBU@Q0U:@@Q6<HDYBDY000DY@000P@Q00DDY@@Q:DXHaQcW008Q200<00048B488@P004Ha001:
DSW>48@48@aS0RU:01l48ABU9BTHaR48;F/001S6124<HacW0008@P@Q248]JaS68@P000aS00048A24
5:D48@aS000<H`@Q000]J`0224803`@Q5:D48BDY48@DY@007>L<Hb48?Nl001BU36<00003Ool00`00
Oomoo`0;Ool00`00Ool<H`0:36<3248236<03PQ236<@Q12436<DYCF]E[EBU36<5:D<HaS67>L56<H0
1248<Ha244ic0V<H00A_Ng>LJeYJePMF]@09DYAF]EkgG_MJeUJeG_MS65[F009:DP03DYAJeU[F009F
]@03F]INmekg009JeP05G_MW>FLiG_MF]@02DY@024Ha=Jd]Jc6<@Q1JeV<HG_L2DY@00e[FIcUW>@02
IcT00f<HF]IBU003DY@2BU800eJeHaQW>@02JeX016mkHaQF]E:D0UJe00EBU4Ha=JdLi`Q2008@Q004
>LiBU4YB9BT236<00a2436<<H`0336<2Ool00`00Oomoo`0;Ool000aoo`03001oo`0000@000031240
00@Q00X000848@0:0008@R48?Nle[ABU48@0012436<2248212401@Q236<<HcF]AS400TYB00IS64ic
BU96<CW>;F/4?Nl2@Q000dHaBU924002@Q001SW>@Q0mkc6<=Jdmk`9:DP8mk`96<@9:DP0C?Nm6<DHa
@Q0mkcW>?NlaS3W>9BTHaQcW6<I:DU:DCW<e[Cg_@Q0014YB00A243g_?Nle[@8icP04?Nle[D8@CW<2
BU82CW<02THa@Q0icSW>?Nm2436<:DX000@Q0P0000@Licg_=Jd<H`848@<0000312400000009oo`03
001oogoo00]oo`0C001oogooBU8DY@Q236<002U:5:DQ24Ha124U:@Q2124DYCW>00000RU:014Lib48
Li`Q24Ha7>L]Jc6<CW<@Q0aS7>L48E:D7>L48ABU0088@P06DY@@Q48@248001240PaS0PQ200hQ21BU
2488@QBU@Q0U:@@Q6<HDYBDY000DY@000P@Q00DDY@@Q:DXHaQcW008Q200<00048B488@P004Ha001:
DSW>48@48@aS0RU:01l48ABU9BTHaR48;F/001S6124<HacW0008@P@Q248]JaS68@P000aS00048A24
5:D48@aS000<H`@Q000]J`0224803`@Q5:D48BDY48@DY@007>L<Hb48?Nl001BU36<00003Ool00`00
Oomoo`0;Ool00`00Ool<H`0:36<3248236<03PQ236<@Q12436<DYCF]E[EBU36<5:D<HaS67>L56<H0
1248<Ha244ic0V<H00A_Ng>LJeYJePMF]@09DYAF]EkgG_MJeUJeG_MS65[F009:DP03DYAJeU[F009F
]@03F]INmekg009JeP05G_MW>FLiG_MF]@02DY@024Ha=Jd]Jc6<@Q1JeV<HG_L2DY@00e[FIcUW>@02
IcT00f<HF]IBU003DY@2BU800eJeHaQW>@02JeX016mkHaQF]E:D0UJe00EBU4Ha=JdLi`Q2008@Q004
>LiBU4YB9BT236<00a2436<<H`0336<2Ool00`00Oomoo`0;Ool000aoo`03001oo`00014000<48@04
5:DQ248@>Lh300002@@Q2488@P00248000aS8@Q:DP02AS43E[D00dicBU8mk`05AS400d8@?Nlmk`03
@Q001THaBU9243g_>Lhmk`924096<@924007BU96<D8@@Q0mkdYB@Q000THa00i243g_>LhmkaS67>LD
YE:DAS5:DTicAS5244ic0dHa0TYB00A243g_>Lhmk`92400A=JdicT8@AS5244icBU8icSF]>Lhe[CW>
=JdU:AcW124<H`02248011cW>Lhmk`@Q0P0000<48@0000000`000Woo00<007ooOol02goo00T007oo
Ool@Q000:DX]JbDY?Nl00PQ200PLicW>:DX48@005:DYBSW>0R4800PLi`Q2HaP48Be[8@PaS1BU0R48
00PU:C6<9BTYBRDY7>L000@Q0QcW00/icPQ26<H8@QS65:D<HaS67>L48B48008DY@0O8@PHaQS65:De
[Be[5:D001S636<Q20@Q8@PDY@@Q<H`@Q3F]6<HU:@@Q6<H<HbU:5:DQ21248@P<Hb486<H00QcW00P<
HbU:<H`Li`@Q48@Q21240SF]01D002e[@Q0icPaS;F/@Q0005:D001BU1248@P0036<Q20Q236<LiaBU
12400Q2400laS2DY5:D<H`@Q;F/<Ha246<H<H`Q2000Q200048@00goo00<007ooOol02goo00<007oo
36<00PaS00<8@PaS36<01@aS00<8@PaS36<00PaS00`8@PaS48@<Ha248@Q245Je@Q0Li`aS48@26<H2
5:D248@01B48>LiBU5[FG_L00V]J00EkgW>LG_MBU5Je009Nm`=JeP9F]@06F]INmekgHaQNme[F0U:D
00EF]EkgIcU[FVLi009S609Nm`9S609Nm`9S600<F]IBU5:DE[E:DSF]:DXicUJeKg]cW6]J0Ukg1F<H
00]W>F<HF]IF]E[FG_MBU4icDYAS66Li00=S600:F]I:DTHaCW=F]DYB>Lh]JacW36<25:D02CF]DYA6
<B48248<Ha2436<8@P0336<2Ool00`00Oomoo`0;Ool000aoo`03001oo`0001@00007:DXaS4YB6<H0
00@Q36<00P@Q00T000@Q248@Q3F]E[E:DT8@?Nl00T8@00ABU5Je@Q16<@9>L`08AS52448@?NlicSg_
@Q16<@=:DP03AS4mkcW>00<mk`04@Q1BU4YBBU83AS42@Q0014Ha?Nm2448@13g_0QcW00<U:E:DBU80
0Tic00A:DT8@BU92408icP03?Nm:DTYB0096<@0=CW=BU4Ha?NlaS4YBAS4mkd8@BU8mkc6<=Jd00cW>
00<]J`aS36<00`@Q00<YBSF]=Jd010@Q1@000Woo00<007ooOol02goo01<007ooOol48AcW248icP@Q
249241cW124<HacWG_L004ic:DXe[@02:DX07a249BT@Q248248icR480008@QS6:DXU:A2424848AcW
36<Lib48E[DQ21cW:DXLid8@:DX48AS6?NlHaRDY008@Q00:8@PHaQ24=JdQ20@QAS4Q21BU48@28@P0
4`0048@48B4848@icP009BTDYBU:5:DYBS6<000DY@Q2E[DDYBe[008000075:D001S6:DX]J`Q20000
0P@Q00PaS2U:248DYA246<HQ20000RDY00`000aS6<H<HaS6124LiaBU248002U:248236<021BU7>LD
YA24000YBQ249BT37>L010Q2@Q0002DY0goo00<007ooOol02goo00<007oo36<03PaS00L8@PaS36<<
H`Q25:De[@02DY@00be[48@8@P025:D02PaS248<HaBU9BU245kgJeYS65kg0V]J00M_NfLiF]INmfLi
JeYS6004F]H015kgHaQS66<H0VLi00ANme:DDYAJeP9Nm`05HaQ[FVmkKg]W>@03HaP04EkgF]INmekg
F]IF]E[FG_M>Lc6<9BTicUkgLia_NfLiHaP00VLi00AJeU:DDYAF]@9S6007G_MJeVLiKg]W>EJeDY@0
0U[F0UJe00]NmeJeBU96<DicE[E>LcW>9BTDY@aS008HaP06=Je>Ld8@7>L8@PaS0Q2400@8@PaS36<<
H`9oo`03001oogoo00]oo`0037oo00<007oo00000P0000<48@0000001P000P@Q100000L48@00000i
cSF]?Nl<H`021240300012400000248HaTYBCW=BU4HaBU96<@9>L`03BU96<D8@009>L`05BU8mkcW>
>Lhmk`04AS42BU82CW<014Ha@Q1243g_0T8@1dHa00=244Ha@Q001D8@00@e[BDY6<HLi`9>L`06BU9>
LdicAS5>Ld8@0S6<0SF]0dHa00m:DU:DDY@mkcF]?Nle[C6<?Nm6<Cg_;F/e[CW>@Q000SW>00<000Q2
00000PaS00DYBRe[:DX48@0000848@0300048@000080009oo`03001oogoo00]oo`08001oogoo000H
aRDY6<HicP8@Q00936<HaP@Q48@8@Sg_6<HU:AS6008icP0;1248@PQ26<HYBRDY@Q0<HbDY?NlDY@02
00003E:D@Q0002486<H48Cg_36<U:CF]124000@Q008<H`88@P0O48@8@PQ27>LicPQ26<H<HaS6124@
Q1cW36<8@SF]000HaQcW5:D8@S6<8@PDY@aSAS4DY@Q2000]Jdic7>L00R48014e[ABU5:D]JaS6248@
Q36<;F/U:AcW48@DYB48000@Q248008Li`045:D<Ha24000248@02@aS9BT48@aS9BTHaPaS124Q2002
7>L212400aBU;F/48@02124022DY24848B485:DLi`0048@3Ool00`00Oomoo`0;Ool01000Ool<H`Q2
0`aS0PQ20PaS0PQ20`aS0PQ200T<Ha2424848AcWAS5JeTYB9BT00PQ20Q240PQ200P@Q2U:CW=_Ng_N
LiaS65kg0VLi00Q[FVLiIcU_Ng>LIcUJeUJe15[F00ANmf<HIcUW>@9[FP07HaQJeUJeCW=:DTicF]H0
0f<H0ekg0U[F0Ukg0U[F0Ukg00E:DRe[:DY245kg009[FP05HaQW>FLiHaQJeP03CW<01EJeG_MJeU[F
HaP00Vmk00INmdicBU9>Le:DE[D2F]H01e:DCW=F]EkgE[E24248008<H`8Q2006?Nm:DSF]6<H8@PaS
0Q2410aS0Woo00<007ooOol02goo000<Ool00`00Ool0000D00000cW>=Jde[@0600002@@Q248Q248@
G_MS65[FE[E>L`02BU801DicDYABU4YB?Nl00cW>00=6<DYBAS400T8@00A:DTicDYA>L`96<@03?Nla
S2DY008U:@08=Je2448@>Li6<DYBAS524096<@E2400<<H`U:AS6;F]244icDYA>LdYBAS5>LdYB0Sg_
0SF]00/icSF]=JdicT8@DYA:DSW>:DXicSF]00@icP08=JdicT8@?Nle[@@Q24848@8HaP04;F/e[AS6
124200000`@Q000000030002Ool00`00Oomoo`0;Ool04`00OomoocF]48@icQBUF]HLi`Q2>LhYBRe[
5:D00124;F/LidYB008HaP0O=Je241cW8@P<H`Q236<U:@aS000Q21247>LaS2DY124000aSAS4<HaBU
7>L@Q0Q29BU6<B48;F/Lic6<12400SW>00@]J`Q27>L00088@P0I48@HaRe[48@Q20009BT48DHa48@8
@PaS<H`@Q2DY000<H`@Q;F/48A24:DX48A2400000RU:01H<H`008@P48Cg_9BT8@RU:48@001cW=Je>
LacW48@]JcW>48@DY@@Q2480008Q2007000DYA245:D002485:D00PQ200l48B487>LQ21S69BTHaQ24
7>L48B4836<Lia24:DX00goo00<007ooOol02goo00@007oo36<8@P<<H`88@P<<H`06248<Ha2448@<
H`Q20Q2400L8@P@Q7>M6<EJe@Q0Q2002248336<011248@Q6<F]J0Woo00=g_F]JJeX00f]J0fLi00IN
meJeDYAF]E[FG_L2F]H00ekgIcU[FP02JeX2IcT01U[FCW<mkcW>?Nm6<@9>L`04DYAJeUkgG_L2F]H2
HaP035kgF]IJeUJeAS4icSg_CW=Nmf]JKg][FP9S6004IcUS65JeE[D2BU802e:DE[EBU5JeHaQ[FUkg
CW=6<DYBDY@00UJe00YBU4icCW=F]EkgE[DmkacW248@Q08YBP924003;F/@Q0aS008@Q0@<H`04249o
ogoo000=Ool000aoo`03001oo`00018000848@03<H`YBSF]0088@P800007124000@Q;F]244YBE[D0
15[F0Tic00=:DTHa?Nl00cW>00HmkdHaBU9243g_AS44DY@01TYB@Q0mkcW>:DXU:@<Li`8U:@03;F/e
[DHa009240=6<@04@Q16<D8@=Jd2<H`00d8@AS56<@02DY@015Je?Nm6<Dic0dYB00@icRU:<H`icP<e
[@96<@07<H`e[Cg_>Lhe[CW>;F/00S6<00LicSg_=JdLi`@Q36<48@027>L00be[=Jd<H`0412450002
Ool00`00Oomoo`0;Ool01@00Oomoogoo00000QS600M>LbU:HaPQ23W>248000025:D00fLi9BUF]@02
248021245:DHaRU:5:EBU2DY<H`324802`aS124@Q0aS8@PHaR4848ANmbe[12400Q2400LaS2488@PL
iaBU248Q20025:D041S6000<Ha24124U:BU:24800124248DY@Q2;F/48@000QBU00dQ20@Q8@P]JcF]
36=F]@@Q248DYDYB36<@Q0026<H03bDY7>LaS1S69BTe[B48DY@aS1BU248aS0Q236<@Q00312401@Q2
0000000012400QcW00D@Q1S648@@Q0aS00<48@067>LaS0@Q124001240P0000@@Q00036<<H`8@Q005
F]IoogooOol0000=Ool00`00Ool<H`02248236<2248336<00`Q236<<H`0536<224801AS6>Li:DSg_
8@P00PaS00L@Q0aS36<Licg_G_M_N`02Li`2Nmh02W>LIcUW>F<HG_MJeTicAS5:DUJe15kg00=S66Li
JeX00W>L00IW>E[FDYA>LdHa>Lh3=Jd2>Lh014HaDYAS66<H15kg0U[F00YF]E:DCW=:DTicDYANmfmk
Mke_N`9Nm`06JeY_NekgG_M:DTHa0U:D00=>LdYBE[D00Ukg011F]E:DDYABU4icAS5243g_AS5>LeJe
BU8e[AS636<DY@8aS005AS5242DY36<8@P0248@01@aS248<H`aS24800Woo00<007ooOol02goo000<
Ool00`00Ool0000=00000`@Q0000000200001`@Q000DYC6<;F/HaP@Q00<000848@04DYA6<DYBBU83
DY@014Ha?Nlmkc6<13F]00DmkdYBAS5243g_00=>L`9F]@04DYA6<CF]:DX2;F/012U:8@PLiaBU0QS6
00DQ22DY@Q1243g_0096<@A24006?Nm>LcW><H`icTYB0UJe00E:DSg_BU9:DTHa008e[@07>Lhe[D8@
AS5243g_=Jd00THa0cg_00HicRU:<H`aS248:DX2=Jd00be[1248@P0212427>L00cF]<H`48@021247
0002Ool00`00Oomoo`0;Ool04`00Oomoogoo249:DP00<H`YBQBU36<8@Q24<H`icP@Q8@P002U:008H
aP0<E[E244ic;F/@Q0006<H48Be[48A:DP000QcW014001S69BT<HaS6248Q20Q25:D48ABU<H`000@Q
000Lia24008<H`07=Jd8@QBU24800124:DX00QcW00@48B489BT@Q0848@0?48@48B48000DYBe[:DX@
Q2486<H@Q36<5:E241cW00<8@P0?AS4Q2248000HaRe[124HaP0048@<H`Q27>Le[@@Q008Li`05:DX8
@Q2448@HaP0224828@P212400a2412448@0248@03aS68@PDY@006<H@Q1BU124DY@@Q48@]J`@Q6<H4
8@03Ool00`00Oomoo`0;Ool00`00Ool<H`0236<2248:36<2248236<00`Q248@YBP02@Q0012DY48@<
Ha240PQ200HQ24YBIcUS65kgJeX2Mkd00fLiE[EF]@02DY@014icBU9>LeJe0V<H00ENme[FHaQ[FW>L
009g_@04Kg]NmdYB?Nl2@Q000cW><H`]J`03;F/00cF]AS5F]@02HaP2G_L5F]H01E:DCW=:DU:DIcT0
0WNm00E[FUkgHaQ[FVLi009F]@04BU9BU5[FE[D2DY@2F]H3G_L00eJeBU96<@02AS42@Q02BU801Cg_
9BTDY@aS6<H00SF]00E:DT8@8@P<H`Q2008@Q00536<8@PaS36<8@P02Ool00`00Oomoo`0;Ool000ao
o`03001oo`0001@00005124icRDY9BT48@030002124013W>@Q16<DYB0Tic00A243F]<H`aS08e[@8m
k`0DAS5>LdHa@Q0icT8@CW=BU5[FG_MF]D8@;F/LibU:<H`]JbU:9BTLi`<HaP045:DLicF]=Jd2@Q00
14Ha@Q16<Cg_0SW>00DU:B489BTicTic009F]@05AS5:DTicCW<icP02;F/01CF]@Q1243g_CW<00THa
0dYB00m6<Cg_=JdYBSW>?Nm243g_7>LaS3F]000<H`Q236<00QcW00@icS6<124000848@0300048@@Q
00<0009oo`03001oogoo00]oo`0@001oogoo248003W>124]J`aSAS4HaRDYAS4YBT8@AS429BT030aS
=Jde[C6<?NlU:Be[36<@Q2U:@Q0icP8U:@0:48@Lia24000LiaBU7>L@Q1BU6<H2<H`021BU36<DYB48
;F/48@aS24828@P3124070Q2000<HdYB36<48BU:6<H000Q25:D@Q1BU7>L48AcW48@HaP00:DX@Q2U:
0016<Cg_249241S60RDY00H@Q2e[<H`Lidic2482000248@01@Q2=Jd002e[5:D00R4800T8@Q249BT0
01S6;F/000Q248@00QBU0PaS0cF]00l<H`00@Q0aS1BU248DY@Q25:D8@Q245:DLib486<H00goo00<0
07ooOol02goo00<007oo24800PaS0PQ20PaS0PQ20PaS00<8@PaS36<00PaS00<8@PaS36<00PQ200/L
id8@CW<e[ABU36<@Q0aS248Q24Ha009Nm`05F]IW>FmkHaQ:DP02AS401dYBCW=BU5[FIcU[FV<H009J
eP0@G_MS66mkNmioog>LF]I6<CW>?Nm244Ha>LhaS2U:9BT28@P01BDY<Ha245:DF]H015kg0U[F00QB
U4Ha>LhmkeJeKg]g_F]J0V<H00=[FVLiE[D00TYB00=>Le[FG_L00Ukg0V<H0ekg00aJeTicAS5>LeJe
F]IF]DicBU92436<8@P236<01QcW>LhicTYB>LhLi`88@P8@Q00536<8@PaS36<8@P02Ool00`00Oomo
o`0;Ool000aoo`03001oo`0001@00005124U:Cg_>LhDY@03000010@Q000Lic6<0SF]0TYB00]242DY
<H`aS3g_AS5:DU:DE[E:DT8@008icP9>L`07DYAJeU[FDY@]Ja246<H00RDY0RU:00<Q21cW8@P00QS6
00D@Q1S68@P]Jcg_00=2408icP0:=Jd]Jb487>LaS4icDYAJeTYB@Q03CW<01CW>=Jde[Cg_BU800SF]
0TYB00Y243g_>LhicSF];F/icSg_BU9>L`96<@07>LhQ2248124000@Q5:D00Re[00De[AcW124000@Q
00800003124000000080009oo`03001oogoo00]oo`0;001oogoo?NlLiaS6>Lh<Hb48:DX00002@Q02
9BT01248000e[@aS0R4800D002487>L<HacW0088@P065:DYBQBU36<001240P@Q00he[@@Q<H`8@PaS
6<H<HcF]DY@YBPQ29BTDYBDY0PaS0PQ200<YBQ247>L00P@Q00LmkaBU9BTicQBU6<HQ2002>Lh041S6
0008@P@Q6<H48AcW;F/HaR48248YBS6<00048A240`aS00@8@QS60008@P8HaP0936<U:AS6=JdDY@aS
48@8@PaS00800005<H`00000124YBP0236<00`@Q@Q048@0212404AS636<8@PQ2124<HacW:DX@Q0aS
<H`<Hcg_48@DY@aS8@P00PQ20goo00<007ooOol02goo00<007oo24800PaS0PQ20PaS0PQ20PaS0`Q2
0PaS0PQ200T@Q0aS124@Q3W>E[E:DRDY48@00PaS00H8@QS6=JeBU5[FG_L2IcT01E:D?Nm2448@DY@0
0Ukg00eW>FmkJeYF]DicE[EW>F]JKg]g_G_NJeY240029BT01cW>AS5243g_>LhaS2U:008Q200<7>LU
:Be[?Nm:DUJeG_MS65kgDYA6<CW>0S6<00A6<F<HMke_N`9Nm`04JeY_Nf<HCW<2BU801e:DF]IF]E[F
IcU[FV<H00=JeP05DYA:DTicF]IS6002IcT01EkgCW<mkbe[7>L00PaS00TU:DHaAS5:DS6<5:D8@PaS
48@01PaS0Woo00<007ooOol02goo000<Ool00`00Ool0000D00001P@Q36=24248=Jd8@P<48@09000U
:Cg_AS5>LeJeBU8e[Be[008icP96<@04>Lhe[E:DAS42>Lh02TYBCW=>Le:DE[EJeTYB:DX@Q1BU0QcW
0b480QcW0QS600HDYA245:DHaQBU8@P2AS402cg_:DX@Q1245:De[DHaDYAF]DHa@Q000dYB00Q6<CW>
<H`aS3W>AS4e[CW>0THa00<mkcW>>Lh00SF]00dmkdHaCW=6<D8@AS5243W>;F/DY@@Q24848@03:DX0
0cW>36<000090002Ool00`00Oomoo`0;Ool04`00OomoodYB=JdYBTic36<icP@Q36<DY@@Q5:DQ2124
6<H005Je0088@P0A=JdU:BDY000Libe[7>L<Hb481248@QBU48@<H`@Q7>L48@0336<02`00:DX<HaBU
8@PLi`00124Q212436<00`@Q00PLiaBU6<He[@@Q7>L]JaS60Q2400H000@Q48@@Q1S60002248032e[
2488@P005:DU:AcW36<@Q0aS248@Q08U:@09248Q22e[9BTicRU:000LiaBU008<H`03:DX8@Q240084
8@088@PLi`aS24800124:DXLi`800005<H`8@PaS124Li`0224801AS6000001S624800`aS00L48@00
000@Q0@Q6<H00003Ool00`00Oomoo`0;Ool00`00Ool8@P0236<2248236<2248236<3248248@22482
48@224804BU:CW=BU3W>7>L@Q0aS248DYC6<CW=JeV<HIcUS64icAS400U:D0V<H0U[F00mS65kgCW=:
DUkgKg]cW6mkLiakgVLi?NlLiaS6:DX00SF]0cW>00@aS2U::DXYBP8U:@0<;F/e[D8@CW=BU4ic>LhU
:B48;F]:DV<H0Vmk00=W>EkgHaP00V]J00AJeTicCW=>L`9F]@9>L`03F]INme[F009BU0=F]@04F]IN
me[FE[D2F]H01dic>LhU:AS636<HaS6<009:DP06AS4U:@aS248<Ha2410aS0PQ20Woo00<007ooOol0
2goo000<Ool00`00Ool0000700000`@Q0000000<00001BDYDY@YBQBU24800`0000HaS48@CW=>LdYB
@Q02=Jd2AS4025:D>Lh]JcW>@Q0mkcW>?Nl2CW<01e:DE[EF]E[FDY@e[AS600<DY@056<HLiacW7>LH
aP045:D00a2436<@Q0025:D02@aS5:DHaQS65:DaS4YBE[EBU002@Q001TYBCW=:DTHa?Nle[@8aS003
?Nm6<CF]008icP04?Nle[CF]>Lh2AS400e:D@Q0icP02:DX01Re[<H`U:AcW36<0008DY@057>M2448@
=Jd48@0:0002Ool00`00Oomoo`0;Ool04P00Oomoo`00124<H`Q28@PU:@@Q<H`DYE[F1256<A24248i
cP<0000;36<Q21cW7>L@Q0aS8@Pe[ABUBU88@P0236<021S636<YBQcW124Lib4800036<H01bU:1240
01BU6<H@Q1BU008U:@09AS4]JaS6000e[Be[:DXQ21S60088@P0>6<HQ21S6248]J`@Q24848AcW48@H
aQBU36<aS08HaP04248Q20Q29BT236<020Q248@8@QBU8@PU:@@Q9BT27>L03CW>000LiacW@Q0Q21S6
5:DYBP@Q6<H<Ha240080008Q2004248@Q248;F/27>L03`@Q7>L48@Q200048AS6124HaP007>LDYB48
:DX<H`03Ool00`00Oomoo`0;Ool00`00Ool8@P0236<2248236<2248236<324806@aS48@8@P@Q48@D
Y@Q2124HaSg_DYA:DRe[5:D48@Q27>LmkeJeHaQ_Nf]JG_M>Le:D009S6004IcUJeTYBCW<2F]H00eJe
F]IW>@03Kg/01WNmNmi_Ne:D=JdU:@8Li`039BTYBRe[00D]J`06:DXQ22488@PU:BU:0Re[00TYBR48
:DY6<FLiLia[FV<HG_L00fLi00=S65JeCW<00Tic0U[F01MBU4YBBU9>LdYBAS5:DUJeG_MW>F<HE[E6
<D8@AS5:DSg_:DXHaQ245:DU:D8@009>L`04?NlLi`Q2248636<22482Ool00`00Oomoo`0;Ool000ao
o`03001oo`0001<000<48@0436<icRU:=Jd21240100036=244Ha0TYB0Tic01T]JcW>E[EF]DHa<H`e
[Cg_@Q0icT8@CW=:DU:DCW=BU5JeDYAJeUJeAS4aS1BU48@DY@046<H35:D648@02QBU6<HHaRDY>Li6
<EJeBU8icSg_0Tic00E:DTHa@Q0e[Be[008aS004?Nm:DSW><H`3:DX01bDY=JdmkdHaDYA:DSF]008a
S0037>LQ21S600848@040008@Re[8@P2<H`00bDY12448@05000010@Q000000000Woo00<007ooOol0
2goo01<007ooOomNm`Q2G_M241BU9BTaS1cW000]JbU:000Q20Q248@00002>Lh07c6<36<HaPaS7>LY
BQcW36<48@005:D<Hb489BTDY@Q2;F/YBSF]48@e[B48?Nl48@00248LiaBU48@8@PaS0092400;6<H@
Q1BU5:DHaR48;F]6<AcW;F/<H`0212404QBU0000036<48@000Q2>Lh<H`@Q248e[AS65:D<HbU:48@4
8@8DY@0J9BT000Q2BU8<H`@Q248<HaS6:DX@Q0@Q7>LDY@Q2000<H`@Q000Q20@Q248YBQBU124<H`8L
i`038@P8@P0000848@038@P@Q1cW0088@P0:000Li`00124DYAcW24848@00G_L3Ool00`00Oomoo`0;
Ool00`00Ool8@P0236<2248236<2248236<3248236<224805@aS48@8@P@Q48@YBTHaCW<mkaS60008
@RU:CW=S67>LMke_Ne[FCW=JeP02IcT015kgBU9245:D0Ukg00iS66]JKg][FVLiJeYcW7NmLia_Nekg
BU8e[BDY224800<LiaS65:D00aBU00/HaRDY<H`mkdicHaQ_Nf]JG_MJeV<H009[FP03HaQNme:D00=6
<@04E[ES65kgCW<4AS4034YBE[ENmfLiHaQF]DYB@Q0mkcW>:DXHaP8@Q0036<HaS4YB009>L`03=JdD
Y@Q200<<H`03248<H`aS0088@P0436=oogoo000=Ool000aoo`03001oo`0001H0000:124aS4ic5:D8
@P001248@T8@AS42E[D015:DCW<e[D8@0U:D00PmkaS6=Je244Ha@Q1>Le:D0dic00Y:DU:DDYABU5Je
F]IF]DHa=JdHaP8@Q0045:D@Q1BU5:D548@02aBU6<HDYBDY>Li6<DicDYA:DSg_BU8014ic0TYB00Xm
kcW><H`aS3W>CW=:DT8@>LhaS08e[@05<H`]JcF]?Nm:DP02AS402T8@>LhU:AS600048@0036<LidYB
0Sg_00<48@0000002@000Woo00<007ooOol02goo00L007ooOolQ24YB5:E[FP0248@01PaS248DY@00
36<DY@8Q200SCW<icPQ2248DY@Q2=Jd48C6<8@P@Q000@Q0003W>:DX8@RDY36<Li`aS124002DY248a
S0@Q36<8@QS6000@Q1cW48@48@025:D2248031245:D8@PQ2124DY@aS5:D<HbDY8@PYBP88@P0?1240
00@Q6<H48BU:00048@aS24848@Q2<H`48D8@00800006124000@Q6<H<H`Q20PaS00D48C6<124<Ha24
008DY@0@000YBPaS124<HbDY36<aS124124]J`@Q5:DYBP0024827>L01@@Q000@Q0Q26<H00P0000DL
i`0048@8@Sg_008<H`059BUoogooOol0000=Ool00`00Ool8@P0236<2248236<00`Q236<<H`0236<2
248336<05PQ236<<H`aS248<HacW>LiBU4YB9BT48@Q2<HaF]F]JKg]cW6]JF]IF]Ekg0V<H00EBU48@
AS5JeV<H009Nm`05IcU_Nf]JIcU[FP02Kg/02g>LMkeg_FmkG_M:DSg_<H`YBRDY8@P01QS600LLib48
:DXaS3g_CW=Nm`02JeX016LiG_MJeV<H0V]J00EW>F<HG_MBU4Ha00924006DYAS66LiF]I>LdHa0TYB
00A>Le:DE[EJeP9Nm`0;F]IBU4YB=JdQ212436<@Q248>LiBU002BU800bU:36<8@P0248@2248248@2
248010aSOomoo`003Goo000<Ool00`00Ool0000F00003`@Q2496<C6<>Lh8@P00249F]DYB?Nm244ic
DYA24003BU801CF]7>LicTHa?Nl00SW>00=244icDY@00dic00ABU5JeDYABU09JeP06E[E>LdYB<H`U
:AS60Q2400<<Ha2448@00QBU00<U:C6<@Q000dic00=:DTHa@Q000dic00A:DTHaAS56<@8mk`05=JdY
BRU:>Lhe[@02CW<043g_>LhicSW>?Nm243g_<H`mkd8@AS4mkcF]:DX8@P000P@Q00<]JaBU=Jd00SF]
00<48@0000002@000Woo00<007ooOol02goo01<007ooOomg_@aS=JdaS124000@Q1BU36<Q20aS48@8
@QBU8@PU:@048@P020@QAS4DYBe[248e[BDY@Q0200001`aS48@8@PaS9BT8@PaS00@YBP085:DaS124
48@<H`0036<HaP<48@0:=Jd<H`aS7>LHaP@Q7>L48A246<H27>L02aBU6<He[@aS124000@Q6<H<HaS6
12400QcW00DU:A249BTQ2124008000045:DYBS6<<H`26<H224801SF]<H`LicF]000Li`8]J`030004
8DYB008<H`05000LiaBU124<H`02248212400`Q212448@0312402PQ2;F/@Q1BU48@8@P@Q36<8@Q24
0PaS0goo00<007ooOol02goo00<007oo36<01`aS00@8@PaS36<<H`88@P@<H`0>248<H`aS36<8@Q24
:DY:DU:D=Jd@Q0aS:DY>L`9Nm`03F]IS66Li009[FP9Nm`0<BU8mkd8@E[EJeU:DCW=JeV]JLia_Nf]J
0Vmk0V]J00UcW7NmMke[FV<HE[E>LdHa?Nl00S6<0Re[018aS3F]>Li244icF]IS66LiJeYW>F<HG_MS
66LiKg][FVLiHaP2G_L01UJeCW=6<DHaBU9F]@9S6003F]IBU4ic00=>L`0?DYAF]E[FF]INme[FCW<e
[AcW36<8@Q24:DY6<E:D009240037>L48@Q2008@Q088@P8@Q088@P0436=oogoo000=Ool000aoo`03
001oo`@Q01P00003@Q0aS2DY0088@P09124HaSW>>LhU:DHaF]IF]E:D009>L`03?NlDYBe[008aS08e
[@09>Li>Le:DDYA>LeJeCW=:DTHa009>L`03DYAF]EJe009Nm`04F]IBU4icCW<3@Q02AS4014icDYAB
U4ic0THa00=244HaCW<00Tic00E:DTicAS5:DSg_00<e[@8icP03;F/aS48@00=6<@<]J`03>Li:DT8@
008icP04?Nl]Jb48;F/2000212400acWAS5240025:D00`@Q0000000200000`@Q000000040002Ool0
0`00Oomoo`0;Ool04`00OomoobU:48@DYBe[:DXHaVLi8@Q2436<36<Li`Q20012412400<0000<36<4
8A24248@Q0006<H<Hcg_:DY241cW0`aS00l002481248@P@Q36<DYC6<6<H000Q20008@PaS:DX00P@Q
0`0001@DY@006<HQ20Q2124<Hb489BT001BU124Licg_<H`LiaS68@PaS1BU0QS600H48A245:D@Q0aS
9BT236<03BDY000<Hc6<7>M6<BU:000HaQ24124]JacW00848@0@:DX48@aS248Lia246<H000@Q000<
H`Q236<8@P@Q00026<H03a24248U:A24;F/HaR4836<8@P0036<Q20008@P]J`03Ool00`00Oomoo`0;
Ool00`00Ool<H`0236<2248436<3248636<03PQ236<<H`aS24848AcW@Q1JeTHa7>L<HacW>Lh2AS40
0dicHaQcW002Mkd2IcT01Dic?NlmkdicDY@00TYB00=JeV]JKg/00V]J0W>L00A[FV<HJeY_N`AcW003
Kg]W>F<H009JeP0;E[EBU5JeE[EJeUkgIcU_Nf]JIcUS6002G_L016LiKg]_Nf]J0VLi00=S65[FE[D0
0UJe0Tic0THa00EF]F<HHaQJeTic0096<@04CW=F]E[FDY@2CW<025:DAS4aS1cW36<8@QBU=Jd2CW<2
;F/00a241248@P0636<00`Q236<<H`02Ool00`00Oomoo`0;Ool000aoo`03001oo`0001L0000>124L
id8@>LhHaPaS5:D48AcW;F]244HaE[EJeP=BU005?NlaS3W>>Li24002=Jd01Sg_BU8mkcg_BU9BU09>
L`9:DP04DYA6<DYBBU82CW<00e:DF]IF]@06E[D01E:DCW=:DSg_@Q000TYB0dic00A:DT8@@Q1:DP96
<@03?Nm:DSg_00924003=JdU:C6<00=6<@09@Q0e[AcW;F/e[DHa>Lh]JbU:008e[@0848@48@00000<
HacW=Jd]J`848@`0009oo`03001oogoo00]oo`0>001oogoo248@Q0@Q9BT8@Tic1248@RDY124@Q08H
aP0336<8@QcW008DY@0=<H`<HaBU000YBQ24AS48@QS6000Q22DY48@00P@Q0100036<7>LLiaBU124@
Q3F]124Q20aS248@Q0Q2000U:@8aS00536<Li`0048@DY@0200005A2436<48@aS6<H@Q0aS:DX48@00
48@8@QS67>LHaQ246<H8@PaS;F/aS00200004aBU:DXYBPaS<H`48A24000DYA245:DLibe[1248@RDY
124<HbDY008DY@05=Jd8@P@Q9BTHaP0212401RDY5:DQ20Q248@]J`8<H`055:D@Q12436<Li`021240
0a248@PQ200236<00`00248HaP03Ool00`00Oomoo`0;Ool01@00Ool<H`aS24800PaS0PQ20PaS0PQ2
10aS00h8@PaS36<<H`Q236<@Q0aS124@Q3F]E[E>Lbe[0Q2400DQ23F]AS5JeV]J009cW00?Mke[FV]J
DYA244HaDYAF]DYBCW=JeV<HG_MF]F<H009_N`9W>@9[FP04IcU[FW>LMkd5Li`3Kg/4JeX00fLiG_MN
m`02HaP016LiJeY_NfLi0U[F00IS66LiF]IBU5JeG_L2E[D014Ha?Nm:DU[F0V<H00MJeTYB?Nm6<EJe
F]IBU002BU8014Ha>LhU:ABU0PaS00@Q248@DY@mk`8Li`88@P8<H`05248<H`aS36<8@P0336<2Ool0
0`00Oomoo`0;Ool000aoo`03001oo`0001P0000=125:DSg_8@P48@aS248HaTHaCW=JeTicBU800dic
00de[CW>AS5>Ld8@<H`e[DHa>LhaS3F]>Li24002BU8014icDYABU4YB14ic1DYB00=>LdYBBU800dHa
0dYB00=>LdYBBU800THa00<icS6<>Lh00T8@00A:DT8@@Q16<@9BU005?Nl]Jc6<>Li24002CW<0148@
?NlU:BU:0cg_00]243g_7>L48@001248@R48AS4aS1S600h0009oo`03001oogoo00]oo`05001oogoo
48@000026<H02@Q248@001245:DHaRU:7>LHaP02000021cW2488@R486<HaS0@Q48@236<061BU36<8
@QBU248Lia2436<002e[124YBPQ2:DXDYA249BT@Q248248<H`@Q48@48@800003124LiaBU00848@0>
7>L48BDY6<H<Ha2436<DYA249BT00248;F/U:@88@P0:36<48@aS36<8@P@Q5:D48BU:5:D36<H01S6<
248aS12436<U:@88@P0D48@YBQ241248@R485:DHaQBU36<aS000;F/<Ha2436<YBP@Q000<H`80008@
Q00?00048@Q27>LYBP00?Nl8@Q24248HaPQ26<H@Q1BU00=oo`03001oogoo00]oo`05001oo`aS36<8
@P0336<01@Q236<<H`aS248010aS00@8@PaS36<<H`88@P0B48@<H`@Q36<YBTYBDY@icQS636<DYC6<
DYA[FVmkJeYW>F]J0VLi00EF]E:DF]IS65Je009:DP9F]@9:DP05E[ES66<HG_MW>@02Kg/00fLiHaQ[
FP02JeX00fmkLia_N`03Kg/00g>LKg][FP02IcT02F<HG_MNmf]JKg]W>F<HF]IBU002BU801U[FHaQN
meJeF]IS609Nm`05DYA6<DHaDYANm`02JeX015Je@Q0mkdYB0eJe00ABU4YB<H`HaP8<H`056<He[DYB
BU8]J`0248@01@@Q36<<H`aS24800PaS0PQ20`aS0Woo00<007ooOol02goo000<Ool00`00Ool0000H
00001@@Q:DXmkbe[36<00P@Q00LDYCg_AS5:DSg_CW=BU002CW<02D8@?Nm:DTic?NlU:C6<>Lh]J`03
=Jd013W>=JdmkdHa0U:D00=>LdYBCW<00U:D1dic0dYB1Dic0TYB0cW>0Re[00HaS3W>?Nm:DT8@?Nl2
BU804T8@>LhmkcW>AS5F]DicAS4icS6<:DXicTHa@Q0mkcW>5:D48@88@P0536<U:CW>=Jd8@P0>0002
Ool00`00Oomoo`0;Ool04`00OomoobU:9BT8@RU:7>L@Q3W>6<I6<AcW9BT<Hbe[24848AS6008<H`0E
9BTQ20aS48@8@Q24000U:@aS5:D0048@5:DYBP00248YBQcW6<H<H`0000848@088@PU:Be[5:D000@Q
8@PDY@88@P0:48@HaQcW1248@PaS8@P@Q0@Q248248@224802QBU6<H<HaS6124Q22e[124Q21BU0P00
00DQ20aS8@PQ20Q200848@058@PDY@00124HaP025:D052486<H8@R485:D48ABU7>L48@aS@Q0YBQS6
248001cW48@48ABU7>L248@01AS6000YBRU:5:D00P@Q00<002DY7>L00PaS00L001S648@48@aS:DX@
Q003Ool00`00Oomoo`0;Ool00`00Ool<H`02248736<00`Q236<<H`0236<010Q236<<H`aS0PQ200T<
Ha242488@QcW?NmBU4Ha:DX00Q2400L]Je:DIcUW>EkgHaQ[FP02IcT2G_L01fLiJeYJeTHa@Q1:DTic
009:DP=>L`05DYAS66mkKg]S6002G_L2HaP00fLiJeYW>@02IcT00f]JKg][FP02IcT6JeX015kgDYA:
DTYB0THa00=:DU:DF]H01V<H00QJeU:DDYANmf]JKg]W>E:D0T8@00i:DU[FHaQNmdHa:DXDY@Q248@U
:DHaCW<mkb480`Q21PaS0PQ20`aS0Woo00<007ooOol02goo000<Ool00`00Ool0000H00002P@Q36=:
DSF]6<HQ2124124YBSg_0SF]00I:DUJeE[EF]DicAS42BU803d8@?NlYBRU:=JdmkcW>;F/aS2e[<H`i
cTicBU8mk`02=Jd00cW>?Nm:DP04CW<00dYBDYA>L`03CW<03dYBCW=>LdHa@Q0mkcF]9BTaS3F]>Lhe
[AcW=Je24002?Nl2AS42@Q000dHa@Q0e[@02@Q000dHa?Nle[@02=Jd014Ha@Q0mkbDY0P@Q00H000@Q
9BTicS6<9BT600000`@Q000000060002Ool00`00Oomoo`0;Ool04P00Oomoof]J6<HicPaS;F/Li`Q2
7>LU:Cg_5:D@Q36<48@48@<@Q08Li`0MCW<000Q28@PU:@0012400248124Li`aS8@PHaS6<48@8@PaS
48@DYBDY248HaRU:1252436<000aS00248@030Q2000@Q0008@P48@00BU8<HaBU9BT<H`848@0A000D
Y@005:D48CW>36<48@aS248Q2124124Lia24124000028@P00acW1248@P025:D02`aS124LiaS6248D
Y@aS000e[@00<H`00P@Q00Pe[ABU36<DYCF]6<HQ20aS0PQ200<@Q1cW;F/00a2400L48@aS000@Q1BU
0008@P026<H01B481248@RU:00000goo00<007ooOol02goo00<007oo24800PaS0PQ21PaS0`Q20PaS
01<8@PaS36<<H`Q236<@Q0aS124@Q36<CW=BU3W>7>LDYBU:?Nm>L`02DY@046<HLiag_GNmJeYNmfLi
JeYS64YB@Q16<DicDYA>LdYB0THa00E:DUJeHaQS65[F00=F]@03F]INmf<H00=W>@9[FPAW>@09JeY_
Nf]JHaQJeU:DBU96<DYB009BU005AS5244YBF]IS6003F]H00f<HIcUNm`02E[D055kgHaQS65[FCW=6
<DYBG_MW>E:D=JdLia2436<DYBe[CW=BU3F]5:D3248636<2248336<2Ool00`00Oomoo`0;Ool000ao
o`03001oo`0001P000848@06?Nm:DS6<7>LQ20@Q0RDY00@]JbU:BU9>L`9F]@0@DYA>LdicCW=BU4Ha
>Lhe[D8@AS4icS6<=JdaS3F]>Lh2?Nl01CF]<H`e[CF];F/00SF]0THa0TYB00U>LdYBBU96<D8@?Nm2
44YB?Nl00SF]00<YBSg_?Nl00d8@00DicS6<=Jde[CW>008aS00@>Li244YB=Jd]JcW>?Nm243F]<H`e
[C6<@Q0mkbe[248212400`0036<HaP02@Q000aBU0000000=0002Ool00`00Oomoo`0;Ool01000Oomo
ogoo0RDY00P]J`Q248@DYB48124@Q1BU0PaS00<Q2000;F/00P0000P<HaBU48@YBP005:D<Ha240R48
00P<H`@Q>LhU:@@Q<H`U:C6<0a240QS600P48B4836<LiaBU8@PHaPaS0P0001lLi`Q2000<HaS636<L
i`Q2>LhHaQBU<H`Q20aS248aS248000U:Be[6<H48ABU=Jd@Q0Q28@P00124124<H`02:DX01PaS48@L
i`0024848@8DY@0=9BTDYBDY<H`LiaBU=Jd001cW36<DY@aS24800P@Q00<HaP@Q36<00PQ200<DY@00
00000P0000H48ABU000@Q0@Q7>L212401`008@P000aS124@Q1S600=oo`03001oogoo00]oo`03001o
o`Q2008<H`88@P8<H`88@P8<H`<8@P8<H`88@P8<H`88@P8@Q088@P058@Q6<EJeBU8]J`027>L01RU:
=JdmkdHaF]IcW09oo`03LiaS66<H009[FP03G_MBU5Je009JeP03E[EBU4YB0096<@05CW=F]E:DCW=:
DP04CW<00eJeG_MNm`04HaP02FLiHaQJeUJeG_MS65[FCW=6<@02BU8025:DF]INmeJeAS5244YBDY@3
BU8015:DF]IJeTic0TYB00YBU5JeE[E>LdYBDYANme[F?NlLi`8@Q0035:DLicF]009BU008;F/<H`@Q
124<Ha2436<8@P8<H`88@P<<H`04249oogoo000=Ool000aoo`03001oo`0001T0000<124<HdYB:DXH
aQ242480036<8@PHaT8@0dYB011BU4YBDYABU4icBU9BU4icBU96<Cg_@Q0mkc6<:DXaS08e[@07:DXe
[Cg_>Lhe[C6<;F/01CF]00I244Ha=JdaS3F]<H`2@Q001CF]<H`aS3F]AS400T8@00A:DSW>;F/]J`@a
S003:DXe[CF]008U:@<icP@e[@03@Q0mkbDY00848@0736<8@Re[6<HicSg_24803`000Woo00<007oo
Ool02goo00d007ooOomoo`aS<H`002DY124aS0aS:DX00002;F/3:DX050@Q2488@PaS248YBP@Q9BTH
aQcW?Nle[BDY000<H`006<I240@Q6<H2;F/030@Q36<DYA24000DYB4848A:DU:D8@P@Q0<48@030004
8@Q2008Li`041248@R489BT2248010aS7>L8@P000P@Q00/001S68@PLi`Q26<I240Q2:DXDY@@Q0088
@P8DY@0O36<000006<H8@Q247>L8@R4836<@Q0aS8@PLia245:D48@Q2<H`48A246<HDYA24124DYB48
124@Q0@Q00000PaS00l8@QBU36<48@aS5:D<HaBU000DYA2436<003W>00000goo00<007ooOol02goo
00<007oo24800PaS0PQ20PaS0PQ20PaS0`Q20PaS0PQ20PaS0PQ2014<Ha2436<48A24<HaBU5Je?NlL
iaBU8@P]Jc6<>Li>LfLi009_N`03JeYW>F]J009_N`9[FP08IcUS65kgG_MJeU:DBU96<@9>L`03BU96
<DYB009>L`03BU96<DHa009:DP09CW=BU5JeF]INme[FBU9244ic009JeP06BU9244YBDYAF]E[F0V<H
00=F]DYB@Q0013g_00U244HaAS4mkd8@AS5BU5JeDY@00TYB00EBU5JeBU8]JaS6008@Q0066<HYBTHa
E[E6<B480`Q200<<Ha2436<00`aS0PQ210aS0Woo00<007ooOol02goo000<Ool00`00Ool000030000
0`@Q0000000B00001P@Q00048CW>BU8aS08@Q006000HaR487>LicTHa0Sg_00I244YBAS5:DU:DCW<3
BU802dicBU9:DT8@<H`e[Cg_>LhaS3F]@Q000THa00=243W>;F/00RU:01P]JbU::DXe[Cg_<H`e[Cg_
;F/icTHa=JdLicW>BU9243W>?Nm6<DYB>LhaS1S67>L28@P022U:7>LHaQcW<Ha244Ha?Nl2>Lh01cF]
;F/aS2485:D48@aS0088@P056<I>LcF]8@P48@0?0002Ool00`00Oomoo`0;Ool03P00OomooacW000L
i`0048@DYBU:5:E:DRe[24826<H00`@Q48@8@P025:D040Q27>L<H`Q2124@Q1BU7>LQ22e[000<HaBU
48@HaP000PQ200@48AS6124Li`88@P04000Q21BU6<H2000011BU7>LLiaBU0PQ200<<HacW24800PaS
00l001S6124000Q2000<Ha2436<8@Q249BT001cW00000QBU00D8@PaS000aS24800<8@P8]J`071248
@PQ26<H@Q0@Q@Q000QcW00l001S69BT@Q0008@PYBPQ25:D001cW=JdU:AS67>L00P0000<HaRDY2480
0QS600l@Q0Q2124DYA24124HaQ24000<HaBU124DYBU:24800goo00<007ooOol02goo00<007oo36<0
1PaS0PQ21@aS00D8@PaS36<<H`Q2008<H`88@P0@36<@Q0Q2248Lid8@F]I:DRDY5:DLibU:;F/e[DHa
E[D2F]H025kgIcUcW6mkIcU[FVmkJeX2HaP01F]JIcUF]DHaBU800U:D0TYB00IF]EkgG_MF]Dic@Q03
?Nl00d8@AS5:DP02DY@024YBAS5>LeJeDYA6<D8@CW<2F]H2E[D015kgHaQJeTYB0SW>0d8@00DicRe[
<Ha6<EJe009Nm`03E[E>LdHa009:DP03?NlYBQS6008@Q0077>Le[E:DDY@e[ABU24800`aS0PQ20PaS
0PQ20PaS0PQ200@<HgooOol000eoo`0037oo00<007oo12406`0000/8@Tic<H`e[A24124<HbDY6<HY
BRe[008e[@03@Q1BU4YB009:DP0:CW=:DTHaAS5>Le:DCW<mkc6<?Nl2AS42?Nl01TYBCW=:DTYB?Nle
[@8aS00C=JdU:BU:<H`icS6<>Li6<CW>;F/e[Be[<H`mkdHa@Q0mkc6<>Lh00THa00<mkcW>=Jd00SF]
0SW>00<HaRDY>Lh00THa011:DTHaAS4e[BU:8@Pe[@aS1248@P@Q5:DQ248@=Jd8@Q00009oo`03001o
ogoo00]oo`08001oogoo8@P8@Q248@P0008<H`09?NlaS4Ha;F/YBPQ29BT8@THa008DY@0=<H`48B48
48@YBP@Q36<8@QS67>L8@RU:@Q000PaS00@Lia2412448@8000<<H`079BT]J`@Q:DY:DPaS9BT00UJe
00`<HbDY00048@00248<HaBU<H`U:CF]<H`236<02RDY@Q048@005:DLi`@Q:DX48BDY0`Q200@003W>
5:D<H`848@067>L8@R4836<Q23g_0Q2400@<HaS6000DY@8<H`05248001245:DHaP0212402PQ25:DU
:@aS000Q22e[124Li`aS0aBU00<8@P@Q5:D00P@Q00@Li`Q2248icP80000336<48@Q200=oo`03001o
ogoo00]oo`05001oo`aS36<8@P0236<2248236<2248336<2248236<010Q236<@Q0aS0PQ20PaS00d4
8@aS:DY>LeJe>LhHaQBU8@P]JcF]@Q1:DP02DY@015[FHaQW>FLi16<H00MNmf]JLia[FUJeBU9BU002
G_L2F]H01VLiJeY[FVLiF]IBU096<@03@Q0mkcg_00924009BU9BU5JeE[E>LdHa@Q1:DUJe009Nm`06
E[E>Le:DG_MS65Je0THa0dic01PmkbU:=Je>Lf<HIcUS65kgE[E:DT8@>LhaS2DY6<H@Q1BU9BU245:D
BU8U:@Q2124248@00`aS2488@P0236<2248236<2248010aSOomoo`003Goo000<Ool00`00Ool0000L
00001aS6E[DDYB4836<000aS008U:@05:DXicSW>DYA6<@02BU800dHa@Q16<@02AS401E:DCW=6<DHa
>Lh00THa24ic00=243g_?Nl00SW>00`aS2DY9BT]JcW>AS5243W>5:De[Cg_BU82AS400d8@=Jde[@03
@Q02AS43@Q005CF]6<H]JcW>BU96<D8@?NlicSF]6<HYBR480008@P@Q248Libe[<H`Q200600000`@Q
000000080002Ool00`00Oomoo`0;Ool01`00OomoocF]5:DHaRDY008HaP0:5:D<Hbe[7>MJeS6<48AS
61cWJeX236<00acW124HaP0212403000@Q0DYB48;F/001cW124001cW124Q2088@P0<36<DYEJe248U
:B487>L<H`@Q6<H8@QBU0PaS00P8@PaS36<HaPaS6<H48Be[0Q2400PU:@Q25:DicQcW6<H<Ha240PQ2
00TLi`aS6<HDYB485:D8@Sg_12400PQ20SW>00P@Q1cW36<8@P@Q000@Q0Q20QBU01D8@Sg_124DYB48
36<YBPaS248@Q0007>LU:@aS000@Q1BU124@Q2DY00000Q2400P000aS7>LDY@00248<HaBU0QcW00D8
@P@Q124Q21BU00=oo`03001oogoo00]oo`05001oo`aS36<8@P0236<2248236<2248336<2248336<0
10Q236<@Q0aS0PQ200h@Q0aS124@Q3W>E[E>LbU:36<@Q2DY<H`icTHa0U[F00AS65kgG_MNm`9S609N
m`08IcU_NfmkIcUJeUJeG_MW>@9[FP9W>@9[FP03IcUS66<H009JeP0=DYA>LdYB@Q0mkdHaE[ES65[F
AS4icT8@E[D00V<H00ENmeJeCW=>LeJe009S600:F]IF]EkgG_MF]DHa=Je245JeHaP3G_L01UJeBU8m
kcF]:DXLi`8@Q0087>LaS4HaBU8e[ABU1248@P<@Q088@P0448@<H`Q2248236<2248010aSOomoo`00
3Goo000<Ool00`00Ool0000500000`@Q0000000D00002P@Q:DYJePQ248@8@P@Q000icRe[0SW>00Xm
kd8@AS5:DSg_@Q16<DicDYA>L`=:DP04AS5>LdicCW<4BU800dicAS5:DP04BU82?Nl02CF]7>LicT8@
BU9243W>;F/icP02AS400d8@AS56<@02>Lh2@Q000dHaBU96<@02@Q0013g_;F/Q22U:0d8@00I6<Cg_
<H`U:BU:;F/236<01`Q236<U:ABU?NlicPQ20140009oo`03001oogoo00]oo`0B001oogooE[D@Q2DY
48@000aS8@Q6<ABU:DX<H`@QAS4002U:0`Q20RU:00l<H`@Q000001247>L48AcW9BT@Q3g_7>LU:A24
=Jd00P0000PHaRU:36<@Q1cW000U:@000QBU01H000@Q000002DY124e[@00124003W>48@HaP@Q0008
@Q246<He[@008@P]J`8@Q00;7>LHaP00:DXLiaS648@Q2000124<H`0212402@Q27>LHaR48124U:ABU
48@U:@0248@052485:DDYC6<48@00124?NlDYA248@PDY@aS48@mk`@Q36<48@009BT224801`aS248U
:A24;F/@Q0aS008HaP06000@Q1246<He[ABU0goo00<007ooOol02goo00<007oo36<02@aS0PQ20`aS
0PQ20PaS0PQ20PaS0PQ200h<Ha2424848AcWAS5JeTHa7>L8@Q249BTaS48@0UJe00=S66LiG_L00ekg
00ES66]JKg][FVLi00AS6003JeY_Nfmk00AW>@IS600@G_MF]DYB?Nm6<E[FIcUJeTHa@Q1BU5kgHaQN
me[FE[D2DY@01EJeG_MNmf<HIcT00V<H01UF]D8@?Nm6<E:DF]INme[FDYA:DT8@?NlaS2DY5:D<HaBU
9BTmkdYB?NlQ20aS124<H`0248@536<2248536<2Ool00`00Oomoo`0;Ool000aoo`03001oo`0001T0
00848@8000052496<E[F36<@Q002124010Q27>M6<DHa0Sg_00M:DTHa>Li244YBE[E>L`05BU802Tic
DYA>LdYBCW=:DTHaBU96<D8@0cg_00M:DTHaAS4mkbe[>Li24002BU800d8@>Lhmk`02AS401D8@>Lhe
[BU:?Nl00T8@00=6<DYBBU800THa00@mkbe[8@PYBP9240<icP04:DXQ23F]36<212401P0036<HaSg_
;F/Li`P000031240000000L0009oo`03001oogoo00]oo`0:001oogooF]H48BDY48@]J`Q27>L336<0
1P@Q8@P]J`@Q248@Q09:DP08124U:CW>8@P0048@6<H<H`<0000A48@8@QS6<H`48C6<6<H48BDY6<HL
iaBU48@icQS6248DY@027>L031BU7>LLia248@PLiaBU48@48ABU248<H`8@Q080000;24848Be[000L
i`Q28@PU:@00?Nl8@P0248@01CF]<H`Lia2400000PaS00<U:@aS36<00P@Q00<aS2DY?Nl00QBU00hH
aP007>L001BU6<H48@00?NlHaQ247>LQ20@Q0P0000D8@P@Q7>L]JacW0080000536<HaP@Q7>LQ2002
124236<01P@Q7>L48D8@124000=oo`03001oogoo00]oo`03001oo`aS00/<H`@8@P@<H`88@P8<H`04
248<Ha2448@224802B48BU9NmdHa6<H48A24:DXe[@02?Nl01e:DHaQW>EkgE[EJeVLi009[FP05IcUS
66<HHaQW>@02JeX2IcT01F<HIcUW>FLiHaP015kg00US66LiHaQBU4HaBU9JeVLiHaP00UJe00YJeV<H
G_MJeUJeDYA>Le:DG_MS609Nm`=W>@09E[E243W>@Q1>LekgHaQF]DYB008mk`03>Lh]JacW008@Q007
7>Le[DYBBU8aS124124010aS00D8@PaS48@<H`Q200H<H`04249oogoo000=Ool000aoo`03001oo`00
01h0000836<icV]J48@<H`Q236<48@8<H`0;9BU243g_@Q0icTYBDYA244HaBU96<@02@Q001E:DBU9B
U4icBU800dic00ABU48@@Q12408e[@07?Nm6<DHa?NlaS3W>@Q000TYB1DHa00DmkcW>?NlaS3W>00=2
4003=Jdmkd8@00924006>LhLibDY?Nm6<C6<0SW>00TU:Be[7>L8@Q2436<002e[8@P00SW>00<48@00
000040000Woo00<007ooOol02goo00d007ooOom>LdYB<H`DY@@Q8@P000Q236<Li`029BT011BU9BT4
8Be[0`aS00/002486<H48Be[8@P8@QBU36<LibDY00848@0A36<LicW>248<HaS65:D@Q1S6@Q0HaR48
5:D@Q0aS000YBP0248@02`@Q5:DHaPaS248001BU24848@006<H00PaS00L]J`@Q2488@PaS48@DY@02
248020@Q0008@QcW6<H<Ha24:DX348@01ABU48@<H`@Q:DX00PQ201PHaP@Q36<000aS5:D8@S6<36<L
ia247>L001S6248icQS6124<H`0048@48B4848@200000be[9BTYBP0224802QcW000Q200024848AcW
248DYAcW0goo00<007ooOol02goo00D007oo36<<H`Q200H<H`03248<H`aS008<H`88@PH<H`03248<
H`aS008<H`0<48@<H`@Q248YBUJeHaQ241BU248DYB480RU:00He[DicF]IF]E:DF]H2IcT00f<HG_MS
6002G_L01fLiKg]_NfLiHaQW>F]J009W>@03HaQNmeJe009F]@04F]IS66<HE[D2CW<015[FIcUW>F<H
0ekg00=JeUJeDY@00dic00=JeV<HF]H00U:D0ekg00a6<C6<>LiBU6<HF]I:DT8@AS4icRU:7>L25:D0
1QS6;F]6<E:D@Q0Q2088@P8<H`<8@PH<H`88@P8<H`04249oogoo000=Ool000aoo`03001oo`0001h0
0007124<HcW>HaPHaPaS000010Q200dU:Be[;F/aS48@AS4icT8@?Nle[CW>?Nm:DP02CW<3BU801Tic
AS56<DHaCW=6<@<mk`9:DP06@Q0mkc6<@Q1:DTHa148@00<icSF]>Lh00T8@00He[Cg_AS5242e[<H`2
>Lh024Ha?NlU:AcW?Nm2436<;F/29BT00be[12448@0236<01ABU6<I>LcW>48@00P0000<48@000000
3P000Woo00<007ooOol02goo00/007ooOole[A24124Q24YB248DY@Q2008@Q006124Li`@Q<H`DYDYB
0S6<00`icQcW48@000aS24848A24248DYB48:DX236<01A242480048@6<H00R4800XicPQ2@Q0Li`aS
48@e[A2436<48@8aS00?48@48Be[48@aS0Q2124001BU000DY@@Q24848@0000848@087>LHaPaS9BT4
8BU:<H`48@8@Q004248001S6000236<051S68@PDYABU9BT]J`@Q6<HDY@00124@Q1BU36<HaPaS8@PD
Y@0036<25:D02@aS124LiaS648@HaP006<H0000348@00`@Q5:DHaP0200002@@Q7>L48@@Q000LibDY
6<H00003Ool00`00Oomoo`0;Ool00`00Ool<H`0324800`aS2488@P0736<3248536<2248236<22482
36<02@@Q36<]Je[FIcU6<AS6124<H`026<H022DY;F/icTHaDYANmf<HG_L5E[D00f<HKg][FP02IcT0
1fmkJeYNmekgHaQW>E[F009BU004E[ES66<HF]H2DY@015[FHaQS66<H0ekg00]F]DicDYAJeUJeCW=B
U6<HG_M6<Cg_009BU00FHaQBU3F]>LiF]E[FAS4icT8@BU8e[AS648@DYAS68@Pmke[FDY@YBPaS2482
36<3248236<01@Q236<<H`aS24800PaS0PQ200@<HgooOol000eoo`0037oo00<007oo0000800000H8
@THaG_L<H`@Q48@236<02P00124U:A24=Jdmkd8@<H`icSg_0S6<00/icTYBAS5244HaDYA:DSg_=Jdi
cT8@0096<@<mk`03AS5>LdYB00924096<@9:DP96<@04>Lhe[CW>?Nl2AS401Sg_@Q1:DT8@>LhU:@8]
J`0E>Li242e[9BTaS3W>=JdLibe[=Jd8@P@Q36<48A248@Q:DSg_;F/000@Q0180009oo`03001oogoo
00]oo`07001oogoo6<HaS0Q212400`Q200@LiaBU7>L@Q08DY@03?Nl001240092400O36<aS0aS248<
HaBU7>L<Ha24=JdU:AcW6<HQ2124;F/@Q3W>@Q0HaPQ2>LhYBR487>LYBPQ2000Li`Q200000Q2401l<
H`Q26<H000Q29BT48@aS124Q20aS248001S648@8@P@Q6<HLi`@Q48@HaQcW<H`@Q0@Q8@P48A245:D4
8@0224802000124000aS248DY@aS000324803QcW>Lh8@QS65:D8@Q24248HaPQ2124YBQS636<25:D0
11S6<H`8@P@Q0QS600lQ212448@Q20005:D48A24000<H`Q236<DYB48;F/00goo00<007ooOol02goo
00@007oo36<<H`<8@PX<H`88@P8<H`88@P8<H`06248<H`aS24848@Q20Q2400P48@Q2;F]NmfLi@Q0D
Y@@Q0Q240QcW00<Q23F]CW<00UJe0U:D00Q:DTHaAS5BU5kgHaQNmf<H0V]J00INmdicDYANmfLiG_L2
E[D01e[FHaQW>F<HF]IF]E[F00=Nm`9JeP04E[E>LdYBDY@2HaP01UJeDYAS66<HBU8e[@96<@9JeP09
@Q0icTHaBU8mkcW>?NlicR48008@Q00:6<HQ23F]E[ENmcg_48@48@aS48@2248236<01A242488@PaS
48@00PQ20PaS0PQ200@<HgooOol000eoo`0037oo00<007oo00002@0000<48@0000005@0000D8@TYB
JeX8@QBU008@Q00:1248@PQ28@PU:Cg_@Q0YBRe[:DX29BT01cW>AS52436<@Q16<DYB00<e[@03@Q1:
DT8@00924005?Nm6<DHaBU8mk`03@Q0014Ha@Q12448@0cF]00<icT8@AS400Sg_00A244Ha?NlQ208U
:@07>Li2436<9BTQ22U:7>L00RDY00T<H`0036<<H`@Q=JdYBTHa?Nl05@000Woo00<007ooOol02goo
00D007ooOom_NbDY008HaP0;5:D8@QS636<8@QS624848@Q25:DLi`036<H01PQ28@PU:@aS124aS084
8@0?00048@Q236<48ABU48@<HdHa5:DHaP@Q<H`8@RU:00848@06000<HacW48@]JaS60SF]00H48A24
000000Q28@P26<H0124848@Q21S60Q2401448CF]7>LQ200048@e[ABU;F/YBQcW36<8@QcW248@Q0Q2
0080000M:DX000aS24848@aS6<HU:AcW36<001cW124000@Q000@Q1BU48@001S648@8@Re[48@Lib48
000DY@02124236<03`@Q248001S648@000@Q5:D]J`0036<DYBDY24800003Ool00`00Oomoo`0;Ool0
0`00Ool<H`0236<2248336<00`Q236<<H`0936<010Q236<<H`aS0PQ200d<H`Q2248<Ha24248000Q2
;F]F]Ekg@Q0Q200248@25:D05aS69BTicTHaBU96<D8@?Nle[Cg_CW=JeUJeDYAF]F<HG_M>Ld8@BU9N
mfLiHaP00U[F00ENmf<HIcUS65kg009JeP=Nm`06F]IF]E:DBU96<E:D0V<H0U[F0V<H00iBU3W>?Nlm
kdicF]I>LcW>;F/icTHa@Q0aS1cW0QBU00LLib48<Ha:DU[FBU8Q20021240112436<8@PQ20`aS0PQ2
0PaS0PQ20PaS0PQ200@<HgooOol000eoo`0037oo00<007oo0000100000<48@0000006`0000@<Hbe[
Kg/<H`8U:@88@P0836<000Q29BTQ22e[7>LHaP8Li`03=Jdmkd8@008mk`04BU8mkcF]6<H2>Lh2AS42
?Nl2@Q001dHa@Q1243g_=JdicSg_00924005>Lh]Jbe[<H`icP02@Q001THa?Nm2448@?Nl]J`8Li`09
>Li243g_8@PDYA247>LaS1240088@P0736<8@Sg_6<HmkcF]24805@000Woo00<007ooOol02goo01<0
07ooOole[@Q2000U:@005:D002486<H<HaBU:DX@Q2489BTDY@02:DX0336<48@001cW124DYA2436<Q
20Q27>L<H`848@0A9BTDYAcW48@HaR48248HaR487>L00124248<HaS6124DY@0200007bDY7>LHaPaS
AS4LiaBU124aS3W>249:DPQ21248@Q2436<48AS65:D8@P@Q36<0024848@000aS5:D@Q0aS008@Q006
5:D003F]<H`Li`@Q0QBU01L48@0048@@Q0aS6<H<H`@Q6<HLieJe5:D<HcF]36<HaR4836<Q20006<HQ
2000008DY@05248Li`Q2000U:@0248@020@Q<H`48ABU248mkaBU48@3Ool00`00Oomoo`0;Ool00`00
Ool<H`0236<2248336<010Q236<<H`aS0`Q22@aS0PQ200d<Ha2436<48@Q248@<H`00124YBUJeHaQ:
DP02:DX01QS65:DDYAS69BTe[@8mk`0A=Jd]Jbe[>Li>LekgF]IBU5JeG_MF]DHa>Li6<E[FHaQNm`03
F]H4G_L03E[FE[EF]EkgHaQNme:DBU96<DYBDYAJeUkg009JeP04G_MS65Je@Q02>Lh054YBF]IBU3F]
9BT]Jd8@>LhQ21245:DHaQcW;F]:DUJeBU8U:@aS248236<2248736<00`Q236<<H`0236<32482Ool0
0`00Oomoo`0;Ool000aoo`03001oo`0002<00003248icUkg008DY@03<H`48A2400<8@P03:DXLibDY
008HaP045:De[Cg_AS43@Q000cg_=JdLi`02>Lh4@Q001DHa?Nm6<D8@?Nl00SW>00De[CW>@Q1243W>
008aS006>Lhmkcg_?Nm243g_0T8@00LmkcF]6<HHaSF]@Q0icP025:D011S6=Jd<H`@Q0PQ200L48BDY
36=>Ld8@48@48@0500000`@Q0000000=0002Ool00`00Oomoo`0;Ool04`00OomooaBU9BTicP@Q5:D0
02e[9BT8@P@Q5:DLi`00>LhHaPQ200<000048@P<H`@Q0002<H`2:DX05PaS48@Li`aS48@8@PaS48@]
J`@Q9BU24000@Q0e[AS6:DX00248248HaQcW0QBU01le[A24124icQS68@Pe[@00;F/DYBU:5:D@Q0Q2
;F/Q20Q27>L48@Q2:DX8@P@Q6<H<H`005:DQ20001248@P025:D03000248<HacW;F/HaPQ2000<Ha24
5:DLi`848@0A;F/DY@Q248@8@P00124HaRU:7>L8@R48248001247>L8@P0200001B486<HLi`@Q48@0
0P@Q00<8@QS612400P0000<8@QcW5:D00goo00<007ooOol02goo00<007oo36<01`aS00@8@PaS36<<
H`<8@PX<H`04248<H`aS36<2248020aS48@<H`00248YBU:DG_L2CW<02C6<7>L@Q0aS6<HYBSF]>Lhe
[@02:DX0136<AS5JeV<H0Ukg00QS65[FBU8icT8@DYANme[F0UJe0U[F0eJe00MBU4YBAS5BU5kgF]I>
L`02AS400dicDYABU002E[D01E:DE[ENme:D?Nl00SF]00E6<EJeCW<aS2DY008YBP0:7>LDYAS67>LH
aR48@Q1JeTic:DX22480112436<8@PQ20PaS0`Q20PaS0PQ20PaS0PQ20PaS00@8@WooOol000eoo`00
37oo00<007oo00008P0000@48@00124aS09BU006;F/DYABU36<48B480QcW00He[AcW6<HQ22U:=Jd2
>Lh02CF]>LhmkcW>6<He[CW>AS524002?Nl0548@?Nlmkcg_>LhaS2U:;F/e[Cg_@Q0e[C6<;F/e[C6<
=JdicSg_@Q02>Lh013F];F/LiacW0S6<00@@Q2486<HaS080008<H`06248aS0aS@Q16<A245`000Woo
00<007ooOol02goo00@007ooOolaS08<H`0=5:D8@T8@000<HbDY5:D]JcF]48@U:ABU00000RU:00@D
Y@Q2:DX8@P8HaP07124000Q25:D<HaS68@P00PQ20P0000@@Q1BU12448@8DY@0800048ABU0008@Q24
AS448@8]J`0E000Q20aS124@Q2DY6<HaS1BU8@P@Q000248DYAcW:DX000aS7>L001cW0088@P08:DX<
H`@Q000@Q1BU48@0008<H`0E6<H8@Q249BTYBP00124@Q0aS5:D8@P@Q248DY@006<H48AS65:DU:AS6
00848@087>LU:AcW6<HaS24848@48@80000;7>LHaP00000DYAS69BTDYA247>L<H`0248@00aBU8@Qo
o`02Ool00`00Oomoo`0;Ool00`00Ool<H`0536<2248736<010Q236<<H`aS0PQ21@aS0PQ20`aS00P8
@PaS48@@Q0@Q248Q24Ha0UJe00=>LcF]8@P00QBU00DLibU:>LhmkcF]008]J`0=>Li:DU:DE[EJeUkg
F]I>Lcg_@Q1BU5kgF]H00UJe0U[F00MF]E:DCW=:DT8@?Nm:DP02E[D00dYBAS56<@02BU800e:DE[EF
]@02DY@00eJeCW<icP02<H`0148@BU8mkbe[0RU:00<Lia245:D00b4800PicUJeE[DaS0aS124<Ha24
0PQ200<<Ha2436<00PQ20PaS0PQ20`aS0PQ20PaS00@8@WooOol000eoo`0037oo00<007oo00008P00
00@48@00124aS09BU006;F/DYABU36<48B480QcW00He[AcW6<HQ22U:=Jd2>Lh02CF]>LhmkcW>6<He
[CW>AS524002?Nl0548@?Nlmkcg_>LhaS2U:;F/e[Cg_@Q0e[C6<;F/e[C6<=JdicSg_@Q02>Lh013F]
;F/LiacW0S6<00@@Q2486<HaS080008<H`06248aS0aS@Q16<A245`000Woo00<007ooOol02goo00@0
07ooOolaS08<H`0=5:D8@T8@000<HbDY5:D]JcF]48@U:ABU00000RU:00@DY@Q2:DX8@P8HaP071240
00Q25:D<HaS68@P00PQ20P0000@@Q1BU12448@8DY@0800048ABU0008@Q24AS448@8]J`0E000Q20aS
124@Q2DY6<HaS1BU8@P@Q000248DYAcW:DX000aS7>L001cW0088@P08:DX<H`@Q000@Q1BU48@0008<
H`0E6<H8@Q249BTYBP00124@Q0aS5:D8@P@Q248DY@006<H48AS65:DU:AS600848@087>LU:AcW6<Ha
S24848@48@80000;7>LHaP00000DYAS69BTDYA247>L<H`0248@00aBU8@Qoo`02Ool00`00Oomoo`0;
Ool00`00Ool<H`0536<2248736<010Q236<<H`aS0PQ21@aS0PQ20`aS00P8@PaS48@@Q0@Q248Q24Ha
0UJe00=>LcF]8@P00QBU00DLibU:>LhmkcF]008]J`0=>Li:DU:DE[EJeUkgF]I>Lcg_@Q1BU5kgF]H0
0UJe0U[F00MF]E:DCW=:DT8@?Nm:DP02E[D00dYBAS56<@02BU800e:DE[EF]@02DY@00eJeCW<icP02
<H`0148@BU8mkbe[0RU:00<Lia245:D00b4800PicUJeE[DaS0aS124<Ha240PQ200<<Ha2436<00PQ2
0PaS0PQ20`aS0PQ20PaS00@8@WooOol000eoo`0037oo00<007oo12400P0000<48@0000005@0000<4
8@0000002@000QcW00A6<DYB36<U:@88@P0?124HaRDY:DXU:B486<HDYBU:;F/aS3W>?NlicQBU008e
[@E2400<?Nle[CF]<H`YBR48;F/aS3W>AS4e[C6<0Re[00<YBS6<>Lh00Sg_00@icSg_>LhLi`8HaP0?
48@HaRDY:DX8@P@Q248<Ha2436<icPaS@Q0mkbU:014000031240000000@0009oo`03001oogoo00]o
o`06001oogooF]HHaPQ20QcW00/Q200048@DY@Q236<icQS6?Nm:DP@Q0096<@08000]JacW6<HU:A24
000]J`<@Q00C0008@QS65:D48A24124U:BU:6<H@Q2e[124000aS24848@Q2;F/00aS600LDYB4836<D
Y@aSCW=BU0025:D01b48CW<Li`0048@YBPaS008Li`0648@8@P@Q124@Q0Q20`0000@8@QcW5:D<H`88
@P037>LDY@aS008@Q00J000<H`Q2248Li`@Q48@8@P@Q48@Q20aS248Q20aS5:D8@R487>L<H`005:D@
Q248248U:@8Li`0348@<H`@Q008Q200:248@Q0Q2248@Q00048@Li`0036<3Ool00`00Oomoo`0;Ool0
0`00Ool<H`0536<2248836<01@Q236<<H`aS24802PaS0PQ200<<Ha2436<00P@Q00<HaSW>>Lh00U:D
00U242e[7>LDYAS6:DXe[CW>;F/00RDY00@]JcF]=Jdmk`9:DP04?Nle[D8@DY@2G_L2F]H02EkgF]IF
]DicBU9243W>?Nm:DP02E[D01TicBU96<Cg_@Q1:DP9JeP05E[EBU5:DAS4e[@02;F/00c6<=JdYBP02
9BT2:DX01BDY8@PQ22U:?Nl00UJe00HicQBU1248@Q2436<2248236<00`Q236<<H`0236<01@Q236<<
H`aS24801@aS0Woo00<007ooOol02goo000<Ool00`00Ool0000P00000`@Q0000000500000a24AS5N
m`029BT01@aS12448@@Q248010@Q00/8@PaS48@Q22U:5:D@Q2e[<H`icSg_0096<@8mk`07=Jd]JbU:
8@PHaRU:<H`00Sg_00HicS6<:DXU:A24>Lh2?Nl01CW><H`YBQBU6<H00R4800<U:BU:24800PQ200XQ
23W>?Nl<HcF]2496<D8@<H`48@h000031240000000L0009oo`03001oogoo00]oo`0C001oogoo=Jd]
JaS636<DYCW>8@P<H`0048@<HaBU@Q0000Q248@00PaS00TQ21S67>L@Q0@Q9BT@Q2DY000010Q2018a
S124;F/000@Q248]JcF]5:D00248=JdaS0Q2:DXQ20@Q36<224803c6<1248@P006<HDY@@Q000U:ABU
?Nl<H`Q28@P48@025:D00aS62480000236<02@Q25:D48@aS:DX8@Re[248@Q00200002ABU36<LiacW
248@Q000248DY@0248@336<01A2436<U:@@Q48@010@Q00LU:ABU;F/000Q2000@Q0035:D03@@Q<H`L
i`Q248@HaR4848@48@aS000YBP00008@Q0=oo`03001oogoo00]oo`03001oo`aS00l<H`88@P@<H`88
@PD<H`88@P8<H`88@P0436<@Q0Q2124248@01SF]DYAJeTYB=JdQ208DY@057>LU:B487>LHaP037>L0
2248;F/aS2U:9BTe[DYBE[D4F]H03E:DBU96<Cg_=JdaS3W>CW=Nme[FDYA:DSg_008aS008?NmBU5[F
E[E:DT8@>LhaS08]J`8YBP068@PHaR48;F/icSF]0RU:00DmkeJeF]HmkaS60088@P0348@<H`Q2008<
H`88@P@<H`03248<H`aS00D<H`03248<H`aS009oo`03001oogoo00]oo`0037oo00<007oo0000:@00
00H8@SW>@Q0mka24;F/224801P@Q48@48@@Q000<H`848@0800048@@Q124<Hbe[>Lhmk`8icP03=Jdm
kbU:008Li`0=6<H@Q2U:=Jdmkd8@>Lhe[B487>L@Q1BU?Nl00SW>00@U:BU::DXHaP8]J`0=36<8@PQ2
248003W>36<HaRDY5:E6<DYB9BT01@0000<48@0000003@0000<48@0000000P000Woo00<007ooOol0
2goo00`007ooOole[@@Q6<H8@QS648@YBQ247>L25:D01AcW36<@Q0aS9BT00P0000T@Q1cW8@Q240aS
:DX48@aS5:D00`@Q00X8@PaS248DYBe[000@Q0@Q:DXDY@848@078@Pe[AS69BT<H`@Q:DX00`0001L<
Ha2436<icRDY6<H8@V<H6<HLi`aS48@8@P00124HaP0048@U:AS65:D48ABU008HaP0336<@Q2e[008D
Y@8Li`03?NlDY@aS008DY@848@0H6<HaS1BU124LibU:248Li`@Q36<000Q2000DY@009BT<H`0048@8
@P006<H@Q1cW0R4800`48BDY48@8@P@Q7>LHaQBU6<He[@00124224801BU:Oomoogoo00003Goo00<0
07oo36<040aS0PQ20`aS0PQ21@aS0PQ200<<Ha2436<00PQ20Q2400/8@P00000@Q36<BU9BU4ic?NlY
BQBU008<H`<@Q0<DY@096<HQ22486<HDYB48=Je244YB00=>L`04AS4icS6<;F/2:DX03SF]BU9JeUkg
E[E6<CW>:DXU:C6<AS5>LdHa>Lh2<H`02Re[:DXYBRDY8@PHaQBU7>L]JcF]0S6<00E245JeE[DicQS6
0088@PH<H`88@Pl<H`9oo`03001oogoo00]oo`0037oo00<007oo0000:P0000/48B48?Nm:DRDY36<H
aQBU36<8@Q24008<H`04248<H`aS36<2248212400`Q27>LHaP036<H011BU6<HHaRDY0QBU00DaS3g_
?NlmkbU:00<Li`8HaP039BTHaQBU008U:@<<H`0=124000aS48@8@Q24=Jd002DY<Ha241BU12405`00
00<48@0000000Woo00<007ooOol02goo00`007ooOol48A24124DYA24@Q0002DY124348@010aS124H
aPQ20P@Q00<DY@aS5:D00P0000PHaQBU5:D000Q248@000@Q0R4800D<H`Q25:D8@SF]008Q2009249:
DTic<H`U:DHa0008@PaS00<Li`0336<8@QBU008@Q0076<H000aS1248@QS612400P0000@DY@Q2124<
H`8Li`0348@48@Q200<48@<<H`046<H8@PQ212436<H02@Q21248@PQ2000<Ha240008@P02000040aS
48@Li`005:D@Q2486<H000aS<H`<HbDY000@Q0Q20PaS00d48@00000Q21BU000Lia24<H`48A24124e
[@021243Ool00`00Oomoo`0;Ool00`00Ool<H`0336<00`Q236<<H`0;36<4248436<2248336<010Q2
36<@Q0aS0PQ200h<Ha242488@P@Q36<Q23W>CW=BU4YB=JdQ21BU112400DDYAS66<HHaQBU008@Q004
5:DQ22U:;F/2<H`2>Lh00be[9BTQ20029BT03BU:>Li>Le:DBU8mkcF];F/YBRe[>Lhmkc6<00<YBP05
9BTQ22487>LHaP025:D01AcW:DX]Jc6<?Nl00Tic00@aS1BU1248@QP<H`9oo`03001oogoo00]oo`00
37oo00<007oo00005P0000<48@0000004`0000T8@Re[@Q12436<124HaQBU36<00P@Q00@8@Q2436<<
H`88@P045:D8@P00124200001QcW:DXLi`0024848@8DY@0@6<HQ22485:DYBQS6:DXHaRDY8@PU:AcW
48@8@P@Q000224802aBU0008@Q24<H`8@PaS@Q1:DSW>12404P0000<48@0000001`000Woo00<007oo
Ool02goo00X007ooOolQ21cW5:E6<BU:8@PYBP800007248001S65:DU:@0012400PQ200<@Q1S636<0
0QcW01X@Q1cW5:D@Q0Q2000DYAS624848ABU124@Q0Q2124DY@Q2124YBPaS8@P<H`00;F/DY@Q20SW>
0RDY00LLi`@Q<H`Lia245:DU:@0324826<H04A245:DU:@aS:DY6<AS600048AS68@P@Q0@Q5:D@Q000
5:D00PaS0Q2401T8@QBU124DYB48:DX<H`Q236<HaP@Q6<H001S6124e[Be[0008@Re[8@PicQS636<D
Y@0200001AcW248]Jbe[6<H00P@Q00De[B486<H8@P00008HaP8000036<H48ABU00=oo`03001oogoo
00]oo`03001oo`aS008<H`88@Ph<H`<8@PD<H`88@P8<H`88@P<<H`88@P0436<@Q124248212402QBU
:DXmkdYBCW=:DSg_<H`U:AcW0aS600@DYA2448@DY@<HaP8@Q08HaP09:DX]JbDY7>LHaQcW8@PU:Be[
008e[@05<H`]Jc6<=JdaS002;F/00bU:8@PQ20028@P00acW5:DDY@0348@02acW:DXe[Cg_AS5:DT8@
:DX<H`@Q24800PaS00<8@PaS36<00PQ20`aS00<8@PaS36<030aS0Woo00<007ooOol02goo000<Ool0
0`00Ool0000[00002@@Q000000Q2>Li6<Dic>Lh@Q0025:D26<H01@aS248<H`0036<00Q2400D48@00
12448@aS00<8@P<000848@0900048@Q2124HaRDY48@U:A2400<00003248@Q0aS00848@0536<HaR48
36<48@02AS400d8@6<H8@P0H00000`@Q000000020002Ool00`00Oomoo`0;Ool01P00Oomooekg248a
S08<H`0;48AF]@00AS448@Q236<LicW>248YBP0236<04aBU>LhHaTHa248icRDY5:D<Hb48124U:C6<
7>LU:B4848@DYA24008<H`8000036<I240@Q00<YBP80008DY@0G>LhQ20Q2000<Hb48;F/8@Q24000L
iaS6>Lh@Q1BU248HaP@Q48@8@P@Q36<Li`0300001@Q25:D8@QBU9BT00QcW010U:@aS:DXDY@aS6<HU
:ABU36<icQcW36<HaR4824848@8<H`848@0;48@HaPQ27>L<HbU:248001249BT48@0248@03Cg_36<a
S1246<H@Q36<124DYA245:D<H`00008<H`=oo`03001oogoo00]oo`03001oo`aS008<H`03248<H`aS
00H<H`88@P<<H`03248<H`aS00P<H`<8@P8<H`88@P<<H`0D248<H`aS48@<H`Q21248@QS6;F]245:D
E[E>Lcg_=Jd]JbU:8@PHaP8DY@066<HLiacW5:D8@P000PaS00HHaR487>LDYA245:D26<H27>L26<H0
1QcW9BT]Jc6<:DXQ20@HaP035:D@Q124008@Q0056<HQ236<>Li6<@02BU801cW>8@P8@P@Q248@Q0aS
0088@P8<H`88@P8<H`03248<H`aS00H<H`04248<H`aS36<2248010aSOomoo`003Goo000<Ool00`00
Ool0000_00003`@Q248]Jd8@BU8mkcF];F/@Q0@Q36<@Q1cW6<H<H`021240200012448@Q21248@P@Q
0002248236<00a24248<H`0224800`@Q2488@P0212401@Q236<48@@Q36<00QcW00<@Q0@Q6<H00cg_
00<U:@@Q00007P000Woo00<007ooOol02goo01<007ooOom>L`@Q48@48C6<36=BU248:DX48CW>6<Ha
S0aS000U:@0212400a24:DXDY@02124324804QBU0008@PQ2:DX001cW124HaQBU00048@aS7>L<HbDY
000DY@848@03000<Hc6<00848@08;F/8@PaS124001BU124U:@80000E124DY@Q20008@QS67>L]JbU:
<H`LiaBU124001BU;F/<Ha24124DY@00008]J`0C6<H48BDY2480012436<HaP@Q000<HaBU000DY@@Q
;F/000Q200000QBU0PaS0QBU00DU:BU:48@000Q200<HaP03:DXHaQcW008DY@06AS4<HaBU8@Pe[BDY
0P0000<YBQBUOol00Woo00<007ooOol02goo00<007oo36<010aS00<8@PaS36<00PaS1@Q20PaS0PQ2
0`aS0PQ20PaS00<8@PaS36<00PQ20`aS0PQ20Q240`Q200@<Ha2436<8@P848@0:36<Lic6<@Q16<D8@
AS5:DT8@=Jd3;F/01RDY7>LHaQBU48@<H`8@Q0045:DHaQ2436<224800`aS48@@Q00336<00a245:DH
aP027>L00aS648@@Q00336<01QBU8@PQ22e[=Jdmk`=6<@06>Lh]JaS624848@Q20PaS0PQ21PaS0PQ2
30aS0PQ200@<HgooOol000eoo`0037oo00<007oo00003P0000<48@0000008@0000X48@Q29BTmkd8@
>Li6<CF]<H`DY@848@0348@DYA24008HaP8Li`036<HDY@aS008<H`04248<H`Q2124224801P@Q0008
@PQ236<@Q0<<H`0:7>L<HaBU5:De[DHa>LhmkbDY124Q0002Ool00`00Oomoo`0;Ool02000Oomoofmk
000DYCg_36<2AS402ABU124Q248@8@P002U:248<H`026<H020@Q7>L8@PaS?Nl@Q3W>1242248022e[
00048AS6248@Q1BU124236<00`Q25:D8@P035:D01@aS@Q0U:AS636<00bU:00/48AcW248]Jc6<1240
01cW5:D48AcW008Q2004248HaP@Q8@P248@00b486<H000021242248011249BT002DY0b4801h48@00
48@<H`0036<001247>LDY@@Q000U:ABU248DYB48:DXQ212436<DY@@Q48@000aS24848A24<H`236<2
00003BDY7>L8@P@Q000<H`00248<H`@Q36<@Q0aS00=oo`03001oogoo00]oo`03001oo`aS0088@P8<
H`88@P8<H`<8@PH<H`88@P0436<8@PQ2248236<2248336<010Q236<<H`aS0PQ20PaS10Q200@<Ha24
48@8@P848@0536<DYB48;F/icP02AS42@Q02AS401SW>;F/YBRU:;F/YBP8U:@038@PLiaS6008DY@8@
Q0@DY@036<HDYA24008<H`0348@DYABU00<DY@0>6<HYBSg_?Nm:DTicBU9243W>:DXDY@@Q0008@P8@
Q00336<8@PaS008<H`88@P8<H`03248<H`aS00<<H`03248<H`Q20088@P8<H`88@P<<H`9oo`03001o
ogoo00]oo`0037oo00<007oo00003P0000<48@0000008`000P@Q00T001S69BTmkd8@?Nm:DT8@=Jd0
0Re[0QBU00<HaPaS12400PaS00<48A245:D00QS600<LiaS66<H00QBU00T@Q1BU5:DDYAS648@8@PaS
?Nl00SF]00A6<Cg_7>L48B<0009oo`03001oogoo00]oo`0C001oogoo7>L]J`@Q>Lh48@aS7>LU:D8@
:DXe[@0036<48ABU24800P@Q00/DY@Q25:D@Q2e[124]Ja24=Jd@Q2DY00848@0=<H`LidYB5:DaS124
0008@PaS248DY@@Q36<00PQ200<<Hcg_00000R4800HDYA2448@DYBDY1242;F/02b487>L]J`Q25:D0
01S6000Li`aS9BT00Q2400X000aS5:D<H`Q27>L<HacW124HaP8]J`0:24848@Q29BTDY@Q27>LU:A24
6<H248@01aBU000LiaBU48@HaPQ2008000848@0448@48@aS0002124040aS1240000048@48A245:D0
01247>L8@R4836<48@aS0RDY00D48GooOomoo`0000eoo`03001oo`aS00<8@P8<H`04248<H`aS36<2
248636<624800`aS2488@P0436<2248336<2248436<224800`aS48@@Q0022483124021247>LU:BU:
<H`icT8@AS42@Q0014HaBU96<D8@0Sg_00De[C6<=Jde[C6<008]J`8aS08]J`03:DXU:AcW008DY@04
6<HQ22DY:DX2;F/00cW>AS5>L`02CW<01D8@=JdYBQS636<00P0000@48@aS48@<H`88@P<<H`88@P8<
H`04248<H`aS36<324800`aS2488@P0336<2248236<010Q2Oomoo`003Goo000<Ool00`00Ool0000a
00000`@Q00000005000212401QBU:DXmkcW>AS4icP8mk`04=JdicT8@?Nl2>Lh01Re[=JdU:B486<HU
:@8<H`0848@8@PQ248@HaR48:DXe[@8mk`8icP045:D8@P00124S0002Ool00`00Oomoo`0;Ool04`00
Oomooc6<000aS1BU1248@SW>:DX@Q1BU124DY@Q236<8@QcW008<H`0H?NlQ236<9BT<HaS600048C6<
48@U:@007>L001cW000@Q0@Q24848B48000Q20Q20P@Q00D8@P@Q36<<HacW008HaP0<8@P001BU:DXQ
20001240012436<Q21S60P@Q010@Q1S612400124000U:B4848@DY@aS124LiaBU8@P000<8@P0::DXQ
20aS124000aS000DY@00:DX236<03@@Q9BT<H`aS5:D@Q0aS48@<Ha24000YBPaS0080000448@002DY
8@P236<020@Q48@48BDY48@mka2436<224801AcW6<H48B4836<00goo00<007ooOol02goo00<007oo
24800PaS00@8@PaS36<<H`88@P8<H`<8@PL<H`88@P0336<8@PaS00<<H`88@P8<H`88@P8<H`88@P@<
H`<8@P0636<@Q12448@<H`Q20`@Q00L8@Q247>LQ22DY<Ha24002CW<00dHa?Nlmk`03?Nl00d8@AS56
<@04AS400d8@?NlicP02=Jd01S6<;F/]Jc6<>Li24096<@9:DP924007<H`Q21BU36<48@0024800Q24
00<<H`Q224801PaS0PQ21@aS0PQ21`aS0PQ200<<H`Q224800Woo00<007ooOol02goo000<Ool00`00
Ool0000`00000`@Q0000000900000`@Q24800002000224801QBU6<HYBRU:=JdaS08e[@924003?Nla
S48@008mk`8e[@07>Li243g_?NlicRe[5:D00P@Q9`000Woo00<007ooOol02goo010007ooOom6<A24
248LiaS68@P8@P@Q8@Pe[AS6AS448@8Q200F248@Q1248@P48Cg_000<Ha245:D002e[36<aS1248@P8
@PaS<H`<HaBU000236<021248@PU:@006<HDY@aS48@21242<H`032e[36<@Q3g_248@Q1BU8@P8@QS6
48@]J`8@Q007124YBP@Q124001S624800P0000L48AcW124Li`0048@YBP0336<04P006<H8@PaS000@
Q00036<001BU248001cW36<HaS6<36<00088@P035:D8@P@Q008HaP06:DXHaRDY5:D@Q0Q20aBU00D4
8@007>LLia2400848@0348@]J`aS0088@P038@PHaWoo009oo`03001oogoo00]oo`03001oo`aS00D<
H`88@P<<H`@8@PH<H`88@PH<H`88@P8<H`88@P<<H`<8@P<<H`<8@P0836<@Q12448@<H`Q212400084
8@<8@P065:DQ22U::DXU:B480RDY00@YBRe[=JdicP@mk`05@Q0mkcW>>Lhmk`02@Q07?Nl01CW>;F/Q
224848@00PQ20P@Q00D8@Q245:D@Q0aS0088@P<<H`05248<H`aS36<8@P0336<4248636<62482Ool0
0`00Oomoo`0;Ool000aoo`03001oo`0004T000031240000000848@0448@HaQS67>L29BT00aS65:D8
@P0]0002Ool00`00Oomoo`0;Ool03@00Oomood8@E[D<HeJe48@48AS6124icPaS0088@P030008@PQ2
00<48@0<7>L48@aS48@HaP0024848ABU36<DY@aS0P@Q014YBP@Q6<H48@Q236<000aS8@PU:@Q2?Nl4
8BU:6<HYBPQ2008aS00>5:DU:A24124<HcF]9BT@Q1BU6<HLiaBU000HaP8DY@0?124]J`Q25:De[CW>
9BTLi`Q28@P@Q0@Q5:DYBPQ200848@038@Pe[B48008@Q00F248YBPQ28@PU:@00248HaT8@:DXQ20aS
<H`YBQ24;F/HaPaS6<H@Q2e[00029BT248@200003a24124HaQBU36<YBP@Q248YBQcW36<8@Re[8@PD
Y@03Ool00`00Oomoo`0;Ool00`00Ool<H`0436<2248436<5248236<4248436<2248336<00`Q236<<
H`0236<224800`aS2488@P02248010aS48@<H`aS0`Q20PaS112400@<H`Q212448@@000061248@PQ2
248@Q1BU0QS611cW0R4800<U:BU:;F/00c6<00@e[C6<;F/U:@8Q20036<H<H`@Q00848@88@P0736<@
Q12436<8@P@Q24800PaS0PQ21PaS00<8@PaS36<010Q21@aS10Q200<<H`Q224800Woo00<007ooOol0
2goo000<Ool00`00Ool0001O00000`@Q0000000R0002Ool00`00Oomoo`0;Ool04`00Oomoof<H249F
]A24:DX48ABU000DY@Q2000U:ABU48@Q23W>0088@P0@124HaP000008@QBU00048C6<000DYB48:DXm
kacWCW<25:D00`006<H0000248@324801CF]7>L0048@5:D00P0000l<HbDY000002e[000U:A248@P4
8BU:5:D8@P007>L00PaS00DaS0009BTQ2000008@Q0038@P0000000848@056<H8@RDY9BT<H`027>L0
400048@<HacW8@P<HaS61248@Q249BT48@Q2=Jd001S60P@Q00Y:DP008@PDY@@Q6<H<H`Q2124HaP84
8@0?36<48BDY36<002e[8@P000@Q6<H000aS48@YBPaS00=oo`03001oogoo00]oo`03001oo`aS00/<
H`@8@P<<H`88@P@<H`<8@P<<H`88@P<<H`88@P<<H`<8@P0336<@Q0aS00D8@P0336<@Q124008@Q08<
H`0324848@00008000H48@L8@P0336<@Q1BU008DY@@HaP0348@<H`Q20088@P<48@03248<Ha24008@
Q00436<8@P@Q248336<2248;36<3248336<4248236<22482Ool00`00Oomoo`0;Ool000aoo`03001o
o`0008@0009oo`03001oogoo00]oo`0>001oogoo;F]6<A247>L@Q3F]36<LiaS6000DY@848@03248Q
2000008DY@07;F/<H`007>LDYAcWAS400Q240PQ2018000aS48@Q21BU7>L<H`006<HDYA24000@Q0@Q
;F/<HbDY7>L2248236<29BT01cF]5:D8@RU:8@P@Q0000088@P0>>LhDYB488@P8@Q249BT000Q29BT4
8A24000Li`848@048@PDYABU9BT236<01AcW36<LiaBU12400Q2400P8@PaS48@Li`aS000<H`000P@Q
00hDYB486<H48AcW6<HaS124000@Q1BU6<H@Q2480PQ200l48B489BTQ20Q2000@Q0aS48@Q20aS5:D<
HdHa00000goo00<007ooOol02goo00<007oo24800PaS0PQ20PaS0`Q20PaS0PQ22PaS0PQ20`aS0PQ2
0PaS0PQ20`aS00<8@PaS36<00PaS0`Q21PaS0PQ20P@Q00<8@PaS48@00a2400<DYA2448@00`aS10Q2
0P@Q0PQ21`@Q00<8@P@Q124010@Q00<8@PaS48@00Q240PaS0`Q200@<Ha2448@<H`88@PX<H`03248<
H`aS008<H`88@P8<H`<8@P8<H`<8@P9oo`03001oogoo00]oo`0037oo00<007oo0000>`0000<48@00
00008`0000<48@00000080000Woo00<007ooOol02goo00H007ooOole[@Q28@P224802c6<00048A24
9BTHaSW>000Q20@Q48@00PQ200<48B4848@00RDY00H48CW>36<HaPQ2;F/236<02aS6124]Jbe[7>LD
YA248@Pe[C6<24800QBU00D@Q0aS124<HbU:008000848@0648@U:@00000YBQ240P@Q0`Q200`48@Q2
9BT8@QS65:DLiaBU8@PDYA2436<26<H010@Q48@8@P000S6<00l8@RU:48@<H`@Q9BT@Q36<36<@Q0Q2
7>L000aS5:D00P0000HQ20aS8@PDY@00248200001QBU8@P@Q0Q2124Li`<48@05000Lib4836<mk`02
12401aS6?Nl48@005:E240Q200=oo`03001oogoo00]oo`03001oo`aS008<H`88@P<<H`04248<H`aS
36<2248336<00`Q236<<H`0436<2248336<2248236<2248336<3248236<4248536<2248212422483
36<00a245:DDY@0248@:36<42482124224821244248010aS48@@Q1240PaS10Q200@<Ha2448@<H`88
@P<<H`<8@P@<H`88@P@<H`88@P8<H`04248<H`aS36<32482Ool00`00Oomoo`0;Ool000aoo`03001o
o`0004@000031240000003d0009oo`03001oogoo00]oo`0C001oogoo9BTDY@Q2124YBQBU48@DYAS6
:DY6<@@Q?Nl<Hb485:D00Sg_01h<Hb4812448A24248mk`0024848BU:248DY@00>Lh<H`@Q8@P8@P@Q
<H`U:Be[000<HdHa9BT00124DY@300003@@Q8@PaS1BU48@Q22e[124<H`Q2000HaPaS00848@0@6<H0
00Q28@PU:DHa6<I240@Q36<U:AcW24848@aS48@2:DX02@Q2<H`48@0024848AS6248U:@025:D28@P0
20aS8@P<HaS6:DX]J`0024825:D01P005:D000006<HYBP80008Li`8000066<H48@0036<YBQ240`aS
00@48BU:<H`U:@=oo`03001oogoo00]oo`04001oo`aS36<5248436<3248236<3248736<2248336<0
10Q236<<H`aS0`Q20`aS0`Q20`aS1@Q20PaS0Q2400@<H`Q22488@PD48@<8@P/<H`<@Q08<H`@@Q0<<
H`D8@P8<H`0548@<H`Q21248@P0336<2248236<3248336<3248436<2248536<32482Ool00`00Oomo
o`0;Ool000aoo`03001oogoo08Ioo`03001oogoo00]oo`03001oogoo08Moo`03001oogoo00]oo`03
001oogoo08Ioo`03001oogoo00]oo`0037oo00<007ooOol0QWoo00<007ooOol02goo00<007ooOol0
Qgoo00<007ooOol02goo00<007ooOol0QWoo00<007ooOol02goo000<Oon:000=Oon;000=Oon:000=
Ool00?moom=oo`00ogoodgoo003oOooCOol00001\
\>"],
  ImageRangeCache->{{{0, 465}, {144.625, 0}} -> {-0.0825029, -0.0234425, 
  0.00680647, 0.00680647}, {{12.0625, 149.813}, {141.125, 
  3.4375}} -> {-14.3601, -6.03998, 0.968155, 0.968155}, {{163.625, 301.313}, {
  141.125, 3.4375}} -> {-161.168, -6.07183, 0.968595, 0.968595}, {{315.125, 
  452.875}, {141.125, 3.4375}} -> {-307.772, -6.03998, 0.968155, 0.968155}}]
}, Open  ]],

Cell[TextData[{
  "Again, the energy compaction property of the DCT is clearly visible. Most \
of the signal's energy is concentrated in relatively small low-frequency zone \
of the transform domain located at the lower-left corner of the DCT magnitude \
matrix. As already mentioned, the DCT is nearly optimal in its energy \
compaction capabilities. The approximation ",
  Cell[BoxData[
      \(TraditionalForm\`\(A\&~\)\)]],
  " is guaranteed to improve as the number of coefficients is increased. "
}], "Text"]
}, Open  ]]
},
FrontEndVersion->"Microsoft Windows 3.0",
ScreenRectangle->{{0, 1280}, {0, 968}},
PrintingStyleEnvironment->"Printout",
WindowToolbars->"EditBar",
CellGrouping->Manual,
WindowSize->{687, 615},
WindowMargins->{{Automatic, 268}, {Automatic, -5}},
PrintingCopies->1,
PrintingPageRange->{Automatic, Automatic},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, -1}},
ShowCellLabel->True,
ShowCellTags->False,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False},
StyleDefinitions -> "ArticleClassic.nb"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1709, 49, 42, 0, 72, "Title"],
Cell[1754, 51, 35, 0, 41, "Author"],
Cell[1792, 53, 112, 4, 55, "Address"],
Cell[1907, 59, 76, 2, 31, "Input"],

Cell[CellGroupData[{
Cell[2008, 65, 31, 0, 56, "Section"],
Cell[2042, 67, 346, 6, 61, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2425, 78, 38, 0, 56, "Section"],

Cell[CellGroupData[{
Cell[2488, 82, 51, 0, 43, "Subsection"],
Cell[2542, 84, 63, 0, 27, "Text"],
Cell[2608, 86, 335, 10, 32, "NumberedEquation"],
Cell[2946, 98, 46, 0, 27, "Text"],
Cell[2995, 100, 315, 9, 32, "NumberedEquation"],
Cell[3313, 111, 42, 0, 27, "Text"],
Cell[3358, 113, 430, 11, 88, "NumberedEquation"],
Cell[3791, 126, 115, 3, 27, "Text"],
Cell[3909, 131, 159, 3, 32, "NumberedEquation"],
Cell[4071, 136, 536, 12, 61, "Text"],
Cell[4610, 150, 155, 3, 42, "Input"],

Cell[CellGroupData[{
Cell[4790, 157, 273, 6, 71, "Input"],
Cell[5066, 165, 32443, 1340, 77, 15761, 1128, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[37558, 1511, 43, 0, 43, "Subsection"],
Cell[37604, 1513, 1132, 23, 129, "Text"],
Cell[38739, 1538, 324, 14, 27, "Text"],
Cell[39066, 1554, 394, 9, 40, "NumberedEquation"],
Cell[39463, 1565, 28, 0, 27, "Text"],

Cell[CellGroupData[{
Cell[39516, 1569, 206, 5, 51, "Input"],
Cell[39725, 1576, 36021, 883, 131, 7276, 524, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],
Cell[75761, 2462, 514, 17, 44, "Text"],
Cell[76278, 2481, 288, 9, 38, "NumberedEquation"],
Cell[76569, 2492, 22, 0, 27, "Text"],
Cell[76594, 2494, 238, 5, 41, "NumberedEquation"],
Cell[76835, 2501, 634, 16, 61, "Text"],
Cell[77472, 2519, 270, 9, 40, "NumberedEquation"],
Cell[77745, 2530, 190, 8, 27, "Text"],
Cell[77938, 2540, 280, 6, 40, "NumberedEquation"],
Cell[78221, 2548, 156, 5, 27, "Text"],
Cell[78380, 2555, 230, 6, 94, "Input"],
Cell[78613, 2563, 186, 8, 27, "Text"],

Cell[CellGroupData[{
Cell[78824, 2575, 91, 2, 31, "Input"],
Cell[78918, 2579, 275, 5, 30, "Output"]
}, Open  ]],
Cell[79208, 2587, 104, 3, 27, "Text"],

Cell[CellGroupData[{
Cell[79337, 2594, 240, 5, 78, "Input"],
Cell[79580, 2601, 276, 5, 30, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[79917, 2613, 38, 0, 56, "Section"],
Cell[79958, 2615, 54, 0, 27, "Text"],
Cell[80015, 2617, 513, 12, 49, "NumberedEquation"],
Cell[80531, 2631, 502, 12, 49, "NumberedEquation"],
Cell[81036, 2645, 829, 25, 78, "Text"],
Cell[81868, 2672, 695, 16, 110, "NumberedEquation"],
Cell[82566, 2690, 160, 5, 27, "Text"],
Cell[82729, 2697, 173, 4, 31, "Input"],

Cell[CellGroupData[{
Cell[82927, 2705, 283, 7, 71, "Input"],
Cell[83213, 2714, 59564, 1613, 296, 12930, 1028, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[142826, 4333, 44, 0, 56, "Section"],
Cell[142873, 4335, 250, 6, 44, "Text"],

Cell[CellGroupData[{
Cell[143148, 4345, 322, 6, 71, "Input"],
Cell[143473, 4353, 24076, 934, 92, 12959, 792, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],
Cell[167564, 5290, 121, 2, 27, "Text"],

Cell[CellGroupData[{
Cell[167710, 5296, 311, 6, 51, "Input"],
Cell[168024, 5304, 71, 2, 30, "Output"]
}, Open  ]],
Cell[168110, 5309, 449, 18, 44, "Text"],
Cell[168562, 5329, 159, 4, 27, "NumberedEquation"],
Cell[168724, 5335, 160, 4, 27, "NumberedEquation"],
Cell[168887, 5341, 473, 11, 61, "Text"],

Cell[CellGroupData[{
Cell[169385, 5356, 104, 2, 31, "Input"],
Cell[169492, 5360, 276, 5, 30, "Output"]
}, Open  ]],
Cell[169783, 5368, 208, 4, 44, "Text"],
Cell[169994, 5374, 177, 5, 27, "NumberedEquation"],
Cell[170174, 5381, 181, 5, 27, "NumberedEquation"]
}, Open  ]],

Cell[CellGroupData[{
Cell[170392, 5391, 27, 0, 56, "Section"],
Cell[170422, 5393, 312, 7, 44, "Text"],
Cell[170737, 5402, 335, 10, 40, "Text"],
Cell[171075, 5414, 119, 3, 27, "Text"],
Cell[171197, 5419, 309, 7, 65, "Input"],
Cell[171509, 5428, 51, 0, 27, "Text"],

Cell[CellGroupData[{
Cell[171585, 5432, 69, 2, 31, "Input"],
Cell[171657, 5436, 641, 11, 131, "Output"]
}, Open  ]],
Cell[172313, 5450, 311, 11, 27, "Text"],
Cell[172627, 5463, 102, 2, 31, "Input"],
Cell[172732, 5467, 273, 7, 44, "Text"],

Cell[CellGroupData[{
Cell[173030, 5478, 307, 7, 51, "Input"],
Cell[173340, 5487, 29527, 995, 120, 12744, 783, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],
Cell[202882, 6485, 238, 5, 44, "Text"],
Cell[203123, 6492, 189, 4, 51, "Input"],
Cell[203315, 6498, 268, 5, 44, "Text"],
Cell[203586, 6505, 167, 3, 51, "Input"],

Cell[CellGroupData[{
Cell[203778, 6512, 572, 11, 134, "Input"],
Cell[204353, 6525, 239794, 4209, 154, 103537, 2522, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],
Cell[444162, 10737, 514, 9, 78, "Text"]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

