(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    205022,       7644]*)
(*NotebookOutlinePosition[    206035,       7678]*)
(*  CellTagsIndexPosition[    205991,       7674]*)
(*WindowFrame->Normal*)



Notebook[{
Cell["WALSH-HADAMARD TRANSFORM", "Title"],

Cell["Mariusz Jankowski", "Author"],

Cell["\<\
Department of Electrical Engineering
University of Southern Maine
mjkcc@usm.maine.edu\
\>", "Address"],

Cell[BoxData[
    \(<< ImageProcessing`\)], "Input",
  CellLabel->"In[2]:="],

Cell[CellGroupData[{

Cell["INTRODUCTION", "Section"],

Cell[TextData[{
  "Unlike the other well-known transforms, such as the DFT and DCT, the \
elements of the basis vectors of the Hadamard transform take binary values +1 \
and -1, only. They are therefore well suited for digital signal processing \
applications were computational simplicity is required. The basis vectors of \
the ",
  Cell[BoxData[
      \(TraditionalForm\`2\^n\)]],
  "-point Hadamard transform can be generated by sampling a class of \
functions called Walsh functions. For this reason the Hadamard transform is \
often called the Walsh-Hadamard transform (WHT).  The Walsh functions form a \
complete orthonormal basis for square integrable functions."
}], "Text"],

Cell[CellGroupData[{

Cell["ONE-DIMENSIONAL WALSH-HADAMARD TRANSFORM", "Section"],

Cell[" The symmetric form of the 1-D Hadamard transform is", "Text"],

Cell[TextData[{
  " ",
  Cell[BoxData[
      \(TraditionalForm
      \`X[k]\  = \ 
        1\/\@N\ \(\[Sum]\+\(n = 0\)\%\(N - 1\)x[n]\ 
              \((\(-1\))\)\^\(\[Sum]\+\(i = 0\)\%\(m - 1\)\ 
                  \(\(b\_i\)(n)\)\ \(\(b\_i\)(k)\)\ \)\)\)]],
  ",\t\tfor  ",
  Cell[BoxData[
      \(TraditionalForm\`k\  = \ 0, 1,  ... , N - 1\)]]
}], "NumberedEquation"],

Cell[TextData[{
  " ",
  Cell[BoxData[
      \(TraditionalForm
      \`x[n]\  = \ 
        1\/\@N\ \(\[Sum]\+\(n = 0\)\%\(N - 1\)X[n]\ 
              \((\(-1\))\)\^\(\[Sum]\+\(i = 0\)\%\(m - 1\)\ 
                  \(\(b\_i\)(n)\)\ \(\(b\_i\)(k)\)\ \)\)\)]],
  ",\t\tfor  ",
  Cell[BoxData[
      \(TraditionalForm\`n\  = \ 0, 1,  ... , N - 1\)]]
}], "NumberedEquation"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      FormBox[
        RowBox[{"N", " ", "=", " ", 
          FormBox[\(2\^m\),
            "TraditionalForm"]}], TraditionalForm]]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(b\_i\)(z)\ \)\)]],
  " is the ",
  StyleBox["i-th",
    FontSlant->"Italic"],
  " bit in the binary representation of ",
  StyleBox["z",
    FontSlant->"Italic"],
  ". The addition of the bits ",
  Cell[BoxData[
      \(TraditionalForm\`b\_i\)]],
  " in the exponent of (-1) is in modulo-2 arithmetic. Note thet the forward \
and inverse Hadamard transforms are identical. The basis signals of the \
Hadamard transform are defined by"
}], "Text"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm
    \`f(n, k)\  = \ 
      \((\(-1\))\)\^\(\[Sum]\+\(i = 0\)\%\(m - 1\)\ 
          \(\(b\_i\)(n)\)\ \(\(b\_i\)(k)\)\ \)\)]]], "NumberedEquation"],

Cell[TextData[{
  "The ",
  StyleBox["i-th",
    FontSlant->"Italic"],
  " bit of a binary reprsentation of an integer may be obtained using ",
  StyleBox["IntegerDigits", "Program"],
  ". The sum defines an inner product of two vectors of length m, whose \
elements are the binary digits of the m-bit binary representations of the \
integers ",
  StyleBox["n",
    FontSlant->"Italic"],
  " and ",
  StyleBox["k",
    FontSlant->"Italic"],
  ". The basis sequences may therefore be defined in the following way"
}], "Text"],

Cell[BoxData[
    \(f[n_, k_] := 
      \((\(-1\))\)^\((IntegerDigits[n, 2, 3] . IntegerDigits[k, 2, 3])\)\)], 
  "Input",
  CellLabel->"In[3]:="],

Cell[TextData[{
  "For ",
  Cell[BoxData[
      \(TraditionalForm\`N = 8\)]],
  " or equivalently ",
  Cell[BoxData[
      \(TraditionalForm\`m = 3\)]],
  ", the ",
  Cell[BoxData[
      \(TraditionalForm\`k = 2\)]],
  " basis sequence has the following values"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Table[f[n, 2], \ {n, 0, 7}]\)], "Input",
  CellLabel->"In[4]:="],

Cell[BoxData[
    \({1, 1, \(-1\), \(-1\), 1, 1, \(-1\), \(-1\)}\)], "Output",
  CellLabel->"Out[4]="]
}, Open  ]],

Cell[TextData[{
  "All the basis sequences of length ",
  Cell[BoxData[
      \(TraditionalForm\`N = 2\^n\)]],
  " can be obtained using the function ",
  StyleBox["HadamardKernel", "Program"],
  ". Below, we plot all members of the length ",
  Cell[BoxData[
      \(TraditionalForm\`N = 8\)]],
  " family of Hadamard basis sequences."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[
      GraphicsArray[
        Map[DiscretePlot[#\ , PlotType \[Rule] FlatTop, 
              DisplayFunction \[Rule] Identity]\ &\ , 
          Partition[HadamardKernel[8]\ \@8, 4], {2}]]]; \)\)], "Input",
  CellLabel->"In[10]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .30183 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0.00718644 0.238095 [
[ 0 0 0 0 ]
[ 1 .30183 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .30183 L
0 .30183 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.00718644 0.245293 0.144071 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.136054 0.309017 0.294302 [
[.15986 .29652 -3 -9 ]
[.15986 .29652 3 0 ]
[.29592 .29652 -3 -9 ]
[.29592 .29652 3 0 ]
[.43197 .29652 -3 -9 ]
[.43197 .29652 3 0 ]
[.56803 .29652 -3 -9 ]
[.56803 .29652 3 0 ]
[.70408 .29652 -3 -9 ]
[.70408 .29652 3 0 ]
[.84014 .29652 -3 -9 ]
[.84014 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 .01472 -12 -4.5 ]
[.01131 .01472 0 4.5 ]
[.01131 .16187 -24 -4.5 ]
[.01131 .16187 0 4.5 ]
[.01131 .45617 -18 -4.5 ]
[.01131 .45617 0 4.5 ]
[.01131 .60332 -6 -4.5 ]
[.01131 .60332 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.15986 .30902 m
.15986 .31527 L
s
[(1)] .15986 .29652 0 1 Mshowa
.29592 .30902 m
.29592 .31527 L
s
[(2)] .29592 .29652 0 1 Mshowa
.43197 .30902 m
.43197 .31527 L
s
[(3)] .43197 .29652 0 1 Mshowa
.56803 .30902 m
.56803 .31527 L
s
[(4)] .56803 .29652 0 1 Mshowa
.70408 .30902 m
.70408 .31527 L
s
[(5)] .70408 .29652 0 1 Mshowa
.84014 .30902 m
.84014 .31527 L
s
[(6)] .84014 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(7)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05102 .30902 m
.05102 .31277 L
s
.07823 .30902 m
.07823 .31277 L
s
.10544 .30902 m
.10544 .31277 L
s
.13265 .30902 m
.13265 .31277 L
s
.18707 .30902 m
.18707 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.2415 .30902 m
.2415 .31277 L
s
.26871 .30902 m
.26871 .31277 L
s
.32313 .30902 m
.32313 .31277 L
s
.35034 .30902 m
.35034 .31277 L
s
.37755 .30902 m
.37755 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45918 .30902 m
.45918 .31277 L
s
.48639 .30902 m
.48639 .31277 L
s
.51361 .30902 m
.51361 .31277 L
s
.54082 .30902 m
.54082 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62245 .30902 m
.62245 .31277 L
s
.64966 .30902 m
.64966 .31277 L
s
.67687 .30902 m
.67687 .31277 L
s
.73129 .30902 m
.73129 .31277 L
s
.7585 .30902 m
.7585 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.81293 .30902 m
.81293 .31277 L
s
.86735 .30902 m
.86735 .31277 L
s
.89456 .30902 m
.89456 .31277 L
s
.92177 .30902 m
.92177 .31277 L
s
.94898 .30902 m
.94898 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 .01472 m
.03006 .01472 L
s
[(-1)] .01131 .01472 1 0 Mshowa
.02381 .16187 m
.03006 .16187 L
s
[(-0.5)] .01131 .16187 1 0 Mshowa
.02381 .45617 m
.03006 .45617 L
s
[(0.5)] .01131 .45617 1 0 Mshowa
.02381 .60332 m
.03006 .60332 L
s
[(1)] .01131 .60332 1 0 Mshowa
.125 Mabswid
.02381 .04415 m
.02756 .04415 L
s
.02381 .07358 m
.02756 .07358 L
s
.02381 .10301 m
.02756 .10301 L
s
.02381 .13244 m
.02756 .13244 L
s
.02381 .1913 m
.02756 .1913 L
s
.02381 .22073 m
.02756 .22073 L
s
.02381 .25016 m
.02756 .25016 L
s
.02381 .27959 m
.02756 .27959 L
s
.02381 .33845 m
.02756 .33845 L
s
.02381 .36788 m
.02756 .36788 L
s
.02381 .39731 m
.02756 .39731 L
s
.02381 .42674 m
.02756 .42674 L
s
.02381 .4856 m
.02756 .4856 L
s
.02381 .51503 m
.02756 .51503 L
s
.02381 .54446 m
.02756 .54446 L
s
.02381 .57389 m
.02756 .57389 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.00768 w
.02381 .60332 m
.15986 .60332 L
s
.15986 .60332 m
.15986 .60332 L
s
.15986 .60332 m
.29592 .60332 L
s
.29592 .60332 m
.29592 .60332 L
s
.29592 .60332 m
.43197 .60332 L
s
.43197 .60332 m
.43197 .60332 L
s
.43197 .60332 m
.56803 .60332 L
s
.56803 .01472 m
.56803 .60332 L
s
.56803 .01472 m
.70408 .01472 L
s
.70408 .01472 m
.70408 .01472 L
s
.70408 .01472 m
.84014 .01472 L
s
.84014 .01472 m
.84014 .01472 L
s
.84014 .01472 m
.97619 .01472 L
s
.97619 .01472 m
.97619 .01472 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.267442 0.00718644 0.488926 0.144071 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.136054 0.309017 0.294302 [
[.15986 .29652 -3 -9 ]
[.15986 .29652 3 0 ]
[.29592 .29652 -3 -9 ]
[.29592 .29652 3 0 ]
[.43197 .29652 -3 -9 ]
[.43197 .29652 3 0 ]
[.56803 .29652 -3 -9 ]
[.56803 .29652 3 0 ]
[.70408 .29652 -3 -9 ]
[.70408 .29652 3 0 ]
[.84014 .29652 -3 -9 ]
[.84014 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 .01472 -12 -4.5 ]
[.01131 .01472 0 4.5 ]
[.01131 .16187 -24 -4.5 ]
[.01131 .16187 0 4.5 ]
[.01131 .45617 -18 -4.5 ]
[.01131 .45617 0 4.5 ]
[.01131 .60332 -6 -4.5 ]
[.01131 .60332 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.15986 .30902 m
.15986 .31527 L
s
[(1)] .15986 .29652 0 1 Mshowa
.29592 .30902 m
.29592 .31527 L
s
[(2)] .29592 .29652 0 1 Mshowa
.43197 .30902 m
.43197 .31527 L
s
[(3)] .43197 .29652 0 1 Mshowa
.56803 .30902 m
.56803 .31527 L
s
[(4)] .56803 .29652 0 1 Mshowa
.70408 .30902 m
.70408 .31527 L
s
[(5)] .70408 .29652 0 1 Mshowa
.84014 .30902 m
.84014 .31527 L
s
[(6)] .84014 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(7)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05102 .30902 m
.05102 .31277 L
s
.07823 .30902 m
.07823 .31277 L
s
.10544 .30902 m
.10544 .31277 L
s
.13265 .30902 m
.13265 .31277 L
s
.18707 .30902 m
.18707 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.2415 .30902 m
.2415 .31277 L
s
.26871 .30902 m
.26871 .31277 L
s
.32313 .30902 m
.32313 .31277 L
s
.35034 .30902 m
.35034 .31277 L
s
.37755 .30902 m
.37755 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45918 .30902 m
.45918 .31277 L
s
.48639 .30902 m
.48639 .31277 L
s
.51361 .30902 m
.51361 .31277 L
s
.54082 .30902 m
.54082 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62245 .30902 m
.62245 .31277 L
s
.64966 .30902 m
.64966 .31277 L
s
.67687 .30902 m
.67687 .31277 L
s
.73129 .30902 m
.73129 .31277 L
s
.7585 .30902 m
.7585 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.81293 .30902 m
.81293 .31277 L
s
.86735 .30902 m
.86735 .31277 L
s
.89456 .30902 m
.89456 .31277 L
s
.92177 .30902 m
.92177 .31277 L
s
.94898 .30902 m
.94898 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 .01472 m
.03006 .01472 L
s
[(-1)] .01131 .01472 1 0 Mshowa
.02381 .16187 m
.03006 .16187 L
s
[(-0.5)] .01131 .16187 1 0 Mshowa
.02381 .45617 m
.03006 .45617 L
s
[(0.5)] .01131 .45617 1 0 Mshowa
.02381 .60332 m
.03006 .60332 L
s
[(1)] .01131 .60332 1 0 Mshowa
.125 Mabswid
.02381 .04415 m
.02756 .04415 L
s
.02381 .07358 m
.02756 .07358 L
s
.02381 .10301 m
.02756 .10301 L
s
.02381 .13244 m
.02756 .13244 L
s
.02381 .1913 m
.02756 .1913 L
s
.02381 .22073 m
.02756 .22073 L
s
.02381 .25016 m
.02756 .25016 L
s
.02381 .27959 m
.02756 .27959 L
s
.02381 .33845 m
.02756 .33845 L
s
.02381 .36788 m
.02756 .36788 L
s
.02381 .39731 m
.02756 .39731 L
s
.02381 .42674 m
.02756 .42674 L
s
.02381 .4856 m
.02756 .4856 L
s
.02381 .51503 m
.02756 .51503 L
s
.02381 .54446 m
.02756 .54446 L
s
.02381 .57389 m
.02756 .57389 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.00768 w
.02381 .60332 m
.15986 .60332 L
s
.15986 .01472 m
.15986 .60332 L
s
.15986 .01472 m
.29592 .01472 L
s
.29592 .60332 m
.29592 .01472 L
s
.29592 .60332 m
.43197 .60332 L
s
.43197 .01472 m
.43197 .60332 L
s
.43197 .01472 m
.56803 .01472 L
s
.56803 .01472 m
.56803 .01472 L
s
.56803 .01472 m
.70408 .01472 L
s
.70408 .60332 m
.70408 .01472 L
s
.70408 .60332 m
.84014 .60332 L
s
.84014 .01472 m
.84014 .60332 L
s
.84014 .01472 m
.97619 .01472 L
s
.97619 .60332 m
.97619 .01472 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.511074 0.00718644 0.732558 0.144071 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.136054 0.309017 0.294302 [
[.15986 .29652 -3 -9 ]
[.15986 .29652 3 0 ]
[.29592 .29652 -3 -9 ]
[.29592 .29652 3 0 ]
[.43197 .29652 -3 -9 ]
[.43197 .29652 3 0 ]
[.56803 .29652 -3 -9 ]
[.56803 .29652 3 0 ]
[.70408 .29652 -3 -9 ]
[.70408 .29652 3 0 ]
[.84014 .29652 -3 -9 ]
[.84014 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 .01472 -12 -4.5 ]
[.01131 .01472 0 4.5 ]
[.01131 .16187 -24 -4.5 ]
[.01131 .16187 0 4.5 ]
[.01131 .45617 -18 -4.5 ]
[.01131 .45617 0 4.5 ]
[.01131 .60332 -6 -4.5 ]
[.01131 .60332 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.15986 .30902 m
.15986 .31527 L
s
[(1)] .15986 .29652 0 1 Mshowa
.29592 .30902 m
.29592 .31527 L
s
[(2)] .29592 .29652 0 1 Mshowa
.43197 .30902 m
.43197 .31527 L
s
[(3)] .43197 .29652 0 1 Mshowa
.56803 .30902 m
.56803 .31527 L
s
[(4)] .56803 .29652 0 1 Mshowa
.70408 .30902 m
.70408 .31527 L
s
[(5)] .70408 .29652 0 1 Mshowa
.84014 .30902 m
.84014 .31527 L
s
[(6)] .84014 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(7)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05102 .30902 m
.05102 .31277 L
s
.07823 .30902 m
.07823 .31277 L
s
.10544 .30902 m
.10544 .31277 L
s
.13265 .30902 m
.13265 .31277 L
s
.18707 .30902 m
.18707 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.2415 .30902 m
.2415 .31277 L
s
.26871 .30902 m
.26871 .31277 L
s
.32313 .30902 m
.32313 .31277 L
s
.35034 .30902 m
.35034 .31277 L
s
.37755 .30902 m
.37755 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45918 .30902 m
.45918 .31277 L
s
.48639 .30902 m
.48639 .31277 L
s
.51361 .30902 m
.51361 .31277 L
s
.54082 .30902 m
.54082 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62245 .30902 m
.62245 .31277 L
s
.64966 .30902 m
.64966 .31277 L
s
.67687 .30902 m
.67687 .31277 L
s
.73129 .30902 m
.73129 .31277 L
s
.7585 .30902 m
.7585 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.81293 .30902 m
.81293 .31277 L
s
.86735 .30902 m
.86735 .31277 L
s
.89456 .30902 m
.89456 .31277 L
s
.92177 .30902 m
.92177 .31277 L
s
.94898 .30902 m
.94898 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 .01472 m
.03006 .01472 L
s
[(-1)] .01131 .01472 1 0 Mshowa
.02381 .16187 m
.03006 .16187 L
s
[(-0.5)] .01131 .16187 1 0 Mshowa
.02381 .45617 m
.03006 .45617 L
s
[(0.5)] .01131 .45617 1 0 Mshowa
.02381 .60332 m
.03006 .60332 L
s
[(1)] .01131 .60332 1 0 Mshowa
.125 Mabswid
.02381 .04415 m
.02756 .04415 L
s
.02381 .07358 m
.02756 .07358 L
s
.02381 .10301 m
.02756 .10301 L
s
.02381 .13244 m
.02756 .13244 L
s
.02381 .1913 m
.02756 .1913 L
s
.02381 .22073 m
.02756 .22073 L
s
.02381 .25016 m
.02756 .25016 L
s
.02381 .27959 m
.02756 .27959 L
s
.02381 .33845 m
.02756 .33845 L
s
.02381 .36788 m
.02756 .36788 L
s
.02381 .39731 m
.02756 .39731 L
s
.02381 .42674 m
.02756 .42674 L
s
.02381 .4856 m
.02756 .4856 L
s
.02381 .51503 m
.02756 .51503 L
s
.02381 .54446 m
.02756 .54446 L
s
.02381 .57389 m
.02756 .57389 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.00768 w
.02381 .60332 m
.15986 .60332 L
s
.15986 .60332 m
.15986 .60332 L
s
.15986 .60332 m
.29592 .60332 L
s
.29592 .01472 m
.29592 .60332 L
s
.29592 .01472 m
.43197 .01472 L
s
.43197 .01472 m
.43197 .01472 L
s
.43197 .01472 m
.56803 .01472 L
s
.56803 .01472 m
.56803 .01472 L
s
.56803 .01472 m
.70408 .01472 L
s
.70408 .01472 m
.70408 .01472 L
s
.70408 .01472 m
.84014 .01472 L
s
.84014 .60332 m
.84014 .01472 L
s
.84014 .60332 m
.97619 .60332 L
s
.97619 .60332 m
.97619 .60332 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.754707 0.00718644 0.97619 0.144071 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.136054 0.309017 0.294302 [
[.15986 .29652 -3 -9 ]
[.15986 .29652 3 0 ]
[.29592 .29652 -3 -9 ]
[.29592 .29652 3 0 ]
[.43197 .29652 -3 -9 ]
[.43197 .29652 3 0 ]
[.56803 .29652 -3 -9 ]
[.56803 .29652 3 0 ]
[.70408 .29652 -3 -9 ]
[.70408 .29652 3 0 ]
[.84014 .29652 -3 -9 ]
[.84014 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 .01472 -12 -4.5 ]
[.01131 .01472 0 4.5 ]
[.01131 .16187 -24 -4.5 ]
[.01131 .16187 0 4.5 ]
[.01131 .45617 -18 -4.5 ]
[.01131 .45617 0 4.5 ]
[.01131 .60332 -6 -4.5 ]
[.01131 .60332 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.15986 .30902 m
.15986 .31527 L
s
[(1)] .15986 .29652 0 1 Mshowa
.29592 .30902 m
.29592 .31527 L
s
[(2)] .29592 .29652 0 1 Mshowa
.43197 .30902 m
.43197 .31527 L
s
[(3)] .43197 .29652 0 1 Mshowa
.56803 .30902 m
.56803 .31527 L
s
[(4)] .56803 .29652 0 1 Mshowa
.70408 .30902 m
.70408 .31527 L
s
[(5)] .70408 .29652 0 1 Mshowa
.84014 .30902 m
.84014 .31527 L
s
[(6)] .84014 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(7)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05102 .30902 m
.05102 .31277 L
s
.07823 .30902 m
.07823 .31277 L
s
.10544 .30902 m
.10544 .31277 L
s
.13265 .30902 m
.13265 .31277 L
s
.18707 .30902 m
.18707 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.2415 .30902 m
.2415 .31277 L
s
.26871 .30902 m
.26871 .31277 L
s
.32313 .30902 m
.32313 .31277 L
s
.35034 .30902 m
.35034 .31277 L
s
.37755 .30902 m
.37755 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45918 .30902 m
.45918 .31277 L
s
.48639 .30902 m
.48639 .31277 L
s
.51361 .30902 m
.51361 .31277 L
s
.54082 .30902 m
.54082 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62245 .30902 m
.62245 .31277 L
s
.64966 .30902 m
.64966 .31277 L
s
.67687 .30902 m
.67687 .31277 L
s
.73129 .30902 m
.73129 .31277 L
s
.7585 .30902 m
.7585 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.81293 .30902 m
.81293 .31277 L
s
.86735 .30902 m
.86735 .31277 L
s
.89456 .30902 m
.89456 .31277 L
s
.92177 .30902 m
.92177 .31277 L
s
.94898 .30902 m
.94898 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 .01472 m
.03006 .01472 L
s
[(-1)] .01131 .01472 1 0 Mshowa
.02381 .16187 m
.03006 .16187 L
s
[(-0.5)] .01131 .16187 1 0 Mshowa
.02381 .45617 m
.03006 .45617 L
s
[(0.5)] .01131 .45617 1 0 Mshowa
.02381 .60332 m
.03006 .60332 L
s
[(1)] .01131 .60332 1 0 Mshowa
.125 Mabswid
.02381 .04415 m
.02756 .04415 L
s
.02381 .07358 m
.02756 .07358 L
s
.02381 .10301 m
.02756 .10301 L
s
.02381 .13244 m
.02756 .13244 L
s
.02381 .1913 m
.02756 .1913 L
s
.02381 .22073 m
.02756 .22073 L
s
.02381 .25016 m
.02756 .25016 L
s
.02381 .27959 m
.02756 .27959 L
s
.02381 .33845 m
.02756 .33845 L
s
.02381 .36788 m
.02756 .36788 L
s
.02381 .39731 m
.02756 .39731 L
s
.02381 .42674 m
.02756 .42674 L
s
.02381 .4856 m
.02756 .4856 L
s
.02381 .51503 m
.02756 .51503 L
s
.02381 .54446 m
.02756 .54446 L
s
.02381 .57389 m
.02756 .57389 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.00768 w
.02381 .60332 m
.15986 .60332 L
s
.15986 .01472 m
.15986 .60332 L
s
.15986 .01472 m
.29592 .01472 L
s
.29592 .01472 m
.29592 .01472 L
s
.29592 .01472 m
.43197 .01472 L
s
.43197 .60332 m
.43197 .01472 L
s
.43197 .60332 m
.56803 .60332 L
s
.56803 .01472 m
.56803 .60332 L
s
.56803 .01472 m
.70408 .01472 L
s
.70408 .60332 m
.70408 .01472 L
s
.70408 .60332 m
.84014 .60332 L
s
.84014 .60332 m
.84014 .60332 L
s
.84014 .60332 m
.97619 .60332 L
s
.97619 .01472 m
.97619 .60332 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.15776 0.245293 0.294644 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.136054 0.0147151 0.294302 [
[.15986 .00222 -3 -9 ]
[.15986 .00222 3 0 ]
[.29592 .00222 -3 -9 ]
[.29592 .00222 3 0 ]
[.43197 .00222 -3 -9 ]
[.43197 .00222 3 0 ]
[.56803 .00222 -3 -9 ]
[.56803 .00222 3 0 ]
[.70408 .00222 -3 -9 ]
[.70408 .00222 3 0 ]
[.84014 .00222 -3 -9 ]
[.84014 .00222 3 0 ]
[.97619 .00222 -3 -9 ]
[.97619 .00222 3 0 ]
[.01131 .16187 -18 -4.5 ]
[.01131 .16187 0 4.5 ]
[.01131 .30902 -6 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .45617 -18 -4.5 ]
[.01131 .45617 0 4.5 ]
[.01131 .60332 -6 -4.5 ]
[.01131 .60332 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.15986 .01472 m
.15986 .02097 L
s
[(1)] .15986 .00222 0 1 Mshowa
.29592 .01472 m
.29592 .02097 L
s
[(2)] .29592 .00222 0 1 Mshowa
.43197 .01472 m
.43197 .02097 L
s
[(3)] .43197 .00222 0 1 Mshowa
.56803 .01472 m
.56803 .02097 L
s
[(4)] .56803 .00222 0 1 Mshowa
.70408 .01472 m
.70408 .02097 L
s
[(5)] .70408 .00222 0 1 Mshowa
.84014 .01472 m
.84014 .02097 L
s
[(6)] .84014 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(7)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.05102 .01472 m
.05102 .01847 L
s
.07823 .01472 m
.07823 .01847 L
s
.10544 .01472 m
.10544 .01847 L
s
.13265 .01472 m
.13265 .01847 L
s
.18707 .01472 m
.18707 .01847 L
s
.21429 .01472 m
.21429 .01847 L
s
.2415 .01472 m
.2415 .01847 L
s
.26871 .01472 m
.26871 .01847 L
s
.32313 .01472 m
.32313 .01847 L
s
.35034 .01472 m
.35034 .01847 L
s
.37755 .01472 m
.37755 .01847 L
s
.40476 .01472 m
.40476 .01847 L
s
.45918 .01472 m
.45918 .01847 L
s
.48639 .01472 m
.48639 .01847 L
s
.51361 .01472 m
.51361 .01847 L
s
.54082 .01472 m
.54082 .01847 L
s
.59524 .01472 m
.59524 .01847 L
s
.62245 .01472 m
.62245 .01847 L
s
.64966 .01472 m
.64966 .01847 L
s
.67687 .01472 m
.67687 .01847 L
s
.73129 .01472 m
.73129 .01847 L
s
.7585 .01472 m
.7585 .01847 L
s
.78571 .01472 m
.78571 .01847 L
s
.81293 .01472 m
.81293 .01847 L
s
.86735 .01472 m
.86735 .01847 L
s
.89456 .01472 m
.89456 .01847 L
s
.92177 .01472 m
.92177 .01847 L
s
.94898 .01472 m
.94898 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02381 .16187 m
.03006 .16187 L
s
[(0.5)] .01131 .16187 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(1)] .01131 .30902 1 0 Mshowa
.02381 .45617 m
.03006 .45617 L
s
[(1.5)] .01131 .45617 1 0 Mshowa
.02381 .60332 m
.03006 .60332 L
s
[(2)] .01131 .60332 1 0 Mshowa
.125 Mabswid
.02381 .04415 m
.02756 .04415 L
s
.02381 .07358 m
.02756 .07358 L
s
.02381 .10301 m
.02756 .10301 L
s
.02381 .13244 m
.02756 .13244 L
s
.02381 .1913 m
.02756 .1913 L
s
.02381 .22073 m
.02756 .22073 L
s
.02381 .25016 m
.02756 .25016 L
s
.02381 .27959 m
.02756 .27959 L
s
.02381 .33845 m
.02756 .33845 L
s
.02381 .36788 m
.02756 .36788 L
s
.02381 .39731 m
.02756 .39731 L
s
.02381 .42674 m
.02756 .42674 L
s
.02381 .4856 m
.02756 .4856 L
s
.02381 .51503 m
.02756 .51503 L
s
.02381 .54446 m
.02756 .54446 L
s
.02381 .57389 m
.02756 .57389 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.00768 w
.02381 .30902 m
.15986 .30902 L
s
.15986 .30902 m
.15986 .30902 L
s
.15986 .30902 m
.29592 .30902 L
s
.29592 .30902 m
.29592 .30902 L
s
.29592 .30902 m
.43197 .30902 L
s
.43197 .30902 m
.43197 .30902 L
s
.43197 .30902 m
.56803 .30902 L
s
.56803 .30902 m
.56803 .30902 L
s
.56803 .30902 m
.70408 .30902 L
s
.70408 .30902 m
.70408 .30902 L
s
.70408 .30902 m
.84014 .30902 L
s
.84014 .30902 m
.84014 .30902 L
s
.84014 .30902 m
.97619 .30902 L
s
.97619 .30902 m
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.267442 0.15776 0.488926 0.294644 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.136054 0.309017 0.294302 [
[.15986 .29652 -3 -9 ]
[.15986 .29652 3 0 ]
[.29592 .29652 -3 -9 ]
[.29592 .29652 3 0 ]
[.43197 .29652 -3 -9 ]
[.43197 .29652 3 0 ]
[.56803 .29652 -3 -9 ]
[.56803 .29652 3 0 ]
[.70408 .29652 -3 -9 ]
[.70408 .29652 3 0 ]
[.84014 .29652 -3 -9 ]
[.84014 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 .01472 -12 -4.5 ]
[.01131 .01472 0 4.5 ]
[.01131 .16187 -24 -4.5 ]
[.01131 .16187 0 4.5 ]
[.01131 .45617 -18 -4.5 ]
[.01131 .45617 0 4.5 ]
[.01131 .60332 -6 -4.5 ]
[.01131 .60332 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.15986 .30902 m
.15986 .31527 L
s
[(1)] .15986 .29652 0 1 Mshowa
.29592 .30902 m
.29592 .31527 L
s
[(2)] .29592 .29652 0 1 Mshowa
.43197 .30902 m
.43197 .31527 L
s
[(3)] .43197 .29652 0 1 Mshowa
.56803 .30902 m
.56803 .31527 L
s
[(4)] .56803 .29652 0 1 Mshowa
.70408 .30902 m
.70408 .31527 L
s
[(5)] .70408 .29652 0 1 Mshowa
.84014 .30902 m
.84014 .31527 L
s
[(6)] .84014 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(7)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05102 .30902 m
.05102 .31277 L
s
.07823 .30902 m
.07823 .31277 L
s
.10544 .30902 m
.10544 .31277 L
s
.13265 .30902 m
.13265 .31277 L
s
.18707 .30902 m
.18707 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.2415 .30902 m
.2415 .31277 L
s
.26871 .30902 m
.26871 .31277 L
s
.32313 .30902 m
.32313 .31277 L
s
.35034 .30902 m
.35034 .31277 L
s
.37755 .30902 m
.37755 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45918 .30902 m
.45918 .31277 L
s
.48639 .30902 m
.48639 .31277 L
s
.51361 .30902 m
.51361 .31277 L
s
.54082 .30902 m
.54082 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62245 .30902 m
.62245 .31277 L
s
.64966 .30902 m
.64966 .31277 L
s
.67687 .30902 m
.67687 .31277 L
s
.73129 .30902 m
.73129 .31277 L
s
.7585 .30902 m
.7585 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.81293 .30902 m
.81293 .31277 L
s
.86735 .30902 m
.86735 .31277 L
s
.89456 .30902 m
.89456 .31277 L
s
.92177 .30902 m
.92177 .31277 L
s
.94898 .30902 m
.94898 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 .01472 m
.03006 .01472 L
s
[(-1)] .01131 .01472 1 0 Mshowa
.02381 .16187 m
.03006 .16187 L
s
[(-0.5)] .01131 .16187 1 0 Mshowa
.02381 .45617 m
.03006 .45617 L
s
[(0.5)] .01131 .45617 1 0 Mshowa
.02381 .60332 m
.03006 .60332 L
s
[(1)] .01131 .60332 1 0 Mshowa
.125 Mabswid
.02381 .04415 m
.02756 .04415 L
s
.02381 .07358 m
.02756 .07358 L
s
.02381 .10301 m
.02756 .10301 L
s
.02381 .13244 m
.02756 .13244 L
s
.02381 .1913 m
.02756 .1913 L
s
.02381 .22073 m
.02756 .22073 L
s
.02381 .25016 m
.02756 .25016 L
s
.02381 .27959 m
.02756 .27959 L
s
.02381 .33845 m
.02756 .33845 L
s
.02381 .36788 m
.02756 .36788 L
s
.02381 .39731 m
.02756 .39731 L
s
.02381 .42674 m
.02756 .42674 L
s
.02381 .4856 m
.02756 .4856 L
s
.02381 .51503 m
.02756 .51503 L
s
.02381 .54446 m
.02756 .54446 L
s
.02381 .57389 m
.02756 .57389 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.00768 w
.02381 .60332 m
.15986 .60332 L
s
.15986 .01472 m
.15986 .60332 L
s
.15986 .01472 m
.29592 .01472 L
s
.29592 .60332 m
.29592 .01472 L
s
.29592 .60332 m
.43197 .60332 L
s
.43197 .01472 m
.43197 .60332 L
s
.43197 .01472 m
.56803 .01472 L
s
.56803 .60332 m
.56803 .01472 L
s
.56803 .60332 m
.70408 .60332 L
s
.70408 .01472 m
.70408 .60332 L
s
.70408 .01472 m
.84014 .01472 L
s
.84014 .60332 m
.84014 .01472 L
s
.84014 .60332 m
.97619 .60332 L
s
.97619 .01472 m
.97619 .60332 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.511074 0.15776 0.732558 0.294644 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.136054 0.309017 0.294302 [
[.15986 .29652 -3 -9 ]
[.15986 .29652 3 0 ]
[.29592 .29652 -3 -9 ]
[.29592 .29652 3 0 ]
[.43197 .29652 -3 -9 ]
[.43197 .29652 3 0 ]
[.56803 .29652 -3 -9 ]
[.56803 .29652 3 0 ]
[.70408 .29652 -3 -9 ]
[.70408 .29652 3 0 ]
[.84014 .29652 -3 -9 ]
[.84014 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 .01472 -12 -4.5 ]
[.01131 .01472 0 4.5 ]
[.01131 .16187 -24 -4.5 ]
[.01131 .16187 0 4.5 ]
[.01131 .45617 -18 -4.5 ]
[.01131 .45617 0 4.5 ]
[.01131 .60332 -6 -4.5 ]
[.01131 .60332 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.15986 .30902 m
.15986 .31527 L
s
[(1)] .15986 .29652 0 1 Mshowa
.29592 .30902 m
.29592 .31527 L
s
[(2)] .29592 .29652 0 1 Mshowa
.43197 .30902 m
.43197 .31527 L
s
[(3)] .43197 .29652 0 1 Mshowa
.56803 .30902 m
.56803 .31527 L
s
[(4)] .56803 .29652 0 1 Mshowa
.70408 .30902 m
.70408 .31527 L
s
[(5)] .70408 .29652 0 1 Mshowa
.84014 .30902 m
.84014 .31527 L
s
[(6)] .84014 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(7)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05102 .30902 m
.05102 .31277 L
s
.07823 .30902 m
.07823 .31277 L
s
.10544 .30902 m
.10544 .31277 L
s
.13265 .30902 m
.13265 .31277 L
s
.18707 .30902 m
.18707 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.2415 .30902 m
.2415 .31277 L
s
.26871 .30902 m
.26871 .31277 L
s
.32313 .30902 m
.32313 .31277 L
s
.35034 .30902 m
.35034 .31277 L
s
.37755 .30902 m
.37755 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45918 .30902 m
.45918 .31277 L
s
.48639 .30902 m
.48639 .31277 L
s
.51361 .30902 m
.51361 .31277 L
s
.54082 .30902 m
.54082 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62245 .30902 m
.62245 .31277 L
s
.64966 .30902 m
.64966 .31277 L
s
.67687 .30902 m
.67687 .31277 L
s
.73129 .30902 m
.73129 .31277 L
s
.7585 .30902 m
.7585 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.81293 .30902 m
.81293 .31277 L
s
.86735 .30902 m
.86735 .31277 L
s
.89456 .30902 m
.89456 .31277 L
s
.92177 .30902 m
.92177 .31277 L
s
.94898 .30902 m
.94898 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 .01472 m
.03006 .01472 L
s
[(-1)] .01131 .01472 1 0 Mshowa
.02381 .16187 m
.03006 .16187 L
s
[(-0.5)] .01131 .16187 1 0 Mshowa
.02381 .45617 m
.03006 .45617 L
s
[(0.5)] .01131 .45617 1 0 Mshowa
.02381 .60332 m
.03006 .60332 L
s
[(1)] .01131 .60332 1 0 Mshowa
.125 Mabswid
.02381 .04415 m
.02756 .04415 L
s
.02381 .07358 m
.02756 .07358 L
s
.02381 .10301 m
.02756 .10301 L
s
.02381 .13244 m
.02756 .13244 L
s
.02381 .1913 m
.02756 .1913 L
s
.02381 .22073 m
.02756 .22073 L
s
.02381 .25016 m
.02756 .25016 L
s
.02381 .27959 m
.02756 .27959 L
s
.02381 .33845 m
.02756 .33845 L
s
.02381 .36788 m
.02756 .36788 L
s
.02381 .39731 m
.02756 .39731 L
s
.02381 .42674 m
.02756 .42674 L
s
.02381 .4856 m
.02756 .4856 L
s
.02381 .51503 m
.02756 .51503 L
s
.02381 .54446 m
.02756 .54446 L
s
.02381 .57389 m
.02756 .57389 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.00768 w
.02381 .60332 m
.15986 .60332 L
s
.15986 .60332 m
.15986 .60332 L
s
.15986 .60332 m
.29592 .60332 L
s
.29592 .01472 m
.29592 .60332 L
s
.29592 .01472 m
.43197 .01472 L
s
.43197 .01472 m
.43197 .01472 L
s
.43197 .01472 m
.56803 .01472 L
s
.56803 .60332 m
.56803 .01472 L
s
.56803 .60332 m
.70408 .60332 L
s
.70408 .60332 m
.70408 .60332 L
s
.70408 .60332 m
.84014 .60332 L
s
.84014 .01472 m
.84014 .60332 L
s
.84014 .01472 m
.97619 .01472 L
s
.97619 .01472 m
.97619 .01472 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.754707 0.15776 0.97619 0.294644 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.136054 0.309017 0.294302 [
[.15986 .29652 -3 -9 ]
[.15986 .29652 3 0 ]
[.29592 .29652 -3 -9 ]
[.29592 .29652 3 0 ]
[.43197 .29652 -3 -9 ]
[.43197 .29652 3 0 ]
[.56803 .29652 -3 -9 ]
[.56803 .29652 3 0 ]
[.70408 .29652 -3 -9 ]
[.70408 .29652 3 0 ]
[.84014 .29652 -3 -9 ]
[.84014 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 .01472 -12 -4.5 ]
[.01131 .01472 0 4.5 ]
[.01131 .16187 -24 -4.5 ]
[.01131 .16187 0 4.5 ]
[.01131 .45617 -18 -4.5 ]
[.01131 .45617 0 4.5 ]
[.01131 .60332 -6 -4.5 ]
[.01131 .60332 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.15986 .30902 m
.15986 .31527 L
s
[(1)] .15986 .29652 0 1 Mshowa
.29592 .30902 m
.29592 .31527 L
s
[(2)] .29592 .29652 0 1 Mshowa
.43197 .30902 m
.43197 .31527 L
s
[(3)] .43197 .29652 0 1 Mshowa
.56803 .30902 m
.56803 .31527 L
s
[(4)] .56803 .29652 0 1 Mshowa
.70408 .30902 m
.70408 .31527 L
s
[(5)] .70408 .29652 0 1 Mshowa
.84014 .30902 m
.84014 .31527 L
s
[(6)] .84014 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(7)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05102 .30902 m
.05102 .31277 L
s
.07823 .30902 m
.07823 .31277 L
s
.10544 .30902 m
.10544 .31277 L
s
.13265 .30902 m
.13265 .31277 L
s
.18707 .30902 m
.18707 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.2415 .30902 m
.2415 .31277 L
s
.26871 .30902 m
.26871 .31277 L
s
.32313 .30902 m
.32313 .31277 L
s
.35034 .30902 m
.35034 .31277 L
s
.37755 .30902 m
.37755 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45918 .30902 m
.45918 .31277 L
s
.48639 .30902 m
.48639 .31277 L
s
.51361 .30902 m
.51361 .31277 L
s
.54082 .30902 m
.54082 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62245 .30902 m
.62245 .31277 L
s
.64966 .30902 m
.64966 .31277 L
s
.67687 .30902 m
.67687 .31277 L
s
.73129 .30902 m
.73129 .31277 L
s
.7585 .30902 m
.7585 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.81293 .30902 m
.81293 .31277 L
s
.86735 .30902 m
.86735 .31277 L
s
.89456 .30902 m
.89456 .31277 L
s
.92177 .30902 m
.92177 .31277 L
s
.94898 .30902 m
.94898 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 .01472 m
.03006 .01472 L
s
[(-1)] .01131 .01472 1 0 Mshowa
.02381 .16187 m
.03006 .16187 L
s
[(-0.5)] .01131 .16187 1 0 Mshowa
.02381 .45617 m
.03006 .45617 L
s
[(0.5)] .01131 .45617 1 0 Mshowa
.02381 .60332 m
.03006 .60332 L
s
[(1)] .01131 .60332 1 0 Mshowa
.125 Mabswid
.02381 .04415 m
.02756 .04415 L
s
.02381 .07358 m
.02756 .07358 L
s
.02381 .10301 m
.02756 .10301 L
s
.02381 .13244 m
.02756 .13244 L
s
.02381 .1913 m
.02756 .1913 L
s
.02381 .22073 m
.02756 .22073 L
s
.02381 .25016 m
.02756 .25016 L
s
.02381 .27959 m
.02756 .27959 L
s
.02381 .33845 m
.02756 .33845 L
s
.02381 .36788 m
.02756 .36788 L
s
.02381 .39731 m
.02756 .39731 L
s
.02381 .42674 m
.02756 .42674 L
s
.02381 .4856 m
.02756 .4856 L
s
.02381 .51503 m
.02756 .51503 L
s
.02381 .54446 m
.02756 .54446 L
s
.02381 .57389 m
.02756 .57389 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.00768 w
.02381 .60332 m
.15986 .60332 L
s
.15986 .01472 m
.15986 .60332 L
s
.15986 .01472 m
.29592 .01472 L
s
.29592 .01472 m
.29592 .01472 L
s
.29592 .01472 m
.43197 .01472 L
s
.43197 .60332 m
.43197 .01472 L
s
.43197 .60332 m
.56803 .60332 L
s
.56803 .60332 m
.56803 .60332 L
s
.56803 .60332 m
.70408 .60332 L
s
.70408 .01472 m
.70408 .60332 L
s
.70408 .01472 m
.84014 .01472 L
s
.84014 .01472 m
.84014 .01472 L
s
.84014 .01472 m
.97619 .01472 L
s
.97619 .60332 m
.97619 .01472 L
s
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[10]:=",
  ImageSize->{438.75, 132.375},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006f0000Q1000`40O003h00Oogoo]goo003oOong
Ool00?mookMoo`00ogoo]goo003oOongOol00?mookMoo`00ogoo]goo003oOongOol00?mookMoo`00
ogoo]goo000NOol5001UOol5001UOol5001UOol5001EOol0021oo`05001oogooOol0001UOol01@00
Oomoogoo0000IGoo00D007ooOomoo`0006Eoo`05001oogooOol0001COol001Yoo`<000=oo`05001o
ogooOol0000VOolO000JOol30003Ool01@00Oomoogoo00002Goo2`0027oo5@002Goo2`006Woo0`00
0goo00@007ooOomoo`80019oobP002Aoo`<000=oo`04001oogooOol20008OolD0009Ool;000COol0
0`00Oomoo`0<Ool0021oo`05001oogooOol0000VOol00`00Oomoo`0lOol01@00Oomoogoo00002Goo
00<007ooOol01goo00<007ooOol01Woo00<007ooOol04Goo00<007ooOol01goo00<007ooOol01goo
00<007ooOol07Woo00D007ooOomoo`0001=oo`03001oogoo02Aoo`03001oogoo02Qoo`05001oogoo
Ool00009Ool00`00Oomoo`0@Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`0AOol00`00
Oomoo`0<Ool0021oo`05001oogooOol0000VOol00`00Oomoo`0lOol01@00Oomoogoo00002Goo00<0
07ooOol01goo00<007ooOol01Woo00<007ooOol04Goo00<007ooOol01goo00<007ooOol01goo00<0
07ooOol07Woo00D007ooOomoo`0001=oo`03001oogoo02Aoo`03001oogoo02Qoo`05001oogooOol0
0009Ool00`00Oomoo`0@Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`0AOol00`00Oomo
o`0<Ool001moo`8000=oo`03001oogoo02Aoo`03001oogoo03]oo`8000=oo`03001oogoo00Moo`03
001oogoo00Moo`03001oogoo00Ioo`03001oogoo015oo`03001oogoo00Moo`03001oogoo00Moo`03
001oogoo01eoo`8000=oo`03001oogoo015oo`03001oogoo02Aoo`03001oogoo02Moo`8000=oo`03
001oogoo00Moo`03001oogoo011oo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo015oo`03
001oogoo00aoo`0097oo00<007ooOol097oo00<007ooOol0@7oo00<007ooOol01goo00<007ooOol0
1goo00<007ooOol01Woo00<007ooOol04Goo00<007ooOol01goo00<007ooOol01goo00<007ooOol0
8Woo00<007ooOol04Goo00<007ooOol097oo00<007ooOol0;7oo00<007ooOol01goo00<007ooOol0
47oo00<007ooOol01goo00<007ooOol01goo00<007ooOol04Goo00<007ooOol037oo000TOol00`00
Oomoo`0TOol00`00Oomoo`10Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`06Ool00`00
Oomoo`0AOol00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`0ROol00`00Oomoo`0AOol00`00
Oomoo`0TOol00`00Oomoo`0/Ool00`00Oomoo`07Ool00`00Oomoo`0@Ool00`00Oomoo`07Ool00`00
Oomoo`07Ool00`00Oomoo`0AOol00`00Oomoo`0<Ool002Aoo`03001oogoo02Aoo`03001oogoo041o
o`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Ioo`03001oogoo015oo`03001oogoo00Mo
o`03001oogoo00Moo`03001oogoo029oo`03001oogoo015oo`03001oogoo02Aoo`03001oogoo02ao
o`03001oogoo00Moo`03001oogoo011oo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo015o
o`03001oogoo00aoo`0097oo00<007ooOol097oo00<007ooOol0@7oo00<007ooOol01goo00<007oo
Ool01goo00<007ooOol01Woo00<007ooOol04Goo00<007ooOol01goo00<007ooOol01goo00<007oo
Ool08Woo00<007ooOol04Goo00<007ooOol097oo00<007ooOol0;7oo00<007ooOol01goo00<007oo
Ool047oo00<007ooOol01goo00<007ooOol01goo00<007ooOol04Goo00<007ooOol037oo000TOol0
0`00Oomoo`0TOol00`00Oomoo`10Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`06Ool0
0`00Oomoo`0AOol00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`0ROol00`00Oomoo`0AOol0
0`00Oomoo`0TOol00`00Oomoo`0/Ool00`00Oomoo`07Ool00`00Oomoo`0@Ool00`00Oomoo`07Ool0
0`00Oomoo`07Ool00`00Oomoo`0AOol00`00Oomoo`0<Ool001Ioo`03001oogoo009oo`03001oogoo
009oo`05001oogooOol0000VOol00`00Oomoo`0bOol00`00Oomoo`02Ool00`00Oomoo`02Ool01@00
Oomoogoo00002Goo00<007ooOol01goo00<007ooOol01Woo00<007ooOol04Goo00<007ooOol01goo
00<007ooOol01goo00<007ooOol057oo00<007ooOol00Woo00<007ooOol00Woo00D007ooOomoo`00
01=oo`03001oogoo02Aoo`03001oogoo01ioo`03001oogoo009oo`03001oogoo009oo`05001oogoo
Ool00009Ool00`00Oomoo`0@Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`0AOol00`00
Oomoo`0<Ool001Eoo`03001oo`0000Moo`03001oo`00009oo`03001oogoo02Aoo`03001oogoo035o
o`03001oo`0000Moo`03001oo`00009oo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Io
o`03001oogoo015oo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo01=oo`03001oo`0000Mo
o`03001oo`00009oo`03001oogoo015oo`03001oogoo02Aoo`03001oogoo01eoo`03001oo`0000Mo
o`03001oo`00009oo`03001oogoo00Moo`03001oogoo011oo`03001oogoo00Moo`03001oogoo00Mo
o`03001oogoo015oo`03001oogoo00aoo`0047oo0`000Woo00<007oo00002Goo00@007ooOol002Io
o`03001oogoo02aoo`<0009oo`03001oo`0000Uoo`04001oogoo0009Ool00`00Oomoo`07Ool00`00
Oomoo`06Ool00`00Oomoo`0AOol00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`0>Ool30002
Ool00`00Ool00009Ool00`00Oomoo`02000BOol00`00Oomoo`0TOol00`00Oomoo`0HOol30002Ool0
0`00Ool00009Ool00`00Oomoo`020008Ool00`00Oomoo`0@Ool00`00Oomoo`07Ool00`00Oomoo`07
Ool00`00Oomoo`0AOol00`00Oomoo`0<Ool001Eoo`03001oo`0000Moo`8000=oo`03001oogoo00Ao
o`D000Ioo`<000Moo`8000Uoo`<000Ioo`03001oogoo00Ioo`8000Uoo`03001oogoo01Aoo`03001o
o`0000Moo`8000=oo`03001oogoo00Aoo`D000Ioo`<000Moo`8000Uoo`<000Ioo`8000Moo`<000Qo
o`8001Eoo`03001oo`0000Moo`8000=oo`03001oogoo00Aoo`D000Ioo`<000Moo`8000Uoo`<000Io
o`03001oogoo00Ioo`<000Qoo`03001oogoo01Aoo`03001oo`0000Moo`8000=oo`03001oogoo00Ao
o`D000Ioo`<000Moo`8000Uoo`<000Moo`03001oogoo00Eoo`8000Uoo`8000ioo`005Goo00<007oo
00001goo00<007ooOol00Woo00<007ooOol01Woo00<007ooOol01Woo00<007ooOol02Goo00<007oo
Ool01Woo0P001Woo00<007oo00001goo00<007oo000027oo00<007ooOol057oo00<007oo00001goo
00<007ooOol00Woo00<007ooOol01Woo0P001goo00<007oo000027oo0P002Goo00<007ooOol017oo
00<007oo00001goo00<007oo000027oo0P005Goo00<007oo00001goo00<007ooOol00Woo00<007oo
Ool01Woo00<007ooOol01Woo00<007oo00002Goo00<007ooOol01goo00<007ooOol017oo00<007oo
00001goo00<007oo000027oo00<007ooOol057oo00<007oo00001goo00<007ooOol00Woo00<007oo
Ool01Woo0P001goo00<007ooOol027oo0P0027oo0P001goo0`001Woo00<007oo000027oo0P003Woo
000FOol00`00Oomoo`06Ool30002Ool00`00Oomoo`06Ool00`00Oomoo`07Ool00`00Oomoo`07Ool0
0`00Oomoo`06Ool40007Ool00`00Oomoo`05Ool00`00Ool00008Ool00`00Oomoo`0EOol00`00Oomo
o`06Ool30002Ool00`00Oomoo`06Ool20008Ool20008Ool00`00Oomoo`06Ool40007Ool00`00Oomo
o`05Ool00`00Ool00008Ool2000FOol00`00Oomoo`06Ool30002Ool00`00Oomoo`06Ool00`00Oomo
o`07Ool20008Ool00`00Oomoo`06Ool40007Ool00`00Oomoo`05Ool00`00Ool00008Ool00`00Oomo
o`0EOol00`00Oomoo`06Ool30002Ool00`00Oomoo`06Ool20008Ool00`00Oomoo`07Ool00`00Oomo
o`06Ool40007Ool20006Ool00`00Ool00008Ool2000>Ool002Aoo`03001oogoo00Ioo`03001oogoo
00Moo`03001oogoo00Qoo`03001oogoo00Eoo`<000Ioo`8000Qoo`8000Yoo`03001oogoo029oo`03
001oogoo00Ioo`8000Qoo`8000Qoo`8000Moo`03001oo`0000Ioo`<000Moo`<000Uoo`03001oogoo
029oo`03001oogoo00Ioo`03001oogoo00Moo`8000Uoo`03001oogoo00Eoo`03001oo`0000Ioo`80
00Qoo`<000Uoo`03001oogoo029oo`03001oogoo00Ioo`8000Qoo`03001oogoo00Moo`8000Moo`<0
00Moo`8000Moo`8000Yoo`03001oogoo00aoo`0097oo00<007ooOol01Woo00<007ooOol01Woo00<0
07oo00001goo00<007oo000027oo0P001Woo00<007ooOol01goo00<007ooOol01goo00<007oo0000
97oo00<007ooOol01Woo0P001goo00<007oo00001goo0`0027oo0P001Woo00<007oo00001goo00<0
07oo00001goo00<007oo000097oo00<007ooOol01Woo00<007ooOol01Woo00<007oo00001goo00<0
07oo000027oo0P001Woo00<007ooOol01goo00<007oo00001goo00<007oo000097oo00<007ooOol0
1Woo0P001goo00<007oo00001goo0`0027oo0P001goo0P001goo00<007ooOol01goo00<007oo0000
3Woo000TOol00`00Oomoo`05Ool20009Ool00`00Oomoo`07Ool00`00Oomoo`07Ool20006Ool30008
Ool20007Ool3000TOol00`00Oomoo`05Ool30008Ool20008Ool00`00Oomoo`08Ool00`00Oomoo`04
Ool30008Ool20007Ool3000TOol00`00Oomoo`05Ool20009Ool20008Ool00`00Oomoo`08Ool00`00
Oomoo`04Ool30008Ool20007Ool3000TOol00`00Oomoo`05Ool30008Ool00`00Oomoo`07Ool00`00
Oomoo`07Ool20007Ool30007Ool20007Ool3000>Ool002Aoo`03001oogoo02Aoo`03001oogoo041o
o`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Ioo`03001oogoo015oo`03001oogoo00Mo
o`03001oogoo00Moo`03001oogoo029oo`03001oogoo015oo`03001oogoo02Aoo`03001oogoo02ao
o`03001oogoo00Moo`03001oogoo011oo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo015o
o`03001oogoo00aoo`0097oo00<007ooOol097oo00<007ooOol0@7oo00<007ooOol01goo00<007oo
Ool01goo00<007ooOol01Woo00<007ooOol04Goo00<007ooOol01goo00<007ooOol01goo00<007oo
Ool08Woo00<007ooOol04Goo00<007ooOol097oo00<007ooOol0;7oo00<007ooOol01goo00<007oo
Ool047oo00<007ooOol01goo00<007ooOol01goo00<007ooOol04Goo00<007ooOol037oo000TOol0
0`00Oomoo`0TOol00`00Oomoo`10Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`06Ool0
0`00Oomoo`0AOol00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`0ROol00`00Oomoo`0AOol0
0`00Oomoo`0TOol00`00Oomoo`0/Ool00`00Oomoo`07Ool00`00Oomoo`0@Ool00`00Oomoo`07Ool0
0`00Oomoo`07Ool00`00Oomoo`0AOol00`00Oomoo`0<Ool0029oodT0025oodT0025oodT0025oodT0
00eoo`0097oo00<007ooOol01goo00<007ooOol01goo00<007ooOol01Woo00<007ooOol01goo00<0
07ooOol01goo00<007ooOol01goo00<007ooOol01goo00<007ooOol08Woo00<007ooOol01goo00<0
07ooOol01goo00<007ooOol01Woo00<007ooOol01goo00<007ooOol01goo00<007ooOol01goo00<0
07ooOol01goo00<007ooOol08Woo00<007ooOol01goo00<007ooOol01goo00<007ooOol01Woo00<0
07ooOol01goo00<007ooOol01goo00<007ooOol01goo00<007ooOol01goo00<007ooOol08Woo00<0
07ooOol01goo00<007ooOol01goo00<007ooOol01Woo00<007ooOol01goo00<007ooOol01goo00<0
07ooOol01goo00<007ooOol01goo00<007ooOol037oo000TOol00`00Oomoo`0TOol00`00Oomoo`10
Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`06Ool00`00Oomoo`0AOol00`00Oomoo`07
Ool00`00Oomoo`07Ool00`00Oomoo`0ROol00`00Oomoo`0AOol00`00Oomoo`0TOol00`00Oomoo`0/
Ool00`00Oomoo`07Ool00`00Oomoo`0@Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`0A
Ool00`00Oomoo`0<Ool002Aoo`03001oogoo02Aoo`03001oogoo041oo`03001oogoo00Moo`03001o
ogoo00Moo`03001oogoo00Ioo`03001oogoo015oo`03001oogoo00Moo`03001oogoo00Moo`03001o
ogoo029oo`03001oogoo015oo`03001oogoo02Aoo`03001oogoo02aoo`03001oogoo00Moo`03001o
ogoo011oo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo015oo`03001oogoo00aoo`0097oo
00<007ooOol097oo00<007ooOol0@7oo00<007ooOol01goo00<007ooOol01goo00<007ooOol01Woo
00<007ooOol04Goo00<007ooOol01goo00<007ooOol01goo00<007ooOol08Woo00<007ooOol04Goo
00<007ooOol097oo00<007ooOol0;7oo00<007ooOol01goo00<007ooOol047oo00<007ooOol01goo
00<007ooOol01goo00<007ooOol04Goo00<007ooOol037oo000TOol00`00Oomoo`0TOol00`00Oomo
o`10Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`06Ool00`00Oomoo`0AOol00`00Oomo
o`07Ool00`00Oomoo`07Ool00`00Oomoo`0ROol00`00Oomoo`0AOol00`00Oomoo`0TOol00`00Oomo
o`0/Ool00`00Oomoo`07Ool00`00Oomoo`0@Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomo
o`0AOol00`00Oomoo`0<Ool002Aoo`03001oogoo02Aoo`03001oogoo041oo`03001oogoo00Moo`03
001oogoo00Moo`03001oogoo00Ioo`03001oogoo015oo`03001oogoo00Moo`03001oogoo00Moo`03
001oogoo029oo`03001oogoo015oo`03001oogoo02Aoo`03001oogoo02aoo`03001oogoo00Moo`03
001oogoo011oo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo015oo`03001oogoo00aoo`00
97oo00<007ooOol097oo00<007ooOol0@7oo00<007ooOol01goo00<007ooOol01goo00<007ooOol0
1Woo00<007ooOol04Goo00<007ooOol01goo00<007ooOol01goo00<007ooOol08Woo00<007ooOol0
4Goo00<007ooOol097oo00<007ooOol0;7oo00<007ooOol01goo00<007ooOol047oo00<007ooOol0
1goo00<007ooOol01goo00<007ooOol04Goo00<007ooOol037oo000TOol00`00Oomoo`0TOol00`00
Oomoo`10Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`06Ool00`00Oomoo`0AOol00`00
Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`0ROol00`00Oomoo`0AOol00`00Oomoo`0TOol00`00
Oomoo`0/Ool00`00Oomoo`07Ool00`00Oomoo`0@Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00
Oomoo`0AOol00`00Oomoo`0<Ool001Ioo`03001oogoo009oo`03001oogoo009oo`05001oogooOol0
000VOol00`00Oomoo`0bOol00`00Oomoo`02Ool00`00Oomoo`02Ool01@00Oomoogoo00002Goo00<0
07ooOol01goo00<007ooOol01Woo00<007ooOol04Goo00<007ooOol01goo00<007ooOol01goo00<0
07ooOol057oo00<007ooOol00Woo00<007ooOol00Woo00D007ooOomoo`0001=oo`03001oogoo02Ao
o`03001oogoo01ioo`03001oogoo009oo`03001oogoo009oo`05001oogooOol00009Ool00`00Oomo
o`0@Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`0AOol00`00Oomoo`0<Ool001Eoo`03
001oo`0000Moo`03001oo`00009oo`03001oogoo02Aoo`03001oogoo035oo`03001oo`0000Moo`03
001oo`00009oo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Ioo`03001oogoo015oo`03
001oogoo00Moo`03001oogoo00Moo`03001oogoo01=oo`03001oo`0000Moo`03001oo`00009oo`03
001oogoo015oo`03001oogoo02Aoo`03001oogoo01eoo`03001oo`0000Moo`03001oo`00009oo`03
001oogoo00Moo`03001oogoo011oo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo015oo`03
001oogoo00aoo`005Goo00<007oo00002Goo00@007ooOol002Ioo`03001oogoo035oo`03001oo`00
00Uoo`04001oogoo0009Ool00`00Oomoo`07Ool00`00Oomoo`06Ool00`00Oomoo`0AOol00`00Oomo
o`07Ool00`00Oomoo`07Ool00`00Oomoo`0COol00`00Ool00009Ool00`00Oomoo`02000BOol00`00
Oomoo`0TOol00`00Oomoo`0MOol00`00Ool00009Ool00`00Oomoo`020008Ool00`00Oomoo`0@Ool0
0`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`0AOol00`00Oomoo`0<Ool001Eoo`03001oo`00
00Moo`8000=oo`03001oogoo02Aoo`03001oogoo035oo`03001oo`0000Moo`8000=oo`03001oogoo
00Moo`03001oogoo00Moo`03001oogoo00Ioo`03001oogoo015oo`03001oogoo00Moo`03001oogoo
00Moo`03001oogoo01=oo`03001oo`0000Moo`8000=oo`03001oogoo015oo`03001oogoo02Aoo`03
001oogoo01eoo`03001oo`0000Moo`8000=oo`03001oogoo00Moo`03001oogoo011oo`03001oogoo
00Moo`03001oogoo00Moo`03001oogoo015oo`03001oogoo00aoo`005Goo00<007oo00001goo00<0
07ooOol00Woo00<007ooOol097oo00<007ooOol0<Goo00<007oo00001goo00<007ooOol00Woo00<0
07ooOol01goo00<007ooOol01goo00<007ooOol01Woo00<007ooOol04Goo00<007ooOol01goo00<0
07ooOol01goo00<007ooOol04goo00<007oo00001goo00<007ooOol00Woo00<007ooOol04Goo00<0
07ooOol097oo00<007ooOol07Goo00<007oo00001goo00<007ooOol00Woo00<007ooOol01goo00<0
07ooOol047oo00<007ooOol01goo00<007ooOol01goo00<007ooOol04Goo00<007ooOol037oo000F
Ool00`00Oomoo`06Ool30002Ool00`00Oomoo`0TOol00`00Oomoo`0bOol00`00Oomoo`06Ool30002
Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`06Ool00`00Oomoo`0AOol00`00Oomoo`07
Ool00`00Oomoo`07Ool00`00Oomoo`0DOol00`00Oomoo`06Ool30002Ool00`00Oomoo`0AOol00`00
Oomoo`0TOol00`00Oomoo`0NOol00`00Oomoo`06Ool30002Ool00`00Oomoo`07Ool00`00Oomoo`0@
Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`0AOol00`00Oomoo`0<Ool002Aoo`03001o
ogoo02Aoo`03001oogoo041oo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Ioo`03001o
ogoo015oo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo029oo`03001oogoo015oo`03001o
ogoo02Aoo`03001oogoo02aoo`03001oogoo00Moo`03001oogoo011oo`03001oogoo00Moo`03001o
ogoo00Moo`03001oogoo015oo`03001oogoo00aoo`0097oo00<007ooOol097oo00<007ooOol0@7oo
00<007ooOol01goo00<007ooOol01goo00<007ooOol01Woo00<007ooOol04Goo00<007ooOol01goo
00<007ooOol01goo00<007ooOol08Woo00<007ooOol04Goo00<007ooOol097oo00<007ooOol0;7oo
00<007ooOol01goo00<007ooOol047oo00<007ooOol01goo00<007ooOol01goo00<007ooOol04Goo
00<007ooOol037oo000TOol00`00Oomoo`0TOol00`00Oomoo`10Ool00`00Oomoo`07Ool00`00Oomo
o`07Ool00`00Oomoo`06Ool00`00Oomoo`0AOol00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomo
o`0ROol00`00Oomoo`0AOol00`00Oomoo`0TOol00`00Oomoo`0/Ool00`00Oomoo`07Ool00`00Oomo
o`0@Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`0AOol00`00Oomoo`0<Ool002Aoo`03
001oogoo02Aoo`03001oogoo041oo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Ioo`03
001oogoo015oo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo029oo`03001oogoo015oo`03
001oogoo02Aoo`03001oogoo02aoo`03001oogoo00Moo`03001oogoo011oo`03001oogoo00Moo`03
001oogoo00Moo`03001oogoo015oo`03001oogoo00aoo`007Woo1@0000=oo`00Ool09Goo00<007oo
Ool0>Woo1@0000=oo`00Ool027oo00<007ooOol01goo00<007ooOol01Woo00<007ooOol04Goo00<0
07ooOol01goo00<007ooOol01goo00<007ooOol077oo1@0000=oo`00Ool04Woo00<007ooOol097oo
00<007ooOol09Woo1@0000=oo`00Ool027oo00<007ooOol047oo00<007ooOol01goo00<007ooOol0
1goo00<007ooOol04Goo00<007ooOol037oo000POol01@00Oomoogoo00009Woo00<007ooOol0?7oo
00D007ooOomoo`0000Uoo`03001oogoo00Moo`03001oogoo00Ioo`03001oogoo015oo`03001oogoo
00Moo`03001oogoo00Moo`03001oogoo01ioo`05001oogooOol0000COol00`00Oomoo`0TOol00`00
Oomoo`0XOol01@00Oomoogoo00002Goo00<007ooOol047oo00<007ooOol01goo00<007ooOol01goo
00<007ooOol04Goo00<007ooOol037oo000POol01000Oomoogoo:000?Woo00@007ooOomoo`/000Uo
o`X001=oo`/000Uoo`03001oogoo01ioo`04001oogooOolE000VOol;000POol01000Oomoogoo2`00
4Woo2`002Goo5@003Woo000POol01@00Oomoogoo0000IGoo00D007ooOomoo`0006Eoo`05001oogoo
Ool0001UOol01@00Oomoogoo0000Dgoo000POol00`00Oomoo`1WOol00`00Oomoo`1WOol00`00Oomo
o`1WOol00`00Oomoo`1EOol001moo`8006Qoo`8006Qoo`8006Qoo`8005Moo`00ogoo]goo003oOong
Ool00?mookMoo`00ogoo]goo003oOongOol00?mookMoo`00ogoo]goo003oOongOol00?mookMoo`00
ogoo]goo003oOongOol00?mookMoo`009goo1@001Woo0`0027oo0P002Goo0`001goo00<007ooOol0
1goo0P002Goo00<007ooOol0ogooCGoo000YOol00`00Oomoo`06Ool00`00Oomoo`0:Ool00`00Oomo
o`07Ool00`00Oomoo`05Ool00`00Ool00008Ool00`00Ool00008Ool00`00Oomoo`3oOom=Ool002Uo
o`03001oogoo00Moo`03001oogoo00Qoo`03001oogoo00Ioo`@000Qoo`03001oogoo00Ioo`03001o
o`0000Qoo`03001oogoo0?moodeoo`00:Goo00<007ooOol01goo00<007ooOol02Goo00<007ooOol0
1Goo00<007oo00001goo0P002Goo0P002Woo00<007ooOol0ogooC7oo000YOol00`00Oomoo`06Ool0
0`00Ool00008Ool00`00Ool00008Ool20007Ool00`00Oomoo`08Ool00`00Oomoo`07Ool00`00Ool0
003oOom>Ool002Qoo`8000Uoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Eoo`<000Uo
o`8000Moo`<001moo`D006Eoo`D006Eoo`D005Eoo`00RWoo00D007ooOomoo`0006Eoo`05001oogoo
Ool0001UOol01@00Oomoogoo0000Dgoo0024Ool30003Ool01@00Oomoogoo00002Goo2`0027oo2`00
2Goo2`002Goo00<007ooOol067oo0`000goo00@007ooOomoo`80019ooa@001=oo`/001Yoo`<000=o
o`04001oogooOol20008OolD000COolE000>Ool001moo`03001oogoo06Qoo`05001oogooOol00009
Ool00`00Oomoo`07Ool00`00Oomoo`06Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07
Ool00`00Oomoo`07Ool00`00Oomoo`0NOol01@00Oomoogoo00004goo00<007ooOol047oo00<007oo
Ool04Goo00<007ooOol0:7oo00D007ooOomoo`0000Uoo`03001oogoo011oo`03001oogoo015oo`03
001oogoo015oo`03001oogoo00aoo`007GooCP007goo00D007ooOomoo`0000Uoo`03001oogoo00Mo
o`03001oogoo00Ioo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Mo
o`03001oogoo01ioo`05001oogooOol0000COol00`00Oomoo`0@Ool00`00Oomoo`0AOol00`00Oomo
o`0XOol01@00Oomoogoo00002Goo00<007ooOol047oo00<007ooOol04Goo00<007ooOol04Goo00<0
07ooOol037oo000OOol00`00Oomoo`1WOol20003Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00
Oomoo`06Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00
Oomoo`0MOol20003Ool00`00Oomoo`0AOol00`00Oomoo`0@Ool00`00Oomoo`0AOol00`00Oomoo`0W
Ool20003Ool00`00Oomoo`07Ool00`00Oomoo`0@Ool00`00Oomoo`0AOol00`00Oomoo`0AOol00`00
Oomoo`0<Ool001moo`03001oogoo06aoo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Io
o`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo029o
o`03001oogoo015oo`03001oogoo011oo`03001oogoo015oo`03001oogoo02aoo`03001oogoo00Mo
o`03001oogoo011oo`03001oogoo015oo`03001oogoo015oo`03001oogoo00aoo`007goo00<007oo
Ool0K7oo00<007ooOol01goo00<007ooOol01goo00<007ooOol01Woo00<007ooOol01goo00<007oo
Ool01goo00<007ooOol01goo00<007ooOol01goo00<007ooOol08Woo00<007ooOol04Goo00<007oo
Ool047oo00<007ooOol04Goo00<007ooOol0;7oo00<007ooOol01goo00<007ooOol047oo00<007oo
Ool04Goo00<007ooOol04Goo00<007ooOol037oo000OOol00`00Oomoo`1/Ool00`00Oomoo`07Ool0
0`00Oomoo`07Ool00`00Oomoo`06Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07Ool0
0`00Oomoo`07Ool00`00Oomoo`0ROol00`00Oomoo`0AOol00`00Oomoo`0@Ool00`00Oomoo`0AOol0
0`00Oomoo`0/Ool00`00Oomoo`07Ool00`00Oomoo`0@Ool00`00Oomoo`0AOol00`00Oomoo`0AOol0
0`00Oomoo`0<Ool001moo`03001oogoo06aoo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo
00Ioo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo
029oo`03001oogoo015oo`03001oogoo011oo`03001oogoo015oo`03001oogoo02aoo`03001oogoo
00Moo`03001oogoo011oo`03001oogoo015oo`03001oogoo015oo`03001oogoo00aoo`007goo00<0
07ooOol0K7oo00<007ooOol01goo00<007ooOol01goo00<007ooOol01Woo00<007ooOol01goo00<0
07ooOol01goo00<007ooOol01goo00<007ooOol01goo00<007ooOol08Woo00<007ooOol04Goo00<0
07ooOol047oo00<007ooOol04Goo00<007ooOol0;7oo00<007ooOol01goo00<007ooOol047oo00<0
07ooOol04Goo00<007ooOol04Goo00<007ooOol037oo000OOol00`00Oomoo`1NOol00`00Oomoo`02
Ool00`00Oomoo`02Ool01@00Oomoogoo00002Goo00<007ooOol01goo00<007ooOol01Woo00<007oo
Ool01goo00<007ooOol01goo00<007ooOol01goo00<007ooOol01goo00<007ooOol057oo00<007oo
Ool00Woo00<007ooOol00Woo00D007ooOomoo`0001=oo`03001oogoo011oo`03001oogoo015oo`03
001oogoo01ioo`03001oogoo009oo`03001oogoo009oo`05001oogooOol00009Ool00`00Oomoo`0@
Ool00`00Oomoo`0AOol00`00Oomoo`0AOol00`00Oomoo`0<Ool001moo`03001oogoo05eoo`03001o
o`0000Moo`03001oo`00009oo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Ioo`03001o
ogoo00Moo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo01=oo`03001o
o`0000Moo`03001oo`00009oo`03001oogoo015oo`03001oogoo011oo`03001oogoo015oo`03001o
ogoo01eoo`03001oo`0000Moo`03001oo`00009oo`03001oogoo00Moo`03001oogoo011oo`03001o
ogoo015oo`03001oogoo015oo`03001oogoo00aoo`004Goo00<007ooOol00Woo00<007ooOol00Woo
00D007ooOomoo`0005Yoo`<0009oo`03001oo`0000Uoo`04001oogoo0009Ool00`00Oomoo`07Ool0
0`00Oomoo`06Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07Ool0
0`00Oomoo`0>Ool30002Ool00`00Ool00009Ool00`00Oomoo`02000BOol00`00Oomoo`0@Ool00`00
Oomoo`0AOol00`00Oomoo`0HOol30002Ool00`00Ool00009Ool00`00Oomoo`020008Ool00`00Oomo
o`0@Ool00`00Oomoo`0AOol00`00Oomoo`0AOol00`00Oomoo`0<Ool0011oo`03001oo`0000Moo`03
001oo`00009oo`03001oogoo05eoo`03001oo`0000Moo`8000=oo`03001oogoo00Moo`03001oogoo
00Moo`03001oogoo00Ioo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo
00Moo`03001oogoo01=oo`03001oo`0000Moo`8000=oo`03001oogoo015oo`03001oogoo011oo`03
001oogoo015oo`03001oogoo01eoo`03001oo`0000Moo`8000=oo`03001oogoo00Moo`03001oogoo
011oo`03001oogoo015oo`03001oogoo015oo`03001oogoo00aoo`0047oo00<007oo00002Goo00@0
07ooOol005moo`03001oo`0000Moo`03001oogoo009oo`03001oogoo00Aoo`D000Ioo`<000Moo`80
00Uoo`<000Ioo`8000Moo`<000Qoo`8001Eoo`03001oo`0000Moo`03001oogoo009oo`03001oogoo
00Aoo`D000Ioo`<000Moo`8000Uoo`<000Ioo`03001oogoo00Ioo`<000Qoo`03001oogoo01Aoo`03
001oo`0000Moo`03001oogoo009oo`03001oogoo00Aoo`D000Ioo`<000Moo`8000Uoo`<000Moo`03
001oogoo00Eoo`8000Uoo`8000ioo`0047oo00<007oo00001goo0P000goo00<007ooOol0GWoo00<0
07ooOol01Woo0`000Woo00<007ooOol01Woo0P001goo00<007oo000027oo0P0027oo0P001Woo00<0
07oo00001goo00<007oo000027oo0P005Woo00<007ooOol01Woo0`000Woo00<007ooOol01Woo00<0
07ooOol01Woo00<007oo00002Goo00<007ooOol01Woo0P001Woo00<007oo00001goo00<007oo0000
27oo00<007ooOol05Goo00<007ooOol01Woo0`000Woo00<007ooOol01Woo0P001goo00<007ooOol0
27oo0P002Goo00<007ooOol01Goo0`001Woo00<007oo000027oo0P003Woo000@Ool00`00Ool00007
Ool00`00Oomoo`02Ool00`00Oomoo`1/Ool00`00Oomoo`06Ool20008Ool20008Ool00`00Oomoo`06
Ool40007Ool00`00Oomoo`05Ool00`00Ool00008Ool2000TOol00`00Oomoo`06Ool00`00Oomoo`07
Ool20008Ool00`00Oomoo`06Ool40007Ool00`00Oomoo`05Ool00`00Ool00008Ool00`00Oomoo`0S
Ool00`00Oomoo`06Ool20008Ool00`00Oomoo`07Ool00`00Oomoo`06Ool40007Ool20006Ool00`00
Ool00008Ool2000>Ool0015oo`03001oogoo00Ioo`<0009oo`03001oogoo06aoo`03001oogoo00Io
o`8000Qoo`8000Qoo`8000Moo`<000Ioo`<000Moo`<000Uoo`03001oogoo029oo`03001oogoo00Io
o`03001oogoo00Moo`8000Uoo`03001oogoo00Eoo`<000Ioo`8000Qoo`<000Uoo`03001oogoo029o
o`03001oogoo00Ioo`8000Qoo`03001oogoo00Moo`8000Moo`03001oo`0000Moo`8000Moo`8000Yo
o`03001oogoo00aoo`007goo00<007ooOol0K7oo00<007ooOol01Woo0P001goo00<007oo00001goo
0`0027oo0P001Woo00<007oo00001goo00<007oo00001goo00<007oo000097oo00<007ooOol01Woo
00<007ooOol01Woo00<007oo00001goo00<007oo000027oo0P001Woo00<007ooOol01goo00<007oo
00001goo00<007oo000097oo00<007ooOol01Woo0P001goo00<007oo00001goo0`0027oo0P001goo
0P001goo00<007ooOol01goo00<007oo00003Woo000OOol00`00Oomoo`1/Ool00`00Oomoo`05Ool3
0008Ool20008Ool00`00Oomoo`07Ool20006Ool30008Ool20007Ool3000TOol00`00Oomoo`05Ool2
0009Ool20008Ool00`00Oomoo`07Ool20006Ool30008Ool20007Ool3000TOol00`00Oomoo`05Ool3
0008Ool00`00Oomoo`07Ool00`00Oomoo`08Ool00`00Oomoo`05Ool30007Ool20007Ool3000>Ool0
01moo`03001oogoo06aoo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Ioo`03001oogoo
00Moo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo029oo`03001oogoo
015oo`03001oogoo011oo`03001oogoo015oo`03001oogoo02aoo`03001oogoo00Moo`03001oogoo
011oo`03001oogoo015oo`03001oogoo015oo`03001oogoo00aoo`007goo00<007ooOol0K7oo00<0
07ooOol01goo00<007ooOol01goo00<007ooOol01Woo00<007ooOol01goo00<007ooOol01goo00<0
07ooOol01goo00<007ooOol01goo00<007ooOol08Woo00<007ooOol04Goo00<007ooOol047oo00<0
07ooOol04Goo00<007ooOol0;7oo00<007ooOol01goo00<007ooOol047oo00<007ooOol04Goo00<0
07ooOol04Goo00<007ooOol037oo000OOol00`00Oomoo`1/Ool00`00Oomoo`07Ool00`00Oomoo`07
Ool00`00Oomoo`06Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07
Ool00`00Oomoo`0ROol00`00Oomoo`0AOol00`00Oomoo`0@Ool00`00Oomoo`0AOol00`00Oomoo`0/
Ool00`00Oomoo`07Ool00`00Oomoo`0@Ool00`00Oomoo`0AOol00`00Oomoo`0AOol00`00Oomoo`0<
Ool001Uoo`D00003Ool007oo06]oodT0025oodT0025oodT000eoo`006goo00D007ooOomoo`0006io
o`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Ioo`03001oogoo00Moo`03001oogoo00Mo
o`03001oogoo00Moo`03001oogoo00Moo`03001oogoo029oo`03001oogoo015oo`03001oogoo011o
o`03001oogoo015oo`03001oogoo02aoo`03001oogoo00Moo`03001oogoo011oo`03001oogoo015o
o`03001oogoo015oo`03001oogoo00aoo`006goo00@007ooOomoodX002Eoo`03001oogoo00Moo`03
001oogoo00Moo`03001oogoo00Ioo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Moo`03
001oogoo00Moo`03001oogoo029oo`03001oogoo015oo`03001oogoo011oo`03001oogoo015oo`03
001oogoo02aoo`03001oogoo00Moo`03001oogoo011oo`03001oogoo015oo`03001oogoo015oo`03
001oogoo00aoo`006goo00D007ooOomoo`0006ioo`03001oogoo00Moo`03001oogoo00Moo`03001o
ogoo00Ioo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Moo`03001o
ogoo029oo`03001oogoo015oo`03001oogoo011oo`03001oogoo015oo`03001oogoo02aoo`03001o
ogoo00Moo`03001oogoo011oo`03001oogoo015oo`03001oogoo015oo`03001oogoo00aoo`006goo
00D007ooOomoo`0006ioo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Ioo`03001oogoo
00Moo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo029oo`03001oogoo
015oo`03001oogoo011oo`03001oogoo015oo`03001oogoo02aoo`03001oogoo00Moo`03001oogoo
011oo`03001oogoo015oo`03001oogoo015oo`03001oogoo00aoo`006Woo0P000goo00<007ooOol0
K7oo00<007ooOol01goo00<007ooOol01goo00<007ooOol01Woo00<007ooOol01goo00<007ooOol0
1goo00<007ooOol01goo00<007ooOol01goo00<007ooOol08Woo00<007ooOol04Goo00<007ooOol0
47oo00<007ooOol04Goo00<007ooOol0;7oo00<007ooOol01goo00<007ooOol047oo00<007ooOol0
4Goo00<007ooOol04Goo00<007ooOol037oo000OOol00`00Oomoo`1/Ool00`00Oomoo`07Ool00`00
Oomoo`07Ool00`00Oomoo`06Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00
Oomoo`07Ool00`00Oomoo`0ROol00`00Oomoo`0AOol00`00Oomoo`0@Ool00`00Oomoo`0AOol00`00
Oomoo`0/Ool00`00Oomoo`07Ool00`00Oomoo`0@Ool00`00Oomoo`0AOol00`00Oomoo`0AOol00`00
Oomoo`0<Ool001moo`03001oogoo06aoo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Io
o`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo029o
o`03001oogoo015oo`03001oogoo011oo`03001oogoo015oo`03001oogoo02aoo`03001oogoo00Mo
o`03001oogoo011oo`03001oogoo015oo`03001oogoo015oo`03001oogoo00aoo`007goo00<007oo
Ool0GWoo00<007ooOol00Woo00<007ooOol00Woo00D007ooOomoo`0000Uoo`03001oogoo00Moo`03
001oogoo00Ioo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Moo`03
001oogoo01Aoo`03001oogoo009oo`03001oogoo009oo`05001oogooOol0000COol00`00Oomoo`0@
Ool00`00Oomoo`0AOol00`00Oomoo`0NOol00`00Oomoo`02Ool00`00Oomoo`02Ool01@00Oomoogoo
00002Goo00<007ooOol047oo00<007ooOol04Goo00<007ooOol04Goo00<007ooOol037oo000OOol0
0`00Oomoo`1MOol00`00Ool00007Ool00`00Ool00002Ool00`00Oomoo`07Ool00`00Oomoo`07Ool0
0`00Oomoo`06Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07Ool0
0`00Oomoo`0COol00`00Ool00007Ool00`00Ool00002Ool00`00Oomoo`0AOol00`00Oomoo`0@Ool0
0`00Oomoo`0AOol00`00Oomoo`0MOol00`00Ool00007Ool00`00Ool00002Ool00`00Oomoo`07Ool0
0`00Oomoo`0@Ool00`00Oomoo`0AOol00`00Oomoo`0AOol00`00Oomoo`0<Ool001moo`03001oogoo
05eoo`03001oo`0000Uoo`04001oogoo0009Ool00`00Oomoo`07Ool00`00Oomoo`06Ool00`00Oomo
o`07Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`0COol00`00Ool0
0009Ool00`00Oomoo`02000BOol00`00Oomoo`0@Ool00`00Oomoo`0AOol00`00Oomoo`0MOol00`00
Ool00009Ool00`00Oomoo`020008Ool00`00Oomoo`0@Ool00`00Oomoo`0AOol00`00Oomoo`0AOol0
0`00Oomoo`0<Ool001moo`03001oogoo05eoo`03001oo`0000Moo`8000=oo`03001oogoo00Moo`03
001oogoo00Moo`03001oogoo00Ioo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Moo`03
001oogoo00Moo`03001oogoo01=oo`03001oo`0000Moo`8000=oo`03001oogoo015oo`03001oogoo
011oo`03001oogoo015oo`03001oogoo01eoo`03001oo`0000Moo`8000=oo`03001oogoo00Moo`03
001oogoo011oo`03001oogoo015oo`03001oogoo015oo`03001oogoo00aoo`003goo1@000Woo00<0
07ooOol00Woo00D007ooOomoo`0005moo`03001oo`0000Moo`03001oogoo009oo`03001oogoo00Mo
o`03001oogoo00Moo`03001oogoo00Ioo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Mo
o`03001oogoo00Moo`03001oogoo01=oo`03001oo`0000Moo`03001oogoo009oo`03001oogoo015o
o`03001oogoo011oo`03001oogoo015oo`03001oogoo01eoo`03001oo`0000Moo`03001oogoo009o
o`03001oogoo00Moo`03001oogoo011oo`03001oogoo015oo`03001oogoo015oo`03001oogoo00ao
o`004Goo00<007ooOol01Woo00<007oo00000Woo00<007ooOol0GWoo00<007ooOol01Woo0`000Woo
00<007ooOol01goo00<007ooOol01goo00<007ooOol01Woo00<007ooOol01goo00<007ooOol01goo
00<007ooOol01goo00<007ooOol01goo00<007ooOol057oo00<007ooOol01Woo0`000Woo00<007oo
Ool04Goo00<007ooOol047oo00<007ooOol04Goo00<007ooOol07Woo00<007ooOol01Woo0`000Woo
00<007ooOol01goo00<007ooOol047oo00<007ooOol04Goo00<007ooOol04Goo00<007ooOol037oo
000AOol00`00Oomoo`08Ool01000Oomoo`00KWoo00<007ooOol01goo00<007ooOol01goo00<007oo
Ool01Woo00<007ooOol01goo00<007ooOol01goo00<007ooOol01goo00<007ooOol01goo00<007oo
Ool08Woo00<007ooOol04Goo00<007ooOol047oo00<007ooOol04Goo00<007ooOol0;7oo00<007oo
Ool01goo00<007ooOol047oo00<007ooOol04Goo00<007ooOol04Goo00<007ooOol037oo000AOol0
0`00Oomoo`06Ool20003Ool00`00Oomoo`1/Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomo
o`06Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomo
o`0ROol00`00Oomoo`0AOol00`00Oomoo`0@Ool00`00Oomoo`0AOol00`00Oomoo`0/Ool00`00Oomo
o`07Ool00`00Oomoo`0@Ool00`00Oomoo`0AOol00`00Oomoo`0AOol00`00Oomoo`0<Ool0015oo`03
001oogoo00Ioo`03001oogoo009oo`03001oogoo06aoo`03001oogoo00Moo`03001oogoo00Moo`03
001oogoo00Ioo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Moo`03
001oogoo029oo`03001oogoo015oo`03001oogoo011oo`03001oogoo015oo`03001oogoo02aoo`03
001oogoo00Moo`03001oogoo011oo`03001oogoo015oo`03001oogoo015oo`03001oogoo00aoo`00
47oo0P0027oo0`000Woo00<007ooOol0K7oo00<007ooOol01goo00<007ooOol01goo00<007ooOol0
1Woo00<007ooOol01goo00<007ooOol01goo00<007ooOol01goo00<007ooOol01goo00<007ooOol0
8Woo00<007ooOol04Goo00<007ooOol047oo00<007ooOol04Goo00<007ooOol0;7oo00<007ooOol0
1goo00<007ooOol047oo00<007ooOol04Goo00<007ooOol04Goo00<007ooOol037oo000OOol00`00
Oomoo`1/Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`06Ool00`00Oomoo`07Ool00`00
Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`0ROol00`00Oomoo`0AOol00`00
Oomoo`0@Ool00`00Oomoo`0AOol00`00Oomoo`0/Ool00`00Oomoo`07Ool00`00Oomoo`0@Ool00`00
Oomoo`0AOol00`00Oomoo`0AOol00`00Oomoo`0<Ool001moo`03001oogoo06Ioo`D00003Ool007oo
00Qoo`03001oogoo00Moo`03001oogoo00Ioo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo
00Moo`03001oogoo00Moo`03001oogoo01aoo`D00003Ool007oo019oo`03001oogoo011oo`03001o
ogoo015oo`03001oogoo02Ioo`D00003Ool007oo00Qoo`03001oogoo011oo`03001oogoo015oo`03
001oogoo015oo`03001oogoo00aoo`007goo00<007ooOol0J7oo00D007ooOomoo`0000Uoo`03001o
ogoo00Moo`03001oogoo00Ioo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Moo`03001o
ogoo00Moo`03001oogoo01ioo`05001oogooOol0000COol00`00Oomoo`0@Ool00`00Oomoo`0AOol0
0`00Oomoo`0XOol01@00Oomoogoo00002Goo00<007ooOol047oo00<007ooOol04Goo00<007ooOol0
4Goo00<007ooOol037oo000OOol00`00Oomoo`1XOol01000Oomoogoo2`002Goo2P002Goo2`002Goo
2`0087oo00@007ooOomooaD0019ooaD002Yoo`04001oogooOol;000BOolE000COol00`00Oomoo`0<
Ool001moo`03001oogoo06Qoo`05001oogooOol0001UOol01@00Oomoogoo0000IGoo00D007ooOomo
o`0005=oo`006Woo0`000Woo00<007ooOol0J7oo00<007ooOol0Igoo00<007ooOol0Igoo00<007oo
Ool0EGoo000JOol00`00Oomoo`02Ool00`00Oomoo`1WOol2001XOol2001XOol2001GOol001]oo`05
001oogooOol0003oOonGOol001]oo`05001oogooOol0003oOonGOol001Yoo`03001oo`000?mooiYo
o`006goo00<007ooOol0ogooVGoo003oOongOol00?mookMoo`00ogoo]goo003oOongOol00001\
\>"],
  ImageRangeCache->{{{0, 437.75}, {131.375, 0}} -> {-0.112027, -0.0301894, 
  0.00964948, 0.00964948}, {{11.5625, 108}, {128.188, 
  68.625}} -> {-3.72406, -1.55665, 0.102134, 0.0472161}, {{117.625, 214}, {
  128.188, 68.625}} -> {-14.5697, -1.55805, 0.102226, 0.0472587}, {{223.688, 
  320.063}, {128.188, 68.625}} -> {-25.4121, -1.55805, 0.102226, 
  0.0472587}, {{329.688, 426.125}, {128.188, 68.625}} -> {-36.2156, -1.55665, 
  0.102134, 0.0472161}, {{11.5625, 108}, {62.6875, 
  3.125}} -> {-2.99929, -3.48725, 0.0959163, 0.0443415}, {{117.625, 214}, {
  62.6875, 3.125}} -> {-14.5697, -4.65349, 0.102226, 0.0472587}, {{223.688, 
  320.063}, {62.6875, 3.125}} -> {-25.4121, -4.65349, 0.102226, 0.0472587}, {{
  329.688, 426.125}, {62.6875, 3.125}} -> {-36.2156, -4.6493, 0.102134, 
  0.0472161}}]
}, Open  ]],

Cell[TextData[{
  "The Hadamard family of sequences may be thought of as sampled rectangular \
waves, thus (1) may be interpreted as a decomposition of a signal by \
rectangular waveforms. This should be compared and contrasted with the \
familar Fourier series decomposition by sine-cosine waveforms. The number of \
zero crossings (divided by two) of the Hadamard functions is known as the ",
  StyleBox["sequency,",
    FontSlant->"Italic"],
  " in analogy with the concept of frequency in the context of sinusoidal \
signals. An examination of the plots of the Hadamard ",
  Cell[BoxData[
      \(TraditionalForm\`N = 8\)]],
  " basis sequences, reveals however that they are not sequency ordered. We \
can use the function ",
  StyleBox["Sequency", "Program"],
  " to count the number of zero-crossings,"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Sequency\ /@\ HadamardKernel[8]\)], "Input"],

Cell[BoxData[
    \({0, 7, 3, 4, 1, 6, 2, 5}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "If a sequency-ordered Hadamard transformation is desired, it may be \
obtained by modifying the definition of the Hadamard basis sequences in \
(1)-(3). The series definition of the ",
  Cell[BoxData[
      \(TraditionalForm\`N = 2\^n\)]],
  " point sequency ordered Hadamard transform is "
}], "Text"],

Cell[TextData[{
  " ",
  Cell[BoxData[
      \(TraditionalForm
      \`X[k]\  = \ 
        1\/\@N\ \(\[Sum]\+\(n = 0\)\%\(N - 1\)x[n]\ 
              \((\(-1\))\)\^\(\[Sum]\+\(i = 0\)\%\(m - 1\)\ 
                  \(\(b\_i\)(n)\)\ \(\(p\_i\)(k)\)\ \)\)\)]],
  ",\t\tfor  ",
  Cell[BoxData[
      \(TraditionalForm\`k\  = \ 0, 1,  ... , N - 1\)]]
}], "NumberedEquation"],

Cell[TextData[{
  " ",
  Cell[BoxData[
      \(TraditionalForm
      \`x[n]\  = \ 
        1\/\@N\ \(\[Sum]\+\(n = 0\)\%\(N - 1\)X[n]\ 
              \((\(-1\))\)\^\(\[Sum]\+\(i = 0\)\%\(m - 1\)\ 
                  \(\(b\_i\)(n)\)\ \(\(p\_i\)(k)\)\ \)\)\)]],
  ",\t\tfor  ",
  Cell[BoxData[
      \(TraditionalForm\`n\  = \ 0, 1,  ... , N - 1\)]]
}], "NumberedEquation"],

Cell["where", "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(p\_0\)(k)\  = \ \(b\_\(m - 1\)\)(k)\)]],
  "\n",
  Cell[BoxData[
      \(TraditionalForm
      \`\(p\_j\)(k)\  = \ \ 
        \(b\_\(m - j\)\)(k)\  + \ \(b\_\(m - j - 1\)\)(k)\)]],
  "\tfor \t",
  Cell[BoxData[
      \(TraditionalForm\`j = 1, \ 2, \  ... , \ m - 1\)]]
}], "NumberedEquation"],

Cell["Using the new definition, we get", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Sequency\ /@\ HadamardKernel[8, \ SequencyOrdered -> True]\)], "Input"],

Cell[BoxData[
    \({0, 1, 2, 3, 4, 5, 6, 7}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["TWO-DIMENSIONAL WALSH-HADAMARD TRANSFORM", "Section"],

Cell[" The series form of the 2-D Hadamard transform is ", "Text"],

Cell[TextData[{
  " ",
  Cell[BoxData[
      \(TraditionalForm
      \`X[k\_1, \ k\_2]\  = \ 
        1\/N\ \(\[Sum]\+\(n\_1 = 0\)\%\(N - 1
                \)\(\[Sum]\+\(n\_2 = 0\)\%\(N - 1\)x[n\_1, \ n\_2]\ 
                \((\(-1\))
                    \)\^\(\[Sum]\+\(i = 0\)\%\(m - 1\)\((
                      \(\(b\_i\)(n\_1)\)\ \(\(b\_i\)(k\_1)\)\  + \ 
                        \(\(b\_i\)(n\_2)\)\ \(\(b\_i\)(k\_2)\))\)\)\)\)\)]],
  ",  for  ",
  Cell[BoxData[
      \(TraditionalForm\`k\_1, \ k\_2\  = \ 0, 1,  ... , N - 1\)]]
}], "NumberedEquation"],

Cell[TextData[{
  " ",
  Cell[BoxData[
      \(TraditionalForm
      \`x[n\_1, \ n\_2]\  = \ 
        1\/N\ \(\[Sum]\+\(k\_1 = 0\)\%\(N - 1
                \)\(\[Sum]\+\(k\_2 = 0\)\%\(N - 1\)X[k\_1, \ k\_2]\ \ 
                \((\(-1\))
                    \)\^\(\[Sum]\+\(i = 0\)\%\(m - 1\)\((
                      \(\(b\_i\)(n\_1)\)\ \(\(b\_i\)(k\_1)\)\  + \ 
                        \(\(b\_i\)(n\_2)\)\ \(\(b\_i\)(k\_2)\))\)\)\)\)\)]],
  ",   for  ",
  Cell[BoxData[
      \(TraditionalForm\`n\_1, \ n\_2\  = \ 0, 1,  ... , N - 1\)]]
}], "NumberedEquation"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      FormBox[
        RowBox[{"N", " ", "=", " ", 
          FormBox[\(2\^n\),
            "TraditionalForm"]}], TraditionalForm]]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(b\_i\)(z)\ \)\)]],
  " is the ",
  Cell[BoxData[
      \(TraditionalForm\`i\)]],
  "-th bit in the binary representation of ",
  Cell[BoxData[
      \(TraditionalForm\`z\)]],
  ". The addition of the bits ",
  Cell[BoxData[
      \(TraditionalForm\`b\_i\)]],
  " in the exponent of (-1) is in modulo-2 arithmetic. The 2D transform is \
separable. In analogy with the 1D case, any real 2D sequence with dimensions \
",
  Cell[BoxData[
      \(TraditionalForm\`N\ x\ N\)]],
  " may be represented by a superposition of ",
  Cell[BoxData[
      \(TraditionalForm\`N\^2\)]],
  " distinct, separable, bi-variate Hadamard basis images. With ",
  Cell[BoxData[
      \(TraditionalForm\`N = 4\)]],
  ", the 16 basis images may be formed from the outer products of the rows \
and columns of the ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalH]\_4\)]],
  " Hadamard kernel. Here we define a 4x4 Hadamard kernel."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\((\[ScriptCapitalH]\_4 = HadamardKernel[4, \ SequencyOrdered -> True])
        \) // MatrixForm\)], "Input",
  CellLabel->"In[27]:="],

Cell[BoxData[
    TagBox[
      RowBox[{"(", GridBox[{
            {\(1\/2\), \(1\/2\), \(1\/2\), \(1\/2\)},
            {\(1\/2\), \(1\/2\), \(-\(1\/2\)\), \(-\(1\/2\)\)},
            {\(1\/2\), \(-\(1\/2\)\), \(-\(1\/2\)\), \(1\/2\)},
            {\(1\/2\), \(-\(1\/2\)\), \(1\/2\), \(-\(1\/2\)\)}
            }], ")"}],
      (MatrixForm[ #]&)]], "Output",
  CellLabel->"Out[27]//MatrixForm="]
}, Open  ]],

Cell["Here we calculate the basis images. ", "Text"],

Cell[BoxData[
    \(\(hbasis = 
      Table[Outer[Times, 
          \[ScriptCapitalH]\_4\[LeftDoubleBracket]i\[RightDoubleBracket], 
          \[ScriptCapitalH]\_4\[LeftDoubleBracket]j\[RightDoubleBracket]], {
          i, 4}, {j, 4}]; \)\)], "Input",
  CellLabel->"In[28]:="],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[
      GraphicsArray[
        Map[ListDensityPlot[4\ Reverse[#], Mesh \[Rule] False, 
              PlotRange \[Rule] {\(-1\), 1}, FrameTicks \[Rule] None, 
              DisplayFunction \[Rule] Identity]&, hbasis, {2}]]]; \)\)], 
  "Input",
  CellLabel->"In[29]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0.0238095 0.238095 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0238095 0.245293 0.245293 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.240385 0.0192308 0.240385 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
00000000
FFFFFFFF
00000000
FFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.267442 0.0238095 0.488926 0.245293 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.240385 0.0192308 0.240385 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
0000FFFF
FFFF0000
0000FFFF
FFFF0000
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.511074 0.0238095 0.732558 0.245293 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.240385 0.0192308 0.240385 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
00FFFF00
FF0000FF
00FFFF00
FF0000FF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.754707 0.0238095 0.97619 0.245293 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.240385 0.0192308 0.240385 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
00FF00FF
FF00FF00
00FF00FF
FF00FF00
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.267442 0.245293 0.488926 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.240385 0.0192308 0.240385 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFF
00000000
00000000
FFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.267442 0.267442 0.488926 0.488926 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.240385 0.0192308 0.240385 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFF0000
0000FFFF
0000FFFF
FFFF0000
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.511074 0.267442 0.732558 0.488926 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.240385 0.0192308 0.240385 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF0000FF
00FFFF00
00FFFF00
FF0000FF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.754707 0.267442 0.97619 0.488926 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.240385 0.0192308 0.240385 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF00FF00
00FF00FF
00FF00FF
FF00FF00
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.511074 0.245293 0.732558 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.240385 0.0192308 0.240385 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
00000000
00000000
FFFFFFFF
FFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.267442 0.511074 0.488926 0.732558 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.240385 0.0192308 0.240385 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
0000FFFF
0000FFFF
FFFF0000
FFFF0000
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.511074 0.511074 0.732558 0.732558 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.240385 0.0192308 0.240385 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
00FFFF00
00FFFF00
FF0000FF
FF0000FF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.754707 0.511074 0.97619 0.732558 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.240385 0.0192308 0.240385 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
00FF00FF
00FF00FF
FF00FF00
FF00FF00
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.754707 0.245293 0.97619 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.240385 0.0192308 0.240385 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFF
FFFFFFFF
FFFFFFFF
FFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.267442 0.754707 0.488926 0.97619 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.240385 0.0192308 0.240385 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFF0000
FFFF0000
FFFF0000
FFFF0000
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.511074 0.754707 0.732558 0.97619 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.240385 0.0192308 0.240385 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF0000FF
FF0000FF
FF0000FF
FF0000FF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.754707 0.754707 0.97619 0.97619 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.240385 0.0192308 0.240385 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF00FF00
FF00FF00
FF00FF00
FF00FF00
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[29]:=",
  ImageSize->{216, 216},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003H0000f1000`40O003h00Of7oo003HOol00=Qo
o`00f7oo003HOol00=Qoo`001Goo<00017oo<0001Goo<00017oo<0001Woo0005Ool00`00Oomoo`0/
Ool00`00Oomoo`02Ool00`00Oomoo`0/Ool00`00Oomoo`03Ool00`00Oomoo`0/Ool00`00Oomoo`02
Ool00`00Oomoo`0/Ool00`00Oomoo`04Ool000Eoobh00003Ool007oo00=ooaP001Moo`03001oogoo
00=oo`/001Moo``00003Ool007oo00=oo``000]oo``000aoo`03001oogoo00Aoo`001Goo;P0000=o
o`00Ool00goo60005goo00<007ooOol00goo2`005goo300000=oo`00Ool00goo30002goo300037oo
00<007ooOol017oo0005Ool^00000goo001oo`03OolH000GOol00`00Oomoo`03Ool;000GOol<0000
0goo001oo`03Ool<000;Ool<000<Ool00`00Oomoo`04Ool000Eoobh00003Ool007oo00=ooaP001Mo
o`03001oogoo00=oo`/001Moo``00003Ool007oo00=oo``000]oo``000aoo`03001oogoo00Aoo`00
1Goo;P0000=oo`00Ool00goo60005goo00<007ooOol00goo2`005goo300000=oo`00Ool00goo3000
2goo300037oo00<007ooOol017oo0005Ool^00000goo001oo`03OolH000GOol00`00Oomoo`03Ool;
000GOol<00000goo001oo`03Ool<000;Ool<000<Ool00`00Oomoo`04Ool000Eoobh00003Ool007oo
00=ooaP001Moo`03001oogoo00=oo`/001Moo``00003Ool007oo00=oo``000]oo``000aoo`03001o
ogoo00Aoo`001Goo;P0000=oo`00Ool00goo60005goo00<007ooOol00goo2`005goo300000=oo`00
Ool00goo30002goo300037oo00<007ooOol017oo0005Ool^00000goo001oo`03OolH000GOol00`00
Oomoo`03Ool;000GOol<00000goo001oo`03Ool<000;Ool<000<Ool00`00Oomoo`04Ool000Eoobh0
0003Ool007oo00=ooaP001Moo`03001oogoo00=oo`/001Moo``00003Ool007oo00=oo``000]oo``0
00aoo`03001oogoo00Aoo`001Goo;P0000=oo`00Ool00goo60005goo00<007ooOol00goo2`005goo
300000=oo`00Ool00goo30002goo300037oo00<007ooOol017oo0005Ool00`00Oomoo`0/Ool00`00
Oomoo`02Ool00`00Oomoo`0EOolH000@OolG000=Ool00`00Oomoo`02Ool00`00Oomoo`09Ool;000<
Ool;00000goo001oo`05Ool000Eoo`03001oogoo02aoo`03001oogoo009oo`03001oogoo01EooaP0
011ooaL000eoo`03001oogoo009oo`03001oogoo00Uoo`/000aoo`/00003Ool007oo00Eoo`001Goo
00<007ooOol0;7oo00<007ooOol00Woo00<007ooOol05Goo600047oo5`003Goo00<007ooOol00Woo
00<007ooOol02Goo2`0037oo2`0000=oo`00Ool01Goo0005Ool00`00Oomoo`0/Ool00`00Oomoo`02
Ool00`00Oomoo`0EOolH000@OolG000=Ool00`00Oomoo`02Ool00`00Oomoo`09Ool;000<Ool;0000
0goo001oo`05Ool000Eoo`03001oogoo02aoo`03001oogoo009oo`03001oogoo01EooaP0011ooaL0
00eoo`03001oogoo009oo`03001oogoo00Uoo`/000aoo`/00003Ool007oo00Eoo`001Goo00<007oo
Ool0;7oo00<007ooOol00Woo00<007ooOol05Goo600047oo5`003Goo00<007ooOol00Woo00<007oo
Ool02Goo2`0037oo2`0000=oo`00Ool01Goo0005Ool00`00Oomoo`0/Ool00`00Oomoo`02Ool00`00
Oomoo`0EOolH000@OolG000=Ool00`00Oomoo`02Ool00`00Oomoo`09Ool;000<Ool;00000goo001o
o`05Ool000Eoo`03001oogoo02aoo`03001oogoo009oo`03001oogoo01EooaP0011ooaL000eoo`03
001oogoo009oo`03001oogoo00Uoo`/000aoo`/00003Ool007oo00Eoo`001Goo00<007ooOol0;7oo
00<007ooOol00Woo00<007ooOol05Goo600047oo5`003Goo00<007ooOol00Woo00<007ooOol02Goo
2`0037oo2`0000=oo`00Ool01Goo0005Ool00`00Oomoo`0/Ool00`00Oomoo`02Ool00`00Oomoo`0E
OolH000@OolG000=Ool00`00Oomoo`02Ool00`00Oomoo`09Ool;000<Ool;00000goo001oo`05Ool0
00Eoo`03001oogoo02aoo`03001oogoo009oo`03001oogoo01EooaP0011ooaL000eoo`03001oogoo
009oo`03001oogoo00Uoo`/000aoo`/00003Ool007oo00Eoo`001Goo00<007ooOol0;7oo00<007oo
Ool00Woo00<007ooOol05Goo600047oo5`003Goo00<007ooOol00Woo00<007ooOol02Goo2`0037oo
2`0000=oo`00Ool01Goo0005Ool^00000goo001oo`03OolH000GOol00`00Oomoo`03Ool;000GOol<
00000goo001oo`03Ool<000;Ool<000<Ool00`00Oomoo`04Ool000Eoobh00003Ool007oo00=ooaP0
01Moo`03001oogoo00=oo`/001Moo``00003Ool007oo00=oo``000]oo``000aoo`03001oogoo00Ao
o`001Goo;P0000=oo`00Ool00goo60005goo00<007ooOol00goo2`005goo300000=oo`00Ool00goo
30002goo300037oo00<007ooOol017oo0005Ool^00000goo001oo`03OolH000GOol00`00Oomoo`03
Ool;000GOol<00000goo001oo`03Ool<000;Ool<000<Ool00`00Oomoo`04Ool000Eoobh00003Ool0
07oo00=ooaP001Moo`03001oogoo00=oo`/001Moo``00003Ool007oo00=oo``000]oo``000aoo`03
001oogoo00Aoo`001Goo;P0000=oo`00Ool00goo60005goo00<007ooOol00goo2`005goo300000=o
o`00Ool00goo30002goo300037oo00<007ooOol017oo0005Ool^00000goo001oo`03OolH000GOol0
0`00Oomoo`03Ool;000GOol<00000goo001oo`03Ool<000;Ool<000<Ool00`00Oomoo`04Ool000Eo
obh00003Ool007oo00=ooaP001Moo`03001oogoo00=oo`/001Moo``00003Ool007oo00=oo``000]o
o``000aoo`03001oogoo00Aoo`001Goo;P0000=oo`00Ool00goo60005goo00<007ooOol00goo2`00
5goo300000=oo`00Ool00goo30002goo300037oo00<007ooOol017oo0005Ool^00000goo001oo`03
OolH000GOol00`00Oomoo`03Ool;000GOol<00000goo001oo`03Ool<000;Ool<000<Ool00`00Oomo
o`04Ool000Eoobh00003Ool007oo00=ooaP001Moo`03001oogoo00=oo`/001Moo``00003Ool007oo
00=oo``000]oo``000aoo`03001oogoo00Aoo`001Goo00<007ooOol0;7oo00<007ooOol00Woo00<0
07ooOol05Goo600047oo5`003Goo00<007ooOol00Woo00<007ooOol02Goo2`0037oo2`0000=oo`00
Ool01Goo0005Ool00`00Oomoo`0/Ool00`00Oomoo`02Ool00`00Oomoo`0EOolH000@OolG000=Ool0
0`00Oomoo`02Ool00`00Oomoo`09Ool;000<Ool;00000goo001oo`05Ool000Eoo`03001oogoo02ao
o`03001oogoo009oo`03001oogoo01EooaP0011ooaL000eoo`03001oogoo009oo`03001oogoo00Uo
o`/000aoo`/00003Ool007oo00Eoo`001Goo00<007ooOol0;7oo00<007ooOol00Woo00<007ooOol0
5Goo600047oo5`003Goo00<007ooOol00Woo00<007ooOol02Goo2`0037oo2`0000=oo`00Ool01Goo
0005Ool00`00Oomoo`0/Ool00`00Oomoo`02Ool00`00Oomoo`0EOolH000@OolG000=Ool00`00Oomo
o`02Ool00`00Oomoo`09Ool;000<Ool;00000goo001oo`05Ool000Eoo`03001oogoo02aoo`03001o
ogoo009oo`03001oogoo01EooaP0011ooaL000eoo`03001oogoo009oo`03001oogoo00Uoo`/000ao
o`/00003Ool007oo00Eoo`001Goo00<007ooOol0;7oo00<007ooOol00Woo00<007ooOol05Goo6000
47oo5`003Goo00<007ooOol00Woo00<007ooOol02Goo2`0037oo2`0000=oo`00Ool01Goo0005Ool0
0`00Oomoo`0/Ool00`00Oomoo`02Ool00`00Oomoo`0EOolH000@OolG000=Ool00`00Oomoo`02Ool0
0`00Oomoo`09Ool;000<Ool;00000goo001oo`05Ool000Eoo`03001oogoo02aoo`03001oogoo009o
o`03001oogoo01EooaP0011ooaL000eoo`03001oogoo009oo`03001oogoo00Uoo`/000aoo`/00003
Ool007oo00Eoo`001Goo00<007ooOol0;7oo00<007ooOol00Woo00<007ooOol05Goo600047oo5`00
3Goo00<007ooOol00Woo00<007ooOol02Goo2`0037oo2`0000=oo`00Ool01Goo0005Ool00`00Oomo
o`0/Ool00`00Oomoo`02Ool00`00Oomoo`0EOolH000@OolG000=Ool00`00Oomoo`02Ool00`00Oomo
o`09Ool;000<Ool;00000goo001oo`05Ool000Eooc0000Aooc0000Eooc0000Aooc0000Ioo`00f7oo
003HOol00=Qoo`00f7oo0005Ool`0004Ool`0005Ool`0004Ool`0006Ool000Eoo`03001oogoo02ao
o`03001oogoo009oo`03001oogoo02aoo`03001oogoo00=oo`03001oogoo02aoo`03001oogoo009o
o`03001oogoo02aoo`03001oogoo00Aoo`001Goo00<007ooOol0;7oo00<007ooOol00Woo00<007oo
Ool05Goo600047oo5`003Goo00<007ooOol00Woo00<007ooOol02Goo2`0037oo2`0000=oo`00Ool0
1Goo0005Ool00`00Oomoo`0/Ool00`00Oomoo`02Ool00`00Oomoo`0EOolH000@OolG000=Ool00`00
Oomoo`02Ool00`00Oomoo`09Ool;000<Ool;00000goo001oo`05Ool000Eoo`03001oogoo02aoo`03
001oogoo009oo`03001oogoo01EooaP0011ooaL000eoo`03001oogoo009oo`03001oogoo00Uoo`/0
00aoo`/00003Ool007oo00Eoo`001Goo00<007ooOol0;7oo00<007ooOol00Woo00<007ooOol05Goo
600047oo5`003Goo00<007ooOol00Woo00<007ooOol02Goo2`0037oo2`0000=oo`00Ool01Goo0005
Ool00`00Oomoo`0/Ool00`00Oomoo`02Ool00`00Oomoo`0EOolH000@OolG000=Ool00`00Oomoo`02
Ool00`00Oomoo`09Ool;000<Ool;00000goo001oo`05Ool000Eoo`03001oogoo02aoo`03001oogoo
009oo`03001oogoo01EooaP0011ooaL000eoo`03001oogoo009oo`03001oogoo00Uoo`/000aoo`/0
0003Ool007oo00Eoo`001Goo00<007ooOol0;7oo00<007ooOol00Woo00<007ooOol05Goo600047oo
5`003Goo00<007ooOol00Woo00<007ooOol02Goo2`0037oo2`0000=oo`00Ool01Goo0005Ool00`00
Oomoo`0/Ool00`00Oomoo`02Ool00`00Oomoo`0EOolH000@OolG000=Ool00`00Oomoo`02Ool00`00
Oomoo`09Ool;000<Ool;00000goo001oo`05Ool000Eoo`03001oogoo02aoo`03001oogoo009oo`03
001oogoo01EooaP0011ooaL000eoo`03001oogoo009oo`03001oogoo00Uoo`/000aoo`/00003Ool0
07oo00Eoo`001Goo00<007ooOol0;7oo00<007ooOol00Woo00<007ooOol05Goo600047oo5`003Goo
00<007ooOol00Woo00<007ooOol02Goo2`0037oo2`0000=oo`00Ool01Goo0005Ool00`00Oomoo`0/
Ool00`00Oomoo`02Ool00`00Oomoo`0EOolH000@OolG000=Ool00`00Oomoo`02Ool00`00Oomoo`09
Ool;000<Ool;00000goo001oo`05Ool000Eoo`03001oogoo02aoo`03001oogoo009oo`03001oogoo
01EooaP0011ooaL000eoo`03001oogoo009oo`03001oogoo00Uoo`/000aoo`/00003Ool007oo00Eo
o`001Goo;P0000=oo`00Ool00goo60005goo00<007ooOol00goo2`005goo300000=oo`00Ool00goo
30002goo300037oo00<007ooOol017oo0005Ool^00000goo001oo`03OolH000GOol00`00Oomoo`03
Ool;000GOol<00000goo001oo`03Ool<000;Ool<000<Ool00`00Oomoo`04Ool000Eoobh00003Ool0
07oo00=ooaP001Moo`03001oogoo00=oo`/001Moo``00003Ool007oo00=oo``000]oo``000aoo`03
001oogoo00Aoo`001Goo;P0000=oo`00Ool00goo60005goo00<007ooOol00goo2`005goo300000=o
o`00Ool00goo30002goo300037oo00<007ooOol017oo0005Ool^00000goo001oo`03OolH000GOol0
0`00Oomoo`03Ool;000GOol<00000goo001oo`03Ool<000;Ool<000<Ool00`00Oomoo`04Ool000Eo
obh00003Ool007oo00=ooaP001Moo`03001oogoo00=oo`/001Moo``00003Ool007oo00=oo``000]o
o``000aoo`03001oogoo00Aoo`001Goo;P0000=oo`00Ool00goo60005goo00<007ooOol00goo2`00
5goo300000=oo`00Ool00goo30002goo300037oo00<007ooOol017oo0005Ool^00000goo001oo`03
OolH000GOol00`00Oomoo`03Ool;000GOol<00000goo001oo`03Ool<000;Ool<000<Ool00`00Oomo
o`04Ool000Eoobh00003Ool007oo00=ooaP001Moo`03001oogoo00=oo`/001Moo``00003Ool007oo
00=oo``000]oo``000aoo`03001oogoo00Aoo`001Goo;P0000=oo`00Ool00goo60005goo00<007oo
Ool00goo2`005goo300000=oo`00Ool00goo30002goo300037oo00<007ooOol017oo0005Ool^0000
0goo001oo`03OolH000GOol00`00Oomoo`03Ool;000GOol<00000goo001oo`03Ool<000;Ool<000<
Ool00`00Oomoo`04Ool000Eoobh00003Ool007oo00=ooaP001Moo`03001oogoo00=oo`/001Moo``0
0003Ool007oo00=oo``000]oo``000aoo`03001oogoo00Aoo`001Goo;P0000=oo`00Ool00goo6000
5goo00<007ooOol00goo2`005goo300000=oo`00Ool00goo30002goo300037oo00<007ooOol017oo
0005Ool^00000goo001oo`03OolH000GOol00`00Oomoo`03Ool;000GOol<00000goo001oo`03Ool<
000;Ool<000<Ool00`00Oomoo`04Ool000Eoobh00003Ool007oo00=ooaP001Moo`03001oogoo00=o
o`/001Moo``00003Ool007oo00=oo``000]oo``000aoo`03001oogoo00Aoo`001Goo;P0000=oo`00
Ool00goo60005goo00<007ooOol00goo2`005goo300000=oo`00Ool00goo30002goo300037oo00<0
07ooOol017oo0005Ool^00000goo001oo`03OolH000GOol00`00Oomoo`03Ool;000GOol<00000goo
001oo`03Ool<000;Ool<000<Ool00`00Oomoo`04Ool000Eoobh00003Ool007oo00=ooaP001Moo`03
001oogoo00=oo`/001Moo``00003Ool007oo00=oo``000]oo``000aoo`03001oogoo00Aoo`001Goo
;P0000=oo`00Ool00goo60005goo00<007ooOol00goo2`005goo300000=oo`00Ool00goo30002goo
300037oo00<007ooOol017oo0005Ool^00000goo001oo`03OolH000GOol00`00Oomoo`03Ool;000G
Ool<00000goo001oo`03Ool<000;Ool<000<Ool00`00Oomoo`04Ool000Eoobh00003Ool007oo00=o
oaP001Moo`03001oogoo00=oo`/001Moo``00003Ool007oo00=oo``000]oo``000aoo`03001oogoo
00Aoo`001Goo;P0000=oo`00Ool00goo60005goo00<007ooOol00goo2`005goo300000=oo`00Ool0
0goo30002goo300037oo00<007ooOol017oo0005Ool^00000goo001oo`03OolH000GOol00`00Oomo
o`03Ool;000GOol<00000goo001oo`03Ool<000;Ool<000<Ool00`00Oomoo`04Ool000Eoo`03001o
ogoo02aoo`03001oogoo009oo`03001oogoo01EooaP0011ooaL000eoo`03001oogoo009oo`03001o
ogoo00Uoo`/000aoo`/00003Ool007oo00Eoo`001Goo00<007ooOol0;7oo00<007ooOol00Woo00<0
07ooOol05Goo600047oo5`003Goo00<007ooOol00Woo00<007ooOol02Goo2`0037oo2`0000=oo`00
Ool01Goo0005Ool00`00Oomoo`0/Ool00`00Oomoo`02Ool00`00Oomoo`0EOolH000@OolG000=Ool0
0`00Oomoo`02Ool00`00Oomoo`09Ool;000<Ool;00000goo001oo`05Ool000Eoo`03001oogoo02ao
o`03001oogoo009oo`03001oogoo01EooaP0011ooaL000eoo`03001oogoo009oo`03001oogoo00Uo
o`/000aoo`/00003Ool007oo00Eoo`001Goo00<007ooOol0;7oo00<007ooOol00Woo00<007ooOol0
5Goo600047oo5`003Goo00<007ooOol00Woo00<007ooOol02Goo2`0037oo2`0000=oo`00Ool01Goo
0005Ool00`00Oomoo`0/Ool00`00Oomoo`02Ool00`00Oomoo`0EOolH000@OolG000=Ool00`00Oomo
o`02Ool00`00Oomoo`09Ool;000<Ool;00000goo001oo`05Ool000Eoo`03001oogoo02aoo`03001o
ogoo009oo`03001oogoo01EooaP0011ooaL000eoo`03001oogoo009oo`03001oogoo00Uoo`/000ao
o`/00003Ool007oo00Eoo`001Goo00<007ooOol0;7oo00<007ooOol00Woo00<007ooOol05Goo6000
47oo5`003Goo00<007ooOol00Woo00<007ooOol02Goo2`0037oo2`0000=oo`00Ool01Goo0005Ool0
0`00Oomoo`0/Ool00`00Oomoo`02Ool00`00Oomoo`0EOolH000@OolG000=Ool00`00Oomoo`02Ool0
0`00Oomoo`09Ool;000<Ool;00000goo001oo`05Ool000Eoo`03001oogoo02aoo`03001oogoo009o
o`03001oogoo01EooaP0011ooaL000eoo`03001oogoo009oo`03001oogoo00Uoo`/000aoo`/00003
Ool007oo00Eoo`001Goo00<007ooOol0:goo0P0017oo00<007ooOol05Goo600047oo5`0037oo0P00
17oo00<007ooOol02Goo2`0037oo3@001Woo003HOol00=Qoo`00f7oo003HOol00=Qoo`001Goo<000
17oo<0001Goo<00017oo<0001Woo0005Ool^00000goo001oo`03OolH000GOol00`00Oomoo`03Ool;
000GOol<00000goo001oo`03Ool<000;Ool<000<Ool00`00Oomoo`04Ool000Eoobh00003Ool007oo
00=ooaP001Moo`03001oogoo00=oo`/001Moo``00003Ool007oo00=oo``000]oo``000aoo`03001o
ogoo00Aoo`001Goo;P0000=oo`00Ool00goo60005goo00<007ooOol00goo2`005goo300000=oo`00
Ool00goo30002goo300037oo00<007ooOol017oo0005Ool^00000goo001oo`03OolH000GOol00`00
Oomoo`03Ool;000GOol<00000goo001oo`03Ool<000;Ool<000<Ool00`00Oomoo`04Ool000Eoobh0
0003Ool007oo00=ooaP001Moo`03001oogoo00=oo`/001Moo``00003Ool007oo00=oo``000]oo``0
00aoo`03001oogoo00Aoo`001Goo;P0000=oo`00Ool00goo60005goo00<007ooOol00goo2`005goo
300000=oo`00Ool00goo30002goo300037oo00<007ooOol017oo0005Ool^00000goo001oo`03OolH
000GOol00`00Oomoo`03Ool;000GOol<00000goo001oo`03Ool<000;Ool<000<Ool00`00Oomoo`04
Ool000Eoobh00003Ool007oo00=ooaP001Moo`03001oogoo00=oo`/001Moo``00003Ool007oo00=o
o``000]oo``000aoo`03001oogoo00Aoo`001Goo;P0000=oo`00Ool00goo60005goo00<007ooOol0
0goo2`005goo300000=oo`00Ool00goo30002goo300037oo00<007ooOol017oo0005Ool^00000goo
001oo`03OolH000GOol00`00Oomoo`03Ool;000GOol<00000goo001oo`03Ool<000;Ool<000<Ool0
0`00Oomoo`04Ool000Eoobh00003Ool007oo00=ooaP001Moo`03001oogoo00=oo`/001Moo``00003
Ool007oo00=oo``000]oo``000aoo`03001oogoo00Aoo`001Goo;P0000=oo`00Ool00goo60005goo
00<007ooOol00goo2`005goo300000=oo`00Ool00goo30002goo300037oo00<007ooOol017oo0005
Ool^00000goo001oo`03OolH000GOol00`00Oomoo`03Ool;000GOol<00000goo001oo`03Ool<000;
Ool<000<Ool00`00Oomoo`04Ool000Eoobh00003Ool007oo00=ooaP001Moo`03001oogoo00=oo`/0
01Moo``00003Ool007oo00=oo``000]oo``000aoo`03001oogoo00Aoo`001Goo;P0000=oo`00Ool0
0goo60005goo00<007ooOol00goo2`005goo300000=oo`00Ool00goo30002goo300037oo00<007oo
Ool017oo0005Ool^00000goo001oo`03OolH000GOol00`00Oomoo`03Ool;000GOol<00000goo001o
o`03Ool<000;Ool<000<Ool00`00Oomoo`04Ool000Eoobh00003Ool007oo00=ooaP001Moo`03001o
ogoo00=oo`/001Moo``00003Ool007oo00=oo``000]oo``000aoo`03001oogoo00Aoo`001Goo;P00
00=oo`00Ool00goo60005goo00<007ooOol00goo2`005goo300000=oo`00Ool00goo30002goo3000
37oo00<007ooOol017oo0005Ool^00000goo001oo`03OolH000GOol00`00Oomoo`03Ool;000GOol<
00000goo001oo`03Ool<000;Ool<000<Ool00`00Oomoo`04Ool000Eoobh00003Ool007oo00=ooaP0
01Moo`03001oogoo00=oo`/001Moo``00003Ool007oo00=oo``000]oo``000aoo`03001oogoo00Ao
o`001Goo;P0000=oo`00Ool00goo60005goo00<007ooOol00goo2`005goo300000=oo`00Ool00goo
30002goo300037oo00<007ooOol017oo0005Ool^00000goo001oo`03OolH000GOol00`00Oomoo`03
Ool;000GOol<00000goo001oo`03Ool<000;Ool<000<Ool00`00Oomoo`04Ool000Eoobh00003Ool0
07oo00=ooaP001Moo`03001oogoo00=oo`/001Moo``00003Ool007oo00=oo``000]oo``000aoo`03
001oogoo00Aoo`001Goo00<007ooOol0;7oo00<007ooOol00Woo00<007ooOol05Goo600047oo5`00
3Goo00<007ooOol00Woo00<007ooOol02Goo2`0037oo2`0000=oo`00Ool01Goo0005Ool00`00Oomo
o`0/Ool00`00Oomoo`02Ool00`00Oomoo`0EOolH000@OolG000=Ool00`00Oomoo`02Ool00`00Oomo
o`09Ool;000<Ool;00000goo001oo`05Ool000Eoo`03001oogoo02aoo`03001oogoo009oo`03001o
ogoo01EooaP0011ooaL000eoo`03001oogoo009oo`03001oogoo00Uoo`/000aoo`/00003Ool007oo
00Eoo`001Goo00<007ooOol0;7oo00<007ooOol00Woo00<007ooOol05Goo600047oo5`003Goo00<0
07ooOol00Woo00<007ooOol02Goo2`0037oo2`0000=oo`00Ool01Goo0005Ool00`00Oomoo`0/Ool0
0`00Oomoo`02Ool00`00Oomoo`0EOolH000@OolG000=Ool00`00Oomoo`02Ool00`00Oomoo`09Ool;
000<Ool;00000goo001oo`05Ool000Eoo`03001oogoo02aoo`03001oogoo009oo`03001oogoo01Eo
oaP0011ooaL000eoo`03001oogoo009oo`03001oogoo00Uoo`/000aoo`/00003Ool007oo00Eoo`00
1Goo00<007ooOol0;7oo00<007ooOol00Woo00<007ooOol05Goo600047oo5`003Goo00<007ooOol0
0Woo00<007ooOol02Goo2`0037oo2`0000=oo`00Ool01Goo0005Ool00`00Oomoo`0/Ool00`00Oomo
o`02Ool00`00Oomoo`0EOolH000@OolG000=Ool00`00Oomoo`02Ool00`00Oomoo`09Ool;000<Ool;
00000goo001oo`05Ool000Eoo`03001oogoo02aoo`03001oogoo009oo`03001oogoo01EooaP0011o
oaL000eoo`03001oogoo009oo`03001oogoo00Uoo`/000aoo`/00003Ool007oo00Eoo`001Goo00<0
07ooOol0;7oo00<007ooOol00Woo00<007ooOol05Goo600047oo5`003Goo00<007ooOol00Woo00<0
07ooOol02Goo2`0037oo2`0000=oo`00Ool01Goo0005Ool00`00Oomoo`0/Ool00`00Oomoo`02Ool0
0`00Oomoo`0EOolH000@OolG000=Ool00`00Oomoo`02Ool00`00Oomoo`09Ool;000<Ool;00000goo
001oo`05Ool000Eoo`03001oogoo02aoo`03001oogoo009oo`03001oogoo01EooaP0011ooaL000eo
o`03001oogoo009oo`03001oogoo00Uoo`/000aoo`/00003Ool007oo00Eoo`001Goo00<007ooOol0
;7oo00<007ooOol00Woo00<007ooOol05Goo600047oo5`003Goo00<007ooOol00Woo00<007ooOol0
2Goo2`0037oo2`0000=oo`00Ool01Goo0005Ool00`00Oomoo`0/Ool00`00Oomoo`02Ool00`00Oomo
o`0EOolH000@OolG000=Ool00`00Oomoo`02Ool00`00Oomoo`09Ool;000<Ool;00000goo001oo`05
Ool000Eoo`03001oogoo02aoo`03001oogoo009oo`03001oogoo01EooaP0011ooaL000eoo`03001o
ogoo009oo`03001oogoo00Uoo`/000aoo`/00003Ool007oo00Eoo`001Goo00<007ooOol0;7oo00<0
07ooOol00Woo00<007ooOol05Goo600047oo5`003Goo00<007ooOol00Woo00<007ooOol02Goo2`00
37oo2`0000=oo`00Ool01Goo0005Ool00`00Oomoo`0/Ool00`00Oomoo`02Ool00`00Oomoo`0EOolH
000@OolG000=Ool00`00Oomoo`02Ool00`00Oomoo`09Ool;000<Ool;00000goo001oo`05Ool000Eo
o`03001oogoo02aoo`03001oogoo009oo`03001oogoo01EooaP0011ooaL000eoo`03001oogoo009o
o`03001oogoo00Uoo`/000aoo`/00003Ool007oo00Eoo`001Goo00<007ooOol0;7oo00<007ooOol0
0Woo00<007ooOol05Goo600047oo5`003Goo00<007ooOol00Woo00<007ooOol02Goo2`0037oo2`00
00=oo`00Ool01Goo0005Ool00`00Oomoo`0/Ool00`00Oomoo`02Ool00`00Oomoo`0EOolH000@OolG
000=Ool00`00Oomoo`02Ool00`00Oomoo`09Ool;000<Ool;00000goo001oo`05Ool000Eoo`03001o
ogoo02aoo`03001oogoo009oo`03001oogoo01EooaP0011ooaL000eoo`03001oogoo009oo`03001o
ogoo00Uoo`/000aoo`/00003Ool007oo00Eoo`001Goo00<007ooOol0;7oo00<007ooOol00Woo00<0
07ooOol05Goo600047oo5`003Goo00<007ooOol00Woo00<007ooOol02Goo2`0037oo2`0000=oo`00
Ool01Goo0005Ool00`00Oomoo`0/Ool00`00Oomoo`02Ool00`00Oomoo`0EOolH000@OolG000=Ool0
0`00Oomoo`02Ool00`00Oomoo`09Ool;000<Ool;00000goo001oo`05Ool000Eooc0000Aooc0000Eo
oc0000Aooc0000Ioo`00f7oo003HOol00=Qoo`00f7oo0005Ool`0004Ool`0005Ool`0004Ool`0006
Ool000Eoo`03001oogoo02aoo`03001oogoo009oo`03001oogoo02aoo`03001oogoo00=oo`03001o
ogoo02aoo`03001oogoo009oo`03001oogoo02aoo`03001oogoo00Aoo`001Goo00<007ooOol0;7oo
00<007ooOol00Woo00<007ooOol05Goo600047oo5`003Goo00<007ooOol00Woo00<007ooOol02Goo
2`0037oo2`0000=oo`00Ool01Goo0005Ool00`00Oomoo`0/Ool00`00Oomoo`02Ool00`00Oomoo`0E
OolH000@OolG000=Ool00`00Oomoo`02Ool00`00Oomoo`09Ool;000<Ool;00000goo001oo`05Ool0
00Eoo`03001oogoo02aoo`03001oogoo009oo`03001oogoo01EooaP0011ooaL000eoo`03001oogoo
009oo`03001oogoo00Uoo`/000aoo`/00003Ool007oo00Eoo`001Goo00<007ooOol0;7oo00<007oo
Ool00Woo00<007ooOol05Goo600047oo5`003Goo00<007ooOol00Woo00<007ooOol02Goo2`0037oo
2`0000=oo`00Ool01Goo0005Ool00`00Oomoo`0/Ool00`00Oomoo`02Ool00`00Oomoo`0EOolH000@
OolG000=Ool00`00Oomoo`02Ool00`00Oomoo`09Ool;000<Ool;00000goo001oo`05Ool000Eoo`03
001oogoo02aoo`03001oogoo009oo`03001oogoo01EooaP0011ooaL000eoo`03001oogoo009oo`03
001oogoo00Uoo`/000aoo`/00003Ool007oo00Eoo`001Goo00<007ooOol0;7oo00<007ooOol00Woo
00<007ooOol05Goo600047oo5`003Goo00<007ooOol00Woo00<007ooOol02Goo2`0037oo2`0000=o
o`00Ool01Goo0005Ool00`00Oomoo`0/Ool00`00Oomoo`02Ool00`00Oomoo`0EOolH000@OolG000=
Ool00`00Oomoo`02Ool00`00Oomoo`09Ool;000<Ool;00000goo001oo`05Ool000Eoo`03001oogoo
02aoo`03001oogoo009oo`03001oogoo01EooaP0011ooaL000eoo`03001oogoo009oo`03001oogoo
00Uoo`/000aoo`/00003Ool007oo00Eoo`001Goo00<007ooOol0;7oo00<007ooOol00Woo00<007oo
Ool05Goo600047oo5`003Goo00<007ooOol00Woo00<007ooOol02Goo2`0037oo2`0000=oo`00Ool0
1Goo0005Ool00`00Oomoo`0/Ool00`00Oomoo`02Ool00`00Oomoo`0EOolH000@OolG000=Ool00`00
Oomoo`02Ool00`00Oomoo`09Ool;000<Ool;00000goo001oo`05Ool000Eoo`03001oogoo02aoo`03
001oogoo009oo`03001oogoo01EooaP0011ooaL000eoo`03001oogoo009oo`03001oogoo00Uoo`/0
00aoo`/00003Ool007oo00Eoo`001Goo00<007ooOol0;7oo00<007ooOol00Woo00<007ooOol05Goo
600047oo5`003Goo00<007ooOol00Woo00<007ooOol02Goo2`0037oo2`0000=oo`00Ool01Goo0005
Ool00`00Oomoo`0/Ool00`00Oomoo`02Ool00`00Oomoo`0EOolH000@OolG000=Ool00`00Oomoo`02
Ool00`00Oomoo`09Ool;000<Ool;00000goo001oo`05Ool000Eoo`03001oogoo02aoo`03001oogoo
009oo`03001oogoo01EooaP0011ooaL000eoo`03001oogoo009oo`03001oogoo00Uoo`/000aoo`/0
0003Ool007oo00Eoo`001Goo00<007ooOol0;7oo00<007ooOol00Woo00<007ooOol05Goo600047oo
5`003Goo00<007ooOol00Woo00<007ooOol02Goo2`0037oo2`0000=oo`00Ool01Goo0005Ool00`00
Oomoo`0/Ool00`00Oomoo`02Ool00`00Oomoo`0EOolH000@OolG000=Ool00`00Oomoo`02Ool00`00
Oomoo`09Ool;000<Ool;00000goo001oo`05Ool000Eoo`03001oogoo02aoo`03001oogoo009oo`03
001oogoo01EooaP0011ooaL000eoo`03001oogoo009oo`03001oogoo00Uoo`/000aoo`/00003Ool0
07oo00Eoo`001Goo00<007ooOol0;7oo00<007ooOol00Woo00<007ooOol05Goo600047oo5`003Goo
00<007ooOol00Woo00<007ooOol02Goo2`0037oo2`0000=oo`00Ool01Goo0005Ool00`00Oomoo`0/
Ool00`00Oomoo`02Ool00`00Oomoo`0EOolH000@OolG000=Ool00`00Oomoo`02Ool00`00Oomoo`09
Ool;000<Ool;00000goo001oo`05Ool000Eoo`03001oogoo02aoo`03001oogoo009oo`03001oogoo
01EooaP0011ooaL000eoo`03001oogoo009oo`03001oogoo00Uoo`/000aoo`/00003Ool007oo00Eo
o`001Goo00<007ooOol0;7oo00<007ooOol00Woo00<007ooOol05Goo600047oo5`003Goo00<007oo
Ool00Woo00<007ooOol02Goo2`0037oo2`0000=oo`00Ool01Goo0005Ool00`00Oomoo`0/Ool00`00
Oomoo`02Ool00`00Oomoo`0EOolH000@OolG000=Ool00`00Oomoo`02Ool00`00Oomoo`09Ool;000<
Ool;00000goo001oo`05Ool000Eoo`03001oogoo02aoo`03001oogoo009oo`03001oogoo01EooaP0
011ooaL000eoo`03001oogoo009oo`03001oogoo00Uoo`/000aoo`/00003Ool007oo00Eoo`001Goo
00<007ooOol0;7oo00<007ooOol00Woo00<007ooOol05Goo600047oo5`003Goo00<007ooOol00Woo
00<007ooOol02Goo2`0037oo2`0000=oo`00Ool01Goo0005Ool00`00Oomoo`0/Ool00`00Oomoo`02
Ool00`00Oomoo`0EOolH000@OolG000=Ool00`00Oomoo`02Ool00`00Oomoo`09Ool;000<Ool;0000
0goo001oo`05Ool000Eoo`03001oogoo02aoo`03001oogoo009oo`03001oogoo01EooaP0011ooaL0
00eoo`03001oogoo009oo`03001oogoo00Uoo`/000aoo`/00003Ool007oo00Eoo`001Goo00<007oo
Ool0;7oo00<007ooOol00Woo00<007ooOol05Goo600047oo5`003Goo00<007ooOol00Woo00<007oo
Ool02Goo2`0037oo2`0000=oo`00Ool01Goo0005Ool00`00Oomoo`0/Ool00`00Oomoo`02Ool00`00
Oomoo`0EOolH000@OolG000=Ool00`00Oomoo`02Ool00`00Oomoo`09Ool;000<Ool;00000goo001o
o`05Ool000Eoo`03001oogoo02aoo`03001oogoo009oo`03001oogoo01EooaP0011ooaL000eoo`03
001oogoo009oo`03001oogoo00Uoo`/000aoo`/00003Ool007oo00Eoo`001Goo00<007ooOol0;7oo
00<007ooOol00Woo00<007ooOol05Goo600047oo5`003Goo00<007ooOol00Woo00<007ooOol02Goo
2`0037oo2`0000=oo`00Ool01Goo0005Ool00`00Oomoo`0/Ool00`00Oomoo`02Ool00`00Oomoo`0E
OolH000@OolG000=Ool00`00Oomoo`02Ool00`00Oomoo`09Ool;000<Ool;00000goo001oo`05Ool0
00Eoo`03001oogoo02aoo`03001oogoo009oo`03001oogoo01EooaP0011ooaL000eoo`03001oogoo
009oo`03001oogoo00Uoo`/000aoo`/00003Ool007oo00Eoo`001Goo00<007ooOol0;7oo00<007oo
Ool00Woo00<007ooOol05Goo600047oo5`003Goo00<007ooOol00Woo00<007ooOol02Goo2`0037oo
2`0000=oo`00Ool01Goo0005Ool00`00Oomoo`0/Ool00`00Oomoo`02Ool00`00Oomoo`0EOolH000@
OolG000=Ool00`00Oomoo`02Ool00`00Oomoo`09Ool;000<Ool;00000goo001oo`05Ool000Eoo`03
001oogoo02aoo`03001oogoo009oo`03001oogoo01EooaP0011ooaL000eoo`03001oogoo009oo`03
001oogoo00Uoo`/000aoo`/00003Ool007oo00Eoo`001Goo00<007ooOol0;7oo00<007ooOol00Woo
00<007ooOol05Goo600047oo5`003Goo00<007ooOol00Woo00<007ooOol02Goo2`0037oo2`0000=o
o`00Ool01Goo0005Ool00`00Oomoo`0/Ool00`00Oomoo`02Ool00`00Oomoo`0EOolH000@OolG000=
Ool00`00Oomoo`02Ool00`00Oomoo`09Ool;000<Ool;00000goo001oo`05Ool000Eoo`03001oogoo
02aoo`03001oogoo009oo`03001oogoo01EooaP0011ooaL000eoo`03001oogoo009oo`03001oogoo
00Uoo`/000aoo`/00003Ool007oo00Eoo`001Goo00<007ooOol0;7oo00<007ooOol00Woo00<007oo
Ool05Goo600047oo5`003Goo00<007ooOol00Woo00<007ooOol02Goo2`0037oo2`0000=oo`00Ool0
1Goo0005Ool00`00Oomoo`0/Ool00`00Oomoo`02Ool00`00Oomoo`0EOolH000@OolG000=Ool00`00
Oomoo`02Ool00`00Oomoo`09Ool;000<Ool;00000goo001oo`05Ool000Eoo`03001oogoo02aoo`03
001oogoo009oo`03001oogoo01EooaP0011ooaL000eoo`03001oogoo009oo`03001oogoo00Uoo`/0
00aoo`/00003Ool007oo00Eoo`001Goo00<007ooOol0;7oo00<007ooOol00Woo00<007ooOol05Goo
600047oo5`003Goo00<007ooOol00Woo00<007ooOol02Goo2`0037oo2`0000=oo`00Ool01Goo0005
Ool00`00Oomoo`0/Ool00`00Oomoo`02Ool00`00Oomoo`0EOolH000@OolG000=Ool00`00Oomoo`02
Ool00`00Oomoo`09Ool;000<Ool;00000goo001oo`05Ool000Eoo`03001oogoo02aoo`03001oogoo
009oo`03001oogoo01EooaP0011ooaL000eoo`03001oogoo009oo`03001oogoo00Uoo`/000aoo`/0
0003Ool007oo00Eoo`001Goo<00017oo<0001Goo<00017oo<0001Woo003HOol00=Qoo`00f7oo003H
Ool00=Qoo`00\
\>"],
  ImageRangeCache->{{{0, 215}, {215, 0}} -> {-0.100021, -0.100021, 0.0195351, 
  0.0195351}, {{5.0625, 52.6875}, {209.875, 
  162.25}} -> {-0.535539, -0.541027, 0.0878108, 0.0878108}, {{57.5, 
  105.063}, {209.875, 162.25}} -> {-5.1468, -0.544384, 0.0879268, 
  0.0879268}, {{109.875, 157.5}, {209.875, 162.25}} -> {-9.73921, -0.541027, 
  0.0878108, 0.0878108}, {{162.25, 209.875}, {209.875, 
  162.25}} -> {-14.3383, -0.541027, 0.0878108, 0.0878108}, {{5.0625, 
  52.6875}, {157.5, 109.875}} -> {-0.535539, -5.14012, 0.0878108, 
  0.0878108}, {{57.5, 105.063}, {157.5, 109.875}} -> {-5.1468, -5.14955, 
  0.0879268, 0.0879268}, {{109.875, 157.5}, {157.5, 
  109.875}} -> {-9.73921, -5.14012, 0.0878108, 0.0878108}, {{162.25, 
  209.875}, {157.5, 109.875}} -> {-14.3383, -5.14012, 0.0878108, 
  0.0878108}, {{5.0625, 52.6875}, {105.063, 57.5}} -> {-0.535539, -9.74195, 
  0.0878108, 0.0878108}, {{57.5, 105.063}, {105.063, 
  57.5}} -> {-5.1468, -9.75746, 0.0879268, 0.0879268}, {{109.875, 157.5}, {
  105.063, 57.5}} -> {-9.73921, -9.74195, 0.0878108, 0.0878108}, {{162.25, 
  209.875}, {105.063, 57.5}} -> {-14.3383, -9.74195, 0.0878108, 0.0878108}, {{
  5.0625, 52.6875}, {52.6875, 5.0625}} -> {-0.535539, -14.3438, 0.0878108, 
  0.0878108}, {{57.5, 105.063}, {52.6875, 5.0625}} -> {-5.1468, -14.3654, 
  0.0879268, 0.0879268}, {{109.875, 157.5}, {52.6875, 
  5.0625}} -> {-9.73921, -14.3438, 0.0878108, 0.0878108}, {{162.25, 
  209.875}, {52.6875, 5.0625}} -> {-14.3383, -14.3438, 0.0878108, 0.0878108}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["HADAMARD MATRICES", "Section"],

Cell[TextData[{
  "A simple recursive relationship exists for generating the Hadamard \
transformation kernel of order ",
  Cell[BoxData[
      \(TraditionalForm\`N = 2\^n\)]],
  " where n is an integer. The Hadamard matrix of the lowest order (",
  StyleBox["N=2",
    FontSlant->"Italic"],
  ") is defined"
}], "Text"],

Cell[TextData[Cell[BoxData[
    FormBox[
      RowBox[{\(\[ScriptCapitalH]\_2\), " ", "=", " ", 
        RowBox[{
          RowBox[{"(", GridBox[{
                {"1", "1"},
                {"1", \(-1\)}
                }], ")"}], " ", \(\@\(1\/2\)\)}]}], TraditionalForm]]]], 
  "NumberedEquation"],

Cell[TextData[{
  "Then, ",
  Cell[BoxData[
      \(TraditionalForm\`H\_N\)]],
  ", the Hadamard kernel of dimensions ",
  StyleBox["N-by-N",
    FontSlant->"Italic"],
  " is defined recursively as"
}], "Text"],

Cell[TextData[Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{\(\[ScriptCapitalH]\_N\), " ", "=", "  ", 
          RowBox[{
            RowBox[{
              RowBox[{"(", GridBox[{
                    {\(\[ScriptCapitalH]\_\(N\/2\)\), 
                      \(\[ScriptCapitalH]\_\(N\/2\)\)},
                    {\(\[ScriptCapitalH]\_\(N\/2\)\), 
                      \(-\[ScriptCapitalH]\_\(N\/2\)\)}
                    }], ")"}], " ", \(\@\(1\/2\)\)}], " ", "=", " ", 
            RowBox[{
              RowBox[{"(", GridBox[{
                    {\(1\/\@2\), \(1\/\@2\)},
                    {\(1\/\@2\), \(-\(1\/\@2\)\)}
                    }], ")"}], " ", "\[CircleTimes]", " ", 
              \(\[ScriptCapitalH]\_\(N\/2\)\)}]}]}], " "}], 
      TraditionalForm]]]], "NumberedEquation"],

Cell[TextData[{
  "where the matrix operator \[CircleTimes] denotes the Kronecker product. \
The Hadamard kernel of size ",
  Cell[BoxData[
      \(TraditionalForm\`N = 8\)]],
  " is"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\((\[ScriptCapitalH]\_8 = HadamardKernel[8])\)\ \@8\  // MatrixForm\)], 
  "Input",
  CellLabel->"In[8]:="],

Cell[BoxData[
    TagBox[
      RowBox[{"(", GridBox[{
            {"1", "1", "1", "1", "1", "1", "1", "1"},
            {"1", \(-1\), "1", \(-1\), "1", \(-1\), "1", \(-1\)},
            {"1", "1", \(-1\), \(-1\), "1", "1", \(-1\), \(-1\)},
            {"1", \(-1\), \(-1\), "1", "1", \(-1\), \(-1\), "1"},
            {"1", "1", "1", "1", \(-1\), \(-1\), \(-1\), \(-1\)},
            {"1", \(-1\), "1", \(-1\), \(-1\), "1", \(-1\), "1"},
            {"1", "1", \(-1\), \(-1\), \(-1\), \(-1\), "1", "1"},
            {"1", \(-1\), \(-1\), "1", \(-1\), "1", "1", \(-1\)}
            }], ")"}],
      (MatrixForm[ #]&)]], "Output",
  CellLabel->"Out[8]//MatrixForm="]
}, Open  ]],

Cell[TextData[{
  "Another simple construction is possible if \[ScriptCapitalA] and \
\[ScriptCapitalB] are Hadamard matrices of orders ",
  Cell[BoxData[
      \(TraditionalForm\`M\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`N\)]],
  ", respectively. Then there exists a Hadamard matrix of order ",
  Cell[BoxData[
      \(TraditionalForm\`M\ N\)]],
  " given by "
}], "Text"],

Cell[TextData[Cell[BoxData[
    FormBox[
      RowBox[{" ", 
        RowBox[{\(\[ScriptCapitalH]\_\(M\ N\)\), " ", "=", " ", 
          RowBox[{
            RowBox[{"(", GridBox[{
                  {\(a\_\(1, 1\)\), \(a\_\(1, 1\)\), ".", \(a\_\(1, M\)\)},
                  {\(a\_\(2, 1\)\), \(a\_\(2, 2\)\), ".", \(a\_\(2, M\)\)},
                  {".", ".", ".", "."},
                  {\(a\_\(M, 1\)\), \(a\_\(M, 2\)\), ".", \(a\_\(M, M\)\)}
                  }], ")"}], " ", "\[CircleTimes]", " ", 
            \(\[ScriptCapitalB]\_N\)}]}]}], TraditionalForm]]]], "Text"],

Cell["\<\
The set of known Hadamard matrices is sufficiently numerous to satisfy almost \
all size requirements. Here we show the non-ordered and ordered Hadamard \
kernels as intensity plots (1 is white). Note that the Hadamard matrix is \
real and symmetric. \
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[
      GraphicsArray[{
          ListDensityPlot[\[ScriptCapitalH]\_8, 
            DisplayFunction \[Rule] Identity], 
          ListDensityPlot[HadamardKernel[8, \ SequencyOrdered -> True], 
            DisplayFunction \[Rule] Identity]}]]; \)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .47619 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0113379 0.47619 [
[ 0 0 0 0 ]
[ 1 .47619 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .47619 L
0 .47619 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0113379 0.477324 0.464853 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.120192 0.0192308 0.120192 [
[.01923 -0.0125 -3 -9 ]
[.01923 -0.0125 3 0 ]
[.25962 -0.0125 -3 -9 ]
[.25962 -0.0125 3 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.74038 -0.0125 -3 -9 ]
[.74038 -0.0125 3 0 ]
[.98077 -0.0125 -3 -9 ]
[.98077 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01923 -6 -4.5 ]
[-0.0125 .01923 0 4.5 ]
[-0.0125 .25962 -6 -4.5 ]
[-0.0125 .25962 0 4.5 ]
[-0.0125 .5 -6 -4.5 ]
[-0.0125 .5 0 4.5 ]
[-0.0125 .74038 -6 -4.5 ]
[-0.0125 .74038 0 4.5 ]
[-0.0125 .98077 -6 -4.5 ]
[-0.0125 .98077 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.01923 0 m
.01923 .00625 L
s
[(0)] .01923 -0.0125 0 1 Mshowa
.25962 0 m
.25962 .00625 L
s
[(2)] .25962 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(4)] .5 -0.0125 0 1 Mshowa
.74038 0 m
.74038 .00625 L
s
[(6)] .74038 -0.0125 0 1 Mshowa
.98077 0 m
.98077 .00625 L
s
[(8)] .98077 -0.0125 0 1 Mshowa
.125 Mabswid
.07933 0 m
.07933 .00375 L
s
.13942 0 m
.13942 .00375 L
s
.19952 0 m
.19952 .00375 L
s
.31971 0 m
.31971 .00375 L
s
.37981 0 m
.37981 .00375 L
s
.4399 0 m
.4399 .00375 L
s
.5601 0 m
.5601 .00375 L
s
.62019 0 m
.62019 .00375 L
s
.68029 0 m
.68029 .00375 L
s
.80048 0 m
.80048 .00375 L
s
.86058 0 m
.86058 .00375 L
s
.92067 0 m
.92067 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01923 m
.00625 .01923 L
s
[(0)] -0.0125 .01923 1 0 Mshowa
0 .25962 m
.00625 .25962 L
s
[(2)] -0.0125 .25962 1 0 Mshowa
0 .5 m
.00625 .5 L
s
[(4)] -0.0125 .5 1 0 Mshowa
0 .74038 m
.00625 .74038 L
s
[(6)] -0.0125 .74038 1 0 Mshowa
0 .98077 m
.00625 .98077 L
s
[(8)] -0.0125 .98077 1 0 Mshowa
.125 Mabswid
0 .07933 m
.00375 .07933 L
s
0 .13942 m
.00375 .13942 L
s
0 .19952 m
.00375 .19952 L
s
0 .31971 m
.00375 .31971 L
s
0 .37981 m
.00375 .37981 L
s
0 .4399 m
.00375 .4399 L
s
0 .5601 m
.00375 .5601 L
s
0 .62019 m
.00375 .62019 L
s
0 .68029 m
.00375 .68029 L
s
0 .80048 m
.00375 .80048 L
s
0 .86058 m
.00375 .86058 L
s
0 .92067 m
.00375 .92067 L
s
.25 Mabswid
0 0 m
0 1 L
s
.01923 .99375 m
.01923 1 L
s
.25962 .99375 m
.25962 1 L
s
.5 .99375 m
.5 1 L
s
.74038 .99375 m
.74038 1 L
s
.98077 .99375 m
.98077 1 L
s
.125 Mabswid
.07933 .99625 m
.07933 1 L
s
.13942 .99625 m
.13942 1 L
s
.19952 .99625 m
.19952 1 L
s
.31971 .99625 m
.31971 1 L
s
.37981 .99625 m
.37981 1 L
s
.4399 .99625 m
.4399 1 L
s
.5601 .99625 m
.5601 1 L
s
.62019 .99625 m
.62019 1 L
s
.68029 .99625 m
.68029 1 L
s
.80048 .99625 m
.80048 1 L
s
.86058 .99625 m
.86058 1 L
s
.92067 .99625 m
.92067 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .01923 m
1 .01923 L
s
.99375 .25962 m
1 .25962 L
s
.99375 .5 m
1 .5 L
s
.99375 .74038 m
1 .74038 L
s
.99375 .98077 m
1 .98077 L
s
.125 Mabswid
.99625 .07933 m
1 .07933 L
s
.99625 .13942 m
1 .13942 L
s
.99625 .19952 m
1 .19952 L
s
.99625 .31971 m
1 .31971 L
s
.99625 .37981 m
1 .37981 L
s
.99625 .4399 m
1 .4399 L
s
.99625 .5601 m
1 .5601 L
s
.99625 .62019 m
1 .62019 L
s
.99625 .68029 m
1 .68029 L
s
.99625 .80048 m
1 .80048 L
s
.99625 .86058 m
1 .86058 L
s
.99625 .92067 m
1 .92067 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFF
FF00FF00FF00FF00
FFFF0000FFFF0000
FF0000FFFF0000FF
FFFFFFFF00000000
FF00FF0000FF00FF
FFFF00000000FFFF
FF0000FF00FFFF00
pop
P
% End of image
.01923 .01923 m
.01923 .98077 L
s
.13942 .01923 m
.13942 .98077 L
s
.25962 .01923 m
.25962 .98077 L
s
.37981 .01923 m
.37981 .98077 L
s
.5 .01923 m
.5 .98077 L
s
.62019 .01923 m
.62019 .98077 L
s
.74038 .01923 m
.74038 .98077 L
s
.86058 .01923 m
.86058 .98077 L
s
.98077 .01923 m
.98077 .98077 L
s
.01923 .01923 m
.98077 .01923 L
s
.01923 .13942 m
.98077 .13942 L
s
.01923 .25962 m
.98077 .25962 L
s
.01923 .37981 m
.98077 .37981 L
s
.01923 .5 m
.98077 .5 L
s
.01923 .62019 m
.98077 .62019 L
s
.01923 .74038 m
.98077 .74038 L
s
.01923 .86058 m
.98077 .86058 L
s
.01923 .98077 m
.98077 .98077 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0113379 0.97619 0.464853 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.120192 0.0192308 0.120192 [
[.01923 -0.0125 -3 -9 ]
[.01923 -0.0125 3 0 ]
[.25962 -0.0125 -3 -9 ]
[.25962 -0.0125 3 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.74038 -0.0125 -3 -9 ]
[.74038 -0.0125 3 0 ]
[.98077 -0.0125 -3 -9 ]
[.98077 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01923 -6 -4.5 ]
[-0.0125 .01923 0 4.5 ]
[-0.0125 .25962 -6 -4.5 ]
[-0.0125 .25962 0 4.5 ]
[-0.0125 .5 -6 -4.5 ]
[-0.0125 .5 0 4.5 ]
[-0.0125 .74038 -6 -4.5 ]
[-0.0125 .74038 0 4.5 ]
[-0.0125 .98077 -6 -4.5 ]
[-0.0125 .98077 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.01923 0 m
.01923 .00625 L
s
[(0)] .01923 -0.0125 0 1 Mshowa
.25962 0 m
.25962 .00625 L
s
[(2)] .25962 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(4)] .5 -0.0125 0 1 Mshowa
.74038 0 m
.74038 .00625 L
s
[(6)] .74038 -0.0125 0 1 Mshowa
.98077 0 m
.98077 .00625 L
s
[(8)] .98077 -0.0125 0 1 Mshowa
.125 Mabswid
.07933 0 m
.07933 .00375 L
s
.13942 0 m
.13942 .00375 L
s
.19952 0 m
.19952 .00375 L
s
.31971 0 m
.31971 .00375 L
s
.37981 0 m
.37981 .00375 L
s
.4399 0 m
.4399 .00375 L
s
.5601 0 m
.5601 .00375 L
s
.62019 0 m
.62019 .00375 L
s
.68029 0 m
.68029 .00375 L
s
.80048 0 m
.80048 .00375 L
s
.86058 0 m
.86058 .00375 L
s
.92067 0 m
.92067 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01923 m
.00625 .01923 L
s
[(0)] -0.0125 .01923 1 0 Mshowa
0 .25962 m
.00625 .25962 L
s
[(2)] -0.0125 .25962 1 0 Mshowa
0 .5 m
.00625 .5 L
s
[(4)] -0.0125 .5 1 0 Mshowa
0 .74038 m
.00625 .74038 L
s
[(6)] -0.0125 .74038 1 0 Mshowa
0 .98077 m
.00625 .98077 L
s
[(8)] -0.0125 .98077 1 0 Mshowa
.125 Mabswid
0 .07933 m
.00375 .07933 L
s
0 .13942 m
.00375 .13942 L
s
0 .19952 m
.00375 .19952 L
s
0 .31971 m
.00375 .31971 L
s
0 .37981 m
.00375 .37981 L
s
0 .4399 m
.00375 .4399 L
s
0 .5601 m
.00375 .5601 L
s
0 .62019 m
.00375 .62019 L
s
0 .68029 m
.00375 .68029 L
s
0 .80048 m
.00375 .80048 L
s
0 .86058 m
.00375 .86058 L
s
0 .92067 m
.00375 .92067 L
s
.25 Mabswid
0 0 m
0 1 L
s
.01923 .99375 m
.01923 1 L
s
.25962 .99375 m
.25962 1 L
s
.5 .99375 m
.5 1 L
s
.74038 .99375 m
.74038 1 L
s
.98077 .99375 m
.98077 1 L
s
.125 Mabswid
.07933 .99625 m
.07933 1 L
s
.13942 .99625 m
.13942 1 L
s
.19952 .99625 m
.19952 1 L
s
.31971 .99625 m
.31971 1 L
s
.37981 .99625 m
.37981 1 L
s
.4399 .99625 m
.4399 1 L
s
.5601 .99625 m
.5601 1 L
s
.62019 .99625 m
.62019 1 L
s
.68029 .99625 m
.68029 1 L
s
.80048 .99625 m
.80048 1 L
s
.86058 .99625 m
.86058 1 L
s
.92067 .99625 m
.92067 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .01923 m
1 .01923 L
s
.99375 .25962 m
1 .25962 L
s
.99375 .5 m
1 .5 L
s
.99375 .74038 m
1 .74038 L
s
.99375 .98077 m
1 .98077 L
s
.125 Mabswid
.99625 .07933 m
1 .07933 L
s
.99625 .13942 m
1 .13942 L
s
.99625 .19952 m
1 .19952 L
s
.99625 .31971 m
1 .31971 L
s
.99625 .37981 m
1 .37981 L
s
.99625 .4399 m
1 .4399 L
s
.99625 .5601 m
1 .5601 L
s
.99625 .62019 m
1 .62019 L
s
.99625 .68029 m
1 .68029 L
s
.99625 .80048 m
1 .80048 L
s
.99625 .86058 m
1 .86058 L
s
.99625 .92067 m
1 .92067 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFF
FFFFFFFF00000000
FFFF00000000FFFF
FFFF0000FFFF0000
FF0000FFFF0000FF
FF0000FF00FFFF00
FF00FF0000FF00FF
FF00FF00FF00FF00
pop
P
% End of image
.01923 .01923 m
.01923 .98077 L
s
.13942 .01923 m
.13942 .98077 L
s
.25962 .01923 m
.25962 .98077 L
s
.37981 .01923 m
.37981 .98077 L
s
.5 .01923 m
.5 .98077 L
s
.62019 .01923 m
.62019 .98077 L
s
.74038 .01923 m
.74038 .98077 L
s
.86058 .01923 m
.86058 .98077 L
s
.98077 .01923 m
.98077 .98077 L
s
.01923 .01923 m
.98077 .01923 L
s
.01923 .13942 m
.98077 .13942 L
s
.01923 .25962 m
.98077 .25962 L
s
.01923 .37981 m
.98077 .37981 L
s
.01923 .5 m
.98077 .5 L
s
.01923 .62019 m
.98077 .62019 L
s
.01923 .74038 m
.98077 .74038 L
s
.01923 .86058 m
.98077 .86058 L
s
.01923 .98077 m
.98077 .98077 L
s
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{259.313, 123.438},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000430000Na000`40O003h00Oogoo17oo003oOol4
Ool00?moo`Aoo`00ogoo17oo000AOol00`00Oomoo`0EOol3000GOol3000EOol2000HOol00`00Oomo
o`0IOol00`00Oomoo`0EOol3000GOol3000EOol2000HOol00`00Oomoo`0;Ool0011oo`03001oo`00
01Ioo`03001oogoo01Qoo`03001oogoo01Aoo`03001oo`0001Ioo`03001oo`0001Uoo`03001oo`00
01Ioo`03001oogoo01Qoo`03001oogoo01Aoo`03001oo`0001Ioo`03001oo`0000aoo`0047oo00<0
07oo00005goo00<007ooOol05Goo10005Goo00<007oo00005Woo00<007oo00006Goo00<007oo0000
5goo00<007ooOol05Goo10005Goo00<007oo00005Woo00<007oo000037oo000@Ool00`00Ool0000G
Ool00`00Oomoo`0EOol00`00Ool0000FOol2000HOol00`00Oomoo`0HOol00`00Ool0000GOol00`00
Oomoo`0EOol00`00Ool0000FOol2000HOol00`00Oomoo`0;Ool0011oo`03001oo`0001Ioo`03001o
o`0001Moo`8001Ioo`03001oogoo01Ioo`03001oo`0001Uoo`03001oo`0001Ioo`03001oo`0001Mo
o`8001Ioo`03001oogoo01Ioo`03001oo`0000aoo`004Goo00<007ooOol05Woo00<007ooOol05goo
00<007ooOol05Goo0P005goo00<007ooOol06Goo00<007ooOol05Woo00<007ooOol05goo00<007oo
Ool05Goo0P005goo00<007ooOol02goo003oOol4Ool00?moo`Aoo`00ogoo17oo000;Ool00`00Oomo
o`02OomY000COol01000OomoogooJ@002Woo000:Ool00`00Ool00003Ool00`00Ool00005Ool00`00
Oomoo`03Ool00`00Oomoo`03Ool00`00Oomoo`04Ool00`00Oomoo`03Ool00`00Oomoo`03Ool00`00
Oomoo`03Ool00`00Oomoo`04Ool00`00Oomoo`03Ool00`00Oomoo`03Ool00`00Oomoo`03Ool00`00
Oomoo`04Ool00`00Oomoo`03Ool00`00Oomoo`03Ool00`00Oomoo`03Ool00`00Oomoo`04Ool00`00
Ool0000BOol00`00Ool00002Ool00`00Ool00005Ool00`00Oomoo`03Ool00`00Oomoo`04Ool00`00
Oomoo`03Ool00`00Oomoo`03Ool00`00Oomoo`03Ool00`00Oomoo`04Ool00`00Oomoo`03Ool00`00
Oomoo`03Ool00`00Oomoo`03Ool00`00Oomoo`04Ool00`00Oomoo`03Ool00`00Oomoo`03Ool00`00
Oomoo`03Ool00`00Oomoo`04Ool00`00Oomoo`03Ool00`00Ool0000:Ool000Yoo`03001oo`0000=o
o`03001oo`0006H0019oo`03001oo`00009oofT000Yoo`002Woo00<007oo00000goo00<007oo0000
2goo00<007ooOol02Woo00<007ooOol02Goo00<007ooOol02Woo00<007ooOol02Goo00<007ooOol0
2Woo00<007ooOol02Goo00<007ooOol02Woo00<007oo00004Woo00<007oo00000Woo00<007oo0000
2goo00<007ooOol02Woo00<007ooOol02Goo00<007ooOol02Woo00<007ooOol02Goo00<007ooOol0
2Woo00<007ooOol02Goo00<007ooOol02Woo00<007oo00002Woo000:Ool00`00Ool00003Ool00`00
Ool0000;Ool00`00Oomoo`0:Ool00`00Oomoo`09Ool00`00Oomoo`0:Ool00`00Oomoo`09Ool00`00
Oomoo`0:Ool00`00Oomoo`09Ool00`00Oomoo`0:Ool00`00Ool0000BOol00`00Ool00002Ool00`00
Ool0000;Ool00`00Oomoo`0:Ool00`00Oomoo`09Ool00`00Oomoo`0:Ool00`00Oomoo`09Ool00`00
Oomoo`0:Ool00`00Oomoo`09Ool00`00Oomoo`0:Ool00`00Ool0000:Ool000]oo`03001oogoo009o
o`03001oo`0000]oo`03001oogoo00Yoo`03001oogoo00Uoo`03001oogoo00Yoo`03001oogoo00Uo
o`03001oogoo00Yoo`03001oogoo00Uoo`03001oogoo00Yoo`03001oo`0001=oo`07001oogooOol0
07oo00002goo00<007ooOol02Woo00<007ooOol02Goo00<007ooOol02Woo00<007ooOol02Goo00<0
07ooOol02Woo00<007ooOol02Goo00<007ooOol02Woo00<007oo00002Woo000@Ool00`00Ool0000;
Ool00`00Oomoo`0:Ool00`00Oomoo`09Ool00`00Oomoo`0:Ool00`00Oomoo`09Ool00`00Oomoo`0:
Ool00`00Oomoo`09Ool00`00Oomoo`0:Ool00`00Ool0000GOol00`00Ool0000;Ool00`00Oomoo`0:
Ool00`00Oomoo`09Ool00`00Oomoo`0:Ool00`00Oomoo`09Ool00`00Oomoo`0:Ool00`00Oomoo`09
Ool00`00Oomoo`0:Ool00`00Ool0000:Ool0011oo`03001oo`0000]oo`03001oogoo00Yoo`03001o
ogoo00Uoo`03001oogoo00Yoo`03001oogoo00Uoo`03001oogoo00Yoo`03001oogoo00Uoo`03001o
ogoo00Yoo`03001oo`0001Moo`03001oo`0000]oo`03001oogoo00Yoo`03001oogoo00Uoo`03001o
ogoo00Yoo`03001oogoo00Uoo`03001oogoo00Yoo`03001oogoo00Uoo`03001oogoo00Yoo`03001o
o`0000Yoo`0047oo00<007oo00002goo00<007ooOol02Woo00<007ooOol02Goo00<007ooOol02Woo
00<007ooOol02Goo00<007ooOol02Woo00<007ooOol02Goo00<007ooOol02Woo00<007oo00005goo
00<007oo00002goo00<007ooOol02Woo00<007ooOol02Goo00<007ooOol02Woo00<007ooOol02Goo
00<007ooOol02Woo00<007ooOol02Goo00<007ooOol02Woo00<007oo00002Woo000@Ool00`00Ool0
000;Ool00`00Oomoo`0:Ool00`00Oomoo`09Ool00`00Oomoo`0:Ool00`00Oomoo`09Ool00`00Oomo
o`0:Ool00`00Oomoo`09Ool00`00Oomoo`0:Ool3000GOol00`00Ool0000;Ool00`00Oomoo`0:Ool0
0`00Oomoo`09Ool00`00Oomoo`0:Ool00`00Oomoo`09Ool00`00Oomoo`0:Ool00`00Oomoo`09Ool0
0`00Oomoo`0:Ool3000:Ool0011oo`03001oo`0000]oo`03001oogoo00Yoo`03001oogoo00Uoo`03
001oogoo00Yoo`03001oogoo00Uoo`03001oogoo00Yoo`03001oogoo00Uoo`03001oogoo00Yoo`03
001oo`0001Moo`03001oo`0000]oo`03001oogoo00Yoo`03001oogoo00Uoo`03001oogoo00Yoo`03
001oogoo00Uoo`03001oogoo00Yoo`03001oogoo00Uoo`03001oogoo00Yoo`03001oo`0000Yoo`00
47oo00<007oo00002goo00<007ooOol02Woo00<007ooOol02Goo00<007ooOol02Woo00<007ooOol0
2Goo00<007ooOol02Woo00<007ooOol02Goo00<007ooOol02Woo00<007oo00005goo00<007oo0000
2goo00<007ooOol02Woo00<007ooOol02Goo00<007ooOol02Woo00<007ooOol02Goo00<007ooOol0
2Woo00<007ooOol02Goo00<007ooOol02Woo00<007oo00002Woo000@Ool00`00Ool0000;Ool00`00
Oomoo`0:Ool00`00Oomoo`09Ool00`00Oomoo`0:Ool00`00Oomoo`09Ool00`00Oomoo`0:Ool00`00
Oomoo`09Ool00`00Oomoo`0:Ool00`00Ool0000GOol00`00Ool0000;Ool00`00Oomoo`0:Ool00`00
Oomoo`09Ool00`00Oomoo`0:Ool00`00Oomoo`09Ool00`00Oomoo`0:Ool00`00Oomoo`09Ool00`00
Oomoo`0:Ool00`00Ool0000:Ool0011oo`03001oo`0000]oo`03001oogoo00Yoo`03001oogoo00Uo
o`03001oogoo00Yoo`03001oogoo00Uoo`03001oogoo00Yoo`03001oogoo00Uoo`03001oogoo00Yo
o`03001oo`0001Moo`03001oo`0000]oo`03001oogoo00Yoo`03001oogoo00Uoo`03001oogoo00Yo
o`03001oogoo00Uoo`03001oogoo00Yoo`03001oogoo00Uoo`03001oogoo00Yoo`03001oo`0000Yo
o`0047oo00<007oo00002goo00<007ooOol02Woo00<007ooOol02Goo00<007ooOol02Woo00<007oo
Ool02Goo00<007ooOol02Woo00<007ooOol02Goo00<007ooOol02Woo00<007oo00005goo00<007oo
00002goo00<007ooOol02Woo00<007ooOol02Goo00<007ooOol02Woo00<007ooOol02Goo00<007oo
Ool02Woo00<007ooOol02Goo00<007ooOol02Woo00<007oo00002Woo000@Ool00`00Ool0001V000G
Ool00`00Ool0001V000:Ool0011oo`03001oo`0000]oo`h000]oo`h000]oo`h000]oo`h00003Ool0
07oo01Ioo`03001oo`0000]oo`03001oogoo00Yoo`03001oogoo00Uoo`03001oogoo00Yooc<00003
Ool007oo00Uoo`0047oo00<007oo00002goo3P002goo3P002goo3P002goo3P0000=oo`00Ool05Woo
00<007oo00002goo00<007ooOol02Woo00<007ooOol02Goo00<007ooOol02Woo<`0000=oo`00Ool0
2Goo000@Ool00`00Ool0000;Ool>000;Ool>000;Ool>000;Ool>00000goo001oo`0FOol00`00Ool0
000;Ool00`00Oomoo`0:Ool00`00Oomoo`09Ool00`00Oomoo`0:Oolc00000goo001oo`09Ool0011o
o`03001oo`0000]oo`h000]oo`h000]oo`h000]oo`h00003Ool007oo01Ioo`03001oo`0000]oo`03
001oogoo00Yoo`03001oogoo00Uoo`03001oogoo00Yooc<00003Ool007oo00Uoo`0047oo00<007oo
00002goo3P002goo3P002goo3P002goo3P0000=oo`00Ool05Woo00<007oo00002goo00<007ooOol0
2Woo00<007ooOol02Goo00<007ooOol02Woo<`0000=oo`00Ool02Goo000@Ool00`00Ool0000;Ool>
000;Ool>000;Ool>000;Ool@000GOol00`00Ool0000;Ool00`00Oomoo`0:Ool00`00Oomoo`09Ool0
0`00Oomoo`0:Oole000:Ool0011oo`03001oo`0000]oo`h000]oo`h000]oo`h000]oo`h00003Ool0
07oo01Ioo`03001oo`0000]oo`03001oogoo00Yoo`03001oogoo00Uoo`03001oogoo00Yooc<00003
Ool007oo00Uoo`0047oo00<007oo00002goo3P002goo3P002goo3P002goo3P0000=oo`00Ool05Woo
00<007oo00002goo00<007ooOol02Woo00<007ooOol02Goo00<007ooOol02Woo<`0000=oo`00Ool0
2Goo000@Ool00`00Ool0000;Ool>000;Ool>000;Ool>000;Ool>00000goo001oo`0FOol00`00Ool0
000;Ool00`00Oomoo`0:Ool00`00Oomoo`09Ool00`00Oomoo`0:Oolc00000goo001oo`09Ool000Yo
o`<000=oo`03001oo`0000]oo`h000]oo`h000]oo`h000]oo`h00003Ool007oo015oo`<0009oo`03
001oo`0000]oo`03001oogoo00Yoo`03001oogoo00Uoo`03001oogoo00Yooc<00003Ool007oo00Uo
o`002Woo00<007ooOol00goo00<007oo00002goo3P002goo3P002goo3P002goo3P0000=oo`00Ool0
4Goo00<007ooOol00Woo00<007oo00002goo00<007ooOol02Woo00<007ooOol02Goo00<007ooOol0
2Woo<`0000=oo`00Ool02Goo000;Ool00`00Oomoo`02Ool00`00Ool0001V000COol01000Oomoogoo
J@002Woo000;Ool00`00Oomoo`02Ool00`00Ool0000;Ool00`00Oomoo`0:OolJ000;Ool00`00Oomo
o`0:OolJ00000goo001oo`0BOol01`00Oomoogoo001oo`0000]oo`03001oogoo00Yooc<000]oo`03
001oogoo00Yoo`03001oo`0000Yoo`002Woo00<007oo00000goo00<007oo00002goo00<007ooOol0
2Woo6P002goo00<007ooOol02Woo6P0000=oo`00Ool04Goo00<007oo00000Woo00<007oo00002goo
00<007ooOol02Woo<`002goo00<007ooOol02Woo00<007oo00002Woo000;Ool00`00Oomoo`02Ool0
0`00Ool0000;Ool00`00Oomoo`0:OolJ000;Ool00`00Oomoo`0:OolJ00000goo001oo`0BOol01`00
Oomoogoo001oo`0000]oo`03001oogoo00Yooc<000]oo`03001oogoo00Yoo`03001oo`0000Yoo`00
47oo00<007oo00002goo00<007ooOol02Woo6P002goo00<007ooOol02Woo6P0000=oo`00Ool05Woo
00<007oo00002goo00<007ooOol02Woo<`002goo00<007ooOol02Woo00<007oo00002Woo000@Ool0
0`00Ool0000;Ool00`00Oomoo`0:OolJ000;Ool00`00Oomoo`0:OolJ00000goo001oo`0FOol00`00
Ool0000;Ool00`00Oomoo`0:Oolc000;Ool00`00Oomoo`0:Ool00`00Ool0000:Ool0011oo`03001o
o`0000]oo`03001oogoo00YooaX000]oo`03001oogoo00Yooa`001Moo`03001oo`0000]oo`03001o
ogoo00Yooc<000]oo`03001oogoo00Yoo`<000Yoo`0047oo00<007oo00002goo00<007ooOol02Woo
6P002goo00<007ooOol02Woo6P0000=oo`00Ool05Woo00<007oo00002goo00<007ooOol02Woo<`00
2goo00<007ooOol02Woo00<007oo00002Woo000@Ool00`00Ool0000;Ool00`00Oomoo`0:OolJ000;
Ool00`00Oomoo`0:OolJ00000goo001oo`0FOol00`00Ool0000;Ool00`00Oomoo`0:Oolc000;Ool0
0`00Oomoo`0:Ool00`00Ool0000:Ool0011oo`03001oo`0000]oo`03001oogoo00YooaX000]oo`03
001oogoo00YooaX00003Ool007oo01Ioo`03001oo`0000]oo`03001oogoo00Yooc<000]oo`03001o
ogoo00Yoo`03001oo`0000Yoo`0047oo00<007oo00002goo00<007ooOol02Woo6P002goo00<007oo
Ool02Woo6P0000=oo`00Ool05Woo00<007oo00002goo00<007ooOol02Woo<`002goo00<007ooOol0
2Woo00<007oo00002Woo000@Ool00`00Ool0000;Ool00`00Oomoo`0:OolJ000;Ool00`00Oomoo`0:
OolJ00000goo001oo`0FOol00`00Ool0000;Ool00`00Oomoo`0:Oolc000;Ool00`00Oomoo`0:Ool0
0`00Ool0000:Ool0011oo`03001oo`0000]oo`03001oogoo00YooaX000]oo`03001oogoo00YooaX0
0003Ool007oo01Ioo`03001oo`0000]oo`03001oogoo00Yooc<000]oo`03001oogoo00Yoo`03001o
o`0000Yoo`0047oo00<007oo0000IP005goo00<007oo0000IP002Woo000@Ool00`00Ool0000;OolJ
000<Ool00`00Oomoo`09OolJ000<Ool00`00Ool0000GOol00`00Ool0000;Ool00`00Oomoo`0:OolJ
000;Ool00`00Oomoo`0:OolJ00000goo001oo`09Ool0011oo`03001oo`0000]ooaX000aoo`03001o
ogoo00UooaX000aoo`03001oo`0001Moo`03001oo`0000]oo`03001oogoo00YooaX000]oo`03001o
ogoo00YooaX00003Ool007oo00Uoo`0047oo00<007oo00002goo6P0037oo00<007ooOol02Goo6P00
37oo00<007oo00005goo00<007oo00002goo00<007ooOol02Woo6P002goo00<007ooOol02Woo6P00
00=oo`00Ool02Goo000@Ool00`00Ool0000;OolJ000<Ool00`00Oomoo`09OolJ000<Ool00`00Ool0
000GOol00`00Ool0000;Ool00`00Oomoo`0:OolJ000;Ool00`00Oomoo`0:OolJ00000goo001oo`09
Ool0011oo`03001oo`0000]ooaX000aoo`03001oogoo00UooaX000aoo`03001oo`0001Moo`03001o
o`0000]oo`03001oogoo00YooaX000]oo`03001oogoo00YooaX00003Ool007oo00Uoo`0047oo00<0
07oo00002goo6P0037oo00<007ooOol02Goo6P0037oo0`005goo00<007oo00002goo00<007ooOol0
2Woo6P002goo00<007ooOol02Woo70002Woo000@Ool00`00Ool0000;OolJ000<Ool00`00Oomoo`09
OolJ000<Ool00`00Ool0000GOol00`00Ool0000;Ool00`00Oomoo`0:OolJ000;Ool00`00Oomoo`0:
OolJ00000goo001oo`09Ool0011oo`03001oo`0000]ooaX000aoo`03001oogoo00UooaX000aoo`03
001oo`0001Moo`03001oo`0000]oo`03001oogoo00YooaX000]oo`03001oogoo00YooaX00003Ool0
07oo00Uoo`0047oo00<007oo00002goo6P0037oo00<007ooOol02Goo6P0037oo00<007oo00005goo
00<007oo00002goo00<007ooOol02Woo6P002goo00<007ooOol02Woo6P0000=oo`00Ool02Goo000;
Ool30002Ool00`00Ool0000;OolJ000<Ool00`00Oomoo`09OolJ000<Ool00`00Ool0000COol30000
17oo001oo`002goo00<007ooOol02Woo6P002goo00<007ooOol02Woo6P0000=oo`00Ool02Goo000<
Ool01`00Oomoogoo001oo`0000]ooaX000aoo`03001oogoo00UooaX000aoo`03001oo`0001Aoo`06
001oogoo001oo`002goo00<007ooOol02Woo6P002goo00<007ooOol02Woo6P0000=oo`00Ool02Goo
000:Ool40002Ool00`00Ool0001V000BOol400000goo0000001W000:Ool000Yoo`03001oo`0000=o
o`03001oo`0000]oo`03001oogoo00Yoo`03001oogoo00Uoo`03001oogoo00Yooc<00003Ool007oo
015oo`03001oo`00009oo`03001oo`0000]ooaX000aoo`03001oogoo00UooaX000aoo`03001oo`00
00Yoo`002goo0P000goo00<007oo00002goo00<007ooOol02Woo00<007ooOol02Goo00<007ooOol0
2Woo<`0000=oo`00Ool04Woo0P000Woo00<007oo00002goo6P0037oo00<007ooOol02Goo6P0037oo
00<007oo00002Woo000<Ool01`00Oomoogoo001oo`0000]oo`03001oogoo00Yoo`03001oogoo00Uo
o`03001oogoo00Yooc<00003Ool007oo01=oo`06001oogoo001oo`002goo6P0037oo00<007ooOol0
2Goo6P0037oo00<007oo00002Woo000@Ool00`00Ool0000;Ool00`00Oomoo`0:Ool00`00Oomoo`09
Ool00`00Oomoo`0:Oolc00000goo001oo`0FOol00`00Ool0000;OolJ000<Ool00`00Oomoo`09OolJ
000<Ool00`00Ool0000:Ool0011oo`03001oo`0000]oo`03001oogoo00Yoo`03001oogoo00Uoo`03
001oogoo00Yooc<00003Ool007oo01Ioo`03001oo`0000]ooaX000aoo`03001oogoo00UooaX000ao
o`03001oo`0000Yoo`0047oo00<007oo00002goo00<007ooOol02Woo00<007ooOol02Goo00<007oo
Ool02Woo=@005goo00<007oo00002goo6P0037oo00<007ooOol02Goo6P0037oo0`002Woo000@Ool0
0`00Ool0000;Ool00`00Oomoo`0:Ool00`00Oomoo`09Ool00`00Oomoo`0:Oolc00000goo001oo`0F
Ool00`00Ool0000;OolJ000<Ool00`00Oomoo`09OolJ000<Ool00`00Ool0000:Ool0011oo`03001o
o`0000]oo`03001oogoo00Yoo`03001oogoo00Uoo`03001oogoo00Yooc<00003Ool007oo01Ioo`03
001oo`0000]ooaX000aoo`03001oogoo00UooaX000aoo`03001oo`0000Yoo`0047oo00<007oo0000
2goo00<007ooOol02Woo00<007ooOol02Goo00<007ooOol02Woo<`0000=oo`00Ool05Woo00<007oo
00002goo6P0037oo00<007ooOol02Goo6P0037oo00<007oo00002Woo000@Ool00`00Ool0000;Ool0
0`00Oomoo`0:Ool00`00Oomoo`09Ool00`00Oomoo`0:Oolc00000goo001oo`0FOol00`00Ool0000;
OolJ000<Ool00`00Oomoo`09OolJ000<Ool00`00Ool0000:Ool0011oo`03001oo`0000]oo`03001o
ogoo00Yoo`03001oogoo00Uoo`03001oogoo00Yooc<00003Ool007oo01Ioo`03001oo`0000]ooaX0
00aoo`03001oogoo00UooaX000aoo`03001oo`0000Yoo`0047oo00<007oo00002goo00<007ooOol0
2Woo00<007ooOol02Goo00<007ooOol02Woo<`0000=oo`00Ool05Woo00<007oo00002goo6P0037oo
00<007ooOol02Goo6P0037oo00<007oo00002Woo000@Ool00`00Ool0001V000GOol00`00Ool0001V
000:Ool0011oo`03001oo`0000]oo`h000]ooaX000aoo`d000aoo`03001oo`0001Moo`03001oo`00
00]ooaX000aoo`d000aoo`03001oogoo00Uoo`h00003Ool007oo00Uoo`0047oo00<007oo00002goo
3P002goo6P0037oo3@0037oo00<007oo00005goo00<007oo00002goo6P0037oo3@0037oo00<007oo
Ool02Goo3P0000=oo`00Ool02Goo000@Ool00`00Ool0000;Ool>000;OolJ000<Ool=000<Ool00`00
Ool0000GOol00`00Ool0000;OolJ000<Ool=000<Ool00`00Oomoo`09Ool>00000goo001oo`09Ool0
011oo`03001oo`0000]oo`h000]ooaX000aoo`d000aoo`03001oo`0001Moo`03001oo`0000]ooaX0
00aoo`d000aoo`03001oogoo00Uoo`h00003Ool007oo00Uoo`0047oo00<007oo00002goo3P002goo
6P0037oo3@0037oo00<007oo00005goo00<007oo00002goo6P0037oo3@0037oo00<007ooOol02Goo
3P0000=oo`00Ool02Goo000@Ool00`00Ool0000;Ool>000;OolJ000<Ool=000<Ool3000GOol00`00
Ool0000;OolJ000<Ool=000<Ool00`00Oomoo`09Ool@000:Ool0011oo`03001oo`0000]oo`h000]o
oaX000aoo`d000aoo`03001oo`0001Moo`03001oo`0000]ooaX000aoo`d000aoo`03001oogoo00Uo
o`h00003Ool007oo00Uoo`0047oo00<007oo00002goo3P002goo6P0037oo3@0037oo00<007oo0000
5goo00<007oo00002goo6P0037oo3@0037oo00<007ooOol02Goo3P0000=oo`00Ool02Goo000@Ool0
0`00Ool0000;Ool>000;OolJ000<Ool=000<Ool00`00Ool0000GOol00`00Ool0000;OolJ000<Ool=
000<Ool00`00Oomoo`09Ool>00000goo001oo`09Ool000Yoo`8000Aoo`03001oo`0000]oo`h000]o
oaX000aoo`d000aoo`03001oo`00019oo`8000=oo`03001oo`0000]ooaX000aoo`d000aoo`03001o
ogoo00Uoo`h00003Ool007oo00Uoo`002Woo00<007oo00000goo00<007oo00002goo3P002goo6P00
37oo3@0037oo00<007oo00004Woo00<007oo00000Woo00<007oo00002goo6P0037oo3@0037oo00<0
07ooOol02Goo3P0000=oo`00Ool02Goo000:Ool00`00Ool00003Ool00`00Ool0001V000BOol00`00
Ool00002OomY000:Ool000Yoo`8000Aoo`03001oo`0000]oo`03001oogoo00Yooc<000]oo`03001o
ogoo00Yoo`03001oo`00019oo`8000=oo`03001oo`0000]oo`h000]ooaX000aoo`d000aoo`03001o
o`0000Yoo`002Woo00<007ooOol00goo00<007oo00002goo00<007ooOol02Woo<`002goo00<007oo
Ool02Woo00<007oo00004Woo00<007ooOol00Woo00<007oo00002goo3P002goo6P0037oo3@0037oo
00<007oo00002Woo000;Ool20003Ool00`00Ool0000;Ool00`00Oomoo`0:Oolc000;Ool00`00Oomo
o`0:Ool00`00Ool0000COol20002Ool00`00Ool0000;Ool>000;OolJ000<Ool=000<Ool00`00Ool0
000:Ool0011oo`03001oo`0000]oo`03001oogoo00Yooc<000]oo`03001oogoo00Yoo`03001oo`00
01Moo`03001oo`0000]oo`h000]ooaX000aoo`d000aoo`03001oo`0000Yoo`0047oo00<007oo0000
2goo00<007ooOol02Woo<`002goo00<007ooOol02Woo00<007oo00005goo00<007oo00002goo3P00
2goo6P0037oo3@0037oo00<007oo00002Woo000@Ool00`00Ool0000;Ool00`00Oomoo`0:Oolc000;
Ool00`00Oomoo`0:Ool3000GOol00`00Ool0000;Ool>000;OolJ000<Ool=000<Ool3000:Ool0011o
o`03001oo`0000]oo`03001oogoo00Yooc<000]oo`03001oogoo00Yoo`03001oo`0001Moo`03001o
o`0000]oo`h000]ooaX000aoo`d000aoo`03001oo`0000Yoo`0047oo00<007oo00002goo00<007oo
Ool02Woo<`002goo00<007ooOol02Woo00<007oo00005goo00<007oo00002goo3P002goo6P0037oo
3@0037oo00<007oo00002Woo000@Ool00`00Ool0000;Ool00`00Oomoo`0:Oolc000;Ool00`00Oomo
o`0:Ool00`00Ool0000GOol00`00Ool0000;Ool>000;OolJ000<Ool=000<Ool00`00Ool0000:Ool0
011oo`03001oo`0000]oo`03001oogoo00Yooc<000]oo`03001oogoo00Yoo`03001oo`0001Moo`03
001oo`0000]oo`h000]ooaX000aoo`d000aoo`03001oo`0000Yoo`0047oo00<007oo00002goo00<0
07ooOol02Woo<`002goo00<007ooOol02Woo00<007oo00005goo00<007oo00002goo3P002goo6P00
37oo3@0037oo00<007oo00002Woo000@Ool00`00Ool0000;Ool00`00Oomoo`0:Oolc000;Ool00`00
Oomoo`0:Ool00`00Ool0000GOol00`00Ool0000;Ool>000;OolJ000<Ool=000<Ool00`00Ool0000:
Ool0011oo`03001oo`0006H001Moo`03001oo`0006H000Yoo`0047oo00<007oo00002goo6P0037oo
3@0037oo00<007ooOol02Goo3P0000=oo`00Ool05Woo00<007oo00002goo3P002goo3P002goo3P00
2goo3P0000=oo`00Ool02Goo000@Ool00`00Ool0000;OolJ000<Ool=000<Ool00`00Oomoo`09Ool>
00000goo001oo`0FOol00`00Ool0000;Ool>000;Ool>000;Ool>000;Ool>00000goo001oo`09Ool0
011oo`03001oo`0000]ooaX000aoo`d000aoo`03001oogoo00Uoo`h00003Ool007oo01Ioo`03001o
o`0000]oo`h000]oo`h000]oo`h000]oo`h00003Ool007oo00Uoo`0047oo00<007oo00002goo6P00
37oo3@0037oo00<007ooOol02Goo3P0000=oo`00Ool05Woo00<007oo00002goo3P002goo3P002goo
3P002goo3P0000=oo`00Ool02Goo000@Ool00`00Ool0000;OolJ000<Ool=000<Ool00`00Oomoo`09
Ool>00000goo001oo`0FOol00`00Ool0000;Ool>000;Ool>000;Ool>000;Ool>00000goo001oo`09
Ool0011oo`03001oo`0000]ooaX000aoo`d000aoo`03001oogoo00Uooa0001Moo`03001oo`0000]o
o`h000]oo`h000]oo`h000]ooa0000Yoo`0047oo00<007oo00002goo6P0037oo3@0037oo00<007oo
Ool02Goo3P0000=oo`00Ool05Woo00<007oo00002goo3P002goo3P002goo3P002goo3P0000=oo`00
Ool02Goo000@Ool00`00Ool0000;OolJ000<Ool=000<Ool00`00Oomoo`09Ool>00000goo001oo`0F
Ool00`00Ool0000;Ool>000;Ool>000;Ool>000;Ool>00000goo001oo`09Ool0011oo`03001oo`00
00]ooaX000aoo`d000aoo`03001oogoo00Uoo`h00003Ool007oo01Ioo`03001oo`0000]oo`h000]o
o`h000]oo`h000]oo`h00003Ool007oo00Uoo`002goo00<007ooOol00Woo00<007oo00002goo6P00
37oo3@0037oo00<007ooOol02Goo3P0000=oo`00Ool04Woo00L007ooOomoo`00Ool0000;Ool>000;
Ool>000;Ool>000;Ool>00000goo001oo`09Ool000Yoo`03001oo`0000=oo`03001oo`0000]ooaX0
00aoo`d000aoo`03001oogoo00Uoo`h00003Ool007oo015oo`03001oo`00009oo`03001oo`0000]o
o`h000]oo`h000]oo`h000]oo`h00003Ool007oo00Uoo`002Woo00<007oo00000goo00<007oo0000
IP004Woo00<007oo00000WooJ@002Woo000;Ool00`00Oomoo`02Ool00`00Ool0000HOol00`00Oomo
o`0FOol00`00Oomoo`0FOol00`00Oomoo`0FOol00`00Ool0000COol01`00Oomoogoo001oo`0001Qo
o`03001oogoo01Ioo`03001oogoo01Ioo`03001oogoo01Ioo`03001oo`0000Yoo`002Woo00<007oo
00000gooJ@004Woo00<007oo00000WooJ@002Woo000;Ool00`00Oomoo`1nOol00`00Oomoo`1dOol0
0?moo`Aoo`00ogoo17oo003oOol4Ool00?moo`Aoo`00\
\>"],
  ImageRangeCache->{{{0, 258.313}, {122.438, 0}} -> {-0.0548844, -0.0238146, 
  0.00816751, 0.00816751}, {{6.6875, 123.313}, {119.5, 
  2.875}} -> {-1.46109, -1.22068, 0.0801368, 0.0801368}, {{134.938, 
  251.563}, {119.5, 2.875}} -> {-11.7386, -1.22068, 0.0801368, 0.0801368}}]
}, Open  ]],

Cell[TextData[{
  "More importantly, matrix ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalH]\_N\)]],
  " is orthogonal, meaning that its inverse is equal to it transpose. The \
Hadamard transformation is therefore a unitary transformation, like the more \
familiar Fourier and cosine transforms. Here we demonstrate the orthogonality \
of the matrix ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalH]\_8\)]],
  ". "
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[ScriptCapitalH]\_8 . Transpose[\[ScriptCapitalH]\_8]\  == \ 
      IdentityMatrix[8]\)], "Input",
  CellLabel->"In[9]:="],

Cell[BoxData[
    \(True\)], "Output",
  CellLabel->"Out[9]="]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["WHT AS A MATRIX OPERATION", "Section"],

Cell[TextData[{
  "The 1-D WHT is a sum of point-by-point products of samples of the input \
sequence with samples of the Walsh-Hadamard basis sequences. As such, this \
summation can be represented as a matrix product of a matrix \
\[ScriptCapitalH] (we drop the subscript for convenience) with the sequence ",
  
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " represented by a vector of length ",
  Cell[BoxData[
      \(TraditionalForm\`N\)]],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell["Analysis and Synthesis Formulations, 1D WHT", "Subsubsection"],

Cell[TextData[{
  "Given an ",
  Cell[BoxData[
      \(TraditionalForm\`N\)]],
  " by ",
  Cell[BoxData[
      \(TraditionalForm\`N\)]],
  " Hadamard matrix and an  ",
  Cell[BoxData[
      \(TraditionalForm\`N\)]],
  "-point vector ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  ",  the ",
  Cell[BoxData[
      \(TraditionalForm\`N\)]],
  "-point forward and inverse WHTs  can be computed using matrix \
multiplication:"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`X\  = \ \[ScriptCapitalH] . \ x\)]],
  "\t(analysis)"
}], "NumberedEquation"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`x\  = \ \[ScriptCapitalH] . \ X\)]],
  "\t(synthesis)"
}], "NumberedEquation"],

Cell["\<\
Note, that the analysis and synthesis formulations are identical.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Analysis and Synthesis Formulations, 2D WHT", "Subsubsection"],

Cell["\<\
To obtain the 2D WHT matrix formulations, note that the 2-D WHT is a \
separable transformation, therefore it may be computed using a sequence of \
row and column 1-D WHT transformations. The row and column operations may be \
concisely expressed with the following matrix operation:\
\>", "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm
      \`X\  = \ \(\[ScriptCapitalH] . \ x . \[ScriptCapitalH]\^T = \ \ 
          \[ScriptCapitalH] . \ x . \[ScriptCapitalH]\)\)]],
  "\t\t\t(analysis)"
}], "NumberedEquation"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm
      \`x\  = \ \(\[ScriptCapitalH] . \ X . \ \((\[ScriptCapitalH])\)\^T\  = 
          \ \ \[ScriptCapitalH] . \ X . \ \[ScriptCapitalH]\)\)]],
  "\t\t\t(synthesis)"
}], "NumberedEquation"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["EXAMPLES", "Section"],

Cell["\<\
The Hadamard kernel, as verified in an earlier section, is orthogonal and \
symmetric and because it is real, it is also unitary and Hermitian. This \
results in identical formulations for the foward and inverse transformations.\
\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(X\_H = \[ScriptCapitalH] . X . \[ScriptCapitalH]; \n
    X\&~ = \[ScriptCapitalH] . X\_H . \[ScriptCapitalH]\  // Chop; \n
    Show[GraphicsArray[{{ListPlot3D[X\_H, DisplayFunction \[Rule] Identity], 
            ListDensityPlot[X\_H, Mesh \[Rule] False, 
              DisplayFunction \[Rule] Identity]}, {
            ListPlot3D[X\&~, DisplayFunction \[Rule] Identity], 
            ListDensityPlot[X\&~, Mesh \[Rule] False, 
              DisplayFunction \[Rule] Identity]}}]]; \)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0193128 0.47619 [
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0193128 0.477324 0.387175 MathSubStart
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
5.55112e-017 1.04977 -0.0679587 1.04977 [
[.11158 .21312 -6 -8.95035 ]
[.11158 .21312 0 .04965 ]
[.28836 .14356 -5.67606 -9 ]
[.28836 .14356 .32394 0 ]
[.47788 .06904 -5.31864 -9 ]
[.47788 .06904 .68136 0 ]
[.68156 -0.01098 -4.96123 -9 ]
[.68156 -0.01098 1.03877 0 ]
[.74908 .0689 0 -6.18931 ]
[.74908 .0689 6 2.81069 ]
[.83635 .20254 0 -6.06047 ]
[.83635 .20254 6 2.93953 ]
[.9134 .32052 0 -5.94988 ]
[.9134 .32052 6 3.05012 ]
[.98191 .42546 0 -5.85393 ]
[.98191 .42546 6 3.14607 ]
[.02411 .26511 -6 -2.74232 ]
[.02411 .26511 0 6.25768 ]
[.01568 .31795 -24 -2.78699 ]
[.01568 .31795 0 6.21301 ]
[.00696 .37264 -18 -2.83339 ]
[.00696 .37264 0 6.16661 ]
[-0.00208 .42927 -24 -2.88161 ]
[-0.00208 .42927 0 6.11839 ]
[-0.01144 .48795 -6 -2.93176 ]
[-0.01144 .48795 0 6.06824 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.03716 .25514 m
.68874 0 L
s
.12091 .22234 m
.12558 .22696 L
s
[(2)] .11158 .21312 1 .98897 Mshowa
.2971 .15335 m
.30147 .15825 L
s
[(4)] .28836 .14356 .89202 1 Mshowa
.4859 .07942 m
.48992 .08461 L
s
[(6)] .47788 .06904 .77288 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(8)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.16384 .20553 m
.1666 .20834 L
s
.20751 .18843 m
.21022 .19129 L
s
.25192 .17104 m
.25459 .17394 L
s
.34306 .13535 m
.34564 .13834 L
s
.38984 .11704 m
.39236 .12006 L
s
.43745 .0984 m
.43991 .10147 L
s
.53524 .06011 m
.53759 .06327 L
s
.58547 .04044 m
.58776 .04364 L
s
.63663 .0204 m
.63885 .02365 L
s
.07869 .23888 m
.08153 .2416 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.7368 .07352 m
.73065 .07582 L
s
[(2)] .74908 .0689 -1 .3754 Mshowa
.82395 .20683 m
.81775 .20898 L
s
[(4)] .83635 .20254 -1 .34677 Mshowa
.90091 .32455 m
.89466 .32656 L
s
[(6)] .9134 .32052 -1 .3222 Mshowa
.96935 .42924 m
.96306 .43113 L
s
[(8)] .98191 .42546 -1 .30087 Mshowa
.125 Mabswid
.75965 .10848 m
.75596 .10983 L
s
.78177 .14231 m
.77807 .14365 L
s
.8032 .17508 m
.79948 .1764 L
s
.84407 .23761 m
.84035 .23888 L
s
.86359 .26746 m
.85986 .26871 L
s
.88252 .29643 m
.87878 .29766 L
s
.91876 .35185 m
.915 .35304 L
s
.9361 .37838 m
.93234 .37955 L
s
.95296 .40417 m
.94919 .40532 L
s
.71317 .03738 m
.7095 .03879 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03634 .26033 m
.04245 .25795 L
s
[(0)] .02411 .26511 1 -0.3906 Mshowa
.02795 .31328 m
.03408 .31095 L
s
[(0.25)] .01568 .31795 1 -0.38067 Mshowa
.01926 .36808 m
.02541 .3658 L
s
[(0.5)] .00696 .37264 1 -0.37036 Mshowa
.01027 .42483 m
.01644 .42261 L
s
[(0.75)] -0.00208 .42927 1 -0.35964 Mshowa
.00095 .48363 m
.00715 .48147 L
s
[(1)] -0.01144 .48795 1 -0.3485 Mshowa
.125 Mabswid
.03468 .27078 m
.03835 .26935 L
s
.03301 .2813 m
.03669 .27988 L
s
.03134 .29189 m
.03501 .29047 L
s
.02965 .30255 m
.03332 .30114 L
s
.02623 .32409 m
.02991 .3227 L
s
.02451 .33497 m
.02819 .33359 L
s
.02277 .34593 m
.02646 .34455 L
s
.02102 .35697 m
.02471 .35559 L
s
.01749 .37927 m
.02118 .37791 L
s
.0157 .39054 m
.0194 .38919 L
s
.0139 .40189 m
.0176 .40054 L
s
.01209 .41332 m
.01579 .41198 L
s
.00843 .43642 m
.01214 .4351 L
s
.00658 .4481 m
.01029 .44678 L
s
.00472 .45986 m
.00843 .45855 L
s
.00284 .4717 m
.00656 .4704 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.5 Mabswid
.664 .741 .908 r
.36056 .56222 .40512 .60371 .47916 .5815 .4359 .53885 Metetra
.664 .741 .908 r
.4359 .53885 .47916 .5815 .55526 .55867 .5134 .5148 Metetra
.664 .741 .908 r
.5134 .5148 .55526 .55867 .63352 .53519 .59315 .49006 Metetra
.664 .741 .908 r
.59315 .49006 .63352 .53519 .71403 .51104 .67525 .46458 Metetra
.664 .741 .908 r
.67525 .46458 .71403 .51104 .79688 .48619 .75981 .43835 Metetra
.664 .741 .908 r
.75981 .43835 .79688 .48619 .88217 .4606 .84693 .41131 Metetra
.664 .741 .908 r
.84693 .41131 .88217 .4606 .97003 .43424 .93675 .38345 Metetra
.664 .741 .908 r
.31365 .51855 .36056 .56222 .4359 .53885 .39033 .49391 Metetra
.664 .741 .908 r
.39033 .49391 .4359 .53885 .5134 .5148 .46926 .46855 Metetra
.664 .741 .908 r
.46926 .46855 .5134 .5148 .59315 .49006 .55055 .44243 Metetra
.664 .741 .908 r
.55055 .44243 .59315 .49006 .67525 .46458 .6343 .41553 Metetra
.664 .741 .908 r
.6343 .41553 .67525 .46458 .75981 .43835 .72063 .38779 Metetra
.664 .741 .908 r
.72063 .38779 .75981 .43835 .84693 .41131 .80966 .35918 Metetra
.664 .741 .908 r
.80966 .35918 .84693 .41131 .93675 .38345 .90152 .32967 Metetra
.664 .741 .908 r
.2642 .4725 .31365 .51855 .39033 .49391 .34225 .4465 Metetra
.664 .741 .908 r
.34225 .4465 .39033 .49391 .46926 .46855 .42266 .41972 Metetra
.664 .741 .908 r
.42266 .41972 .46926 .46855 .55055 .44243 .50553 .39211 Metetra
.664 .741 .908 r
.50553 .39211 .55055 .44243 .6343 .41553 .591 .36364 Metetra
.664 .741 .908 r
.591 .36364 .6343 .41553 .72063 .38779 .67917 .33427 Metetra
.664 .741 .908 r
.67917 .33427 .72063 .38779 .80966 .35918 .77017 .30396 Metetra
.664 .741 .908 r
.77017 .30396 .80966 .35918 .90152 .32967 .86416 .27265 Metetra
.664 .741 .908 r
.212 .42389 .2642 .4725 .34225 .4465 .29145 .39641 Metetra
.664 .741 .908 r
.29145 .39641 .34225 .4465 .42266 .41972 .37338 .36808 Metetra
.664 .741 .908 r
.37338 .36808 .42266 .41972 .50553 .39211 .45789 .33885 Metetra
.664 .741 .908 r
.45789 .33885 .50553 .39211 .591 .36364 .54512 .30868 Metetra
.664 .741 .908 r
.54512 .30868 .591 .36364 .67917 .33427 .6352 .27753 Metetra
.664 .741 .908 r
.6352 .27753 .67917 .33427 .77017 .30396 .72827 .24535 Metetra
.664 .741 .908 r
.72827 .24535 .77017 .30396 .86416 .27265 .82447 .21208 Metetra
.664 .741 .908 r
.1568 .3725 .212 .42389 .29145 .39641 .2377 .34341 Metetra
.901 .485 .132 r
.2377 .34341 .29145 .39641 .37338 .36808 .30686 .53394 Metetra
.409 .068 .272 r
.30686 .53394 .37338 .36808 .45789 .33885 .39898 .50457 Metetra
.409 .068 .272 r
.39898 .50457 .45789 .33885 .54512 .30868 .49438 .47416 Metetra
.49438 .47416 .54512 .30868 .6352 .27753 .5885 .21727 Metetra
.664 .741 .908 r
.5885 .21727 .6352 .27753 .72827 .24535 .68371 .18303 Metetra
.664 .741 .908 r
.68371 .18303 .72827 .24535 .82447 .21208 .78223 .14761 Metetra
.664 .741 .908 r
.09834 .31807 .1568 .3725 .2377 .34341 .18072 .28723 Metetra
.901 .485 .132 r
.18072 .28723 .2377 .34341 .30686 .53394 .24699 .47891 Metetra
.646 .762 .934 r
.24699 .47891 .30686 .53394 .39898 .50457 .3411 .44757 Metetra
.646 .762 .934 r
.3411 .44757 .39898 .50457 .49438 .47416 .43867 .41508 Metetra
.938 .772 .649 r
.43867 .41508 .49438 .47416 .5885 .21727 .53881 .15314 Metetra
.664 .741 .908 r
.53881 .15314 .5885 .21727 .68371 .18303 .63625 .11666 Metetra
.664 .741 .908 r
.63625 .11666 .68371 .18303 .78223 .14761 .73719 .07886 Metetra
.664 .741 .908 r
.03634 .26033 .09834 .31807 .18072 .28723 .12022 .22757 Metetra
.901 .485 .132 r
.12022 .22757 .18072 .28723 .24699 .47891 .18308 .42016 Metetra
.646 .762 .934 r
.18308 .42016 .24699 .47891 .3411 .44757 .27924 .38665 Metetra
.646 .762 .934 r
.27924 .38665 .3411 .44757 .43867 .41508 .37905 .35186 Metetra
.938 .772 .649 r
.37905 .35186 .43867 .41508 .53881 .15314 .48583 .08476 Metetra
.664 .741 .908 r
.48583 .08476 .53881 .15314 .63625 .11666 .58558 .0458 Metetra
.664 .741 .908 r
.58558 .0458 .63625 .11666 .73719 .07886 .68905 .00539 Metetra
0 g
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.12091 .22234 m
.12558 .22696 L
s
[(2)] .11158 .21312 1 .98897 Mshowa
.2971 .15335 m
.30147 .15825 L
s
[(4)] .28836 .14356 .89202 1 Mshowa
.4859 .07942 m
.48992 .08461 L
s
[(6)] .47788 .06904 .77288 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(8)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.16384 .20553 m
.1666 .20834 L
s
.20751 .18843 m
.21022 .19129 L
s
.25192 .17104 m
.25459 .17394 L
s
.34306 .13535 m
.34564 .13834 L
s
.38984 .11704 m
.39236 .12006 L
s
.43745 .0984 m
.43991 .10147 L
s
.53524 .06011 m
.53759 .06327 L
s
.58547 .04044 m
.58776 .04364 L
s
.63663 .0204 m
.63885 .02365 L
s
.07869 .23888 m
.08153 .2416 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0193128 0.97619 0.387175 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.120192 0.0192308 0.120192 [
[.01923 -0.0125 -3 -9 ]
[.01923 -0.0125 3 0 ]
[.25962 -0.0125 -3 -9 ]
[.25962 -0.0125 3 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.74038 -0.0125 -3 -9 ]
[.74038 -0.0125 3 0 ]
[.98077 -0.0125 -3 -9 ]
[.98077 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01923 -6 -4.5 ]
[-0.0125 .01923 0 4.5 ]
[-0.0125 .25962 -6 -4.5 ]
[-0.0125 .25962 0 4.5 ]
[-0.0125 .5 -6 -4.5 ]
[-0.0125 .5 0 4.5 ]
[-0.0125 .74038 -6 -4.5 ]
[-0.0125 .74038 0 4.5 ]
[-0.0125 .98077 -6 -4.5 ]
[-0.0125 .98077 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.01923 0 m
.01923 .00625 L
s
[(0)] .01923 -0.0125 0 1 Mshowa
.25962 0 m
.25962 .00625 L
s
[(2)] .25962 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(4)] .5 -0.0125 0 1 Mshowa
.74038 0 m
.74038 .00625 L
s
[(6)] .74038 -0.0125 0 1 Mshowa
.98077 0 m
.98077 .00625 L
s
[(8)] .98077 -0.0125 0 1 Mshowa
.125 Mabswid
.07933 0 m
.07933 .00375 L
s
.13942 0 m
.13942 .00375 L
s
.19952 0 m
.19952 .00375 L
s
.31971 0 m
.31971 .00375 L
s
.37981 0 m
.37981 .00375 L
s
.4399 0 m
.4399 .00375 L
s
.5601 0 m
.5601 .00375 L
s
.62019 0 m
.62019 .00375 L
s
.68029 0 m
.68029 .00375 L
s
.80048 0 m
.80048 .00375 L
s
.86058 0 m
.86058 .00375 L
s
.92067 0 m
.92067 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01923 m
.00625 .01923 L
s
[(0)] -0.0125 .01923 1 0 Mshowa
0 .25962 m
.00625 .25962 L
s
[(2)] -0.0125 .25962 1 0 Mshowa
0 .5 m
.00625 .5 L
s
[(4)] -0.0125 .5 1 0 Mshowa
0 .74038 m
.00625 .74038 L
s
[(6)] -0.0125 .74038 1 0 Mshowa
0 .98077 m
.00625 .98077 L
s
[(8)] -0.0125 .98077 1 0 Mshowa
.125 Mabswid
0 .07933 m
.00375 .07933 L
s
0 .13942 m
.00375 .13942 L
s
0 .19952 m
.00375 .19952 L
s
0 .31971 m
.00375 .31971 L
s
0 .37981 m
.00375 .37981 L
s
0 .4399 m
.00375 .4399 L
s
0 .5601 m
.00375 .5601 L
s
0 .62019 m
.00375 .62019 L
s
0 .68029 m
.00375 .68029 L
s
0 .80048 m
.00375 .80048 L
s
0 .86058 m
.00375 .86058 L
s
0 .92067 m
.00375 .92067 L
s
.25 Mabswid
0 0 m
0 1 L
s
.01923 .99375 m
.01923 1 L
s
.25962 .99375 m
.25962 1 L
s
.5 .99375 m
.5 1 L
s
.74038 .99375 m
.74038 1 L
s
.98077 .99375 m
.98077 1 L
s
.125 Mabswid
.07933 .99625 m
.07933 1 L
s
.13942 .99625 m
.13942 1 L
s
.19952 .99625 m
.19952 1 L
s
.31971 .99625 m
.31971 1 L
s
.37981 .99625 m
.37981 1 L
s
.4399 .99625 m
.4399 1 L
s
.5601 .99625 m
.5601 1 L
s
.62019 .99625 m
.62019 1 L
s
.68029 .99625 m
.68029 1 L
s
.80048 .99625 m
.80048 1 L
s
.86058 .99625 m
.86058 1 L
s
.92067 .99625 m
.92067 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .01923 m
1 .01923 L
s
.99375 .25962 m
1 .25962 L
s
.99375 .5 m
1 .5 L
s
.99375 .74038 m
1 .74038 L
s
.99375 .98077 m
1 .98077 L
s
.125 Mabswid
.99625 .07933 m
1 .07933 L
s
.99625 .13942 m
1 .13942 L
s
.99625 .19952 m
1 .19952 L
s
.99625 .31971 m
1 .31971 L
s
.99625 .37981 m
1 .37981 L
s
.99625 .4399 m
1 .4399 L
s
.99625 .5601 m
1 .5601 L
s
.99625 .62019 m
1 .62019 L
s
.99625 .68029 m
1 .68029 L
s
.99625 .80048 m
1 .80048 L
s
.99625 .86058 m
1 .86058 L
s
.99625 .92067 m
1 .92067 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
0000FFFFFF000000
0000FFFFFF000000
0000FFFFFF000000
0000000000000000
0000000000000000
0000000000000000
0000000000000000
0000000000000000
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.423961 0.477324 0.791823 MathSubStart
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1.04977 -0.0679587 1.04977 [
[.11158 .21312 -6 -8.95035 ]
[.11158 .21312 0 .04965 ]
[.28836 .14356 -5.67606 -9 ]
[.28836 .14356 .32394 0 ]
[.47788 .06904 -5.31864 -9 ]
[.47788 .06904 .68136 0 ]
[.68156 -0.01098 -4.96123 -9 ]
[.68156 -0.01098 1.03877 0 ]
[.74908 .0689 0 -6.18931 ]
[.74908 .0689 6 2.81069 ]
[.83635 .20254 0 -6.06047 ]
[.83635 .20254 6 2.93953 ]
[.9134 .32052 0 -5.94988 ]
[.9134 .32052 6 3.05012 ]
[.98191 .42546 0 -5.85393 ]
[.98191 .42546 6 3.14607 ]
[.02226 .2767 -12 -2.7521 ]
[.02226 .2767 0 6.2479 ]
[.01473 .32393 -24 -2.79206 ]
[.01473 .32393 0 6.20794 ]
[.00696 .37264 -6 -2.83339 ]
[.00696 .37264 0 6.16661 ]
[-0.00106 .42288 -18 -2.87616 ]
[-0.00106 .42288 0 6.12384 ]
[-0.00933 .47473 -6 -2.92044 ]
[-0.00933 .47473 0 6.07956 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.03716 .25514 m
.68874 0 L
s
.12091 .22234 m
.12558 .22696 L
s
[(2)] .11158 .21312 1 .98897 Mshowa
.2971 .15335 m
.30147 .15825 L
s
[(4)] .28836 .14356 .89202 1 Mshowa
.4859 .07942 m
.48992 .08461 L
s
[(6)] .47788 .06904 .77288 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(8)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.16384 .20553 m
.1666 .20834 L
s
.20751 .18843 m
.21022 .19129 L
s
.25192 .17104 m
.25459 .17394 L
s
.34306 .13535 m
.34564 .13834 L
s
.38984 .11704 m
.39236 .12006 L
s
.43745 .0984 m
.43991 .10147 L
s
.53524 .06011 m
.53759 .06327 L
s
.58547 .04044 m
.58776 .04364 L
s
.63663 .0204 m
.63885 .02365 L
s
.07869 .23888 m
.08153 .2416 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.7368 .07352 m
.73065 .07582 L
s
[(2)] .74908 .0689 -1 .3754 Mshowa
.82395 .20683 m
.81775 .20898 L
s
[(4)] .83635 .20254 -1 .34677 Mshowa
.90091 .32455 m
.89466 .32656 L
s
[(6)] .9134 .32052 -1 .3222 Mshowa
.96935 .42924 m
.96306 .43113 L
s
[(8)] .98191 .42546 -1 .30087 Mshowa
.125 Mabswid
.75965 .10848 m
.75596 .10983 L
s
.78177 .14231 m
.77807 .14365 L
s
.8032 .17508 m
.79948 .1764 L
s
.84407 .23761 m
.84035 .23888 L
s
.86359 .26746 m
.85986 .26871 L
s
.88252 .29643 m
.87878 .29766 L
s
.91876 .35185 m
.915 .35304 L
s
.9361 .37838 m
.93234 .37955 L
s
.95296 .40417 m
.94919 .40532 L
s
.71317 .03738 m
.7095 .03879 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.0345 .27194 m
.04061 .26957 L
s
[(-1)] .02226 .2767 1 -0.38842 Mshowa
.027 .31928 m
.03313 .31695 L
s
[(-0.5)] .01473 .32393 1 -0.37954 Mshowa
.01926 .36808 m
.02541 .3658 L
s
[(0)] .00696 .37264 1 -0.37036 Mshowa
.01128 .41842 m
.01746 .4162 L
s
[(0.5)] -0.00106 .42288 1 -0.36085 Mshowa
.00305 .47038 m
.00924 .46821 L
s
[(1)] -0.00933 .47473 1 -0.35101 Mshowa
.125 Mabswid
.03301 .2813 m
.03669 .27988 L
s
.03152 .29071 m
.0352 .28929 L
s
.03002 .30017 m
.0337 .29876 L
s
.02851 .3097 m
.03219 .30829 L
s
.02547 .32892 m
.02915 .32753 L
s
.02393 .33862 m
.02762 .33723 L
s
.02238 .34838 m
.02607 .347 L
s
.02083 .3582 m
.02452 .35683 L
s
.01769 .37802 m
.02138 .37666 L
s
.0161 .38803 m
.0198 .38667 L
s
.01451 .3981 m
.0182 .39675 L
s
.0129 .40823 m
.0166 .40689 L
s
.00966 .42868 m
.01336 .42735 L
s
.00802 .43901 m
.01173 .43768 L
s
.00638 .4494 m
.01009 .44808 L
s
.00472 .45986 m
.00843 .45855 L
s
.03597 .26265 m
.03964 .26122 L
s
.00137 .48097 m
.00509 .47968 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.5 Mabswid
.363 .797 .622 r
.35406 .69623 .40286 .66852 .47798 .66912 .43294 .65063 Metetra
.759 .884 .935 r
.43294 .65063 .47798 .66912 .55626 .66974 .51309 .60429 Metetra
.555 .621 .873 r
.51309 .60429 .55626 .66974 .6364 .62413 .59549 .60352 Metetra
.609 .863 .991 r
.59549 .60352 .6364 .62413 .71911 .60064 .68048 .57889 Metetra
.755 .897 .941 r
.68048 .57889 .71911 .60064 .80621 .59978 .7664 .52983 Metetra
.722 .692 .821 r
.7664 .52983 .80621 .59978 .89722 .59889 .85377 .47993 Metetra
.582 .533 .765 r
.85377 .47993 .89722 .59889 .98579 .54953 .94867 .47624 Metetra
.746 .771 .873 r
.30506 .65445 .35406 .69623 .43294 .65063 .38573 .60725 Metetra
.746 .771 .873 r
.38573 .60725 .43294 .65063 .51309 .60429 .46773 .55927 Metetra
.508 .696 .954 r
.46773 .55927 .51309 .60429 .59549 .60352 .55145 .55746 Metetra
.655 .753 .922 r
.55145 .55746 .59549 .60352 .68048 .57889 .63822 .53139 Metetra
.747 .779 .879 r
.63822 .53139 .68048 .57889 .7664 .52983 .72628 .48048 Metetra
.747 .779 .879 r
.72628 .48048 .7664 .52983 .85377 .47993 .81588 .42868 Metetra
.536 .693 .94 r
.81588 .42868 .85377 .47993 .94867 .47624 .91275 .42366 Metetra
.859 .997 .793 r
.2475 .68364 .30506 .65445 .38573 .60725 .33449 .58535 Metetra
.872 .852 .82 r
.33449 .58535 .38573 .60725 .46773 .55927 .4205 .48818 Metetra
.192 .425 .857 r
.4205 .48818 .46773 .55927 .55145 .55746 .50469 .53303 Metetra
.615 .861 .99 r
.50469 .53303 .55145 .55746 .63822 .53139 .59394 .50559 Metetra
.884 .881 .826 r
.59394 .50559 .63822 .53139 .72628 .48048 .68258 .40417 Metetra
.811 .723 .767 r
.68258 .40417 .72628 .48048 .81588 .42868 .77017 .30396 Metetra
.437 .447 .772 r
.77017 .30396 .81588 .42868 .91275 .42366 .87192 .34348 Metetra
.558 .453 .69 r
.2054 .49228 .2475 .68364 .33449 .58535 .28474 .4889 Metetra
.555 .564 .818 r
.28474 .4889 .33449 .58535 .4205 .48818 .36781 .48537 Metetra
.718 .966 .938 r
.36781 .48537 .4205 .48818 .50469 .53303 .45591 .43264 Metetra
.639 .606 .8 r
.45591 .43264 .50469 .53303 .59394 .50559 .54573 .40312 Metetra
.562 .566 .815 r
.54573 .40312 .59394 .50559 .68258 .40417 .63946 .39729 Metetra
.172 .703 .848 r
.63946 .39729 .68258 .40417 .77017 .30396 .73793 .39116 Metetra
.209 0 .071 r
.73793 .39116 .77017 .30396 .87192 .34348 .83645 .33341 Metetra
.584 .943 .826 r
.14048 .51413 .2054 .49228 .28474 .4889 .22699 .4614 Metetra
.763 .868 .926 r
.22699 .4614 .28474 .4889 .36781 .48537 .31506 .40772 Metetra
.542 .621 .881 r
.31506 .40772 .36781 .48537 .45591 .43264 .40286 .40202 Metetra
.632 .853 .984 r
.40286 .40202 .45591 .43264 .54573 .40312 .49533 .3708 Metetra
.76 .88 .933 r
.49533 .3708 .54573 .40312 .63946 .39729 .59052 .31347 Metetra
.722 .697 .826 r
.59052 .31347 .63946 .39729 .73793 .39116 .68752 .25506 Metetra
.564 .526 .77 r
.68752 .25506 .73793 .39116 .83645 .33341 .79067 .24499 Metetra
.746 .771 .873 r
.07885 .46158 .14048 .51413 .22699 .4614 .16749 .40673 Metetra
.746 .771 .873 r
.16749 .40673 .22699 .4614 .31506 .40772 .25777 .35086 Metetra
.508 .696 .954 r
.25777 .35086 .31506 .40772 .40286 .40202 .34695 .34353 Metetra
.655 .753 .922 r
.34695 .34353 .40286 .40202 .49533 .3708 .44146 .31025 Metetra
.747 .779 .879 r
.44146 .31025 .49533 .3708 .59052 .31347 .53927 .25043 Metetra
.747 .779 .879 r
.53927 .25043 .59052 .31347 .68752 .25506 .63901 .18944 Metetra
.536 .693 .94 r
.63901 .18944 .68752 .25506 .79067 .24499 .74439 .17725 Metetra
.886 .975 .83 r
.00095 .48363 .07885 .46158 .16749 .40673 .1008 .3739 Metetra
.867 .841 .818 r
.1008 .3739 .16749 .40673 .25777 .35086 .19938 .26558 Metetra
.139 .4 .849 r
.19938 .26558 .25777 .35086 .34695 .34353 .28535 .30687 Metetra
.637 .85 .981 r
.28535 .30687 .34695 .34353 .44146 .31025 .38274 .27149 Metetra
.879 .868 .824 r
.38274 .27149 .44146 .31025 .53927 .25043 .48485 .15788 Metetra
.815 .729 .769 r
.48485 .15788 .53927 .25043 .63901 .18944 .58558 .0458 Metetra
.391 .422 .773 r
.58558 .0458 .63901 .18944 .74439 .17725 .69334 .07922 Metetra
0 g
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.12091 .22234 m
.12558 .22696 L
s
[(2)] .11158 .21312 1 .98897 Mshowa
.2971 .15335 m
.30147 .15825 L
s
[(4)] .28836 .14356 .89202 1 Mshowa
.4859 .07942 m
.48992 .08461 L
s
[(6)] .47788 .06904 .77288 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(8)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.16384 .20553 m
.1666 .20834 L
s
.20751 .18843 m
.21022 .19129 L
s
.25192 .17104 m
.25459 .17394 L
s
.34306 .13535 m
.34564 .13834 L
s
.38984 .11704 m
.39236 .12006 L
s
.43745 .0984 m
.43991 .10147 L
s
.53524 .06011 m
.53759 .06327 L
s
.58547 .04044 m
.58776 .04364 L
s
.63663 .0204 m
.63885 .02365 L
s
.07869 .23888 m
.08153 .2416 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.423961 0.97619 0.791823 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.120192 0.0192308 0.120192 [
[.01923 -0.0125 -3 -9 ]
[.01923 -0.0125 3 0 ]
[.25962 -0.0125 -3 -9 ]
[.25962 -0.0125 3 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.74038 -0.0125 -3 -9 ]
[.74038 -0.0125 3 0 ]
[.98077 -0.0125 -3 -9 ]
[.98077 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01923 -6 -4.5 ]
[-0.0125 .01923 0 4.5 ]
[-0.0125 .25962 -6 -4.5 ]
[-0.0125 .25962 0 4.5 ]
[-0.0125 .5 -6 -4.5 ]
[-0.0125 .5 0 4.5 ]
[-0.0125 .74038 -6 -4.5 ]
[-0.0125 .74038 0 4.5 ]
[-0.0125 .98077 -6 -4.5 ]
[-0.0125 .98077 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.01923 0 m
.01923 .00625 L
s
[(0)] .01923 -0.0125 0 1 Mshowa
.25962 0 m
.25962 .00625 L
s
[(2)] .25962 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(4)] .5 -0.0125 0 1 Mshowa
.74038 0 m
.74038 .00625 L
s
[(6)] .74038 -0.0125 0 1 Mshowa
.98077 0 m
.98077 .00625 L
s
[(8)] .98077 -0.0125 0 1 Mshowa
.125 Mabswid
.07933 0 m
.07933 .00375 L
s
.13942 0 m
.13942 .00375 L
s
.19952 0 m
.19952 .00375 L
s
.31971 0 m
.31971 .00375 L
s
.37981 0 m
.37981 .00375 L
s
.4399 0 m
.4399 .00375 L
s
.5601 0 m
.5601 .00375 L
s
.62019 0 m
.62019 .00375 L
s
.68029 0 m
.68029 .00375 L
s
.80048 0 m
.80048 .00375 L
s
.86058 0 m
.86058 .00375 L
s
.92067 0 m
.92067 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01923 m
.00625 .01923 L
s
[(0)] -0.0125 .01923 1 0 Mshowa
0 .25962 m
.00625 .25962 L
s
[(2)] -0.0125 .25962 1 0 Mshowa
0 .5 m
.00625 .5 L
s
[(4)] -0.0125 .5 1 0 Mshowa
0 .74038 m
.00625 .74038 L
s
[(6)] -0.0125 .74038 1 0 Mshowa
0 .98077 m
.00625 .98077 L
s
[(8)] -0.0125 .98077 1 0 Mshowa
.125 Mabswid
0 .07933 m
.00375 .07933 L
s
0 .13942 m
.00375 .13942 L
s
0 .19952 m
.00375 .19952 L
s
0 .31971 m
.00375 .31971 L
s
0 .37981 m
.00375 .37981 L
s
0 .4399 m
.00375 .4399 L
s
0 .5601 m
.00375 .5601 L
s
0 .62019 m
.00375 .62019 L
s
0 .68029 m
.00375 .68029 L
s
0 .80048 m
.00375 .80048 L
s
0 .86058 m
.00375 .86058 L
s
0 .92067 m
.00375 .92067 L
s
.25 Mabswid
0 0 m
0 1 L
s
.01923 .99375 m
.01923 1 L
s
.25962 .99375 m
.25962 1 L
s
.5 .99375 m
.5 1 L
s
.74038 .99375 m
.74038 1 L
s
.98077 .99375 m
.98077 1 L
s
.125 Mabswid
.07933 .99625 m
.07933 1 L
s
.13942 .99625 m
.13942 1 L
s
.19952 .99625 m
.19952 1 L
s
.31971 .99625 m
.31971 1 L
s
.37981 .99625 m
.37981 1 L
s
.4399 .99625 m
.4399 1 L
s
.5601 .99625 m
.5601 1 L
s
.62019 .99625 m
.62019 1 L
s
.68029 .99625 m
.68029 1 L
s
.80048 .99625 m
.80048 1 L
s
.86058 .99625 m
.86058 1 L
s
.92067 .99625 m
.92067 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .01923 m
1 .01923 L
s
.99375 .25962 m
1 .25962 L
s
.99375 .5 m
1 .5 L
s
.99375 .74038 m
1 .74038 L
s
.99375 .98077 m
1 .98077 L
s
.125 Mabswid
.99625 .07933 m
1 .07933 L
s
.99625 .13942 m
1 .13942 L
s
.99625 .19952 m
1 .19952 L
s
.99625 .31971 m
1 .31971 L
s
.99625 .37981 m
1 .37981 L
s
.99625 .4399 m
1 .4399 L
s
.99625 .5601 m
1 .5601 L
s
.99625 .62019 m
1 .62019 L
s
.99625 .68029 m
1 .68029 L
s
.99625 .80048 m
1 .80048 L
s
.99625 .86058 m
1 .86058 L
s
.99625 .92067 m
1 .92067 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFAA55AAAA550055
AA8E718E8E715571
AA8E718E8E715571
55718E71718EAA8E
FFAA55AAAA550055
AA8E718E8E715571
AA8E718E8E715571
55718E71718EAA8E
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 233.563},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000jA000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00[7oo00<007ooOol04goo0`0057oo0`00
4Woo0P005Woo00<007ooOol05goo002[Ool00`00Ool0000DOol00`00Oomoo`0EOol00`00Oomoo`0A
Ool00`00Ool0000DOol00`00Ool0000HOol00:]oo`03001oo`0001Eoo`03001oogoo019oo`@0019o
o`03001oo`0001Aoo`03001oo`0001Qoo`00Zgoo00<007oo00005Goo00<007ooOol04Woo00<007oo
00004goo0P005Woo00<007ooOol05goo002[Ool00`00Ool0000DOol00`00Ool0000DOol2000COol0
0`00Oomoo`0DOol00`00Ool0000HOol00:aoo`03001oogoo01Aoo`03001oogoo01Aoo`03001oogoo
019oo`8001Eoo`03001oogoo01Moo`00ogoo8Goo001ROol00`00Oomoo`2kOol0065oo`03001oo`00
0;aoo`00HGoo00<007oo0000@goo00<007ooOol0MWoo001ROol00`00Oomoo`11Ool00`00Ool00002
OomN000GOol0065oo`03001oo`00049oo`03001oo`00009oo`8005Yoo`8001Moo`00HWoo00<007oo
Ool0@Goo00<007oo00000Woo00<007oo00005@008Woo8@000Woo00<007ooOol05Goo002VOol00`00
Ool00002Ool00`00Ool0000E000ROolQ0002Ool00`00Oomoo`0EOol00:Moo`06001oogooOol007oo
5P008Woo8@000Woo00<007ooOol05Goo001<Ool2001MOol00`00Ool0000E000ROolQ0002Ool00`00
Oomoo`0EOol004aoo`03001oo`0001Eoo`8004Eoo`03001oo`0001D0029oob40009oo`03001oogoo
01Eoo`00C7oo00<007oo00004goo1@00A7oo60008Woo8@0000=oo`0000005goo001<Ool2000AOol5
00000e;l00000014Ool00`00Ool0000E000ROolQ0002Ool00`00Oomoo`0EOol004aoo`03001oogoo
00eoo`D000ABo0<000Aoo`<003aoo`03001oo`0001D0029oob40009oo`03001oogoo01Eoo`00CGoo
0P002goo1@001U;l00@005;l000000=oo`03001oogoo03aoo`03001oo`0001D0029oob40009oo`03
001oogoo01Eoo`00Egoo1@002E;l00@005;lD_`000Aoo`03001oogoo03]oo`03001oo`0001D0029o
ob40009oo`03001oogoo01Eoo`00EGoo10000U;l00<005;lD_`01e;l00D005;lD_aBo00000=oo`03
001oogoo03]oo`03001oo`0001D0029oob40009oo`03001oogoo01Eoo`00>Goo0`005Woo1@0015;l
00<005;lD_`01e;l00D005;lD_aBo000009oo`03001oo`0003aooaP0029oob400003Ool0000001Mo
o`00>Woo00<007ooOol04goo100025;l00<005;lD_`01U;l00@005;lD_aBo080009oo`03001oogoo
03]oo`03001oo`0001D0029oob40009oo`03001oogoo01Eoo`00>7oo10004Goo1@002e;l00<005;l
D_`01E;l10000U;l00<007ooOol0?Goo00<007oo00005@008Woo8@000Woo00<007ooOol05Goo000h
Ool00`00Ool0000?Ool30003Ool2000<D_`00`00D_aBo003D_`20005D_`00`00Oomoo`0mOol00`00
Ool0000E000ROolQ0002Ool00`00Oomoo`0EOol003Uoo`8000eoo`8000Eoo`03001g500000aBo003
001Bo5;l00<00003D_`005;l00EBo003001oogoo03aoo`03001oo`0001D0029oob40009oo`03001o
ogoo01Eoo`00>Woo00<007ooOol027oo0`001goo00@007LDMa@000]Bo0<000ABo003001Bo5;l00AB
o08003eooaP0029oob400003Ool0000001Moo`00@goo0P002Goo00<007LDMa@00WLD00<005;lD_`0
1U;l0P000U;l00<005;lD_`00e;l00<005;lD_`015;l00<007ooOol0>goo00<007oo00005@008Woo
8@000Woo00<007ooOol05Goo000VOol3000GOol3000;Ool00`00MaAg5003Ma@00`00D_aBo002D_`3
0004D_`00`00D_aBo003D_`00`00D_aBo004D_`2000lOol00`00Ool0000E000ROolQ0002Ool00`00
Oomoo`0EOol002Ioo`03001oogoo01Eoo`8000ioo`03001g57LD00=g5003001Bo5;l008000QBo003
001Bo5;l009Bo003001Bo5;l00ABo0<003]oo`03001oo`0001D0029oob40009oo`03001oogoo01Eo
o`009goo00<007ooOol04Goo0`003goo00<007LDMa@01GLD0P002e;l00D005;lD_aBo00000ABo080
009Bo003001oogoo03Aoo`<0009oo`03001oo`0001D0029oob40009oo`03001oogoo01Eoo`009goo
00<007ooOol03Woo0`004Woo00<007LDMa@01GLD0P0035;l00D005;lD_`005;l00<000ABo08000Eo
o`<002eoo`03001oogoo009oo`03001oo`0001D0029oob40009oo`03001oogoo01Eoo`009Woo00<0
07oo00003Goo0P0000=oo`00Ool04Goo00<007LDMa@01GLD00@007LDMa@000]Bo003001Bo5;l0080
00QBo003001oogoo00Aoo`03001oogoo02eoo`04001oogooOolH000ROolQ00000goo0000000GOol0
02Moo`03001oogoo00Uoo`<001Ioo`03001g57LD00Eg5005001g57LDMa@0000:D_`40009D_`20003
Ool4000^Ool01P00Oomoogoo001ooaH0029oob40009oo`03001oogoo01Eoo`00<Goo0P0000=oo`00
Ool05Woo00<007LDMa@017LD00<007LDMa@00WLD00<005;lD_`01E;l0`000U;l0P002U;l0P000Woo
00<007oo0000;Woo00<007oo00000Woo00<007oo00005@008Woo8@000Woo00<007ooOol05Goo000^
Ool3000JOol00`00MaAg5005Ma@00`00MaAg5003Ma@00`00D_aBo0040006D_`00`00D_aBo008D_`2
0003Ool2000_Ool01P00Oomoogoo001ooaH0029oob40009oo`03001oogoo01Eoo`00;7oo0P007Goo
00<007LDMa@01GLD00<007LDMa@017LD0P002U;l0P002E;l0`000goo00<007ooOol0<Goo00<007oo
00005@008Woo8@000Woo00<007ooOol05Goo000YOol3000NOol00`00MaAg5005Ma@00`00MaAg5005
Ma@2000:D_`20006D_`30002D_`2000fOolH000ROolQ00000goo0000000GOol002Ioo`@00003D_`0
000001eoo`03001g57LD00Eg5003001g57LD00Ag50@000UBo003001Bo000009Bo0<000IBo003001o
ogoo03Aoo`03001oo`0001D0029oob40009oo`03001oogoo01Eoo`0097oo100015;l0P006goo00<0
07LDMa@01WLD00<007LDMa@017LD1@001e;l0P0000ABo000000000YBo003001oogoo03=oo`03001o
o`0001D0029oob40009oo`03001oogoo01Eoo`008Woo10001U;l00<0077S00006Woo00<007LDMa@0
1GLD00<007LDMa@01GLD1@0015;l1P000U;l00<005;lD_`025;l0P00=7oo00<007oo00005@008Woo
8@000Woo00<007ooOol05Goo000NOol01000Oomoogoo0P0025;l00@0077SLN<001Uoo`03001g57LD
00Eg5003001g57LD00Ag50d0009Bo004001Bo5;l000;D_`00`00Oomoo`0bOol00`00Ool0000E000R
OolQ0002Ool00`00Oomoo`0EOol001eoo`03001oo`00009oo`<000QBo004001ahg7S000GOol00`00
MaAg5005Ma@00`00MaAg5005Ma@90007D_`01000D_aBo0002U;l0P00<goo00<007oo00005@008Woo
8@000Woo00<007ooOol05Goo000MOol00`00Ool00002Ool01000Oomoo`001e;l00D0077SLN=ah`00
01Ioo`03001g57LD00Eg5003001g57LD00Eg50H0009Bo003001Bo5;l00IBo004001Bo5;l0006D_`3
00000e;l00000004Ool2000/OomK00000goo0000000GOol001eoo`04001oo`00Ool20003Ool00`00
D_aBo004D_`01000LN=ahg7S0P0057oo00<007LDMa@01WLD00<007LDMa@017LD10001U;l00<005;l
D_`01U;l00<005;l00000U;l10001E;l00<007ooOol00Woo00<007oo0000:goo00<007oo0000F000
0Woo00<007ooOol05Goo000MOol01000Ool007oo0P0017oo0P000U;l0`00177S0P004goo00<007LD
Ma@01GLD00<007LDMa@00WLD10002U;l00<005;lD_`01E;l00<005;l00000P002U;l00L007ooOomo
o`00Ool0000[Ool00`00Ool0001H0002Ool00`00Oomoo`0EOol001ioo`03001oogoo008000Eoo`<0
00=Bo007001ahg7SLN<0077S00004Woo00<007LDMa@01GLD00<007LD00000P000gLD00<005;lD_`0
25;l00<005;lD_`015;l0`000U;l00<005;lD_`025;l00@007ooOomoo`8002aoo`03001oo`0005P0
009oo`03001oogoo01Eoo`003Woo00<007ooOol00Woo00@007ooOomoo`<000=oo`04001oogooOol2
0007Ool01@00D_aBo5;l00000g7S00@0077SLN<0011oo`03001g57LD00Eg50<000Eg5003001Bo000
00YBo003001Bo5;l00<000=Bo003001Bo00000]Bo004001oogoo000]Ool00`00Ool0001H0002Ool0
0`00Oomoo`0EOol000eoo`03001oo`0000Moo`03001oogoo009oo`03001oo`00009oo`8000Qoo`04
001Bo5;l0004LN<01000LN=ah`003goo00<007LDMa@00gLD0`001gLD00@005;lD_`000UBo0<000IB
o004001Bo5;l0009D_`30002Ool2000[OomK00000goo0000000GOol000eoo`03001oo`0000Qoo`03
001oogoo00=oo`04001oogoo000:Ool01000D_aBo0000g7S00D0077SLN=ah`0000eoo`04001g57LD
Ma@30002Ma@00`00MaAg5004Ma@01@00D_aBo5;l00001U;l0`000U;l00<005;lD_`01E;l00@005;l
D_`000EBo0<0009Bo003001oogoo02eoo`03001oo`0005P0009oo`03001oogoo01Eoo`003Goo00<0
07oo000027oo00@007ooOomoo`8000=oo`03001oogoo00Uoo`03001Bo00000=ah`04001ahg7SLN<2
000;Ool50004Ma@00`00MaAg5005Ma@00`00D_aBo002D_`00`00D_aBo0030006D_`00`00D_aBo005
D_`00`00D_`00002D_`30006D_`00`00Oomoo`0/Ool00`00Ool0001H0002Ool00`00Oomoo`0EOol0
00eoo`03001oo`0000Moo`03001oo`00009oo`03001oogoo009oo`03001oogoo00Yoo`8000Aah`04
001ahg7SLN<20007Ool60006Ma@00`00MaAg5005Ma@00`00D_aBo002D_`30009D_`00`00D_aBo006
D_`40009D_`2000]Ool00`00Ool0001H0002Ool00`00Oomoo`0EOol000ioo`05001oogooOol00004
Ool20003Ool300000goo0000000=Ool20003LN<01`00LN=ahg7S001ah`00009oo`H000AC7@03001g
57LD00=g5003001g57LD00Ag5003001Bo5;l00<0009Bo003001Bo5;l00QBo004001Bo5;lD_`50002
D_`00`00D_aBo008D_`00`00Oomoo`0WOol300000goo001oo`1I0002Ool00`00Oomoo`0EOol0015o
o`03001oo`0000Moo`03001oo`00009oo`03001oogoo00eoo`03001ahg7S009ah`05001ahg7S001a
h`060008Dad01@00MaAg57LD00001gLD0`001U;l00<005;lD_`01e;l10001E;l00@005;lD_`000UB
o08002Uoo`05001oogoo001oo`1I0002Ool00`00Oomoo`0EOol0015oo`03001oo`0000Uoo`03001o
ogoo008000ioo`03001ahg7S009ah`03001ahg7S00D000aC7@04001g57LD0007Ma@00`00D_aBo006
D_`00`00D_aBo004D_`30002D_`00`00D_aBo005D_`00`00D_`00006D_`300000e;l00000005Ool0
0`00Oomoo`0NOol400000goo0000001I00000goo0000000GOol0015oo`03001oo`0000Moo`8000=o
o`03001oogoo00eoo`03001ahg7S009ah`D000=C7@03001C7E<M00YC7@8000Mg5003001Bo5;l00QB
o003001Bo5;l00<000EBo003001Bo5;l00EBo004001Bo5;l0002D_`30005D_`20003Ool00`00Ool0
000OOol00`00Ool00002Ool00`00Ool0001H0002Ool00`00Oomoo`0EOol0015oo`03001oo`0000Mo
o`03001oogoo009oo`03001oogoo00ioo`03001ah`0000@000IC7@03001C7E<M00UC7@8000Mg5080
00UBo0<000UBo003001Bo5;l00EBo003001Bo000008000UBo007001oogooOol007oo000087oo0P00
0Woo00<007oo0000F0000Woo00<007ooOol05Goo000BOol00`00Oomoo`06Ool30002Ool00`00Oomo
o`0>Ool40009Dad00`00DaeC7@07Dad20002Dad00`00MaAg5004Ma@00`00D_`00006D_`20002D_`0
0`00D_aBo008D_`00`00D_aBo003D_`30002D_`00`00D_aBo007D_`00`00Oomoo`02Ool00`00Oomo
o`0POol01@00Oomoo`00Ool0F@000Woo00<007ooOol05Goo000<Ool00`00Oomoo`02Ool00`00Oomo
o`02Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`0<Ool4000<Dad00`00DaeC7@03Dad3
0005Dad00`00MaAg5002Ma@01@00D_aBo5;l00000U;l0`001E;l00<005;lD_`01e;l00<005;lD_`0
0`000e;l00<005;l00002E;l0P000Woo00<007oo000097oo00<007oo0000F0000Woo00<007ooOol0
5Goo000;Ool00`00Ool00008Ool01`00Oomoogoo001oo`0000=oo`03001oogoo00Uoo`<000Aoo`03
001C7E<M00YC7@03001C7E<M008000UC7@05001g57LDMa@00003D_`30008D_`00`00D_aBo006D_`4
0006D_`01000D_aBo0001E;l0`0000=oo`00Ool00Woo00<007ooOol08goo00<007oo0000F0000Woo
00<007ooOol05Goo000;Ool00`00Ool00008Ool00`00Oomoo`03Ool01000Oomoo`002Goo0`0027oo
0P002U<M0`0035<M00<007LDMa@010000U;l00<005;lD_`01e;l00@005;lD_aBo0@000=Bo003001B
o5;l00EBo003001Bo000009Bo0<000Aoo`03001oogoo02Mooe/00003Ool0000001Moo`002goo00<0
07oo00002Goo00<007ooOol00P000goo0P001Woo0P003Goo00<005<MDad015<M0`000U<M00<005<M
Dad02e<M0`001U;l00<005;lD_`01U;l100025;l00<005;lD_`01E;l10001goo00<007ooOol09goo
00<007oo0000F0000Woo00<007ooOol05Goo000;Ool00`00Ool00007Ool00`00Ool00002Ool00`00
Oomoo`02Ool00`00Oomoo`02Ool3000@Ool00`00DaeC7@030006Dad00`00DaeC7@0:Dad20007D_`0
0`00D_aBo004D_`20002D_`00`00D_aBo007D_`00`00D_aBo004D_`2000;Ool00`00Oomoo`0VOol0
0`00Ool0001H0002Ool00`00Oomoo`0EOol000aoo`03001oogoo00Ioo`<0009oo`<0009oo`03001o
o`00008001Aoo`8000YC7@8000MC7@<000YBo003001Bo5;l00<000EBo003001Bo5;l00MBo003001B
o5;l00<0009oo`03001oogoo00Qoo`03001oogoo02Ioo`03001oo`0005P0009oo`03001oogoo01Eo
o`0067oo1@000Woo0P0067oo00<005<MDad02U<M00<005<MDad010000e;l0P0025;l0`0025;l00<0
05;lD_`01U;l10001Woo00<007ooOol01goo00<007ooOol09Woo00<007oo0000F0000Woo00<007oo
Ool05Goo000JOol00`00Oomoo`03Ool00`00Oomoo`0GOol00`00DaeC7@09Dad30009D_`01000D_aB
o5;l10000U;l00<005;lD_`01e;l00@005;lD_aBo0@000]oo`03001oogoo00Ioo`03001oogoo02Io
oe/00003Ool0000001Moo`006Woo00<007ooOol017oo0P0067oo0P001U<M0`000U;l00<005;lD_`0
1e;l10001e;l00<005;lD_`01U;l10003goo00<007ooOol01Woo00<007ooOol09Woo00<007oo0000
F0000Woo00<007ooOol05Goo000JOol00`00Oomoo`06Ool00`00Oomoo`0GOol00`00DaeC7@030006
D_`00`00D_aBo004D_`20002D_`00`00D_aBo007D_`01000D_aBo5;l100057oo00<007ooOol01Goo
00<007ooOol09Woo00<007oo0000F0000Woo00<007ooOol05Goo000JOol00`00Oomoo`07Ool00`00
Oomoo`0GOol30009D_`00`00D_aBo0030005D_`00`00D_aBo006D_`4000IOol00`00Oomoo`04Ool0
0`00Oomoo`0VOol00`00Ool0001H0002Ool00`00Oomoo`0EOol001Uoo`8000Yoo`03001oogoo01Uo
o`03001Bo5;l00IBo0<000QBo003001Bo5;l00ABo08001eoo`03001oogoo00Aoo`03001oogoo02Io
o`03001oo`0005P0009oo`03001oogoo01Eoo`009Woo00<007ooOol06Goo00@005;lD_aBo0@0009B
o003001Bo5;l00MBo003001Bo5;l00<0021oo`03001oogoo00Aoo`03001oogoo02Eoo`03001oo`00
05P0009oo`03001oogoo01Eoo`009goo0P006Woo0`001e;l00<005;lD_`01U;l0`0097oo00<007oo
Ool00goo00<007ooOol09GooF`0000=oo`0000005goo000YOol00`00Oomoo`0HOol00`00D_aBo007
D_`01000D_aBo5;l1000:7oo00<007ooOol00Woo00<007ooOol09Goo00<007oo0000F0000Woo00<0
07ooOol05Goo000ZOol00`00Oomoo`0HOol20007D_`4000/Ool00`00Oomoo`02Ool00`00Oomoo`0U
Ool00`00Ool0001H0002Ool00`00Oomoo`0EOol002]oo`03001oogoo01Uoo`03001Bo5;l00@0035o
o`05001oogooOol0000ROol20003Ool00`00Ool0001H0002Ool00`00Oomoo`0EOol002aoo`03001o
ogoo01Uoo`8003Ioo`04001oogoo000ROol00`00Ool00002Ool00`00Ool0001H0002Ool00`00Oomo
o`0EOol002eoo`8001Uoo`03001oogoo03Eoo`04001oogoo000ROol00`00Ool00002OomK00000goo
0000000GOol002moo`03001oogoo01Ioo`03001oogoo03Ioo`03001oo`00029oo`8000=oo`03001o
o`0005P0009oo`03001oogoo01Eoo`00<7oo00<007ooOol05Goo00<007ooOol0=goo00<007oo0000
8Goo00<007ooOol00Woo00<007oo0000F0000Woo00<007ooOol05Goo000aOol00`00Oomoo`0DOol0
0`00Oomoo`0hOol2000ROol20002Ool00`00Ool0001H0002Ool00`00Oomoo`0EOol0039oo`03001o
ogoo01=oo`03001oogoo03Qoo`8002Ioo`03001oo`0005P0009oo`03001oogoo01Eoo`00<goo0P00
4goo00<007ooOol0>7oo0P009Woo00<007oo0000F0000Woo00<007ooOol05Goo000eOol00`00Oomo
o`0@Ool00`00Oomoo`0dOol4000XOomK00000goo0000000GOol003Ioo`03001oogoo00moo`03001o
ogoo031oo`@002aoo`03001oo`0005P0009oo`03001oogoo01Eoo`00=goo00<007ooOol03Woo00<0
07ooOol0;7oo1000<7oo00<007oo0000F0000Woo00<007ooOol05Goo000hOol2000>Ool00`00Oomo
o`0XOol4000dOol00`00Ool0001H0002Ool00`00Oomoo`0EOol003Yoo`03001oogoo00Yoo`03001o
ogoo02Ioo`<003Qoo`03001oo`0005P0009oo`03001oogoo01Eoo`00>goo00<007ooOol02Goo00<0
07ooOol08Woo1000>gooF`0000=oo`0000005goo000lOol00`00Oomoo`08Ool00`00Oomoo`0NOol4
000oOol00`00Ool0001H0002Ool00`00Oomoo`0EOol003eoo`03001oogoo00Moo`03001oogoo01Yo
o`@004=oo`03001oo`0005P0009oo`03001oogoo01Eoo`00?Woo0P001goo00<007ooOol05Woo1000
Agoo00<007oo0000F0000Woo00<007ooOol05Goo0010Ool00`00Oomoo`04Ool00`00Oomoo`0BOol4
001;Ool00`00Ool0001H0002Ool00`00Oomoo`0EOol0045oo`03001oogoo00=oo`03001oogoo00mo
o`<004moo`03001oo`0005P0009oo`03001oogoo01Eoo`00@Woo00<007ooOol00Woo00<007ooOol0
2goo1000DWooF`0000=oo`0000005goo0013Ool01@00Oomoogoo00002Goo1000EWoo00<007oo0000
F0000Woo00<007ooOol05Goo0014Ool200000goo001oo`04Ool4001JOol00`00Ool0001H0002Ool0
0`00Oomoo`0EOol004Ioo`800003Ool00000008005Yoo`06001oogooOol007ooF@000Woo00<007oo
Ool05Goo0017Ool2001MOol00`00Ool00002Ool00`00Ool0001H0002Ool00`00Oomoo`0EOol00:Io
o`03001oo`00009ooe/00003Ool0000001Moo`00Ygoo00D007ooOomoo`0005aoo`03001oogoo01Eo
o`00YWoo00<007oo00000WooGP005goo002WOol00`00Oomoo`1fOol00?moob5oo`00ogoo8Goo003o
OolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5o
o`00ogoo8Goo003oOolQOol00:aoo`03001oogoo01=oo`<001Aoo`<0019oo`8001Ioo`03001oogoo
01Moo`00Zgoo00<007oo000057oo00<007ooOol05Goo00<007ooOol04Goo00<007oo000057oo00<0
07oo000067oo002[Ool00`00Ool0000EOol00`00Oomoo`0BOol4000BOol00`00Ool0000DOol00`00
Ool0000HOol00:]oo`03001oo`0001Eoo`03001oogoo019oo`03001oo`0001=oo`8001Ioo`03001o
ogoo01Moo`00Zgoo00<007oo000057oo00<007oo000057oo0P004goo00<007ooOol057oo00<007oo
000067oo002/Ool00`00Oomoo`0DOol00`00Oomoo`0DOol00`00Oomoo`0BOol2000EOol00`00Oomo
o`0GOol0065oo`03001oogoo0;aoo`00H7oo00<007oo0000_Goo001POol00`00Ool0002mOol0065o
o`03001oogoo04=oo`03001oogoo07Ioo`00H7oo00<007oo0000@goo00<007oo00000WooGP005goo
001QOol00`00Oomoo`12Ool00`00Ool00002Ool2001JOol2000GOol00:Ioo`03001oo`00009oo`03
001oogoo00Yoo`]F]@/YBQMF]@/YBP/000/YBP9oo`03001oogoo01Eoo`00YWoo00<007oo00000Woo
00<007ooOol02Woo2eJe2bU:5eJe2bU:2`002bU:0Woo00<007ooOol05Goo001;Ool2001JOol01@00
Oomoogoo000037oo2eJe2bU:5eJe2bU:2`002bU:0Woo00<007ooOol05Goo001;Ool00`00Ool0000E
Ool20016Ool00`00Oomoo`0:Ool;E[D;:DXGE[D;:DX;000;:DX2Ool00`00Oomoo`0EOol004]oo`03
001oo`0001=oo`800003Ool0000004Eoo`03001oogoo00Yoo`]F]@/YBQMF]@/YBP/000/YBP9oo`03
001oogoo01Eoo`00Bgoo0P004Goo0`000goo0P00AGoo0P002goo2eJe2bU:5eJe2bU:2`002bU:00=o
o`0000005goo001;Ool00`00Oomoo`0>Ool200000goo001oo`03Ool00`00Ool00004Ool3000mOol0
0`00Oomoo`0:Ool;E[D;:DXGE[D;:DX;000;:DX2Ool00`00Oomoo`0EOol004aoo`8000]oo`<000Qo
o`04001oo`000003Ool00`00Oomoo`0mOol00`00Oomoo`0:Ool;E[D;:DXGE[D;:DX;000;:DX2Ool0
0`00Oomoo`0EOol005Moo`@000Uoo`04001oogoo0004Ool00`00Oomoo`0lOol00`00Oomoo`0:Ool;
E[D;:DXGE[D;:DX;000;:DX2Ool00`00Oomoo`0EOol005Aoo`<00004Ool00000<KP30006Ool01@00
Oomoogoo00000goo00<007ooOol0?7oo00<007ooOol02Woo2eJe2bU:5eJe2bU:2`002bU:0Woo00<0
07ooOol05Goo000hOol3000GOol400001Goo001Vn6Kh00000c6h0`0017oo00T007ooOomoo`00Ool0
07oo0000?Goo00<007ooOol02Woo2eJe2bU:5eJe2bU:2`002bU:0Woo00<007ooOol05Goo000iOol0
0`00Oomoo`0COol30004Ool01@00I_QVn6Kh00001S6h0`0000=oo`00Ool00Woo00@007ooOol003io
o`8000]F]@]6<@/icQM6<@/icP/YBP/icP03Ool0000001Moo`00=goo10004Woo10001Goo00<006Kh
I_P00VKh00<0036h<KP01S6h0P0017oo00<007ooOol0?Woo00<007ooE[D02UJe2dHa2cW>5dHa2cW>
2bU:2cW>0Woo00<007ooOol05Goo000gOol00`00Ool0000@Ool30008Ool00`00I_QVn003I_P00`00
<KPa^007<KP20003Ool00`00Oomoo`0nOol00`00OomF]@0:E[D;AS4;>LhGAS4;>Lh;:DX;>Lh2Ool0
0`00Oomoo`0EOol003Qoo`8000ioo`<000Uoo`03001Vn6Kh00AVn003000a^36h00La^08000Aoo`03
001oogoo03eoo`03001ooeJe00YF]@]6<@/icQM6<@/icP/YBP/icP9oo`03001oogoo01Eoo`00>Goo
00<007ooOol02Goo0`002goo00<006KhI_P01VKh00<0036h<KP01S6h00<0036h00000goo0P00?Woo
00<007ooE[D02UJe2dHa2cW>5dHa2cW>2bU:2cW>0Woo00<007ooOol05Goo0013Ool200000goo001o
o`0:Ool00`00I_QVn007I_P00`00<KPa^006<KP00`00<KP00004Ool00`00Oomoo`0lOol2000;E[D;
AS4;>LhGAS4;>Lh;:DX;>Lh00goo0000000GOol0041oo`<000ioo`03001Vn6Kh00UVn003000a^36h
00Da^004000a^36h0004Ool00`00Oomoo`0kOol00`00OomF]@0:E[D;AS4;>LhGAS4;>Lh;:DX;>Lh2
Ool00`00Oomoo`0EOol002Aoo`<001Moo`@000moo`03001Vn6Kh00UVn003000a^36h00Da^004000a
^36h0004Ool2000lOol00`00OomF]@0:E[D;AS4;>LhGAS4;>Lh;:DX;>Lh2Ool00`00Oomoo`0EOol0
02Aoo`03001oogoo01Eoo`80019oo`03001Vn6Kh00YVn003000a^36h00Da^005000a^36h<KP00004
Ool00`00Oomoo`0jOol00`00OomF]@0:E[D;AS4;>LhGAS4;>Lh;:DX;>Lh2Ool00`00Oomoo`0EOol0
02Eoo`03001oogoo015oo`@0019oo`03001Vn6Kh00aVn003000a^36h00@a^005000a^36h<KP00005
Ool00`00Oomoo`03Ool3000^Ool30002Ool00`00OomF]@0:E[D;AS4;>LhGAS4;>Lh;:DX;>Lh2Ool0
0`00Oomoo`0EOol002Eoo`03001oogoo00moo`8001Eoo`03001_N@0000eVn003000a^36h00@a^003
000a^36h008a^003001oogoo00=oo`03001oogoo00=oo`03001oogoo02eoo`03001oogoo009oo`03
001ooeJe00YF]@]6<@/icQM6<@/icP/YBP/icP9oo`03001oogoo01Eoo`0097oo00<007oo00003Goo
0`005Woo00@006miKgT000iVn003000a^36h00<a^0H000Eoo`04001oogooOol4000_Ool01000Oomo
ogoo0P002eJe2dHa2cW>5dHa2cW>2bU:2cW>00=oo`0000005goo000UOol00`00Oomoo`0:Ool2000H
Ool00`00KgU_N@02KgT00`00I_QVn00;I_P600000d:m0012_@03@[d00`00Oomoo`03Ool01P00Oomo
o`00Ool0031oo`06001oogooOol007oo2eJe2dHa2cW>5dHa2cW>2bU:2cW>0Woo00<007ooOol05Goo
000_Ool3000IOol00`00KgU_N@04KgT00`00I_QVn008I_P200000elK0012_@04@[d00`00@[e2_@02
@[d00`00Oomoo`04Ool00`00Oomoo`02000_Ool00`00Ool00002Ool00`00OomF]@0:E[D;AS4;>LhG
AS4;>Lh;:DX;>Lh2Ool00`00Oomoo`0EOol002eoo`8001]oo`03001_NFmi00E_N@03001Vn6Kh00IV
n08000=O6`030012_D:m00=2_@030012_D:m00=2_@03001oogoo00=oo`05001oogooOol0000`Ool0
1P00Oomoogoo001oo`]F]@]6<@/icQM6<@/icP/YBP/icP9oo`03001oogoo01Eoo`00:Goo10007Goo
00<006miKgT01Vmi00<006KhI_P016Kh00<005lKGa/015lK00<004:m@[d00T:m00<004:m@[d014:m
00<007ooOol00goo00<007ooOol0=Goo00<007ooE[D02UJe2dHa2cW>5dHa2cW>2bU:2cW>0Woo00<0
07ooOol05Goo000XOol3000NOol00`00KgU_N@08KgT01000I_QVn6Kh0P0025lK00D004:m@[e2_@00
00M2_@03001oogoo009oo`03001oogoo03Eoo`8000]F]@]6<@/icQM6<@/icP/YBP/icP03Ool00000
01Moo`009Goo0`0087oo00<006miKgT02Fmi00@006Kh000000]O6`040012_D:m0007@[d00`00Oomo
o`03Ool00`00Oomoo`0dOol00`00OomF]@0:E[D;AS4;>LhGAS4;>Lh;:DX;>Lh2Ool00`00Oomoo`0E
Ool002=oo`80029oo`03001_NFmi00]_N@03001O6elK00]O6`040012_@000003@[d60005Ool00`00
Oomoo`0cOol00`00OomF]@0:E[D;AS4;>LhGAS4;>Lh;:DX;>Lh2Ool00`00Oomoo`0EOol0025oo`80
02=oo`03001_NFmi00Y_N@800003Ga/005lK00YO6`P000E66003001oogoo00=oo`03001oogoo03=o
o`03001ooeJe00YF]@]6<@/icQM6<@/icP/YBP/icP9oo`03001oogoo01Eoo`0087oo0`003goo00<0
07ooOol03goo0P002fmi0P000elK00<005lKGa/01UlK1P000THH00<004HHAQP01THH00<007ooOol0
0goo00<007ooOol0<Woo00<007ooE[D02UJe2dHa2cW>5dHa2cW>2bU:2cW>0Woo00<007ooOol05Goo
000JOol500001Goo000007oo00003Goo00@006mI000000aoo`<0009?GP8000Q_N@03001O6elK00AO
6`03001O6elK009O6`<00003Ga/0000000=Jf@04001664HH0007AQP00`00Oomoo`04Ool00`00Oomo
o`0aOol00`00OomF]@0:E[D;AS4;>LhGAS4;>Lh;:DX;>Lh2Ool00`00Oomoo`0EOol001aoo`04001o
ogooOol20002Ool00`00Oomoo`09Ool01@00KeU_F@003IX00P0027oo0P001dmN00<006miKgT00fmi
0P0025lK10000elK00<005[IF]T00e[I00D004HHAQQ6600000M66003001oogoo00=oo`03001oogoo
009oo`8002eoo`8000/YBP/icP]6<ALicP]6<@]F]@]6<@03Ool0000001Moo`005Woo0`000goo00D0
07ooOomoo`0000Aoo`03001oogoo00Moo`03001_FFmI009_F@03000=VPfJ008000=oo`<000Y?GP80
0003KgT0000000QO6`@000=O6`8000IJf@03001664HH00966003001664HH00A66003001oogoo00Ao
o`07001oogooOol007oo0000;7oo00<007oo:DX02RU:2cW>2dHa5cW>2dHa2eJe2dHa0Woo00<007oo
Ool05Goo000LOol01@00Oomoogoo00001Goo00<007ooOol01Goo00<006mIKeT016mI00@000fJ3IX=
VP<000i?GP8000QO6`8000=O6`04001O6`000009F]T01@00AQQ664HH00001dHH00<007ooOol017oo
00H007ooOol007oo000/Ool00`00OolYBP0::DX;>Lh;AS4G>Lh;AS4;E[D;AS42Ool00`00Oomoo`0E
Ool001aoo`05001oogooOol00006Ool20004Ool00`00KeU_F@05KeT00`003IX=VP033IX2000;Ceh2
0002D_d00`00Ga]O6`02Ga/30006Ga/00`00F]UJf@09F]T00`00AQQ66002AQP00`00AQQ66004AQP0
0`00Oomoo`04Ool00`00Oomoo`02000]Ool00`00OolYBP0::DX;>Lh;AS4G>Lh;AS4;E[D;AS42Ool0
0`00Oomoo`0EOol0015oo`03001oogoo009oo`03001oogoo009oo`8000=oo`03001oogoo00Ioo`04
001oogoo0009KeT00`003IX=VP043IX20006Ceh30004D_d00`00Ga/000020007Ga/200000emm001J
f@0:F]T00`00AQQ66002AQP00`00AQQ66004AQP00`00Oomoo`03Ool200000goo001oo`0]Ool00`00
OolYBP0::DX;>Lh;AS4G>Lh;AS4;E[D;AS42Ool00`00Oomoo`0EOol0011oo`03001oo`0000Moo`03
001oo`00009oo`8000Uoo`8000]_F@03000=VPfJ00D=VP80009?GP8000IBo@<000QO6`8000=OO@03
001JfE[I00UJf@03001664HH00966003001664HH00A660<000Eoo`04001oo`00000/Ool2000;:DX;
>Lh;AS4G>Lh;AS4;E[D;AS400goo0000000GOol000]oo`<0009oo`03001oo`0000Uoo`03001oogoo
008000Uoo`03001_FFmI00Y_F@03000=VPfJ00<=VPH000EBo@<000=Bo@03001O6elK00AO6`03001O
OEmm00AOO@03001JfE[I00QJf@03001664HH00=66004001664HHAQP20002=MP30003Ool00`00Oomo
o`0]Ool00`00OolYBP0::DX;>Lh;AS4G>Lh;AS4;E[D;AS42Ool00`00Oomoo`0EOol0011oo`03001o
o`0000Moo`8000=oo`03001oogoo00Moo`03001_FFmI00a_F@D000DngP03001BoE;m00<000MBo@04
001O6elKGa/20008Ggd00`00F]UJf@08F]T00`00AQQ66003AQP30007=MP01@00Oomoogoo0000;Woo
00<007oo:DX02RU:2cW>2dHa5cW>2dHa2eJe2dHa0Woo00<007ooOol05Goo000@Ool00`00Ool00007
Ool00`00Oomoo`02Ool20007Ool00`00KeU_F@0;KeT200000elK000ngP07?]h3000:D_d01000Ga/0
00002Umm00<005[IF]T025[I00<004HHAQP00dHH0P0023GH00D007ooOomoo`0002ioo`03001oobU:
00XYBP/icP]6<ALicP]6<@]F]@]6<@9oo`03001oogoo01Eoo`004Goo00<007ooOol01Woo0`000Woo
00<007ooOol01Goo0P002fmI0P0015lK00<003kN?]h00SkN0`000SkN00<005;mD_d025;m0P003Emm
00<005[IF]T01e[I00@004HHAQQ660800003I]P003GH00Pef005001oogooOol0000YOol300000goo
001oo`0;:DX;>Lh;AS4G>Lh;AS4;E[D;AS42Ool00`00Oomoo`0EOol001Yoo`03001oo`00009oo`03
001oogoo00Aoo`03001_fVoJ008000M_F@8000MO6`@000HngP03001BoE;m00ABo@<0009?OP8000]O
O@03001JfE[I00QJf@<000=Vf08000Pef004001oogooOol2000YOol01@00Oomoo`00Ool02bU:2cW>
2dHa5cW>2dHa2eJe2dHa0Woo00<007ooOol05Goo000JOol00`00Ool00002Ool00`00Oomoo`03Ool0
0`00KmY_fP03KmX20003KeT20007Ga/40009?]h00`00D_eBo@030007Cgh20006Ggd?0006I]P20008
=MP01@00Oomoogoo00001Woo00<007ooOol07Woo100000=oo`0000002bU:2cW>2dHa5cW>2dHa2eJe
2dHa00=oo`0000005goo000JOol01000Ool007oo0P0017oo00<006oJKmX01VoJ0`001UlK0`0015lK
00<003kN?]h00ckN1P002dmn1`001dHi0`002fKH0P0023GH00<007ooOol00Woo0P000goo00<007oo
00007goo00<007oo00000Woo00<007ooOol02Woo2eJe2bU:5eJe2bU:2`002bU:0Woo00<007ooOol0
5Goo000JOol01000Ool007oo0P000goo00<006oJKmX01VoJ0P0000=O6`00Ga/00UlK0`0025lK1@00
1D9k0P001dmn0`0000=>N@00AST034Hi00<006mi00002VKH00<003GH000023GH00<007ooOol00Woo
00L007ooOomoo`00Ool0000POol20002Ool00`00Oomoo`0:Ool;E[D;:DXGE[D;:DX;000;:DX2Ool0
0`00Oomoo`0EOol0011oo`03001oogoo009oo`03001oogoo009oo`80009oo`05001oogooOol00008
KmX00`00Ga]O6`02Ga/30009Ga/200000emm0012N`09@W/20002Cgh30005CWT00`00ASU6>@09AST0
1000KgU_N@002fKH00<003GH00000cGH1@0017oo00<007ooOol00Woo00<007ooOol087oo00@007oo
Ool000aoo`]F]@/YBQMF]@/YBP/000/YBP9oo`03001oogoo01Eoo`003goo00<007oo00001goo00<0
07oo00000Woo00D007ooOomoo`0000I_fP8000=O6`800003Ga/005lK00MO6`8000=OO@030012Nd9k
00Y2N`8000Q>N@030016>DHi00Q6>@03001_NFmi009_N@03001Vf6KH00QVf0H000E2_@04001oogoo
Ool20002Ool00`00Ool0000TOol00`00Oomoo`0:Ool;E[D;:DXGE[D;:DX;000;:DX2Ool00`00Oomo
o`0EOol000moo`03001oo`0000Uoo`04001oogoo0002Ool00`00KmY_fP04KmX00`00Ga]O6`030004
Ga/00`00Ga]O6`03Ga/20006Ggd00`00@W]2N`07@W/3000:CWT00`00ASU6>@06AST00`00KgU_N@03
KgT00`00I]QVf006I]P2000015lK0012_@001d:m100000=oo`00Ool00Woo00<007ooOol08goo00<0
07ooOol02Woo2eJe2bU:5eJe2bU:2`002bU:0Woo00<007ooOol05Goo000?Ool00`00Ool00007Ool2
0003Ool00`00Ool00005KmX50008Ga/00`00Ga]O6`020009Ggd00`00@W]2N`05@W/01@00FmeKgE_M
00002Dii00<004HiAST01DHi00<006miKgT01Fmi00<006KHI]P00fKH0P0015lK00<004:m00001d:m
00D007ooOomoo`0002Uoo`8000]oo`]F]@/YBQMF]@/YBP/000/YBP03Ool0000001Moo`003goo00<0
07oo00001goo00@007ooOomoo`<000A_fP@000aO6`8000]OO@030012Nd9k00=2N`8000AKg@03001>
NDii00Q>N@030016>DHi00A6>@03001_NFmi00E_N@04001Vf6KHI]P20006Ga/01000@[e2_@001d:m
00@007ooOol002Uoo`03001oogoo00Yoo`]F]@/YBQMF]@/YBP/000/YBP9oo`03001oogoo01Eoo`00
47oo00<007ooOol01Woo0`0000Aoo`00001_fPD00003Ool005lK00YO6`800003BkT0000000]OO@05
0012Nd9k@W/00007Fmd00`00CWU>N@07CWT00`00ASU6>@03AST00`00KgU_N@07KgT30009Ga/00`00
@[d00007@[d01@00Oomoogoo0000:7oo00<007ooOol02Woo2eJe2bU:5eJe2bU:2`002bU:0Woo00<0
07ooOol05Goo000GOol500000goo000000030005Ool00`00Ga]O6`07Ga/00`00BkU;^@03BkT20009
Ggd01000@W/0000025_M00<004iiCWT024ii00D004HiASU6>@0000Y_N@03001O6elK00YO6`/0009o
o`03001oogoo02Ioo`03001oogoo00Yoo`]F]@/YBQMF]@/YBP/000/YBP9oo`03001oogoo01Eoo`00
6Goo00@007ooOomoo`8000Uoo`03001O6elK00AO6aX000IKg@03001>NDii00M>N@040016>DHi0009
KgT200000elK001O6`08Ga/30002BQL00`00BQM:5`05BQL00`00Ool0000XOol00`00Oomoo`0:Ool;
E[D;:DXGE[D;:DX;000;:DX2Ool00`00Oomoo`0EOol001Uoo`03001oogoo009oo`03001oogoo00Qo
o`03001O6elK009O6`<00003Ool004GE00M5e@030016>DHi00U6>@04001_N@000004Fmd00`00CWU>
N@08CWT20008KgT20004Ga/00`00Ga]O6`04Ga/20003F[T01000BQM:5`001TXG00<007oo0000:7oo
0P002goo2eJe2bU:5eJe2bU:2`002bU:00=oo`0000005goo000IOol00`00Oomoo`03Ool20009Ool0
0`00Ga/000020004Ool00`00AME5e@05AMD00`00ASU6>@08AST01@00KgU_N@005KX00P000e_M00<0
04iiCWT01Tii0`001Vmi0P001UlK00<005lKGa/00UlK0P001EZi00@004XGBQL000M:5`8002Qoo`03
001ooeJe00YF]@]6<@/icQM6<@/icP/YBP/icP9oo`03001oogoo01Eoo`006Goo00<007ooOol01Goo
00<007ooOol01goo0P001Woo00<004GEAMD01TGE00<004HiAST01dHi00D006miKgU_N@00008E^P80
0003Fmd004ii00A>N@<000=?O`80009_N@8000UO6`04001O6`000008F[T01000BQM:5`001TXG0P00
:7oo00<007ooE[D02UJe2dHa2cW>5dHa2cW>2bU:2cW>0Woo00<007ooOol05Goo000HOol20008Ool0
0`00Oomoo`0>Ool00`00AME5e@06AMD00`00ASU6>@06AST00`00KgU_N@03KgT010005KXE^QFj0`00
00A>N@00000000Q?O`8000aO6`03001J^EZi00QJ^@05001:5dXGBQL00006BQL00`00Oomoo`0VOol0
0`00OomF]@0:E[D;AS4;>LhGAS4;>Lh;:DX;>Lh2Ool00`00Oomoo`0EOol002=oo`03001oogoo00eo
o`030015eDGE00M5e@030016>DHi00A6>@03001_NFmi00E_N@03000E^QFj008E^P8000Q?O`<0009B
o@03001O6elK00MO6`800003Gid005Zi00UJ^@04001:5dXG0006BQL00`00Oomoo`0VOol00`00OomF
]@0:E[D;AS4;>LhGAS4;>Lh;:DX;>Lh2Ool00`00Oomoo`0EOol002Aoo`8000ioo`030015eDGE00M5
e@030016>DHi0096>@03001_NFmi00I_N@03000E^QFj00@E^P8000=?O`<000IBo@03001O6elK00AO
6`8000=OW@03001J^EZi00QJ^@05001:5dXGBQL00006BQL00`00Oomoo`0UOol00`00OomF]@0:E[D;
AS4;>LhGAS4;>Lh;:DX;>Lh2Ool00`00Oomoo`0EOol002Ioo`03001oogoo00]oo`030015eDGE00M5
e@050016>DHiAST0000:KgT;0009D_d00`00Ga]O6`02Ga/20006Gid00`00F[UJ^@07F[T00`00BQM:
5`02BQL01000BQM:5dXG0`009goo0P002eJe2dHa2cW>5dHa2cW>2bU:2cW>00=oo`0000005goo000W
Ool00`00Oomoo`0:Ool00`00AME5e@08AMD01000ASU6>@0026mi0P0000=O6`00?]h01ckN00<005;m
D_d025;m00@005lK000000QOW@03001J^EZi00QJ^@03001:5dXG009:5`<0009oo`03001oogoo02Eo
o`03001ooeJe00YF]@]6<@/icQM6<@/icP/YBP/icP9oo`03001oogoo01Eoo`00:7oo00<007ooOol0
2Goo00<004GEAMD024GE00<004Hi000026mi00<005lKGa/00UlK00<003kN?]h01SkN00<005;mD_d0
1e;m0P002enM00<005ZiF[T01eZi00@004XGBQM:5`8000Aoo`03001oogoo02Eoo`03001ooeJe00YF
]@]6<@/icQM6<@/icP/YBP/icP9oo`03001oogoo01Eoo`00:Goo0P002Woo00<004GEAMD024GE0P00
1Vmi0P001UlK00<003kN?]h01SkN00<005;mD_d015;m0P000T]o0P002EnM00<005ZiF[T025Zi0`00
0Woo00D007ooOomoo`00029oo`8000=oo`03001ooeJe00YF]@]6<@/icQM6<@/icP/YBP/icP9oo`03
001oogoo01Eoo`00:goo00<007ooOol01goo00<004GEAMD01dGE00<006_hJoP00P000Vmi0P002ElK
00<003kN?]h01SkN00<005;mD_d00`001T]o5@001Goo00@007ooOol0029oo`03001oo`00009oo`03
001ooeJe00YF]@]6<@/icQM6<@/icP/YBP/icP9oo`03001oogoo01Eoo`00;7oo00<007ooOol01Woo
00<004GEAMD01TGE00<006_hJoP00f_h0P0035lK2`001d]o0P006Woo00@007ooOol0029oo`03001o
o`00009oo`8000]F]@]6<@/icQM6<@/icP/YBP/icP03Ool0000001Moo`00;Goo00<007ooOol01Goo
00<004GEAMD01DGE00<006_hJoP00f_h0P0000=O6`00Ga/025lK0P0000=OW@00AW/01dIk0P000d]o
0`007Goo00<007oo00008Woo0P000goo00<007ooE[D02UJe2dHa2cW>5dHa2cW>2bU:2cW>0Woo00<0
07ooOol05Goo000^Ool20006Ool00`00AME5e@03AMD00`00JoQ[n002JoP20004Ga/00`00Ga]O6`05
Ga/01@00GieOWEnM00002TIk0`008Goo00<007oo00008Goo00<007ooOol00Woo00<007ooE[D02UJe
2dHa2cW>5dHa2cW>2bU:2cW>0Woo00<007ooOol05Goo000`Ool00`00Oomoo`03Ool00`00AME5e@02
AMD01000JoQ[n6_h0P001elK00<005lKGa/00UlK0P001EnM00<004IkAW/01TIk0P0097oo0P008Woo
0P000Woo00<007ooE[D02UJe2dHa2cW>5dHa2cW>2bU:2cW>0Woo00<007ooOol05Goo000aOol00`00
Oomoo`02Ool00`00AME5e@02AMD01000JoP000002UlK00@005lK000000MOW@030016NdIk00A6N`80
02Ioo`8002Ioo`03001ooeJe00YF]@]6<@/icQM6<@/icP/YBP/icP9oo`03001oogoo01Eoo`00<Woo
00D007ooOomoo`0000=5e@03001[n00000eO6`03001OWEnM00QOW@040016NdIkAW/2000XOol2000V
Ool00`00OomF]@0:E[D;AS4;>LhGAS4;>Lh;:DX;>Lh2Ool00`00Oomoo`0EOol003=oo`06001oogoo
Ool004GE0`0000=oo`0000002ElK0P0000<_<`00000025nM00@004Ik000002Ioo`@002Qoo`8000]F
]@]6<@/icQM6<@/icP/YBP/icP03Ool0000001Moo`00=7oo0P0000Aoo`00000000Eoo`03001O6elK
00AO6a4002Aoo`@002aoo`03001ooeJe00YF]@]6<@/icQM6<@/icP/YBP/icP9oo`03001oogoo01Eo
o`00=Woo0P0027oo0P000UlK0P0000=oo`00Ool0;Woo1000<7oo00<007ooE[D02UJe2dHa2cW>5dHa
2cW>2bU:2cW>0Woo00<007ooOol05Goo000gOol00`00Oomoo`08Ool20003Ool00`00Oomoo`0YOol4
000dOol00`00OomF]@0:E[D;AS4;>LhGAS4;>Lh;:DX;>Lh2Ool00`00Oomoo`0EOol003Qoo`03001o
ogoo00]oo`03001oogoo02Ioo`@003Qoo`03001ooeJe00YF]@]6<@/icQM6<@/icP/YBP/icP9oo`03
001oogoo01Eoo`00>Goo0P002goo00<007ooOol08Woo1000?7oo0P002eJe2dHa2cW>5dHa2cW>2bU:
2cW>00=oo`0000005goo000kOol00`00Oomoo`08Ool00`00Oomoo`0NOol40010Ool00`00OolYBP0:
:DX;>Lh;AS4G>Lh;AS4;E[D;AS42Ool00`00Oomoo`0EOol003aoo`03001oogoo00Moo`03001oogoo
01]oo`<004Aoo`03001oobU:00XYBP/icP]6<ALicP]6<@]F]@]6<@9oo`03001oogoo01Eoo`00?Goo
00<007ooOol01Woo00<007ooOol05goo1000Agoo00<007oo:DX02RU:2cW>2dHa5cW>2dHa2eJe2dHa
0Woo00<007ooOol05Goo000nOol20006Ool00`00Oomoo`0COol4001;Ool00`00OolYBP0::DX;>Lh;
AS4G>Lh;AS4;E[D;AS42Ool00`00Oomoo`0EOol0041oo`03001oogoo00=oo`03001oogoo00moo`@0
04moo`03001oobU:00XYBP/icP]6<ALicP]6<@]F]@]6<@9oo`03001oogoo01Eoo`00@Goo00<007oo
Ool00Woo00<007ooOol02goo1000Dgoo0P002bU:2cW>2dHa5cW>2dHa2eJe2dHa00=oo`0000005goo
0012Ool01@00Oomoogoo00002Goo1000Egoo00<007oo:DX02RU:2cW>2dHa5cW>2dHa2eJe2dHa0Woo
00<007ooOol05Goo0013Ool200000goo001oo`04Ool4001KOol00`00OolYBP0::DX;>Lh;AS4G>Lh;
AS4;E[D;AS42Ool00`00Oomoo`0EOol004Eoo`800003Ool00000008005]oo`06001oogooOol007oo
2bU:2cW>2dHa5cW>2dHa2eJe2dHa0Woo00<007ooOol05Goo0016Ool2001NOol00`00Ool00002Ool0
0`00OolYBP0::DX;>Lh;AS4G>Lh;AS4;E[D;AS42Ool00`00Oomoo`0EOol00:Ioo`03001oo`00009o
o`8000/YBP/icP]6<ALicP]6<@]F]@]6<@03Ool0000001Moo`00Ygoo00D007ooOomoo`0005aoo`03
001oogoo01Eoo`00YWoo00<007oo00000WooGP005goo002WOol00`00Oomoo`1fOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {232.563, 0}} -> {-0.0510701, -0.0405654, 
  0.00732454, 0.00732454}, {{6.9375, 137}, {227, 
  121.5}} -> {-0.291797, -0.142555, 0.00936763, 0.00936763}, {{150, 280}, {
  227, 121.5}} -> {-15.5796, -1.57215, 0.0898273, 0.0898273}, {{6.9375, 
  137}, {111, 5.5}} -> {-0.270833, -1.20058, 0.00920759, 0.00920759}, {{150, 
  280}, {111, 5.5}} -> {-15.5796, -11.9921, 0.0898273, 0.0898273}}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"Microsoft Windows 3.0",
ScreenRectangle->{{0, 1280}, {0, 968}},
PrintingStyleEnvironment->"Printout",
WindowToolbars->"EditBar",
CellGrouping->Manual,
WindowSize->{655, 646},
WindowMargins->{{Automatic, 259}, {Automatic, 64}},
PrintingCopies->1,
PrintingPageRange->{Automatic, Automatic},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, -1}},
ShowCellLabel->True,
ShowCellTags->False,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False},
StyleDefinitions -> "ArticleClassic.nb"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1709, 49, 41, 0, 72, "Title"],
Cell[1753, 51, 35, 0, 41, "Author"],
Cell[1791, 53, 112, 4, 55, "Address"],
Cell[1906, 59, 76, 2, 31, "Input"],

Cell[CellGroupData[{
Cell[2007, 65, 31, 0, 56, "Section"],
Cell[2041, 67, 684, 12, 95, "Text"],

Cell[CellGroupData[{
Cell[2750, 83, 59, 0, 56, "Section"],
Cell[2812, 85, 68, 0, 27, "Text"],
Cell[2883, 87, 370, 11, 43, "NumberedEquation"],
Cell[3256, 100, 370, 11, 43, "NumberedEquation"],
Cell[3629, 113, 680, 22, 61, "Text"],
Cell[4312, 137, 196, 4, 30, "NumberedEquation"],
Cell[4511, 143, 524, 15, 61, "Text"],
Cell[5038, 160, 146, 4, 31, "Input"],
Cell[5187, 166, 273, 11, 27, "Text"],

Cell[CellGroupData[{
Cell[5485, 181, 84, 2, 31, "Input"],
Cell[5572, 185, 102, 2, 30, "Output"]
}, Open  ]],
Cell[5689, 190, 347, 10, 44, "Text"],

Cell[CellGroupData[{
Cell[6061, 204, 257, 6, 76, "Input"],
Cell[6321, 212, 62171, 2664, 141, 30577, 2268, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],
Cell[68507, 2879, 821, 16, 112, "Text"],

Cell[CellGroupData[{
Cell[69353, 2899, 64, 1, 31, "Input"],
Cell[69420, 2902, 58, 1, 30, "Output"]
}, Open  ]],
Cell[69493, 2906, 321, 7, 44, "Text"],
Cell[69817, 2915, 370, 11, 43, "NumberedEquation"],
Cell[70190, 2928, 370, 11, 43, "NumberedEquation"],
Cell[70563, 2941, 21, 0, 27, "Text"],
Cell[70587, 2943, 351, 11, 43, "NumberedEquation"],
Cell[70941, 2956, 48, 0, 27, "Text"],

Cell[CellGroupData[{
Cell[71014, 2960, 91, 1, 31, "Input"],
Cell[71108, 2963, 58, 1, 30, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[71215, 2970, 59, 0, 56, "Section"],
Cell[71277, 2972, 66, 0, 27, "Text"],
Cell[71346, 2974, 559, 14, 58, "NumberedEquation"],
Cell[71908, 2990, 562, 14, 58, "NumberedEquation"],
Cell[72473, 3006, 1161, 35, 95, "Text"],

Cell[CellGroupData[{
Cell[73659, 3045, 154, 3, 31, "Input"],
Cell[73816, 3050, 396, 9, 109, "Output"]
}, Open  ]],
Cell[74227, 3062, 52, 0, 27, "Text"],
Cell[74282, 3064, 276, 6, 31, "Input"],

Cell[CellGroupData[{
Cell[74583, 3074, 293, 7, 71, "Input"],
Cell[74879, 3083, 38196, 1348, 224, 12930, 1028, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[113124, 4437, 36, 0, 56, "Section"],
Cell[113163, 4439, 320, 9, 44, "Text"],
Cell[113486, 4450, 300, 8, 46, "NumberedEquation"],
Cell[113789, 4460, 210, 8, 27, "Text"],
Cell[114002, 4470, 805, 18, 70, "NumberedEquation"],
Cell[114810, 4490, 195, 6, 27, "Text"],

Cell[CellGroupData[{
Cell[115030, 4500, 127, 3, 33, "Input"],
Cell[115160, 4505, 665, 13, 137, "Output"]
}, Open  ]],
Cell[115840, 4521, 390, 12, 44, "Text"],
Cell[116233, 4535, 577, 11, 79, "Text"],
Cell[116813, 4548, 275, 5, 61, "Text"],

Cell[CellGroupData[{
Cell[117113, 4557, 285, 6, 71, "Input"],
Cell[117401, 4565, 27670, 993, 132, 9134, 760, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],
Cell[145086, 5561, 451, 11, 61, "Text"],

Cell[CellGroupData[{
Cell[145562, 5576, 143, 3, 31, "Input"],
Cell[145708, 5581, 62, 2, 30, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[145819, 5589, 44, 0, 56, "Section"],
Cell[145866, 5591, 469, 12, 61, "Text"],

Cell[CellGroupData[{
Cell[146360, 5607, 68, 0, 33, "Subsubsection"],
Cell[146431, 5609, 440, 18, 44, "Text"],
Cell[146874, 5629, 134, 4, 27, "NumberedEquation"],
Cell[147011, 5635, 135, 4, 27, "NumberedEquation"],
Cell[147149, 5641, 89, 2, 27, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[147275, 5648, 68, 0, 33, "Subsubsection"],
Cell[147346, 5650, 307, 5, 61, "Text"],
Cell[147656, 5657, 233, 6, 27, "NumberedEquation"],
Cell[147892, 5665, 246, 6, 27, "NumberedEquation"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[148187, 5677, 27, 0, 56, "Section"],
Cell[148217, 5679, 254, 5, 44, "Text"],

Cell[CellGroupData[{
Cell[148496, 5688, 514, 8, 134, "Input"],
Cell[149013, 5698, 55969, 1941, 242, 25532, 1561, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

