(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    714482,      19680]*)
(*NotebookOutlinePosition[    715564,      19719]*)
(*  CellTagsIndexPosition[    715493,      19713]*)
(*WindowFrame->Normal*)



Notebook[{
Cell["DISCRETE WAVELET TRANSFORM", "Title"],

Cell["Mariusz Jankowski", "Author"],

Cell["\<\
Department of Electrical Engineering
University of Southern Maine
mjkcc@usm.maine.edu\
\>", "Address"],

Cell[BoxData[
    \(<< ImageProcessing`\)], "Input",
  CellLabel->"In[15]:="],

Cell[BoxData[
    \(<< SignalPlot`\)], "Input",
  CellLabel->"In[16]:="],

Cell[CellGroupData[{

Cell["INTRODUCTION", "Section"],

Cell["\<\
Wavelet-based analysis of signals is an interesting new tool for the \
mathematician, scientist and engineer. Similar to Fourier series analysis, \
where sinusoids are chosen as the basis function, wavelet analysis is also \
based on a decomposition of a signal using an orthonormal (typically, \
although not necessarily) family of basis functions. Unlike a sine wave, a \
wavelet has its energy concentrated in time. Sinusoids are useful in \
analyzing periodic and time-invariant phenomena, while wavelets are well \
suited for the analysis of transient, time-varying signals. \
\>", "Text"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .2943 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.00700719 0.47619 [
[ 0 0 0 0 ]
[ 1 .2943 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .2943 L
0 .2943 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.00700719 0.477324 0.287295 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0476191 0.309019 0.294306 [
[.02381 .29652 -9 -9 ]
[.02381 .29652 9 0 ]
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.7381 .29652 -3 -9 ]
[.7381 .29652 3 0 ]
[.97619 .29652 -6 -9 ]
[.97619 .29652 6 0 ]
[.4875 .01471 -12 -4.5 ]
[.4875 .01471 0 4.5 ]
[.4875 .16187 -24 -4.5 ]
[.4875 .16187 0 4.5 ]
[.4875 .45617 -18 -4.5 ]
[.4875 .45617 0 4.5 ]
[.4875 .60333 -6 -4.5 ]
[.4875 .60333 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.02381 .30902 m
.02381 .31527 L
s
[(-10)] .02381 .29652 0 1 Mshowa
.2619 .30902 m
.2619 .31527 L
s
[(-5)] .2619 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(5)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(10)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 .01471 m
.50625 .01471 L
s
[(-1)] .4875 .01471 1 0 Mshowa
.5 .16187 m
.50625 .16187 L
s
[(-0.5)] .4875 .16187 1 0 Mshowa
.5 .45617 m
.50625 .45617 L
s
[(0.5)] .4875 .45617 1 0 Mshowa
.5 .60333 m
.50625 .60333 L
s
[(1)] .4875 .60333 1 0 Mshowa
.125 Mabswid
.5 .04414 m
.50375 .04414 L
s
.5 .07357 m
.50375 .07357 L
s
.5 .103 m
.50375 .103 L
s
.5 .13244 m
.50375 .13244 L
s
.5 .1913 m
.50375 .1913 L
s
.5 .22073 m
.50375 .22073 L
s
.5 .25016 m
.50375 .25016 L
s
.5 .27959 m
.50375 .27959 L
s
.5 .33845 m
.50375 .33845 L
s
.5 .36788 m
.50375 .36788 L
s
.5 .39731 m
.50375 .39731 L
s
.5 .42674 m
.50375 .42674 L
s
.5 .4856 m
.50375 .4856 L
s
.5 .51503 m
.50375 .51503 L
s
.5 .54446 m
.50375 .54446 L
s
.5 .57389 m
.50375 .57389 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.02846 .39784 L
.03279 .47329 L
.03754 .54057 L
.0402 .56874 L
.04262 .58745 L
.04385 .59428 L
.04516 .59946 L
.04627 .60217 L
.0475 .60332 L
.04882 .6024 L
.04957 .6009 L
.05024 .59892 L
.05156 .59344 L
.05281 .58624 L
.0552 .56729 L
.05742 .54396 L
.06244 .47342 L
.07295 .2796 L
.0781 .18365 L
.08284 .10781 L
.08545 .07397 L
.08832 .04487 L
.08981 .03341 L
.0912 .02511 L
.09197 .02154 L
.09267 .01894 L
.09348 .0167 L
.09424 .01535 L
.09549 .01475 L
.09612 .01521 L
.09681 .0163 L
.09804 .01973 L
.09919 .02468 L
.10055 .03257 L
.10179 .04174 L
.10458 .06886 L
.1145 .22212 L
.12511 .42355 L
.13025 .50731 L
.13278 .54066 L
.13511 .56574 L
.13723 .58329 L
.1383 .59012 L
.13947 .59603 L
.14065 .60022 L
.14192 .60276 L
.14311 .60328 L
.1442 .60216 L
.14544 .59907 L
Mistroke
.14655 .59461 L
.14784 .58754 L
.14906 .57904 L
.15122 .55965 L
.15356 .53299 L
.15887 .4538 L
.16375 .36524 L
.17272 .19465 L
.17765 .11398 L
.18007 .08136 L
.18231 .05638 L
.18476 .03538 L
.18605 .02716 L
.18671 .02374 L
.18742 .02067 L
.18856 .01705 L
.18963 .01517 L
.19091 .01483 L
.19207 .01635 L
.19317 .01936 L
.19419 .02352 L
.19531 .02958 L
.19651 .03773 L
.19896 .05958 L
.20117 .08503 L
.20629 .16079 L
.21182 .26131 L
.21701 .36154 L
.22185 .44991 L
.22681 .52551 L
.22898 .55171 L
.23134 .57459 L
.23268 .58476 L
.23392 .59225 L
.23511 .59763 L
.23637 .60142 L
.23769 .60322 L
.23893 .60287 L
.23965 .60179 L
.2403 .60023 L
.24101 .59789 L
.24177 .59473 L
.24308 .58753 L
.24428 .57915 L
.24697 .55428 L
.25182 .49072 L
.26282 .2912 L
.27213 .12525 L
.27682 .06396 L
.2781 .05103 L
Mistroke
.27949 .03921 L
.28078 .03016 L
.28198 .02358 L
.28271 .02047 L
.28337 .01823 L
.2841 .01638 L
.28488 .01516 L
.28556 .01473 L
.2863 .01493 L
.28699 .01576 L
.28763 .01706 L
.28883 .02091 L
.29014 .02719 L
.29152 .03601 L
.2928 .04625 L
.29761 .10082 L
.30277 .18223 L
.31296 .3751 L
.31833 .47048 L
.32127 .51491 L
.32403 .54959 L
.32642 .57325 L
.32765 .5829 L
.329 .59138 L
.33039 .59781 L
.33115 .60029 L
.33186 .60194 L
.33313 .6033 L
.33384 .60316 L
.33448 .60248 L
.33573 .59966 L
.33687 .59534 L
.33813 .58872 L
.33946 .57961 L
.3417 .55966 L
.34415 .53147 L
.35498 .35091 L
.36031 .248 L
.36525 .15903 L
.37009 .08713 L
.37219 .06249 L
.37447 .04123 L
.37578 .03171 L
.37698 .02478 L
.37812 .01982 L
.37933 .01639 L
.38061 .01479 L
.38181 .01518 L
.38311 .0177 L
.38385 .02006 L
Mistroke
.38451 .0228 L
.38566 .02881 L
.38693 .03729 L
.38949 .06017 L
.39409 .11844 L
.40448 .30352 L
.4091 .39219 L
.41416 .47996 L
.41646 .51433 L
.41893 .54573 L
.42105 .56787 L
.42336 .58608 L
.42405 .59033 L
.42478 .59417 L
.42609 .5994 L
.42732 .60232 L
.42802 .60313 L
.42867 .60332 L
.42989 .60222 L
.43099 .59957 L
.43227 .59459 L
.43349 .58798 L
.43579 .57055 L
.43793 .54903 L
.44276 .48357 L
.45352 .28687 L
.4588 .18814 L
.46363 .11007 L
.468 .0566 L
.4702 .03737 L
.47145 .02899 L
.47261 .02289 L
.47387 .01816 L
.47506 .01553 L
.47613 .01472 L
.47729 .01548 L
.47855 .01828 L
.47919 .02045 L
.47989 .02343 L
.48113 .03019 L
.48229 .03821 L
.48495 .06249 L
.48748 .09258 L
.49222 .16446 L
.50289 .36473 L
.50784 .45447 L
.51249 .52504 L
.51507 .55577 L
.51643 .56912 L
.51786 .58095 L
Mistroke
.51907 .58905 L
.51971 .59262 L
.52039 .59589 L
.5216 .6002 L
.52272 .60257 L
.52395 .60331 L
.52509 .60227 L
.52634 .59922 L
.52697 .59694 L
.52767 .59384 L
.52883 .58731 L
.53008 .57846 L
.53235 .55783 L
.53693 .49982 L
.54112 .43138 L
.55029 .25747 L
.55532 .16579 L
.56007 .09352 L
.56277 .0614 L
.5642 .04759 L
.5657 .03549 L
.56697 .02738 L
.56764 .02387 L
.56836 .02073 L
.56962 .0168 L
.57081 .01496 L
.57209 .01499 L
.57281 .01594 L
.57348 .01741 L
.57471 .0216 L
.57602 .02813 L
.57719 .03571 L
.57828 .04431 L
.58078 .06901 L
.59923 .3856 L
.60428 .47437 L
.60706 .51598 L
.60969 .54895 L
.61213 .57322 L
.61342 .58328 L
.61479 .59177 L
.61593 .59714 L
.6172 .60114 L
.61835 .60301 L
.61943 .60323 L
.62066 .60166 L
.62136 .59991 L
.62201 .59773 L
.6232 .59238 L
.62446 .58475 L
Mistroke
.62688 .56493 L
.62907 .54134 L
.63441 .46475 L
.63943 .37492 L
.64969 .18081 L
.65485 .09965 L
.65779 .0638 L
.6591 .05066 L
.66052 .03857 L
.66187 .0293 L
.66313 .0227 L
.66432 .01823 L
.66559 .01545 L
.66673 .01472 L
.66779 .01552 L
.66896 .01807 L
.67022 .02274 L
.67148 .02941 L
.67286 .03891 L
.67564 .06476 L
.67821 .09602 L
.68061 .13063 L
.68947 .28952 L
.69908 .46725 L
.70174 .50816 L
.70456 .54477 L
.70696 .56964 L
.70834 .58101 L
.70961 .58942 L
.71088 .59591 L
.71208 .60022 L
.71335 .60277 L
.71407 .6033 L
.71474 .60319 L
.71596 .60153 L
.71707 .59838 L
.71834 .59284 L
.71954 .5858 L
.72181 .5678 L
.7242 .54257 L
.72848 .48344 L
.73813 .30829 L
.74764 .1357 L
.75038 .0958 L
.75297 .06441 L
.75529 .04228 L
.75659 .03259 L
.75782 .02535 L
.75888 .02057 L
.76002 .01699 L
Mistroke
.76128 .01496 L
.76244 .0149 L
.76365 .01665 L
.76496 .02067 L
.7662 .02646 L
.76735 .03353 L
.76959 .05173 L
.77162 .07309 L
.77616 .13562 L
.7863 .32038 L
.79184 .42472 L
.79701 .50864 L
.79928 .53862 L
.80143 .56232 L
.80261 .57325 L
.8039 .58331 L
.80507 .59069 L
.80616 .59611 L
.80736 .60034 L
.808 .60184 L
.80869 .60288 L
.80937 .60331 L
.81009 .60312 L
.81138 .60113 L
.81257 .5974 L
.81368 .59232 L
.8149 .58499 L
.81621 .57518 L
.8188 .54996 L
.82118 .52046 L
.82658 .43579 L
.83639 .25015 L
.84099 .16665 L
.84529 .10014 L
.84764 .07066 L
.84979 .04869 L
.85217 .03041 L
.85348 .02324 L
.85473 .01843 L
.85598 .01558 L
.85668 .01485 L
.85733 .01473 L
.85851 .01592 L
.85977 .01912 L
.86089 .02368 L
.86195 .02936 L
.86433 .0472 L
.86692 .0738 L
.86927 .10398 L
.87456 .18853 L
Mistroke
.88348 .35789 L
.88837 .44733 L
.89295 .51844 L
.89542 .54913 L
.89767 .57172 L
.89887 .58138 L
.90018 .58998 L
.9015 .59652 L
.90221 .59917 L
.90288 .60106 L
.90408 .60302 L
.90521 .6032 L
.90622 .60196 L
.90732 .59915 L
.90852 .59434 L
.90979 .58731 L
.91206 .56988 L
.91452 .54437 L
.91717 .51009 L
.92195 .43351 L
.93283 .22749 L
.93774 .14164 L
.94044 .10146 L
.94297 .06963 L
.94442 .05439 L
.94598 .04055 L
.94728 .03121 L
.94802 .02681 L
.94871 .02332 L
.94941 .02034 L
.95006 .01817 L
.95074 .01643 L
.95148 .01524 L
.95279 .01482 L
.95402 .01644 L
.95518 .01971 L
.95645 .02528 L
.95779 .03323 L
.95903 .04262 L
.96126 .06383 L
.96366 .09254 L
.97413 .26913 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.00700719 0.97619 0.287295 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.479296 0.0414079 0.311962 0.325045 [
[.06522 .29946 -9 -9 ]
[.06522 .29946 9 0 ]
[.27226 .29946 -6 -9 ]
[.27226 .29946 6 0 ]
[.68634 .29946 -3 -9 ]
[.68634 .29946 3 0 ]
[.89337 .29946 -6 -9 ]
[.89337 .29946 6 0 ]
[.4668 .06818 -30 -4.5 ]
[.4668 .06818 0 4.5 ]
[.4668 .14944 -24 -4.5 ]
[.4668 .14944 0 4.5 ]
[.4668 .2307 -30 -4.5 ]
[.4668 .2307 0 4.5 ]
[.4668 .39322 -24 -4.5 ]
[.4668 .39322 0 4.5 ]
[.4668 .47448 -18 -4.5 ]
[.4668 .47448 0 4.5 ]
[.4668 .55575 -24 -4.5 ]
[.4668 .55575 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.06522 .31196 m
.06522 .31821 L
s
[(-10)] .06522 .29946 0 1 Mshowa
.27226 .31196 m
.27226 .31821 L
s
[(-5)] .27226 .29946 0 1 Mshowa
.68634 .31196 m
.68634 .31821 L
s
[(5)] .68634 .29946 0 1 Mshowa
.89337 .31196 m
.89337 .31821 L
s
[(10)] .89337 .29946 0 1 Mshowa
.125 Mabswid
.10663 .31196 m
.10663 .31571 L
s
.14803 .31196 m
.14803 .31571 L
s
.18944 .31196 m
.18944 .31571 L
s
.23085 .31196 m
.23085 .31571 L
s
.31366 .31196 m
.31366 .31571 L
s
.35507 .31196 m
.35507 .31571 L
s
.39648 .31196 m
.39648 .31571 L
s
.43789 .31196 m
.43789 .31571 L
s
.5207 .31196 m
.5207 .31571 L
s
.56211 .31196 m
.56211 .31571 L
s
.60352 .31196 m
.60352 .31571 L
s
.64493 .31196 m
.64493 .31571 L
s
.72774 .31196 m
.72774 .31571 L
s
.76915 .31196 m
.76915 .31571 L
s
.81056 .31196 m
.81056 .31571 L
s
.85197 .31196 m
.85197 .31571 L
s
.02381 .31196 m
.02381 .31571 L
s
.93478 .31196 m
.93478 .31571 L
s
.97619 .31196 m
.97619 .31571 L
s
.25 Mabswid
0 .31196 m
1 .31196 L
s
.4793 .06818 m
.48555 .06818 L
s
[(-0.75)] .4668 .06818 1 0 Mshowa
.4793 .14944 m
.48555 .14944 L
s
[(-0.5)] .4668 .14944 1 0 Mshowa
.4793 .2307 m
.48555 .2307 L
s
[(-0.25)] .4668 .2307 1 0 Mshowa
.4793 .39322 m
.48555 .39322 L
s
[(0.25)] .4668 .39322 1 0 Mshowa
.4793 .47448 m
.48555 .47448 L
s
[(0.5)] .4668 .47448 1 0 Mshowa
.4793 .55575 m
.48555 .55575 L
s
[(0.75)] .4668 .55575 1 0 Mshowa
.125 Mabswid
.4793 .08443 m
.48305 .08443 L
s
.4793 .10068 m
.48305 .10068 L
s
.4793 .11693 m
.48305 .11693 L
s
.4793 .13319 m
.48305 .13319 L
s
.4793 .16569 m
.48305 .16569 L
s
.4793 .18194 m
.48305 .18194 L
s
.4793 .1982 m
.48305 .1982 L
s
.4793 .21445 m
.48305 .21445 L
s
.4793 .24695 m
.48305 .24695 L
s
.4793 .26321 m
.48305 .26321 L
s
.4793 .27946 m
.48305 .27946 L
s
.4793 .29571 m
.48305 .29571 L
s
.4793 .32821 m
.48305 .32821 L
s
.4793 .34447 m
.48305 .34447 L
s
.4793 .36072 m
.48305 .36072 L
s
.4793 .37697 m
.48305 .37697 L
s
.4793 .40948 m
.48305 .40948 L
s
.4793 .42573 m
.48305 .42573 L
s
.4793 .44198 m
.48305 .44198 L
s
.4793 .45823 m
.48305 .45823 L
s
.4793 .49074 m
.48305 .49074 L
s
.4793 .50699 m
.48305 .50699 L
s
.4793 .52324 m
.48305 .52324 L
s
.4793 .53949 m
.48305 .53949 L
s
.4793 .05193 m
.48305 .05193 L
s
.4793 .03567 m
.48305 .03567 L
s
.4793 .01942 m
.48305 .01942 L
s
.4793 .00317 m
.48305 .00317 L
s
.4793 .572 m
.48305 .572 L
s
.4793 .58825 m
.48305 .58825 L
s
.4793 .6045 m
.48305 .6045 L
s
.25 Mabswid
.4793 0 m
.4793 .61803 L
s
.5 Mabswid
.02381 .31196 m
.02899 .31196 L
.03416 .31196 L
.03934 .31196 L
.04451 .31196 L
.04969 .31196 L
.05487 .31196 L
.06004 .31196 L
.06522 .31196 L
.07039 .31196 L
.07557 .31196 L
.08075 .31196 L
.08592 .31196 L
.0911 .31196 L
.09627 .31196 L
.10145 .31195 L
.10663 .31195 L
.1118 .31195 L
.11698 .31195 L
.12215 .31196 L
.12733 .31197 L
.13251 .31198 L
.13768 .312 L
.14286 .31203 L
.14803 .31206 L
.15321 .31209 L
.15839 .31211 L
.16356 .31212 L
.16874 .3121 L
.17391 .31205 L
.17909 .31195 L
.18427 .31179 L
.18944 .31159 L
.19462 .31135 L
.19979 .3111 L
.20497 .31089 L
.21014 .31076 L
.21532 .31079 L
.2205 .31104 L
.22567 .31154 L
.23085 .31232 L
.23602 .31335 L
.2412 .31454 L
.24638 .31576 L
.25155 .3168 L
.25673 .3174 L
.2619 .31733 L
.26708 .31639 L
.27226 .31445 L
.27743 .31151 L
Mistroke
.28261 .30774 L
.28778 .30353 L
.29296 .29945 L
.29814 .29624 L
.30331 .29463 L
.30849 .29527 L
.31366 .29862 L
.31884 .30487 L
.32402 .31373 L
.32919 .32438 L
.33437 .33545 L
.33954 .34519 L
.34472 .35176 L
.3499 .35355 L
.35507 .34927 L
.36025 .33833 L
.36542 .32112 L
.3706 .29923 L
.37578 .2755 L
.38095 .25372 L
.38613 .23781 L
.3913 .23123 L
.39648 .2367 L
.40166 .25555 L
.40683 .28694 L
.41201 .32764 L
.41718 .37172 L
.42236 .41134 L
.42754 .43859 L
.43271 .44677 L
.43789 .43108 L
.44306 .39014 L
.44824 .32745 L
.45342 .25196 L
.45859 .1781 L
.46377 .1237 L
.46894 .10501 L
.47412 .13294 L
.4793 .21063 L
.48447 .32869 L
.48965 .46121 L
.49482 .56791 L
.5 .60332 L
.50518 .53579 L
.51035 .37528 L
.51553 .18114 L
.5207 .03666 L
.52588 .01472 L
.53106 .13 L
.53623 .31772 L
Mistroke
.54141 .48224 L
.54658 .54232 L
.55176 .47354 L
.55694 .33749 L
.56211 .21828 L
.56729 .17295 L
.57246 .21779 L
.57764 .30234 L
.58282 .36575 L
.58799 .38383 L
.59317 .35354 L
.59834 .30754 L
.60352 .28245 L
.6087 .28097 L
.61387 .29813 L
.61905 .31898 L
.62422 .32566 L
.6294 .32222 L
.63458 .31493 L
.63975 .30763 L
.64493 .30687 L
.6501 .3097 L
.65528 .31186 L
.66046 .31361 L
.66563 .31343 L
.67081 .31215 L
.67598 .31174 L
.68116 .31158 L
.68634 .31165 L
.69151 .31202 L
.69669 .31206 L
.70186 .312 L
.70704 .31201 L
.71222 .31194 L
.71739 .31193 L
.72257 .31197 L
.72774 .31196 L
.73292 .31196 L
.7381 .31197 L
.74327 .31196 L
.74845 .31196 L
.75362 .31196 L
.7588 .31196 L
.76398 .31196 L
.76915 .31196 L
.77433 .31196 L
.7795 .31196 L
.78468 .31196 L
.78986 .31196 L
.79503 .31196 L
Mistroke
.80021 .31196 L
.80538 .31196 L
.81056 .31196 L
.81573 .31196 L
.82091 .31196 L
.82609 .31196 L
.83126 .31196 L
.83644 .31196 L
.84161 .31196 L
.84679 .31196 L
.85197 .31196 L
.85714 .31196 L
.86232 .31196 L
.86749 .31196 L
.87267 .31196 L
.87785 .31196 L
.88302 .31196 L
.8882 .31196 L
.89337 .31196 L
.89855 .31196 L
.90373 .31196 L
.9089 .31196 L
.91408 .31196 L
.91925 .31196 L
.92443 .31196 L
.92961 .31196 L
.93478 .31196 L
.93996 .31196 L
.94513 .31196 L
.95031 .31196 L
.95549 .31196 L
.96066 .31196 L
.96584 .31196 L
.97101 .31196 L
.97619 .31196 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "NumberedFigure",
  ImageSize->{417.25, 122.75},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006Q0000NQ000`40O003h00OogooXWoo003oOonR
Ool00?mooj9oo`00ogoo=7oo0P00K7oo003oOoldOol00`00Oomoo`1[Ool006=oo`D0009oo`03001o
ogoo0<Ioo`03001oogoo00Ioo`03001oogoo069oo`00IGoo00<007ooOol00Woo00<007ooOol0aWoo
0P001goo00<007ooOol0HWoo000POol2000@Ool00`00Oomoo`0>Ool00`00Oomoo`0>Ool00`00Oomo
o`08Ool30003Ool20003Ool2000;Ool00`00Oomoo`0>Ool00`00Oomoo`0>Ool00`00Oomoo`0>Ool2
000@Ool00`00Oomoo`1dOol00`00Oomoo`06Ool00`00Oomoo`1ROol0021oo`8000moo`80011oo`80
00moo`8000moo`8000=oo`03001oogoo00Uoo`80011oo`8000moo`8000moo`8000moo`8007Ioo`03
001oogoo00Eoo`8006Aoo`0087oo0P003goo0P003goo00<007oo00003goo0P003goo0P000goo00<0
07ooOol02Goo0P003goo00<007oo00003goo0P003goo0P003goo00<007oo0000MGoo0P001Woo0P00
I7oo000POol00`00Ool0000>Ool00`00Ool0000>Ool00`00Ool0000>Ool00`00Ool0000>Ool30003
Ool00`00Oomoo`09Ool00`00Ool0000>Ool00`00Ool0000>Ool00`00Ool0000?Ool2000?Ool00`00
Ool0001eOol00`00Oomoo`05Ool2001TOol0021oo`03001oo`0000ioo`03001oo`0000ioo`03001o
o`0000ioo`03001oo`0000moo`03001oo`00009oo`03001oogoo00Uoo`03001oo`0000ioo`03001o
o`0000ioo`03001oo`0000moo`8000moo`03001oo`0007Eoo`03001oogoo00Eoo`8006Aoo`007goo
00@007ooOol000ioo`03001oo`0000ioo`03001oo`0000ioo`03001oo`0000moo`03001oo`00009o
o`03001oogoo00Uoo`03001oo`0000ioo`03001oo`0000ioo`03001oo`0000ioo`04001oogoo000>
Ool00`00Ool0001eOol20006Ool2001TOol001moo`04001oogoo000=Ool01000Oomoo`003Woo00<0
07oo00003Woo00<007oo00003Woo00@007ooOol0009oo`8000Yoo`03001oo`0000ioo`03001oo`00
00ioo`04001oogoo000=Ool01000Oomoo`003Woo00<007oo0000HGoo00<007ooOol00Woo00<007oo
Ool00Woo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol01Goo0P00I7oo000OOol01000Oomo
o`003Goo00@007ooOol000ioo`03001oo`0000ioo`04001oogoo000=Ool01000Oomoo`000Woo00<0
07ooOol02Goo00<007oo00003Woo00@007ooOol000eoo`04001oogoo000=Ool01000Oomoo`003Goo
00@007ooOol0061oo`03001oo`0000Qoo`07001oogooOol007oo00000goo00<007ooOol01Goo0P00
I7oo000OOol01000Oomoo`003Goo00@007ooOol000eoo`04001oogoo000>Ool01000Oomoo`003Goo
00@007ooOol0009oo`03001oogoo00Qoo`05001oogooOol0000<Ool01@00Oomoogoo00003Goo00@0
07ooOol000eoo`04001oogoo000=Ool01000Oomoo`00Fgoo0`000Woo00<007oo000027oo00<007oo
Ool00goo00@007ooOomoo`8000Ioo`8006Aoo`007goo00@007ooOol000eoo`04001oogoo000=Ool0
1000Oomoo`003Woo00@007ooOol000eoo`04001oogoo0002Ool00`00Oomoo`08Ool01@00Oomoogoo
000037oo00D007ooOomoo`0000eoo`04001oogoo000=Ool01000Oomoo`003Goo00@007ooOol0061o
o`03001oo`0000Uoo`03001oogoo008000Aoo`03001oogoo00Eoo`03001oo`0006=oo`007goo00@0
07ooOol000eoo`04001oogoo000=Ool01000Oomoo`003Woo00@007ooOol000eoo`04001oogoo0002
Ool00`00Oomoo`08Ool01@00Oomoogoo000037oo00D007ooOomoo`0000eoo`04001oogoo000=Ool0
1000Oomoo`003Goo00@007ooOol0061oo`03001oo`0000Moo`03001oo`00009oo`03001oogoo00=o
o`03001oogoo00Eoo`03001oo`0006=oo`007goo00@007ooOol000eoo`05001oogooOol0000<Ool0
1@00Oomoogoo000037oo00D007ooOomoo`0000eoo`04001oogoo0002Ool20009Ool01@00Oomoogoo
000037oo00D007ooOomoo`0000eoo`04001oogoo000=Ool01000Oomoo`003Goo00@007ooOol0065o
o`03001oogoo00Ioo`<0009oo`<000=oo`03001oogoo00Eoo`03001oo`0006=oo`007goo00@007oo
Ool000eoo`05001oogooOol0000<Ool01@00Oomoogoo000037oo00D007ooOomoo`0000eoo`07001o
ogooOol007oo00002Woo00D007ooOomoo`0000aoo`05001oogooOol0000<Ool01@00Oomoogoo0000
3Goo00@007ooOol000eoo`05001oogooOol0001dOol20006Ool00`00Ool0001SOol001moo`04001o
ogoo000=Ool01@00Oomoogoo000037oo00D007ooOomoo`0000aoo`05001oogooOol0000<Ool00`00
Oomoo`02Ool00`00Ool0000:Ool01@00Oomoogoo000037oo00D007ooOomoo`0000aoo`05001oogoo
Ool0000<Ool01@00Oomoogoo00003Goo00D007ooOomoo`0007Aoo`03001oogoo00Eoo`03001oo`00
06=oo`007Woo00D007ooOomoo`0000eoo`05001oogooOol0000<Ool01@00Oomoogoo000037oo00<0
07ooOol00Woo00<007ooOol02Goo00<007ooOol00Woo00<007oo00002Woo00D007ooOomoo`0000ao
o`05001oogooOol0000<Ool01@00Oomoogoo000037oo00<007ooOol00Woo00<007ooOol02Woo00D0
07ooOomoo`0007Aoo`03001oogoo00Eoo`03001oo`0006=oo`007Woo00D007ooOomoo`0000eoo`05
001oogooOol0000<Ool01@00Oomoogoo000037oo00<007ooOol00Woo00<007ooOol02Goo00<007oo
Ool00Woo00<007oo00002Woo00D007ooOomoo`0000aoo`05001oogooOol0000<Ool01@00Oomoogoo
000037oo00<007ooOol00Woo00<007ooOol02Woo00D007ooOomoo`00079oo`04001oo`000006Ool0
0`00Ool0001SOol001ioo`05001oogooOol0000=Ool01@00Oomoogoo000037oo00D007ooOomoo`00
00aoo`03001oogoo009oo`03001oogoo00Uoo`03001oogoo009oo`04001oo`000009Ool01@00Oomo
ogoo000037oo00D007ooOomoo`0000aoo`05001oogooOol0000<Ool00`00Oomoo`02Ool00`00Oomo
o`0:Ool01@00Oomoogoo0000LWoo00<007oo00001goo00<007oo0000Hgoo000NOol00`00Oomoo`02
Ool00`00Oomoo`0:Ool01@00Oomoogoo000037oo00D007ooOomoo`0000aoo`03001oogoo009oo`03
001oogoo00Uoo`03001oogoo009oo`03001oo`0000Yoo`05001oogooOol0000<Ool01@00Oomoogoo
000037oo00<007ooOol00Woo00<007ooOol02Goo00<007ooOol00Woo00<007ooOol02Woo00D007oo
Oomoo`00075oo`800003Ool007oo00Eoo`04001oogoo001SOol001ioo`03001oogoo009oo`03001o
ogoo00Yoo`05001oogooOol0000<Ool01@00Oomoogoo000037oo00<007ooOol00Woo00<007ooOol0
2Goo00<007ooOol00Woo00<007oo00002Woo00D007ooOomoo`0000aoo`03001oogoo009oo`03001o
ogoo00Uoo`03001oogoo009oo`03001oogoo00Uoo`03001oogoo009oo`03001oogoo00Yoo`05001o
ogooOol0001aOol00`00Ool000020005Ool01000Oomoo`00Hgoo000NOol00`00Oomoo`02Ool00`00
Oomoo`0:Ool01@00Oomoogoo000037oo00D007ooOomoo`0000aoo`03001oogoo009oo`03001oogoo
00Uoo`03001oogoo009oo`03001oo`0000Yoo`05001oogooOol0000<Ool00`00Oomoo`02Ool00`00
Oomoo`09Ool00`00Oomoo`02Ool00`00Oomoo`09Ool00`00Oomoo`02Ool00`00Oomoo`0:Ool01@00
Oomoogoo0000LGoo00@007oo000000Ioo`04001oogoo001SOol001ioo`03001oogoo009oo`03001o
ogoo00Yoo`03001oogoo009oo`03001oogoo00Uoo`05001oogooOol0000;Ool00`00Oomoo`03Ool0
0`00Oomoo`09Ool00`00Oomoo`02Ool00`00Ool0000:Ool00`00Oomoo`02Ool00`00Oomoo`09Ool0
0`00Oomoo`02Ool00`00Oomoo`09Ool00`00Oomoo`02Ool00`00Oomoo`09Ool00`00Oomoo`02Ool0
0`00Oomoo`09Ool00`00Oomoo`02Ool00`00Oomoo`1_Ool01000Ool000001Woo00@007ooOol006=o
o`007Woo00<007ooOol00Woo00<007ooOol02Woo00<007ooOol00Woo00<007ooOol02Goo00D007oo
Oomoo`0000]oo`03001oogoo00=oo`03001oogoo00Uoo`03001oogoo009oo`03001oo`0000Yoo`03
001oogoo009oo`03001oogoo00Uoo`03001oogoo009oo`03001oogoo00Uoo`03001oogoo009oo`03
001oogoo00Uoo`03001oogoo009oo`03001oogoo00Uoo`03001oogoo009oo`03001oogoo06moo`03
001oo`00008000Eoo`04001oogoo001SOol001ioo`03001oogoo009oo`03001oogoo00Yoo`03001o
ogoo009oo`03001oogoo00Uoo`05001oogooOol0000;Ool00`00Oomoo`03Ool00`00Oomoo`09Ool0
0`00Oomoo`02Ool01000Ool0000027oo00<007ooOol00goo00<007ooOol02Goo00<007ooOol00Woo
00<007ooOol02Goo00<007ooOol00Woo00<007ooOol02Goo00<007ooOol00Woo00<007ooOol02Goo
00<007ooOol00goo00<007ooOol0HWoo00<007ooOol00Woo00<007ooOol00Woo00@007oo001oo`80
00Ioo`04001oogoo001SOol001ioo`03001oogoo009oo`03001oogoo00Yoo`03001oogoo009oo`03
001oogoo00Uoo`05001oogooOol0000;Ool00`00Oomoo`03Ool00`00Oomoo`09Ool00`00Oomoo`02
Ool00`00Ool00009Ool00`00Oomoo`03Ool00`00Oomoo`08Ool00`00Oomoo`03Ool00`00Oomoo`09
Ool00`00Oomoo`02Ool00`00Oomoo`09Ool00`00Oomoo`02Ool00`00Oomoo`09Ool00`00Oomoo`03
Ool00`00Oomoo`1QOol00`00Ool00007Ool01@00Ool00000Ool00P001Woo00@007ooOol006=oo`00
7Goo00<007ooOol00goo00<007ooOol02Woo00<007ooOol00Woo00<007ooOol02Goo00<007ooOol0
0Woo00<007ooOol027oo00<007ooOol00goo00<007ooOol02Goo00<007ooOol00Woo00<007oo0000
2Goo00<007ooOol00goo00<007ooOol027oo00<007ooOol00goo00<007ooOol02Goo00<007ooOol0
0Woo00<007ooOol02Goo00<007ooOol00Woo00<007ooOol02Goo00<007ooOol00goo00<007ooOol0
G7oo0`000Woo00<007oo00002Goo00<007ooOol00`001Goo00@007ooOol006=oo`007Goo00<007oo
Ool00goo00<007ooOol02Woo00<007ooOol00Woo00<007ooOol02Goo00<007ooOol00Woo00<007oo
Ool027oo00<007ooOol00goo00D007ooOomoo`0000Aoo`03001oo`00009oo`06001oogoo001oo`00
2Goo00<007ooOol00goo00<007ooOol027oo00<007ooOol00goo00<007ooOol02Goo00<007ooOol0
0Woo00<007ooOol02Goo00<007ooOol00goo00<007ooOol027oo00<007ooOol00goo00<007ooOol0
HGoo00<007oo00001goo0`000Woo0P001Woo00@007ooOol006=oo`007Goo00<007ooOol00goo00<0
07ooOol02Goo00<007ooOol00goo00<007ooOol02Goo00<007ooOol00Woo00<007ooOol027oo00<0
07ooOol00goo00H007ooOol007oo0005Ool02@00Ool007oo001oo`00Ool00009Ool00`00Oomoo`03
Ool00`00Oomoo`08Ool00`00Oomoo`03Ool00`00Oomoo`09Ool00`00Oomoo`02Ool00`00Oomoo`09
Ool00`00Oomoo`03Ool00`00Oomoo`08Ool00`00Oomoo`03Ool00`00Oomoo`1QOol00`00Ool00007
Ool00`00Ool00002Ool20006Ool01000Oomoo`00Hgoo000MOol00`00Oomoo`03Ool00`00Oomoo`09
Ool00`00Oomoo`03Ool00`00Oomoo`09Ool00`00Oomoo`02Ool00`00Oomoo`08Ool01000Oomoogoo
0`000Woo00<007oo00001Goo00P007ooOomoo`00Ool007oo0P0027oo00<007ooOol00goo00<007oo
Ool027oo00<007ooOol00goo00<007ooOol02Goo00<007ooOol00Woo00<007ooOol02Goo00<007oo
Ool00goo00<007ooOol027oo00<007ooOol00goo00<007ooOol0HWoo00<007ooOol01Woo0`000Woo
0`001Goo00@007ooOol006=oo`007Goo00<007ooOol00goo00<007ooOol02Goo00<007ooOol00goo
00<007ooOol027oo00<007ooOol00goo00<007ooOol027oo00<007ooOol017oo00D007oo001oo`00
00Eoo`04001oo`000002Ool00`00Ool00009Ool00`00Oomoo`03Ool00`00Oomoo`08Ool00`00Oomo
o`03Ool00`00Oomoo`09Ool00`00Oomoo`02Ool00`00Oomoo`09Ool00`00Oomoo`03Ool00`00Oomo
o`08Ool00`00Oomoo`03Ool00`00Oomoo`1]Ool01@00Oomoogoo00001Woo00@007ooOol000Eoo`03
001oogoo05]oo`007Goo00<007ooOol00goo00<007ooOol02Goo00<007ooOol00goo00<007ooOol0
27oo00<007ooOol00goo00<007ooOol027oo00<007ooOol017oo00D007oo001oo`0000Eoo`03001o
o`0000=oo`03001oo`0000Uoo`03001oogoo00=oo`03001oogoo00Qoo`03001oogoo00=oo`03001o
ogoo00Uoo`03001oogoo009oo`03001oogoo00Uoo`03001oogoo00=oo`03001oogoo00Qoo`03001o
ogoo00=oo`03001oogoo06eoo`05001oogooOol00006Ool01000Oomoo`001Goo00<007ooOol0Fgoo
000MOol00`00Oomoo`03Ool00`00Oomoo`09Ool00`00Oomoo`03Ool00`00Oomoo`08Ool00`00Oomo
o`03Ool00`00Oomoo`08Ool00`00Oomoo`04Ool01000Oomoo`001Woo00<007oo00000P0000Aoo`00
Ool000Uoo`03001oogoo00=oo`03001oogoo00Qoo`03001oogoo00=oo`03001oogoo00Qoo`03001o
ogoo00=oo`03001oogoo00Uoo`03001oogoo00=oo`03001oogoo00Qoo`03001oogoo00=oo`03001o
ogoo06eoo`04001oogooOol20005Ool01000Oomoo`001Goo00<007ooOol0Fgoo000MOol00`00Oomo
o`04Ool00`00Oomoo`08Ool00`00Oomoo`03Ool00`00Oomoo`08Ool00`00Oomoo`03Ool00`00Oomo
o`08Ool00`00Oomoo`04Ool00`00Oomoo`07Ool00`00Oomoo`03Ool00`00Ool00009Ool00`00Oomo
o`03Ool00`00Oomoo`08Ool00`00Oomoo`03Ool00`00Oomoo`08Ool00`00Oomoo`04Ool00`00Oomo
o`08Ool00`00Oomoo`03Ool00`00Oomoo`07Ool00`00Oomoo`04Ool00`00Oomoo`1]Ool01@00Oomo
ogoo00001Woo00@007ooOol000Eoo`03001oogoo05]oo`007Goo00<007ooOol017oo00<007ooOol0
27oo00<007ooOol00goo00<007ooOol027oo00<007ooOol00goo00<007ooOol027oo00<007ooOol0
17oo00<007ooOol01goo00<007ooOol00goo00@007oo000000Qoo`03001oogoo00=oo`03001oogoo
00Qoo`03001oogoo00=oo`03001oogoo00Qoo`03001oogoo00Aoo`03001oogoo00Qoo`03001oogoo
00=oo`03001oogoo00Moo`03001oogoo00Aoo`03001oogoo06eoo`05001oogooOol00006Ool01000
Oomoo`001Goo00<007ooOol0Fgoo000MOol00`00Oomoo`04Ool00`00Oomoo`08Ool00`00Oomoo`03
Ool00`00Oomoo`08Ool00`00Oomoo`03Ool00`00Oomoo`08Ool00`00Oomoo`04Ool00`00Oomoo`07
Ool00`00Oomoo`03Ool00`00Ool00009Ool00`00Oomoo`03Ool00`00Oomoo`08Ool00`00Oomoo`03
Ool00`00Oomoo`08Ool00`00Oomoo`04Ool00`00Oomoo`08Ool00`00Oomoo`03Ool00`00Oomoo`07
Ool00`00Oomoo`04Ool00`00Oomoo`1]Ool01000Oomoogoo0P001Goo00@007ooOol000Aoo`03001o
o`0005aoo`007Goo00<007ooOol017oo00<007ooOol027oo00<007ooOol00goo00<007ooOol027oo
00<007ooOol00goo00<007ooOol027oo00<007ooOol017oo00<007ooOol01goo00<007ooOol00goo
00<007oo00002Goo00<007ooOol00goo00<007ooOol027oo00<007ooOol00goo00<007ooOol027oo
00<007ooOol017oo00<007ooOol027oo00<007ooOol00goo00<007ooOol01goo00<007ooOol017oo
00<007ooOol0KGoo00D007ooOomoo`0000Ioo`04001oogoo0004Ool00`00Ool0001LOol001eoo`03
001oogoo00Aoo`03001oogoo00Qoo`03001oogoo00=oo`03001oogoo00Qoo`03001oogoo00=oo`03
001oogoo00Qoo`03001oogoo00Aoo`03001oogoo00Moo`03001oogoo00=oo`03001oo`0000Uoo`03
001oogoo00=oo`03001oogoo00Qoo`03001oogoo00=oo`03001oogoo00Qoo`03001oogoo00Aoo`03
001oogoo00Qoo`03001oogoo00=oo`03001oogoo00Moo`03001oogoo00Aoo`03001oogoo06eoo`05
001oogooOol00006Ool01000Oomoo`0017oo00<007oo0000G7oo000MOol00`00Oomoo`04Ool00`00
Oomoo`08Ool00`00Oomoo`04Ool00`00Oomoo`07Ool00`00Oomoo`03Ool00`00Oomoo`08Ool00`00
Oomoo`04Ool00`00Oomoo`07Ool00`00Oomoo`03Ool00`00Ool00008Ool00`00Oomoo`04Ool00`00
Oomoo`08Ool00`00Oomoo`04Ool00`00Oomoo`07Ool00`00Oomoo`04Ool00`00Oomoo`07Ool00`00
Oomoo`04Ool00`00Oomoo`07Ool00`00Oomoo`04Ool00`00Oomoo`1/Ool00`00Oomoo`02Ool20005
Ool01000Oomoo`0017oo00<007oo0000G7oo000MOol00`00Oomoo`04Ool00`00Oomoo`08Ool00`00
Oomoo`04Ool00`00Oomoo`07Ool00`00Oomoo`03Ool00`00Oomoo`08Ool00`00Oomoo`04Ool00`00
Oomoo`07Ool00`00Oomoo`04Ool20008Ool00`00Oomoo`04Ool00`00Oomoo`08Ool00`00Oomoo`04
Ool00`00Oomoo`07Ool00`00Oomoo`04Ool00`00Oomoo`07Ool00`00Oomoo`04Ool00`00Oomoo`07
Ool00`00Oomoo`04Ool00`00Oomoo`1MOol00`00Oomoo`02Ool01000Oomoogoo0`000goo00<007oo
Ool00Woo00<007ooOol017oo00@007ooOol000Aoo`03001oo`0005aoo`007Goo00<007ooOol017oo
00<007ooOol027oo00<007ooOol017oo00<007ooOol01goo00<007ooOol00goo00<007ooOol027oo
00<007ooOol017oo00<007ooOol01goo00<007ooOol017oo0`001goo00<007ooOol017oo00<007oo
Ool027oo00<007ooOol017oo00<007ooOol01goo00<007ooOol017oo00<007ooOol01goo00<007oo
Ool017oo00<007ooOol01goo00<007ooOol01Goo00<007ooOol0Fgoo00<007oo00001goo00<007oo
Ool00Woo0`000goo00<007ooOol017oo00D007ooOomoo`0000=oo`03001oo`0005aoo`007Goo00<0
07ooOol017oo00<007ooOol027oo00<007ooOol017oo00<007ooOol01goo00<007ooOol00goo00<0
07ooOol027oo00<007ooOol017oo00<007ooOol01goo00<007ooOol017oo0P0027oo00<007ooOol0
1Goo00<007ooOol01Woo00<007ooOol01Goo00<007ooOol01goo00<007ooOol017oo00<007ooOol0
1goo00<007ooOol017oo00<007ooOol01goo00<007ooOol01Goo00<007ooOol0EWoo0`000Woo00D0
07oo001oo`0000Ioo`03001oogoo009oo`8000=oo`8000Eoo`05001oogooOol00003Ool00`00Ool0
001LOol001eoo`03001oogoo00Aoo`03001oogoo00Qoo`03001oogoo00Aoo`03001oogoo00Moo`03
001oogoo00Aoo`03001oogoo00Moo`03001oogoo00Aoo`03001oogoo00Moo`03001oogoo00Aoo`80
00Qoo`03001oogoo00Eoo`03001oogoo00Ioo`03001oogoo00Eoo`03001oogoo00Moo`03001oogoo
00Aoo`03001oogoo00Moo`03001oogoo00Aoo`03001oogoo00Moo`03001oogoo00Eoo`03001oogoo
05]oo`06001oo`00001oo`001Goo00@007ooOomoo`8000Aoo`03001oogoo00Aoo`05001oogooOol0
0003Ool00`00Ool0001LOol001eoo`03001oogoo00Aoo`03001oogoo00Moo`03001oogoo00Eoo`03
001oogoo00Moo`03001oogoo00Aoo`03001oogoo00Moo`03001oogoo00Aoo`03001oogoo00Ioo`03
001oogoo00Eoo`8000Qoo`03001oogoo00Eoo`03001oogoo00Ioo`03001oogoo00Eoo`03001oogoo
00Moo`03001oogoo00Aoo`03001oogoo00Moo`03001oogoo00Aoo`03001oogoo00Moo`03001oogoo
00Eoo`03001oogoo05]oo`06001oo`00001oo`0017oo00<007oo00000Woo0P0017oo00<007ooOol0
17oo00D007ooOomoo`0000=oo`03001oo`0005aoo`007Goo00<007ooOol017oo00<007ooOol01goo
00<007ooOol01Goo00<007ooOol01goo00<007ooOol017oo00<007ooOol01goo00<007ooOol017oo
00<007ooOol01Woo00<007ooOol01Goo0P0027oo00<007ooOol01Goo00<007ooOol01Woo00<007oo
Ool01Goo00<007ooOol01goo00<007ooOol017oo00<007ooOol01goo00<007ooOol017oo00<007oo
Ool01goo00<007ooOol01Goo00<007ooOol0G7oo0P000goo00<007ooOol00Woo00@007ooOomoo`<0
00=oo`8000Eoo`05001oogooOol00003Ool00`00Ool0001LOol0015oo`D0009oo`03001oogoo009o
o`03001oogoo00Aoo`03001oogoo00Moo`03001oogoo00Eoo`03001oogoo00Ioo`03001oo`0000Eo
o`03001oogoo00Moo`03001oogoo00Aoo`03001oogoo00Ioo`03001oogoo00Eoo`<000Moo`03001o
ogoo00Eoo`03001oogoo00Ioo`03001oogoo00Eoo`03001oogoo00Ioo`8000Ioo`03001oogoo00Mo
o`03001oogoo00Aoo`03001oogoo00Moo`03001oogoo00H00003Ool007oo05aoo`05001oogooOol0
0009Ool00`00Oomoo`02Ool00`00Oomoo`04Ool01@00Oomoogoo00000goo00<007oo0000G7oo000C
Ool01`00Oomoogoo001oo`0000=oo`03001oogoo00Aoo`03001oogoo00Moo`03001oogoo00Eoo`03
001oogoo00Ioo`800003Ool007oo00=oo`03001oogoo00Moo`03001oogoo00Aoo`03001oogoo00Io
o`03001oogoo00Eoo`8000Qoo`03001oogoo00Eoo`03001oogoo00Ioo`03001oogoo00Eoo`03001o
ogoo00Eoo`03001oo`0000Ioo`03001oogoo00Moo`03001oogoo00Aoo`03001oogoo00Moo`03001o
ogoo009oo`03001oogoo00800003Ool007oo01ioo`D0009oo`03001oogoo025oo`03001oogoo00mo
o`05001oogooOol00009Ool00`00Oomoo`02Ool00`00Oomoo`04Ool01@00Oomoogoo00000goo00<0
07oo000057oo00<007ooOol087oo1@000Woo00<007ooOol06goo000=Ool30003Ool01`00Oomoogoo
001oo`0000=oo`03001oogoo00Aoo`03001oogoo00Moo`03001oogoo00Eoo`03001oogoo009oo`<0
0005Ool007ooOol00004Ool00`00Oomoo`07Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomo
o`05Ool20008Ool00`00Oomoo`05Ool00`00Oomoo`06Ool00`00Oomoo`05Ool00`00Oomoo`07Ool0
0`00Oomoo`04Ool00`00Oomoo`07Ool00`00Oomoo`04Ool00`00Oomoo`07Ool00`00Oomoo`02Ool0
0`00Oomoo`0200000goo001oo`0POol01`00Oomoogoo001oo`00025oo`03001oo`0000moo`03001o
ogoo009oo`03001oogoo00Moo`03001oogoo009oo`8000Eoo`05001oogooOol00003Ool01000Oomo
o`004Woo00<007oo00008goo00L007ooOomoo`00Ool0000LOol001=oo`07001oogooOol007oo0000
0goo00<007ooOol017oo00<007ooOol01goo00<007ooOol01Goo00<007ooOol01Woo0`001Goo00<0
07ooOol01goo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol01Goo0P0027oo00<007ooOol0
1Goo00<007ooOol01Woo00<007ooOol01Goo00<007ooOol01Goo0P001goo00<007ooOol01goo00<0
07ooOol017oo00<007ooOol01goo00<007ooOol00Woo00<007ooOol00P0000=oo`00Ool06Woo0`00
0goo00L007ooOomoo`00Ool0000LOol30004Ool00`00Oomoo`0=Ool00`00Oomoo`02Ool00`00Oomo
o`07Ool00`00Oomoo`02Ool20005Ool01@00Oomoogoo00000goo00@007ooOol001Aoo`03001oogoo
025oo`07001oogooOol007oo000077oo000COol01`00Oomoogoo001oo`0000=oo`03001oogoo00Eo
o`03001oogoo00Ioo`03001oogoo00Eoo`03001oogoo00Ioo`8000Ioo`03001oogoo00Moo`03001o
ogoo00Eoo`03001oogoo00Eoo`03001oogoo00Eoo`8000Qoo`03001oogoo00Eoo`03001oogoo00Io
o`03001oogoo00Eoo`03001oogoo00Eoo`8000Moo`03001oogoo00Moo`03001oogoo00Aoo`03001o
ogoo00Moo`03001oogoo009oo`03001oogoo00800003Ool007oo021oo`07001oogooOol007oo0000
8Goo0P0047oo00<007ooOol00goo00<007ooOol01Woo00<007ooOol00Woo0P001Goo00D007ooOomo
o`0000=oo`04001oogoo000BOol2000TOol01`00Oomoogoo001oo`0001aoo`004Woo0P0017oo00<0
07ooOol00Woo00<007ooOol01Goo00<007ooOol01Woo00<007ooOol01Goo00<007ooOol01Woo1000
17oo00<007ooOol01goo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol01Goo0`001goo00<0
07ooOol01Goo00<007ooOol01Woo00<007ooOol01Goo00<007ooOol01Goo0`001goo00<007ooOol0
1Woo00<007ooOol01Goo00<007ooOol01Woo00@007ooOomoo`80009oo`03001oo`00029oo`07001o
ogooOol007oo00008Goo00<007ooOol03goo00<007ooOol00goo00<007ooOol01Woo00<007ooOol0
0Woo0P0017oo00<007ooOol00Woo00@007ooOol000=oo`03001oogoo00=oo`03001oogoo00Yoo`03
001oogoo02=oo`07001oogooOol007oo000077oo000MOol00`00Oomoo`05Ool00`00Oomoo`06Ool0
0`00Oomoo`05Ool00`00Oomoo`06Ool00`00Oomoo`05Ool00`00Oomoo`07Ool00`00Oomoo`05Ool0
0`00Oomoo`05Ool00`00Oomoo`05Ool20008Ool00`00Oomoo`05Ool00`00Oomoo`06Ool00`00Oomo
o`05Ool00`00Oomoo`06Ool00`00Oomoo`06Ool00`00Oomoo`06Ool00`00Oomoo`05Ool00`00Oomo
o`05Ool00`00Oomoo`06Ool00`00Oomoo`0QOol20004Ool00`00Oomoo`0POol3000?Ool00`00Oomo
o`03Ool00`00Oomoo`06Ool00`00Oomoo`02Ool20004Ool00`00Oomoo`02Ool01000Oomoo`000goo
00<007ooOol00Woo0P0037oo0`008Woo0P0017oo00<007ooOol06goo000MOol00`00Oomoo`05Ool0
0`00Oomoo`06Ool00`00Oomoo`05Ool00`00Oomoo`06Ool00`00Oomoo`05Ool00`00Oomoo`07Ool0
0`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`05Ool20008Ool00`00Oomoo`05Ool00`00Oomo
o`06Ool00`00Oomoo`05Ool00`00Oomoo`06Ool00`00Oomoo`06Ool00`00Oomoo`06Ool00`00Oomo
o`05Ool00`00Oomoo`05Ool00`00Oomoo`06Ool00`00Oomoo`1LOol00`00Oomoo`03Ool00`00Oomo
o`05Ool00`00Oomoo`03Ool20004Ool00`00Oomoo`02Ool01000Oomoo`000goo00<007ooOol00Woo
00<007oo0000E7oo000MOol00`00Oomoo`05Ool00`00Oomoo`06Ool00`00Oomoo`05Ool00`00Oomo
o`06Ool00`00Oomoo`05Ool00`00Oomoo`07Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomo
o`05Ool20008Ool00`00Oomoo`05Ool00`00Oomoo`06Ool00`00Oomoo`05Ool00`00Oomoo`06Ool0
0`00Oomoo`06Ool00`00Oomoo`06Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`06Ool0
0`00Oomoo`1>Ool3000;Ool00`00Oomoo`03Ool00`00Oomoo`05Ool00`00Oomoo`03Ool20004Ool0
0`00Oomoo`02Ool01000Oomoo`000goo00D007ooOomoo`00009oo`03001oogoo059oo`007Goo00<0
07ooOol01Goo00<007ooOol01Woo00<007ooOol01Goo00<007ooOol01Woo00<007ooOol01Goo00<0
07ooOol01Woo00<007ooOol01Woo00<007ooOol01Goo00<007ooOol01Goo0P001goo00<007ooOol0
1Woo00<007ooOol01Woo00<007ooOol01Goo00<007ooOol01Woo00<007ooOol01Woo00<007ooOol0
1Goo00<007ooOol01Woo00<007ooOol01Goo00<007ooOol01Woo00<007ooOol0CGoo00D007ooOomo
o`0000Yoo`03001oogoo00=oo`03001oogoo00Eoo`03001oogoo00=oo`8000Aoo`03001oogoo009o
o`04001oogoo0003Ool01@00Oomoogoo00000Woo00<007ooOol0DWoo000MOol00`00Oomoo`05Ool0
0`00Oomoo`06Ool00`00Oomoo`05Ool00`00Oomoo`06Ool00`00Oomoo`05Ool00`00Oomoo`06Ool0
0`00Oomoo`06Ool00`00Oomoo`05Ool00`00Oomoo`05Ool20007Ool00`00Oomoo`06Ool00`00Oomo
o`06Ool00`00Oomoo`05Ool00`00Oomoo`06Ool00`00Oomoo`06Ool00`00Oomoo`05Ool00`00Oomo
o`06Ool00`00Oomoo`05Ool00`00Oomoo`06Ool00`00Oomoo`1;Ool20005Ool00`00Oomoo`07Ool0
0`00Oomoo`03Ool00`00Oomoo`05Ool00`00Oomoo`03Ool20004Ool00`00Oomoo`02Ool01000Oomo
o`000goo00D007ooOomoo`00009oo`03001oogoo009oo`8004ioo`003goo]`004goo_@002goo000D
Ool00`00Oomoo`06Ool00`00Oomoo`05Ool00`00Oomoo`06Ool00`00Oomoo`06Ool00`00Oomoo`05
Ool00`00Oomoo`05Ool00`00Oomoo`06Ool00`00Oomoo`06Ool00`00Oomoo`05Ool00`00Oomoo`06
Ool00`00Oomoo`05Ool00`00Oomoo`06Ool00`00Oomoo`06Ool00`00Oomoo`05Ool00`00Oomoo`06
Ool00`00Oomoo`06Ool00`00Oomoo`05Ool00`00Oomoo`06Ool00`00Oomoo`05Ool00`00Oomoo`06
Ool00`00Oomoo`0JOol00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`05
Ool00`00Oomoo`04Ool00`00Ool000060007Ool00`00Ool00005Ool00`00Ool00004Ool01000Oomo
o`0017oo00<007oo00001Goo0P0017oo00<007oo00000Woo00<007ooOol00P000Woo00@007ooOomo
o`80009oo`06001oogoo001oo`000Woo00<007ooOol00Woo00<007ooOol017oo00<007ooOol01Goo
00<007ooOol01Goo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol017oo00<007ooOol01Goo
00<007ooOol03Woo000DOol00`00Oomoo`06Ool00`00Oomoo`05Ool00`00Oomoo`06Ool00`00Oomo
o`06Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`06Ool00`00Oomoo`06Ool00`00Oomo
o`05Ool00`00Oomoo`06Ool00`00Oomoo`05Ool00`00Oomoo`06Ool00`00Oomoo`06Ool00`00Oomo
o`05Ool00`00Oomoo`06Ool00`00Oomoo`06Ool00`00Oomoo`05Ool00`00Oomoo`06Ool00`00Oomo
o`05Ool00`00Oomoo`1MOol00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomo
o`03Ool20004Ool00`00Oomoo`02Ool01000Oomoo`000goo00D007ooOomoo`0000=oo`03001oo`00
055oo`0057oo00<007ooOol01Goo00<007ooOol01Woo00<007ooOol01Goo00<007ooOol01goo00<0
07ooOol01Goo00<007ooOol01Goo00<007ooOol01Woo00<007ooOol01Woo00<007ooOol01Goo00<0
07ooOol01Woo00<007ooOol01Goo00<007ooOol01Woo00<007ooOol01Goo00<007ooOol01Woo00<0
07ooOol01Woo00<007ooOol01Woo00<007ooOol01Goo00<007ooOol01Woo00<007ooOol01Goo00<0
07ooOol0GGoo00<007ooOol017oo00<007ooOol01Goo00<007ooOol017oo00<007ooOol00goo0P00
17oo00<007ooOol00Woo00@007ooOol000=oo`05001oogooOol00004Ool00`00Oomoo`1@Ool001Ao
o`03001oogoo00Eoo`03001oogoo00Ioo`03001oogoo00Eoo`03001oogoo00Moo`03001oogoo00Eo
o`03001oogoo00Ioo`03001oogoo00Eoo`03001oogoo00Ioo`03001oogoo00Eoo`03001oogoo00Io
o`03001oogoo00Eoo`03001oogoo00Ioo`03001oogoo00Eoo`03001oogoo00Moo`03001oogoo00Eo
o`03001oogoo00Ioo`03001oogoo00Eoo`03001oogoo00Ioo`03001oogoo00Eoo`03001oogoo05io
o`03001oogoo009oo`03001oogoo00Ioo`03001oogoo00Aoo`03001oogoo00=oo`8000Aoo`03001o
ogoo009oo`04001oogoo0004Ool00`00Ool0001HOol001Aoo`03001oogoo00Eoo`03001oogoo00Io
o`03001oogoo00Eoo`03001oogoo00Moo`03001oogoo00Eoo`03001oogoo00Ioo`03001oogoo00Eo
o`03001oogoo00Ioo`03001oogoo00Eoo`03001oogoo00Ioo`8000Ioo`03001oogoo00Moo`03001o
ogoo00Aoo`03001oogoo00Moo`03001oogoo00Eoo`03001oogoo00Ioo`03001oogoo00Eoo`03001o
ogoo00Ioo`03001oogoo00Eoo`03001oogoo05ioo`03001oogoo009oo`03001oogoo00Ioo`03001o
ogoo00Aoo`03001oogoo00=oo`8000Aoo`03001oogoo009oo`04001oogoo0004Ool00`00Ool0001H
Ool001Aoo`03001oogoo00Eoo`03001oogoo00Ioo`03001oogoo00Eoo`03001oogoo00Moo`03001o
ogoo00Aoo`03001oogoo00Moo`03001oogoo00Eoo`03001oogoo00Ioo`03001oogoo00Eoo`03001o
ogoo00Ioo`03001oogoo00Eoo`03001oogoo00Moo`03001oogoo00Aoo`03001oogoo00Moo`03001o
ogoo00Eoo`03001oogoo00Ioo`03001oogoo00Eoo`03001oogoo00Ioo`03001oogoo00Eoo`03001o
ogoo05moo`04001oogoo0009Ool00`00Oomoo`04Ool00`00Oomoo`03Ool20004Ool00`00Oomoo`02
Ool01000Oomoo`0017oo00<007oo0000F7oo000DOol00`00Oomoo`05Ool00`00Oomoo`06Ool00`00
Oomoo`05Ool00`00Oomoo`07Ool00`00Oomoo`04Ool00`00Oomoo`07Ool00`00Oomoo`05Ool00`00
Oomoo`06Ool00`00Oomoo`05Ool00`00Oomoo`06Ool00`00Oomoo`05Ool00`00Oomoo`07Ool00`00
Oomoo`04Ool00`00Oomoo`07Ool00`00Oomoo`05Ool00`00Oomoo`06Ool00`00Oomoo`05Ool00`00
Oomoo`06Ool00`00Oomoo`05Ool00`00Oomoo`1POol00`00Ool0000:Ool00`00Oomoo`03Ool00`00
Oomoo`03Ool20004Ool00`00Oomoo`02Ool01000Oomoo`0017oo00<007oo0000F7oo000DOol00`00
Oomoo`05Ool00`00Oomoo`06Ool00`00Oomoo`05Ool00`00Oomoo`07Ool00`00Oomoo`04Ool00`00
Oomoo`07Ool00`00Oomoo`05Ool00`00Oomoo`06Ool00`00Oomoo`05Ool00`00Oomoo`06Ool00`00
Oomoo`05Ool00`00Oomoo`07Ool00`00Oomoo`04Ool00`00Oomoo`07Ool00`00Oomoo`04Ool00`00
Oomoo`07Ool00`00Oomoo`05Ool00`00Oomoo`06Ool00`00Oomoo`05Ool00`00Oomoo`1POol2000;
Ool00`00Oomoo`03Ool00`00Oomoo`03Ool20004Ool00`00Oomoo`02Ool01000Oomoo`0017oo00<0
07oo0000F7oo000DOol00`00Oomoo`05Ool00`00Oomoo`06Ool00`00Oomoo`05Ool00`00Oomoo`07
Ool00`00Oomoo`04Ool00`00Oomoo`07Ool00`00Oomoo`05Ool00`00Oomoo`06Ool00`00Oomoo`05
Ool00`00Oomoo`06Ool00`00Oomoo`05Ool00`00Oomoo`07Ool00`00Oomoo`04Ool00`00Oomoo`07
Ool00`00Oomoo`04Ool00`00Oomoo`07Ool00`00Oomoo`05Ool00`00Oomoo`06Ool00`00Oomoo`05
Ool00`00Oomoo`1]Ool00`00Oomoo`02Ool00`00Oomoo`04Ool20004Ool00`00Oomoo`02Ool01000
Oomoo`0017oo00<007oo0000F7oo000DOol00`00Oomoo`05Ool00`00Oomoo`06Ool00`00Oomoo`05
Ool00`00Oomoo`07Ool00`00Oomoo`04Ool00`00Oomoo`07Ool00`00Oomoo`05Ool00`00Oomoo`06
Ool00`00Oomoo`05Ool00`00Oomoo`06Ool20006Ool00`00Oomoo`07Ool00`00Oomoo`04Ool00`00
Oomoo`07Ool00`00Oomoo`04Ool00`00Oomoo`07Ool00`00Oomoo`05Ool00`00Oomoo`06Ool00`00
Oomoo`05Ool00`00Oomoo`1]Ool00`00Oomoo`02Ool00`00Oomoo`04Ool20004Ool00`00Oomoo`02
Ool01000Oomoo`0017oo00<007oo0000F7oo000DOol00`00Oomoo`05Ool00`00Oomoo`07Ool00`00
Oomoo`04Ool00`00Oomoo`07Ool00`00Oomoo`04Ool00`00Oomoo`07Ool00`00Oomoo`05Ool00`00
Oomoo`06Ool00`00Oomoo`05Ool00`00Oomoo`06Ool00`00Oomoo`05Ool00`00Oomoo`07Ool00`00
Oomoo`04Ool00`00Oomoo`07Ool00`00Oomoo`04Ool00`00Oomoo`07Ool00`00Oomoo`05Ool00`00
Oomoo`06Ool00`00Oomoo`05Ool00`00Oomoo`1]Ool00`00Oomoo`02Ool00`00Oomoo`04Ool20004
Ool00`00Oomoo`02Ool01000Oomoo`0017oo0P00FGoo000DOol00`00Oomoo`05Ool00`00Oomoo`07
Ool00`00Oomoo`04Ool00`00Oomoo`07Ool00`00Oomoo`04Ool00`00Oomoo`07Ool00`00Oomoo`05
Ool00`00Oomoo`06Ool00`00Oomoo`05Ool00`00Oomoo`06Ool00`00Oomoo`05Ool00`00Oomoo`07
Ool00`00Oomoo`04Ool00`00Oomoo`07Ool00`00Oomoo`04Ool00`00Oomoo`08Ool00`00Oomoo`04
Ool00`00Oomoo`06Ool00`00Oomoo`05Ool00`00Oomoo`1]Ool00`00Oomoo`02Ool00`00Oomoo`04
Ool20004Ool00`00Oomoo`02Ool01000Oomoo`001Goo00<007ooOol0Egoo000DOol00`00Oomoo`05
Ool00`00Oomoo`07Ool00`00Oomoo`04Ool00`00Oomoo`07Ool00`00Oomoo`04Ool00`00Oomoo`07
Ool00`00Oomoo`05Ool00`00Oomoo`06Ool00`00Oomoo`05Ool00`00Oomoo`06Ool00`00Oomoo`05
Ool00`00Oomoo`07Ool00`00Oomoo`04Ool00`00Oomoo`07Ool00`00Oomoo`04Ool00`00Oomoo`08
Ool00`00Oomoo`04Ool00`00Oomoo`06Ool00`00Oomoo`04Ool00`00Oomoo`1VOol00`00Oomoo`02
Ool00`00Oomoo`04000017oo001oo`0017oo0P0017oo00<007ooOol00Woo00@007ooOol000Eoo`03
001oogoo05Moo`0057oo00<007ooOol01Goo00<007ooOol01goo00<007ooOol017oo00<007ooOol0
1goo00<007ooOol017oo00<007ooOol01goo00<007ooOol01Goo00<007ooOol01Woo00<007ooOol0
17oo00<007ooOol01goo00<007ooOol017oo00<007ooOol027oo00<007ooOol017oo00<007ooOol0
1goo00<007ooOol017oo00<007ooOol027oo00<007ooOol017oo00<007ooOol01Woo00<007ooOol0
17oo00<007ooOol0IGoo00<007oo00001Woo0P000goo0P0000=oo`00Ool00Woo0P0017oo00<007oo
Ool00Woo00@007ooOol000Eoo`03001oogoo05Moo`0057oo00<007ooOol01Goo00<007ooOol01goo
00<007ooOol017oo00<007ooOol01goo00<007ooOol017oo00<007ooOol01goo00<007ooOol01Goo
00<007ooOol01Woo00<007ooOol017oo00<007ooOol01goo00<007ooOol017oo00<007ooOol027oo
00<007ooOol017oo00<007ooOol01goo00<007ooOol017oo00<007ooOol027oo00<007ooOol00goo
00<007ooOol01goo00<007ooOol017oo00<007ooOol0IGoo00<007oo00001goo0P000Woo00@007oo
Ool000=oo`8000Aoo`03001oogoo009oo`04001oogoo001OOol001Aoo`03001oogoo00Eoo`03001o
ogoo00Moo`03001oogoo00Aoo`03001oogoo00Moo`03001oogoo00Aoo`03001oogoo00Moo`03001o
ogoo00Aoo`03001oogoo00Moo`03001oogoo00Aoo`03001oogoo00Moo`8000Eoo`03001oogoo00Qo
o`03001oogoo00Aoo`03001oogoo00Moo`03001oogoo00Aoo`03001oogoo00Qoo`03001oogoo00=o
o`03001oogoo00Moo`03001oogoo00Aoo`03001oogoo06Eoo`03001oo`0000Moo`80009oo`<000Ao
o`03001oo`0000=oo`03001oogoo009oo`04001oogoo001OOol001Aoo`03001oogoo00Eoo`03001o
ogoo00Moo`03001oogoo00Aoo`03001oogoo00Qoo`03001oogoo00=oo`03001oogoo00Moo`03001o
ogoo00Aoo`03001oogoo00Moo`03001oogoo00Aoo`03001oogoo00Moo`03001oogoo00Aoo`03001o
ogoo00Qoo`03001oogoo00Aoo`03001oogoo00Moo`03001oogoo00Aoo`03001oogoo00Qoo`03001o
ogoo00=oo`03001oogoo00Qoo`03001oogoo00=oo`03001oogoo06Eoo`03001oo`0000Moo`04001o
o`00Ool20005Ool00`00Ool00003Ool00`00Oomoo`03Ool00`00Ool0001OOol001Aoo`03001oogoo
00Eoo`03001oogoo00Moo`03001oogoo00=oo`03001oogoo00Uoo`03001oogoo00=oo`03001oogoo
00Moo`03001oogoo00Aoo`03001oogoo00Moo`03001oogoo00Aoo`03001oogoo00Moo`8000Eoo`03
001oogoo00Qoo`03001oogoo00Aoo`03001oogoo00Moo`03001oogoo00Aoo`03001oogoo00Qoo`03
001oogoo00=oo`03001oogoo00Qoo`03001oogoo00=oo`03001oogoo06Ioo`03001oogoo00Ioo`80
009oo`@000=oo`<000=oo`03001oogoo00=oo`80061oo`0057oo00<007ooOol01Goo00<007ooOol0
1goo00<007ooOol00goo00<007ooOol02Goo00<007ooOol00goo00<007ooOol01goo00<007ooOol0
17oo00<007ooOol01goo00<007ooOol017oo00<007ooOol01goo0P001Goo00<007ooOol027oo00<0
07ooOol017oo00<007ooOol01goo00<007ooOol017oo00<007ooOol027oo00<007ooOol00goo00<0
07ooOol027oo00<007ooOol00goo00<007ooOol0Kgoo00@007ooOol000Moo`03001oo`0000=oo`03
001oogoo00=oo`80061oo`0057oo00<007ooOol01Goo00<007ooOol01goo00<007ooOol00goo00<0
07ooOol02Goo00<007ooOol00goo00<007ooOol01goo00<007ooOol017oo00<007ooOol01goo00<0
07ooOol017oo00<007ooOol01goo0P001Goo00<007ooOol027oo00<007ooOol00goo00<007ooOol0
2Goo00<007ooOol00goo00<007ooOol027oo00<007ooOol00goo00<007ooOol027oo00<007ooOol0
0goo00<007ooOol0Kgoo00@007ooOol000Moo`03001oo`0000=oo`03001oogoo00=oo`80061oo`00
57oo00<007ooOol017oo00<007ooOol027oo00<007ooOol00goo00<007ooOol02Goo00<007ooOol0
0goo00<007ooOol027oo00<007ooOol00goo00<007ooOol01goo00<007ooOol017oo00<007ooOol0
1goo0P001Goo00<007ooOol027oo00<007ooOol00goo00<007ooOol02Goo00<007ooOol00goo00<0
07ooOol027oo00<007ooOol00goo00<007ooOol027oo00<007ooOol00goo00<007ooOol0Kgoo00@0
07ooOol000Moo`03001oo`0000=oo`03001oogoo00=oo`80061oo`0057oo00<007ooOol017oo00<0
07ooOol027oo00<007ooOol00goo00<007ooOol02Goo00<007ooOol00goo00<007ooOol027oo00<0
07ooOol00goo00<007ooOol01goo00<007ooOol017oo00<007ooOol01goo0P001Goo00<007ooOol0
2Goo00<007ooOol00Woo00<007ooOol02Goo00<007ooOol00goo00<007ooOol027oo00<007ooOol0
0goo00<007ooOol027oo00<007ooOol00goo00<007ooOol0L7oo00<007oo00001goo0`000goo00<0
07ooOol00goo0P00H7oo000EOol00`00Oomoo`03Ool00`00Oomoo`08Ool00`00Oomoo`03Ool00`00
Oomoo`09Ool00`00Oomoo`03Ool00`00Oomoo`08Ool00`00Oomoo`03Ool00`00Oomoo`08Ool00`00
Oomoo`03Ool00`00Oomoo`07Ool20005Ool00`00Oomoo`09Ool00`00Oomoo`02Ool00`00Oomoo`09
Ool00`00Oomoo`03Ool00`00Oomoo`08Ool00`00Oomoo`03Ool00`00Oomoo`08Ool00`00Oomoo`03
Ool00`00Oomoo`1`Ool00`00Ool00007Ool00`00Ool00003Ool00`00Oomoo`03Ool2001POol001Eo
o`03001oogoo00=oo`03001oogoo00Qoo`03001oogoo00=oo`03001oogoo00Uoo`03001oogoo009o
o`03001oogoo00Uoo`03001oogoo00=oo`03001oogoo00Qoo`8000Aoo`03001oogoo009oo`03001o
ogoo009oo`8000Eoo`03001oogoo00Uoo`03001oogoo009oo`03001oogoo00Uoo`03001oogoo009o
o`03001oogoo00Uoo`03001oogoo00=oo`03001oogoo00Qoo`03001oogoo00=oo`03001oogoo071o
o`8000Qoo`03001oo`0000=oo`03001oogoo00=oo`80061oo`005Goo00<007ooOol00goo00<007oo
Ool027oo00<007ooOol00goo00<007ooOol02Goo00<007ooOol00Woo00<007ooOol02Goo00<007oo
Ool00goo00<007ooOol027oo00<007oo00000goo00L007ooOomoo`00Ool00003Ool20005Ool00`00
Oomoo`09Ool00`00Oomoo`02Ool00`00Oomoo`09Ool00`00Oomoo`02Ool00`00Oomoo`09Ool00`00
Oomoo`03Ool00`00Oomoo`08Ool00`00Oomoo`03Ool00`00Oomoo`1aOol00`00Oomoo`06Ool30003
Ool00`00Oomoo`03Ool2001POol001Eoo`03001oogoo00=oo`03001oogoo00Qoo`03001oogoo00=o
o`03001oogoo00Uoo`03001oogoo009oo`03001oogoo00Uoo`03001oogoo00=oo`03001oogoo00Qo
o`03001oo`0000=oo`03001oogoo00=oo`04001oogooOol20005Ool00`00Oomoo`09Ool00`00Oomo
o`02Ool00`00Oomoo`09Ool00`00Oomoo`02Ool00`00Oomoo`09Ool00`00Oomoo`03Ool00`00Oomo
o`08Ool00`00Oomoo`03Ool00`00Oomoo`1jOol00`00Ool00003Ool00`00Oomoo`03Ool2001POol0
01Eoo`03001oogoo00=oo`03001oogoo00Qoo`03001oogoo00=oo`03001oogoo00Uoo`03001oogoo
009oo`03001oogoo00Uoo`03001oogoo00=oo`03001oogoo00Qoo`03001oo`0000=oo`04001oogoo
Ool20004Ool20005Ool00`00Oomoo`09Ool00`00Oomoo`02Ool00`00Oomoo`09Ool00`00Oomoo`02
Ool00`00Oomoo`09Ool00`00Oomoo`03Ool00`00Oomoo`08Ool00`00Oomoo`03Ool00`00Oomoo`1j
Ool00`00Ool00002Ool00`00Oomoo`04Ool2001POol001Eoo`03001oogoo00=oo`03001oogoo00Uo
o`03001oogoo009oo`03001oogoo00Uoo`03001oogoo009oo`03001oogoo00Uoo`03001oogoo00=o
o`03001oogoo00Qoo`03001oo`0000=oo`05001oogooOol00005Ool20005Ool00`00Oomoo`09Ool0
0`00Oomoo`02Ool00`00Oomoo`09Ool00`00Oomoo`02Ool00`00Oomoo`09Ool00`00Oomoo`03Ool0
0`00Oomoo`08Ool00`00Oomoo`03Ool00`00Oomoo`1jOol30002Ool00`00Oomoo`04Ool2001POol0
01Eoo`03001oogoo00=oo`03001oogoo00Uoo`03001oogoo009oo`03001oogoo00Uoo`03001oogoo
009oo`03001oogoo00Uoo`03001oogoo00=oo`03001oogoo00Qoo`8000Aoo`04001oogooOol30003
Ool20005Ool00`00Oomoo`09Ool00`00Oomoo`02Ool00`00Oomoo`09Ool00`00Oomoo`02Ool00`00
Oomoo`0:Ool00`00Oomoo`02Ool00`00Oomoo`08Ool00`00Oomoo`02Ool00`00Oomoo`1/Ool00`00
Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Ool00002Ool00`00Oomoo`04Ool2001P
Ool001Eoo`03001oogoo00=oo`03001oogoo00Uoo`03001oogoo009oo`03001oogoo00Uoo`03001o
ogoo009oo`03001oogoo00Uoo`03001oogoo00=oo`03001oogoo00Qoo`03001oogoo00=oo`03001o
ogoo00Moo`8000Eoo`03001oogoo00Uoo`03001oogoo009oo`03001oogoo00Uoo`03001oogoo009o
o`03001oogoo00Yoo`03001oogoo009oo`03001oogoo00Qoo`03001oogoo009oo`03001oogoo06]o
o`03001oo`0000Moo`03001oo`0000=oo`03001oo`00009oo`03001oogoo00Aoo`80061oo`005Goo
00<007ooOol00goo00<007ooOol02Goo00<007ooOol00Woo00<007ooOol02Goo00<007ooOol00Woo
00<007ooOol02Goo00<007ooOol00goo00<007ooOol027oo00<007ooOol00goo00<007ooOol01goo
0P001Goo00<007ooOol02Goo00<007ooOol00Woo00<007ooOol02Goo00<007ooOol00Woo00<007oo
Ool02Woo00D007ooOomoo`0000]oo`03001oogoo009oo`03001oogoo06]oo`03001oo`0000Uoo`04
001oogooOol30002Ool00`00Oomoo`04Ool2001POol001Eoo`03001oogoo00=oo`03001oogoo00Uo
o`03001oogoo009oo`03001oogoo00Uoo`03001oogoo009oo`03001oogoo00Uoo`03001oogoo009o
o`03001oogoo00Uoo`03001oogoo00=oo`03001oogoo00Moo`8000Eoo`03001oogoo00Uoo`03001o
ogoo009oo`03001oogoo00Uoo`03001oogoo009oo`03001oogoo00Yoo`05001oogooOol0000<Ool0
1@00Oomoogoo0000KGoo00<007oo00001goo0P0017oo00<007oo00000Woo00<007ooOol017oo0P00
H7oo000EOol00`00Oomoo`03Ool00`00Oomoo`09Ool01@00Oomoogoo000037oo00<007ooOol00Woo
00<007ooOol02Woo00D007ooOomoo`0000]oo`03001oogoo00=oo`03001oogoo00Moo`03001oo`00
00Aoo`03001oogoo00Uoo`03001oogoo009oo`03001oogoo00Uoo`03001oogoo009oo`03001oogoo
00Yoo`05001oogooOol0000<Ool01@00Oomoogoo0000KGoo00<007oo00001goo00<007ooOol00goo
00<007oo00000Woo00<007ooOol017oo0P00H7oo000EOol00`00Oomoo`03Ool00`00Oomoo`09Ool0
1@00Oomoogoo000037oo00<007ooOol00Woo00<007ooOol02Woo00D007ooOomoo`0000aoo`03001o
ogoo009oo`03001oogoo00Moo`03001oo`0000Aoo`03001oogoo00Uoo`03001oogoo009oo`03001o
ogoo00Uoo`03001oogoo009oo`03001oogoo00Yoo`05001oogooOol0000<Ool01@00Oomoogoo0000
KWoo00<007ooOol01Woo0`000goo0`000Woo00<007ooOol017oo0P00H7oo000EOol00`00Oomoo`03
Ool00`00Oomoo`09Ool01@00Oomoogoo000037oo00<007ooOol00Woo00<007ooOol02Woo00D007oo
Oomoo`0000aoo`03001oogoo009oo`03001oogoo00Moo`03001oo`0000Aoo`03001oogoo00Uoo`05
001oogooOol0000<Ool00`00Oomoo`02Ool00`00Oomoo`0:Ool01@00Oomoogoo000037oo00D007oo
Oomoo`0007eoo`03001oo`00009oo`03001oogoo00Aoo`80061oo`005Woo00D007ooOomoo`0000ao
o`05001oogooOol0000<Ool00`00Oomoo`02Ool00`00Oomoo`0:Ool01@00Oomoogoo000037oo00<0
07ooOol00Woo00<007ooOol01goo00<007oo000017oo00<007ooOol02Goo00D007ooOomoo`0000ao
o`03001oogoo009oo`03001oogoo00Yoo`05001oogooOol0000<Ool01@00Oomoogoo0000OGoo00<0
07oo00000Woo00<007ooOol017oo0P00H7oo000FOol01@00Oomoogoo000037oo00D007ooOomoo`00
00aoo`03001oogoo009oo`03001oogoo00Yoo`05001oogooOol0000<Ool01@00Oomoogoo00002Woo
0`0017oo00<007ooOol02Goo00D007ooOomoo`0000aoo`03001oogoo009oo`03001oogoo00Yoo`05
001oogooOol0000<Ool01@00Oomoogoo0000OGoo0`000Woo00<007ooOol017oo0P00H7oo000FOol0
1@00Oomoogoo000037oo00D007ooOomoo`0000aoo`03001oogoo009oo`03001oogoo00Yoo`05001o
ogooOol0000<Ool01@00Oomoogoo00002Woo00<007oo000017oo00<007ooOol02Goo00D007ooOomo
o`0000aoo`03001oogoo009oo`03001oogoo00Yoo`05001oogooOol0000<Ool01@00Oomoogoo0000
OGoo00H007ooOol007oo0007Ool00`00Oomoo`1NOol001Ioo`05001oogooOol0000<Ool01@00Oomo
ogoo000037oo00D007ooOomoo`0000eoo`05001oogooOol0000<Ool01@00Oomoogoo00002Woo00<0
07oo000017oo00<007ooOol02Goo00D007ooOomoo`0000eoo`05001oogooOol0000<Ool01@00Oomo
ogoo000037oo00D007ooOomoo`0007eoo`06001oogoo001oo`001goo00<007ooOol0GWoo000FOol0
1@00Oomoogoo000037oo00D007ooOomoo`0000aoo`05001oogooOol0000=Ool01@00Oomoogoo0000
37oo00D007ooOomoo`0000Yoo`03001oo`0000=oo`03001oogoo00]oo`04001oogoo000=Ool01@00
Oomoogoo000037oo00D007ooOomoo`0000aoo`05001oogooOol0001mOol2000017oo001oo`001goo
00<007ooOol0GWoo000FOol01@00Oomoogoo000037oo00D007ooOomoo`0000aoo`05001oogooOol0
000=Ool01@00Oomoogoo000037oo00D007ooOomoo`0000Yoo`03001oo`0000=oo`03001oogoo00]o
o`04001oogoo000=Ool01@00Oomoogoo000037oo00D007ooOomoo`0000eoo`04001oogoo001mOol0
1P00Oomoo`00Ool000Moo`03001oogoo05ioo`005Woo00D007ooOomoo`0000aoo`05001oogooOol0
000=Ool01000Oomoo`003Goo00D007ooOomoo`0000aoo`05001oogooOol0000:Ool200001Goo001o
ogoo00003Goo00@007ooOol000eoo`05001oogooOol0000<Ool01@00Oomoogoo00003Goo00@007oo
Ool007eoo`06001oogoo001oo`001goo00<007ooOol0GWoo000FOol01@00Oomoogoo000037oo00D0
07ooOomoo`0000eoo`04001oogoo000=Ool01000Oomoo`003Goo00D007ooOomoo`0000Yoo`04001o
ogoo0002Ool00`00Oomoo`0;Ool01000Oomoo`003Goo00D007ooOomoo`0000aoo`05001oogooOol0
000=Ool01000Oomoo`00OGoo0P0000Aoo`00Ool000Moo`03001oogoo05ioo`005Woo00@007ooOol0
00ioo`04001oogoo000=Ool01000Oomoo`003Goo00@007ooOol000eoo`05001oogooOol0000:Ool0
1000Oomoo`000Woo00<007ooOol02goo00@007ooOol000eoo`05001oogooOol0000=Ool01000Oomo
o`003Goo00@007ooOol006Uoo`03001oogoo009oo`03001oogoo009oo`03001oogoo009oo`03001o
ogoo009oo`06001oogoo001oo`00J7oo000GOol00`00Ool0000>Ool01000Oomoo`003Goo00@007oo
Ool000eoo`04001oogoo000>Ool00`00Ool0000;Ool01000Oomoo`000Woo00<007ooOol02goo00@0
07ooOol000eoo`04001oogoo000>Ool01000Oomoo`003Goo00@007ooOol006Qoo`03001oo`0000Qo
o`07001oogooOol007oo00000goo00H007ooOol007oo001XOol001Moo`03001oo`0000ioo`04001o
ogoo000=Ool01000Oomoo`003Goo00@007ooOol000ioo`03001oo`0000]oo`04001oogoo0002Ool0
0`00Oomoo`0;Ool01000Oomoo`003Goo00@007ooOol000ioo`03001oo`0000ioo`04001oogoo001X
Ool00`00Ool00008Ool00`00Oomoo`03Ool01000Oomoogoo0P0000Aoo`00Ool006Qoo`005goo00<0
07oo00003Woo00<007oo00003Woo00@007ooOol000eoo`04001oogoo000>Ool00`00Ool0000;Ool0
1P00Oomoo`00Ool000ioo`04001oogoo000=Ool01000Oomoo`003Woo00<007oo00003Woo00@007oo
Ool006Qoo`03001oo`0000Uoo`03001oogoo008000Aoo`06001oogoo001oo`00J7oo000GOol00`00
Ool0000>Ool00`00Ool0000>Ool01000Oomoo`003Goo00@007ooOol000ioo`03001oo`0000]oo`80
0004Ool007oo000>Ool00`00Ool0000?Ool00`00Ool0000>Ool00`00Ool0000>Ool01000Oomoo`00
J7oo00<007oo00001goo00<007oo00000Woo00<007ooOol00goo00H007ooOol007oo001XOol001Mo
o`03001oo`0000ioo`03001oo`0000ioo`04001oogoo000>Ool00`00Ool0000>Ool00`00Ool0000;
Ool01P00Oomoo`00Ool000ioo`03001oo`0000moo`03001oo`0000ioo`03001oo`0000ioo`03001o
o`0006Yoo`03001oogoo00Ioo`<0009oo`<000=oo`800003Ool0000006Uoo`005goo00<007oo0000
3Woo00<007oo00003Woo00<007oo00003goo00<007oo00003Woo00<007oo00002goo00H007ooOol0
07oo000?Ool2000?Ool00`00Ool0000>Ool00`00Ool0000>Ool00`00Ool0001nOol00`00Oomoo`02
001YOol001Moo`03001oo`0000ioo`03001oo`0000moo`8000moo`8000moo`03001oo`0000Aoo`D0
009oo`06001oogoo001oo`003goo0P003goo0P003goo00<007oo00003Woo00<007oo0000OWoo00<0
07ooOol00P00JGoo000GOol2000@Ool2000?Ool2000?Ool2000@Ool00`00Oomoo`05Ool00`00Oomo
o`02Ool01000Oomoogoo0P003goo0P003goo0P003goo0`003goo0P00OWoo0P000Woo00<007ooOol0
Igoo000HOol00`00Oomoo`0>Ool00`00Oomoo`0>Ool2000?Ool2000@Ool00`00Oomoo`05Ool00`00
Oomoo`02Ool20002Ool00`00Oomoo`0>Ool2000@Ool00`00Oomoo`0>Ool00`00Oomoo`0>Ool2001n
Ool01@00Oomoogoo0000JGoo001UOol00`00Oomoo`02Ool00`00Oomoo`36Ool01@00Oomoogoo0000
JGoo001UOol00`00Oomoo`02Ool00`00Oomoo`36Ool20002Ool00`00Oomoo`1WOol006Aoo`8000Ao
o`03001oogoo0<Ioo`03001oogoo06]oo`00ogoo=7oo00<007ooOol0Jgoo003oOoldOol00`00Oomo
o`1[Ool00?mooj9oo`00ogooXWoo0000\
\>"],
  ImageRangeCache->{{{0, 416.25}, {121.75, 0}} -> {-0.0564992, -0.0147182, 
  0.00507628, 0.00507628}, {{11.125, 198.688}, {118.813, 
  2.875}} -> {-12.3326, -1.14217, 0.115901, 0.0187529}, {{217.5, 405.063}, {
  118.813, 2.875}} -> {-39.58, -1.00809, 0.128758, 0.0164027}}],

Cell[TextData[{
  "It is well known that a periodic signal may be written as a series \
expansion of sinusoids (or equivalently complex exponentials). More generally \
a signal ",
  Cell[BoxData[
      \(TraditionalForm\`f(t)\)]],
  " may be expressed as the following superposition "
}], "Text"],

Cell[TextData[{
  "\t",
  Cell[BoxData[
      \(TraditionalForm\`f(t) = \ \[Sum]\+k\( a\_k\) \(\(\[Psi]\_k\)(t)\)\)]]
}], "NumberedEquation"],

Cell[TextData[{
  "where ",
  StyleBox["k",
    FontSlant->"Italic"],
  " is an integer index of the finite or infinite summation, ",
  Cell[BoxData[
      \(TraditionalForm\`a\_k\)]],
  " are the real (or complex) valued expansion coefficients and ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Psi]\_k\)(t)\)]],
  " are a set of real (or complex) functions of ",
  StyleBox["t ",
    FontSlant->"Italic"],
  "called the expansion functions. If the expansion (1) is unique, the set is \
called a ",
  StyleBox["basis",
    FontSlant->"Italic"],
  " for the class of signals under investigation. It is desirable to have an \
orthogonal basis, meaning"
}], "Text"],

Cell[TextData[{
  "\t",
  Cell[BoxData[
      FormBox[
        RowBox[{
        \(\[Integral]\ 
            \(\(\[Psi]\_k\)(t)\)\ \ \(\(\[Psi]\_l\)(t)\) \[DifferentialD]t\), 
          "  ", "=", " ", 
          RowBox[{"{", GridBox[{
                {\(0, \), \(k \[NotEqual] l\)},
                {\(1, \), \(k = l\)}
                }]}]}], TraditionalForm]]]
}], "NumberedEquation"],

Cell[TextData[{
  "then the coefficients can be calculated by the ",
  StyleBox["inner product",
    FontSlant->"Italic"],
  " "
}], "Text"],

Cell[TextData[{
  "\t",
  Cell[BoxData[
      \(TraditionalForm
      \`a\_k\  = \ 
        \[Integral]\(f(t)\)\ \(\(\[Psi]\_k\)(t)\)\ \ \[DifferentialD]t\)]]
}], "NumberedEquation"],

Cell[TextData[{
  "For a Fourier series, the orthogonal basis functions ",
  Cell[BoxData[
      \(TraditionalForm\`\(\ \(\[Psi]\_k\)(t)\)\)]],
  " are ",
  Cell[BoxData[
      \(TraditionalForm\`\[ExponentialE]\^\(\ j\ \ k\ \[Omega]\_0\ t\)\)]],
  ", with ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\_0\)]],
  " known as the fundamental frequency. For a Taylor series expansion ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Psi]\_k\)(t)\  = \ t\^k\)]],
  ".  "
}], "Text"],

Cell[CellGroupData[{

Cell["Problem 1", "Exercise"],

Cell[TextData[{
  "From Fourier theory it is well known that real and even functions ",
  Cell[BoxData[
      \(TraditionalForm\`f(t)\)]],
  " have a cosine expansion. Rewrite equations (1)-(3) using ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Psi]\_k\)(t)\  = \ cos(k\ \[Omega]\_0\ t)\)]],
  ". Prove the correctness of (2) and find the cosine coefficients of the \
following periodic pulse train:"
}], "ExerciseText"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.295918 0.136054 0.0147151 0.588604 [
[.02381 .00222 -6 -9 ]
[.02381 .00222 6 0 ]
[.15986 .00222 -6 -9 ]
[.15986 .00222 6 0 ]
[.43197 .00222 -3 -9 ]
[.43197 .00222 3 0 ]
[.56803 .00222 -3 -9 ]
[.56803 .00222 3 0 ]
[.70408 .00222 -3 -9 ]
[.70408 .00222 3 0 ]
[.84014 .00222 -3 -9 ]
[.84014 .00222 3 0 ]
[.97619 .00222 -3 -9 ]
[.97619 .00222 3 0 ]
[.28342 .13244 -18 -4.5 ]
[.28342 .13244 0 4.5 ]
[.28342 .25016 -18 -4.5 ]
[.28342 .25016 0 4.5 ]
[.28342 .36788 -18 -4.5 ]
[.28342 .36788 0 4.5 ]
[.28342 .4856 -18 -4.5 ]
[.28342 .4856 0 4.5 ]
[.28342 .60332 -6 -4.5 ]
[.28342 .60332 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.02381 .01472 m
.02381 .02097 L
s
[(-2)] .02381 .00222 0 1 Mshowa
.15986 .01472 m
.15986 .02097 L
s
[(-1)] .15986 .00222 0 1 Mshowa
.43197 .01472 m
.43197 .02097 L
s
[(1)] .43197 .00222 0 1 Mshowa
.56803 .01472 m
.56803 .02097 L
s
[(2)] .56803 .00222 0 1 Mshowa
.70408 .01472 m
.70408 .02097 L
s
[(3)] .70408 .00222 0 1 Mshowa
.84014 .01472 m
.84014 .02097 L
s
[(4)] .84014 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(5)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.05102 .01472 m
.05102 .01847 L
s
.07823 .01472 m
.07823 .01847 L
s
.10544 .01472 m
.10544 .01847 L
s
.13265 .01472 m
.13265 .01847 L
s
.18707 .01472 m
.18707 .01847 L
s
.21429 .01472 m
.21429 .01847 L
s
.2415 .01472 m
.2415 .01847 L
s
.26871 .01472 m
.26871 .01847 L
s
.32313 .01472 m
.32313 .01847 L
s
.35034 .01472 m
.35034 .01847 L
s
.37755 .01472 m
.37755 .01847 L
s
.40476 .01472 m
.40476 .01847 L
s
.45918 .01472 m
.45918 .01847 L
s
.48639 .01472 m
.48639 .01847 L
s
.51361 .01472 m
.51361 .01847 L
s
.54082 .01472 m
.54082 .01847 L
s
.59524 .01472 m
.59524 .01847 L
s
.62245 .01472 m
.62245 .01847 L
s
.64966 .01472 m
.64966 .01847 L
s
.67687 .01472 m
.67687 .01847 L
s
.73129 .01472 m
.73129 .01847 L
s
.7585 .01472 m
.7585 .01847 L
s
.78571 .01472 m
.78571 .01847 L
s
.81293 .01472 m
.81293 .01847 L
s
.86735 .01472 m
.86735 .01847 L
s
.89456 .01472 m
.89456 .01847 L
s
.92177 .01472 m
.92177 .01847 L
s
.94898 .01472 m
.94898 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.29592 .13244 m
.30217 .13244 L
s
[(0.2)] .28342 .13244 1 0 Mshowa
.29592 .25016 m
.30217 .25016 L
s
[(0.4)] .28342 .25016 1 0 Mshowa
.29592 .36788 m
.30217 .36788 L
s
[(0.6)] .28342 .36788 1 0 Mshowa
.29592 .4856 m
.30217 .4856 L
s
[(0.8)] .28342 .4856 1 0 Mshowa
.29592 .60332 m
.30217 .60332 L
s
[(1)] .28342 .60332 1 0 Mshowa
.125 Mabswid
.29592 .04415 m
.29967 .04415 L
s
.29592 .07358 m
.29967 .07358 L
s
.29592 .10301 m
.29967 .10301 L
s
.29592 .16187 m
.29967 .16187 L
s
.29592 .1913 m
.29967 .1913 L
s
.29592 .22073 m
.29967 .22073 L
s
.29592 .27959 m
.29967 .27959 L
s
.29592 .30902 m
.29967 .30902 L
s
.29592 .33845 m
.29967 .33845 L
s
.29592 .39731 m
.29967 .39731 L
s
.29592 .42674 m
.29967 .42674 L
s
.29592 .45617 m
.29967 .45617 L
s
.29592 .51503 m
.29967 .51503 L
s
.29592 .54446 m
.29967 .54446 L
s
.29592 .57389 m
.29967 .57389 L
s
.25 Mabswid
.29592 0 m
.29592 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .60332 m
.04262 .60332 L
.06244 .60332 L
.07216 .60332 L
.08255 .60332 L
.08562 .60332 L
.08852 .60332 L
.08979 .60332 L
.09113 .60332 L
.09183 .60332 L
.0926 .01472 L
.0933 .01472 L
.09396 .01472 L
.10458 .01472 L
.14335 .01472 L
.18458 .01472 L
.20517 .01472 L
.21519 .01472 L
.21993 .01472 L
.22428 .01472 L
.22651 .01472 L
.22763 .01472 L
.22886 .60332 L
.23009 .60332 L
.23142 .60332 L
.2338 .60332 L
.24277 .60332 L
.26248 .60332 L
.30384 .60332 L
.32454 .60332 L
.34368 .60332 L
.35327 .60332 L
.35796 .60332 L
.36002 .60332 L
.36119 .60332 L
.36227 .60332 L
.36333 .60332 L
.36447 .01472 L
.36568 .01472 L
.36679 .01472 L
.37165 .01472 L
.38201 .01472 L
.422 .01472 L
.46046 .01472 L
.48034 .01472 L
.49036 .01472 L
.4931 .01472 L
.49605 .01472 L
.49748 .01472 L
.49818 .01472 L
Mistroke
.49884 .01472 L
.50005 .60332 L
.5007 .60332 L
.50138 .60332 L
.54301 .60332 L
.58313 .60332 L
.60155 .60332 L
.612 .60332 L
.62174 .60332 L
.62669 .60332 L
.63138 .60332 L
.63398 .60332 L
.63469 .60332 L
.63544 .60332 L
.63608 .01472 L
.63679 .01472 L
.64171 .01472 L
.66279 .01472 L
.70305 .01472 L
.74179 .01472 L
.76187 .01472 L
.76675 .01472 L
.76943 .01472 L
.77074 .01472 L
.77196 .01472 L
.77266 .60332 L
.77339 .60332 L
.77495 .60332 L
.77767 .60332 L
.78298 .60332 L
.82092 .60332 L
.86131 .60332 L
.87992 .60332 L
.88974 .60332 L
.90019 .60332 L
.9027 .60332 L
.90542 .60332 L
.90618 .60332 L
.90697 .60332 L
.90766 .60332 L
.9084 .01472 L
.9091 .01472 L
.90985 .01472 L
.9112 .01472 L
.9214 .01472 L
.94152 .01472 L
.97619 .01472 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "NumberedFigure",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo000?Ool3
000QOol50012Ool5000QOol3000ROol2000TOol3000ROol00`00Oomoo`0=Ool000moo`03001oogoo
02=oo`03001oogoo04Aoo`03001oogoo025oo`03001oogoo02Aoo`03001oogoo029oo`03001oogoo
021oo`03001oo`0000ioo`002Woo0`000goo00<007ooOol077oo0`000goo00<007ooOol0A7oo00<0
07ooOol08Woo00<007ooOol08Woo00<007ooOol08Goo10008goo00<007ooOol037oo000@Ool00`00
Oomoo`0ROol00`00Oomoo`14Ool00`00Oomoo`0ROol00`00Oomoo`0SOol00`00Oomoo`0POol00`00
Ool0000ROol2000?Ool000moo`03001oo`0002=oo`03001oogoo04Aoo`03001oogoo025oo`03001o
o`00029oo`03001oo`0002=oo`80029oo`03001oogoo00ioo`0047oo00<007ooOol08Goo0P00AGoo
0P0097oo00<007ooOol08Woo00<007ooOol08goo00<007ooOol087oo0`003Woo003oOolQOol005Qo
o`03001oogoo0<Eoo`00F7oo00<007ooOol0aGoo001HOol00`00Oomoo`35Ool005Qoo`03001oogoo
0<Eoo`001gooo`004P0027oo000>Ool00`00Oomoo`04Ool00`00Oomoo`04Ool01@00Oomoogoo0000
0goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol017oo00<007ooOol017oo00D007ooOomo
o`0000=oo`03001oogoo00Aoo`03001oogoo00Eoo`03001oogoo00Aoo`03001oogoo00Aoo`05001o
ogooOol00003Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`04Ool0
1@00Oomoogoo00000goo00<007ooOol017oo00<007ooOol017oo00<007ooOol01Goo00<007ooOol0
17oo00D007ooOomoo`0000=oo`03001oogoo00Aoo`03001oogoo00Aoo`03001oogoo00Eoo`03001o
ogoo00Aoo`05001oogooOol00003Ool00`00Oomoo`04Ool00`00Oomoo`04Ool00`00Oomoo`05Ool0
0`00Oomoo`04Ool01@00Oomoogoo00000goo00<007ooOol017oo00<007ooOol017oo00<007ooOol0
3Goo000>Ool00`00Oomoo`0?Ool00`00Oomoo`0@Ool00`00Oomoo`0?Ool00`00Oomoo`0@Ool00`00
Oomoo`0?Ool00`00Oomoo`0@Ool00`00Oomoo`0?Ool00`00Oomoo`0?Ool00`00Oomoo`0@Ool00`00
Oomoo`0?Ool00`00Oomoo`0@Ool00`00Oomoo`0?Ool00`00Oomoo`0@Ool00`00Oomoo`0?Ool00`00
Oomoo`0=Ool0021oo`03001oogoo029oo`03001oogoo011oo`03001oogoo00moo`03001oogoo029o
o`03001oogoo029oo`03001oogoo029oo`03001oogoo029oo`03001oogoo01moo`0087oo00<007oo
Ool08Woo00<007ooOol047oo00<007ooOol03goo00<007ooOol08Woo00<007ooOol08Woo00<007oo
Ool08Woo00<007ooOol08Woo00<007ooOol07goo000POol00`00Oomoo`0ROol00`00Oomoo`0@Ool0
0`00Oomoo`0?Ool00`00Oomoo`0ROol00`00Oomoo`0ROol00`00Oomoo`0ROol00`00Oomoo`0ROol0
0`00Oomoo`0OOol0021oo`03001oogoo029oo`03001oogoo011oo`03001oogoo00moo`03001oogoo
029oo`03001oogoo029oo`03001oogoo029oo`03001oogoo029oo`03001oogoo01moo`0087oo00<0
07ooOol08Woo00<007ooOol047oo00<007ooOol03goo00<007ooOol08Woo00<007ooOol08Woo00<0
07ooOol08Woo00<007ooOol08Woo00<007ooOol07goo000POol00`00Oomoo`0ROol00`00Oomoo`0@
Ool2000@Ool00`00Oomoo`0ROol00`00Oomoo`0ROol00`00Oomoo`0ROol00`00Oomoo`0ROol00`00
Oomoo`0OOol0021oo`03001oogoo029oo`03001oogoo011oo`03001oogoo00moo`03001oogoo029o
o`03001oogoo029oo`03001oogoo029oo`03001oogoo029oo`03001oogoo01moo`0087oo00<007oo
Ool08Woo00<007ooOol047oo00<007ooOol03goo00<007ooOol08Woo00<007ooOol08Woo00<007oo
Ool08Woo00<007ooOol08Woo00<007ooOol07goo000POol00`00Oomoo`0ROol00`00Oomoo`0@Ool0
0`00Oomoo`0?Ool00`00Oomoo`0ROol00`00Oomoo`0ROol00`00Oomoo`0ROol00`00Oomoo`0ROol0
0`00Oomoo`0OOol0021oo`03001oogoo029oo`03001oogoo011oo`03001oogoo00moo`03001oogoo
029oo`03001oogoo029oo`03001oogoo029oo`03001oogoo029oo`03001oogoo01moo`0087oo00<0
07ooOol08Woo00<007ooOol047oo00<007ooOol03goo00<007ooOol08Woo00<007ooOol08Woo00<0
07ooOol08Woo00<007ooOol08Woo00<007ooOol07goo000POol00`00Oomoo`0ROol00`00Oomoo`0@
Ool00`00Oomoo`0?Ool00`00Oomoo`0ROol00`00Oomoo`0ROol00`00Oomoo`0ROol00`00Oomoo`0R
Ool00`00Oomoo`0OOol0021oo`03001oogoo029oo`03001oogoo011oo`03001oogoo00moo`03001o
ogoo029oo`03001oogoo029oo`03001oogoo029oo`03001oogoo029oo`03001oogoo01moo`0087oo
00<007ooOol08Woo00<007ooOol047oo0P0047oo00<007ooOol08Woo00<007ooOol08Woo00<007oo
Ool08Woo00<007ooOol08Woo00<007ooOol07goo000POol00`00Oomoo`0ROol00`00Oomoo`0@Ool0
0`00Oomoo`0?Ool00`00Oomoo`0ROol00`00Oomoo`0ROol00`00Oomoo`0ROol00`00Oomoo`0ROol0
0`00Oomoo`0OOol0021oo`03001oogoo029oo`03001oogoo011oo`03001oogoo00moo`03001oogoo
029oo`03001oogoo029oo`03001oogoo029oo`03001oogoo029oo`03001oogoo01moo`0087oo00<0
07ooOol08Woo00<007ooOol047oo00<007ooOol03goo00<007ooOol08Woo00<007ooOol08Woo00<0
07ooOol08Woo00<007ooOol08Woo00<007ooOol07goo000POol00`00Oomoo`0ROol00`00Oomoo`0@
Ool00`00Oomoo`0?Ool00`00Oomoo`0ROol00`00Oomoo`0ROol00`00Oomoo`0ROol00`00Oomoo`0R
Ool00`00Oomoo`0OOol0021oo`03001oogoo029oo`03001oogoo011oo`03001oogoo00moo`03001o
ogoo029oo`03001oogoo029oo`03001oogoo029oo`03001oogoo029oo`03001oogoo01moo`0087oo
00<007ooOol08Woo00<007ooOol047oo00<007ooOol03goo00<007ooOol08Woo00<007ooOol08Woo
00<007ooOol08Woo00<007ooOol08Woo00<007ooOol07goo000POol00`00Oomoo`0ROol00`00Oomo
o`0@Ool00`00Oomoo`0?Ool00`00Oomoo`0ROol00`00Oomoo`0ROol00`00Oomoo`0ROol00`00Oomo
o`0ROol00`00Oomoo`0OOol0021oo`03001oogoo029oo`03001oogoo011oo`80011oo`03001oogoo
029oo`03001oogoo029oo`03001oogoo029oo`03001oogoo029oo`03001oogoo01moo`0087oo00<0
07ooOol08Woo00<007ooOol047oo00<007ooOol03goo00<007ooOol08Woo00<007ooOol08Woo00<0
07ooOol08Woo00<007ooOol08Woo00<007ooOol07goo000POol00`00Oomoo`0ROol00`00Oomoo`0@
Ool00`00Oomoo`0?Ool00`00Oomoo`0ROol00`00Oomoo`0ROol00`00Oomoo`0ROol00`00Oomoo`0R
Ool00`00Oomoo`0OOol0021oo`03001oogoo029oo`03001oogoo011oo`03001oogoo00moo`03001o
ogoo029oo`03001oogoo029oo`03001oogoo029oo`03001oogoo029oo`03001oogoo01moo`0087oo
00<007ooOol08Woo00<007ooOol047oo00<007ooOol03goo00<007ooOol08Woo00<007ooOol08Woo
00<007ooOol08Woo00<007ooOol08Woo00<007ooOol07goo000POol00`00Oomoo`0ROol00`00Oomo
o`0@Ool00`00Oomoo`0?Ool00`00Oomoo`0ROol00`00Oomoo`0ROol00`00Oomoo`0ROol00`00Oomo
o`0ROol00`00Oomoo`0OOol0021oo`03001oogoo029oo`03001oo`0000Aoo`04001oogooOol30005
Ool00`00Oomoo`0?Ool00`00Oomoo`0ROol00`00Oomoo`0ROol00`00Oomoo`0ROol00`00Oomoo`0R
Ool00`00Oomoo`0OOol0021oo`03001oogoo029oo`800003Ool007oo00Ioo`03001oogoo00Eoo`03
001oogoo00moo`03001oogoo029oo`03001oogoo029oo`03001oogoo029oo`03001oogoo029oo`03
001oogoo01moo`0087oo00<007ooOol08Woo0P0000=oo`00Ool01goo00<007ooOol017oo0P0047oo
00<007ooOol08Woo00<007ooOol08Woo00<007ooOol08Woo00<007ooOol08Woo00<007ooOol07goo
000POol00`00Oomoo`0ROol200000goo001oo`07Ool00`00Oomoo`04Ool00`00Oomoo`0?Ool00`00
Oomoo`0ROol00`00Oomoo`0ROol00`00Oomoo`0ROol00`00Oomoo`0ROol00`00Oomoo`0OOol0021o
o`03001oogoo029oo`800003Ool007oo00Ioo`03001oo`0000Eoo`03001oogoo00moo`03001oogoo
029oo`03001oogoo029oo`03001oogoo029oo`03001oogoo029oo`03001oogoo01moo`0087oo00<0
07ooOol08Woo00<007oo00002Goo00<007ooOol017oo00<007ooOol03goo00<007ooOol08Woo00<0
07ooOol08Woo00<007ooOol08Woo00<007ooOol08Woo00<007ooOol07goo000POol00`00Oomoo`0R
Ool00`00Oomoo`0@Ool00`00Oomoo`0?Ool00`00Oomoo`0ROol00`00Oomoo`0ROol00`00Oomoo`0R
Ool00`00Oomoo`0ROol00`00Oomoo`0OOol0021oo`03001oogoo029oo`03001oogoo011oo`03001o
ogoo00moo`03001oogoo029oo`03001oogoo029oo`03001oogoo029oo`03001oogoo029oo`03001o
ogoo01moo`0087oo00<007ooOol08Woo00<007ooOol047oo00<007ooOol03goo00<007ooOol08Woo
00<007ooOol08Woo00<007ooOol08Woo00<007ooOol08Woo00<007ooOol07goo000POol00`00Oomo
o`0ROol00`00Oomoo`0@Ool00`00Oomoo`0?Ool00`00Oomoo`0ROol00`00Oomoo`0ROol00`00Oomo
o`0ROol00`00Oomoo`0ROol00`00Oomoo`0OOol0021oo`03001oogoo029oo`03001oogoo011oo`80
011oo`03001oogoo029oo`03001oogoo029oo`03001oogoo029oo`03001oogoo029oo`03001oogoo
01moo`0087oo00<007ooOol08Woo00<007ooOol047oo00<007ooOol03goo00<007ooOol08Woo00<0
07ooOol08Woo00<007ooOol08Woo00<007ooOol08Woo00<007ooOol07goo000POol00`00Oomoo`0R
Ool00`00Oomoo`0@Ool00`00Oomoo`0?Ool00`00Oomoo`0ROol00`00Oomoo`0ROol00`00Oomoo`0R
Ool00`00Oomoo`0ROol00`00Oomoo`0OOol0021oo`03001oogoo029oo`03001oogoo011oo`03001o
ogoo00moo`03001oogoo029oo`03001oogoo029oo`03001oogoo029oo`03001oogoo029oo`03001o
ogoo01moo`0087oo00<007ooOol08Woo00<007ooOol047oo00<007ooOol03goo00<007ooOol08Woo
00<007ooOol08Woo00<007ooOol08Woo00<007ooOol08Woo00<007ooOol07goo000POol00`00Oomo
o`0ROol00`00Oomoo`0@Ool00`00Oomoo`0?Ool00`00Oomoo`0ROol00`00Oomoo`0ROol00`00Oomo
o`0ROol00`00Oomoo`0ROol00`00Oomoo`0OOol0021oo`03001oogoo029oo`03001oogoo011oo`03
001oogoo00moo`03001oogoo029oo`03001oogoo029oo`03001oogoo029oo`03001oogoo029oo`03
001oogoo01moo`0087oo00<007ooOol08Woo00<007ooOol047oo00<007ooOol03goo00<007ooOol0
8Woo00<007ooOol08Woo00<007ooOol08Woo00<007ooOol08Woo00<007ooOol07goo000POol00`00
Oomoo`0ROol00`00Oomoo`0@Ool2000@Ool00`00Oomoo`0ROol00`00Oomoo`0ROol00`00Oomoo`0R
Ool00`00Oomoo`0ROol00`00Oomoo`0OOol0021oo`03001oogoo029oo`03001oogoo011oo`03001o
ogoo00moo`03001oogoo029oo`03001oogoo029oo`03001oogoo029oo`03001oogoo029oo`03001o
ogoo01moo`0087oo00<007ooOol08Woo00<007ooOol047oo00<007ooOol03goo00<007ooOol08Woo
00<007ooOol08Woo00<007ooOol08Woo00<007ooOol08Woo00<007ooOol07goo000POol00`00Oomo
o`0ROol00`00Oomoo`0@Ool00`00Oomoo`0?Ool00`00Oomoo`0ROol00`00Oomoo`0ROol00`00Oomo
o`0ROol00`00Oomoo`0ROol00`00Oomoo`0OOol0021oo`03001oogoo029oo`03001oogoo011oo`03
001oogoo00moo`03001oogoo029oo`03001oogoo029oo`03001oogoo029oo`03001oogoo029oo`03
001oogoo01moo`0087oo00<007ooOol08Woo00<007ooOol047oo00<007ooOol03goo00<007ooOol0
8Woo00<007ooOol08Woo00<007ooOol08Woo00<007ooOol08Woo00<007ooOol07goo000POol00`00
Oomoo`0ROol00`00Oomoo`0@Ool00`00Oomoo`0?Ool00`00Oomoo`0ROol00`00Oomoo`0ROol00`00
Oomoo`0ROol00`00Oomoo`0ROol00`00Oomoo`0OOol0021oo`03001oogoo029oo`03001oogoo011o
o`03001oogoo00moo`03001oogoo029oo`03001oogoo029oo`03001oogoo029oo`03001oogoo029o
o`03001oogoo01moo`0087oo00<007ooOol08Woo00<007ooOol047oo0P0047oo00<007ooOol08Woo
00<007ooOol08Woo00<007ooOol08Woo00<007ooOol08Woo00<007ooOol07goo000POol00`00Oomo
o`0ROol00`00Oomoo`0@Ool00`00Oomoo`0?Ool00`00Oomoo`0ROol00`00Oomoo`0ROol00`00Oomo
o`0ROol00`00Oomoo`0ROol00`00Oomoo`0OOol0021oo`03001oogoo029oo`03001oogoo011oo`03
001oogoo00moo`03001oogoo029oo`03001oogoo029oo`03001oogoo029oo`03001oogoo029oo`03
001oogoo01moo`0087oo00<007ooOol08Woo00<007ooOol047oo00<007ooOol03goo00<007ooOol0
8Woo00<007ooOol08Woo00<007ooOol08Woo00<007ooOol08Woo00<007ooOol07goo000POol00`00
Oomoo`0ROol00`00Oomoo`0@Ool00`00Oomoo`0?Ool00`00Oomoo`0ROol00`00Oomoo`0ROol00`00
Oomoo`0ROol00`00Oomoo`0ROol00`00Oomoo`0OOol0021oo`03001oogoo029oo`03001oogoo011o
o`03001oogoo00moo`03001oogoo029oo`03001oogoo029oo`03001oogoo029oo`03001oogoo029o
o`03001oogoo01moo`0087oo00<007ooOol08Woo00<007oo000017oo00<007ooOol00Woo0`0017oo
00<007ooOol03goo00<007ooOol08Woo00<007ooOol08Woo00<007ooOol08Woo00<007ooOol08Woo
00<007ooOol07goo000POol00`00Oomoo`0ROol200000goo001oo`08Ool00`00Oomoo`03Ool00`00
Oomoo`0?Ool00`00Oomoo`0ROol00`00Oomoo`0ROol00`00Oomoo`0ROol00`00Oomoo`0ROol00`00
Oomoo`0OOol0021oo`03001oogoo029oo`800003Ool007oo00Ioo`@000Aoo`80011oo`03001oogoo
029oo`03001oogoo029oo`03001oogoo029oo`03001oogoo029oo`03001oogoo01moo`0087oo00<0
07ooOol08Woo0P0000=oo`00Ool01Woo00<007oo00001Goo00<007ooOol03goo00<007ooOol08Woo
00<007ooOol08Woo00<007ooOol08Woo00<007ooOol08Woo00<007ooOol07goo000POol00`00Oomo
o`0ROol200000goo001oo`07Ool20005Ool00`00Oomoo`0?Ool00`00Oomoo`0ROol00`00Oomoo`0R
Ool00`00Oomoo`0ROol00`00Oomoo`0ROol00`00Oomoo`0OOol0021oo`03001oogoo029oo`03001o
o`0000Yoo`03001oogoo00=oo`03001oogoo00moo`03001oogoo029oo`03001oogoo029oo`03001o
ogoo029oo`03001oogoo029oo`03001oogoo01moo`0087oo00<007ooOol08Woo00<007ooOol047oo
00<007ooOol03goo00<007ooOol08Woo00<007ooOol08Woo00<007ooOol08Woo00<007ooOol08Woo
00<007ooOol07goo000POol00`00Oomoo`0ROol00`00Oomoo`0@Ool00`00Oomoo`0?Ool00`00Oomo
o`0ROol00`00Oomoo`0ROol00`00Oomoo`0ROol00`00Oomoo`0ROol00`00Oomoo`0OOol0021oo`03
001oogoo029oo`03001oogoo011oo`03001oogoo00moo`03001oogoo029oo`03001oogoo029oo`03
001oogoo029oo`03001oogoo029oo`03001oogoo01moo`0087oo00<007ooOol08Woo00<007ooOol0
47oo00<007ooOol03goo00<007ooOol08Woo00<007ooOol08Woo00<007ooOol08Woo00<007ooOol0
8Woo00<007ooOol07goo000POol00`00Oomoo`0ROol00`00Oomoo`0@Ool2000@Ool00`00Oomoo`0R
Ool00`00Oomoo`0ROol00`00Oomoo`0ROol00`00Oomoo`0ROol00`00Oomoo`0OOol0021oo`03001o
ogoo029oo`03001oogoo011oo`03001oogoo00moo`03001oogoo029oo`03001oogoo029oo`03001o
ogoo029oo`03001oogoo029oo`03001oogoo01moo`0087oo00<007ooOol08Woo00<007ooOol047oo
00<007ooOol03goo00<007ooOol08Woo00<007ooOol08Woo00<007ooOol08Woo00<007ooOol08Woo
00<007ooOol07goo000POol00`00Oomoo`0ROol00`00Oomoo`0@Ool00`00Oomoo`0?Ool00`00Oomo
o`0ROol00`00Oomoo`0ROol00`00Oomoo`0ROol00`00Oomoo`0ROol00`00Oomoo`0OOol0021oo`03
001oogoo029oo`03001oogoo011oo`03001oogoo00moo`03001oogoo029oo`03001oogoo029oo`03
001oogoo029oo`03001oogoo029oo`03001oogoo01moo`0087oo00<007ooOol08Woo00<007ooOol0
47oo00<007ooOol03goo00<007ooOol08Woo00<007ooOol08Woo00<007ooOol08Woo00<007ooOol0
8Woo00<007ooOol07goo000POol00`00Oomoo`0ROol00`00Oomoo`0@Ool00`00Oomoo`0?Ool00`00
Oomoo`0ROol00`00Oomoo`0ROol00`00Oomoo`0ROol00`00Oomoo`0ROol00`00Oomoo`0OOol0021o
o`03001oogoo029oo`03001oogoo011oo`03001oogoo00moo`03001oogoo029oo`03001oogoo029o
o`03001oogoo029oo`03001oogoo029oo`03001oogoo01moo`0087oo00<007ooOol08Woo00<007oo
Ool047oo0P0047oo00<007ooOol08Woo00<007ooOol08Woo00<007ooOol08Woo00<007ooOol08Woo
00<007ooOol07goo000POol00`00Oomoo`0ROol00`00Oomoo`0@Ool00`00Oomoo`0?Ool00`00Oomo
o`0ROol00`00Oomoo`0ROol00`00Oomoo`0ROol00`00Oomoo`0ROol00`00Oomoo`0OOol0021oo`03
001oogoo029oo`03001oogoo011oo`03001oogoo00moo`03001oogoo029oo`03001oogoo029oo`03
001oogoo029oo`03001oogoo029oo`03001oogoo01moo`0087oo00<007ooOol08Woo00<007ooOol0
47oo00<007ooOol03goo00<007ooOol08Woo00<007ooOol08Woo00<007ooOol08Woo00<007ooOol0
8Woo00<007ooOol07goo000POol00`00Oomoo`0ROol00`00Oomoo`0@Ool00`00Oomoo`0?Ool00`00
Oomoo`0ROol00`00Oomoo`0ROol00`00Oomoo`0ROol00`00Oomoo`0ROol00`00Oomoo`0OOol0021o
o`03001oogoo029oo`03001oogoo011oo`03001oogoo00moo`03001oogoo029oo`03001oogoo029o
o`03001oogoo029oo`03001oogoo029oo`03001oogoo01moo`0087oo00<007ooOol08Woo00<007oo
Ool047oo00<007ooOol03goo00<007ooOol08Woo00<007ooOol08Woo00<007ooOol08Woo00<007oo
Ool08Woo00<007ooOol07goo000POol00`00Oomoo`0ROol00`00Oomoo`0@Ool00`00Oomoo`0?Ool0
0`00Oomoo`0ROol00`00Oomoo`0ROol00`00Oomoo`0ROol00`00Oomoo`0ROol00`00Oomoo`0OOol0
021oo`03001oogoo029oo`03001oogoo011oo`80011oo`03001oogoo029oo`03001oogoo029oo`03
001oogoo029oo`03001oogoo029oo`03001oogoo01moo`0087oo00<007ooOol08Woo00<007ooOol0
47oo00<007ooOol03goo00<007ooOol08Woo00<007ooOol08Woo00<007ooOol08Woo00<007ooOol0
8Woo00<007ooOol07goo000POol00`00Oomoo`0ROol00`00Oomoo`0@Ool00`00Oomoo`0?Ool00`00
Oomoo`0ROol00`00Oomoo`0ROol00`00Oomoo`0ROol00`00Oomoo`0ROol00`00Oomoo`0OOol0021o
o`03001oogoo029oo`03001oogoo011oo`03001oogoo00moo`03001oogoo029oo`03001oogoo029o
o`03001oogoo029oo`03001oogoo029oo`03001oogoo01moo`0087oo00<007ooOol08Woo00<007oo
Ool047oo00<007ooOol03goo00<007ooOol08Woo00<007ooOol08Woo00<007ooOol08Woo00<007oo
Ool08Woo00<007ooOol07goo000POol00`00Oomoo`0ROol00`00Oomoo`0@Ool00`00Oomoo`0?Ool0
0`00Oomoo`0ROol00`00Oomoo`0ROol00`00Oomoo`0ROol00`00Oomoo`0ROol00`00Oomoo`0OOol0
021oo`03001oogoo029oo`03001oo`0000Aoo`04001oogooOol20006Ool00`00Oomoo`0?Ool00`00
Oomoo`0ROol00`00Oomoo`0ROol00`00Oomoo`0ROol00`00Oomoo`0ROol00`00Oomoo`0OOol0021o
o`03001oogoo029oo`800003Ool007oo00Ioo`03001oo`0000Eoo`03001oogoo00moo`03001oogoo
029oo`03001oogoo029oo`03001oogoo029oo`03001oogoo029oo`03001oogoo01moo`0087oo00<0
07ooOol08Woo0P0000=oo`00Ool01Woo00<007oo00001Goo0P0047oo00<007ooOol08Woo00<007oo
Ool08Woo00<007ooOol08Woo00<007ooOol08Woo00<007ooOol07goo000POol00`00Oomoo`0ROol2
00000goo001oo`06Ool20006Ool00`00Oomoo`0?Ool00`00Oomoo`0ROol00`00Oomoo`0ROol00`00
Oomoo`0ROol00`00Oomoo`0ROol00`00Oomoo`0OOol0021oo`03001oogoo029oo`800003Ool007oo
00Ioo`03001oogoo00Eoo`03001oogoo00moo`03001oogoo029oo`03001oogoo029oo`03001oogoo
029oo`03001oogoo029oo`03001oogoo01moo`0087oo00<007ooOol08Woo00<007oo00002Goo0P00
1Goo00<007ooOol03goo00<007ooOol08Woo00<007ooOol08Woo00<007ooOol08Woo00<007ooOol0
8Woo00<007ooOol07goo000POol00`00Oomoo`0ROol00`00Oomoo`0@Ool00`00Oomoo`0?Ool00`00
Oomoo`0ROol00`00Oomoo`0ROol00`00Oomoo`0ROol00`00Oomoo`0ROol00`00Oomoo`0OOol0021o
o`03001oogoo029oo`03001oogoo011oo`03001oogoo00moo`03001oogoo029oo`03001oogoo029o
o`03001oogoo029oo`03001oogoo029oo`03001oogoo01moo`0087oo00<007ooOol08Woo00<007oo
Ool047oo00<007ooOol03goo00<007ooOol08Woo00<007ooOol08Woo00<007ooOol08Woo00<007oo
Ool08Woo00<007ooOol07goo000POol00`00Oomoo`0ROol00`00Oomoo`0@Ool00`00Oomoo`0?Ool0
0`00Oomoo`0ROol00`00Oomoo`0ROol00`00Oomoo`0ROol00`00Oomoo`0ROol00`00Oomoo`0OOol0
021oo`03001oogoo029oo`03001oogoo011oo`80011oo`03001oogoo029oo`03001oogoo029oo`03
001oogoo029oo`03001oogoo029oo`03001oogoo01moo`0087oo00<007ooOol08Woo00<007ooOol0
47oo00<007ooOol03goo00<007ooOol08Woo00<007ooOol08Woo00<007ooOol08Woo00<007ooOol0
8Woo00<007ooOol07goo000POol00`00Oomoo`0ROol00`00Oomoo`0@Ool00`00Oomoo`0?Ool00`00
Oomoo`0ROol00`00Oomoo`0ROol00`00Oomoo`0ROol00`00Oomoo`0ROol00`00Oomoo`0OOol0021o
o`03001oogoo029oo`03001oogoo011oo`03001oogoo00moo`03001oogoo029oo`03001oogoo029o
o`03001oogoo029oo`03001oogoo029oo`03001oogoo01moo`0087oo00<007ooOol08Woo00<007oo
Ool047oo00<007ooOol03goo00<007ooOol08Woo00<007ooOol08Woo00<007ooOol08Woo00<007oo
Ool08Woo00<007ooOol07goo000POol00`00Oomoo`0ROol00`00Oomoo`0@Ool00`00Oomoo`0?Ool0
0`00Oomoo`0ROol00`00Oomoo`0ROol00`00Oomoo`0ROol00`00Oomoo`0ROol00`00Oomoo`0OOol0
021oo`03001oogoo029oo`03001oogoo011oo`03001oogoo00moo`03001oogoo029oo`03001oogoo
029oo`03001oogoo029oo`03001oogoo029oo`03001oogoo01moo`0087oo00<007ooOol08Woo00<0
07ooOol047oo00<007ooOol03goo00<007ooOol08Woo00<007ooOol08Woo00<007ooOol08Woo00<0
07ooOol08Woo00<007ooOol07goo000POol00`00Oomoo`0ROol00`00Oomoo`0@Ool2000@Ool00`00
Oomoo`0ROol00`00Oomoo`0ROol00`00Oomoo`0ROol00`00Oomoo`0ROol00`00Oomoo`0OOol0021o
o`03001oogoo029oo`03001oogoo011oo`03001oogoo00moo`03001oogoo029oo`03001oogoo029o
o`03001oogoo029oo`03001oogoo029oo`03001oogoo01moo`0087oo00<007ooOol08Woo00<007oo
Ool047oo00<007ooOol03goo00<007ooOol08Woo00<007ooOol08Woo00<007ooOol08Woo00<007oo
Ool08Woo00<007ooOol07goo000POol00`00Oomoo`0ROol00`00Oomoo`0@Ool00`00Oomoo`0?Ool0
0`00Oomoo`0ROol00`00Oomoo`0ROol00`00Oomoo`0ROol00`00Oomoo`0ROol00`00Oomoo`0OOol0
021oo`03001oogoo029oo`03001oogoo011oo`03001oogoo00moo`03001oogoo029oo`03001oogoo
029oo`03001oogoo029oo`03001oogoo029oo`03001oogoo01moo`0087oo00<007ooOol08Woo00<0
07ooOol047oo00<007ooOol03goo00<007ooOol08Woo00<007ooOol08Woo00<007ooOol08Woo00<0
07ooOol08Woo00<007ooOol07goo000POol00`00Oomoo`0ROol00`00Oomoo`0@Ool00`00Oomoo`0?
Ool00`00Oomoo`0ROol00`00Oomoo`0ROol00`00Oomoo`0ROol00`00Oomoo`0ROol00`00Oomoo`0O
Ool0021oo`03001oogoo029oo`03001oogoo011oo`03001oogoo00moo`03001oogoo029oo`03001o
ogoo029oo`03001oogoo029oo`03001oogoo029oo`03001oogoo01moo`0087oo00<007ooOol08Woo
00<007ooOol047oo0P0047oo00<007ooOol08Woo00<007ooOol08Woo00<007ooOol08Woo00<007oo
Ool08Woo00<007ooOol07goo000POol00`00Oomoo`0ROol00`00Oomoo`0@Ool00`00Oomoo`0?Ool0
0`00Oomoo`0ROol00`00Oomoo`0ROol00`00Oomoo`0ROol00`00Oomoo`0ROol00`00Oomoo`0OOol0
021oo`03001oogoo029oo`03001oogoo011oo`03001oogoo00moo`03001oogoo029oo`03001oogoo
029oo`03001oogoo029oo`03001oogoo029oo`03001oogoo01moo`0087oo00<007ooOol08Woo00<0
07ooOol047oo00<007ooOol03goo00<007ooOol08Woo00<007ooOol08Woo00<007ooOol08Woo00<0
07ooOol08Woo00<007ooOol07goo000POol00`00Oomoo`0ROol00`00Oomoo`0@Ool00`00Oomoo`0?
Ool00`00Oomoo`0ROol00`00Oomoo`0ROol00`00Oomoo`0ROol00`00Oomoo`0ROol00`00Oomoo`0O
Ool0021oo`03001oogoo029oo`03001oogoo011oo`03001oogoo00moo`03001oogoo029oo`03001o
ogoo029oo`03001oogoo029oo`03001oogoo029oo`03001oogoo01moo`0087oo00<007ooOol08Woo
00<007oo000017oo00<007ooOol00Woo00<007ooOol017oo00<007ooOol03goo00<007ooOol08Woo
00<007ooOol08Woo00<007ooOol08Woo00<007ooOol08Woo00<007ooOol07goo000POol00`00Oomo
o`0ROol200000goo001oo`06Ool00`00Ool00005Ool00`00Oomoo`0?Ool00`00Oomoo`0ROol00`00
Oomoo`0ROol00`00Oomoo`0ROol00`00Oomoo`0ROol00`00Oomoo`0OOol0021oo`03001oogoo029o
o`800003Ool007oo00Ioo`03001oo`0000Eoo`80011oo`03001oogoo029oo`03001oogoo029oo`03
001oogoo029oo`03001oogoo029oo`03001oogoo01moo`0087oo00<007ooOol08Woo0P0000=oo`00
Ool01goo00<007ooOol017oo00<007ooOol03goo00<007ooOol08Woo00<007ooOol08Woo00<007oo
Ool08Woo00<007ooOol08Woo00<007ooOol07goo000POol00`00Oomoo`0ROol200000goo001oo`06
Ool00`00Ool00005Ool00`00Oomoo`0?Ool00`00Oomoo`0ROol00`00Oomoo`0ROol00`00Oomoo`0R
Ool00`00Oomoo`0ROol00`00Oomoo`0OOol0021oo`03001oogoo029oo`03001oo`0000Uoo`03001o
ogoo00Aoo`03001oogoo00moo`03001oogoo029oo`03001oogoo029oo`03001oogoo029oo`03001o
ogoo029oo`03001oogoo01moo`0087oo00<007ooOol08Woo00<007ooOol047oo00<007ooOol03goo
00<007ooOol08Woo00<007ooOol08Woo00<007ooOol08Woo00<007ooOol08Woo00<007ooOol07goo
000POol00`00Oomoo`0ROol00`00Oomoo`0@Ool00`00Oomoo`0?Ool00`00Oomoo`0ROol00`00Oomo
o`0ROol00`00Oomoo`0ROol00`00Oomoo`0ROol00`00Oomoo`0OOol0021oo`03001oogoo029oo`03
001oogoo011oo`03001oogoo00moo`03001oogoo029oo`03001oogoo029oo`03001oogoo029oo`03
001oogoo029oo`03001oogoo01moo`0087oo00<007ooOol08Woo00<007ooOol047oo00<007ooOol0
3goo00<007ooOol08Woo00<007ooOol08Woo00<007ooOol08Woo00<007ooOol08Woo00<007ooOol0
7goo000POol00`00Oomoo`0ROol00`00Oomoo`0@Ool2000@Ool00`00Oomoo`0ROol00`00Oomoo`0R
Ool00`00Oomoo`0ROol00`00Oomoo`0ROol00`00Oomoo`0OOol0021oo`03001oogoo029oo`03001o
ogoo011oo`03001oogoo00moo`03001oogoo029oo`03001oogoo029oo`03001oogoo029oo`03001o
ogoo029oo`03001oogoo01moo`0087oo00<007ooOol08Woo00<007ooOol047oo00<007ooOol03goo
00<007ooOol08Woo00<007ooOol08Woo00<007ooOol08Woo00<007ooOol08Woo00<007ooOol07goo
000POol00`00Oomoo`0ROol00`00Oomoo`0@Ool00`00Oomoo`0?Ool00`00Oomoo`0ROol00`00Oomo
o`0ROol00`00Oomoo`0ROol00`00Oomoo`0ROol00`00Oomoo`0OOol0021oo`03001oogoo029oo`03
001oogoo011oo`03001oogoo00moo`03001oogoo029oo`03001oogoo029oo`03001oogoo029oo`03
001oogoo029oo`03001oogoo01moo`0087oo00<007ooOol08Woo00<007ooOol047oo00<007ooOol0
3goo00<007ooOol08Woo00<007ooOol08Woo00<007ooOol08Woo00<007ooOol08Woo00<007ooOol0
7goo000POol00`00Oomoo`0ROol00`00Oomoo`0@Ool00`00Oomoo`0?Ool00`00Oomoo`0ROol00`00
Oomoo`0ROol00`00Oomoo`0ROol00`00Oomoo`0ROol00`00Oomoo`0OOol0021oo`03001oogoo029o
o`03001oogoo011oo`03001oogoo00moo`03001oogoo029oo`03001oogoo029oo`03001oogoo029o
o`03001oogoo029oo`03001oogoo01moo`0087oo00<007ooOol08Woo00<007ooOol047oo0P0047oo
00<007ooOol08Woo00<007ooOol08Woo00<007ooOol08Woo00<007ooOol08Woo00<007ooOol07goo
000POol00`00Oomoo`0ROol00`00Oomoo`0@Ool00`00Oomoo`0?Ool00`00Oomoo`0ROol00`00Oomo
o`0ROol00`00Oomoo`0ROol00`00Oomoo`0ROol00`00Oomoo`0OOol0021oo`03001oogoo029oo`03
001oogoo011oo`03001oogoo00moo`03001oogoo029oo`03001oogoo029oo`03001oogoo029oo`03
001oogoo029oo`03001oogoo01moo`0087oo00<007ooOol08Woo00<007ooOol047oo00<007ooOol0
3goo00<007ooOol08Woo00<007ooOol08Woo00<007ooOol08Woo00<007ooOol08Woo00<007ooOol0
7goo000POol00`00Oomoo`0ROol00`00Oomoo`0@Ool00`00Oomoo`0?Ool00`00Oomoo`0ROol00`00
Oomoo`0ROol00`00Oomoo`0ROol00`00Oomoo`0ROol00`00Oomoo`0OOol0021oo`03001oogoo029o
o`03001oogoo011oo`03001oogoo00moo`03001oogoo029oo`03001oogoo029oo`03001oogoo029o
o`03001oogoo029oo`03001oogoo01moo`0087oo00<007ooOol08Woo00<007ooOol047oo00<007oo
Ool03goo00<007ooOol08Woo00<007ooOol08Woo00<007ooOol08Woo00<007ooOol08Woo00<007oo
Ool07goo000POol00`00Oomoo`0ROol00`00Oomoo`0@Ool00`00Oomoo`0?Ool00`00Oomoo`0ROol0
0`00Oomoo`0ROol00`00Oomoo`0ROol00`00Oomoo`0ROol00`00Oomoo`0OOol0021oo`03001oogoo
029oo`03001oogoo011oo`80011oo`03001oogoo029oo`03001oogoo029oo`03001oogoo029oo`03
001oogoo029oo`03001oogoo01moo`0087oo00<007ooOol08Woo00<007ooOol047oo00<007ooOol0
3goo00<007ooOol08Woo00<007ooOol08Woo00<007ooOol08Woo00<007ooOol08Woo00<007ooOol0
7goo000POol00`00Oomoo`0ROol00`00Oomoo`0@Ool00`00Oomoo`0?Ool00`00Oomoo`0ROol00`00
Oomoo`0ROol00`00Oomoo`0ROol00`00Oomoo`0ROol00`00Oomoo`0OOol0021oo`03001oogoo029o
o`03001oogoo011oo`03001oogoo00moo`03001oogoo029oo`03001oogoo029oo`03001oogoo029o
o`03001oogoo029oo`03001oogoo01moo`0087oo00<007ooOol08Woo00<007ooOol047oo00<007oo
Ool03goo00<007ooOol08Woo00<007ooOol08Woo00<007ooOol08Woo00<007ooOol08Woo00<007oo
Ool07goo000POol00`00Oomoo`0ROol00`00Oomoo`0@Ool00`00Oomoo`0?Ool00`00Oomoo`0ROol0
0`00Oomoo`0ROol00`00Oomoo`0ROol00`00Oomoo`0ROol00`00Oomoo`0OOol0021oo`03001oogoo
029oo`03001oogoo00Moo`D000Aoo`03001oogoo00moo`03001oogoo029oo`03001oogoo029oo`03
001oogoo029oo`03001oogoo029oo`03001oogoo01moo`0087oo00<007ooOol08Woo00<007ooOol0
2Goo00<007ooOol017oo00<007ooOol03goo00<007ooOol08Woo00<007ooOol08Woo00<007ooOol0
8Woo00<007ooOol08Woo00<007ooOol07goo000>OolC000TOolV000TOolV000TOolV000QOol0055o
o`03001oogoo00Aoo`03001oogoo0<Eoo`00DGoo00<007ooOol017oo00<007ooOol0aGoo001@Ool2
0006Ool00`00Oomoo`35Ool005Qoo`03001oogoo0<Eoo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-2.37917, -0.07747, 
  0.0270326, 0.00624851}}]
}, Open  ]],

Cell["\<\
A wavelet expansion is similar in form to (1), but is defined by a \
two-parameter family of functions\
\>", "Text"],

Cell[TextData[{
  "\t",
  Cell[BoxData[
      \(TraditionalForm
      \`f(t) = \ 
        \[Sum]\+k\ 
          \(\[Sum]\+j\ a\_\(j, k\)\ \(\(\[Psi]\_\(j, k\)\)(t)\)\)\)]]
}], "NumberedEquation"],

Cell[TextData[{
  "where ",
  StyleBox["j",
    FontSlant->"Italic"],
  " and ",
  StyleBox["k",
    FontSlant->"Italic"],
  " are integers and the functions ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Psi]\_\(j, k\)\)(t)\)]],
  " are the wavelet expansion functions. As indicated earlier, they usually \
form an orthogonal basis. The two-parameter expansion coefficients ",
  Cell[BoxData[
      \(TraditionalForm\`\(\ a\_\(j, k\)\)\)]],
  " are called the discrete wavelet transform (DWT) of ",
  Cell[BoxData[
      \(TraditionalForm\`f(t)\)]],
  " and (4) is the synthesis formula (i.e. inverse transformation). \
Interestingly, just as there exists a fast algorithm for computing the \
Fourier series coefficients of a sampled periodic signal, so there exists a \
fast algorithm for calculating the DWT of a sampled signal. The wavelet basis \
functions are related to each other in the following way (compare this with \
the Fourier series) "
}], "Text"],

Cell[TextData[{
  "\t",
  Cell[BoxData[
      \(TraditionalForm\`\(\ 
      \(\[Psi]\_\(j, k\)\)(t)\  = \ 
        2\^\(j/2\)\ \ \ \(\[Psi](\(2\^j\) t\  - \ k)\)\)\)]]
}], "Text"],

Cell[TextData[{
  "where the function ",
  Cell[BoxData[
      \(TraditionalForm\`\(\ \[Psi](t)\)\)]],
  " is called the generating or ",
  StyleBox["mother ",
    FontSlant->"Italic"],
  "wavelet. Therefore, all wavelet basis functions are obtained from a single \
wavelet by ",
  StyleBox["translation",
    FontSlant->"Italic"],
  " and ",
  StyleBox["scaling",
    FontSlant->"Italic"],
  ". Here is an example\n"
}], "Text"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.29787 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0309017 0.952381 [
[ 0 0 0 0 ]
[ 1 1.29787 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.29787 L
0 1.29787 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0309017 0.97619 0.619505 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.267442 0.0221484 0.311962 0.325045 [
[.04596 .29946 -9 -9 ]
[.04596 .29946 9 0 ]
[.48893 .29946 -6 -9 ]
[.48893 .29946 6 0 ]
[.71041 .29946 -6 -9 ]
[.71041 .29946 6 0 ]
[.93189 .29946 -6 -9 ]
[.93189 .29946 6 0 ]
[.25494 .06818 -30 -4.5 ]
[.25494 .06818 0 4.5 ]
[.25494 .14944 -24 -4.5 ]
[.25494 .14944 0 4.5 ]
[.25494 .2307 -30 -4.5 ]
[.25494 .2307 0 4.5 ]
[.25494 .39322 -24 -4.5 ]
[.25494 .39322 0 4.5 ]
[.25494 .47448 -18 -4.5 ]
[.25494 .47448 0 4.5 ]
[.25494 .55575 -24 -4.5 ]
[.25494 .55575 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.04596 .31196 m
.04596 .31821 L
s
[(-10)] .04596 .29946 0 1 Mshowa
.48893 .31196 m
.48893 .31821 L
s
[(10)] .48893 .29946 0 1 Mshowa
.71041 .31196 m
.71041 .31821 L
s
[(20)] .71041 .29946 0 1 Mshowa
.93189 .31196 m
.93189 .31821 L
s
[(30)] .93189 .29946 0 1 Mshowa
.125 Mabswid
.09025 .31196 m
.09025 .31571 L
s
.13455 .31196 m
.13455 .31571 L
s
.17885 .31196 m
.17885 .31571 L
s
.22315 .31196 m
.22315 .31571 L
s
.31174 .31196 m
.31174 .31571 L
s
.35604 .31196 m
.35604 .31571 L
s
.40033 .31196 m
.40033 .31571 L
s
.44463 .31196 m
.44463 .31571 L
s
.53322 .31196 m
.53322 .31571 L
s
.57752 .31196 m
.57752 .31571 L
s
.62182 .31196 m
.62182 .31571 L
s
.66611 .31196 m
.66611 .31571 L
s
.75471 .31196 m
.75471 .31571 L
s
.799 .31196 m
.799 .31571 L
s
.8433 .31196 m
.8433 .31571 L
s
.8876 .31196 m
.8876 .31571 L
s
.00166 .31196 m
.00166 .31571 L
s
.97619 .31196 m
.97619 .31571 L
s
.25 Mabswid
0 .31196 m
1 .31196 L
s
.26744 .06818 m
.27369 .06818 L
s
[(-0.75)] .25494 .06818 1 0 Mshowa
.26744 .14944 m
.27369 .14944 L
s
[(-0.5)] .25494 .14944 1 0 Mshowa
.26744 .2307 m
.27369 .2307 L
s
[(-0.25)] .25494 .2307 1 0 Mshowa
.26744 .39322 m
.27369 .39322 L
s
[(0.25)] .25494 .39322 1 0 Mshowa
.26744 .47448 m
.27369 .47448 L
s
[(0.5)] .25494 .47448 1 0 Mshowa
.26744 .55575 m
.27369 .55575 L
s
[(0.75)] .25494 .55575 1 0 Mshowa
.125 Mabswid
.26744 .08443 m
.27119 .08443 L
s
.26744 .10068 m
.27119 .10068 L
s
.26744 .11693 m
.27119 .11693 L
s
.26744 .13319 m
.27119 .13319 L
s
.26744 .16569 m
.27119 .16569 L
s
.26744 .18194 m
.27119 .18194 L
s
.26744 .1982 m
.27119 .1982 L
s
.26744 .21445 m
.27119 .21445 L
s
.26744 .24695 m
.27119 .24695 L
s
.26744 .26321 m
.27119 .26321 L
s
.26744 .27946 m
.27119 .27946 L
s
.26744 .29571 m
.27119 .29571 L
s
.26744 .32821 m
.27119 .32821 L
s
.26744 .34447 m
.27119 .34447 L
s
.26744 .36072 m
.27119 .36072 L
s
.26744 .37697 m
.27119 .37697 L
s
.26744 .40948 m
.27119 .40948 L
s
.26744 .42573 m
.27119 .42573 L
s
.26744 .44198 m
.27119 .44198 L
s
.26744 .45823 m
.27119 .45823 L
s
.26744 .49074 m
.27119 .49074 L
s
.26744 .50699 m
.27119 .50699 L
s
.26744 .52324 m
.27119 .52324 L
s
.26744 .53949 m
.27119 .53949 L
s
.26744 .05193 m
.27119 .05193 L
s
.26744 .03567 m
.27119 .03567 L
s
.26744 .01942 m
.27119 .01942 L
s
.26744 .00317 m
.27119 .00317 L
s
.26744 .572 m
.27119 .572 L
s
.26744 .58825 m
.27119 .58825 L
s
.26744 .6045 m
.27119 .6045 L
s
.25 Mabswid
.26744 0 m
.26744 .61803 L
s
.5 Mabswid
.02381 .31196 m
.02658 .31196 L
.02935 .31196 L
.03212 .31196 L
.03488 .31196 L
.03765 .31196 L
.04042 .31196 L
.04319 .31196 L
.04596 .31196 L
.04873 .31196 L
.0515 .31196 L
.05426 .31196 L
.05703 .31196 L
.0598 .31196 L
.06257 .31196 L
.06534 .31195 L
.06811 .31195 L
.07087 .31195 L
.07364 .31195 L
.07641 .31196 L
.07918 .31197 L
.08195 .31198 L
.08472 .312 L
.08749 .31203 L
.09025 .31206 L
.09302 .31209 L
.09579 .31211 L
.09856 .31212 L
.10133 .3121 L
.1041 .31205 L
.10687 .31195 L
.10963 .31179 L
.1124 .31159 L
.11517 .31135 L
.11794 .3111 L
.12071 .31089 L
.12348 .31076 L
.12625 .31079 L
.12901 .31104 L
.13178 .31154 L
.13455 .31232 L
.13732 .31335 L
.14009 .31454 L
.14286 .31576 L
.14563 .3168 L
.14839 .3174 L
.15116 .31733 L
.15393 .31639 L
.1567 .31445 L
.15947 .31151 L
Mistroke
.16224 .30774 L
.16501 .30353 L
.16777 .29945 L
.17054 .29624 L
.17331 .29463 L
.17608 .29527 L
.17885 .29862 L
.18162 .30487 L
.18439 .31373 L
.18715 .32438 L
.18992 .33545 L
.19269 .34519 L
.19546 .35176 L
.19823 .35355 L
.201 .34927 L
.20377 .33833 L
.20653 .32112 L
.2093 .29923 L
.21207 .2755 L
.21484 .25372 L
.21761 .23781 L
.22038 .23123 L
.22315 .2367 L
.22591 .25555 L
.22868 .28694 L
.23145 .32764 L
.23422 .37172 L
.23699 .41134 L
.23976 .43859 L
.24252 .44677 L
.24529 .43108 L
.24806 .39014 L
.25083 .32745 L
.2536 .25196 L
.25637 .1781 L
.25914 .1237 L
.2619 .10501 L
.26467 .13294 L
.26744 .21063 L
.27021 .32869 L
.27298 .46121 L
.27575 .56791 L
.27852 .60332 L
.28128 .53579 L
.28405 .37528 L
.28682 .18114 L
.28959 .03666 L
.29236 .01472 L
.29513 .13 L
.2979 .31772 L
Mistroke
.30066 .48224 L
.30343 .54232 L
.3062 .47354 L
.30897 .33749 L
.31174 .21828 L
.31451 .17295 L
.31728 .21779 L
.32004 .30234 L
.32281 .36575 L
.32558 .38383 L
.32835 .35354 L
.33112 .30754 L
.33389 .28245 L
.33666 .28097 L
.33942 .29813 L
.34219 .31898 L
.34496 .32566 L
.34773 .32222 L
.3505 .31493 L
.35327 .30763 L
.35604 .30687 L
.3588 .3097 L
.36157 .31186 L
.36434 .31361 L
.36711 .31343 L
.36988 .31215 L
.37265 .31174 L
.37542 .31158 L
.37818 .31165 L
.38095 .31202 L
.38372 .31206 L
.38649 .312 L
.38926 .31201 L
.39203 .31194 L
.3948 .31193 L
.39756 .31197 L
.40033 .31196 L
.4031 .31196 L
.40587 .31197 L
.40864 .31196 L
.41141 .31196 L
.41417 .31196 L
.41694 .31196 L
.41971 .31196 L
.42248 .31196 L
.42525 .31196 L
.42802 .31196 L
.43079 .31196 L
.43355 .31196 L
.43632 .31196 L
Mistroke
.43909 .31196 L
.44186 .31196 L
.44463 .31196 L
.4474 .31196 L
.45017 .31196 L
.45293 .31196 L
.4557 .31196 L
.45847 .31196 L
.46124 .31196 L
.46401 .31196 L
.46678 .31196 L
.46955 .31196 L
.47231 .31196 L
.47508 .31196 L
.47785 .31196 L
.48062 .31196 L
.48339 .31196 L
.48616 .31196 L
.48893 .31196 L
.49169 .31196 L
.49446 .31196 L
.49723 .31196 L
.5 .31196 L
.50277 .31196 L
.50554 .31196 L
.50831 .31196 L
.51107 .31196 L
.51384 .31196 L
.51661 .31196 L
.51938 .31196 L
.52215 .31196 L
.52492 .31196 L
.52769 .31196 L
.53045 .31196 L
.53322 .31196 L
.46678 .31196 L
.46955 .31196 L
.47231 .31196 L
.47508 .31196 L
.47785 .31196 L
.48062 .31196 L
.48339 .31196 L
.48616 .31196 L
.48893 .31196 L
.49169 .31196 L
.49446 .31196 L
.49723 .31196 L
.5 .31196 L
.50277 .31196 L
.50554 .31196 L
Mistroke
.50831 .31195 L
.51107 .31195 L
.51384 .31195 L
.51661 .31195 L
.51938 .31196 L
.52215 .31197 L
.52492 .31198 L
.52769 .312 L
.53045 .31203 L
.53322 .31206 L
.53599 .31209 L
.53876 .31211 L
.54153 .31212 L
.5443 .3121 L
.54707 .31205 L
.54983 .31195 L
.5526 .31179 L
.55537 .31159 L
.55814 .31135 L
.56091 .3111 L
.56368 .31089 L
.56645 .31076 L
.56921 .31079 L
.57198 .31104 L
.57475 .31154 L
.57752 .31232 L
.58029 .31335 L
.58306 .31454 L
.58583 .31576 L
.58859 .3168 L
.59136 .3174 L
.59413 .31733 L
.5969 .31639 L
.59967 .31445 L
.60244 .31151 L
.6052 .30774 L
.60797 .30353 L
.61074 .29945 L
.61351 .29624 L
.61628 .29463 L
.61905 .29527 L
.62182 .29862 L
.62458 .30487 L
.62735 .31373 L
.63012 .32438 L
.63289 .33545 L
.63566 .34519 L
.63843 .35176 L
.6412 .35355 L
.64396 .34927 L
Mistroke
.64673 .33833 L
.6495 .32112 L
.65227 .29923 L
.65504 .2755 L
.65781 .25372 L
.66058 .23781 L
.66334 .23123 L
.66611 .2367 L
.66888 .25555 L
.67165 .28694 L
.67442 .32764 L
.67719 .37172 L
.67996 .41134 L
.68272 .43859 L
.68549 .44677 L
.68826 .43108 L
.69103 .39014 L
.6938 .32745 L
.69657 .25196 L
.69934 .1781 L
.7021 .1237 L
.70487 .10501 L
.70764 .13294 L
.71041 .21063 L
.71318 .32869 L
.71595 .46121 L
.71872 .56791 L
.72148 .60332 L
.72425 .53579 L
.72702 .37528 L
.72979 .18114 L
.73256 .03666 L
.73533 .01472 L
.7381 .13 L
.74086 .31772 L
.74363 .48224 L
.7464 .54232 L
.74917 .47354 L
.75194 .33749 L
.75471 .21828 L
.75748 .17295 L
.76024 .21779 L
.76301 .30234 L
.76578 .36575 L
.76855 .38383 L
.77132 .35354 L
.77409 .30754 L
.77685 .28245 L
.77962 .28097 L
.78239 .29813 L
Mistroke
.78516 .31898 L
.78793 .32566 L
.7907 .32222 L
.79347 .31493 L
.79623 .30763 L
.799 .30687 L
.80177 .3097 L
.80454 .31186 L
.80731 .31361 L
.81008 .31343 L
.81285 .31215 L
.81561 .31174 L
.81838 .31158 L
.82115 .31165 L
.82392 .31202 L
.82669 .31206 L
.82946 .312 L
.83223 .31201 L
.83499 .31194 L
.83776 .31193 L
.84053 .31197 L
.8433 .31196 L
.84607 .31196 L
.84884 .31197 L
.85161 .31196 L
.85437 .31196 L
.85714 .31196 L
.85991 .31196 L
.86268 .31196 L
.86545 .31196 L
.86822 .31196 L
.87099 .31196 L
.87375 .31196 L
.87652 .31196 L
.87929 .31196 L
.88206 .31196 L
.88483 .31196 L
.8876 .31196 L
.89037 .31196 L
.89313 .31196 L
.8959 .31196 L
.89867 .31196 L
.90144 .31196 L
.90421 .31196 L
.90698 .31196 L
.90975 .31196 L
.91251 .31196 L
.91528 .31196 L
.91805 .31196 L
.92082 .31196 L
Mistroke
.92359 .31196 L
.92636 .31196 L
.92913 .31196 L
.93189 .31196 L
.93466 .31196 L
.93743 .31196 L
.9402 .31196 L
.94297 .31196 L
.94574 .31196 L
.9485 .31196 L
.95127 .31196 L
.95404 .31196 L
.95681 .31196 L
.95958 .31196 L
.96235 .31196 L
.96512 .31196 L
.96788 .31196 L
.97065 .31196 L
.97342 .31196 L
.97619 .31196 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.678366 0.97619 1.26697 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.150029 0.0229489 0.311962 0.325045 [
[.37952 .29946 -6 -9 ]
[.37952 .29946 6 0 ]
[.60901 .29946 -6 -9 ]
[.60901 .29946 6 0 ]
[.8385 .29946 -6 -9 ]
[.8385 .29946 6 0 ]
[.13753 .06818 -30 -4.5 ]
[.13753 .06818 0 4.5 ]
[.13753 .14944 -24 -4.5 ]
[.13753 .14944 0 4.5 ]
[.13753 .2307 -30 -4.5 ]
[.13753 .2307 0 4.5 ]
[.13753 .39322 -24 -4.5 ]
[.13753 .39322 0 4.5 ]
[.13753 .47448 -18 -4.5 ]
[.13753 .47448 0 4.5 ]
[.13753 .55575 -24 -4.5 ]
[.13753 .55575 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.37952 .31196 m
.37952 .31821 L
s
[(10)] .37952 .29946 0 1 Mshowa
.60901 .31196 m
.60901 .31821 L
s
[(20)] .60901 .29946 0 1 Mshowa
.8385 .31196 m
.8385 .31821 L
s
[(30)] .8385 .29946 0 1 Mshowa
.125 Mabswid
.19593 .31196 m
.19593 .31571 L
s
.24182 .31196 m
.24182 .31571 L
s
.28772 .31196 m
.28772 .31571 L
s
.33362 .31196 m
.33362 .31571 L
s
.42542 .31196 m
.42542 .31571 L
s
.47131 .31196 m
.47131 .31571 L
s
.51721 .31196 m
.51721 .31571 L
s
.56311 .31196 m
.56311 .31571 L
s
.65491 .31196 m
.65491 .31571 L
s
.7008 .31196 m
.7008 .31571 L
s
.7467 .31196 m
.7467 .31571 L
s
.7926 .31196 m
.7926 .31571 L
s
.10413 .31196 m
.10413 .31571 L
s
.05823 .31196 m
.05823 .31571 L
s
.01234 .31196 m
.01234 .31571 L
s
.88439 .31196 m
.88439 .31571 L
s
.93029 .31196 m
.93029 .31571 L
s
.97619 .31196 m
.97619 .31571 L
s
.25 Mabswid
0 .31196 m
1 .31196 L
s
.15003 .06818 m
.15628 .06818 L
s
[(-0.75)] .13753 .06818 1 0 Mshowa
.15003 .14944 m
.15628 .14944 L
s
[(-0.5)] .13753 .14944 1 0 Mshowa
.15003 .2307 m
.15628 .2307 L
s
[(-0.25)] .13753 .2307 1 0 Mshowa
.15003 .39322 m
.15628 .39322 L
s
[(0.25)] .13753 .39322 1 0 Mshowa
.15003 .47448 m
.15628 .47448 L
s
[(0.5)] .13753 .47448 1 0 Mshowa
.15003 .55575 m
.15628 .55575 L
s
[(0.75)] .13753 .55575 1 0 Mshowa
.125 Mabswid
.15003 .08443 m
.15378 .08443 L
s
.15003 .10068 m
.15378 .10068 L
s
.15003 .11693 m
.15378 .11693 L
s
.15003 .13319 m
.15378 .13319 L
s
.15003 .16569 m
.15378 .16569 L
s
.15003 .18194 m
.15378 .18194 L
s
.15003 .1982 m
.15378 .1982 L
s
.15003 .21445 m
.15378 .21445 L
s
.15003 .24695 m
.15378 .24695 L
s
.15003 .26321 m
.15378 .26321 L
s
.15003 .27946 m
.15378 .27946 L
s
.15003 .29571 m
.15378 .29571 L
s
.15003 .32821 m
.15378 .32821 L
s
.15003 .34447 m
.15378 .34447 L
s
.15003 .36072 m
.15378 .36072 L
s
.15003 .37697 m
.15378 .37697 L
s
.15003 .40948 m
.15378 .40948 L
s
.15003 .42573 m
.15378 .42573 L
s
.15003 .44198 m
.15378 .44198 L
s
.15003 .45823 m
.15378 .45823 L
s
.15003 .49074 m
.15378 .49074 L
s
.15003 .50699 m
.15378 .50699 L
s
.15003 .52324 m
.15378 .52324 L
s
.15003 .53949 m
.15378 .53949 L
s
.15003 .05193 m
.15378 .05193 L
s
.15003 .03567 m
.15378 .03567 L
s
.15003 .01942 m
.15378 .01942 L
s
.15003 .00317 m
.15378 .00317 L
s
.15003 .572 m
.15378 .572 L
s
.15003 .58825 m
.15378 .58825 L
s
.15003 .6045 m
.15378 .6045 L
s
.25 Mabswid
.15003 0 m
.15003 .61803 L
s
.5 Mabswid
.02381 .31196 m
.02524 .31196 L
.02668 .31196 L
.02811 .31196 L
.02955 .31196 L
.03098 .31196 L
.03242 .31196 L
.03385 .31196 L
.03528 .31196 L
.03672 .31196 L
.03815 .31196 L
.03959 .31196 L
.04102 .31196 L
.04246 .31196 L
.04389 .31196 L
.04532 .31195 L
.04676 .31195 L
.04819 .31195 L
.04963 .31195 L
.05106 .31196 L
.0525 .31197 L
.05393 .31198 L
.05536 .312 L
.0568 .31203 L
.05823 .31206 L
.05967 .31209 L
.0611 .31211 L
.06254 .31212 L
.06397 .3121 L
.0654 .31205 L
.06684 .31195 L
.06827 .31179 L
.06971 .31159 L
.07114 .31135 L
.07258 .3111 L
.07401 .31089 L
.07544 .31076 L
.07688 .31079 L
.07831 .31104 L
.07975 .31154 L
.08118 .31232 L
.08262 .31335 L
.08405 .31454 L
.08548 .31576 L
.08692 .3168 L
.08835 .3174 L
.08979 .31733 L
.09122 .31639 L
.09266 .31445 L
.09409 .31151 L
Mistroke
.09552 .30774 L
.09696 .30353 L
.09839 .29945 L
.09983 .29624 L
.10126 .29463 L
.1027 .29527 L
.10413 .29862 L
.10557 .30487 L
.107 .31373 L
.10843 .32438 L
.10987 .33545 L
.1113 .34519 L
.11274 .35176 L
.11417 .35355 L
.11561 .34927 L
.11704 .33833 L
.11847 .32112 L
.11991 .29923 L
.12134 .2755 L
.12278 .25372 L
.12421 .23781 L
.12565 .23123 L
.12708 .2367 L
.12851 .25555 L
.12995 .28694 L
.13138 .32764 L
.13282 .37172 L
.13425 .41134 L
.13569 .43859 L
.13712 .44677 L
.13855 .43108 L
.13999 .39014 L
.14142 .32745 L
.14286 .25196 L
.14429 .1781 L
.14573 .1237 L
.14716 .10501 L
.14859 .13294 L
.15003 .21063 L
.15146 .32869 L
.1529 .46121 L
.15433 .56791 L
.15577 .60332 L
.1572 .53579 L
.15863 .37528 L
.16007 .18114 L
.1615 .03666 L
.16294 .01472 L
.16437 .13 L
.16581 .31772 L
Mistroke
.16724 .48224 L
.16867 .54232 L
.17011 .47354 L
.17154 .33749 L
.17298 .21828 L
.17441 .17295 L
.17585 .21779 L
.17728 .30234 L
.17871 .36575 L
.18015 .38383 L
.18158 .35354 L
.18302 .30754 L
.18445 .28245 L
.18589 .28097 L
.18732 .29813 L
.18876 .31898 L
.19019 .32566 L
.19162 .32222 L
.19306 .31493 L
.19449 .30763 L
.19593 .30687 L
.19736 .3097 L
.1988 .31186 L
.20023 .31361 L
.20166 .31343 L
.2031 .31215 L
.20453 .31174 L
.20597 .31158 L
.2074 .31165 L
.20884 .31202 L
.21027 .31206 L
.2117 .312 L
.21314 .31201 L
.21457 .31194 L
.21601 .31193 L
.21744 .31197 L
.21888 .31196 L
.22031 .31196 L
.22174 .31197 L
.22318 .31196 L
.22461 .31196 L
.22605 .31196 L
.22748 .31196 L
.22892 .31196 L
.23035 .31196 L
.23178 .31196 L
.23322 .31196 L
.23465 .31196 L
.23609 .31196 L
.23752 .31196 L
Mistroke
.23896 .31196 L
.24039 .31196 L
.24182 .31196 L
.24326 .31196 L
.24469 .31196 L
.24613 .31196 L
.24756 .31196 L
.249 .31196 L
.25043 .31196 L
.25186 .31196 L
.2533 .31196 L
.25473 .31196 L
.25617 .31196 L
.2576 .31196 L
.25904 .31196 L
.26047 .31196 L
.2619 .31196 L
.26334 .31196 L
.26477 .31196 L
.26621 .31196 L
.26764 .31196 L
.26908 .31196 L
.27051 .31196 L
.27194 .31196 L
.27338 .31196 L
.27481 .31196 L
.27625 .31196 L
.27768 .31196 L
.27912 .31196 L
.28055 .31196 L
.28199 .31196 L
.28342 .31196 L
.28485 .31196 L
.28629 .31196 L
.28772 .31196 L
.2533 .31196 L
.25473 .31196 L
.25617 .31196 L
.2576 .31196 L
.25904 .31196 L
.26047 .31196 L
.2619 .31196 L
.26334 .31196 L
.26477 .31196 L
.26621 .31196 L
.26764 .31196 L
.26908 .31196 L
.27051 .31196 L
.27194 .31196 L
.27338 .31196 L
Mistroke
.27481 .31195 L
.27625 .31195 L
.27768 .31195 L
.27912 .31195 L
.28055 .31196 L
.28199 .31197 L
.28342 .31198 L
.28485 .312 L
.28629 .31203 L
.28772 .31206 L
.28916 .31209 L
.29059 .31211 L
.29203 .31212 L
.29346 .3121 L
.29489 .31205 L
.29633 .31195 L
.29776 .31179 L
.2992 .31159 L
.30063 .31135 L
.30207 .3111 L
.3035 .31089 L
.30493 .31076 L
.30637 .31079 L
.3078 .31104 L
.30924 .31154 L
.31067 .31232 L
.31211 .31335 L
.31354 .31454 L
.31497 .31576 L
.31641 .3168 L
.31784 .3174 L
.31928 .31733 L
.32071 .31639 L
.32215 .31445 L
.32358 .31151 L
.32501 .30774 L
.32645 .30353 L
.32788 .29945 L
.32932 .29624 L
.33075 .29463 L
.33219 .29527 L
.33362 .29862 L
.33505 .30487 L
.33649 .31373 L
.33792 .32438 L
.33936 .33545 L
.34079 .34519 L
.34223 .35176 L
.34366 .35355 L
.34509 .34927 L
Mistroke
.34653 .33833 L
.34796 .32112 L
.3494 .29923 L
.35083 .2755 L
.35227 .25372 L
.3537 .23781 L
.35513 .23123 L
.35657 .2367 L
.358 .25555 L
.35944 .28694 L
.36087 .32764 L
.36231 .37172 L
.36374 .41134 L
.36517 .43859 L
.36661 .44677 L
.36804 .43108 L
.36948 .39014 L
.37091 .32745 L
.37235 .25196 L
.37378 .1781 L
.37522 .1237 L
.37665 .10501 L
.37808 .13294 L
.37952 .21063 L
.38095 .32869 L
.38239 .46121 L
.38382 .56791 L
.38526 .60332 L
.38669 .53579 L
.38812 .37528 L
.38956 .18114 L
.39099 .03666 L
.39243 .01472 L
.39386 .13 L
.3953 .31772 L
.39673 .48224 L
.39816 .54232 L
.3996 .47354 L
.40103 .33749 L
.40247 .21828 L
.4039 .17295 L
.40534 .21779 L
.40677 .30234 L
.4082 .36575 L
.40964 .38383 L
.41107 .35354 L
.41251 .30754 L
.41394 .28245 L
.41538 .28097 L
.41681 .29813 L
Mistroke
.41824 .31898 L
.41968 .32566 L
.42111 .32222 L
.42255 .31493 L
.42398 .30763 L
.42542 .30687 L
.42685 .3097 L
.42828 .31186 L
.42972 .31361 L
.43115 .31343 L
.43259 .31215 L
.43402 .31174 L
.43546 .31158 L
.43689 .31165 L
.43832 .31202 L
.43976 .31206 L
.44119 .312 L
.44263 .31201 L
.44406 .31194 L
.4455 .31193 L
.44693 .31197 L
.44836 .31196 L
.4498 .31196 L
.45123 .31197 L
.45267 .31196 L
.4541 .31196 L
.45554 .31196 L
.45697 .31196 L
.45841 .31196 L
.45984 .31196 L
.46127 .31196 L
.46271 .31196 L
.46414 .31196 L
.46558 .31196 L
.46701 .31196 L
.46845 .31196 L
.46988 .31196 L
.47131 .31196 L
.47275 .31196 L
.47418 .31196 L
.47562 .31196 L
.47705 .31196 L
.47849 .31196 L
.47992 .31196 L
.48135 .31196 L
.48279 .31196 L
.48422 .31196 L
.48566 .31196 L
.48709 .31196 L
.48853 .31196 L
Mistroke
.48996 .31196 L
.49139 .31196 L
.49283 .31196 L
.49426 .31196 L
.4957 .31196 L
.49713 .31196 L
.49857 .31196 L
.5 .31196 L
.50143 .31196 L
.50287 .31196 L
.5043 .31196 L
.50574 .31196 L
.50717 .31196 L
.50861 .31196 L
.51004 .31196 L
.51147 .31196 L
.51291 .31196 L
.51434 .31196 L
.51578 .31196 L
.51721 .31196 L
.48279 .31196 L
.48422 .31196 L
.48566 .31196 L
.48709 .31196 L
.48853 .31196 L
.48996 .31196 L
.49139 .31196 L
.49283 .31196 L
.49426 .31196 L
.4957 .31196 L
.49713 .31196 L
.49857 .31196 L
.5 .31196 L
.50143 .31196 L
.50287 .31196 L
.5043 .31195 L
.50574 .31195 L
.50717 .31195 L
.50861 .31195 L
.51004 .31196 L
.51147 .31197 L
.51291 .31198 L
.51434 .312 L
.51578 .31203 L
.51721 .31206 L
.51865 .31209 L
.52008 .31211 L
.52151 .31212 L
.52295 .3121 L
.52438 .31205 L
Mistroke
.52582 .31195 L
.52725 .31179 L
.52869 .31159 L
.53012 .31135 L
.53155 .3111 L
.53299 .31089 L
.53442 .31076 L
.53586 .31079 L
.53729 .31104 L
.53873 .31154 L
.54016 .31232 L
.54159 .31335 L
.54303 .31454 L
.54446 .31576 L
.5459 .3168 L
.54733 .3174 L
.54877 .31733 L
.5502 .31639 L
.55164 .31445 L
.55307 .31151 L
.5545 .30774 L
.55594 .30353 L
.55737 .29945 L
.55881 .29624 L
.56024 .29463 L
.56168 .29527 L
.56311 .29862 L
.56454 .30487 L
.56598 .31373 L
.56741 .32438 L
.56885 .33545 L
.57028 .34519 L
.57172 .35176 L
.57315 .35355 L
.57458 .34927 L
.57602 .33833 L
.57745 .32112 L
.57889 .29923 L
.58032 .2755 L
.58176 .25372 L
.58319 .23781 L
.58462 .23123 L
.58606 .2367 L
.58749 .25555 L
.58893 .28694 L
.59036 .32764 L
.5918 .37172 L
.59323 .41134 L
.59466 .43859 L
.5961 .44677 L
Mistroke
.59753 .43108 L
.59897 .39014 L
.6004 .32745 L
.60184 .25196 L
.60327 .1781 L
.6047 .1237 L
.60614 .10501 L
.60757 .13294 L
.60901 .21063 L
.61044 .32869 L
.61188 .46121 L
.61331 .56791 L
.61474 .60332 L
.61618 .53579 L
.61761 .37528 L
.61905 .18114 L
.62048 .03666 L
.62192 .01472 L
.62335 .13 L
.62478 .31772 L
.62622 .48224 L
.62765 .54232 L
.62909 .47354 L
.63052 .33749 L
.63196 .21828 L
.63339 .17295 L
.63483 .21779 L
.63626 .30234 L
.63769 .36575 L
.63913 .38383 L
.64056 .35354 L
.642 .30754 L
.64343 .28245 L
.64487 .28097 L
.6463 .29813 L
.64773 .31898 L
.64917 .32566 L
.6506 .32222 L
.65204 .31493 L
.65347 .30763 L
.65491 .30687 L
.65634 .3097 L
.65777 .31186 L
.65921 .31361 L
.66064 .31343 L
.66208 .31215 L
.66351 .31174 L
.66495 .31158 L
.66638 .31165 L
.66781 .31202 L
Mistroke
.66925 .31206 L
.67068 .312 L
.67212 .31201 L
.67355 .31194 L
.67499 .31193 L
.67642 .31197 L
.67785 .31196 L
.67929 .31196 L
.68072 .31197 L
.68216 .31196 L
.68359 .31196 L
.68503 .31196 L
.68646 .31196 L
.68789 .31196 L
.68933 .31196 L
.69076 .31196 L
.6922 .31196 L
.69363 .31196 L
.69507 .31196 L
.6965 .31196 L
.69793 .31196 L
.69937 .31196 L
.7008 .31196 L
.70224 .31196 L
.70367 .31196 L
.70511 .31196 L
.70654 .31196 L
.70797 .31196 L
.70941 .31196 L
.71084 .31196 L
.71228 .31196 L
.71371 .31196 L
.71515 .31196 L
.71658 .31196 L
.71801 .31196 L
.71945 .31196 L
.72088 .31196 L
.72232 .31196 L
.72375 .31196 L
.72519 .31196 L
.72662 .31196 L
.72806 .31196 L
.72949 .31196 L
.73092 .31196 L
.73236 .31196 L
.73379 .31196 L
.73523 .31196 L
.73666 .31196 L
.7381 .31196 L
.73953 .31196 L
Mistroke
.74096 .31196 L
.7424 .31196 L
.74383 .31196 L
.74527 .31196 L
.7467 .31196 L
.71228 .31196 L
.71371 .31196 L
.71515 .31196 L
.71658 .31196 L
.71801 .31196 L
.71945 .31196 L
.72088 .31196 L
.72232 .31196 L
.72375 .31196 L
.72519 .31196 L
.72662 .31196 L
.72806 .31196 L
.72949 .31196 L
.73092 .31196 L
.73236 .31196 L
.73379 .31195 L
.73523 .31195 L
.73666 .31195 L
.7381 .31195 L
.73953 .31196 L
.74096 .31197 L
.7424 .31198 L
.74383 .312 L
.74527 .31203 L
.7467 .31206 L
.74814 .31209 L
.74957 .31211 L
.751 .31212 L
.75244 .3121 L
.75387 .31205 L
.75531 .31195 L
.75674 .31179 L
.75818 .31159 L
.75961 .31135 L
.76104 .3111 L
.76248 .31089 L
.76391 .31076 L
.76535 .31079 L
.76678 .31104 L
.76822 .31154 L
.76965 .31232 L
.77108 .31335 L
.77252 .31454 L
.77395 .31576 L
.77539 .3168 L
Mistroke
.77682 .3174 L
.77826 .31733 L
.77969 .31639 L
.78112 .31445 L
.78256 .31151 L
.78399 .30774 L
.78543 .30353 L
.78686 .29945 L
.7883 .29624 L
.78973 .29463 L
.79116 .29527 L
.7926 .29862 L
.79403 .30487 L
.79547 .31373 L
.7969 .32438 L
.79834 .33545 L
.79977 .34519 L
.8012 .35176 L
.80264 .35355 L
.80407 .34927 L
.80551 .33833 L
.80694 .32112 L
.80838 .29923 L
.80981 .2755 L
.81124 .25372 L
.81268 .23781 L
.81411 .23123 L
.81555 .2367 L
.81698 .25555 L
.81842 .28694 L
.81985 .32764 L
.82129 .37172 L
.82272 .41134 L
.82415 .43859 L
.82559 .44677 L
.82702 .43108 L
.82846 .39014 L
.82989 .32745 L
.83133 .25196 L
.83276 .1781 L
.83419 .1237 L
.83563 .10501 L
.83706 .13294 L
.8385 .21063 L
.83993 .32869 L
.84137 .46121 L
.8428 .56791 L
.84423 .60332 L
.84567 .53579 L
.8471 .37528 L
Mistroke
.84854 .18114 L
.84997 .03666 L
.85141 .01472 L
.85284 .13 L
.85427 .31772 L
.85571 .48224 L
.85714 .54232 L
.85858 .47354 L
.86001 .33749 L
.86145 .21828 L
.86288 .17295 L
.86431 .21779 L
.86575 .30234 L
.86718 .36575 L
.86862 .38383 L
.87005 .35354 L
.87149 .30754 L
.87292 .28245 L
.87435 .28097 L
.87579 .29813 L
.87722 .31898 L
.87866 .32566 L
.88009 .32222 L
.88153 .31493 L
.88296 .30763 L
.88439 .30687 L
.88583 .3097 L
.88726 .31186 L
.8887 .31361 L
.89013 .31343 L
.89157 .31215 L
.893 .31174 L
.89443 .31158 L
.89587 .31165 L
.8973 .31202 L
.89874 .31206 L
.90017 .312 L
.90161 .31201 L
.90304 .31194 L
.90448 .31193 L
.90591 .31197 L
.90734 .31196 L
.90878 .31196 L
.91021 .31197 L
.91165 .31196 L
.91308 .31196 L
.91452 .31196 L
.91595 .31196 L
.91738 .31196 L
.91882 .31196 L
Mistroke
.92025 .31196 L
.92169 .31196 L
.92312 .31196 L
.92456 .31196 L
.92599 .31196 L
.92742 .31196 L
.92886 .31196 L
.93029 .31196 L
.93173 .31196 L
.93316 .31196 L
.9346 .31196 L
.93603 .31196 L
.93746 .31196 L
.9389 .31196 L
.94033 .31196 L
.94177 .31196 L
.9432 .31196 L
.94464 .31196 L
.94607 .31196 L
.9475 .31196 L
.94894 .31196 L
.95037 .31196 L
.95181 .31196 L
.95324 .31196 L
.95468 .31196 L
.95611 .31196 L
.95754 .31196 L
.95898 .31196 L
.96041 .31196 L
.96185 .31196 L
.96328 .31196 L
.96472 .31196 L
.96615 .31196 L
.96758 .31196 L
.96902 .31196 L
.97045 .31196 L
.97189 .31196 L
.97332 .31196 L
.97476 .31196 L
.97619 .31196 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "NumberedFigure",
  ImageSize->{273.875, 355.438},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004A0001Ha000`40O003h00Oogoo4Woo003oOolB
Ool00?mooa9oo`00ogoo4Woo003oOolBOol00?mooa9oo`00ogoo4Woo003oOolBOol00?mooa9oo`00
C7oo00<007ooOol0`Woo001<Ool00`00Oomoo`32Ool004aoo`03001oogoo0<9oo`00C7oo00<007oo
Ool0`Woo001<Ool00`00Oomoo`03Ool00`00Oomoo`1`Ool00`00Oomoo`19Ool004aoo`03001oogoo
00=oo`03001oogoo071oo`03001oogoo04Uoo`00C7oo00<007ooOol00goo00<007ooOol0L7oo00<0
07ooOol0BGoo001<Ool00`00Oomoo`02Ool2001aOol2001;Ool004aoo`03001oogoo009oo`80075o
o`8004]oo`00C7oo00<007ooOol00Woo0P00LGoo0P00Bgoo001<Ool00`00Oomoo`02Ool2001aOol2
001;Ool004aoo`03001oogoo009oo`80075oo`8004]oo`00C7oo00<007ooOol00Woo0P00LGoo0P00
Bgoo001<Ool00`00Oomoo`02Ool2001aOol2001;Ool004aoo`03001oogoo009oo`80075oo`8004]o
o`00=Woo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol017oo00<007oo
Ool00Woo0P00LGoo0P00Bgoo000eOol00`00Ool00008Ool01`00Oomoogoo001oo`0000Eoo`03001o
ogoo009oo`80075oo`8004]oo`00<7oo0`000Woo00<007oo000027oo00<007ooOol00goo00<007oo
Ool00goo0P000goo0P00LGoo0P00Bgoo000eOol00`00Ool00009Ool00`00Oomoo`020006Ool00`00
Oomoo`02Ool2001aOol2001;Ool003Eoo`03001oo`0000Moo`03001oo`00009oo`03001oogoo00Eo
o`03001oogoo009oo`03001oo`00071oo`03001oo`0004Yoo`00=Woo00<007ooOol01Woo0`000Woo
0`001Goo00<007ooOol00Woo00<007oo0000L7oo00<007oo0000BWoo001<Ool00`00Oomoo`02Ool0
0`00Ool0001`Ool00`00Ool0001:Ool004aoo`03001oogoo009oo`03001oo`00071oo`03001oo`00
04Yoo`00C7oo00<007ooOol00Woo00<007oo0000L7oo00<007oo0000BWoo001<Ool00`00Oomoo`02
Ool00`00Ool0001`Ool00`00Ool0001:Ool004aoo`03001oogoo009oo`03001oo`00071oo`03001o
o`0004Yoo`00C7oo00<007ooOol00Woo00<007oo0000L7oo00<007oo0000BWoo001:Ool00`00Ool0
0004Ool00`00Ool0001YOol00`00Oomoo`04Ool00`00Ool0001:Ool004Yoo`03001oo`0000Aoo`03
001oo`0006Uoo`03001oogoo00Aoo`03001oo`0004Yoo`00BWoo00<007oo000017oo00<007oo0000
JGoo00<007ooOol017oo00<007oo0000BWoo0019Ool200000goo001oo`03Ool00`00Ool0001XOol2
0006Ool00`00Ool0001:Ool004Uoo`04001oo`000004Ool00`00Ool0001XOol00`00Ool00005Ool0
0`00Ool0001:Ool004Uoo`04001oo`000004Ool00`00Ool0001XOol00`00Ool00005Ool00`00Ool0
001:Ool004Uoo`04001oo`000004Ool00`00Ool0001XOol00`00Ool00005Ool00`00Ool0001:Ool0
04Uoo`04001oo`000004Ool00`00Ool0001XOol00`00Ool00005Ool00`00Ool0001:Ool004Uoo`04
001oo`000004Ool00`00Ool0001XOol00`00Ool00005Ool00`00Ool0001:Ool004Uoo`04001oo`00
0004Ool00`00Ool0001XOol00`00Ool00005Ool00`00Ool0001:Ool003]oo`03001oogoo009oo`03
001oogoo009oo`06001oogooOol007oo0P0017oo00<007oo0000J7oo00<007oo00001Goo00<007oo
0000BWoo000jOol00`00Ool00007Ool00`00Ool00002Ool01000Ool0000017oo00<007oo0000J7oo
00<007oo00001Goo00<007oo0000BWoo000eOol30002Ool00`00Ool00009Ool01@00Oomoo`00Ool0
0`000goo00<007oo0000J7oo00<007oo00001Goo00<007oo0000BWoo000jOol00`00Ool00007Ool2
0003Ool01000Ool0000017oo00<007oo0000J7oo00<007oo00001Goo00<007oo0000BWoo000jOol0
0`00Ool00007Ool00`00Oomoo`02Ool01000Ool0000017oo00<007oo0000J7oo00<007oo00001Goo
00<007oo0000BWoo000kOol00`00Oomoo`06Ool30002Ool01000Ool0000017oo00<007oo0000J7oo
00<007oo00001Goo00<007oo0000BWoo0019Ool01000Ool0000017oo00<007oo0000J7oo00<007oo
00001Goo00<007oo0000BWoo0019Ool01000Oomoo`0017oo00<007oo0000J7oo00@007ooOol000Ao
o`03001oo`0004Yoo`00BGoo00@007ooOol000Aoo`03001oo`0000Aoo`03001oogoo065oo`04001o
ogoo0004Ool00`00Ool00004Ool00`00Oomoo`13Ool004Uoo`04001oogoo0004Ool00`00Ool00004
Ool00`00Oomoo`1QOol01000Oomoo`0017oo00<007oo000017oo00<007ooOol0@goo0019Ool01000
Oomoo`0017oo00<007oo000017oo00<007ooOol0HGoo00@007ooOol000Aoo`03001oo`0000Aoo`03
001oogoo04=oo`00BGoo00@007ooOol000Aoo`03001oo`0000Aoo`03001oogoo065oo`04001oogoo
0004Ool00`00Ool00004Ool00`00Oomoo`13Ool004Uoo`04001oogoo0004Ool00`00Ool00004Ool0
0`00Oomoo`1QOol01000Oomoo`0017oo00<007oo000017oo00<007ooOol0@goo0019Ool01000Oomo
o`0017oo00<007oo000017oo00<007ooOol0HGoo00@007ooOol000Aoo`03001oo`0000Aoo`03001o
ogoo04=oo`00BGoo00@007ooOol000Aoo`03001oo`0000=oo`8006=oo`04001oogoo0004Ool00`00
Ool00003Ool00`00Ool00014Ool004Uoo`04001oogoo0004Ool00`00Ool00003Ool2001SOol01000
Oomoo`0017oo00<007oo00000goo00<007oo0000A7oo0019Ool01000Oomoo`0017oo00<007oo0000
0goo0P00Hgoo00@007ooOol000Aoo`03001oo`0000=oo`03001oo`0004Aoo`00BGoo00@007ooOol0
00Aoo`03001oo`0000=oo`8006=oo`04001oogoo0004Ool00`00Ool00003Ool00`00Ool00014Ool0
04Uoo`04001oogoo0004Ool00`00Ool00003Ool2001SOol01000Oomoo`0017oo00<007oo00000goo
00<007oo0000A7oo0018Ool01@00Oomoogoo000017oo00<007oo00000goo0P00HWoo00D007ooOomo
o`0000Aoo`03001oo`0000=oo`03001oo`0004Aoo`00B7oo00D007ooOomoo`0000Aoo`03001oo`00
00=oo`80069oo`05001oogooOol00004Ool00`00Ool00003Ool00`00Ool00014Ool003Ioo`03001o
ogoo009oo`04001oogooOol30003Ool01000Oomoo`000goo00<007ooOol00Woo00<007oo00000goo
0P00HWoo00D007ooOomoo`0000Aoo`04001oogoo0002Ool00`00Ool00014Ool003Eoo`03001oo`00
00Moo`03001oogoo009oo`05001oo`00Ool00003Ool00`00Oomoo`02Ool00`00Ool00003Ool2001R
Ool01@00Oomoogoo000017oo00@007ooOol0009oo`03001oo`0004Aoo`00<7oo0`000Woo00<007oo
00001goo0P001Goo00<007oo00000goo0P000goo00<007oo00000goo0P00FGoo00<007ooOol01Woo
00D007ooOomoo`0000Aoo`04001oogoo0002Ool00`00Ool00014Ool003Eoo`03001oo`0000Moo`80
00=oo`80009oo`05001oogooOol00004Ool00`00Ool00003Ool2001IOol20007Ool01@00Oomoogoo
000017oo00@007ooOol0009oo`03001oo`0004Aoo`00=Goo00<007oo00001goo0`000Woo00D007oo
Oomoo`0000=oo`03001oogoo009oo`03001oo`0000=oo`8005Uoo`8000Moo`05001oogooOol00004
Ool01000Oomoo`000Woo00<007oo0000A7oo000fOol00`00Oomoo`06Ool20003Ool300000goo001o
o`02Ool00`00Oomoo`02Ool00`00Ool00003Ool2001IOol20007Ool01@00Oomoogoo000017oo00@0
07ooOol0009oo`03001oo`0004Aoo`00?Woo00@007ooOol000Ioo`05001oogooOol00004Ool00`00
Ool00003Ool2001HOol01000Oomoo`001Woo00D007ooOomoo`0000Aoo`04001oogoo0002Ool00`00
Ool00014Ool003ioo`04001oogoo0006Ool01@00Oomoogoo000017oo00<007oo00000goo0P00F7oo
00@007ooOol000Ioo`05001oogooOol00004Ool01000Oomoo`000Woo00<007oo0000A7oo000nOol0
1000Oomoo`001Woo00D007ooOomoo`0000Aoo`03001oo`0000=oo`8005Qoo`04001oogoo0006Ool0
1@00Oomoogoo000017oo00@007ooOol0009oo`03001oo`0004Aoo`00?Woo00@007ooOol000Ioo`05
001oogooOol00004Ool00`00Ool00003Ool00`00Ool0001GOol01000Oomoo`001Woo00D007ooOomo
o`0000Aoo`04001oogoo0002Ool00`00Ool00014Ool003ioo`04001oogoo0006Ool01@00Oomoogoo
000017oo00<007oo00000goo00<007oo0000Egoo00@007ooOol000Ioo`05001oogooOol00004Ool0
1000Oomoo`000Woo00<007oo0000A7oo000?Ool50002Ool00`00Oomoo`0TOol01@00Oomoogoo0000
1Woo00D007ooOomoo`0000Aoo`03001oo`0000=oo`03001oo`0002Ioo`D0009oo`03001oogoo02Io
o`05001oogooOol00006Ool3000017oo001oo`000Woo00@007ooOol0009oo`03001oo`0002Moo`80
00Aoo`03001oogoo01Aoo`004Goo00L007ooOomoo`00Ool0000UOol01@00Oomoogoo00001Woo00D0
07ooOomoo`0000Aoo`03001oo`0000=oo`03001oo`0002Qoo`07001oogooOol007oo00009goo00<0
07ooOol00Woo00<007ooOol00goo00@007ooOomoo`800004Ool007oo0002Ool01P00Oomoo`00Ool0
02Uoo`06001oogoo001oo`005Goo000;Ool30003Ool01`00Oomoogoo001oo`0002Eoo`05001oogoo
Ool00006Ool01@00Oomoogoo000017oo00<007oo00000goo00<007oo0000:7oo00L007ooOomoo`00
Ool0000WOol00`00Oomoo`02Ool00`00Oomoo`03Ool20002Ool2000017oo001oo`000Woo00H007oo
Ool007oo000XOol01`00Oomoogoo001oo`0001Eoo`004Goo00L007ooOomoo`00Ool0000UOol01@00
Oomoogoo00001Woo00D007ooOomoo`0000=oo`04001oogoo0002Ool01000Oomoo`00:7oo00L007oo
Oomoo`00Ool0000WOol00`00Oomoo`02Ool00`00Oomoo`03Ool20002Ool200000goo00000003Ool0
0`00Ool00002Ool00`00Oomoo`0WOol01P00Oomoo`00Ool001Eoo`004Goo00L007ooOomoo`00Ool0
000UOol01@00Oomoogoo00001Woo00D007ooOomoo`0000=oo`04001oogoo0002Ool01000Oomoo`00
0goo0P008goo00L007ooOomoo`00Ool0000WOol00`00Oomoo`02Ool00`00Oomoo`03Ool01000Ool0
07oo0P0000=oo`0000000goo00<007oo00000Woo00@007ooOomoo`80029oo`03001oo`00009oo`03
001oo`0001Eoo`0047oo0P0017oo00<007ooOol08goo00<007ooOol00Woo00<007ooOol017oo00D0
07ooOomoo`0000=oo`04001oogoo0002Ool01000Oomoo`000goo0P008Woo0P0017oo00<007ooOol0
9Goo00<007ooOol00goo00<007ooOol00goo0P000Woo00D007oo001oo`0000=oo`03001oo`00009o
o`04001oogooOol2000SOol00`00Oomoo`02Ool00`00Oomoo`0DOol003aoo`03001oogoo009oo`03
001oogoo00=oo`03001oogoo009oo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOomo
o`80051oo`03001oogoo00=oo`03001oogoo009oo`03001oogoo009oo`05001oogooOol00003Ool0
0`00Ool00002Ool01000Oomoogoo0P00?goo000cOol20007Ool00`00Oomoo`02Ool00`00Oomoo`03
Ool00`00Oomoo`02Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`04001oogooOol20017Ool2
0007Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`02Ool01@00Oomoogoo00000goo00<0
07oo00000Woo00@007ooOomoo`8003moo`00<Woo00@007ooOol000Ioo`03001oogoo009oo`03001o
ogoo00=oo`03001oogoo009oo`05001oogooOol00002Ool01000Oomoo`000Woo00H007ooOol007oo
0016Ool01000Oomoo`001Woo00<007ooOol00goo00<007ooOol00Woo00<007ooOol00Woo00D007oo
Oomoo`0000=oo`03001oo`00009oo`06001oogoo001oo`00?goo000aOol01@00Oomoogoo00001Woo
00<007ooOol00Woo00<007ooOol00goo00<007ooOol00Woo00D007ooOomoo`00009oo`04001oogoo
0002Ool01P00Oomoo`00Ool004Eoo`05001oogooOol00006Ool00`00Oomoo`03Ool00`00Oomoo`02
Ool00`00Oomoo`02Ool01@00Oomoogoo00000goo00<007oo00000Woo00H007ooOol007oo000oOol0
035oo`05001oogooOol00006Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`02Ool01@00
Oomoogoo00000Woo00@007ooOol0009oo`06001oogoo001oo`0017oo00<007ooOol0?Woo00D007oo
Oomoo`0000Ioo`03001oogoo00=oo`03001oogoo009oo`03001oogoo009oo`05001oogooOol00003
Ool00`00Ool00002Ool01P00Oomoo`00Ool000Aoo`03001oogoo03Qoo`009Goo10001goo00<007oo
Ool00goo00<007ooOol00goo00<007ooOol00goo00<007ooOol00Woo00<007ooOol00Woo00D007oo
Oomoo`00009oo`04001oogoo0002Ool01000Oomoo`000Woo00<007ooOol00P00=7oo10001goo00<0
07ooOol00goo00<007ooOol00goo00<007ooOol00goo00<007ooOol00Woo00<007ooOol00Woo00D0
07ooOomoo`0000=oo`03001oo`00009oo`04001oogoo0002Ool00`00Oomoo`02000jOol000Ioool0
00H000Ioo`001Woo00<007ooOol02Goo00<007ooOol027oo00<007ooOol02Goo00<007oo00000`00
1Woo0P001Goo00L007ooOomoo`00Ool00004Ool00`00Oomoo`02Ool01@00Oomoogoo00000Woo00<0
07ooOol00P0000Eoo`00Oomoo`00009oo`05001oo`00Ool0000:Ool00`00Oomoo`09Ool00`00Oomo
o`08Ool00`00Oomoo`09Ool00`00Oomoo`08Ool00`00Ool000030006Ool20005Ool01`00Oomoogoo
001oo`0000Aoo`03001oogoo009oo`05001oogooOol00003Ool01P00Ool00000Ool0009oo`08001o
ogoo001oo`00Ool000Yoo`03001oogoo00Uoo`03001oogoo00Qoo`03001oogoo00Uoo`03001oogoo
00Yoo`00=goo00<007ooOol00Woo00<007ooOol00goo00<007ooOol00Woo00<007ooOol00Woo00D0
07ooOomoo`00009oo`04001oogoo0002Ool01000Oomoo`000Woo0P00BGoo00<007ooOol00Woo00<0
07ooOol00goo00<007ooOol00Woo00<007ooOol00Woo00D007ooOomoo`0000=oo`03001oo`00009o
o`04001oogoo0002Ool2000mOol003Moo`03001oogoo009oo`03001oogoo00=oo`03001oogoo009o
o`03001oogoo009oo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol000=oo`03001o
ogoo04Moo`03001oogoo009oo`03001oogoo00=oo`03001oogoo009oo`03001oogoo009oo`05001o
ogooOol00003Ool00`00Ool00002Ool01000Oomoo`000goo00<007ooOol0>goo000gOol00`00Oomo
o`02Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`02Ool01@00Oomoogoo00000Woo00@0
07ooOol0009oo`04001oogoo001=Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`02Ool0
0`00Oomoo`02Ool01@00Oomoogoo00000goo00<007oo00000Woo00@007ooOol0045oo`00=goo00D0
07ooOomoo`0000Ioo`03001oogoo009oo`03001oogoo009oo`05001oogooOol00002Ool01000Oomo
o`000Woo00<007oo0000CWoo00D007ooOomoo`0000Ioo`03001oogoo009oo`03001oogoo009oo`05
001oogooOol00003Ool00`00Ool00002Ool00`00Ool00012Ool003Moo`05001oogooOol00006Ool0
0`00Oomoo`02Ool00`00Oomoo`02Ool01@00Oomoogoo00000Woo00@007ooOol000=oo`8004ioo`05
001oogooOol00006Ool00`00Oomoo`02Ool00`00Oomoo`02Ool01@00Oomoogoo00000goo00<007oo
00000goo0P00@Woo000hOol01000Oomoo`001Woo00<007ooOol00Woo00<007ooOol00Woo00D007oo
Oomoo`00009oo`04001oogoo0003Ool2001?Ool01000Oomoo`001Woo00<007ooOol00Woo00<007oo
Ool00Woo00D007ooOomoo`0000=oo`03001oo`0000=oo`80049oo`00>7oo00<007oo00001goo00<0
07ooOol00Woo00<007ooOol00Woo00D007ooOomoo`00009oo`04001oogoo0003Ool2001?Ool00`00
Ool00007Ool00`00Oomoo`02Ool00`00Oomoo`02Ool01@00Oomoogoo00000goo00<007oo00000goo
0P00@Woo000iOol20007Ool00`00Oomoo`02Ool00`00Oomoo`02Ool01@00Oomoogoo00000Woo00@0
07ooOol000=oo`80051oo`8000Moo`03001oogoo009oo`03001oogoo009oo`05001oogooOol00003
Ool00`00Ool00003Ool20012Ool003Uoo`8000Qoo`05001oogooOol00004Ool01@00Oomoogoo0000
0Woo00@007ooOol000=oo`80051oo`8000Qoo`05001oogooOol00004Ool01@00Oomoogoo00000goo
00<007oo00000goo0P00@Woo000jOol00`00Oomoo`06Ool01@00Oomoogoo000017oo00D007ooOomo
o`00009oo`04001oogoo0003Ool2001AOol00`00Oomoo`06Ool01@00Oomoogoo000017oo00D007oo
Oomoo`0000=oo`03001oo`0000=oo`80049oo`00@goo00@007ooOol000Eoo`05001oogooOol00002
Ool01000Oomoo`000goo0P00FWoo00D007ooOomoo`0000Aoo`05001oogooOol00003Ool00`00Ool0
0003Ool20012Ool004=oo`04001oogoo0005Ool01@00Oomoogoo00000Woo00@007ooOol000=oo`80
05Yoo`05001oogooOol00004Ool01@00Oomoogoo00000goo00<007oo00000goo0P00@Woo0013Ool0
1000Oomoo`001Goo00D007ooOomoo`00009oo`04001oogoo0003Ool2001JOol01@00Oomoogoo0000
17oo00D007ooOomoo`0000=oo`03001oo`0000=oo`80049oo`00@goo00@007ooOol000Eoo`05001o
ogooOol00002Ool01000Oomoo`000goo0P00FWoo00D007ooOomoo`0000Aoo`05001oogooOol00003
Ool00`00Ool00003Ool20012Ool004=oo`04001oogoo0005Ool01@00Oomoogoo00000Woo00@007oo
Ool000Aoo`03001oogoo05Qoo`05001oogooOol00004Ool01@00Oomoogoo00000goo00<007oo0000
17oo00<007ooOol0@7oo0013Ool01000Oomoo`001Goo00D007ooOomoo`00009oo`04001oogoo0004
Ool00`00Oomoo`1HOol01@00Oomoogoo000017oo00D007ooOomoo`0000=oo`03001oo`0000Aoo`03
001oogoo041oo`00@goo00@007ooOol000Eoo`05001oogooOol00002Ool01000Oomoo`0017oo00<0
07ooOol0F7oo00D007ooOomoo`0000Aoo`05001oogooOol00003Ool00`00Ool00004Ool00`00Oomo
o`10Ool003Ioo`03001oogoo009oo`04001oogooOol300000goo001oo`020005Ool01@00Oomoogoo
00000Woo00@007ooOol005moo`05001oogooOol00004Ool01@00Oomoogoo00000goo00<007oo0000
Agoo000eOol00`00Ool00007Ool01000Oomoogoo0P0000=oo`00Ool017oo00D007ooOomoo`00009o
o`04001oogoo001OOol01@00Oomoogoo000017oo00D007ooOomoo`0000=oo`03001oo`0004Moo`00
=Goo00<007oo000027oo00L007ooOomoo`00Ool00005Ool20002Ool01000Oomoo`000Woo00<007oo
Ool0GWoo00@007ooOol000Aoo`05001oogooOol00003Ool00`00Ool00017Ool003Eoo`03001oo`00
00Qoo`04001oogooOol30005Ool20002Ool01000Oomoo`000Woo00<007ooOol0GWoo00@007ooOol0
00Eoo`04001oogoo0003Ool00`00Ool00017Ool003Eoo`03001oo`0000Moo`03001oo`00009oo`03
001oo`0000Eoo`80009oo`07001oogooOol007oo0000H7oo00@007ooOol000Eoo`04001oogoo0003
Ool00`00Ool00017Ool003Ioo`03001oogoo00Moo`04001oogooOol30005Ool20002Ool01`00Oomo
ogoo001oo`00061oo`04001oogoo0005Ool01000Oomoo`000goo00<007oo0000Agoo0014Ool00`00
Ool00005Ool20002Ool01`00Oomoogoo001oo`00061oo`04001oogoo0005Ool01000Oomoo`000goo
00<007oo0000Agoo0014Ool00`00Ool00005Ool20002Ool01`00Oomoogoo001oo`00061oo`03001o
o`0000Ioo`04001oogoo0003Ool00`00Ool00017Ool004Aoo`03001oo`0000Eoo`80009oo`07001o
ogooOol007oo0000H7oo00<007oo00001Woo00@007ooOol000=oo`03001oo`0004Moo`00A7oo00<0
07oo00001Goo0P000Woo00L007ooOomoo`00Ool0001POol00`00Ool00006Ool01000Oomoo`000goo
00<007oo0000Agoo0014Ool00`00Ool00005Ool20002Ool01`00Oomoogoo001oo`00061oo`03001o
o`0000Ioo`04001oogoo0003Ool00`00Ool00017Ool004Aoo`03001oo`0000Eoo`80009oo`07001o
ogooOol007oo0000H7oo00<007oo00001Woo00@007ooOol000=oo`03001oo`0004Moo`00A7oo00<0
07oo00001Goo0P000Woo00L007ooOomoo`00Ool0001POol00`00Ool00006Ool01000Oomoo`000goo
00<007oo0000Agoo0014Ool00`00Ool00005Ool20002Ool01`00Oomoogoo001oo`00061oo`03001o
o`0000Ioo`04001oogoo0003Ool00`00Ool00017Ool004Aoo`8000Ioo`80009oo`07001oogooOol0
07oo0000H7oo0P001goo00@007ooOol000=oo`03001oo`0004Moo`00AGoo00<007ooOol017oo0P00
0Woo00L007ooOomoo`00Ool0001QOol00`00Oomoo`05Ool01000Oomoo`000goo00<007oo0000Agoo
0015Ool00`00Oomoo`04Ool20002Ool01`00Oomoogoo001oo`00065oo`03001oogoo00Eoo`04001o
ogoo0003Ool00`00Ool00017Ool004aoo`80009oo`07001oogooOol007oo0000JGoo00@007ooOol0
00=oo`03001oo`0004Moo`00C7oo0P0000=oo`00Ool00goo00<007oo0000JGoo00<007oo000017oo
00<007oo0000Agoo001<Ool200000goo001oo`03Ool00`00Ool0001YOol00`00Ool00004Ool00`00
Ool00017Ool004aoo`800003Ool007oo00=oo`03001oo`0006Uoo`03001oo`0000Aoo`03001oo`00
04Moo`00>goo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol017oo0P0000=oo`00Ool00goo
00<007oo0000JGoo00<007oo000017oo00<007oo0000Agoo000jOol00`00Ool00007Ool00`00Ool0
0005Ool200000goo001oo`03Ool00`00Ool0001YOol00`00Ool00004Ool00`00Ool00017Ool003Yo
o`03001oo`0000Uoo`03001oogoo00=oo`800003Ool007oo00=oo`03001oo`0006Uoo`03001oo`00
00Aoo`03001oo`0004Moo`00>Woo00<007oo00001goo0P001Woo0P0000=oo`00Ool00goo00<007oo
0000JGoo00<007oo000017oo00<007oo0000Agoo000jOol00`00Ool00007Ool00`00Oomoo`05Ool2
00000goo001oo`03Ool00`00Ool0001YOol00`00Ool00004Ool00`00Ool00017Ool003]oo`03001o
ogoo00Ioo`<000Eoo`800003Ool007oo00=oo`03001oo`0006Uoo`03001oo`0000Aoo`03001oo`00
04Moo`00C7oo0P0000=oo`00Ool00goo00<007oo0000JGoo00<007oo000017oo00<007oo0000Agoo
001<Ool200000goo001oo`03Ool00`00Ool0001YOol00`00Ool00004Ool00`00Ool00017Ool004ao
o`800003Ool007oo00=oo`03001oo`0006Uoo`03001oo`0000Aoo`03001oo`0004Moo`00C7oo0P00
00=oo`00Ool00goo00<007oo0000JGoo00<007oo000017oo00<007oo0000Agoo001<Ool200000goo
001oo`03Ool00`00Ool0001YOol00`00Ool00004Ool00`00Ool00017Ool004aoo`800003Ool007oo
00=oo`8006Yoo`03001oo`0000Aoo`8004Qoo`00C7oo0P0000=oo`00Ool017oo00<007ooOol0J7oo
00<007oo00001Goo00<007ooOol0AWoo001<Ool01000Ool000001Goo00<007ooOol0JGoo0P001Goo
00<007ooOol0AWoo001<Ool01000Ool000001Goo00<007ooOol0JGoo0P001Goo00<007ooOol0AWoo
001<Ool01000Ool000001Goo00<007ooOol0JGoo0P001Goo00<007ooOol0AWoo001<Ool01000Ool0
00001Goo00<007ooOol0JGoo0P001Goo00<007ooOol0AWoo001<Ool01000Ool000001Goo00<007oo
Ool0JGoo0P001Goo00<007ooOol0AWoo001<Ool01000Ool000001Goo00<007ooOol0JGoo0P001Goo
00<007ooOol0AWoo001<Ool01000Ool000001Goo00<007ooOol0JGoo0P001Goo00<007ooOol0AWoo
001<Ool01000Ool000001Goo00<007ooOol0JGoo0P001Goo00<007ooOol0AWoo000fOol00`00Oomo
o`02Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`04Ool01000Ool00000LGoo0P00CWoo
000eOol00`00Ool00008Ool01`00Oomoogoo001oo`0000Eoo`04001oo`00001aOol2001>Ool003Eo
o`03001oo`0000Qoo`03001oogoo00=oo`03001oogoo00=oo`@0075oo`8004ioo`00=Goo00<007oo
00002Goo00<007ooOol00P001Woo00@007oo0000075oo`8004ioo`00=Goo00<007oo00001goo00<0
07oo00000Woo00<007ooOol01Goo00@007oo0000075oo`8004ioo`00=Woo00<007ooOol01Woo0`00
0Woo0`001Goo00@007oo0000075oo`8004ioo`00C7oo00<007oo0000LWoo00<007ooOol0CGoo001<
Ool00`00Ool0001bOol00`00Oomoo`1=Ool004aoo`03001oo`00079oo`03001oogoo04eoo`00C7oo
00<007oo0000LWoo00<007ooOol0CGoo001<Ool00`00Ool0001bOol00`00Oomoo`1=Ool004aoo`03
001oo`00079oo`03001oogoo04eoo`00C7oo00<007oo0000LWoo00<007ooOol0CGoo001<Ool00`00
Ool0001bOol00`00Oomoo`1=Ool004aoo`03001oo`00079oo`03001oogoo04eoo`00C7oo00<007oo
Ool0`Woo001<Ool00`00Oomoo`32Ool004aoo`03001oogoo0<9oo`00C7oo00<007ooOol0`Woo003o
OolBOol00?mooa9oo`00ogoo4Woo003oOolBOol00?mooa9oo`00ogoo4Woo003oOolBOol00?mooa9o
o`00ogoo4Woo003oOolBOol00?mooa9oo`00ogoo4Woo003oOolBOol00?mooa9oo`00ogoo4Woo000]
Ool00`00Oomoo`3QOol002eoo`800>9oo`00;Goo00<007ooOol0hGoo000]Ool00`00Oomoo`3QOol0
02eoo`04001oogoo000kOol00`00Oomoo`0iOol00`00Oomoo`0hOol00`00Oomoo`0[Ool002eoo`80
0003Ool007oo03Yoo`03001oogoo03Uoo`03001oogoo03Qoo`03001oogoo02]oo`00;Goo00@007oo
Ool003]oo`03001oogoo03Uoo`03001oogoo03Qoo`03001oogoo02]oo`00;Goo00@007ooOol003]o
o`03001oogoo03Qoo`8003Yoo`03001oogoo02]oo`00;Goo00@007ooOol003]oo`03001oogoo03Qo
o`8003Yoo`03001oogoo02]oo`00;Goo00@007ooOol003]oo`03001oogoo03Qoo`8003Yoo`03001o
ogoo02]oo`00;Goo0P0000=oo`00Ool0>Woo00<007ooOol0>7oo0P00>Woo00<007ooOol0:goo000]
Ool01000Oomoo`00>goo00<007ooOol0>7oo0P00>Woo00<007ooOol0:goo000]Ool01000Oomoo`00
>goo00<007ooOol0>7oo0P00>Woo00<007ooOol0:goo000]Ool01000Oomoo`00>goo00<007ooOol0
>7oo0P00>Woo00<007ooOol0:goo000]Ool200000goo001oo`0jOol00`00Oomoo`0hOol2000jOol0
0`00Oomoo`0[Ool002eoo`04001oogoo000kOol00`00Oomoo`0hOol2000jOol00`00Oomoo`0[Ool0
01Qoo`03001oogoo009oo`03001oogoo009oo`03001oogoo009oo`03001oogoo00=oo`04001oogoo
000kOol00`00Oomoo`0hOol2000jOol00`00Oomoo`0[Ool001Moo`03001oo`0000Qoo`07001oogoo
Ool007oo000017oo00@007ooOol003]oo`03001oogoo03Qoo`8003Yoo`03001oogoo02]oo`004Woo
0`000Woo00<007oo000027oo00<007ooOol00goo00<007ooOol00Woo1000>goo00<007ooOol0>7oo
0P00>Woo00<007ooOol0:goo000GOol00`00Ool00009Ool00`00Oomoo`020005Ool00`00Oomoo`02
000jOol00`00Oomoo`0hOol2000jOol2000/Ool001Moo`03001oo`0000Moo`03001oo`00009oo`03
001oogoo00Aoo`03001oogoo008003Yoo`03001oogoo03Qoo`8003Yoo`8002aoo`0067oo00<007oo
Ool01Woo0`000Woo0`0017oo00<007ooOol00P00>Woo00<007ooOol0>7oo0P00>Woo0P00;7oo000]
Ool200000goo0000000jOol00`00Oomoo`0hOol2000jOol2000/Ool002eoo`03001oogoo008003Yo
o`03001oogoo03Qoo`8003Yoo`8002aoo`00;Goo00<007ooOol00P00>Woo00<007ooOol0>7oo0P00
>Woo0P00;7oo000]Ool00`00Oomoo`02000jOol00`00Oomoo`0hOol2000jOol2000/Ool002eoo`80
0003Ool0000003Yoo`03001oogoo03Qoo`8003Yoo`8002aoo`00;Goo00<007ooOol00P00>Woo00<0
07ooOol0>7oo0P00>Woo0P00;7oo000/Ool20002Ool2000fOol01@00Oomoogoo0000=goo00<007oo
Ool00P00=Woo00@007ooOomoo`8002aoo`00;7oo0P000Woo0P00=Woo00<007ooOol00P00=goo00<0
07ooOol00P00=Woo00@007ooOomoo`8002aoo`00;7oo0P000Woo0P00=Woo00<007ooOol00P00=Woo
0P000Woo0P00=Woo00@007ooOomoo`8002aoo`00;7oo0`0000=oo`000000=Woo00<007ooOol00P00
=Woo0P000Woo0P00=Woo00@007ooOomoo`8002aoo`00;7oo0P000Woo0P00=Woo00<007ooOol00P00
=Woo0P000Woo0P00=Woo0P000Woo0P00;7oo000/Ool20002Ool2000fOol00`00Oomoo`02000fOol2
0002Ool2000fOol20002Ool2000/Ool002aoo`80009oo`8003Ioo`03001oogoo008003Ioo`80009o
o`8003Ioo`80009oo`8002aoo`00;7oo0`0000=oo`000000=Woo00<007ooOol00P00=Woo0P000Woo
0P00=Woo0P000Woo0P00;7oo000/Ool20002Ool2000fOol00`00Oomoo`02000fOol20002Ool2000f
Ool20002Ool2000/Ool001eoo`03001oogoo009oo`03001oogoo009oo`03001oogoo009oo`80009o
o`8003Ioo`03001oogoo008003Ioo`80009oo`8003Ioo`80009oo`8002aoo`0077oo00<007oo0000
1goo00<007oo00000goo0P000Woo0P00=Woo00<007ooOol00P00=Woo0P000Woo0P00=Woo0P000Woo
0P00;7oo000GOol30002Ool00`00Ool00009Ool01000Oomoogoo1P00=Woo00<007ooOol00P00=Woo
0P000Woo0P00=Woo0P000Woo0P00;7oo000LOol00`00Ool00007Ool20004Ool20002Ool2000eOol2
0002Ool2000fOol20002Ool2000eOol00`00Ool00002Ool2000/Ool001aoo`03001oo`0000Moo`03
001oogoo00=oo`80009oo`8003Eoo`80009oo`8003Ioo`80009oo`8003Eoo`03001oo`00009oo`80
02aoo`007Goo00<007ooOol01Woo0`000goo0P000Woo0P00=Goo0P000Woo0P00=Woo0P000Woo0P00
=Goo00<007oo00000Woo0P00;7oo000/Ool300000goo0000000eOol20002Ool2000fOol20002Ool2
000eOol00`00Ool00002Ool2000/Ool002aoo`80009oo`8003Eoo`80009oo`8003Ioo`80009oo`80
03Eoo`03001oo`00009oo`8002aoo`00;7oo0P000Woo0P0000=oo`00Ool0<Woo00@007oo001oo`80
009oo`03001oogoo035oo`80009oo`80009oo`03001oogoo031oo`03001oo`00009oo`800003Ool0
07oo02Uoo`00;7oo0P000Woo0P0000=oo`00Ool0<Woo00@007oo001oo`80009oo`03001oogoo035o
o`80009oo`80009oo`03001oogoo031oo`03001oo`00009oo`800003Ool007oo02Uoo`00;7oo0P00
0Woo0P0000=oo`00Ool0<Woo00@007oo001oo`80009oo`03001oogoo035oo`80009oo`80009oo`03
001oogoo031oo`03001oo`00009oo`800003Ool007oo02Uoo`00;7oo0`0000Eoo`00001oo`0003=o
o`04001oo`00Ool20002Ool00`00Oomoo`0aOol20002Ool20002Ool00`00Oomoo`0`Ool00`00Ool0
0002Ool200000goo001oo`0YOol002aoo`80009oo`800003Ool007oo039oo`04001oo`00Ool20002
Ool00`00Oomoo`0aOol20002Ool20002Ool00`00Oomoo`0`Ool00`00Ool00002Ool200000goo001o
o`0YOol002aoo`80009oo`800003Ool007oo039oo`04001oo`00Ool20002Ool00`00Oomoo`0aOol2
0002Ool20002Ool00`00Oomoo`0`Ool00`00Ool00002Ool200000goo001oo`0YOol002aoo`80009o
o`800003Ool00000039oo`04001oo`00Ool20002Ool00`00Oomoo`0aOol20002Ool200000goo0000
000bOol00`00Ool00002Ool200000goo0000000YOol002aoo`<00004Ool00000Ool2000bOol01000
Ool007oo0P000Woo00<007ooOol0<Goo0P000Woo0P0000=oo`000000<Woo00<007oo00000Woo0P00
00=oo`000000:Goo000/Ool20002Ool200000goo0000000bOol01000Ool007oo0P000Woo00<007oo
Ool0<Goo0P000Woo0P0000=oo`000000<Woo00<007oo00000Woo0P0000=oo`000000:Goo000/Ool2
0002Ool200000goo0000000bOol01000Ool007oo0P000Woo00<007ooOol0<Goo0P000Woo0P0000=o
o`000000<Woo00<007oo00000Woo0P0000=oo`000000:Goo000/Ool20002Ool200000goo0000000b
Ool01000Ool007oo0P000Woo00<007ooOol0<Goo0P000Woo0P0000=oo`000000<Woo00<007oo0000
0Woo0P0000=oo`000000:Goo000/Ool3000017oo000007oo0P00<Woo00@007oo001oo`80009oo`03
001oogoo035oo`80009oo`800003Ool00000039oo`03001oo`00009oo`800003Ool0000002Uoo`00
:goo00<007oo00000Woo0P0000=oo`000000<Woo00@007oo001oo`80009oo`03001oogoo031oo`03
001oo`00009oo`800003Ool00000039oo`03001oo`00009oo`800003Ool0000002Uoo`0067oo00<0
07ooOol00Woo00@007ooOomoo`<000=oo`07001oogooOol007oo00000Woo0P0000=oo`000000<Woo
00@007oo001oo`80009oo`03001oogoo031oo`03001oo`00009oo`800003Ool00000039oo`03001o
o`00009oo`800003Ool0000002Uoo`005goo00<007oo00001goo00<007ooOol00Woo00<007oo0000
0Woo00<007oo00000Woo0P0000=oo`000000<Woo00T007oo001oo`00Ool007oo0000<Woo00<007oo
00000Woo0P0000=oo`000000<Woo00<007oo00000Woo0P0000=oo`000000:Goo000BOol30002Ool0
0`00Ool00008Ool00`00Oomoo`02Ool20002Ool00`00Ool0000400000goo0000000]Ool00`00Oomo
o`02Ool02@00Ool007oo001oo`00Ool0000^Ool01`00Oomoogoo001oo`00009oo`800003Ool00000
02ioo`07001oogooOol007oo00000Woo0P0000=oo`000000:Goo000GOol00`00Ool00008Ool01000
Oomoogoo0P000goo00<007oo00000Woo0P0000=oo`000000;Goo0P000goo00T007oo001oo`00Ool0
07oo0000;Woo00L007ooOomoo`00Ool00002Ool200000goo0000000]Ool20003Ool00`00Ool00002
Ool200000goo0000000YOol001Moo`03001oo`0000Moo`03001oo`00009oo`8000=oo`03001oo`00
009oo`800003Ool0000002eoo`8000=oo`09001oo`00Ool007oo001oo`0002ioo`07001oogooOol0
07oo00000Woo0P0000=oo`000000;Goo0P000goo00<007oo00000Woo0P0000=oo`000000:Goo000H
Ool00`00Oomoo`07Ool01000Oomoogoo0`000Woo00<007oo00000Woo0P0000=oo`000000;Goo0P00
0goo00T007oo001oo`00Ool007oo0000;Woo00L007ooOomoo`00Ool00002Ool200000goo0000000]
Ool20003Ool00`00Ool00002Ool200000goo0000000YOol002Ioo`8000=oo`05001oo`00001oo`02
00000goo0000000]Ool20003Ool02@00Ool007oo001oo`00Ool0000]Ool20003Ool00`00Ool00002
Ool200000goo0000000]Ool20003Ool00`00Ool00002Ool200000goo0000000YOol002Ioo`8000=o
o`03001oo`00009oo`800003Ool0000002eoo`8000=oo`09001oo`00Ool007oo001oo`0002eoo`03
001oo`00009oo`03001oo`00009oo`800003Ool0000002eoo`8000=oo`03001oo`00009oo`800003
Ool0000002Uoo`009Woo0P000goo00<007oo00000Woo0P0000=oo`000000;Goo0P000goo00T007oo
001oo`00Ool007oo0000;Goo00<007oo00000Woo00<007oo00000Woo0P0000=oo`000000;Goo0P00
0goo00<007oo00000Woo0P0000=oo`000000:Goo000VOol20003Ool00`00Ool00002Ool200000goo
0000000]Ool20003Ool02@00Ool007oo001oo`00Ool0000]Ool00`00Ool00002Ool00`00Ool00002
Ool200000goo0000000]Ool20003Ool00`00Ool00002Ool200000goo0000000YOol002Ioo`8000=o
o`03001oo`00009oo`800003Ool0000002eoo`8000=oo`08001oo`00Ool007oo001oo`8002aoo`03
001oo`00009oo`03001oo`00009oo`800003Ool0000002eoo`8000=oo`03001oo`00009oo`800003
Ool0000002Uoo`009Woo0P000goo00D007oo000007oo00800003Ool0000002aoo`03001oo`0000=o
o`08001oo`00Ool007oo001oo`8002aoo`03001oo`00009oo`03001oo`00009oo`800003Ool00000
02aoo`03001oo`0000=oo`03001oo`00009oo`800003Ool0000002Uoo`009Woo0P000goo00<007oo
00000Woo0P0000=oo`000000;7oo00<007oo00001P0000Eoo`00Ool007oo008002aoo`03001oo`00
00<00003Ool007oo00<00003Ool0000002aoo`04001oo`00Ool300000goo001oo`0300000goo0000
000YOol002Ioo`03001oo`00009oo`03001oo`00009oo`800003Ool0000002aoo`03001oo`00009o
o`800003Ool0000000<00003Ool0000002aoo`06001oo`00001oo`000Woo00D007oo000007oo0080
02aoo`04001oogoo0002Ool01@00Ool00000Ool00P0000=oo`000000:Goo000VOol00`00Ool00002
Ool00`00Ool00002Ool200000goo0000000/Ool00`00Ool00002Ool200000goo0000000300000goo
0000000/Ool01000Ool007oo0P000Woo00D007oo000007oo008002aoo`05001oogoo001oo`020000
17oo000007oo0P0000=oo`000000:Goo000VOol00`00Ool00002Ool00`00Ool0000200000goo001o
o`0200000goo001oo`0YOol00`00Ool00002Ool200000goo00000004000017oo001oo`00:Woo00@0
07oo001oo`80009oo`05001oo`00001oo`020002Ool00`00Oomoo`0WOol01000Oomoo`000Woo00<0
07oo00001@0000Aoo`00Ool002Moo`009Woo00<007oo00000Woo00P007oo001oo`00Ool007oo0P00
00=oo`00Ool0:Goo00<007oo00000Woo0P0000=oo`000000100000Aoo`00Ool002Yoo`06001oo`00
001oo`000Woo00D007oo000007oo00800003Ool0000002Uoo`03001oogoo00800003Ool007oo00H0
0004Ool007oo000WOol002Eoo`04001oogoo0002Ool02000Ool007oo001oo`00Ool200000goo001o
o`0YOol01000Ool007oo0`0000Eoo`00Ool007oo00800004Ool007oo000YOol01@00Oomoo`00Ool0
0P000Woo100000Aoo`00001oo`8002Uoo`05001oogoo001oo`0200001Goo001oo`00Ool00P0000Ao
o`00Ool002Moo`009Goo00@007ooOol0009oo`08001oo`00Ool007oo001oo`800003Ool0000002Uo
o`03001oo`00009oo`07001oogoo001oo`00Ool00P0000Aoo`00Ool002Uoo`04001oogoo0002Ool0
1@00Oomoo`00Ool00P0000Aoo`00001oo`8002Uoo`04001oogoo0002Ool01P00Ool007oo001oo`80
0003Ool007oo008002Ioo`0087oo0P000goo00@007ooOol0009oo`03001oo`0000800003Ool007oo
00800003Ool0000002Aoo`03001oogoo009oo`03001oo`00009oo`07001oogoo001oo`00Ool00P00
00Aoo`00000002Aoo`8000=oo`04001oogoo0002Ool01@00Oomoo`00Ool00P0000Aoo`00001oo`80
02Aoo`8000=oo`04001oogoo0002Ool01P00Ool007oo001oo`800005Ool00000Ool0000VOol0021o
o`8000=oo`04001oogoo0002Ool02000Ool007oo001oo`00Ool200000goo0000000SOol00`00Ool0
0003Ool00`00Ool00002Ool01`00Oomoo`00Ool007oo00800004Ool00000000TOol20003Ool01000
Oomoo`000Woo00D007ooOol007oo00800004Ool00000Ool2000SOol00`00Ool00003Ool01000Oomo
o`000Woo00H007oo001oo`00Ool200001Goo000007oo00009Woo000OOol00`00Ool00003Ool01000
Oomoo`000Woo00P007oo001oo`00Ool007oo0P0000=oo`0000008goo00<007oo00000goo00<007oo
00000Woo00L007ooOol007oo001oo`02000017oo000000008goo00@007ooOol0009oo`04001oogoo
0002Ool01@00Oomoo`00Ool00P0000Aoo`00001oo`8002=oo`03001oo`0000=oo`04001oogoo0002
Ool01P00Ool007oo001oo`800005Ool00000Ool0000VOol001moo`03001oo`0000=oo`04001oogoo
0002Ool02000Ool007oo001oo`00Ool200001Goo000007oo000087oo00@007ooOol000=oo`06001o
ogoo001oo`000Woo00@007oo001oo`800005Ool00000001oo`02000POol01000Oomoo`000Woo00@0
07ooOol0009oo`05001oogoo001oo`02000017oo000007oo0P0000=oo`00Ool087oo00<007oo0000
0goo00@007ooOol0009oo`06001oo`00Ool007oo0P0000Aoo`00001oo`<002Aoo`001Wooo`001P00
1Woo0009Ool00`00Oomoo`09Ool00`00Oomoo`03Ool2000017oo001oogoo0P000Woo00@007ooOol0
009oo`08001oo`00Ool007oo001oo`800003Ool0000000<000Yoo`03001oogoo00Uoo`03001oogoo
00=oo`800005Ool007ooOol00002Ool01`00Oomoogoo001oo`00009oo`04001oo`00Ool2000017oo
000007oo10002Goo00<007ooOol02Goo00<007ooOol017oo00<007oo00000Woo0P000Woo00@007oo
Ool0009oo`05001oo`00001oo`02000017oo000007oo1P002Goo00<007ooOol02Goo00<007ooOol0
0goo0P0000Aoo`00Oomoo`80009oo`04001oogoo0002Ool01P00Ool007oo001oo`800004Ool00000
Ool4000:Ool00`00Oomoo`09Ool00`00Oomoo`0:Ool001eoo`8000=oo`04001oogoo0002Ool02`00
Oomoo`00Ool007oo001oo`00Ool00P0000Aoo`00000001moo`8000=oo`04001oogoo0003Ool00`00
Ool00002Ool01000Ool007oo0P0000Eoo`00001oo`00021oo`8000=oo`04001oogoo0002Ool01@00
Oomoo`00Ool00P0000Aoo`00001oo`800004Ool00000000POol20003Ool01000Oomoo`000Woo00T0
07ooOol007oo001oo`00Ool00P0000Aoo`00001oo`8002Eoo`008Woo00@007ooOol0009oo`0;001o
ogoo001oo`00Ool007oo001oo`02000017oo000000009Goo00<007oo00000goo00<007oo00000Woo
00@007oo001oo`800005Ool00000Ool0000UOol01000Oomoo`000Woo00@007ooOol0009oo`05001o
o`00001oo`02000017oo001oo`009Goo00@007ooOol0009oo`09001oogoo001oo`00Ool007oo0080
0004Ool00000Ool2000UOol0029oo`04001oogoo0002Ool02`00Oomoo`00Ool007oo001oo`00Ool0
0P0000=oo`0000009Woo00<007oo00000goo00<007oo00000Woo00@007oo001oo`800005Ool00000
Ool0000UOol01000Oomoo`000Woo00@007ooOol0009oo`05001oo`00001oo`02000017oo001oo`00
9Goo00@007ooOol0009oo`09001oogoo001oo`00Ool007oo00800005Ool00000Ool0000VOol002=o
o`8000=oo`05001oogoo001oo`0300000goo001oo`03000XOol00`00Ool00003Ool00`00Ool00002
Ool01000Ool007oo0P0000=oo`000000:7oo00<007oo00000Woo00@007ooOol0009oo`05001oo`00
001oo`03000XOol00`00Ool00003Ool02@00Oomoo`00Ool007oo001oo`0200000goo0000000XOol0
02=oo`8000=oo`0;001oogoo001oo`00Ool007oo001oo`03000XOol00`00Ool00003Ool00`00Ool0
0002Ool01000Ool007oo0P0000=oo`000000:7oo00<007oo00000Woo00@007ooOol0009oo`08001o
o`00001oo`00Ool002Qoo`03001oo`0000=oo`09001oogoo001oo`00Ool007oo00800003Ool00000
02Qoo`008goo0P000goo00/007ooOol007oo001oo`00Ool007oo00<002Qoo`03001oo`0000=oo`03
001oo`00009oo`04001oo`00Ool200000goo0000000XOol00`00Ool00002Ool01000Oomoo`000Woo
00P007oo000007oo001oo`00:7oo00<007oo00000goo00T007ooOol007oo001oo`00Ool00P0000=o
o`000000:7oo000SOol20003Ool02`00Oomoo`00Ool007oo001oo`00Ool00`00:Goo0P000goo00<0
07oo00000Woo00@007oo001oo`800003Ool0000002Qoo`03001oo`00009oo`04001oogoo0002Ool0
2000Ool00000Ool007oo000YOol20003Ool02@00Oomoo`00Ool007oo001oo`0200000goo0000000X
Ool002=oo`8000=oo`05001oogoo001oo`0300000goo001oo`03000YOol20003Ool00`00Ool00002
Ool01000Ool007oo0P0000=oo`000000:7oo0P000goo00@007ooOol0009oo`08001oo`00001oo`00
Ool002Uoo`8000=oo`09001oogoo001oo`00Ool007oo00800003Ool0000002Qoo`008goo0P0017oo
00X007oo001oo`00Ool007oo001oo`<002Uoo`8000=oo`03001oo`00009oo`04001oo`00Ool20000
0goo0000000YOol00`00Oomoo`02Ool00`00Ool00002Ool02000Ool00000Ool007oo000YOol20003
Ool02@00Oomoo`00Ool007oo001oo`0200000goo0000000XOol002=oo`8000Aoo`0:001oo`00Ool0
07oo001oo`00Ool3000YOol00`00Oomoo`02Ool00`00Ool00002Ool01000Ool007oo0P0000=oo`00
0000:Goo00<007ooOol00Woo00<007oo00000Woo00P007oo000007oo001oo`00:Goo0P000goo00T0
07ooOol007oo001oo`00Ool00P0000=oo`000000:7oo000YOol02P00Ool007oo001oo`00Ool007oo
0`00;Woo00<007oo00000Woo00@007oo001oo`800003Ool0000002ioo`03001oo`00009oo`08001o
o`00001oo`00Ool002ioo`09001oogoo001oo`00Ool007oo00800003Ool0000002Qoo`00:Goo0P00
0Woo0`0000=oo`00Ool00`00;Woo00<007oo00000Woo00@007oo001oo`800003Ool0000002ioo`03
001oo`00009oo`08001oo`00001oo`00Ool002ioo`03001oo`00009oo`04001oo`00Ool200000goo
0000000XOol002Uoo`80009oo`06001oo`00Ool007oo0`00;Woo00<007oo00000Woo00@007oo001o
o`800003Ool0000002ioo`03001oo`00009oo`08001oo`00001oo`00Ool002ioo`03001oo`00009o
o`04001oo`00Ool200000goo0000000XOol002Uoo`80009oo`06001oo`00Ool007oo0`00;Woo00<0
07oo00000Woo00@007oo001oo`800003Ool007oo02ioo`03001oo`00009oo`08001oo`00001oo`00
Ool002ioo`03001oo`00009oo`04001oo`00Ool200000goo0000000XOol002Uoo`80009oo`06001o
o`00Ool007oo0`00;Woo00<007oo00000Woo00@007oo001oo`800003Ool007oo02ioo`03001oo`00
009oo`08001oo`00001oo`00Ool002ioo`03001oo`00009oo`04001oo`00Ool200000goo0000000X
Ool002Uoo`80009oo`<00006Ool007oo001oo`00;Woo00<007oo00000Woo00@007oo001oo`800003
Ool007oo02ioo`03001oo`00009oo`08001oo`00001oo`00Ool002ioo`03001oo`00009oo`04001o
o`00Ool20002Ool00`00Oomoo`0VOol002Uoo`80009oo`09001oo`00Ool007oo001oo`0002ioo`03
001oo`00009oo`04001oo`00Ool200000goo001oo`0^Ool00`00Ool00002Ool02000Ool00000Ool0
07oo000^Ool00`00Ool00002Ool01000Ool007oo0P000Woo00<007ooOol09Woo000YOol20002Ool0
2@00Ool007oo001oo`00Ool0000^Ool00`00Ool00002Ool01000Ool007oo0P0000=oo`00Ool0;Woo
00<007oo00000Woo00P007oo000007oo001oo`00;Woo00<007oo00000Woo00@007oo001oo`80009o
o`03001oogoo02Ioo`0067oo00<007ooOol00Woo00@007ooOomoo`<000=oo`04001oo`000002Ool0
1`00Ool007oo001oo`00031oo`03001oo`00009oo`04001oo`00Ool2000aOol00`00Ool00002Ool0
1P00Ool00000Ool0031oo`03001oo`00009oo`04001oo`00Ool2000[Ool001Moo`03001oo`0000Mo
o`03001oogoo009oo`03001oo`000080009oo`07001oo`00Ool007oo0000<Goo0P000Woo00@007oo
001oo`80035oo`03001oo`00009oo`06001oo`00001oo`00<Goo0P000Woo00@007oo001oo`8002]o
o`005goo00<007oo000027oo00<007ooOol00goo0`000Woo0`0000Aoo`00Ool0035oo`80009oo`04
001oo`00Ool2000aOol00`00Ool00002Ool01P00Ool00000Ool0035oo`8000=oo`800003Ool00000
02]oo`005goo00<007oo000027oo00@007ooOomoo`800003Ool00000009oo`<00004Ool007oo000a
Ool20002Ool01000Ool007oo0P00<Goo00<007oo00000Woo00H007oo000007oo000aOol20003Ool2
00000goo0000000[Ool001Moo`03001oo`0000Moo`03001oo`00009oo`03001oogoo0080009oo`<0
0004Ool007oo000aOol20002Ool01000Ool007oo0P00<Goo00<007oo00000Woo00@007oo001oo`80
035oo`8000=oo`800003Ool0000002]oo`0067oo00<007ooOol01goo00@007ooOomoo`D0009oo`<0
0003Ool00000039oo`80009oo`04001oo`00Ool2000aOol00`00Ool00002Ool01@00Ool007oo0000
<Woo0P000goo0P0000=oo`000000:goo000YOol20002Ool300000goo0000000bOol20002Ool01000
Ool007oo0P00<Goo0P000goo00D007oo001oo`00039oo`8000=oo`800003Ool0000002]oo`00:Goo
0P000Woo0`0000=oo`000000<Woo0P000Woo00@007oo001oo`80035oo`8000=oo`05001oo`00Ool0
000bOol20003Ool200000goo0000000[Ool002Uoo`80009oo`<00003Ool00000039oo`80009oo`04
001oo`00Ool2000aOol20003Ool01@00Ool007oo0000<Woo0P000goo0P0000=oo`000000:goo000Y
Ool20002Ool300000goo0000000bOol20002Ool01000Ool007oo0P00<Goo0P000goo00D007oo001o
o`00039oo`8000=oo`800003Ool0000002]oo`00:Goo0P000Woo0`0000=oo`000000<Woo0P000Woo
00@007oo001oo`80039oo`09001oogooOol007oo001oo`00039oo`8000=oo`800003Ool0000002]o
o`00:Goo0P000Woo0`0000=oo`000000<Woo0P000Woo00@007oo001oo`80039oo`09001oogooOol0
07oo001oo`00039oo`8000=oo`800003Ool0000002]oo`00:Goo0P000Woo0`0000=oo`000000<Woo
0P000Woo00@007oo001oo`80039oo`09001oogooOol007oo001oo`00039oo`8000=oo`800003Ool0
000002]oo`00:Goo0P000Woo0`0000=oo`000000<Woo00P007ooOomoo`00Ool007oo0P00<Woo00T0
07ooOomoo`00Ool007oo0000<Woo0P000goo0P0000=oo`000000:goo000ZOol00`00Oomoo`030000
0goo0000000bOol02000Oomoogoo001oo`00Ool2000bOol02@00Oomoogoo001oo`00Ool0000cOol0
1000Oomoogoo0P0000=oo`000000:goo000ZOol00`00Oomoo`0300000goo0000000bOol02000Oomo
ogoo001oo`00Ool2000bOol02@00Oomoogoo001oo`00Ool0000cOol01000Oomoogoo0P0000=oo`00
0000:goo000]Ool300000goo0000000fOol01000Ool007oo0P00=Woo00D007oo001oo`0003Moo`80
0003Ool0000002]oo`00;Goo0`0000=oo`000000=Woo00@007oo001oo`8003Ioo`05001oo`00Ool0
000gOol200000goo0000000[Ool002eoo`<00003Ool0000003Ioo`80009oo`8003Ioo`80009oo`03
001oogoo03Eoo`800003Ool0000002]oo`00;Goo0`0000=oo`000000=Woo0P000Woo0P00=Woo0P00
0Woo00<007ooOol0=Goo0P0000=oo`000000:goo000]Ool300000goo0000000fOol20002Ool2000f
Ool20002Ool00`00Oomoo`0eOol200000goo0000000[Ool001eoo`03001oogoo009oo`03001oogoo
009oo`03001oogoo00=oo`<00003Ool0000003Ioo`80009oo`8003Ioo`80009oo`03001oogoo03Eo
o`800003Ool0000002]oo`0077oo00<007oo00001goo00<007oo000017oo0`0000=oo`000000=Woo
0P000Woo0P00=Woo0P000Woo00<007ooOol0=Goo0P0000=oo`000000:goo000LOol00`00Ool00009
Ool00`00Oomoo`02Ool300000goo0000000fOol20002Ool2000fOol20002Ool00`00Oomoo`0eOol2
00000goo0000000[Ool001aoo`03001oo`0000Moo`8000Eoo`<00003Ool0000003Ioo`80009oo`80
03Ioo`80009oo`03001oogoo03Eoo`800003Ool0000002]oo`0077oo00<007oo00001goo00<007oo
Ool017oo0`0000=oo`000000=Woo0P000Woo0P00=Woo0P000Woo00<007ooOol0=Goo0P0000=oo`00
0000:goo000MOol00`00Oomoo`06Ool30004Ool300000goo0000000fOol20002Ool2000fOol20002
Ool00`00Oomoo`0eOol200000goo0000000[Ool002eoo`<00003Ool0000003Ioo`80009oo`8003Io
o`80009oo`03001oogoo03Eoo`800003Ool0000002]oo`00;Goo0`0000=oo`000000=Woo0P000Woo
0P00=Woo0P000Woo00<007ooOol0=Goo0P0000=oo`000000:goo000]Ool300000goo0000000fOol2
0002Ool2000fOol20002Ool00`00Oomoo`0eOol200000goo0000000[Ool002eoo`<00003Ool00000
03Ioo`80009oo`8003Ioo`80009oo`03001oogoo03Eoo`800003Ool0000002]oo`00;Goo0`0000=o
o`000000=Woo0P000Woo00<007ooOol0=Goo0P000Woo00<007ooOol0=Goo0P0000=oo`000000:goo
000]Ool300000goo0000000fOol20002Ool00`00Oomoo`0eOol20002Ool00`00Oomoo`0eOol20000
0goo0000000[Ool002eoo`<0009oo`03001oogoo03Eoo`04001oogoo000gOol20002Ool00`00Oomo
o`0eOol20002Ool00`00Oomoo`0YOol002eoo`<0009oo`03001oogoo03Eoo`04001oogoo000gOol2
0002Ool00`00Oomoo`0eOol20002Ool00`00Oomoo`0YOol002eoo`<0009oo`03001oogoo03Eoo`04
001oogoo000gOol20002Ool00`00Oomoo`0eOol20002Ool00`00Oomoo`0YOol002eoo`<0009oo`03
001oogoo03Eoo`04001oogoo000gOol20002Ool00`00Oomoo`0eOol20002Ool00`00Oomoo`0YOol0
02eoo`<0009oo`03001oogoo03Eoo`04001oogoo000gOol20002Ool00`00Oomoo`0eOol20002Ool0
0`00Oomoo`0YOol002eoo`<0009oo`03001oogoo03Eoo`04001oogoo000gOol20002Ool00`00Oomo
o`0eOol20002Ool00`00Oomoo`0YOol002eoo`<0009oo`03001oogoo03Eoo`04001oogoo000gOol2
0002Ool00`00Oomoo`0eOol20002Ool00`00Oomoo`0YOol002eoo`<0009oo`03001oogoo03Eoo`04
001oogoo000gOol20002Ool00`00Oomoo`0eOol20002Ool00`00Oomoo`0YOol002eoo`<003Yoo`03
001oogoo03Qoo`8003Yoo`8002ioo`0067oo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol0
0Woo00<007ooOol00goo0`00>Woo00<007ooOol0>7oo0P00>Woo0P00;Woo000GOol00`00Ool00008
Ool01`00Oomoogoo001oo`0000Aoo`<003Yoo`03001oogoo03Qoo`8003Yoo`8002ioo`005goo00<0
07oo000027oo00<007ooOol00goo00<007ooOol00Woo0`00>Woo00<007ooOol0>7oo0P00>Woo0P00
;Woo000GOol00`00Ool00009Ool00`00Oomoo`020005Ool3000jOol00`00Oomoo`0hOol2000jOol2
000^Ool001Moo`03001oo`0000Moo`03001oo`00009oo`03001oogoo00Aoo`<003Yoo`03001oogoo
03Qoo`8003Yoo`8002ioo`0067oo00<007ooOol01Woo0`000Woo0`0017oo0`00>Woo00<007ooOol0
>7oo0P00>Woo0P00;Woo000]Ool2000kOol00`00Oomoo`0hOol2000jOol00`00Oomoo`0]Ool002eo
o`8003]oo`03001oogoo03Qoo`8003Yoo`03001oogoo02eoo`00;Goo0P00>goo00<007ooOol0>7oo
0P00>Woo00<007ooOol0;Goo000]Ool2000kOol00`00Oomoo`0hOol2000jOol00`00Oomoo`0]Ool0
02eoo`8003]oo`03001oogoo03Uoo`03001oogoo03Qoo`03001oogoo02eoo`00;Goo0P00>goo00<0
07ooOol0>Goo00<007ooOol0>7oo00<007ooOol0;Goo000]Ool2000kOol00`00Oomoo`0iOol00`00
Oomoo`0hOol00`00Oomoo`0]Ool002eoo`8003]oo`03001oogoo03Uoo`03001oogoo03Qoo`03001o
ogoo02eoo`00;Goo0P00>goo00<007ooOol0>Goo00<007ooOol0>7oo00<007ooOol0;Goo000]Ool0
0`00Oomoo`3QOol002eoo`03001oogoo0>5oo`00;Goo00<007ooOol0hGoo000]Ool00`00Oomoo`3Q
Ool00?mooa9oo`00ogoo4Woo003oOolBOol00?mooa9oo`00ogoo4Woo003oOolBOol00?mooa9oo`00
ogoo4Woo0000\
\>"],
  ImageRangeCache->{{{0, 272.875}, {354.438, 0}} -> {-0.0250052, -0.0329947, 
  0.00384795, 0.00384795}, {{6.5, 266.375}, {345.813, 
  185.25}} -> {-13.2116, -1.0619, 0.173791, 0.011842}, {{6.5, 266.375}, {
  169.188, 8.5625}} -> {-7.62765, -3.15293, 0.167679, 0.0118385}}],

Cell[TextData[{
  "Note however, that there is no single and universal mother wavelet \
function. The mother wavelet must simply satisfy a small set of conditions \
and is typically selected based on the signal processing problem domain. \
Almost all useful wavelet systems satisfy the multiresolution condition. This \
means that given an approximation of a signal ",
  Cell[BoxData[
      \(TraditionalForm\`f(t)\)]],
  " using translates of a mother wavelet up to some chosen scale, we can \
achieve a better approximation by using expansion signals with half the width \
and half as wide translation steps. This is conceptually similar to improving \
frequency resolution by doubling the number of harmonics (i.e. halving the \
fundamental harmonic) in a Fourier series expansion. The multiresolution \
formulation needs two closely related functions: the wavelet function ",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi](t)\)]],
  " and the so-called ",
  StyleBox["scaling",
    FontSlant->"Italic"],
  " function ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi](t)\)]],
  ". Equation (1) may now be reformulated as follows:"
}], "Text"],

Cell[TextData[{
  "\t",
  Cell[BoxData[
      \(TraditionalForm
      \`f(t) = \ 
        \[Sum]\+\(k = \(-\[Infinity]\)\)\%\[Infinity]\( c\_k\) 
              \(\[Phi](t - k)\)\  + \ 
          \[Sum]\+\(k = \(-\[Infinity]\)\)\%\[Infinity]\ 
            \(\[Sum]\+\(j = 0\)\%\[Infinity]\ 
              d\_\(j, k\)\ \(\[Psi](\(2\^j\) t\  - \ k)\)\)\)]]
}], "NumberedEquation"]
}, Open  ]],

Cell[CellGroupData[{

Cell["SCALING AND WAVELET FUNCTIONS", "Section"],

Cell[TextData[{
  "The scaling function ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi](t)\)]],
  " has a recursive formulation which involves the scaling coefficents ",
  Cell[BoxData[
      \(TraditionalForm\`h(n)\)]],
  ". This recursive relation called the ",
  StyleBox["dilation equation",
    FontSlant->"Italic"],
  " (also refinement equation, multiresolution equation) is a ",
  StyleBox["two scale",
    FontSlant->"Italic"],
  " difference equation."
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm
      \`\(\[Phi](t)\  = \ 
        \@2\ \(\[Sum]\+n\( h(n)\)\ \(\[Phi](2  t\  - \ n)\)\)\ \)\)]],
  ",\t\tfor    ",
  Cell[BoxData[
      \(TraditionalForm\`n\ \[Epsilon]\[DoubleStruckCapitalZ]\)]]
}], "NumberedEquation"],

Cell[TextData[{
  "The wavelet function ",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi](t)\)]],
  " is related to the scaling function via the following summation "
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm
      \`\[Psi](t)\  = \ 
        \@2\ \(\[Sum]\+n\( g(n)\)\ \(\[Phi](2  t - n)\)\)\)]],
  ",\t\tfor    ",
  Cell[BoxData[
      \(TraditionalForm\`n\ \[Epsilon]\[DoubleStruckCapitalZ]\)]]
}], "NumberedEquation"],

Cell[TextData[{
  "Given a finite set of real (or possibly complex) scaling and wavelet \
coefficients and a unit pulse for the \"lowest\" resolution scaling function, \
equations (6) and (7) may be iterated to obtain these functions at higher \
resolutions. The scaling and wavelet coefficients are related. For example, \
for a finite and even length ",
  Cell[BoxData[
      \(TraditionalForm\`h(n)\)]],
  ","
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`g(n)\  = \ \((\(-1\))\)\^n\ \(h(N - 1 - n)\)\)]],
  ", \t\tfor  ",
  Cell[BoxData[
      \(TraditionalForm\`n = 0, 1,  ... , \ N - 1\)]]
}], "NumberedEquation"],

Cell[TextData[{
  "For a FIR filter ",
  Cell[BoxData[
      \(TraditionalForm\`h(n)\)]],
  ", multiplication by ",
  Cell[BoxData[
      \(TraditionalForm\`\((\(-1\))\)\^n\)]],
  " is equivalent to a frequency shift by ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega] = \[Pi]\)]],
  ", which transforms a prototype lowpass filter into a highpass filter. The \
filters ",
  Cell[BoxData[
      \(TraditionalForm\`h(n)\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`g(n)\)]],
  " form a complementary lowpass and highpass pair. Consider a well known \
length 4 FIR filter, known as the Daubechies order 4 filter ",
  Cell[BoxData[
      \(TraditionalForm\`\((D\_2)\)\)]],
  "."
}], "Text"],

Cell[BoxData[
    \(h[0] = 1\/\(2\ \@2\)\ \((1 + \@3)\); \ 
    h[1] = 1\/\(2\ \@2\)\ \((3 + \@3)\); \n
    h[2] = 1\/\(2\ \@2\)\ \((3 - \@3)\); h[3] = 1\/\(2\ \@2\)\ \((1 - \@3)\); 
    \)], "Input"],

Cell[TextData[{
  "It is instructive to view the magnitude responses of the Daubechies ",
  Cell[BoxData[
      \(TraditionalForm\`D\_2\)]],
  " scaling and wavelet filters."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[
      ListMagnitudePlot[DaubechiesFIR[2], \ Decibel -> False, 
        PlotStyle -> {RGBColor[1, 0, 0]}, \ DisplayFunction -> Identity], 
      ListMagnitudePlot[Reverse[DaubechiesFIR[2]]*{1, \(-1\), 1, \(-1\)}, \ 
        Decibel -> False, \ PlotStyle -> {RGBColor[0, 0, 1]}, 
        DisplayFunction -> Identity], DisplayFunction -> $DisplayFunction]; 
    \)\)], "Input",
  CellLabel->"In[20]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 1.90476 0.0147151 0.416206 [
[.21429 .00222 -9 -9 ]
[.21429 .00222 9 0 ]
[.40476 .00222 -9 -9 ]
[.40476 .00222 9 0 ]
[.59524 .00222 -9 -9 ]
[.59524 .00222 9 0 ]
[.78571 .00222 -9 -9 ]
[.78571 .00222 9 0 ]
[.97619 .00222 -9 -9 ]
[.97619 .00222 9 0 ]
[.01131 .09796 -18 -4.5 ]
[.01131 .09796 0 4.5 ]
[.01131 .1812 -18 -4.5 ]
[.01131 .1812 0 4.5 ]
[.01131 .26444 -18 -4.5 ]
[.01131 .26444 0 4.5 ]
[.01131 .34768 -18 -4.5 ]
[.01131 .34768 0 4.5 ]
[.01131 .43092 -6 -4.5 ]
[.01131 .43092 0 4.5 ]
[.01131 .51416 -18 -4.5 ]
[.01131 .51416 0 4.5 ]
[.01131 .5974 -18 -4.5 ]
[.01131 .5974 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.21429 .01472 m
.21429 .02097 L
s
[(0.1)] .21429 .00222 0 1 Mshowa
.40476 .01472 m
.40476 .02097 L
s
[(0.2)] .40476 .00222 0 1 Mshowa
.59524 .01472 m
.59524 .02097 L
s
[(0.3)] .59524 .00222 0 1 Mshowa
.78571 .01472 m
.78571 .02097 L
s
[(0.4)] .78571 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(0.5)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.0619 .01472 m
.0619 .01847 L
s
.1 .01472 m
.1 .01847 L
s
.1381 .01472 m
.1381 .01847 L
s
.17619 .01472 m
.17619 .01847 L
s
.25238 .01472 m
.25238 .01847 L
s
.29048 .01472 m
.29048 .01847 L
s
.32857 .01472 m
.32857 .01847 L
s
.36667 .01472 m
.36667 .01847 L
s
.44286 .01472 m
.44286 .01847 L
s
.48095 .01472 m
.48095 .01847 L
s
.51905 .01472 m
.51905 .01847 L
s
.55714 .01472 m
.55714 .01847 L
s
.63333 .01472 m
.63333 .01847 L
s
.67143 .01472 m
.67143 .01847 L
s
.70952 .01472 m
.70952 .01847 L
s
.74762 .01472 m
.74762 .01847 L
s
.82381 .01472 m
.82381 .01847 L
s
.8619 .01472 m
.8619 .01847 L
s
.9 .01472 m
.9 .01847 L
s
.9381 .01472 m
.9381 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02381 .09796 m
.03006 .09796 L
s
[(0.2)] .01131 .09796 1 0 Mshowa
.02381 .1812 m
.03006 .1812 L
s
[(0.4)] .01131 .1812 1 0 Mshowa
.02381 .26444 m
.03006 .26444 L
s
[(0.6)] .01131 .26444 1 0 Mshowa
.02381 .34768 m
.03006 .34768 L
s
[(0.8)] .01131 .34768 1 0 Mshowa
.02381 .43092 m
.03006 .43092 L
s
[(1)] .01131 .43092 1 0 Mshowa
.02381 .51416 m
.03006 .51416 L
s
[(1.2)] .01131 .51416 1 0 Mshowa
.02381 .5974 m
.03006 .5974 L
s
[(1.4)] .01131 .5974 1 0 Mshowa
.125 Mabswid
.02381 .03553 m
.02756 .03553 L
s
.02381 .05634 m
.02756 .05634 L
s
.02381 .07715 m
.02756 .07715 L
s
.02381 .11877 m
.02756 .11877 L
s
.02381 .13958 m
.02756 .13958 L
s
.02381 .16039 m
.02756 .16039 L
s
.02381 .20201 m
.02756 .20201 L
s
.02381 .22282 m
.02756 .22282 L
s
.02381 .24363 m
.02756 .24363 L
s
.02381 .28525 m
.02756 .28525 L
s
.02381 .30606 m
.02756 .30606 L
s
.02381 .32687 m
.02756 .32687 L
s
.02381 .36849 m
.02756 .36849 L
s
.02381 .3893 m
.02756 .3893 L
s
.02381 .41011 m
.02756 .41011 L
s
.02381 .45173 m
.02756 .45173 L
s
.02381 .47254 m
.02756 .47254 L
s
.02381 .49335 m
.02756 .49335 L
s
.02381 .53497 m
.02756 .53497 L
s
.02381 .55578 m
.02756 .55578 L
s
.02381 .57659 m
.02756 .57659 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
1 0 0 r
.5 Mabswid
.02381 .60332 m
.02499 .60332 L
.02605 .60332 L
.02729 .60332 L
.02846 .60332 L
.02954 .60332 L
.03053 .60332 L
.03163 .60332 L
.03279 .60332 L
.03395 .60332 L
.0352 .60332 L
.03638 .60332 L
.03746 .60332 L
.03873 .60332 L
.04011 .60332 L
.04141 .60332 L
.04262 .60332 L
.04386 .60332 L
.04521 .60332 L
.04765 .60332 L
.05003 .60332 L
.05221 .60331 L
.05459 .60331 L
.05719 .60331 L
.06244 .6033 L
.06527 .6033 L
.06795 .60329 L
.07296 .60328 L
.07836 .60326 L
.08424 .60323 L
.08936 .6032 L
.0948 .60316 L
.10458 .60305 L
.11395 .6029 L
.12405 .60268 L
.13359 .60241 L
.14233 .60209 L
.16125 .60114 L
.17198 .6004 L
.18195 .59958 L
.20241 .59737 L
.221 .59468 L
.24018 .59111 L
.26098 .58622 L
.3019 .57305 L
.3413 .55536 L
.37919 .53336 L
.41953 .50444 L
.45835 .47143 L
.49963 .4313 L
Mistroke
.53939 .38854 L
.57764 .34459 L
.61833 .29601 L
.65752 .24883 L
.69915 .19984 L
.73927 .15529 L
.77787 .11627 L
.81893 .08029 L
.85847 .0522 L
.89649 .03213 L
.91604 .02468 L
.92607 .02165 L
.93697 .01897 L
.94744 .017 L
.95205 .01633 L
.95712 .01572 L
.9619 .01528 L
.96637 .01498 L
.96884 .01486 L
.9711 .01479 L
.97229 .01476 L
.97358 .01473 L
.97424 .01473 L
.97493 .01472 L
.97619 .01472 L
Mfstroke
0 0 1 r
.02381 .01472 m
.02499 .01472 L
.02605 .01473 L
.02729 .01475 L
.02846 .01477 L
.03053 .01484 L
.03279 .01494 L
.03527 .01508 L
.0379 .01527 L
.04262 .0157 L
.04749 .01627 L
.05205 .01692 L
.06244 .01884 L
.07305 .02141 L
.08274 .02429 L
.10458 .0326 L
.14429 .05392 L
.18248 .08142 L
.22313 .11722 L
.26226 .15692 L
.30384 .20328 L
.34391 .25054 L
.38246 .29696 L
.42346 .34587 L
.46295 .39115 L
.50092 .43187 L
.54134 .47115 L
.58025 .50427 L
.62161 .53388 L
.66146 .55677 L
.69979 .57369 L
.71917 .58045 L
.74057 .58662 L
.76105 .59137 L
.77984 .59481 L
.79918 .59757 L
.82004 .59975 L
.83896 .60115 L
.84969 .60174 L
.85966 .60217 L
.87019 .60253 L
.88012 .60278 L
.88904 .60295 L
.89403 .60303 L
.89871 .60309 L
.90817 .60318 L
.91319 .60322 L
.91858 .60325 L
.92422 .60327 L
.92958 .60329 L
Mistroke
.93439 .6033 L
.93711 .6033 L
.93963 .60331 L
.94438 .60331 L
.94706 .60331 L
.94951 .60332 L
.95167 .60332 L
.95404 .60332 L
.95523 .60332 L
.95651 .60332 L
.95771 .60332 L
.95882 .60332 L
.96106 .60332 L
.96224 .60332 L
.96349 .60332 L
.96457 .60332 L
.96559 .60332 L
.96671 .60332 L
.96791 .60332 L
.96892 .60332 L
.97002 .60332 L
.97117 .60332 L
.97223 .60332 L
.97324 .60332 L
.97415 .60332 L
.9752 .60332 L
.97619 .60332 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[20]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo003oOolQ
Ool004=oo`03001oogoo009oo`03001oogoo00D002Ioo`03001oogoo009oo`04001oogooOol3000W
Ool00`00Oomoo`02Ool01000Oomoogoo0P00:Goo00<007ooOol00Woo00<007ooOol00Woo0`009Woo
00<007ooOol00Woo00<007ooOol00Woo00<007ooOol00goo0012Ool00`00Ool00008Ool00`00Oomo
o`0UOol00`00Ool00007Ool00`00Oomoo`0VOol00`00Ool00009Ool00`00Oomoo`0UOol00`00Ool0
0009Ool00`00Oomoo`0TOol00`00Ool00007Ool00`00Ool00004Ool0049oo`03001oo`0000Qoo`03
001oogoo02Eoo`03001oo`0000Qoo`03001oogoo02Eoo`03001oo`0000Qoo`03001oogoo02Ioo`03
001oo`0000Moo`@002Eoo`03001oo`0000Uoo`03001oogoo009oo`00@Woo00<007oo000027oo00<0
07ooOol09Goo00<007oo000027oo00<007ooOol09Goo00<007oo00002Goo00<007ooOol09Goo00<0
07oo00001goo00<007oo00009Woo00<007oo00001goo0P001Goo0012Ool00`00Ool00008Ool00`00
Oomoo`0UOol00`00Ool00007Ool00`00Ool0000VOol00`00Ool00007Ool00`00Ool0000WOol00`00
Ool00008Ool2000VOol00`00Ool00007Ool00`00Oomoo`04Ool004=oo`03001oogoo00Ioo`8002Qo
o`03001oogoo00Moo`03001oogoo02Ioo`03001oogoo00Moo`03001oogoo02Moo`03001oogoo00Qo
o`03001oogoo02Eoo`03001oogoo00Ioo`<000Aoo`00ogoo8Goo000EOol00`00Oomoo`3oOol9Ool0
01Eoo`03001oogoo0?moo`Uoo`005Goo00<007ooOol0ogoo2Goo000EOol00`00Oomoo`3oOol9Ool0
00ioo`L000L07o<000Ql00H000=oo`005Goo00<007ooOol017oo1@0O27oo00<007ooOol027oo00<0
07ooOol01goo00<007ooOol01goo00<007ooOol01goo00<007ooOol027oo00<007ooOol01goo00<0
07ooOol01goo00<007ooOol027oo00<007ooOol01goo00<007ooOol01goo00<007ooOol01goo00<0
07ooOol027oo00<007ooOol01goo00<007ooOol01goo00<007ooOol01goo00<007ooOol027oo00<0
07ooOol01goo00<007ooOol01goo00<007ooOol01goo00<007ooOol027oo00<007ooOol01goo00<0
07ooOol01Woo1G`01goo00<007ooOol01goo000EOol00`00Oomoo`09Ool301lTOol00`00Oomoo`0a
Ool00`00Oomoo`0`Ool00`00Oomoo`0`Ool00`00Oomoo`0ROol3O00<Ool00`00Oomoo`07Ool001Eo
o`03001oogoo00aoo`<07meoo`=l01Uoo`005Goo00<007ooOol03goo0`0Of7oo0W`077oo000EOol0
0`00Oomoo`0BOol201oDOol2O00NOol001Eoo`8001Eoo`807m1oo`9l021oo`005Goo00<007ooOol0
5Woo0P0Oc7oo0W`08Woo000EOol00`00Oomoo`0HOol201o8Ool2O00TOol001Eoo`03001oogoo01Yo
o`807lAoo`9l02Ioo`005Goo00<007ooOol077oo0P0O`7oo0W`0:7oo000EOol2000OOol201nlOol2
O00ZOol001Eoo`03001oogoo021oo`0301moogoo0;Qoo`03O01oogoo02Yoo`005Goo00<007ooOol0
8Goo00<07gooOol0]Woo00=l07ooOol0:goo000EOol00`00Oomoo`0ROol201ndOol2O00^Ool001Eo
o`03001oogoo02Aoo`0301moogoo0;1oo`03O01oogoo02ioo`005Goo00<007ooOol09Goo00<07goo
Ool0[Woo00=l07ooOol0;goo000EOol2000WOol201n/Ool2O00bOol001Eoo`03001oogoo02Qoo`03
01moogoo0:Qoo`03O01oogoo039oo`005Goo00<007ooOol0:Goo00<07gooOol0YWoo00=l07ooOol0
<goo0005Ool00`00Oomoo`02Ool01000Oomoogoo0`0017oo00<007ooOol0:Woo00<07gooOol0Xgoo
0W`0=Woo0004Ool00`00Ool00007Ool00`00Oomoo`04Ool00`00Oomoo`0[Ool00`0OOomoo`2QOol0
0g`0Oomoo`0fOol000Aoo`03001oo`0000Qoo`03001oogoo00=oo`<002aoo`0301moogoo09moo`03
O01oogoo03Moo`0017oo00<007oo000027oo00<007ooOol00goo00<007ooOol0;Goo0P0OWWoo00=l
07ooOol0>7oo0004Ool00`00Ool00007Ool00`00Ool00004Ool00`00Oomoo`0_Ool00`0OOomoo`2J
Ool00g`0Oomoo`0iOol000Eoo`03001oogoo00Moo`03001oogoo00=oo`03001oogoo031oo`0301mo
ogoo09Moo`9l03aoo`005Goo00<007ooOol0<Goo00<07gooOol0UGoo00=l07ooOol0?7oo000EOol0
0`00Oomoo`0bOol00`0OOomoo`2COol00g`0Oomoo`0mOol001Eoo`8003Aoo`0301moogoo095oo`03
O01oogoo03ioo`005Goo00<007ooOol0=7oo00<07gooOol0Sgoo00=l07ooOol0?goo000EOol00`00
Oomoo`0eOol00`0OOomoo`2=Ool00g`0Oomoo`10Ool001Eoo`03001oogoo03Ioo`0301moogoo08]o
o`03O01oogoo045oo`005Goo00<007ooOol0=goo00<07gooOol0RGoo00=l07ooOol0@Woo000EOol0
0`00Oomoo`0hOol00`0OOomoo`28Ool00g`0Oomoo`12Ool001Eoo`8003Yoo`0301moogoo08Ioo`03
O01oogoo04=oo`005Goo00<007ooOol0>Woo00<07gooOol0Q7oo00=l07ooOol0A7oo000EOol00`00
Oomoo`0kOol00`0OOomoo`22Ool00g`0Oomoo`15Ool001Eoo`03001oogoo03aoo`0301moogoo081o
o`03O01oogoo04Ioo`005Goo00<007ooOol0?Goo00<07gooOol0OWoo00=l07ooOol0Agoo000EOol2
000oOol00`0OOomoo`1lOol00g`0Oomoo`18Ool001Eoo`03001oogoo03moo`0301moogoo07Yoo`03
O01oogoo04Uoo`005Goo00<007ooOol0@7oo00<07gooOol0N7oo00=l07ooOol0BWoo000EOol00`00
Oomoo`10Ool00`0OOomoo`1gOol00g`0Oomoo`1;Ool000Eoo`03001oogoo009oo`03001oogoo009o
o`<000=oo`03001oogoo045oo`0301moogoo07Eoo`03O01oogoo04aoo`0017oo00<007oo00002Goo
00<007ooOol00Woo00<007ooOol0@Woo00<07gooOol0Lgoo00=l07ooOol0CGoo0004Ool00`00Ool0
0007Ool40003Ool30013Ool00`0OOomoo`1bOol00g`0Oomoo`1=Ool000Aoo`03001oo`0000Moo`03
001oo`0000Aoo`03001oogoo04Aoo`0301moogoo071oo`03O01oogoo04ioo`0017oo00<007oo0000
27oo0P0017oo00<007ooOol0AGoo00<07gooOol0KWoo00=l07ooOol0Cgoo0005Ool00`00Oomoo`08
Ool00`00Oomoo`02Ool00`00Oomoo`15Ool00`0OOomoo`1]Ool00g`0Oomoo`1@Ool001Eoo`03001o
ogoo04Ioo`0301moogoo06]oo`03O01oogoo055oo`005Goo0P00B7oo00<07gooOol0JGoo00=l07oo
Ool0DWoo000EOol00`00Oomoo`18Ool00`0OOomoo`1WOol00g`0Oomoo`1COol001Eoo`03001oogoo
04Uoo`0301moogoo06Eoo`03O01oogoo05Aoo`005Goo00<007ooOol0BWoo00<07gooOol0Hgoo00=l
07ooOol0EGoo000EOol00`00Oomoo`1;Ool00`0OOomoo`1ROol00g`0Oomoo`1EOol001Eoo`03001o
ogoo04aoo`0301moogoo061oo`03O01oogoo05Ioo`005Goo0P00CWoo00<07gooOol0GWoo00=l07oo
Ool0Egoo000EOol00`00Oomoo`1=Ool00`0OOomoo`1MOol00g`0Oomoo`1HOol001Eoo`03001oogoo
04ioo`0301moogoo05]oo`03O01oogoo05Uoo`005Goo00<007ooOol0Cgoo00<07gooOol0FGoo00=l
07ooOol0FWoo000EOol00`00Oomoo`1@Ool00`0OOomoo`1HOol00g`0Oomoo`1JOol001Eoo`03001o
ogoo055oo`0301moogoo05Ioo`03O01oogoo05]oo`005Goo0P00Dgoo00<07gooOol0E7oo00=l07oo
Ool0G7oo000EOol00`00Oomoo`1COol00`0OOomoo`1BOol00g`0Oomoo`1MOol001Eoo`03001oogoo
05Aoo`0301moogoo051oo`03O01oogoo05ioo`001Goo00<007ooOol00Woo00@007ooOomoo`8000Eo
o`03001oogoo05Eoo`0301moogoo04ioo`03O01oogoo05moo`0017oo00<007oo00001goo00<007oo
000017oo00<007ooOol0EWoo00<07gooOol0C7oo00=l07ooOol0H7oo0004Ool00`00Ool00007Ool0
0`00Ool00004Ool3001FOol00`0OOomoo`1<Ool00g`0Oomoo`1POol000Aoo`03001oo`0000Moo`80
00Eoo`03001oogoo05Moo`0301moogoo04Yoo`03O01oogoo065oo`0017oo00<007oo00001goo00<0
07ooOol017oo00<007ooOol0F7oo00<07gooOol0B7oo00=l07ooOol0HWoo0005Ool00`00Oomoo`07
Ool20004Ool00`00Oomoo`1IOol00`0OOomoo`16Ool00g`0Oomoo`1SOol001Eoo`03001oogoo05Yo
o`0301moogoo04Aoo`03O01oogoo06Aoo`005Goo00<007ooOol0Fgoo00<07gooOol0@Woo00=l07oo
Ool0IGoo000EOol2001LOol00`0OOomoo`12Ool00g`0Oomoo`1UOol001Eoo`03001oogoo05aoo`03
01moogoo041oo`03O01oogoo06Ioo`005Goo00<007ooOol0GGoo00<07gooOol0?Woo00=l07ooOol0
Igoo000EOol00`00Oomoo`1NOol00`0OOomoo`0lOol00g`0Oomoo`1XOol001Eoo`03001oogoo05mo
o`0301moogoo03Yoo`03O01oogoo06Uoo`005Goo0P00HGoo00<07gooOol0>7oo00=l07ooOol0JWoo
000EOol00`00Oomoo`1QOol00`0OOomoo`0fOol00g`0Oomoo`1[Ool001Eoo`03001oogoo065oo`03
01moogoo03Ioo`03O01oogoo06]oo`005Goo00<007ooOol0HWoo00<07gooOol0=7oo00=l07ooOol0
K7oo000EOol00`00Oomoo`1SOol00`0OOomoo`0bOol00g`0Oomoo`1]Ool001Eoo`03001oogoo06Ao
o`0301moogoo031oo`03O01oogoo06ioo`005Goo0P00IWoo00<07gooOol0;Woo00=l07ooOol0Kgoo
000EOol00`00Oomoo`1VOol00`0OOomoo`0/Ool00g`0Oomoo`1`Ool001Eoo`03001oogoo06Ioo`03
01moogoo02aoo`03O01oogoo071oo`005Goo00<007ooOol0Igoo00<07gooOol0:Woo00=l07ooOol0
LGoo0005Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`1XOol00`0O
Oomoo`0XOol00g`0Oomoo`1bOol000Aoo`03001oo`0000Moo`03001oo`0000Aoo`03001oogoo06Uo
o`0301moogoo02Ioo`03O01oogoo07=oo`0017oo00<007oo00001goo00<007oo000017oo0`00JWoo
00<07gooOol097oo00=l07ooOol0M7oo0004Ool00`00Ool00008Ool00`00Oomoo`03Ool00`00Oomo
o`1[Ool00`0OOomoo`0ROol00g`0Oomoo`1eOol000Aoo`03001oo`0000Moo`03001oo`0000Aoo`03
001oogoo06]oo`0301moogoo025oo`03O01oogoo07Ioo`001Goo00<007ooOol01goo00<007ooOol0
0goo00<007ooOol0K7oo00<07gooOol087oo00=l07ooOol0MWoo000EOol00`00Oomoo`1]Ool00`0O
Oomoo`0NOol00g`0Oomoo`1gOol001Eoo`8006moo`0301moogoo01aoo`03O01oogoo07Qoo`005Goo
00<007ooOol0Kgoo00<07gooOol06Woo00=l07ooOol0NGoo000EOol00`00Oomoo`1`Ool00`0OOomo
o`0HOol00g`0Oomoo`1jOol001Eoo`03001oogoo071oo`0301moogoo01Moo`03O01oogoo07]oo`00
5Goo00<007ooOol0LGoo00<07gooOol05Woo00=l07ooOol0Ngoo000EOol00`00Oomoo`1bOol00`0O
Oomoo`0DOol00g`0Oomoo`1lOol001Eoo`8007Aoo`0301moogoo019oo`03O01oogoo07eoo`005Goo
00<007ooOol0M7oo00<07gooOol047oo00=l07ooOol0OWoo000EOol00`00Oomoo`1eOol00`0OOomo
o`0>Ool00g`0Oomoo`1oOol001Eoo`03001oogoo07Ioo`0301moogoo00aoo`03O01oogoo081oo`00
5Goo00<007ooOol0Mgoo00<07gooOol02Woo00=l07ooOol0PGoo000EOol2001iOol00`0OOomoo`08
Ool00g`0Oomoo`22Ool001Eoo`03001oogoo07Qoo`0301moogoo00Moo`03O01oogoo08=oo`005Goo
00<007ooOol0NGoo00<07gooOol01Goo00=l07ooOol0Q7oo000EOol00`00Oomoo`1jOol00`0OOomo
o`03Ool00g`0Oomoo`25Ool000eoo`D000=oo`03001oogoo07]oo`0501moogooOoml0028Ool000mo
o`03001oogoo00=oo`03001oogoo07aoo`0301moog`008Uoo`003goo00<007ooOol00goo0`00OGoo
00<07gooOol0R7oo000?Ool00`00Oomoo`03Ool00`00Oomoo`1lOol00g`0Ool07`29Ool000moo`03
001oogoo00=oo`03001oogoo07]oo`05O01oogooOol07`28Ool000ioo`8000Eoo`03001oogoo07Yo
o`03O01oogoo00=oo`0301moogoo08Eoo`005Goo00<007ooOol0NGoo00=l07ooOol01Goo00<07goo
Ool0Q7oo000EOol00`00Oomoo`1hOol00g`0Oomoo`07Ool00`0OOomoo`23Ool001Eoo`8007Qoo`03
O01oogoo00Uoo`0301moogoo089oo`005Goo00<007ooOol0MWoo00=l07ooOol02goo00<07gooOol0
PGoo000EOol00`00Oomoo`1eOol00g`0Oomoo`0=Ool00`0OOomoo`20Ool001Eoo`03001oogoo07Ao
o`03O01oogoo00moo`0301moogoo07moo`005Goo00<007ooOol0Lgoo00=l07ooOol04Goo00<07goo
Ool0OWoo000EOol2001cOol00g`0Oomoo`0COol00`0OOomoo`1mOol001Eoo`03001oogoo075oo`03
O01oogoo01Eoo`0301moogoo07aoo`005Goo00<007ooOol0L7oo00=l07ooOol05goo0P0OO7oo000E
Ool00`00Oomoo`1_Ool00g`0Oomoo`0JOol00`0OOomoo`1iOol001Eoo`03001oogoo06ioo`03O01o
ogoo01aoo`0301moogoo07Qoo`005Goo00<007ooOol0K7oo0W`087oo00<07gooOol0Mgoo000EOol2
001/Ool00g`0Oomoo`0QOol00`0OOomoo`1fOol001Eoo`03001oogoo06Yoo`03O01oogoo02=oo`80
7gIoo`005Goo00<007ooOol0JGoo00=l07ooOol09Woo00<07gooOol0Lgoo000EOol00`00Oomoo`1X
Ool00g`0Oomoo`0XOol00`0OOomoo`1bOol000=oo`D0009oo`04001oogooOol30004Ool00`00Oomo
o`1VOol2O00/Ool201mbOol000Eoo`03001oogoo00Ioo`03001oogoo00Aoo`03001oogoo06Eoo`03
O01oogoo02ioo`0301moogoo06moo`001Goo00<007ooOol01goo00<007ooOol00goo0`00I7oo00=l
07ooOol0<7oo00<07gooOol0KWoo0005Ool00`00Oomoo`07Ool00`00Oomoo`03Ool00`00Oomoo`1R
Ool2O00dOol201m^Ool000Eoo`03001oogoo00Ioo`03001oo`0000Aoo`03001oogoo065oo`03O01o
ogoo03Ioo`0301moogoo06]oo`0017oo0P002Goo00<007ooOol00goo00<007ooOol0H7oo00=l07oo
Ool0>7oo00<07gooOol0JWoo000EOol00`00Oomoo`1NOol2O00lOol201mZOol001Eoo`8005ioo`03
O01oogoo03ioo`0301moogoo06Moo`005Goo00<007ooOol0Fgoo0W`0@Woo0P0OIgoo000EOol00`00
Oomoo`1IOol2O016Ool201mUOol001Eoo`03001oogoo05Moo`9l04Yoo`807f=oo`005Goo00<007oo
Ool0EGoo0W`0CWoo0P0OHGoo000EOol00`00Oomoo`1COol2O01BOol201mOOol001Eoo`80059oo`9l
05Ioo`0301moogoo05aoo`005Goo00<007ooOol0Cgoo0W`0FGoo0P0OG7oo000EOol00`00Oomoo`1<
Ool3O01MOol201mJOol001Eoo`03001oogoo04Yoo`9l069oo`807eQoo`005Goo00<007ooOol0Agoo
0g`0IWoo0P0OEWoo000EOol20015Ool3O01[Ool401mBOol001Eoo`03001oogoo049oo`9l079oo`@0
7dioo`005Goo00<007ooOol0?goo0g`0N7oo0`0OBgoo000EOol00`00Oomoo`0kOol4O01nOol401m7
Ool000=oo`D0009oo`03001oogoo009oo`<000=oo`03001oogoo03Eoo`Il08Ioo`H07d5oo`001Goo
00<007ooOol027oo00<007ooOol00Woo00<007ooOol0<7oo1G`0TWoo1@0O?7oo0005Ool00`00Oomo
o`06Ool40003Ool3000[Ool5O02LOol501lgOol000Eoo`03001oogoo00Ioo`03001oo`0000Aoo`03
001oogoo011ooa]l0:Iooa/07aaoo`001Goo00<007ooOol01goo0P0017oo4g`0g7oo4`0O2Goo0004
Ool2000:Ool00`00Oomoo`02Ool00`00Oomoo`3oOol9Ool001Eoo`03001oogoo0?moo`Uoo`005Goo
00<007ooOol0ogoo2Goo003oOolQOol00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.0416348, -0.11919, 
  0.00194834, 0.00891653}}]
}, Open  ]],

Cell[TextData[{
  "The scaling and wavelet functions never directly enter into the discrete \
wavelet transform calculation. It is the FIR filter coefficients that are \
important. It is of great interest however, to construct the scaling and \
wavelet functions (at a minimum, to see them!). Here we construct these \
functions by recursion, directly from equations (6) and (7). The recursion \
needs a starting point. We begin with a unit height, unit length pulse which \
defines the scaling function at its ",
  StyleBox["coarsest level, ",
    FontSlant->"Italic"],
  "typically denoted by",
  StyleBox[" j=0.",
    FontSlant->"Italic"],
  " "
}], "Text"],

Cell[BoxData[
    \(\[Phi]\_0[x_] := 0; \n
    \[Phi]\_0[x_] := 1\  /; \ 0 \[LessEqual] x < 1\)], "Input"],

Cell[TextData[{
  "Here are the dilation and wavelet equations. The syntax \" ",
  Cell[BoxData[
      \(\(\[Phi]\_j_[x_] := \ \(\[Phi]\_j[x] = \)\ \)\)]],
  "\" is called ",
  StyleBox["dynamic programming",
    FontSlant->"Italic"],
  ". It defines and saves function values as they are computed."
}], "Text"],

Cell[BoxData[
    \(\[Phi]\_j_[x_] := \ 
      \(\[Phi]\_j[x]\  = 
        \[Sum]\+\(n = 0\)\%3 h[n]\ \[Phi]\_\(j - 1\)[2\ x\  - \ n]\); \n
    \[Psi]\_j_[x_] := \ 
      \(\[Psi]\_j[x]\  = 
        \[Sum]\+\(n = 0\)\%3\((\(-1\))\)\^n\ h[3 - n]\ \ 
            \[Phi]\_\(j - 1\)[2\ x\  - \ n]\)\)], "Input"],

Cell[TextData[{
  "We obtain ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Phi]\_j\)(x)\)]],
  " by tabulating its values for some ",
  StyleBox["j",
    FontSlant->"Italic"],
  " at all dyadic points ",
  Cell[BoxData[
      \(TraditionalForm\`x = \ 1\/2\^j\)]],
  " on the interval ",
  Cell[BoxData[
      \(TraditionalForm\`0 \[LessEqual] x < N - 1\)]],
  ". Note that at level ",
  StyleBox["j=1",
    FontSlant->"Italic"],
  ", and therefore the points ",
  Cell[BoxData[
      \(TraditionalForm\`x = \ 0, 1\/2, \ 1, \ 3\/2\)]],
  ", we get the values of the scaling coefficients."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Table[\[Phi]\_1[x], \ {x, \ 0, \ 3, \ 1\/2}]\)], "Input"],

Cell[BoxData[
    \({\(1 + \@3\)\/\(2\ \@2\), \(3 + \@3\)\/\(2\ \@2\), 
      \(3 - \@3\)\/\(2\ \@2\), \(1 - \@3\)\/\(2\ \@2\), 0, 0, 0}\)], "Output"]
}, Open  ]],

Cell["\<\
The next step in the iteration yields 10 nonzero points with values\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Table[\[Phi]\_2[x], \ {x, \ 0, \ 3, \ 1\/4}]\)], "Input"],

Cell[BoxData[
    \({1\/8\ \((1 + \@3)\)\^2, 1\/8\ \((1 + \@3)\)\ \((3 + \@3)\), 
      1\/8\ \((3 - \@3)\)\ \((1 + \@3)\) + 
        1\/8\ \((1 + \@3)\)\ \((3 + \@3)\), 
      1\/8\ \((1 - \@3)\)\ \((1 + \@3)\) + 1\/8\ \((3 + \@3)\)\^2, 
      1\/8\ \((3 - \@3)\)\ \((1 + \@3)\) + 
        1\/8\ \((3 - \@3)\)\ \((3 + \@3)\), 
      1\/8\ \((1 - \@3)\)\ \((3 + \@3)\) + 
        1\/8\ \((3 - \@3)\)\ \((3 + \@3)\), 
      1\/8\ \((3 - \@3)\)\^2 + 1\/8\ \((1 - \@3)\)\ \((1 + \@3)\), 
      1\/8\ \((1 - \@3)\)\ \((3 - \@3)\) + 
        1\/8\ \((1 - \@3)\)\ \((3 + \@3)\), 
      1\/8\ \((1 - \@3)\)\ \((3 - \@3)\), 1\/8\ \((1 - \@3)\)\^2, 0, 0, 0}
      \)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Continuing the interation of (6) and (7) to level ",
  StyleBox["j=5",
    FontSlant->"Italic"],
  ", we get,"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[
      GraphicsArray[
        \(ListPlot[#1, \ PlotJoined -> True, \ DisplayFunction -> Identity]\ &
            \)\ /@\ {Table[{x, \[Phi]\_5[x]}, \ {x, \ 0, \ 3, \ 1\/2\^5}], \ 
            Table[{x, \[Psi]\_5[x]}, \ {x, \ 0, \ 3, \ 1\/2\^5}]}]]; \)\)], 
  "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .2943 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.00700719 0.47619 [
[ 0 0 0 0 ]
[ 1 .2943 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .2943 L
0 .2943 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.00700719 0.477324 0.287295 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.31746 0.136827 0.0608782 [
[.18254 .12433 -9 -9 ]
[.18254 .12433 9 0 ]
[.34127 .12433 -3 -9 ]
[.34127 .12433 3 0 ]
[.5 .12433 -9 -9 ]
[.5 .12433 9 0 ]
[.65873 .12433 -3 -9 ]
[.65873 .12433 3 0 ]
[.81746 .12433 -9 -9 ]
[.81746 .12433 9 0 ]
[.97619 .12433 -3 -9 ]
[.97619 .12433 3 0 ]
[.01131 .01507 -12 -4.5 ]
[.01131 .01507 0 4.5 ]
[.01131 .25858 -6 -4.5 ]
[.01131 .25858 0 4.5 ]
[.01131 .38034 -6 -4.5 ]
[.01131 .38034 0 4.5 ]
[.01131 .5021 -6 -4.5 ]
[.01131 .5021 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.18254 .13683 m
.18254 .14308 L
s
[(0.5)] .18254 .12433 0 1 Mshowa
.34127 .13683 m
.34127 .14308 L
s
[(1)] .34127 .12433 0 1 Mshowa
.5 .13683 m
.5 .14308 L
s
[(1.5)] .5 .12433 0 1 Mshowa
.65873 .13683 m
.65873 .14308 L
s
[(2)] .65873 .12433 0 1 Mshowa
.81746 .13683 m
.81746 .14308 L
s
[(2.5)] .81746 .12433 0 1 Mshowa
.97619 .13683 m
.97619 .14308 L
s
[(3)] .97619 .12433 0 1 Mshowa
.125 Mabswid
.05556 .13683 m
.05556 .14058 L
s
.0873 .13683 m
.0873 .14058 L
s
.11905 .13683 m
.11905 .14058 L
s
.15079 .13683 m
.15079 .14058 L
s
.21429 .13683 m
.21429 .14058 L
s
.24603 .13683 m
.24603 .14058 L
s
.27778 .13683 m
.27778 .14058 L
s
.30952 .13683 m
.30952 .14058 L
s
.37302 .13683 m
.37302 .14058 L
s
.40476 .13683 m
.40476 .14058 L
s
.43651 .13683 m
.43651 .14058 L
s
.46825 .13683 m
.46825 .14058 L
s
.53175 .13683 m
.53175 .14058 L
s
.56349 .13683 m
.56349 .14058 L
s
.59524 .13683 m
.59524 .14058 L
s
.62698 .13683 m
.62698 .14058 L
s
.69048 .13683 m
.69048 .14058 L
s
.72222 .13683 m
.72222 .14058 L
s
.75397 .13683 m
.75397 .14058 L
s
.78571 .13683 m
.78571 .14058 L
s
.84921 .13683 m
.84921 .14058 L
s
.88095 .13683 m
.88095 .14058 L
s
.9127 .13683 m
.9127 .14058 L
s
.94444 .13683 m
.94444 .14058 L
s
.25 Mabswid
0 .13683 m
1 .13683 L
s
.02381 .01507 m
.03006 .01507 L
s
[(-2)] .01131 .01507 1 0 Mshowa
.02381 .25858 m
.03006 .25858 L
s
[(2)] .01131 .25858 1 0 Mshowa
.02381 .38034 m
.03006 .38034 L
s
[(4)] .01131 .38034 1 0 Mshowa
.02381 .5021 m
.03006 .5021 L
s
[(6)] .01131 .5021 1 0 Mshowa
.125 Mabswid
.02381 .04551 m
.02756 .04551 L
s
.02381 .07595 m
.02756 .07595 L
s
.02381 .10639 m
.02756 .10639 L
s
.02381 .16727 m
.02756 .16727 L
s
.02381 .19771 m
.02756 .19771 L
s
.02381 .22814 m
.02756 .22814 L
s
.02381 .28902 m
.02756 .28902 L
s
.02381 .31946 m
.02756 .31946 L
s
.02381 .3499 m
.02756 .3499 L
s
.02381 .41078 m
.02756 .41078 L
s
.02381 .44122 m
.02756 .44122 L
s
.02381 .47166 m
.02756 .47166 L
s
.02381 .53254 m
.02756 .53254 L
s
.02381 .56297 m
.02756 .56297 L
s
.02381 .59341 m
.02756 .59341 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .18802 m
.03373 .22549 L
.04365 .24925 L
.05357 .27668 L
.06349 .2904 L
.07341 .30779 L
.08333 .32885 L
.09325 .34894 L
.10317 .3553 L
.1131 .36534 L
.12302 .37906 L
.13294 .39179 L
.14286 .4082 L
.15278 .42362 L
.1627 .43806 L
.17262 .45276 L
.18254 .45374 L
.19246 .4584 L
.20238 .46674 L
.2123 .47409 L
.22222 .48511 L
.23214 .49515 L
.24206 .50421 L
.25198 .51353 L
.2619 .52653 L
.27183 .53854 L
.28175 .54956 L
.29167 .56085 L
.30159 .57116 L
.31151 .58172 L
.32143 .59256 L
.33135 .60332 L
.34127 .5117 L
.35119 .44752 L
.36111 .41076 L
.37103 .36666 L
.38095 .34999 L
.39087 .32597 L
.40079 .2946 L
.41071 .2652 L
.42063 .26323 L
.43056 .25391 L
.44048 .23724 L
.4504 .22254 L
.46032 .20048 L
.47024 .1804 L
.48016 .16229 L
.49008 .14365 L
.5 .15244 L
.50992 .15388 L
Mistroke
.51984 .14798 L
.52976 .14404 L
.53968 .13275 L
.5496 .12343 L
.55952 .11608 L
.56944 .1082 L
.57937 .09297 L
.58929 .07971 L
.59921 .06842 L
.60913 .0566 L
.61905 .04676 L
.62897 .03638 L
.63889 .02548 L
.64881 .01472 L
.65873 .05514 L
.66865 .08185 L
.67857 .09485 L
.68849 .11152 L
.69841 .11447 L
.70833 .1211 L
.71825 .13141 L
.72817 .14073 L
.7381 .13633 L
.74802 .13561 L
.75794 .13857 L
.76786 .14054 L
.77778 .14618 L
.7877 .15084 L
.79762 .15452 L
.80754 .15845 L
.81746 .14868 L
.82738 .14258 L
.8373 .14015 L
.84722 .13674 L
.85714 .137 L
.86706 .13628 L
.87698 .13458 L
.8869 .13313 L
.89683 .13537 L
.90675 .13662 L
.91667 .13688 L
.92659 .13741 L
.93651 .13695 L
.94643 .13676 L
.95635 .13683 L
.96627 .13683 L
.97619 .13683 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.00700719 0.97619 0.287295 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.31746 0.272544 0.0344419 [
[.18254 .26004 -9 -9 ]
[.18254 .26004 9 0 ]
[.34127 .26004 -3 -9 ]
[.34127 .26004 3 0 ]
[.5 .26004 -9 -9 ]
[.5 .26004 9 0 ]
[.65873 .26004 -3 -9 ]
[.65873 .26004 3 0 ]
[.81746 .26004 -9 -9 ]
[.81746 .26004 9 0 ]
[.97619 .26004 -3 -9 ]
[.97619 .26004 3 0 ]
[.01131 .01423 -24 -4.5 ]
[.01131 .01423 0 4.5 ]
[.01131 .10034 -12 -4.5 ]
[.01131 .10034 0 4.5 ]
[.01131 .18644 -24 -4.5 ]
[.01131 .18644 0 4.5 ]
[.01131 .35865 -18 -4.5 ]
[.01131 .35865 0 4.5 ]
[.01131 .44475 -6 -4.5 ]
[.01131 .44475 0 4.5 ]
[.01131 .53086 -18 -4.5 ]
[.01131 .53086 0 4.5 ]
[.01131 .61696 -12 -4.5 ]
[.01131 .61696 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.18254 .27254 m
.18254 .27879 L
s
[(0.5)] .18254 .26004 0 1 Mshowa
.34127 .27254 m
.34127 .27879 L
s
[(1)] .34127 .26004 0 1 Mshowa
.5 .27254 m
.5 .27879 L
s
[(1.5)] .5 .26004 0 1 Mshowa
.65873 .27254 m
.65873 .27879 L
s
[(2)] .65873 .26004 0 1 Mshowa
.81746 .27254 m
.81746 .27879 L
s
[(2.5)] .81746 .26004 0 1 Mshowa
.97619 .27254 m
.97619 .27879 L
s
[(3)] .97619 .26004 0 1 Mshowa
.125 Mabswid
.05556 .27254 m
.05556 .27629 L
s
.0873 .27254 m
.0873 .27629 L
s
.11905 .27254 m
.11905 .27629 L
s
.15079 .27254 m
.15079 .27629 L
s
.21429 .27254 m
.21429 .27629 L
s
.24603 .27254 m
.24603 .27629 L
s
.27778 .27254 m
.27778 .27629 L
s
.30952 .27254 m
.30952 .27629 L
s
.37302 .27254 m
.37302 .27629 L
s
.40476 .27254 m
.40476 .27629 L
s
.43651 .27254 m
.43651 .27629 L
s
.46825 .27254 m
.46825 .27629 L
s
.53175 .27254 m
.53175 .27629 L
s
.56349 .27254 m
.56349 .27629 L
s
.59524 .27254 m
.59524 .27629 L
s
.62698 .27254 m
.62698 .27629 L
s
.69048 .27254 m
.69048 .27629 L
s
.72222 .27254 m
.72222 .27629 L
s
.75397 .27254 m
.75397 .27629 L
s
.78571 .27254 m
.78571 .27629 L
s
.84921 .27254 m
.84921 .27629 L
s
.88095 .27254 m
.88095 .27629 L
s
.9127 .27254 m
.9127 .27629 L
s
.94444 .27254 m
.94444 .27629 L
s
.25 Mabswid
0 .27254 m
1 .27254 L
s
.02381 .01423 m
.03006 .01423 L
s
[(-7.5)] .01131 .01423 1 0 Mshowa
.02381 .10034 m
.03006 .10034 L
s
[(-5)] .01131 .10034 1 0 Mshowa
.02381 .18644 m
.03006 .18644 L
s
[(-2.5)] .01131 .18644 1 0 Mshowa
.02381 .35865 m
.03006 .35865 L
s
[(2.5)] .01131 .35865 1 0 Mshowa
.02381 .44475 m
.03006 .44475 L
s
[(5)] .01131 .44475 1 0 Mshowa
.02381 .53086 m
.03006 .53086 L
s
[(7.5)] .01131 .53086 1 0 Mshowa
.02381 .61696 m
.03006 .61696 L
s
[(10)] .01131 .61696 1 0 Mshowa
.125 Mabswid
.02381 .03145 m
.02756 .03145 L
s
.02381 .04867 m
.02756 .04867 L
s
.02381 .06589 m
.02756 .06589 L
s
.02381 .08311 m
.02756 .08311 L
s
.02381 .11756 m
.02756 .11756 L
s
.02381 .13478 m
.02756 .13478 L
s
.02381 .152 m
.02756 .152 L
s
.02381 .16922 m
.02756 .16922 L
s
.02381 .20366 m
.02756 .20366 L
s
.02381 .22088 m
.02756 .22088 L
s
.02381 .2381 m
.02756 .2381 L
s
.02381 .25532 m
.02756 .25532 L
s
.02381 .28977 m
.02756 .28977 L
s
.02381 .30699 m
.02756 .30699 L
s
.02381 .32421 m
.02756 .32421 L
s
.02381 .34143 m
.02756 .34143 L
s
.02381 .37587 m
.02756 .37587 L
s
.02381 .39309 m
.02756 .39309 L
s
.02381 .41031 m
.02756 .41031 L
s
.02381 .42753 m
.02756 .42753 L
s
.02381 .46197 m
.02756 .46197 L
s
.02381 .4792 m
.02756 .4792 L
s
.02381 .49642 m
.02756 .49642 L
s
.02381 .51364 m
.02756 .51364 L
s
.02381 .54808 m
.02756 .54808 L
s
.02381 .5653 m
.02756 .5653 L
s
.02381 .58252 m
.02756 .58252 L
s
.02381 .59974 m
.02756 .59974 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .26478 m
.03373 .2591 L
.04365 .2555 L
.05357 .25134 L
.06349 .24926 L
.07341 .24663 L
.08333 .24343 L
.09325 .24039 L
.10317 .23943 L
.1131 .2379 L
.12302 .23582 L
.13294 .23389 L
.14286 .23141 L
.15278 .22907 L
.1627 .22688 L
.17262 .22465 L
.18254 .2245 L
.19246 .2238 L
.20238 .22253 L
.2123 .22142 L
.22222 .21975 L
.23214 .21822 L
.24206 .21685 L
.25198 .21544 L
.2619 .21347 L
.27183 .21165 L
.28175 .20998 L
.29167 .20827 L
.30159 .2067 L
.31151 .2051 L
.32143 .20346 L
.33135 .20183 L
.34127 .26948 L
.35119 .31857 L
.36111 .34909 L
.37103 .38458 L
.38095 .40152 L
.39087 .42342 L
.40079 .45031 L
.41071 .47585 L
.42063 .48284 L
.43056 .4948 L
.44048 .51173 L
.4504 .52733 L
.46032 .5479 L
.47024 .56714 L
.48016 .58505 L
.49008 .60332 L
.5 .47886 L
.50992 .39265 L
Mistroke
.51984 .34467 L
.52976 .28645 L
.53968 .26648 L
.5496 .23625 L
.55952 .19578 L
.56944 .15806 L
.57937 .15857 L
.58929 .14884 L
.59921 .12887 L
.60913 .11164 L
.61905 .08416 L
.62897 .05942 L
.63889 .03744 L
.64881 .01472 L
.65873 .10007 L
.66865 .15647 L
.67857 .18391 L
.68849 .21911 L
.69841 .22535 L
.70833 .23935 L
.71825 .2611 L
.72817 .28078 L
.7381 .2715 L
.74802 .26998 L
.75794 .27622 L
.76786 .28037 L
.77778 .29229 L
.7877 .30213 L
.79762 .30989 L
.80754 .31821 L
.81746 .29756 L
.82738 .28468 L
.8373 .27956 L
.84722 .27236 L
.85714 .27291 L
.86706 .27139 L
.87698 .26779 L
.8869 .26474 L
.89683 .26946 L
.90675 .2721 L
.91667 .27265 L
.92659 .27377 L
.93651 .2728 L
.94643 .2724 L
.95635 .27254 L
.96627 .27254 L
.97619 .27254 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 84.75},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000E1000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`003goo0`000goo00<007ooOol0ogoo2Goo
000?Ool00`00Oomoo`03Ool00`00Oomoo`3oOol9Ool000Yoo`<000=oo`03001oogoo009oo`8004Qo
o`03001oogoo03ioo`03001oogoo009oo`03001oogoo009oo`03001oogoo009oo`03001oogoo06io
o`0047oo00<007ooOol00Woo00<007ooOol0AWoo0P00@7oo00<007ooOol01Woo00<007oo00000goo
00<007ooOol0KWoo000?Ool00`00Ool00003Ool00`00Oomoo`15Ool00`00Ool0000jOol30003Ool0
0`00Oomoo`08Ool01@00Oomoogoo0000@Goo00<007ooOol0;7oo000@Ool00`00Oomoo`02Ool00`00
Oomoo`14Ool01@00Oomoogoo0000@7oo00<007ooOol01Goo0P0017oo00<007ooOol0?Woo0P00;Woo
000EOol00`00Oomoo`13Ool00`00Oomoo`02Ool00`00Oomoo`0lOol00`00Ool00007Ool00`00Oomo
o`03Ool00`00Oomoo`0nOol2000^Ool001Eoo`03001oogoo00Yoo`03001oogoo009oo`03001oogoo
009oo`03001oogoo00Uoo`D000Uoo`D0009oo`03001oogoo009oo`03001oogoo00Eoo`04001oogoo
Ool3000;Ool30003Ool00`00Oomoo`02Ool00`00Oomoo`0:Ool2000IOol30007Ool30003Ool00`00
Oomoo`0nOol2000^Ool001Eoo`03001oogoo00Uoo`03001oo`0000Moo`03001oo`0000aoo`03001o
ogoo00]oo`03001oogoo00Ioo`03001oo`0000Eoo`03001oogoo009oo`03001oo`0000]oo`03001o
ogoo00Moo`03001oo`0000eoo`03001oogoo02Ioo`03001oogoo03eoo`03001oo`0002ioo`005Goo
00<007ooOol02Goo00<007oo00002Goo00<007ooOol02Woo00<007ooOol02goo00<007ooOol027oo
00<007ooOol00goo00<007ooOol00goo00<007oo00002goo00<007ooOol027oo00<007ooOol02Woo
00<007ooOol09goo00<007ooOol0?Goo00@007ooOol002eoo`005Goo00<007ooOol02Goo00<007oo
00001goo0P003Goo00<007ooOol02goo00<007ooOol01Woo0P001Goo00<007ooOol017oo00<007oo
00002goo00<007ooOol01Woo0P003Woo00<007ooOol09Woo00<007ooOol0?7oo00D007ooOomoo`00
02eoo`005Goo00<007ooOol02Goo00<007oo00001goo00<007ooOol037oo00<007ooOol02goo00<0
07ooOol01Woo00<007ooOol00goo00<007ooOol017oo00D007oo001oo`0000Uoo`03001oo`0000Mo
o`03001oogoo00]oo`03001oo`0002=oo`03001oogoo009oo`03001oogoo03aoo`05001oogooOol0
000]Ool001Eoo`03001oogoo00Yoo`03001oogoo00Ioo`<000]oo`8000aoo`8000Qoo`<0009oo`03
001oogoo00Ioo`04001oogoo000:Ool00`00Oomoo`06Ool3000<Ool00`00Oomoo`0QOol00`00Ool0
0003Ool00`00Oomoo`0lOol01@00Oomoogoo0000;Goo000EOol00`00Oomoo`0mOol00`00Oomoo`0;
Ool00`00Oomoo`0nOol30004Ool01@00Oomoogoo0000?Goo00<007ooOol00Woo00<007ooOol0:goo
000EOol00`00Oomoo`0lOol00`00Oomoo`0<Ool30013Ool20004Ool00`00Oomoo`0kOol00`00Oomo
o`02Ool00`00Oomoo`0[Ool001Eoo`03001oogoo03]oo`03001oogoo011oo`03001oogoo041oo`03
001oogoo00=oo`03001oogoo03Yoo`03001oogoo00=oo`03001oogoo02]oo`005Goo00<007ooOol0
>Woo00<007ooOol04Woo00<007ooOol047oo0`00;7oo0`000goo00<007ooOol0>Woo00<007ooOol0
17oo00<007ooOol0:Woo000BOomg000VOol00`00Oomoo`0iOol00`00Oomoo`05Ool00`00Oomoo`0Z
Ool001Eoo`03001oogoo03Aoo`80009oo`8001aoo`8000=oo`03001oogoo03Uoo`03001oogoo03Uo
o`03001oogoo00Eoo`03001oogoo02Yoo`005Goo00<007ooOol0<goo00<007oo00000P0087oo0`00
?7oo00<007ooOol0=Woo0`0027oo00<007ooOol0:Woo000EOol00`00Oomoo`0cOol00`00Oomoo`1A
Ool30003Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`0fOol00`00Oomoo`08Ool00`00
Oomoo`0ZOol001Eoo`03001oogoo039oo`03001oogoo059oo`03001oogoo00Moo`03001oo`0000=o
o`03001oogoo03Eoo`03001oogoo00Yoo`03001oogoo02Uoo`005Goo00<007ooOol0<Woo00<007oo
Ool0CGoo0`000goo00<007ooOol027oo00D007ooOomoo`0000Yoo`03001oogoo009oo`03001oogoo
009oo`03001oogoo00Moo`D000Moo`D0009oo`03001oogoo009oo`8000Qoo`<00003Ool007oo00Io
o`<000=oo`03001oogoo009oo`03001oogoo00Qoo`8000aoo`005Goo00<007ooOol0<Goo00<007oo
Ool0E7oo00<007ooOol01Woo0P0017oo00<007ooOol01goo00<007oo00001goo00<007oo00002Woo
00<007ooOol02Goo00<007ooOol01Woo00<007oo000027oo00D007ooOomoo`0000Moo`03001oogoo
00Moo`03001oo`0000]oo`03001oogoo00Uoo`005Goo00<007ooOol0<Goo00<007ooOol0Dgoo00<0
07oo00001goo00<007ooOol00goo00<007ooOol01goo00<007oo00002Goo00<007ooOol00Woo1`00
2goo00<007ooOol027oo00<007ooOol01goo00D007ooOomoo`0000Moo`03001oogoo00Qoo`03001o
ogoo00Qoo`03001oogoo00Yoo`005Goo0P00<Goo00<007ooOol0EGoo00<007ooOol01Woo0`000goo
00<007ooOol01goo00<007oo00001goo1`001Goo0P002goo00<007ooOol01Woo0P002Woo00D007oo
Oomoo`0000Moo`03001oogoo00Ioo`8000aoo`03001oogoo00Uoo`005Goo0P00<Goo00<007ooOol0
I7oo00<007ooOol01goo00@007oo001oo`P000Yoo`8000]oo`03001oogoo00Ioo`8000Uoo`03001o
o`0000=oo`03001oogoo00=oo`03001oo`0000Moo`03001oogoo00Uoo`03001oo`0000]oo`005Goo
0P00<7oo00<007ooOol0IGoo00<007ooOol01Woo1@001Woo0`002Goo0P002Woo0P0027oo0`002Goo
00<007ooOol00goo00<007ooOol00goo00<007ooOol01Woo0`002Woo00<007ooOol02Woo000EOol2
000_Ool00`00Oomoo`1VOol00`00Oomoo`02Ool4000HOol00`00Oomoo`0COol00`00Oomoo`0>Ool0
0`00Oomoo`0VOol000moo`<000=oo`03001oo`0002ioo`03001oogoo06Ioo`03001oo`00008001ao
o`03001oogoo019oo`03001oogoo011oo`03001oogoo02Eoo`003goo00<007ooOol00goo00<007oo
0000;Goo00<007ooOol0Igoo0P007goo00<007ooOol04Woo00<007ooOol047oo00<007ooOol03goo
00<007ooOol04goo000@Ool00`00Oomoo`02Ool3000/Ool00`00Oomoo`1UOom[0009Ool0011oo`03
001oogoo009oo`04001oogoo000ZOol2001ZOol00`00Oomoo`0>Ool00`00Oomoo`0=Ool00`00Oomo
o`0>Ool01000Oomoo`003Goo00<007ooOol017oo00D007ooOomoo`0000Eoo`<000ioo`03001oogoo
00Uoo`003goo00<007oo00000goo00@007ooOol002Uoo`03001oogoo06Yoo`03001oogoo01ioo`03
001oogoo015oo`03001oogoo01Moo`8000=oo`03001oogoo01Yoo`0047oo00<007ooOol00Woo00D0
07ooOomoo`0002Qoo`03001oogoo06Yoo`03001oogoo01moo`03001oogoo011oo`03001oogoo01Uo
o`04001oogoo000LOol001Eoo`03001oogoo009oo`03001oogoo02Aoo`03001oogoo06]oo`03001o
ogoo01moo`03001oogoo011oo`03001oogoo01Yoo`8001eoo`005Goo00<007ooOol00goo00<007oo
Ool08goo00<007ooOol0Jgoo00<007ooOol07goo00<007ooOol03goo00<007ooOol077oo00<007oo
Ool06goo000EOol00`00Oomoo`03Ool00`00Oomoo`0ROol00`00Oomoo`1/Ool00`00Oomoo`0OOol0
0`00Oomoo`0?Ool00`00Oomoo`0jOol001Eoo`03001oogoo00Aoo`03001oogoo025oo`03001oogoo
05aoo`<000=oo`03001oogoo009oo`03001oogoo009oo`03001oogoo021oo`03001oogoo00ioo`03
001oogoo03Yoo`005Goo00<007ooOol017oo00<007ooOol08Goo00<007ooOol0G7oo00<007ooOol0
1goo00<007oo00000goo00<007ooOol087oo00<007ooOol03Woo00<007ooOol0>Woo000EOol00`00
Oomoo`04Ool00`00Oomoo`0QOol00`00Oomoo`1MOol00`00Oomoo`08Ool01@00Oomoogoo00008Woo
00<007ooOol03Woo00<007ooOol0>Woo000EOol00`00Oomoo`05Ool00`00Oomoo`0OOol00`00Oomo
o`1NOol00`00Oomoo`06Ool20004Ool00`00Oomoo`0QOol00`00Oomoo`0=Ool00`00Oomoo`0jOol0
01Eoo`03001oogoo00Eoo`80021oo`03001oogoo05eoo`03001oo`0000Moo`03001oogoo00=oo`03
001oogoo025oo`03001oogoo00aoo`03001oogoo03]oo`0047oo0`000Woo00<007ooOol01goo00<0
07ooOol077oo00<007ooOol0Ggoo00<007ooOol01Woo0`000goo00<007ooOol08Goo00<007ooOol0
37oo00<007ooOol0>goo000AOol01@00Oomoogoo00002Goo00<007ooOol077oo00<007ooOol0KWoo
00<007ooOol08Woo00<007ooOol02goo00<007ooOol0>goo000?Ool40002Ool20009Ool2000LOol0
0`00Oomoo`1^Ool00`00Oomoo`0SOol00`00Oomoo`0:Ool00`00Oomoo`0kOol000moo`03001oo`00
00=oo`03001oogoo00Yoo`03001oogoo01Uoo`03001oogoo06ioo`03001oogoo02Aoo`03001oogoo
00Uoo`03001oogoo03]oo`0047oo0P000goo00<007ooOol02Woo00<007ooOol067oo00<007ooOol0
JWoo00<007ooOol00Woo00<007ooOol097oo00<007ooOol02Goo00<007ooOol0>goo000AOol01@00
Oomoogoo00003Goo00<007ooOol05goo00<007ooOol0JGoo00<007oo00000goo00<007ooOol097oo
00<007ooOol02Goo00<007ooOol0>goo000EOol00`00Oomoo`0;Ool00`00Oomoo`0GOol00`00Oomo
o`1[Ool01@00Oomoogoo00009goo00<007ooOol01goo00<007ooOol0?7oo000EOol00`00Oomoo`0<
Ool00`00Oomoo`0FOol00`00Oomoo`1YOol20004Ool00`00Oomoo`0UOol00`00Oomoo`07Ool00`00
Oomoo`0lOol001Eoo`03001oogoo00aoo`03001oogoo01Eoo`03001oogoo06Yoo`03001oogoo00=o
o`03001oogoo02Eoo`03001oogoo00Moo`03001oogoo03aoo`005Goo00<007ooOol03Goo00<007oo
Ool057oo00<007ooOol0JWoo0`000goo00<007ooOol09Woo00<007ooOol01Woo00<007ooOol0?7oo
000EOol00`00Oomoo`0>Ool00`00Oomoo`0COol00`00Oomoo`1`Ool00`00Oomoo`0VOol20007Ool0
0`00Oomoo`0lOol001Eoo`03001oogoo00moo`8001=oo`03001oogoo071oo`03001oogoo02Qoo`03
001oogoo00Aoo`03001oogoo03aoo`005Goo00<007ooOol04Goo00<007ooOol03goo00<007ooOol0
LGoo00<007ooOol0:7oo00<007ooOol017oo00<007ooOol0?7oo000EOol00`00Oomoo`0BOol00`00
Oomoo`0>Ool00`00Oomoo`1ROol00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00
Oomoo`0YOol00`00Oomoo`03Ool00`00Oomoo`0lOol001Eoo`03001oogoo01=oo`03001oogoo00eo
o`03001oogoo069oo`03001oogoo00Ioo`03001oo`0000=oo`03001oogoo02Yoo`03001oogoo009o
o`03001oogoo03aoo`003goo0P0017oo00<007ooOol057oo00<007ooOol037oo00<007ooOol0HWoo
00<007ooOol027oo00D007ooOomoo`0002aoo`03001oogoo009oo`03001oogoo03aoo`003goo00<0
07oo00000goo00<007ooOol05Goo0P002goo00<007ooOol0I7oo00<007ooOol01Goo0P0017oo00<0
07ooOol0:goo00D007ooOomoo`0003ioo`003goo00<007oo00000goo0P0067oo00<007ooOol027oo
00<007ooOol0HWoo00<007oo00001goo00<007ooOol00goo00<007ooOol0:goo00@007ooOol003mo
o`003goo0P0017oo00<007ooOol067oo00<007ooOol01goo00<007ooOol0HWoo0`001goo0`000goo
00<007ooOol0;7oo00<007oo0000?goo000?Ool00`00Oomoo`03Ool00`00Oomoo`0IOol00`00Oomo
o`06Ool00`00Oomoo`1bOol00`00Oomoo`0/Ool00`00Ool0000oOol0011oo`8000=oo`03001oogoo
01Uoo`03001oogoo00Ioo`03001oogoo079oo`03001oogoo02eoo`8003moo`005Goo00<007ooOol0
6Woo00<007ooOol01Goo00<007ooOol0LWoo00<007ooOol0;Goo0P00?goo000EOol00`00Oomoo`0K
Ool00`00Oomoo`04Ool00`00Oomoo`1bOol00`00Oomoo`0^Ool00`00Oomoo`0mOol001Eoo`03001o
ogoo01aoo`03001oogoo00=oo`03001oogoo06Ioo`D0009oo`03001oogoo009oo`03001oogoo02io
o`03001oogoo03eoo`005Goo00<007ooOol07Goo00D007ooOomoo`0006]oo`07001oogooOol007oo
00000goo00<007ooOol0KWoo000EOol00`00Oomoo`0NOol01000Oomoo`00Jgoo00L007ooOomoo`00
Ool00003Ool00`00Oomoo`1^Ool001Eoo`03001oogoo01moo`03001oo`0006]oo`07001oogooOol0
07oo0000M7oo000EOol00`00Oomoo`0POol2001[Ool01`00Oomoogoo001oo`0007Aoo`005Goo00<0
07ooOol087oo0P00JWoo0P0017oo00<007ooOol0Lgoo000EOol00`00Oomoo`0QOol00`00Oomoo`3T
Ool001Eoo`03001oogoo0?moo`Uoo`005Goo00<007ooOol0ogoo2Goo003oOolQOol00?moob5oo`00
ogoo8Goo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {83.75, 0}} -> {-0.0589635, -0.0147182, 
  0.00737954, 0.00737954}, {{7.9375, 137}, {81.75, 
  1.9375}} -> {-0.57066, -3.18354, 0.0266468, 0.138955}, {{149.938, 279}, {
  81.75, 1.9375}} -> {-5.21922, -10.2528, 0.0297798, 0.274489}}]
}, Open  ]],

Cell["\<\
The scaling and wavelet functions are orthogonal. This verifies \
orthogonality.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[CapitalPhi] = Table[\[Phi]\_2[x], \ {x, \ 0, \ 3, \ 1\/4}]; \n
    \[CapitalPsi] = Table[\[Psi]\_2[x], \ {x, \ 0, \ 3, \ 1\/4}]; \n
    \(\[CapitalPhi] . \[CapitalPsi]\  // N\)\  // Chop\)], "Input"],

Cell[BoxData[
    \(0\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["SCALING AND WAVELET COEFFICIENTS", "Section"],

Cell[TextData[{
  "In this section, an important class of scaling coefficients, Daubechies \
minimum phase FIR filters will be presented. We begin with a set of necessary \
conditions for the solution of (6) to exist. Later we use these conditions to \
solve for ",
  Cell[BoxData[
      \(TraditionalForm\`D\_2\)]],
  " scaling coefficients. The ",
  Cell[BoxData[
      \(TraditionalForm\`D\_2\)]],
  " impulse response coefficients satisfy a system of equations that \
guarantee the following properties:\n(i) uniqueness\n(ii) orthogonality\n\
(iii) accuracy.\nSolving this system yields the desired coefficients. "
}], "Text"],

Cell[CellGroupData[{

Cell["Normalization condition", "Definition"],

Cell[BoxData[
    \(TraditionalForm\`\(\n\[Sum]\_n h(n) = \(\@2 . \)\)\)], 
  "NumberedEquation"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Fundamental condition", "Definition"],

Cell[BoxData[
    \(TraditionalForm\`\(\n
    \[Sum]\_n h(2  n) = \[Sum]\_n\( h(2  n\  + \ 1) . \)\)\)], 
  "NumberedEquation"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Orthonormality condition", "Definition"],

Cell[TextData[Cell[BoxData[
    FormBox[
      RowBox[{\(\[Sum]\_n\( h(n)\)\ \ \(h(n\  - 2  k\ )\)\), "=", " ", 
        RowBox[{\(\[Delta](k)\), " ", "=", " ", 
          RowBox[{"{", GridBox[{
                {"1", \(if\ k = 0\)},
                {"0", "otherwise"}
                }]}]}]}], TraditionalForm]]]], "NumberedEquation"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Accuracy of order p condition (moment condition)", "Definition"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm
      \`\[Sum]\+\(n = 0\)\%\(2  p - 1\)\((\(-1\))\)\^n\ \(n\^k\) \(h(n)\)\  = 
        \ 0\)]],
  "\t\tfor\t",
  Cell[BoxData[
      \(TraditionalForm\`k = \ 0, 1,  ... , \ p - 1\)]]
}], "NumberedEquation"]
}, Open  ]],

Cell[TextData[{
  "We are now in a position to demonstrate a non-trivial wavelet basis\
\[LongDash]the Daubechies 4 filter. The method for any ",
  Cell[BoxData[
      \(TraditionalForm\`D\_\(N\/2\)\)]],
  " follows exactly the same steps. Let ",
  Cell[BoxData[
      \(TraditionalForm\`N = 4\)]],
  " (",
  StyleBox["i.e.",
    FontSlant->"Italic"],
  ",  4 non-zero filter coefficients).  The conditions on the filter \
coefficients read:"
}], "Text",
  CellTags->"D4"],

Cell[TextData[{
  "\t",
  StyleBox["Normalization",
    FontSlant->"Italic"],
  "\t\t\t",
  Cell[BoxData[
      \(TraditionalForm\`c\_0 + c\_1 + c\_2 + c\_3 = \@2\)]]
}], "Text"],

Cell[TextData[{
  "\t",
  StyleBox["Orthonormality (k=0)",
    FontSlant->"Italic"],
  "\t\t",
  Cell[BoxData[
      \(TraditionalForm\`c\_0\%2 + c\_1\%2 + c\_2\%2 + c\_3\%2 = \ 1\)]]
}], "Text"],

Cell[TextData[{
  "\t",
  StyleBox["Orthonormality (k=1)",
    FontSlant->"Italic"],
  "\t\t",
  Cell[BoxData[
      \(TraditionalForm\`\(c\_0\) c\_2 + \(c\_1\) c\_3 = 0\)]]
}], "Text"],

Cell[TextData[{
  "\t",
  Cell[BoxData[
      \(TraditionalForm\`p = 1\)]],
  "\t\t\t\t",
  Cell[BoxData[
      \(TraditionalForm\`c\_0 - c\_1 + c\_2 - c\_3 = 0\)]]
}], "Text"],

Cell[TextData[{
  "\t",
  Cell[BoxData[
      \(TraditionalForm\`p = 2\)]],
  "\t\t\t\t",
  Cell[BoxData[
      \(TraditionalForm\`\(\ 0\ c\_0 - 1  c\_1 + 2  c\_2 - 3  c\_3 = 0\)\)]]
}], "Text"],

Cell[TextData[{
  "One goal is to have the maximum possible ",
  Cell[BoxData[
      \(TraditionalForm\`p\)]],
  " (",
  StyleBox["i.e.",
    FontSlant->"Italic"],
  ", the best possible approximation) so I have included both ",
  Cell[BoxData[
      \(TraditionalForm\`p = 1\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`p = 2\)]],
  ". We now have 5 conditions in 4 unknowns. However, it can be shown that \
the square normalization condition can be obtained from normalization, \
orthonormality and ",
  StyleBox["p=1",
    FontSlant->"Italic"],
  " conditions. The ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " implementation follows immediately."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(sol = 
      Solve[{c0 + c1 + c2 + c3 == \@2, \n
          \t\t\t\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ 
          c0 - c1 + c2 - c3 == 0, \n
          \t\t\t\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ 
          \(-c1\) + 2\ c2 - 3\ c3 == 0, \n
          \t\t\t\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ 
          c0\ c2 + c1\ c3 == 0}, {c0, c1, c2, c3}]\)], "Input",
  CellLabel->"In[21]:="],

Cell[BoxData[
    \({{c0 \[Rule] 1\/8\ \((\@2 - \@6)\), 
        c1 \[Rule] 1\/8\ \((3\ \@2 - \@6)\), 
        c3 \[Rule] 1\/8\ \((\@2 + \@6)\), 
        c2 \[Rule] 1\/8\ \((3\ \@2 + \@6)\)}, {
        c0 \[Rule] 1\/8\ \((\@2 + \@6)\), 
        c1 \[Rule] 1\/8\ \((3\ \@2 + \@6)\), 
        c3 \[Rule] 1\/8\ \((\@2 - \@6)\), 
        c2 \[Rule] 1\/8\ \((3\ \@2 - \@6)\)}}\)], "Output",
  CellLabel->"Out[21]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(D\_2 = {c0, c1, c2, c3} /. 
        sol\[LeftDoubleBracket]\(-1\)\[RightDoubleBracket]\ \)\)], "Input",
  CellLabel->"In[22]:="],

Cell[BoxData[
    \({1\/8\ \((\@2 + \@6)\), 1\/8\ \((3\ \@2 + \@6)\), 
      1\/8\ \((3\ \@2 - \@6)\), 1\/8\ \((\@2 - \@6)\)}\)], "Output",
  CellLabel->"Out[22]="]
}, Open  ]],

Cell[TextData[{
  "Other methods of constructing the ",
  Cell[BoxData[
      \(TraditionalForm\`D\_\(N/2\)\)]],
  " wavelets are available, specifically by beginning with a desired \
frequency domain filter characteristic. The ",
  StyleBox["ImageProcessing", "Program"],
  " function ",
  StyleBox["DaubechiesFIR", "Program"],
  " uses a spectral factorization technique to find coefficients up to order \
",
  Cell[BoxData[
      \(TraditionalForm\`N = 80\)]],
  ". "
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(D\_6 = DaubechiesFIR[6]\)], "Input"],

Cell[BoxData[
    \({0.111540743350109461`, 0.494623890398453092`, 0.751133908021095564`, 
      0.315250351709197751`, \(-0.226264693965439844`\), 
      \(-0.129766867567262078`\), 0.0975016055873230591`, 
      0.0275228655303056735`, \(-0.0315820393174860569`\), 
      0.000553842201161473823`, 0.00477725751094550687`, 
      \(-0.00107730108530847834`\)}\)], "Output"]
}, Open  ]],

Cell["\<\
Here are the coefficient values of some additional well known wavelets.\
\>", "Text"],

Cell[BoxData[{
    \(\(haar = {1, 1}\/\@2. ;\)\), 
    \(\(coif2 = 
        {\(-0.051429728471\), 0.238929728471, 0.602859456942, 0.272140543058, 
            \(-0.051429972847\), \(-0.011070271529\)}\ \@2. ;\)\), 
    \(\(coif4 = 
      {0.011587596739, \(-0.02932013798\), \(-0.04763959031\), 
          0.273021046535, 0.574682393857, 0.294867193696, 
          \(-0.054085607092\), \(-0.042026480461\), 0.016744410163, 
          0.003967883613, \(-0.001289203356\), \(-0.000509505399\)}\ \@2. ; 
    \)\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["DISCRETE WAVELET TRANSFORM", "Section"],

Cell[CellGroupData[{

Cell["Introduction", "Subsection"],

Cell["\<\
With an orthonormal basis for the expansion of functions, we can write (see \
(5))\
\>", "Text"],

Cell[BoxData[
    \(TraditionalForm
    \`\(f(t) = 
      \[Sum]\+\(k\ \[Epsilon]\ \[DoubleStruckCapitalZ]\)\(c\_k\%0\) 
            \(\(\[Phi]\_\(0, k\)\)(t)\) + 
        \[Sum]\+\(j = 0
              \)\%\[Infinity]\(\[Sum]\+\(k\ \[Epsilon]\ 
                \[DoubleStruckCapitalZ]\)\(d\_k\%j\) 
              \(\(\[Psi]\_\(j, k\)\)(t)\)\), \)\)], "NumberedEquation"],

Cell["where the coefficients can be computed using", "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm
      \`c\_k\%0\  = \ 
        \[Integral]\(f(t)\)\ \(\(\[Phi]\_\(0, k\)\)(t)\)\ 
            \[DifferentialD]t\)]],
  ",\t\t",
  Cell[BoxData[
      \(TraditionalForm
      \`d\_k\%j\  = \ 
        \[Integral]\(f(t)\)\ \(\(\[Psi]\_\(j, k\)\)(t)\)\ 
            \[DifferentialD]t\)]]
}], "NumberedEquation"],

Cell["\<\
It can be shown that the wavelet series converges for a wide class of \
functions and wavelet bases. A most striking point about discrete wavelets is \
that, although the expansion coefficients are defined in terms of integrals, \
because of the recursive nature of the equations defining the scaling \
function (and hence the wavelets), we do not actually ever need to compute \
any integrals! \
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Forward Transform (Analysis)", "Subsection"],

Cell[TextData[{
  "Before we look at this in more detail, here is the computation of a DWT \
for a particular case: Suppose that we have a set of ",
  Cell[BoxData[
      \(TraditionalForm\`8 = \(2\^J = 2\^3\)\)]],
  " values corresponding to the sampled values of a particular function. Call \
these ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          SuperscriptBox[
            StyleBox["c",
              FontWeight->"Bold"], "3"], "=", 
          \({c\_0\%3, c\_1\%3, \[Ellipsis], c\_7\%3} . \)}], 
        TraditionalForm]]],
  " The steps required to compute the DWT in say, a ",
  Cell[BoxData[
      \(TraditionalForm\`D\_2\)]],
  " basis are (where we changed the notation from ",
  Cell[BoxData[
      \(TraditionalForm\`h(n)\)]],
  " to ",
  Cell[BoxData[
      \(TraditionalForm\`h\_n\)]],
  ")"
}], "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          StyleBox[
            RowBox[{"(", GridBox[{
                  {\(h\_0\), \(h\_1\), \(h\_2\), \(h\_3\), "0", "0", "0", 
                    "0"},
                  {"0", "0", \(h\_0\), \(h\_1\), \(h\_2\), \(h\_3\), "0", 
                    "0"},
                  {"0", "0", "0", "0", \(h\_0\), \(h\_1\), \(h\_2\), 
                    \(h\_3\)},
                  {\(h\_2\), \(h\_3\), "0", "0", "0", "0", \(h\_0\), 
                    \(h\_1\)},
                  {\(g\_0\), \(g\_1\), \(g\_2\), \(g\_3\), "0", "0", "0", 
                    "0"},
                  {"0", "0", \(g\_0\), \(g\_1\), \(g\_2\), \(g\_3\), "0", 
                    "0"},
                  {"0", "0", "0", "0", \(g\_0\), \(g\_1\), \(g\_2\), 
                    \(g\_3\)},
                  {\(g\_2\), \(g\_3\), "0", "0", "0", "0", \(g\_0\), 
                    \(g\_1\)}
                  }], ")"}],
            GridBoxOptions->{RowSpacings->1.6}], 
          RowBox[{
            RowBox[{"(", GridBox[{
                  {\(c\_0\%3\)},
                  {\(c\_1\%3\)},
                  {\(c\_2\%3\)},
                  {\(c\_3\%3\)},
                  {\(c\_4\%3\)},
                  {\(c\_5\%3\)},
                  {\(c\_6\%3\)},
                  {\(c\_7\%3\)}
                  }], ")"}], "\[LongRightArrow]", 
            RowBox[{"(", GridBox[{
                  {\(c\_0\%2\)},
                  {\(c\_1\%2\)},
                  {\(c\_2\%2\)},
                  {\(\(c\_3\%2\)\+_\)},
                  {\(d\_0\%2\)},
                  {\(d\_1\%2\)},
                  {\(d\_3\%2\nd\_4\%2\)}
                  }], ")"}]}]}], ","}], TraditionalForm]], "NumberedEquation"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          StyleBox[
            RowBox[{"(", GridBox[{
                  {\(h\_0\), \(h\_1\), \(h\_2\), \(h\_3\)},
                  {\(h\_2\), \(h\_3\), \(h\_0\), \(h\_1\)},
                  {\(g\_0\), \(g\_1\), \(g\_2\), \(g\_3\)},
                  {\(g\_2\), \(g\_3\), \(g\_0\), \(g\_1\)}
                  }], ")"}],
            GridBoxOptions->{RowSpacings->1.6,
            ColumnsEqual->True}], 
          RowBox[{
            RowBox[{"(", GridBox[{
                  {\(c\_0\%2\)},
                  {\(c\_1\%2\)},
                  {\(c\_2\%2\)},
                  {\(c\_3\%2\)}
                  }], ")"}], "\[LongRightArrow]", 
            RowBox[{"(", GridBox[{
                  {\(c\_0\%1\)},
                  {\(\(c\_1\%1\)\+_\)},
                  {\(d\_0\%1\)},
                  {\(d\_1\%1\)}
                  }], ")"}]}]}], ",", 
        RowBox[{
          StyleBox[
            RowBox[{"(", GridBox[{
                  {\(h\_0 + h\_2\), \(h\_1 + h\_3\)},
                  {\(g\_0 + g\_2\), \(g\_1 + g\_3\)}
                  }], ")"}],
            GridBoxOptions->{RowSpacings->1.6,
            ColumnSpacings->0.8,
            ColumnsEqual->False}], 
          RowBox[{
            RowBox[{
              RowBox[{"(", GridBox[{
                    {\(c\_0\%1\)},
                    {\(c\_1\%1\)}
                    }], ")"}], "\[LongRightArrow]", 
              RowBox[{"(", GridBox[{
                    {\(\(c\_0\%0\)\+_\)},
                    {\(d\_0\%0\)}
                    }], ")"}]}], "."}]}]}], TraditionalForm]], 
  "NumberedEquation"],

Cell["\<\
The steps in the transform produce intermediate vectors as follows:\
\>", "Warning"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{"(", GridBox[{
                {\(c\_0\%3\)},
                {\(c\_1\%3\)},
                {\(c\_2\%3\)},
                {\(c\_3\%3\)},
                {\(c\_4\%3\)},
                {\(c\_5\%3\)},
                {\(c\_6\%3\nc\_7\%3\)}
                }], ")"}], "\[LongRightArrow]", 
          RowBox[{"(", GridBox[{
                {\(c\_0\%2\)},
                {\(c\_1\%2\)},
                {\(c\_2\%2\)},
                {\(\(c\_3\%2\)\+_\)},
                {\(d\_0\%2\)},
                {\(d\_1\%2\)},
                {\(d\_2\%2\nd\_3\%2\)}
                }], ")"}], "\[LongRightArrow]", 
          RowBox[{"(", GridBox[{
                {\(c\_0\%1\)},
                {\(\(c\_1\%1\)\+_\)},
                {\(d\_0\%1\)},
                {\(\(d\_1\%1\)\+_\)},
                {\(d\_0\%2\)},
                {\(d\_1\%2\)},
                {\(d\_2\%2\nd\_3\%2\)}
                }], ")"}], "\[LongRightArrow]", 
          RowBox[{"(", GridBox[{
                {\(\(c\_0\%0\)\+_\)},
                {\(\(d\_0\%0\)\+_\)},
                {\(d\_0\%1\)},
                {\(\(d\_1\%1\)\+_\)},
                {\(d\_0\%2\)},
                {\(d\_1\%2\)},
                {\(d\_2\%2\nd\_3\%2\)}
                }], ")"}]}], "."}], TraditionalForm]], "NumberedEquation"],

Cell[TextData[{
  "The first decomposition step returns wavelet transform coefficients at \
resolution level ",
  Cell[BoxData[
      \(TraditionalForm\`j = 2\)]],
  ". The operation is effectively a discrete-time circular convolution of the \
sequence ",
  Cell[BoxData[
      \(TraditionalForm
      \`c\^3 = {c\_0\%3, \ c\_1\%3, \  ... \ , \ c\_7\%3}\)]],
  " with two FIR filters ",
  Cell[BoxData[
      \(TraditionalForm\`H\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`G\)]],
  ", followed by downsampling. The filter ",
  Cell[BoxData[
      \(TraditionalForm\`H\)]],
  " is the so-called lowpass filter, with elements equal to the scaling \
coefficients, while ",
  Cell[BoxData[
      \(TraditionalForm\`G\)]],
  ", the highpass filter has elements given by (8). The downsampling step \
effectively removes the odd numbered elements of matrix products ",
  Cell[BoxData[
      \(TraditionalForm\`H . \ c\^3\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`G . c\^3\)]],
  " reducing their dimensionality by a factor of two. The concatenation of \
the two downsampled sequences gives the desired DWT coefficients. The \
circular convolution operation used in (15) results in the so-called ",
  StyleBox["periodic ",
    FontSlant->"Italic"],
  "DWT. The next two steps yield wavelet coefficients at lower resolutions, ",
  
  Cell[BoxData[
      \(TraditionalForm\`j = \ 1\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`j = 0\)]],
  ". The final vector is the full decomposition DWT of the initial set of \
values.  The original sequence ",
  Cell[BoxData[
      FormBox[
        SuperscriptBox[
          StyleBox["c",
            FontWeight->"Bold"], "3"], TraditionalForm]]],
  " is decomposed into a lowest resolution signal (DC term) ",
  Cell[BoxData[
      FormBox[
        SuperscriptBox[
          StyleBox["c",
            FontWeight->"Bold"], "0"], TraditionalForm]]],
  ", and difference (or highpass) signals ",
  Cell[BoxData[
      FormBox[
        SuperscriptBox[
          StyleBox["d",
            FontWeight->"Bold"], "0"], TraditionalForm]]],
  ", ",
  Cell[BoxData[
      FormBox[
        SuperscriptBox[
          StyleBox["d",
            FontWeight->"Bold"], "1"], TraditionalForm]]],
  ", ",
  Cell[BoxData[
      FormBox[
        SuperscriptBox[
          StyleBox["d",
            FontWeight->"Bold"], "2"], TraditionalForm]]],
  ", of finer and finer resolution. Equation (13) now reduces to "
}], "Text"],

Cell[BoxData[
    \(TraditionalForm
    \`\(f(t) = \ 
      \(c\_0\%0\) \(\(\[Phi]\_\(0, 0\)\)(t)\) + \ 
        \(d\_0\%0\) \(\(\[Psi]\_\(0, 0\)\)(t)\) + \ 
        \[Sum]\+\(k = 0\)\%1\( d\_k\%1\) \(\(\[Psi]\_\(1, k\)\)(t)\) + \ 
        \[Sum]\+\(k = 0\)\%3 d\_k\%2\ \ \(\(\[Psi]\_\(2, k\)\)(t) . \)\t\t\t\t
    \)\)], "NumberedEquation"],

Cell[CellGroupData[{

Cell["Problem 4", "Exercise"],

Cell[TextData[{
  "Construct matrix ",
  Cell[BoxData[
      \(TraditionalForm\`H\)]],
  " from the FIR filter ",
  Cell[BoxData[
      \(TraditionalForm\`h = \ {h\_0, \ h\_1, \ h\_2, \ h\_3}\)]],
  ". Obtain the down-sampled matrix ",
  Cell[BoxData[
      \(TraditionalForm\`H\_\[DownArrow]\  = \ \((\[DownArrow]2)\)\ H\)]],
  " by removing every other row. Show the equivalence of the following \
operations:\n",
  Cell[BoxData[
      \(TraditionalForm
      \`\((H . \ \ x)\)\_\[DownArrow]\  \[Equal] \ 
        H\^e\  . \ x\^e\  + \ H\^o\  . \ x\^o\)]],
  ",\nwhere ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " is a vector, ",
  Cell[BoxData[
      \(TraditionalForm\`x\^e\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`x\^o\)]],
  " are the even and odd samples of ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  ", respectively, and ",
  Cell[BoxData[
      \(TraditionalForm\`H\^e\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`H\^o\)]],
  " are circulant matrices formed from the even and odd samples of ",
  Cell[BoxData[
      \(TraditionalForm\`h\)]],
  ", respectively. Which of the two operations is computationally more \
efficient?"
}], "ExerciseText"]
}, Open  ]],

Cell[TextData[{
  "Careful examination of (15)-(17) reveals that iteration proceeds over the \
lowpass DWT coefficients only. The maximum number of decomposition levels is \
",
  StyleBox["J ",
    FontSlant->"Italic"],
  "if length of signal is ",
  Cell[BoxData[
      \(TraditionalForm\`N = 2\^J\)]],
  " or until the first odd length subsequence is encountered. The essential \
point is that the coefficients  ",
  Cell[BoxData[
      FormBox[
        SuperscriptBox[
          StyleBox["c",
            FontWeight->"Bold"], "j"], TraditionalForm]]],
  " and ",
  Cell[BoxData[
      FormBox[
        SuperscriptBox[
          StyleBox["d",
            FontWeight->"Bold"], "j"], TraditionalForm]]],
  " in this decomposition are computed recursively by simple operations on \
the sampled function values and no integrals need to be computed. This is \
known as Mallat's ",
  StyleBox["pyramid algorithm",
    FontSlant->"Italic"],
  " for computing the DWT by computing the expansion of a finite length \
sequence in a discrete wavelet basis. We now define a simple signal with some \
additive noise."
}], "Text"],

Cell[BoxData[
    \(\(x = 
      Join[Table[0, {16}], Table[1, {16}], \ Table[1/2, {32}], 
          Table[1/4, {24}], \ Table[3/4, {24}], Table[0, {16}]]\  + \n\t\t\t
        0.15\ Table[Random[] - 0.5, {128}]; \)\)], "Input",
  CellLabel->"In[23]:="],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(ListPlot[x, PlotJoined \[Rule] True]; \)\)], "Input",
  CellLabel->"In[24]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00744048 0.0529416 0.514627 [
[.17262 .04044 -6 -9 ]
[.17262 .04044 6 0 ]
[.32143 .04044 -6 -9 ]
[.32143 .04044 6 0 ]
[.47024 .04044 -6 -9 ]
[.47024 .04044 6 0 ]
[.61905 .04044 -6 -9 ]
[.61905 .04044 6 0 ]
[.76786 .04044 -9 -9 ]
[.76786 .04044 9 0 ]
[.91667 .04044 -9 -9 ]
[.91667 .04044 9 0 ]
[.01131 .15587 -18 -4.5 ]
[.01131 .15587 0 4.5 ]
[.01131 .25879 -18 -4.5 ]
[.01131 .25879 0 4.5 ]
[.01131 .36172 -18 -4.5 ]
[.01131 .36172 0 4.5 ]
[.01131 .46464 -18 -4.5 ]
[.01131 .46464 0 4.5 ]
[.01131 .56757 -6 -4.5 ]
[.01131 .56757 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.17262 .05294 m
.17262 .05919 L
s
[(20)] .17262 .04044 0 1 Mshowa
.32143 .05294 m
.32143 .05919 L
s
[(40)] .32143 .04044 0 1 Mshowa
.47024 .05294 m
.47024 .05919 L
s
[(60)] .47024 .04044 0 1 Mshowa
.61905 .05294 m
.61905 .05919 L
s
[(80)] .61905 .04044 0 1 Mshowa
.76786 .05294 m
.76786 .05919 L
s
[(100)] .76786 .04044 0 1 Mshowa
.91667 .05294 m
.91667 .05919 L
s
[(120)] .91667 .04044 0 1 Mshowa
.125 Mabswid
.06101 .05294 m
.06101 .05669 L
s
.09821 .05294 m
.09821 .05669 L
s
.13542 .05294 m
.13542 .05669 L
s
.20982 .05294 m
.20982 .05669 L
s
.24702 .05294 m
.24702 .05669 L
s
.28423 .05294 m
.28423 .05669 L
s
.35863 .05294 m
.35863 .05669 L
s
.39583 .05294 m
.39583 .05669 L
s
.43304 .05294 m
.43304 .05669 L
s
.50744 .05294 m
.50744 .05669 L
s
.54464 .05294 m
.54464 .05669 L
s
.58185 .05294 m
.58185 .05669 L
s
.65625 .05294 m
.65625 .05669 L
s
.69345 .05294 m
.69345 .05669 L
s
.73065 .05294 m
.73065 .05669 L
s
.80506 .05294 m
.80506 .05669 L
s
.84226 .05294 m
.84226 .05669 L
s
.87946 .05294 m
.87946 .05669 L
s
.95387 .05294 m
.95387 .05669 L
s
.99107 .05294 m
.99107 .05669 L
s
.25 Mabswid
0 .05294 m
1 .05294 L
s
.02381 .15587 m
.03006 .15587 L
s
[(0.2)] .01131 .15587 1 0 Mshowa
.02381 .25879 m
.03006 .25879 L
s
[(0.4)] .01131 .25879 1 0 Mshowa
.02381 .36172 m
.03006 .36172 L
s
[(0.6)] .01131 .36172 1 0 Mshowa
.02381 .46464 m
.03006 .46464 L
s
[(0.8)] .01131 .46464 1 0 Mshowa
.02381 .56757 m
.03006 .56757 L
s
[(1)] .01131 .56757 1 0 Mshowa
.125 Mabswid
.02381 .07867 m
.02756 .07867 L
s
.02381 .1044 m
.02756 .1044 L
s
.02381 .13014 m
.02756 .13014 L
s
.02381 .1816 m
.02756 .1816 L
s
.02381 .20733 m
.02756 .20733 L
s
.02381 .23306 m
.02756 .23306 L
s
.02381 .28452 m
.02756 .28452 L
s
.02381 .31025 m
.02756 .31025 L
s
.02381 .33599 m
.02756 .33599 L
s
.02381 .38745 m
.02756 .38745 L
s
.02381 .41318 m
.02756 .41318 L
s
.02381 .43891 m
.02756 .43891 L
s
.02381 .49037 m
.02756 .49037 L
s
.02381 .51611 m
.02756 .51611 L
s
.02381 .54184 m
.02756 .54184 L
s
.02381 .02721 m
.02756 .02721 L
s
.02381 .00148 m
.02756 .00148 L
s
.02381 .5933 m
.02756 .5933 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.03125 .08869 m
.03869 .05056 L
.04613 .0191 L
.05357 .04738 L
.06101 .07639 L
.06845 .03502 L
.07589 .01472 L
.08333 .05123 L
.09077 .08519 L
.09821 .01616 L
.10565 .01629 L
.1131 .04374 L
.12054 .04648 L
.12798 .05047 L
.13542 .07636 L
.14286 .0624 L
.1503 .54019 L
.15774 .54225 L
.16518 .58992 L
.17262 .59613 L
.18006 .54657 L
.1875 .56656 L
.19494 .53088 L
.20238 .60212 L
.20982 .54941 L
.21726 .53034 L
.2247 .60332 L
.23214 .56909 L
.23958 .56456 L
.24702 .58686 L
.25446 .60295 L
.2619 .5322 L
.26935 .31359 L
.27679 .32774 L
.28423 .34369 L
.29167 .32269 L
.29911 .28145 L
.30655 .29161 L
.31399 .28167 L
.32143 .27463 L
.32887 .34743 L
.33631 .27833 L
.34375 .29792 L
.35119 .28467 L
.35863 .32983 L
.36607 .31793 L
.37351 .296 L
.38095 .28871 L
.38839 .30939 L
.39583 .31655 L
Mistroke
.40327 .29885 L
.41071 .32579 L
.41815 .2738 L
.4256 .33586 L
.43304 .30207 L
.44048 .32256 L
.44792 .30906 L
.45536 .27978 L
.4628 .30723 L
.47024 .34873 L
.47768 .29926 L
.48512 .33702 L
.49256 .29721 L
.5 .34575 L
.50744 .17203 L
.51488 .2017 L
.52232 .21949 L
.52976 .20409 L
.5372 .19105 L
.54464 .15543 L
.55208 .19514 L
.55952 .18703 L
.56696 .15332 L
.5744 .18773 L
.58185 .16795 L
.58929 .21009 L
.59673 .15117 L
.60417 .20072 L
.61161 .21474 L
.61905 .15919 L
.62649 .19096 L
.63393 .1926 L
.64137 .17917 L
.64881 .15931 L
.65625 .16336 L
.66369 .20443 L
.67113 .15361 L
.67857 .16241 L
.68601 .46883 L
.69345 .40305 L
.70089 .41163 L
.70833 .43583 L
.71577 .42079 L
.72321 .46782 L
.73065 .43668 L
.7381 .469 L
.74554 .41047 L
.75298 .42309 L
.76042 .41173 L
.76786 .40191 L
Mistroke
.7753 .4023 L
.78274 .44257 L
.79018 .41719 L
.79762 .46292 L
.80506 .43154 L
.8125 .47016 L
.81994 .45822 L
.82738 .4466 L
.83482 .41118 L
.84226 .40873 L
.8497 .44761 L
.85714 .4272 L
.86458 .03389 L
.87202 .02003 L
.87946 .05032 L
.8869 .0829 L
.89435 .09061 L
.90179 .02972 L
.90923 .09115 L
.91667 .09141 L
.92411 .08045 L
.93155 .08414 L
.93899 .07974 L
.94643 .08982 L
.95387 .07846 L
.96131 .04189 L
.96875 .06286 L
.97619 .02722 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[24]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo000EOol2003oOol:Ool001Eoo`03001oogoo0?moo`Uoo`005Goo00<0
07ooOol0ogoo2Goo000EOol00`00Oomoo`0QOol30003Ool00`00Oomoo`0QOol30002Ool00`00Oomo
o`0OOol20004Ool00`00Oomoo`0QOol00`00Oomoo`02Ool00`00Oomoo`0LOol50002Ool00`00Oomo
o`02Ool00`00Oomoo`0IOol5000017oo000000000goo00<007ooOol04Goo000EOol00`00Oomoo`0;
Ool00`00Oomoo`03Ool3000=Ool00`00Oomoo`02Ool00`00Ool0000SOol01P00Oomoo`00Ool0021o
o`03001oo`00009oo`03001oo`00025oo`03001oo`00009oo`03001oo`0001moo`07001oogooOol0
07oo00000Woo00<007oo000077oo00D007ooOomoo`0000Aoo`03001oo`00019oo`005Goo00<007oo
Ool00goo00<007ooOol01Goo00<007ooOol00goo00<007oo00003Woo00L007ooOomoo`00Ool0000Q
Ool4000017oo001oo`0087oo00<007oo00000Woo00<007oo00008Goo00<007oo00000Woo00<007oo
00007goo00L007ooOomoo`00Ool00002Ool00`00Ool0000FOol00`00Oomoo`03Ool00`00Oomoo`02
Ool01`00Oomoogoo001oo`00019oo`005Goo00<007ooOol00goo00<007ooOol017oo0P001Goo00<0
07oo00003Woo00L007ooOomoo`00Ool0000QOol00`00Ool00002Ool00`00Ool0000POol20003Ool0
0`00Ool0000ROol01`00Oomoogoo001oo`0001moo`07001oogooOol007oo00000Woo00<007oo0000
5Goo0P001Goo00<007ooOol00Woo00L007ooOomoo`00Ool0000BOol001Eoo`8000Aoo`03001oogoo
00Aoo`03001oo`0000Aoo`04001oogoo000<Ool00`00Ool00002Ool00`00Ool0000ROol20002Ool0
0`00Ool0000POol00`00Oomoo`02Ool00`00Ool0000QOol00`00Ool00002Ool00`00Ool0000OOol0
1`00Oomoogoo001oo`00009oo`03001oo`0001Eoo`8000Eoo`07001oogooOol007oo00000Woo00<0
07oo00002Woo00<007ooOol01Goo000EOol00`00Oomoo`02Ool00`00Ool00004Ool01000Oomoo`00
17oo00@007ooOol000eoo`03001oogoo009oo`03001oogoo029oo`05001oogooOol0000ROol20003
Ool00`00Oomoo`0QOol00`00Oomoo`02Ool00`00Oomoo`0MOol20004Ool00`00Oomoo`02Ool00`00
Oomoo`0COol01000Oomoo`000goo0P0000Eoo`00Oomoo`0000Aoo`03001oogoo00Uoo`03001oogoo
00Eoo`005Goo00<007ooOol00Woo00<007oo000017oo00@007ooOol000=oo`05001oogooOol0003=
Ool01000Oomoo`001Woo00<007ooOol04Goo00<007ooOol01Goo000EOol00`00Oomoo`02Ool00`00
Ool00004Ool01000Oomoo`000goo00D007ooOomoo`000<eoo`04001oogoo0006Ool00`00Oomoo`0@
Ool00`00Oomoo`06Ool001Eoo`03001oogoo009oo`03001oo`0000Aoo`04001oogoo0003Ool00`00
Oomoo`02Ool00`00Oomoo`3:Ool01000Oomoo`001Woo00<007ooOol03Goo00@007ooOol000Qoo`00
5Goo00D007ooOomoo`0000=oo`04001oogoo0004Ool01000Oomoo`0017oo00<007ooOol0bWoo00D0
07ooOomoo`0000Eoo`03001oogoo00eoo`04001oogoo0008Ool001Eoo`05001oogooOol00003Ool0
1000Oomoo`0017oo00@007ooOol000Eoo`800<Yoo`05001oogooOol00004Ool00`00Ool0000>Ool2
00000goo001oo`07Ool000ioool001<000005Goo00D007ooOomoo`0000=oo`04001oo`000004Ool0
0`00Oomoo`020007Ool00`00Ool00009Ool00`00Oomoo`08Ool00`00Oomoo`07Ool00`00Oomoo`07
Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07
Ool00`00Oomoo`07Ool00`00Oomoo`08Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07
Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`08
Ool00`00Oomoo`03Ool01@00Oomoogoo000017oo00<007oo00000Woo00<007ooOol01goo0P0000=o
o`0000001Goo00<007ooOol00Goo000EOol01@00Oomoogoo000017oo00<007oo000017oo00@007oo
Ool000Uoo`03001oogoo00Qoo`03001oogoo02Ioo`03001oogoo02Eoo`03001oogoo02Ioo`03001o
ogoo02Eoo`03001oogoo01Qoo`05001oogooOol00004Ool00`00Ool00002Ool00`00Oomoo`08Ool0
1000Oomoo`002Goo000EOol01000Oomoo`001Goo00<007oo00001Goo00<007oo00002Goo00@007oo
Ool00<Aoo`03001oogoo009oo`07001oogooOol007oo00003Goo00@007ooOol000Uoo`005Goo00@0
07ooOol000Eoo`8000Ioo`03001oo`0000Uoo`04001oo`000034Ool00`00Oomoo`02Ool01`00Oomo
ogoo001oo`0000eoo`03001oogoo00Yoo`005Goo00@007ooOol000Eoo`8000Ioo`8000Yoo`04001o
o`000034Ool00`00Oomoo`02Ool01`00Oomoogoo001oo`0000aoo`03001oogoo00]oo`005Goo00@0
07ooOol000Ioo`03001oogoo00Aoo`8000]oo`03001oo`000<Aoo`03001oogoo009oo`07001oogoo
Ool007oo000037oo00<007ooOol02goo000EOol200000goo001oo`05Ool00`00Oomoo`05Ool00`00
Oomoo`09Ool00`00Ool00034Ool00`00Oomoo`03Ool00`00Ool00003Ool00`00Oomoo`09Ool00`00
Oomoo`0;Ool001Eoo`03001oo`0000moo`03001oogoo00]oo`03001oogoo0<9oo`03001oogoo00=o
o`03001oo`0000=oo`05001oogooOol00003Ool01000Oomoo`003Woo000EOol00`00Ool0000?Ool0
0`00Oomoo`0;Ool00`00Oomoo`32Ool00`00Oomoo`03Ool00`00Ool00003Ool01@00Oomoo`00Ool0
0`0000Aoo`00Ool000ioo`005Goo00<007oo00007Goo00<007ooOol0`Woo00<007ooOol017oo0P00
0goo00@007ooOol000Ioo`03001oogoo00eoo`005Goo00<007ooOol07Goo00<007ooOol0`Woo00<0
07ooOol01Goo00@007ooOomoo`<001Moo`005Goo00<007ooOol07Goo00<007ooOol0`Woo00<007oo
Ool08goo000EOol00`00Oomoo`0MOol00`00Oomoo`32Ool00`00Oomoo`0SOol001Eoo`8001ioo`03
001oogoo0<9oo`03001oogoo02=oo`005Goo00<007ooOol07Goo00<007ooOol0`Woo00<007ooOol0
8goo000EOol00`00Oomoo`0MOol00`00Oomoo`32Ool00`00Oomoo`0SOol001Eoo`03001oogoo01eo
o`03001oogoo0<9oo`03001oogoo02=oo`005Goo00<007ooOol07Goo00<007ooOol0`Woo00<007oo
Ool08goo000EOol00`00Oomoo`0MOol00`00Oomoo`32Ool00`00Oomoo`0SOol001Eoo`03001oogoo
01eoo`03001oogoo0<9oo`03001oogoo02=oo`005Goo0P007Woo00<007ooOol0`Woo00<007ooOol0
8goo000EOol00`00Oomoo`0MOol00`00Oomoo`31Ool00`00Oomoo`0TOol001Eoo`03001oogoo01eo
o`03001oogoo0<5oo`03001oogoo02Aoo`005Goo00<007ooOol07Goo00<007ooOol0`Goo00<007oo
Ool097oo000EOol00`00Oomoo`0MOol00`00Oomoo`31Ool00`00Oomoo`0TOol000Eoo`03001oogoo
009oo`04001oogooOol30004Ool00`00Oomoo`0MOol00`00Oomoo`31Ool00`00Oomoo`0TOol000Ao
o`03001oo`0000Moo`03001oogoo00Aoo`03001oogoo01eoo`03001oogoo07Uoo`03001oogoo04Eo
o`03001oogoo02Aoo`0017oo00<007oo000027oo00<007ooOol00goo0`007Goo00<007ooOol0Jgoo
00<007ooOol00goo00<007ooOol01Goo00<007ooOol04Goo00<007ooOol0<Goo00<007ooOol097oo
0004Ool00`00Ool00008Ool00`00Oomoo`03Ool00`00Oomoo`0MOol00`00Oomoo`1[Ool00`00Oomo
o`03Ool00`00Oomoo`05Ool00`00Oomoo`03Ool00`00Oomoo`05Ool00`00Oomoo`03Ool2000bOol0
0`00Oomoo`0TOol000Aoo`03001oo`0000Moo`03001oo`0000Aoo`03001oogoo01eoo`03001oogoo
06]oo`03001oogoo00=oo`03001oogoo00Eoo`03001oogoo00=oo`03001oogoo00Eoo`<000=oo`03
001oo`00035oo`03001oogoo02Aoo`001Goo00<007ooOol01goo00<007ooOol00goo00<007ooOol0
7Goo00<007ooOol0JWoo00<007oo00000goo00<007oo00001Goo00<007oo000017oo00<007ooOol0
17oo00@007ooOol000=oo`03001oo`00035oo`03001oogoo02Aoo`005Goo00<007ooOol07Goo00<0
07ooOol0JWoo00<007oo00000goo00<007oo00000Woo00H007ooOol007oo0004Ool20005Ool01000
Oomoo`000Woo00@007ooOol0035oo`03001oogoo02Aoo`005Goo00<007ooOol07Goo00<007ooOol0
H7oo00<007ooOol01goo00<007oo00000goo00<007oo00000Woo00H007ooOol007oo0003Ool00`00
Ool00005Ool01000Oomoo`000Woo00@007ooOol0035oo`03001oogoo02Aoo`005Goo00<007ooOol0
7Goo00<007ooOol0H7oo00<007ooOol01goo00<007oo00000goo00@007oo001oo`80009oo`03001o
o`0000=oo`03001oo`0000Aoo`03001oogoo009oo`03001oo`00009oo`03001oogoo02moo`03001o
ogoo02Aoo`005Goo0P007Woo00<007ooOol0H7oo0P0027oo00<007oo00000Woo00@007ooOomoo`80
0006Ool007oo001oo`000goo00<007oo000017oo00<007ooOol00Woo00<007oo00000Woo00<007oo
Ool0;goo00<007ooOol097oo000EOol00`00Oomoo`0NOol00`00Oomoo`1OOol20007Ool01000Oomo
o`000Woo00D007ooOomoo`00009oo`05001oo`00Ool00003Ool01000Oomoo`000Woo00<007ooOol0
0goo00<007oo00000Woo00<007ooOol0;goo00<007ooOol097oo000EOol00`00Oomoo`0NOol00`00
Oomoo`1OOol20007Ool01`00Oomoogoo001oo`0000=oo`08001oogoo001oo`00Ool000=oo`04001o
ogoo0002Ool00`00Oomoo`03Ool00`00Ool00002Ool00`00Oomoo`0_Ool00`00Oomoo`0TOol001Eo
o`03001oogoo01ioo`03001oogoo05moo`03001oo`0000Ioo`04001oogooOol20007Ool00`00Ool0
0002Ool01000Oomoo`000Woo0`001Woo00<007oo00000Woo00<007ooOol0;goo00<007ooOol097oo
000EOol00`00Oomoo`0NOol00`00Oomoo`1OOol00`00Ool00005Ool00`00Oomoo`02Ool00`00Oomo
o`06Ool20003Ool01000Oomoo`002goo0P000goo00<007ooOol0;goo00<007ooOol097oo000EOol0
0`00Oomoo`0NOol00`00Oomoo`1OOol01000Oomoo`0017oo00<007ooOol02goo0P000goo00@007oo
Ool000aoo`05001oogooOol0000aOol00`00Oomoo`0TOol001Eoo`03001oogoo01ioo`03001oogoo
05moo`04001oogoo0003Ool00`00Oomoo`0=Ool01`00Oomoogoo001oo`0000eoo`05001oogooOol0
000aOol00`00Oomoo`0TOol001Eoo`8001moo`03001oogoo05moo`04001oogoo0003Ool00`00Oomo
o`0=Ool00`00Oomoo`02Ool2000=Ool01@00Oomoogoo0000<Goo00<007ooOol097oo000EOol00`00
Oomoo`0NOol00`00Oomoo`1OOol01`00Oomoogoo001oo`00011oo`03001oogoo009oo`80015oo`03
001oogoo02moo`03001oogoo02Aoo`005Goo00<007ooOol07Woo00<007ooOol0Ggoo00L007ooOomo
o`00Ool0000FOol00`00Oomoo`0?Ool00`00Oomoo`0_Ool00`00Oomoo`0TOol001Eoo`03001oogoo
01ioo`03001oogoo05ioo`03001oogoo00=oo`03001oogoo02Moo`03001oogoo02moo`03001oogoo
02Aoo`005Goo00<007ooOol07Woo00<007ooOol0GWoo00<007ooOol00goo00<007ooOol09goo00<0
07ooOol0;goo00<007ooOol097oo000EOol00`00Oomoo`0NOol00`00Oomoo`1NOol00`00Oomoo`0]
Ool00`00Oomoo`0_Ool00`00Oomoo`0TOol001Eoo`03001oogoo01ioo`03001oogoo05ioo`03001o
ogoo02eoo`03001oogoo02moo`03001oogoo02Aoo`005Goo0P007goo00<007ooOol0GWoo00<007oo
Ool0;Goo00<007ooOol0;goo00<007ooOol097oo000EOol00`00Oomoo`0NOol00`00Oomoo`1NOol0
0`00Oomoo`0]Ool00`00Oomoo`0_Ool00`00Oomoo`0TOol001Eoo`03001oogoo01ioo`03001oogoo
05ioo`03001oogoo02eoo`03001oogoo02moo`03001oogoo02Aoo`005Goo00<007ooOol07Woo00<0
07ooOol0GWoo00<007ooOol0;Woo00<007ooOol0;Woo00<007ooOol097oo000EOol00`00Oomoo`0N
Ool00`00Oomoo`1NOol00`00Oomoo`0^Ool00`00Oomoo`0^Ool00`00Oomoo`0TOol000Eoo`03001o
ogoo009oo`03001oogoo009oo`<000=oo`03001oogoo01ioo`03001oogoo05ioo`03001oogoo02io
o`03001oogoo02ioo`03001oogoo02Aoo`0017oo00<007oo00002Goo00<007ooOol00Woo00<007oo
Ool07Woo00<007ooOol0GWoo00<007ooOol0;Woo00<007ooOol0;Woo00<007ooOol097oo0004Ool0
0`00Ool00007Ool40003Ool3000NOol00`00Oomoo`1NOol00`00Oomoo`0^Ool00`00Oomoo`0^Ool0
0`00Oomoo`0TOol000Aoo`03001oo`0000Moo`03001oo`0000Aoo`03001oogoo01ioo`03001oogoo
05ioo`03001oogoo02ioo`03001oogoo02ioo`03001oogoo02Aoo`0017oo00<007oo000027oo0P00
17oo00<007ooOol07Woo00<007ooOol0GWoo00<007ooOol0;Woo00<007ooOol0;Woo00<007ooOol0
97oo0005Ool00`00Oomoo`08Ool00`00Oomoo`02Ool00`00Oomoo`0NOol00`00Oomoo`1NOol00`00
Oomoo`0^Ool00`00Oomoo`0^Ool00`00Oomoo`0TOol001Eoo`03001oogoo01ioo`03001oogoo04Mo
o`03001oogoo01Aoo`03001oogoo02ioo`03001oogoo02ioo`03001oogoo02Aoo`005Goo00<007oo
Ool07Woo00<007ooOol0;Goo00<007ooOol05goo00<007ooOol057oo00<007ooOol0;Woo00<007oo
Ool0;Woo00<007ooOol097oo000EOol00`00Oomoo`0NOol00`00Oomoo`0/Ool20003Ool00`00Oomo
o`0COol00`00Oomoo`07Ool00`00Oomoo`0:Ool00`00Oomoo`0^Ool00`00Oomoo`0^Ool00`00Oomo
o`0TOol001Eoo`8001moo`03001oogoo02Moo`07001oogooOol007oo00000goo00D007ooOomoo`00
015oo`03001oogoo00Moo`03001oogoo00Yoo`03001oogoo02ioo`03001oogoo02ioo`03001oogoo
02Aoo`005Goo00<007ooOol07Woo00<007ooOol09goo0P0000Eoo`00Oomoo`0000=oo`800003Ool0
0000011oo`8000Qoo`8000aoo`03001oogoo02ioo`03001oogoo02ioo`03001oogoo02Aoo`005Goo
00<007ooOol07Woo00<007ooOol09goo00<007oo00000goo00@007ooOomoo`800003Ool0000000Mo
o`03001oogoo00Ioo`03001oo`0000Moo`03001oo`0000]oo`03001oogoo02ioo`03001oogoo02io
o`03001oogoo02Aoo`005Goo00<007ooOol07Woo00<007ooOol09Woo00<007ooOol01Goo00P007oo
Ool007oo001oo`001Goo0`0027oo00<007oo00001goo00<007oo00002goo00<007ooOol0;Woo00<0
07ooOol0;Woo00<007ooOol097oo000EOol00`00Oomoo`0NOol00`00Oomoo`0VOol00`00Oomoo`05
Ool00`00Ool00002Ool01000Oomoo`0017oo00@007ooOol000Aoo`06001oogoo001oo`001goo00<0
07oo000017oo00D007ooOomoo`00009oo`03001oogoo02ioo`03001oogoo02ioo`03001oogoo02Ao
o`005Goo00<007ooOol07Woo00<007ooOol09Woo00<007ooOol01Goo00<007oo00001Goo00D007oo
Oomoo`0000=oo`03001oogoo009oo`06001oogoo001oo`000Woo00D007ooOomoo`00009oo`03001o
ogoo009oo`05001oogooOol00002Ool00`00Oomoo`0^Ool00`00Oomoo`0^Ool00`00Oomoo`0TOol0
01Eoo`03001oogoo01ioo`03001oogoo02Ioo`03001oogoo00Eoo`03001oo`0000Eoo`05001oogoo
Ool00004Ool00`00Oomoo`020002Ool00`00Ool00002Ool01@00Oomoogoo00000goo00D007ooOomo
o`0000=oo`03001oo`00035oo`03001oogoo02ioo`03001oogoo02Aoo`005Goo0P007goo00<007oo
Ool09Woo00<007ooOol01Goo00<007oo00001Goo00D007ooOomoo`0000Aoo`0:001oogoo001oo`00
Ool007oo0002Ool20002Ool01@00Oomoogoo00000goo0P0000Eoo`00001oo`00035oo`03001oogoo
02ioo`03001oogoo02Aoo`005Goo00<007ooOol07Woo00<007ooOol07goo00<007ooOol017oo00<0
07ooOol01Goo00<007oo00001Goo00@007ooOol000Ioo`80009oo`0;001oo`00Ool007oo001oo`00
Ool00004Ool02@00Oomoo`00Ool007oo001oo`02000aOol00`00Oomoo`0^Ool00`00Oomoo`0TOol0
01Eoo`03001oogoo01ioo`03001oogoo01moo`03001oogoo00=oo`03001oogoo00Ioo`03001oo`00
00Eoo`04001oogoo0007Ool00`00Oomoo`020002Ool01`00Ool007oo001oo`0000Aoo`09001oogoo
001oo`00Ool007oo0080035oo`03001oogoo02ioo`03001oogoo02Aoo`005Goo00<007ooOol07Woo
00<007ooOol07goo0P0017oo00<007ooOol01Woo00<007oo00001Woo0P002goo0P000goo0P000Woo
00<007ooOol017oo00P007oo001oo`00Ool007oo0P00<Goo00<007ooOol0;Woo00<007ooOol097oo
000EOol00`00Oomoo`0NOol00`00Oomoo`0OOol20004Ool00`00Oomoo`06Ool00`00Ool00006Ool2
000<Ool01000Oomoogoo0P000Woo00<007ooOol017oo00P007oo001oo`00Ool007oo0P00<Goo00<0
07ooOol0;Woo00<007ooOol097oo000EOol00`00Oomoo`0NOol00`00Oomoo`0OOol00`00Ool00003
Ool00`00Oomoo`06Ool00`00Ool00006Ool00`00Oomoo`0;Ool01@00Oomoogoo00002Woo00P007oo
001oo`00Ool007oo0P00<Goo00<007ooOol0;Woo00<007ooOol097oo000EOol00`00Oomoo`0NOol0
0`00Oomoo`0OOol00`00Ool00002Ool00`00Oomoo`08Ool00`00Oomoo`05Ool00`00Oomoo`0?Ool0
0`00Oomoo`08Ool00`00Ool00002Ool00`00Oomoo`02000aOol00`00Oomoo`0]Ool00`00Oomoo`0U
Ool001Eoo`8001moo`03001oogoo01moo`06001oogoo001oo`002Woo00<007ooOol05goo00<007oo
Ool027oo00<007oo00000Woo00D007ooOomoo`00035oo`03001oogoo02eoo`03001oogoo02Eoo`00
5Goo00<007ooOol07Woo00<007ooOol07goo00<007ooOol00P002goo00<007ooOol08Woo0P000goo
00D007ooOomoo`00035oo`03001oogoo02eoo`03001oogoo02Eoo`005Goo00<007ooOol07Woo00<0
07ooOol07goo00D007ooOomoo`0000]oo`03001oogoo02=oo`03001oogoo00Eoo`03001oogoo02mo
o`03001oogoo02eoo`03001oogoo02Eoo`005Goo00<007ooOol07Woo00<007ooOol07goo00<007oo
Ool03Goo00<007ooOol08goo00<007ooOol01Goo00<007ooOol0;goo00<007ooOol0;Goo00<007oo
Ool09Goo000EOol00`00Oomoo`0NOol00`00Oomoo`0OOol00`00Oomoo`0cOol00`00Oomoo`0gOol0
0`00Oomoo`0]Ool00`00Oomoo`0UOol000Eoo`03001oogoo009oo`04001oogooOol20005Ool00`00
Oomoo`0NOol00`00Oomoo`0OOol00`00Oomoo`1]Ool00`00Oomoo`0]Ool00`00Oomoo`0UOol000Ao
o`03001oo`0000Moo`03001oo`0000Aoo`03001oogoo01ioo`03001oogoo01moo`03001oogoo06eo
o`03001oogoo02eoo`03001oogoo02Eoo`0017oo00<007oo00001goo00<007oo000017oo0`007Woo
00<007ooOol07goo00<007ooOol0KGoo00<007ooOol0;Goo00<007ooOol09Goo0004Ool00`00Ool0
0007Ool20005Ool00`00Oomoo`0NOol00`00Oomoo`0OOol00`00Oomoo`1]Ool00`00Oomoo`0]Ool0
0`00Oomoo`0UOol000Aoo`03001oo`0000Moo`03001oogoo00Aoo`03001oogoo01ioo`03001oogoo
01ioo`03001oogoo06ioo`03001oogoo02eoo`03001oogoo02Eoo`001Goo00<007ooOol01goo0P00
17oo00<007ooOol07Woo00<007ooOol07Woo00<007ooOol0KWoo00<007ooOol0;Goo00<007ooOol0
9Goo000EOol00`00Oomoo`0NOol00`00Oomoo`0NOol00`00Oomoo`1^Ool00`00Oomoo`0]Ool00`00
Oomoo`0UOol001Eoo`03001oogoo01ioo`03001oogoo01ioo`03001oogoo06ioo`03001oogoo02eo
o`03001oogoo02Eoo`005Goo00<007ooOol07Woo00<007ooOol07Woo00<007ooOol0KWoo00<007oo
Ool0;Goo00<007ooOol09Goo000EOol2000OOol00`00Oomoo`0NOol00`00Oomoo`1^Ool00`00Oomo
o`0]Ool00`00Oomoo`0UOol001Eoo`03001oogoo01ioo`03001oogoo01ioo`03001oogoo06ioo`03
001oogoo02eoo`03001oogoo02Eoo`005Goo00<007ooOol07Woo00<007ooOol07Woo00<007ooOol0
KWoo00<007ooOol0;Goo00<007ooOol09Goo000EOol00`00Oomoo`0NOol00`00Oomoo`0NOol00`00
Oomoo`1_Ool00`00Oomoo`0/Ool00`00Oomoo`0UOol001Eoo`03001oogoo01ioo`03001oogoo01io
o`03001oogoo06moo`03001oogoo01=oo`<001Ioo`03001oogoo02Eoo`005Goo00<007ooOol07Woo
00<007ooOol07Woo00<007ooOol0Kgoo00<007oo00004Woo00@007ooOol001Ioo`03001oogoo02Eo
o`005Goo00<007ooOol07Woo00<007ooOol07Woo00<007ooOol0Kgoo00@007oo0000015oo`04001o
ogoo000BOol01@00Oomoogoo00009goo000EOol2000OOol00`00Oomoo`0NOol00`00Oomoo`1_Ool0
1@00Ool007oo00002goo00D007ooOomoo`0000Aoo`03001oogoo00eoo`<000=oo`03001oogoo02Eo
o`005Goo00<007ooOol07Woo00<007ooOol07Woo00<007ooOol0Kgoo00D007oo001oo`0000]oo`80
0003Ool007oo00Aoo`04001oogoo000<Ool00`00Ool00003Ool00`00Oomoo`0UOol001Eoo`03001o
ogoo01ioo`03001oogoo01ioo`03001oogoo06moo`03001oo`00009oo`04001oogoo0007Ool20000
0goo001oo`04Ool01000Oomoo`0037oo00@007ooOol0009oo`03001oogoo02Eoo`005Goo00<007oo
Ool07goo00<007ooOol07Goo00<007ooOol0Kgoo0P000goo00@007ooOol000Moo`03001oo`0000Io
o`04001oo`00000;Ool01@00Oomoogoo00000Woo00<007ooOol09Goo000EOol00`00Oomoo`0OOol0
0`00Oomoo`0MOol00`00Oomoo`1_Ool20003Ool01000Ool000001Woo00<007ooOol01goo00@007oo
000000]oo`05001oogooOol00002Ool00`00Oomoo`0UOol001Eoo`03001oogoo01moo`03001oogoo
01eoo`03001oogoo06moo`8000=oo`04001oo`000006Ool00`00Oomoo`07Ool01@00Ool007oo0000
0Woo00<007ooOol01Goo00D007ooOomoo`00009oo`03001oogoo02Eoo`005Goo00<007ooOol07goo
00<007ooOol07Goo00<007ooOol0Kgoo0P0017oo00@007ooOol000Eoo`03001oogoo00Qoo`800005
Ool007ooOol00007Ool01`00Oomoogoo001oo`0002Qoo`005Goo0P0087oo00<007ooOol07Goo00<0
07ooOol0Kgoo0P0017oo00@007ooOol0009oo`04001oogoo000:Ool01000Oomoo`000Woo00<007oo
Ool017oo00<007ooOol00Woo00<007oo0000:7oo000EOol00`00Oomoo`0OOol00`00Oomoo`0MOol0
0`00Oomoo`1_Ool20007Ool01000Oomoo`000Woo00<007ooOol027oo00P007ooOol007oo001oo`00
1Goo00<007ooOol00goo0P00:7oo000EOol00`00Oomoo`0OOol00`00Oomoo`0MOol00`00Oomoo`1_
Ool20007Ool01000Ool000000Woo00<007ooOol02goo00D007oo001oo`0000Eoo`03001oogoo00=o
o`03001oogoo02Moo`005Goo00<007ooOol07goo00<007ooOol07Goo00<007ooOol0Kgoo0P001goo
00L007oo001oo`00Ool0000=Ool01@00Ool007oo000017oo00<007ooOol017oo00<007ooOol09goo
000EOol00`00Oomoo`0OOol00`00Oomoo`0MOol00`00Oomoo`1_Ool20007Ool01`00Ool007oo001o
o`0000ioo`800003Ool007oo00=oo`03001oogoo02ioo`001Goo00<007ooOol00Woo00<007ooOol0
0Woo00<007ooOol00goo00<007ooOol07goo00<007ooOol07Goo00<007ooOol0Kgoo00<007ooOol0
1goo0P0000=oo`0000003goo00@007ooOol000=oo`03001oogoo02moo`0017oo00<007oo00001goo
00<007oo000017oo00<007ooOol07goo00<007ooOol07Goo00<007ooOol0Kgoo00<007ooOol01goo
00<007ooOol00P003goo00@007ooOol000=oo`03001oogoo02moo`0017oo00<007oo00001goo00<0
07oo000017oo0`007goo00<007ooOol07Goo00<007ooOol0Kgoo00<007ooOol01goo00D007ooOomo
o`0000moo`07001oogooOol007oo0000<Woo0004Ool00`00Ool00008Ool00`00Oomoo`03Ool00`00
Oomoo`0OOol00`00Oomoo`0MOol00`00Oomoo`1_Ool00`00Oomoo`07Ool01@00Oomoogoo00004goo
0P00<goo0004Ool00`00Ool00007Ool00`00Ool00004Ool00`00Oomoo`0OOol00`00Oomoo`0MOol0
0`00Oomoo`1_Ool00`00Oomoo`0;Ool00`00Oomoo`0AOol00`00Oomoo`0bOol000Eoo`03001oogoo
00Moo`03001oogoo00=oo`03001oogoo01moo`03001oogoo01eoo`03001oogoo0<Ioo`005Goo00<0
07ooOol07goo00<007ooOol077oo00<007ooOol0agoo000EOol00`00Oomoo`0OOol00`00Oomoo`0L
Ool00`00Oomoo`37Ool001Eoo`03001oogoo01moo`03001oogoo01aoo`03001oogoo0<Moo`005Goo
0P0087oo00<007ooOol077oo00<007ooOol0agoo000EOol00`00Oomoo`0OOol00`00Oomoo`0LOol0
0`00Oomoo`37Ool001Eoo`03001oogoo01moo`03001oogoo01aoo`03001oogoo0<Moo`005Goo00<0
07ooOol07goo00<007ooOol077oo00<007ooOol0agoo000EOol00`00Oomoo`0OOol00`00Oomoo`0L
Ool00`00Oomoo`37Ool001Eoo`03001oogoo01moo`03001oogoo01aoo`03001oogoo0<Moo`005Goo
00<007ooOol07goo00<007ooOol077oo00<007ooOol0agoo000EOol2000POol00`00Oomoo`0LOol0
0`00Oomoo`37Ool001Eoo`03001oogoo01moo`03001oogoo01aoo`03001oogoo0<Moo`005Goo00<0
07ooOol07goo00<007ooOol077oo00<007ooOol0agoo000EOol00`00Oomoo`0OOol00`00Oomoo`0L
Ool00`00Oomoo`37Ool001Eoo`03001oogoo01moo`03001oogoo00Uoo`03001oogoo00Aoo`03001o
ogoo00Uoo`03001oogoo0<Moo`005Goo00<007ooOol07goo00<007ooOol02Goo00<007ooOol017oo
00<007ooOol02Goo00<007ooOol0agoo000EOol00`00Oomoo`0OOol00`00Oomoo`09Ool00`00Oomo
o`03Ool2000;Ool00`00Oomoo`37Ool001Eoo`80021oo`<000Qoo`8000Eoo`8000]oo`03001oogoo
0<Moo`005Goo00<007ooOol08Goo00<007ooOol01Woo0P0017oo00<007oo00002goo00<007ooOol0
agoo000EOol00`00Oomoo`0QOol00`00Oomoo`03Ool00`00Oomoo`020004Ool00`00Ool0000;Ool0
0`00Oomoo`37Ool001Eoo`03001oogoo025oo`03001oogoo00=oo`06001oogoo001oo`000goo00@0
07ooOol000Uoo`03001oogoo0<Qoo`005Goo00<007ooOol08Woo00<007ooOol00Woo0P0000Aoo`00
Ool000=oo`04001oogoo0009Ool00`00Oomoo`38Ool000eoo`D000=oo`03001oogoo029oo`03001o
ogoo009oo`<0009oo`04001oogoo0003Ool00`00Oomoo`07Ool00`00Oomoo`38Ool000moo`03001o
ogoo00=oo`03001oogoo029oo`05001oogooOol00002Ool01000Oomoo`000Woo00D007ooOomoo`00
00Uoo`03001oogoo0<Qoo`003goo00<007ooOol00goo0`008Woo00D007ooOomoo`00009oo`04001o
ogoo0002Ool01@00Oomoogoo000017oo00<007ooOol00Woo00<007ooOol0b7oo000?Ool00`00Oomo
o`03Ool00`00Oomoo`0ROol01@00Oomoogoo00001Goo00@007ooOol000=oo`03001oogoo00<000Ao
o`03001oogoo0<Qoo`003goo00<007ooOol00goo00<007ooOol08Woo00D007ooOomoo`0000Eoo`04
001oogoo0003Ool01000Oomoo`000Woo00D007ooOomoo`000<Yoo`003Woo0P001Goo00<007ooOol0
8goo00@007ooOol000Eoo`03001oo`0000Aoo`04001oogoo0002Ool01@00Oomoogoo0000bWoo000E
Ool00`00Oomoo`0SOol01000Oomoo`001Goo00<007oo000017oo00<007oo00000goo00D007ooOomo
o`000<Yoo`005Goo00<007ooOol08goo00<007oo00001Woo00<007oo000017oo00<007oo000017oo
00@007ooOol00<Yoo`005Goo00<007ooOol08goo00<007oo00001goo0P001Goo0P0017oo00<007oo
0000bgoo000EOol2000UOol20007Ool20005Ool20004Ool00`00Ool0003;Ool001Eoo`03001oogoo
02Eoo`03001oogoo00Eoo`03001oogoo00Aoo`03001oogoo00Aoo`800<]oo`005Goo00<007ooOol0
;Goo00<007ooOol017oo00<007ooOol017oo0P00bgoo000EOol00`00Oomoo`0]Ool00`00Oomoo`04
Ool00`00Oomoo`05Ool00`00Oomoo`39Ool001Eoo`03001oogoo0?moo`Uoo`005Goo00<007ooOol0
ogoo2Goo000EOol00`00Oomoo`3oOol9Ool001Eoo`03001oogoo0?moo`Uoo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-10.5723, -0.134253, 
  0.493982, 0.007142}}]
}, Open  ]],

Cell["\<\
Here we compute the full decomposition of the example signal.\
\>", "Text"],

Cell[BoxData[
    \(\(X\_DWT = DWT[x, D\_2]; \)\)], "Input"],

Cell["\<\
Here is the structure of the DWT output, the wavelet transform \
coefficients.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Dimensions\ /@\ X\_DWT\)], "Input"],

Cell[BoxData[
    \({{1}, {1}, {2}, {4}, {8}, {16}, {32}, {64}}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  " Here we display the two highest level detail (highpass) coefficients ",
  Cell[BoxData[
      \(TraditionalForm\`d\^6\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`d\^5\)]],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[
      GraphicsArray[
        \(ListPlot[#1, \n\t\t\t\tPlotJoined \[Rule] True, 
              PlotRange \[Rule] All, DisplayFunction \[Rule] Identity]&\)\ /@
          \ {Last[X\_DWT], Last[Drop[X\_DWT, \(-1\)]]}]]; \)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .2943 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.00700719 0.47619 [
[ 0 0 0 0 ]
[ 1 .2943 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .2943 L
0 .2943 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.00700719 0.477324 0.287295 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00869237 0.0151172 0.349575 0.943084 [
[.15986 .33708 -6 -9 ]
[.15986 .33708 6 0 ]
[.31104 .33708 -6 -9 ]
[.31104 .33708 6 0 ]
[.46221 .33708 -6 -9 ]
[.46221 .33708 6 0 ]
[.61338 .33708 -6 -9 ]
[.61338 .33708 6 0 ]
[.76455 .33708 -6 -9 ]
[.76455 .33708 6 0 ]
[.91572 .33708 -6 -9 ]
[.91572 .33708 6 0 ]
[-0.00381 .06665 -24 -4.5 ]
[-0.00381 .06665 0 4.5 ]
[-0.00381 .16096 -24 -4.5 ]
[-0.00381 .16096 0 4.5 ]
[-0.00381 .25527 -24 -4.5 ]
[-0.00381 .25527 0 4.5 ]
[-0.00381 .44388 -18 -4.5 ]
[-0.00381 .44388 0 4.5 ]
[-0.00381 .53819 -18 -4.5 ]
[-0.00381 .53819 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.15986 .34958 m
.15986 .35583 L
s
[(10)] .15986 .33708 0 1 Mshowa
.31104 .34958 m
.31104 .35583 L
s
[(20)] .31104 .33708 0 1 Mshowa
.46221 .34958 m
.46221 .35583 L
s
[(30)] .46221 .33708 0 1 Mshowa
.61338 .34958 m
.61338 .35583 L
s
[(40)] .61338 .33708 0 1 Mshowa
.76455 .34958 m
.76455 .35583 L
s
[(50)] .76455 .33708 0 1 Mshowa
.91572 .34958 m
.91572 .35583 L
s
[(60)] .91572 .33708 0 1 Mshowa
.125 Mabswid
.03893 .34958 m
.03893 .35333 L
s
.06916 .34958 m
.06916 .35333 L
s
.0994 .34958 m
.0994 .35333 L
s
.12963 .34958 m
.12963 .35333 L
s
.1901 .34958 m
.1901 .35333 L
s
.22033 .34958 m
.22033 .35333 L
s
.25057 .34958 m
.25057 .35333 L
s
.2808 .34958 m
.2808 .35333 L
s
.34127 .34958 m
.34127 .35333 L
s
.3715 .34958 m
.3715 .35333 L
s
.40174 .34958 m
.40174 .35333 L
s
.43197 .34958 m
.43197 .35333 L
s
.49244 .34958 m
.49244 .35333 L
s
.52268 .34958 m
.52268 .35333 L
s
.55291 .34958 m
.55291 .35333 L
s
.58314 .34958 m
.58314 .35333 L
s
.64361 .34958 m
.64361 .35333 L
s
.67385 .34958 m
.67385 .35333 L
s
.70408 .34958 m
.70408 .35333 L
s
.73432 .34958 m
.73432 .35333 L
s
.79478 .34958 m
.79478 .35333 L
s
.82502 .34958 m
.82502 .35333 L
s
.85525 .34958 m
.85525 .35333 L
s
.88549 .34958 m
.88549 .35333 L
s
.94596 .34958 m
.94596 .35333 L
s
.97619 .34958 m
.97619 .35333 L
s
.25 Mabswid
0 .34958 m
1 .34958 L
s
.00869 .06665 m
.01494 .06665 L
s
[(-0.3)] -0.00381 .06665 1 0 Mshowa
.00869 .16096 m
.01494 .16096 L
s
[(-0.2)] -0.00381 .16096 1 0 Mshowa
.00869 .25527 m
.01494 .25527 L
s
[(-0.1)] -0.00381 .25527 1 0 Mshowa
.00869 .44388 m
.01494 .44388 L
s
[(0.1)] -0.00381 .44388 1 0 Mshowa
.00869 .53819 m
.01494 .53819 L
s
[(0.2)] -0.00381 .53819 1 0 Mshowa
.125 Mabswid
.00869 .08551 m
.01244 .08551 L
s
.00869 .10437 m
.01244 .10437 L
s
.00869 .12323 m
.01244 .12323 L
s
.00869 .1421 m
.01244 .1421 L
s
.00869 .17982 m
.01244 .17982 L
s
.00869 .19868 m
.01244 .19868 L
s
.00869 .21754 m
.01244 .21754 L
s
.00869 .23641 m
.01244 .23641 L
s
.00869 .27413 m
.01244 .27413 L
s
.00869 .29299 m
.01244 .29299 L
s
.00869 .31185 m
.01244 .31185 L
s
.00869 .33071 m
.01244 .33071 L
s
.00869 .36844 m
.01244 .36844 L
s
.00869 .3873 m
.01244 .3873 L
s
.00869 .40616 m
.01244 .40616 L
s
.00869 .42502 m
.01244 .42502 L
s
.00869 .46275 m
.01244 .46275 L
s
.00869 .48161 m
.01244 .48161 L
s
.00869 .50047 m
.01244 .50047 L
s
.00869 .51933 m
.01244 .51933 L
s
.00869 .04779 m
.01244 .04779 L
s
.00869 .02893 m
.01244 .02893 L
s
.00869 .01006 m
.01244 .01006 L
s
.00869 .55705 m
.01244 .55705 L
s
.00869 .57592 m
.01244 .57592 L
s
.00869 .59478 m
.01244 .59478 L
s
.00869 .61364 m
.01244 .61364 L
s
.25 Mabswid
.00869 0 m
.00869 .61803 L
s
.5 Mabswid
.02381 .31408 m
.03893 .31744 L
.05404 .37843 L
.06916 .36967 L
.08428 .32066 L
.0994 .38173 L
.11451 .3613 L
.12963 .01472 L
.14475 .3343 L
.15986 .32802 L
.17498 .37484 L
.1901 .41532 L
.20522 .41034 L
.22033 .39744 L
.23545 .31316 L
.25057 .51236 L
.26568 .39209 L
.2808 .31348 L
.29592 .33035 L
.31104 .36493 L
.32615 .34562 L
.34127 .33647 L
.35639 .32036 L
.3715 .32074 L
.38662 .32792 L
.40174 .3729 L
.41686 .39604 L
.43197 .32682 L
.44709 .28521 L
.46221 .38122 L
.47732 .37276 L
.49244 .3626 L
.50756 .345 L
.52268 .41068 L
.53779 .28759 L
.55291 .33949 L
.56803 .27754 L
.58314 .31616 L
.59826 .28109 L
.61338 .40723 L
.6285 .32715 L
.64361 .30726 L
.65873 .32227 L
.67385 .16086 L
.68896 .32685 L
.70408 .31649 L
.7192 .38883 L
.73432 .3949 L
.74943 .37424 L
.76455 .32829 L
Mistroke
.77967 .34269 L
.79478 .35726 L
.8099 .34681 L
.82502 .33125 L
.84014 .34241 L
.85525 .60332 L
.87037 .29682 L
.88549 .28631 L
.9006 .34419 L
.91572 .34101 L
.93084 .35123 L
.94596 .3623 L
.96107 .3081 L
.97619 .33059 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.00700719 0.97619 0.287295 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.00691244 0.030722 0.360705 0.748591 [
[.1467 .34821 -3 -9 ]
[.1467 .34821 3 0 ]
[.30031 .34821 -6 -9 ]
[.30031 .34821 6 0 ]
[.45392 .34821 -6 -9 ]
[.45392 .34821 6 0 ]
[.60753 .34821 -6 -9 ]
[.60753 .34821 6 0 ]
[.76114 .34821 -6 -9 ]
[.76114 .34821 6 0 ]
[.91475 .34821 -6 -9 ]
[.91475 .34821 6 0 ]
[-0.01941 .06127 -24 -4.5 ]
[-0.01941 .06127 0 4.5 ]
[-0.01941 .21099 -24 -4.5 ]
[-0.01941 .21099 0 4.5 ]
[-0.01941 .51042 -18 -4.5 ]
[-0.01941 .51042 0 4.5 ]
[ -0.00691 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.1467 .36071 m
.1467 .36696 L
s
[(5)] .1467 .34821 0 1 Mshowa
.30031 .36071 m
.30031 .36696 L
s
[(10)] .30031 .34821 0 1 Mshowa
.45392 .36071 m
.45392 .36696 L
s
[(15)] .45392 .34821 0 1 Mshowa
.60753 .36071 m
.60753 .36696 L
s
[(20)] .60753 .34821 0 1 Mshowa
.76114 .36071 m
.76114 .36696 L
s
[(25)] .76114 .34821 0 1 Mshowa
.91475 .36071 m
.91475 .36696 L
s
[(30)] .91475 .34821 0 1 Mshowa
.125 Mabswid
.02381 .36071 m
.02381 .36446 L
s
.05453 .36071 m
.05453 .36446 L
s
.08525 .36071 m
.08525 .36446 L
s
.11598 .36071 m
.11598 .36446 L
s
.17742 .36071 m
.17742 .36446 L
s
.20814 .36071 m
.20814 .36446 L
s
.23886 .36071 m
.23886 .36446 L
s
.26959 .36071 m
.26959 .36446 L
s
.33103 .36071 m
.33103 .36446 L
s
.36175 .36071 m
.36175 .36446 L
s
.39247 .36071 m
.39247 .36446 L
s
.4232 .36071 m
.4232 .36446 L
s
.48464 .36071 m
.48464 .36446 L
s
.51536 .36071 m
.51536 .36446 L
s
.54608 .36071 m
.54608 .36446 L
s
.5768 .36071 m
.5768 .36446 L
s
.63825 .36071 m
.63825 .36446 L
s
.66897 .36071 m
.66897 .36446 L
s
.69969 .36071 m
.69969 .36446 L
s
.73041 .36071 m
.73041 .36446 L
s
.79186 .36071 m
.79186 .36446 L
s
.82258 .36071 m
.82258 .36446 L
s
.8533 .36071 m
.8533 .36446 L
s
.88402 .36071 m
.88402 .36446 L
s
.94547 .36071 m
.94547 .36446 L
s
.97619 .36071 m
.97619 .36446 L
s
.25 Mabswid
0 .36071 m
1 .36071 L
s
-0.00691 .06127 m
-0.00066 .06127 L
s
[(-0.4)] -0.01941 .06127 1 0 Mshowa
-0.00691 .21099 m
-0.00066 .21099 L
s
[(-0.2)] -0.01941 .21099 1 0 Mshowa
-0.00691 .51042 m
-0.00066 .51042 L
s
[(0.2)] -0.01941 .51042 1 0 Mshowa
.125 Mabswid
-0.00691 .0987 m
-0.00316 .0987 L
s
-0.00691 .13613 m
-0.00316 .13613 L
s
-0.00691 .17356 m
-0.00316 .17356 L
s
-0.00691 .24842 m
-0.00316 .24842 L
s
-0.00691 .28585 m
-0.00316 .28585 L
s
-0.00691 .32328 m
-0.00316 .32328 L
s
-0.00691 .39813 m
-0.00316 .39813 L
s
-0.00691 .43556 m
-0.00316 .43556 L
s
-0.00691 .47299 m
-0.00316 .47299 L
s
-0.00691 .02384 m
-0.00316 .02384 L
s
-0.00691 .54785 m
-0.00316 .54785 L
s
-0.00691 .58528 m
-0.00316 .58528 L
s
.25 Mabswid
-0.00691 0 m
-0.00691 .61803 L
s
.5 Mabswid
.02381 .27957 m
.05453 .32581 L
.08525 .42717 L
.11598 .01472 L
.1467 .35229 L
.17742 .40273 L
.20814 .35546 L
.23886 .49972 L
.26959 .37014 L
.30031 .39745 L
.33103 .34697 L
.36175 .4092 L
.39247 .3398 L
.4232 .27572 L
.45392 .36199 L
.48464 .4585 L
.51536 .3597 L
.54608 .36684 L
.5768 .30078 L
.60753 .39791 L
.63825 .41735 L
.66897 .16095 L
.69969 .3879 L
.73041 .31723 L
.76114 .36312 L
.79186 .34133 L
.82258 .35094 L
.8533 .60332 L
.88402 .35269 L
.91475 .34053 L
.94547 .42053 L
.97619 .37089 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{287.875, 84.6875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004O0000E1000`40O003h00Oogoo87oo003oOolP
Ool00?moob1oo`00ogoo87oo003oOolPOol00?moob1oo`00ogoo87oo003oOolPOol00?moob1oo`00
8Goo00<007ooOol0ngoo000QOol00`00Oomoo`2;Ool00`00Oomoo`1]Ool0025oo`03001oogoo00Uo
o`03001oogoo07moo`03001oogoo00Uoo`03001oogoo065oo`008Goo00<007ooOol02Goo00<007oo
Ool0Ogoo00<007ooOol02Goo00<007ooOol0HGoo000QOol00`00Oomoo`09Ool00`00Oomoo`1oOol0
0`00Oomoo`09Ool00`00Oomoo`1QOol001=oo`03001oogoo009oo`04001oogooOol20003Ool00`00
Oomoo`09Ool00`00Oomoo`1`Ool00`00Oomoo`02Ool00`00Oomoo`02Ool30002Ool00`00Oomoo`09
Ool00`00Oomoo`1QOol0019oo`03001oo`0000Uoo`04001oogoo000;Ool00`00Oomoo`1_Ool00`00
Ool00009Ool01@00Oomoogoo00002goo00<007ooOol0HGoo000=Ool30002Ool00`00Ool00008Ool0
1@00Oomoogoo00002goo00<007ooOol0JWoo0`000Woo00<007oo00001goo10000Woo00<007ooOol0
2Goo00<007ooOol0HGoo000BOol00`00Ool00009Ool01000Oomoo`002goo00<007ooOol0Kgoo00<0
07oo00001goo00<007oo00000goo00<007ooOol02Goo0P00HWoo000BOol00`00Ool00007Ool00`00
Ool00002Ool00`00Oomoo`09Ool00`00Oomoo`1_Ool00`00Ool00008Ool20003Ool00`00Oomoo`09
Ool2001ROol001=oo`03001oogoo00Moo`05001oogooOol0000;Ool00`00Oomoo`1`Ool00`00Oomo
o`08Ool01@00Oomoogoo00002Woo00<007oo0000HWoo000QOol00`00Oomoo`09Ool20020Ool00`00
Oomoo`08Ool00`00Ool0001ROol0025oo`03001oogoo00Uoo`80081oo`03001oogoo00Qoo`03001o
o`00069oo`008Goo00<007ooOol02Goo0P00P7oo00<007ooOol027oo00<007oo0000HWoo000QOol0
0`00Oomoo`09Ool20020Ool00`00Oomoo`08Ool00`00Ool0001ROol001=oo`03001oogoo009oo`04
001oogooOol30002Ool00`00Oomoo`09Ool20020Ool00`00Oomoo`08Ool00`00Ool0001ROol0019o
o`03001oo`0000Moo`03001oogoo009oo`03001oogoo00Uoo`80081oo`03001oogoo00Qoo`03001o
o`00069oo`003Goo0`000Woo00<007oo000027oo00D007ooOomoo`0000]oo`8003Moo`03001oogoo
04Ioo`03001oogoo00Qoo`03001oo`0003Moo`03001oogoo02Qoo`004Woo00<007oo000027oo00D0
07ooOomoo`0000]oo`8003Moo`03001oogoo04Ioo`03001oogoo00Qoo`03001oo`0003Moo`03001o
ogoo02Qoo`004Woo00<007oo00001goo00<007oo00000Woo00<007ooOol02Goo0P00=goo00<007oo
Ool0AWoo00<007ooOol027oo00<007oo0000=goo00<007ooOol0:7oo000COol00`00Oomoo`07Ool0
1@00Oomoogoo00002goo0P00=goo00<007ooOol0AWoo00<007ooOol027oo00@007ooOol003Ioo`03
001oogoo02Qoo`008Goo00<007ooOol027oo00<007oo0000=goo00<007ooOol0=goo00<007ooOol0
0Woo00@007ooOomoo`<000=oo`03001oogoo00Qoo`04001oogoo000fOol00`00Oomoo`0XOol0025o
o`03001oogoo00Qoo`03001oo`0003Moo`8003Moo`03001oo`0000Moo`03001oogoo00=oo`03001o
ogoo00Qoo`04001oogoo000eOol00`00Ool0000YOol0025oo`03001oogoo00Qoo`03001oo`0003Mo
o`80039oo`<0009oo`03001oo`0000Qoo`03001oogoo009oo`03001oogoo00Qoo`04001oogoo000e
Ool00`00Ool0000YOol0025oo`03001oogoo00Qoo`03001oo`0003Moo`8003Moo`03001oo`0000Qo
o`03001oogoo009oo`03001oogoo00Moo`05001oogooOol0000eOol00`00Ool0000YOol001=oo`03
001oogoo009oo`03001oogoo00D00003Ool007oo00Uoo`03001oo`0003Moo`8003Moo`03001oo`00
00Moo`03001oo`0000=oo`03001oogoo00Moo`05001oogooOol0000eOol00`00Ool0000YOol0019o
o`03001oo`0000Qoo`05001oogooOol0000:Ool00`00Ool0000fOol00`00Ool0000hOol00`00Oomo
o`07Ool00`00Oomoo`02Ool00`00Oomoo`07Ool01@00Oomoogoo0000=Goo00<007oo0000:Goo000=
Ool30002Ool00`00Ool00008Ool01@00Oomoogoo00002Woo00@007ooOol003Eoo`03001oo`0004Mo
o`03001oogoo00Moo`05001oogooOol0000eOol00`00Ool0000YOol0019oo`03001oo`0000Qoo`05
001oogooOol0000:Ool50002Ool00`00Oomoo`06Ool30003Ool00`00Oomoo`07Ool20004Ool00`00
Oomoo`08Ool30002Ool01P00Oomoo`00Ool000Eoo`03001oogoo009oo`03001oogoo00Moo`8000Ao
o`03001oogoo02Yoo`03001oogoo00Moo`05001oogooOol0000eOol00`00Ool0000YOol0019oo`03
001oo`0000Qoo`05001oogooOol0000:Ool01000Ool000000Woo00<007oo00001goo00<007ooOol0
0Woo00<007oo00002Woo00H007ooOol007oo0007Ool01000Oomoo`000Woo00L007oo001oo`00Ool0
0004Ool00`00Ool00002Ool00`00Ool00008Ool00`00Ool00002Ool00`00Ool0000[Ool00`00Oomo
o`07Ool01000Oomoogoo0P002Woo1@000Woo00<007ooOol01Woo1@000Woo00<007ooOol01goo0`00
0goo00H007ooOol007oo0004Ool30003Ool00`00Oomoo`07Ool20004Ool00`00Oomoo`0<Ool001=o
o`03001oogoo00Ioo`8000=oo`03001oogoo00Qoo`04001oo`000002Ool00`00Ool00008Ool01`00
Oomoogoo001oo`0000Uoo`07001oo`00Ool007oo000017oo00<007ooOol01@0000Qoo`00Ool007oo
001oo`001Woo00H007ooOol007oo0008Ool00`00Ool00002Ool00`00Ool0000[Ool01000Oomoo`00
1Woo00L007ooOomoo`00Ool0000;Ool01`00Oomoogoo001oo`0000Uoo`07001oogooOol007oo0000
27oo00<007ooOol00Woo00D007oo001oo`00009oo`05001oogooOol00004Ool00`00Ool0000:Ool0
1P00Oomoo`00Ool000eoo`008Goo00<007ooOol027oo00@007oo0000009oo`03001oo`0000Qoo`07
001oogooOol007oo00002Woo0P0000Aoo`00Ool000Aoo`03001oogoo00800009Ool007ooOol007oo
001oo`00009oo`04001oogooOol20003Ool00`00Ool00007Ool30003Ool00`00Ool0000[Ool01@00
Oomoogoo00001Goo00L007ooOomoo`00Ool0000;Ool01`00Oomoogoo001oo`0000Qoo`<000Aoo`03
001oogoo00Moo`06001oogooOol007oo0P000goo00<007ooOol00Woo00<007ooOol00goo00<007oo
Ool01goo00L007ooOomoo`00Ool0000=Ool0025oo`03001oogoo00Qoo`04001oo`000002Ool00`00
Ool00007Ool00`00Ool00002Ool00`00Ool00008Ool02000Ool00000Ool007oo0004Ool200000goo
000000020002Ool01@00Ool007oo00000Woo00D007ooOomoo`0000Aoo`03001oo`0000Moo`<000=o
o`03001oo`0002]oo`05001oogooOol00005Ool01000Oomoogoo0P0037oo00L007ooOomoo`00Ool0
0008Ool30002Ool2000:Ool01P00Oomoogoo001oo`8000=oo`03001oogoo009oo`04001oogooOol2
000;Ool01P00Oomoo`00Ool000eoo`008Goo0`0027oo10000goo00<007ooOol00goo00D007ooOomo
o`0000Aoo`03001oogoo00Qoo`<0009oo`03001oogoo00=oo`<0009oo`8000=oo`@0009oo`04001o
o`00Ool30003Ool00`00Oomoo`06Ool01000Ool000000goo00<007oo0000:Woo00<007ooOol00Woo
00<007ooOol00Woo00@007ooOomoo`8000aoo`07001oogooOol007oo00001goo00@007oo0000009o
o`03001oogoo00Qoo`<0009oo`04001oo`000003Ool01`00Oomoogoo001oo`00009oo`03001oogoo
00Qoo`03001oo`00009oo`03001oo`0000eoo`008Goo00@007ooOol000Aoo`04001oogoo0002Ool0
0`00Oomoo`07Ool01000Oomoogoo0P001Woo0`001Goo00<007oo000027oo0`0017oo00L007ooOomo
o`00Ool00002Ool3000@Ool00`00Ool00006Ool2000YOol00`00Oomoo`03Ool01@00Oomoogoo0000
0goo0`002Woo0P0017oo00<007ooOol01Woo0`0000=oo`00Ool00`0027oo0`000goo00<007oo0000
0goo00<007ooOol00Woo00@007ooOomoo`<000Uoo`03001oogoo009oo`03001oogoo00aoo`008Goo
00@007ooOol000Aoo`04001oogoo0002Ool30007Ool01`00Oomoogoo001oo`0000Eoo`04001oogoo
0004Ool00`00Ool00008Ool00`00Ool00004Ool01000Oomoo`001Goo00<007oo00001Goo00<007oo
Ool00goo0P000goo00@007ooOol000Eoo`03001oo`0002Qoo`03001oogoo00=oo`05001oogooOol0
0004Ool00`00Oomoo`0GOol00`00Oomoo`02Ool00`00Oomoo`0:Ool00`00Ool00005Ool01@00Oomo
ogoo00000goo00<007oo00008Woo000QOol01@00Oomoogoo00000Woo0P000Woo00<007ooOol00Woo
00<007ooOol017oo0P000goo00<007oo00000goo0P000goo00<007ooOol00Woo00@007ooOol000Ao
o`06001oogoo001oo`0017oo00@007ooOol000Moo`03001oogoo00=oo`8000Aoo`03001oo`00009o
o`03001oogoo00<0009oo`03001oogoo02Uoo`03001oogoo00Aoo`04001oogoo0004Ool00`00Oomo
o`0GOol00`00Oomoo`02Ool00`00Oomoo`09Ool01000Oomoo`001Goo00D007ooOomoo`0000=oo`03
001oo`0000Aoo`8000Uoo`<0011oo`0087ooJ@009Woo00<007ooOol017oo00@007ooOol000Aoo`03
001oogoo00Aoo`03001oogoo00Uoo`03001oogoo00Aoo`03001oogoo00=oo`03001oogoo00Qoo`04
001oogoo0005Ool01@00Oomoogoo00000Woo00H007ooOomoo`00Ool20002Ool20005Ool20002Ool0
0`00Oomoo`0>Ool0025oo`07001oogooOol007oo00000Woo00<007oo000017oo0P001Goo0P000Woo
00@007ooOomoo`8000Moo`04001oogoo0003Ool01000Oomoo`000Woo0P001goo0`002Goo00@007oo
Oomoo`80009oo`03001oogoo009oo`04001oogoo0004Ool01000Oomoo`00:gooJ00027oo000QOol0
0`00Oomoo`02Ool20002Ool20006Ool00`00Oomoo`03Ool20002Ool01@00Oomoogoo00002Goo00<0
07oo00000goo0`000goo0P001goo00<007oo00002Goo00@007ooOol000Uoo`04001oogoo000cOol0
0`00Oomoo`04Ool00`00Ool00005Ool00`00Ool00003Ool20005Ool02000Oomoo`00Ool007oo0004
Ool00`00Oomoo`04Ool00`00Oomoo`03Ool00`00Oomoo`020004Ool20003Ool00`00Oomoo`02Ool2
0005Ool00`00Oomoo`03Ool00`00Oomoo`03Ool01000Oomoogoo0P0017oo00<007ooOol027oo000Q
Ool00`00Oomoo`02Ool01@00Oomoogoo00001goo00<007ooOol00Woo00<007oo00000Woo00<007oo
Ool02goo00<007oo00000goo00<007ooOol00goo0P0027oo0P002Goo00@007ooOol000Uoo`03001o
o`0003Aoo`03001oogoo00Eoo`8000Moo`04001oogoo0002Ool00`00Oomoo`02Ool20002Ool01@00
Oomoogoo00000Woo00<007ooOol01Woo00D007ooOomoo`0000Uoo`05001oogooOol00005Ool2000;
Ool00`00Oomoo`03Ool00`00Oomoo`02Ool01@00Oomoogoo00002goo000QOol00`00Oomoo`0>Ool0
0`00Oomoo`02Ool00`00Ool00002Ool00`00Oomoo`0<Ool00`00Oomoo`08Ool20008Ool20009Ool2
00000goo001oo`08Ool00`00Ool0000dOol00`00Oomoo`05Ool20008Ool00`00Ool00002Ool00`00
Oomoo`02Ool01@00Ool007oo000017oo00<007oo000027oo00D007ooOomoo`0000Yoo`04001oogoo
0005Ool00`00Oomoo`0:Ool00`00Oomoo`03Ool00`00Oomoo`03Ool01000Oomoo`002goo000QOol0
0`00Oomoo`0?Ool00`00Oomoo`0200001Goo001oogoo00003Woo00<007ooOol02Goo00<007ooOol0
1Woo00<007ooOol02Woo00<007ooOol027oo00<007oo0000=7oo00<007ooOol01Goo0P002Goo00D0
07ooOomoo`0000=oo`05001oogooOol00005Ool20009Ool01@00Oomoogoo00002Woo00@007ooOol0
01=oo`05001oogooOol00006Ool00`00Ool0000<Ool0025oo`03001oogoo00moo`03001oo`0000=o
o`04001oogoo000JOol00`00Oomoo`06Ool00`00Oomoo`0EOol00`00Ool0000dOol00`00Oomoo`05
Ool2000=Ool01@00Oomoogoo00002Woo00<007ooOol01goo00D007ooOomoo`0000]oo`<001=oo`05
001oogooOol00007Ool2000<Ool0025oo`03001oogoo011oo`03001oogoo00=oo`03001oo`0003]o
o`03001oo`0003Aoo`03001oogoo00Ioo`03001oogoo00]oo`05001oogooOol0000EOol00`00Ool0
000>Ool00`00Oomoo`0AOol01@00Oomoogoo00001goo00<007ooOol02goo000COol00`00Oomoo`02
Ool00`00Oomoo`0500000goo001oo`0GOol2000lOol00`00Ool0000dOol00`00Oomoo`06Ool00`00
Oomoo`0<Ool01000Oomoo`005Goo00<007oo00008Woo00D007ooOomoo`0001Eoo`004Woo00<007oo
000027oo00D007ooOomoo`0001Qoo`8003aoo`03001oo`0003Aoo`03001oogoo01Eoo`03001oo`00
01Ioo`03001oo`00029oo`05001oogooOol0000EOol0019oo`03001oo`0000Qoo`05001oogooOol0
000HOol2000lOol00`00Ool0000dOol00`00Oomoo`0EOol00`00Ool0000GOol00`00Oomoo`0QOol0
1@00Oomoogoo00005Goo000BOol00`00Ool00008Ool01@00Oomoogoo000067oo0P00?7oo00<007oo
0000=7oo00<007ooOol05Goo00<007oo00005goo00<007ooOol08Goo00D007ooOomoo`0001Eoo`00
4Woo00<007oo000027oo00D007ooOomoo`0001Qoo`8003aoo`03001oo`0003Aoo`03001oogoo01Eo
o`03001oo`0003]oo`05001oogooOol0000EOol001=oo`03001oogoo00Ioo`8000=oo`03001oogoo
01Ioo`8003eoo`8003Aoo`03001oogoo01Ioo`03001oogoo03Yoo`05001oogooOol0000EOol0025o
o`03001oogoo01Ioo`03001oogoo03aoo`8002Eoo`03001oogoo009oo`04001oogooOol30003Ool0
0`00Oomoo`0FOol00`00Oomoo`0kOol00`00Ool0000FOol0025oo`03001oogoo01Ioo`03001oogoo
03aoo`8002Aoo`03001oo`0000Moo`03001oogoo00=oo`03001oogoo01Ioo`03001oogoo03]oo`03
001oo`0001Ioo`008Goo00<007ooOol05Woo00<007ooOol0?7oo0P0097oo00<007oo000027oo00<0
07ooOol00Woo00<007ooOol0E7oo00<007oo00005Woo000QOol00`00Oomoo`0FOol00`00Oomoo`0l
Ool2000TOol00`00Ool00008Ool00`00Oomoo`02Ool00`00Oomoo`1DOol00`00Ool0000FOol001=o
o`03001oogoo009oo`04001oogooOol30002Ool00`00Oomoo`1EOol2000TOol00`00Ool00007Ool0
0`00Ool00003Ool00`00Oomoo`1DOol00`00Ool0000FOol0019oo`03001oo`0000Moo`03001oogoo
009oo`03001oogoo05Eoo`03001oogoo02Aoo`03001oogoo00Moo`03001oogoo009oo`03001oogoo
05Aoo`03001oo`0001Ioo`004Woo00<007oo000027oo00D007ooOomoo`0005Moo`03001oogoo03=o
o`03001oogoo05Aoo`03001oo`0001Ioo`004Woo00<007oo000027oo00D007ooOomoo`0005Moo`03
001oogoo03=oo`03001oogoo05Aoo`03001oo`0001Ioo`004Woo00<007oo00001goo00<007oo0000
0Woo00<007ooOol0EGoo00<007ooOol0<goo00<007ooOol0EGoo00<007ooOol05Goo000COol00`00
Oomoo`07Ool01@00Oomoogoo0000Egoo00<007ooOol0<goo00<007ooOol0EGoo00<007ooOol05Goo
000QOol00`00Oomoo`1EOol00`00Oomoo`0cOol00`00Oomoo`1EOol00`00Oomoo`0EOol0025oo`03
001oogoo05Eoo`03001oogoo03=oo`03001oogoo05Eoo`03001oogoo01Eoo`008Goo00<007ooOol0
EGoo00<007ooOol0<goo00<007ooOol0EGoo00<007ooOol05Goo000QOol00`00Oomoo`2;Ool00`00
Oomoo`1]Ool0025oo`03001oogoo0?]oo`00ogoo87oo003oOolPOol00?moob1oo`00ogoo87oo003o
OolPOol00?moob1oo`00ogoo87oo003oOolPOol00?moob1oo`00\
\>"],
  ImageRangeCache->{{{0, 286.875}, {83.6875, 0}} -> {-0.0592822, -0.0147151, 
  0.00738498, 0.00738498}, {{8, 136.938}, {81.6875, 
  1.9375}} -> {-21.0764, -0.467754, 0.632782, 0.0101432}, {{149.875, 
  278.813}, {81.6875, 1.9375}} -> {-55.3876, -0.612466, 0.316208, 0.0129771}}]
}, Open  ]],

Cell[TextData[{
  "A single level decomposition returns two vectors, the lowpass filter \
output ",
  Cell[BoxData[
      \(TraditionalForm\`c\^6\)]],
  " and the highpass filter output ",
  Cell[BoxData[
      \(TraditionalForm\`d\^6\)]],
  ". "
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[
      GraphicsArray[
        \(ListPlot[#1, \n\t\t\t\tPlotJoined \[Rule] True, 
              PlotRange \[Rule] All, DisplayFunction \[Rule] Identity]&\)\ /@
          \ \ DWT[x, \ D\_4, \ 1]]]; \)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .2943 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.00700719 0.47619 [
[ 0 0 0 0 ]
[ 1 .2943 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .2943 L
0 .2943 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.00700719 0.477324 0.287295 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00869237 0.0151172 0.0431248 0.386918 [
[.15986 .03062 -6 -9 ]
[.15986 .03062 6 0 ]
[.31104 .03062 -6 -9 ]
[.31104 .03062 6 0 ]
[.46221 .03062 -6 -9 ]
[.46221 .03062 6 0 ]
[.61338 .03062 -6 -9 ]
[.61338 .03062 6 0 ]
[.76455 .03062 -6 -9 ]
[.76455 .03062 6 0 ]
[.91572 .03062 -6 -9 ]
[.91572 .03062 6 0 ]
[-0.00381 .12051 -18 -4.5 ]
[-0.00381 .12051 0 4.5 ]
[-0.00381 .19789 -18 -4.5 ]
[-0.00381 .19789 0 4.5 ]
[-0.00381 .27528 -18 -4.5 ]
[-0.00381 .27528 0 4.5 ]
[-0.00381 .35266 -18 -4.5 ]
[-0.00381 .35266 0 4.5 ]
[-0.00381 .43004 -6 -4.5 ]
[-0.00381 .43004 0 4.5 ]
[-0.00381 .50743 -18 -4.5 ]
[-0.00381 .50743 0 4.5 ]
[-0.00381 .58481 -18 -4.5 ]
[-0.00381 .58481 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.15986 .04312 m
.15986 .04937 L
s
[(10)] .15986 .03062 0 1 Mshowa
.31104 .04312 m
.31104 .04937 L
s
[(20)] .31104 .03062 0 1 Mshowa
.46221 .04312 m
.46221 .04937 L
s
[(30)] .46221 .03062 0 1 Mshowa
.61338 .04312 m
.61338 .04937 L
s
[(40)] .61338 .03062 0 1 Mshowa
.76455 .04312 m
.76455 .04937 L
s
[(50)] .76455 .03062 0 1 Mshowa
.91572 .04312 m
.91572 .04937 L
s
[(60)] .91572 .03062 0 1 Mshowa
.125 Mabswid
.03893 .04312 m
.03893 .04687 L
s
.06916 .04312 m
.06916 .04687 L
s
.0994 .04312 m
.0994 .04687 L
s
.12963 .04312 m
.12963 .04687 L
s
.1901 .04312 m
.1901 .04687 L
s
.22033 .04312 m
.22033 .04687 L
s
.25057 .04312 m
.25057 .04687 L
s
.2808 .04312 m
.2808 .04687 L
s
.34127 .04312 m
.34127 .04687 L
s
.3715 .04312 m
.3715 .04687 L
s
.40174 .04312 m
.40174 .04687 L
s
.43197 .04312 m
.43197 .04687 L
s
.49244 .04312 m
.49244 .04687 L
s
.52268 .04312 m
.52268 .04687 L
s
.55291 .04312 m
.55291 .04687 L
s
.58314 .04312 m
.58314 .04687 L
s
.64361 .04312 m
.64361 .04687 L
s
.67385 .04312 m
.67385 .04687 L
s
.70408 .04312 m
.70408 .04687 L
s
.73432 .04312 m
.73432 .04687 L
s
.79478 .04312 m
.79478 .04687 L
s
.82502 .04312 m
.82502 .04687 L
s
.85525 .04312 m
.85525 .04687 L
s
.88549 .04312 m
.88549 .04687 L
s
.94596 .04312 m
.94596 .04687 L
s
.97619 .04312 m
.97619 .04687 L
s
.25 Mabswid
0 .04312 m
1 .04312 L
s
.00869 .12051 m
.01494 .12051 L
s
[(0.2)] -0.00381 .12051 1 0 Mshowa
.00869 .19789 m
.01494 .19789 L
s
[(0.4)] -0.00381 .19789 1 0 Mshowa
.00869 .27528 m
.01494 .27528 L
s
[(0.6)] -0.00381 .27528 1 0 Mshowa
.00869 .35266 m
.01494 .35266 L
s
[(0.8)] -0.00381 .35266 1 0 Mshowa
.00869 .43004 m
.01494 .43004 L
s
[(1)] -0.00381 .43004 1 0 Mshowa
.00869 .50743 m
.01494 .50743 L
s
[(1.2)] -0.00381 .50743 1 0 Mshowa
.00869 .58481 m
.01494 .58481 L
s
[(1.4)] -0.00381 .58481 1 0 Mshowa
.125 Mabswid
.00869 .06247 m
.01244 .06247 L
s
.00869 .08182 m
.01244 .08182 L
s
.00869 .10116 m
.01244 .10116 L
s
.00869 .13985 m
.01244 .13985 L
s
.00869 .1592 m
.01244 .1592 L
s
.00869 .17855 m
.01244 .17855 L
s
.00869 .21724 m
.01244 .21724 L
s
.00869 .23658 m
.01244 .23658 L
s
.00869 .25593 m
.01244 .25593 L
s
.00869 .29462 m
.01244 .29462 L
s
.00869 .31397 m
.01244 .31397 L
s
.00869 .33331 m
.01244 .33331 L
s
.00869 .37201 m
.01244 .37201 L
s
.00869 .39135 m
.01244 .39135 L
s
.00869 .4107 m
.01244 .4107 L
s
.00869 .44939 m
.01244 .44939 L
s
.00869 .46873 m
.01244 .46873 L
s
.00869 .48808 m
.01244 .48808 L
s
.00869 .52677 m
.01244 .52677 L
s
.00869 .54612 m
.01244 .54612 L
s
.00869 .56546 m
.01244 .56546 L
s
.00869 .02378 m
.01244 .02378 L
s
.00869 .00443 m
.01244 .00443 L
s
.00869 .60416 m
.01244 .60416 L
s
.25 Mabswid
.00869 0 m
.00869 .61803 L
s
.5 Mabswid
.02381 .0283 m
.03893 .02259 L
.05404 .07134 L
.06916 .01866 L
.08428 .06127 L
.0994 .04101 L
.11451 .02251 L
.12963 .07466 L
.14475 .56554 L
.15986 .56858 L
.17498 .59336 L
.1901 .60332 L
.20522 .56715 L
.22033 .58831 L
.23545 .58748 L
.25057 .58694 L
.26568 .33128 L
.2808 .29275 L
.29592 .31636 L
.31104 .33341 L
.32615 .30009 L
.34127 .3196 L
.35639 .33808 L
.3715 .34213 L
.38662 .31269 L
.40174 .34413 L
.41686 .32303 L
.43197 .29364 L
.44709 .35702 L
.46221 .30459 L
.47732 .30883 L
.49244 .29926 L
.50756 .18115 L
.52268 .19677 L
.53779 .1803 L
.55291 .17136 L
.56803 .17682 L
.58314 .18499 L
.59826 .20605 L
.61338 .15952 L
.6285 .17875 L
.64361 .22019 L
.65873 .17364 L
.67385 .21127 L
.68896 .48704 L
.70408 .48523 L
.7192 .44562 L
.73432 .44524 L
.74943 .46924 L
.76455 .44018 L
Mistroke
.77967 .44311 L
.79478 .44006 L
.8099 .45729 L
.82502 .44834 L
.84014 .45606 L
.85525 .44886 L
.87037 .0607 L
.88549 .03425 L
.9006 .04807 L
.91572 .04252 L
.93084 .03986 L
.94596 .01482 L
.96107 .01472 L
.97619 .07195 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.00700719 0.97619 0.287295 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00869237 0.0151172 0.349575 0.943084 [
[.15986 .33708 -6 -9 ]
[.15986 .33708 6 0 ]
[.31104 .33708 -6 -9 ]
[.31104 .33708 6 0 ]
[.46221 .33708 -6 -9 ]
[.46221 .33708 6 0 ]
[.61338 .33708 -6 -9 ]
[.61338 .33708 6 0 ]
[.76455 .33708 -6 -9 ]
[.76455 .33708 6 0 ]
[.91572 .33708 -6 -9 ]
[.91572 .33708 6 0 ]
[-0.00381 .06665 -24 -4.5 ]
[-0.00381 .06665 0 4.5 ]
[-0.00381 .16096 -24 -4.5 ]
[-0.00381 .16096 0 4.5 ]
[-0.00381 .25527 -24 -4.5 ]
[-0.00381 .25527 0 4.5 ]
[-0.00381 .44388 -18 -4.5 ]
[-0.00381 .44388 0 4.5 ]
[-0.00381 .53819 -18 -4.5 ]
[-0.00381 .53819 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.15986 .34958 m
.15986 .35583 L
s
[(10)] .15986 .33708 0 1 Mshowa
.31104 .34958 m
.31104 .35583 L
s
[(20)] .31104 .33708 0 1 Mshowa
.46221 .34958 m
.46221 .35583 L
s
[(30)] .46221 .33708 0 1 Mshowa
.61338 .34958 m
.61338 .35583 L
s
[(40)] .61338 .33708 0 1 Mshowa
.76455 .34958 m
.76455 .35583 L
s
[(50)] .76455 .33708 0 1 Mshowa
.91572 .34958 m
.91572 .35583 L
s
[(60)] .91572 .33708 0 1 Mshowa
.125 Mabswid
.03893 .34958 m
.03893 .35333 L
s
.06916 .34958 m
.06916 .35333 L
s
.0994 .34958 m
.0994 .35333 L
s
.12963 .34958 m
.12963 .35333 L
s
.1901 .34958 m
.1901 .35333 L
s
.22033 .34958 m
.22033 .35333 L
s
.25057 .34958 m
.25057 .35333 L
s
.2808 .34958 m
.2808 .35333 L
s
.34127 .34958 m
.34127 .35333 L
s
.3715 .34958 m
.3715 .35333 L
s
.40174 .34958 m
.40174 .35333 L
s
.43197 .34958 m
.43197 .35333 L
s
.49244 .34958 m
.49244 .35333 L
s
.52268 .34958 m
.52268 .35333 L
s
.55291 .34958 m
.55291 .35333 L
s
.58314 .34958 m
.58314 .35333 L
s
.64361 .34958 m
.64361 .35333 L
s
.67385 .34958 m
.67385 .35333 L
s
.70408 .34958 m
.70408 .35333 L
s
.73432 .34958 m
.73432 .35333 L
s
.79478 .34958 m
.79478 .35333 L
s
.82502 .34958 m
.82502 .35333 L
s
.85525 .34958 m
.85525 .35333 L
s
.88549 .34958 m
.88549 .35333 L
s
.94596 .34958 m
.94596 .35333 L
s
.97619 .34958 m
.97619 .35333 L
s
.25 Mabswid
0 .34958 m
1 .34958 L
s
.00869 .06665 m
.01494 .06665 L
s
[(-0.3)] -0.00381 .06665 1 0 Mshowa
.00869 .16096 m
.01494 .16096 L
s
[(-0.2)] -0.00381 .16096 1 0 Mshowa
.00869 .25527 m
.01494 .25527 L
s
[(-0.1)] -0.00381 .25527 1 0 Mshowa
.00869 .44388 m
.01494 .44388 L
s
[(0.1)] -0.00381 .44388 1 0 Mshowa
.00869 .53819 m
.01494 .53819 L
s
[(0.2)] -0.00381 .53819 1 0 Mshowa
.125 Mabswid
.00869 .08551 m
.01244 .08551 L
s
.00869 .10437 m
.01244 .10437 L
s
.00869 .12323 m
.01244 .12323 L
s
.00869 .1421 m
.01244 .1421 L
s
.00869 .17982 m
.01244 .17982 L
s
.00869 .19868 m
.01244 .19868 L
s
.00869 .21754 m
.01244 .21754 L
s
.00869 .23641 m
.01244 .23641 L
s
.00869 .27413 m
.01244 .27413 L
s
.00869 .29299 m
.01244 .29299 L
s
.00869 .31185 m
.01244 .31185 L
s
.00869 .33071 m
.01244 .33071 L
s
.00869 .36844 m
.01244 .36844 L
s
.00869 .3873 m
.01244 .3873 L
s
.00869 .40616 m
.01244 .40616 L
s
.00869 .42502 m
.01244 .42502 L
s
.00869 .46275 m
.01244 .46275 L
s
.00869 .48161 m
.01244 .48161 L
s
.00869 .50047 m
.01244 .50047 L
s
.00869 .51933 m
.01244 .51933 L
s
.00869 .04779 m
.01244 .04779 L
s
.00869 .02893 m
.01244 .02893 L
s
.00869 .01006 m
.01244 .01006 L
s
.00869 .55705 m
.01244 .55705 L
s
.00869 .57592 m
.01244 .57592 L
s
.00869 .59478 m
.01244 .59478 L
s
.00869 .61364 m
.01244 .61364 L
s
.25 Mabswid
.00869 0 m
.00869 .61803 L
s
.5 Mabswid
.02381 .31408 m
.03893 .31744 L
.05404 .37843 L
.06916 .36967 L
.08428 .32066 L
.0994 .38173 L
.11451 .3613 L
.12963 .01472 L
.14475 .3343 L
.15986 .32802 L
.17498 .37484 L
.1901 .41532 L
.20522 .41034 L
.22033 .39744 L
.23545 .31316 L
.25057 .51236 L
.26568 .39209 L
.2808 .31348 L
.29592 .33035 L
.31104 .36493 L
.32615 .34562 L
.34127 .33647 L
.35639 .32036 L
.3715 .32074 L
.38662 .32792 L
.40174 .3729 L
.41686 .39604 L
.43197 .32682 L
.44709 .28521 L
.46221 .38122 L
.47732 .37276 L
.49244 .3626 L
.50756 .345 L
.52268 .41068 L
.53779 .28759 L
.55291 .33949 L
.56803 .27754 L
.58314 .31616 L
.59826 .28109 L
.61338 .40723 L
.6285 .32715 L
.64361 .30726 L
.65873 .32227 L
.67385 .16086 L
.68896 .32685 L
.70408 .31649 L
.7192 .38883 L
.73432 .3949 L
.74943 .37424 L
.76455 .32829 L
Mistroke
.77967 .34269 L
.79478 .35726 L
.8099 .34681 L
.82502 .33125 L
.84014 .34241 L
.85525 .60332 L
.87037 .29682 L
.88549 .28631 L
.9006 .34419 L
.91572 .34101 L
.93084 .35123 L
.94596 .3623 L
.96107 .3081 L
.97619 .33059 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 84.75},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000E1000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol002Moo`D0009oo`03001oogoo00Moo`<000=oo`03001o
ogoo00Qoo`8000Aoo`03001oogoo00Uoo`<0009oo`03001oogoo00Qoo`03001oogoo009oo`03001o
ogoo00Qoo`8000Aoo`03001oogoo09aoo`00:Goo00L007ooOomoo`00Ool00008Ool00`00Oomoo`02
Ool00`00Ool0000;Ool01P00Oomoo`00Ool000]oo`06001oogoo001oo`0027oo00<007oo00000Woo
00<007oo00002Goo00<007oo00000Woo00<007oo0000WGoo000YOol01`00Oomoogoo001oo`0000Uo
o`07001oogooOol007oo00002Woo00L007ooOomoo`00Ool00009Ool4000017oo001oo`002Woo00H0
07ooOol007oo0009Ool00`00Ool00002Ool00`00Ool0002MOol002Uoo`07001oogooOol007oo0000
2Goo00L007ooOomoo`00Ool0000;Ool01P00Oomoo`00Ool000Uoo`03001oo`00009oo`03001oo`00
00Qoo`8000=oo`03001oo`0000Uoo`8000=oo`03001oo`0009eoo`00:Goo00L007ooOomoo`00Ool0
0008Ool00`00Ool00002Ool00`00Ool00009Ool00`00Ool00002Ool00`00Ool0000:Ool20002Ool0
0`00Ool00008Ool00`00Oomoo`02Ool00`00Ool00009Ool00`00Oomoo`02Ool00`00Ool0000/Ool0
0`00Oomoo`1^Ool001]oo`03001oogoo00Yoo`8000Aoo`03001oogoo00Qoo`03001oogoo009oo`03
001oogoo00Uoo`03001oogoo009oo`03001oogoo00Yoo`05001oogooOol00009Ool30003Ool00`00
Oomoo`09Ool20003Ool00`00Oomoo`0[Ool00`00Oomoo`1^Ool001]oo`03001oogoo06Eoo`8002Yo
o`03001oogoo00Uoo`03001oogoo069oo`006goo00@007oo000000=oo`03001oogoo009oo`03001o
ogoo05Qoo`03001oo`0002Yoo`03001oogoo00Uoo`03001oogoo069oo`006goo0P0000=oo`00Ool0
0Woo00@007ooOomoo`8005Yoo`04001oogoo000YOol00`00Oomoo`09Ool00`00Oomoo`1ROol001]o
o`06001oogooOol007oo0P000Woo00<007oo0000E7oo0P000Woo0P000goo00<007ooOol067oo00<0
07ooOol00Woo00@007ooOomoo`8000Aoo`03001oogoo00Uoo`03001oogoo069oo`006WooL0005Goo
00<007oo00002Goo00D007ooOomoo`0000]oo`03001oogoo069oo`006goo00P007ooOomoo`00Ool0
07oo0P000goo00<007ooOol0D7oo00<007ooOol01goo00<007ooOol04Woo0`000Woo00<007oo0000
27oo00<007ooOol00Woo00<007ooOol02Goo00<007ooOol0HWoo000KOol00`00Oomoo`02Ool01000
Oomoo`0017oo00<007ooOol0Cgoo00<007ooOol02Goo00<007ooOol05Woo00<007oo00002Goo00D0
07ooOomoo`0000]oo`03001oogoo069oo`006goo00<007ooOol00Woo00<007ooOol01Goo00<007oo
Ool0Cgoo00<007ooOol02Goo00<007ooOol05Woo00<007oo00001goo00<007oo00000goo00<007oo
Ool02Goo00<007ooOol0HWoo000KOol00`00Oomoo`0:Ool00`00Oomoo`1?Ool00`00Oomoo`0SOol0
0`00Oomoo`07Ool00`00Oomoo`02Ool00`00Oomoo`09Ool00`00Oomoo`1ROol001]oo`03001oogoo
00Yoo`03001oogoo04moo`03001oogoo039oo`03001oogoo00Uoo`8006=oo`0037oo00<007ooOol0
0Woo00@007ooOomoo`<000=oo`03001oogoo00Yoo`03001oogoo04moo`03001oogoo039oo`03001o
ogoo00Uoo`8006=oo`002goo00<007oo00001goo00<007ooOol00goo00<007ooOol02Woo00<007oo
Ool0Cgoo00<007ooOol0<Woo00<007ooOol02Goo0P00Hgoo000;Ool00`00Ool00008Ool00`00Oomo
o`02Ool2000;Ool00`00Oomoo`1?Ool00`00Oomoo`0bOol00`00Oomoo`09Ool2001SOol000]oo`03
001oo`0000Qoo`03001oogoo009oo`03001oogoo00Yoo`03001oogoo04moo`03001oogoo02=oo`03
001oogoo009oo`04001oogooOol30003Ool00`00Oomoo`09Ool2001SOol000]oo`03001oo`0000Mo
o`03001oo`0000=oo`03001oogoo00Yoo`03001oogoo04moo`03001oogoo029oo`03001oo`0000Mo
o`03001oogoo00=oo`03001oogoo00Uoo`8006=oo`0037oo00<007ooOol01goo00<007ooOol00Woo
00<007ooOol02Woo00<007ooOol0Cgoo00<007ooOol07Goo0`000Woo00<007oo000027oo00<007oo
Ool00Woo00<007ooOol02Goo0P00=goo00<007ooOol0:Goo000KOol00`00Oomoo`0:Ool00`00Oomo
o`1?Ool00`00Oomoo`0ROol00`00Ool00008Ool00`00Oomoo`02Ool00`00Oomoo`09Ool2000gOol0
0`00Oomoo`0YOol001]oo`03001oogoo00Yoo`03001oogoo03=oo`03001oogoo01Qoo`03001oogoo
02=oo`03001oo`0000Moo`03001oo`0000=oo`03001oogoo00Uoo`8003Moo`03001oogoo02Uoo`00
6goo00<007ooOol02Woo00<007ooOol0:goo100017oo00<007ooOol00Woo00<007ooOol04goo00<0
07ooOol097oo00<007ooOol01goo00<007ooOol00Woo00<007ooOol02Goo0P00=goo00<007ooOol0
:Goo000<Ool00`00Oomoo`02Ool00`00Oomoo`02Ool30002Ool00`00Oomoo`0:Ool00`00Oomoo`0W
Ool01000Oomoo`0017oo00H007ooOol007oo0003Ool00`00Oomoo`0COol00`00Oomoo`0cOol00`00
Oomoo`08Ool00`00Ool0000gOol00`00Oomoo`0YOol000]oo`03001oo`0000Uoo`05001oogooOol0
000<Ool00`00Oomoo`0WOol200000goo001oo`04Ool01@00Ool007oo00000Woo0P005Goo00<007oo
Ool0<goo00<007ooOol027oo00<007oo0000=goo0P00:Woo000;Ool00`00Ool00007Ool40002Ool2
000<Ool00`00Oomoo`0VOol00`00Ool00006Ool20003Ool01@00Ool007oo000057oo00<007ooOol0
<goo00<007ooOol027oo00<007oo0000=goo0P00:Woo000;Ool00`00Ool00007Ool00`00Ool00003
Ool00`00Oomoo`0;Ool00`00Oomoo`0VOol00`00Oomoo`07Ool01000Oomoogoo0P000Woo00<007oo
Ool04Woo00<007ooOol0<goo00<007ooOol027oo00<007oo0000=goo0P00:Woo000;Ool00`00Ool0
0008Ool20003Ool00`00Oomoo`0;Ool00`00Oomoo`0UOol00`00Oomoo`0=Ool01000Oomoo`0057oo
00<007ooOol097oo00<007ooOol00Woo00<007ooOol01@000Woo00<007ooOol027oo00<007oo0000
=goo0P00:Woo000<Ool00`00Oomoo`08Ool01@00Oomoogoo00003Goo00<007ooOol09Goo00<007oo
Ool047oo00<007ooOol04Woo00<007ooOol08goo00<007oo000027oo00<007ooOol00Woo00<007oo
Ool027oo00<007oo0000=Woo00<007oo0000:Woo000KOol00`00Oomoo`0;Ool00`00Oomoo`0UOol0
0`00Oomoo`0@Ool00`00Oomoo`0BOol00`00Oomoo`0NOol30002Ool00`00Ool00008Ool00`00Oomo
o`02Ool00`00Oomoo`08Ool01000Oomoo`00=Goo00<007oo0000:Woo000KOol00`00Oomoo`0;Ool0
0`00Oomoo`0UOol00`00Oomoo`0@Ool00`00Oomoo`0BOol00`00Oomoo`0SOol00`00Ool00008Ool0
0`00Oomoo`02Ool00`00Oomoo`08Ool50002Ool00`00Oomoo`06Ool30003Ool00`00Oomoo`07Ool2
0004Ool00`00Oomoo`08Ool30002Ool01P00Oomoo`00Ool000Eoo`03001oogoo009oo`03001oogoo
00Moo`8000Aoo`03001oogoo00eoo`0037oo00<007ooOol00Woo00@007ooOomoo`8000Aoo`03001o
ogoo00]oo`03001oogoo02Eoo`03001oogoo011oo`03001oogoo019oo`03001oogoo02=oo`03001o
o`0000Qoo`03001oogoo009oo`03001oogoo00Qoo`04001oo`000002Ool00`00Ool00007Ool00`00
Oomoo`02Ool00`00Ool0000:Ool01P00Oomoo`00Ool000Moo`04001oogoo0002Ool01`00Ool007oo
001oo`0000Aoo`03001oo`00009oo`03001oo`0000Qoo`03001oo`00009oo`03001oo`0000ioo`00
2goo00<007oo00001goo00<007oo00000goo00<007ooOol02goo00<007ooOol09Goo00<007ooOol0
47oo00<007ooOol04Woo00<007ooOol097oo00<007ooOol01Woo0P0017oo00<007ooOol027oo00@0
07oo0000009oo`03001oo`0000Qoo`07001oogooOol007oo00002Goo00L007oo001oo`00Ool00004
Ool00`00Oomoo`05000027oo001oo`00Ool007oo0006Ool01P00Oomoo`00Ool000Qoo`<0009oo`03
001oo`0000ioo`002goo00<007oo00001goo00<007oo00000goo0P0037oo00<007ooOol097oo00<0
07ooOol04Goo00<007ooOol04Woo00<007ooOol0<goo00<007ooOol027oo00@007oo0000009oo`03
001oo`0000Qoo`07001oogooOol007oo00002Woo0P0000Aoo`00Ool000Aoo`03001oogoo00800009
Ool007ooOol007oo001oo`00009oo`04001oogooOol20003Ool00`00Ool00007Ool30003Ool00`00
Ool0000>Ool000]oo`03001oo`0000Moo`8000Aoo`03001oogoo00]oo`03001oogoo02Aoo`03001o
ogoo019oo`03001oogoo015oo`03001oogoo03=oo`03001oogoo00Qoo`04001oo`000002Ool00`00
Ool00007Ool00`00Ool00002Ool00`00Ool00008Ool02000Ool00000Ool007oo0004Ool200000goo
000000020002Ool01@00Ool007oo00000Woo00D007ooOomoo`0000Aoo`03001oo`0000Moo`<000=o
o`03001oo`0000ioo`002goo00<007oo00001goo00<007ooOol00goo00<007ooOol02goo00<007oo
Ool03Goo00<007ooOol03Woo00<007ooOol00goo00<007ooOol04Woo00<007ooOol04Goo00<007oo
Ool0<goo0`0027oo10000goo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol00Woo00<007oo
Ool027oo0`000Woo00<007ooOol00goo0`000Woo0P000goo10000Woo00@007oo001oo`<000=oo`03
001oogoo00Ioo`04001oo`000003Ool00`00Ool0000=Ool000aoo`03001oogoo00Moo`8000=oo`03
001oogoo00]oo`03001oogoo00eoo`8000=oo`03001oogoo00Uoo`03001oogoo00=oo`03001oogoo
019oo`03001oogoo015oo`03001oogoo03=oo`04001oogoo0004Ool01000Oomoo`000Woo00<007oo
Ool01Woo00<007ooOol00Woo0P001Woo0`001Goo00<007oo000027oo0`0017oo00@007ooOol0009o
o`03001oogoo00<0011oo`04001oogoo0005Ool2000<Ool001]oo`03001oogoo00]oo`03001oogoo
00aoo`03001oo`0000=oo`8000Eoo`04001oogooOol20002Ool3000EOol00`00Oomoo`0AOol00`00
Oomoo`0cOol01000Oomoo`0017oo00@007ooOol0009oo`<000Ioo`03001oogoo009oo`03001oo`00
00Eoo`04001oogoo0004Ool00`00Ool00008Ool00`00Ool00004Ool01000Oomoo`001Goo00<007oo
00001Goo00<007ooOol00goo0P000goo00@007ooOol000Eoo`03001oo`0000]oo`006goo00<007oo
Ool02goo00<007ooOol037oo00H007ooOol007oo0002Ool00`00Oomoo`02Ool01000Oomoogoo0P00
0Woo00<007ooOol05Goo00<007ooOol04Goo00<007ooOol0<goo00@007ooOol000=oo`80009oo`03
001oogoo009oo`03001oogoo00Aoo`03001oogoo009oo`03001oo`00009oo`<000=oo`03001oogoo
009oo`04001oogoo0004Ool01P00Oomoo`00Ool000Aoo`04001oogoo0007Ool00`00Oomoo`03Ool2
0004Ool00`00Ool00002Ool00`00Oomoo`030002Ool00`00Oomoo`0<Ool001]oo`03001oogoo00]o
o`03001oogoo00]oo`07001oogooOol007oo00000Woo00@007ooOomoo`80009oo`03001oogoo0080
01Qoo`03001oogoo015oo`03001oogoo039oofX000Qoo`0037oo00<007ooOol00Woo00<007ooOol0
0Woo00<007ooOol00Woo00<007ooOol02goo00<007ooOol02goo00<007ooOol00Woo00<007ooOol0
0Woo0P0000=oo`00Ool00P000goo0P0067oo00<007ooOol04Goo00<007ooOol0<goo00L007ooOomo
o`00Ool00002Ool00`00Ool00004Ool20004Ool20003Ool01000Oomoogoo0P001goo00@007ooOol0
00=oo`04001oogoo0002Ool20007Ool30009Ool01000Oomoogoo0P000Woo00<007ooOol00Woo00@0
07ooOol000Aoo`04001oogoo000>Ool000]oo`03001oo`0000Moo`03001oo`0000=oo`03001oogoo
00]oo`03001oogoo00]oo`03001oogoo00Uoo`04001oogoo0004Ool00`00Oomoo`0GOol00`00Oomo
o`0AOol00`00Oomoo`0cOol01000Oomoogoo0`000Woo0P001Woo00<007ooOol00Woo00<007oo0000
0Woo00D007ooOomoo`0000Uoo`03001oo`0000=oo`<000=oo`8000Moo`03001oo`0000Uoo`04001o
ogoo0009Ool01000Oomoo`005Woo000;Ool00`00Ool00007Ool00`00Ool00003Ool2000<Ool00`00
Oomoo`0;Ool00`00Oomoo`0AOol00`00Oomoo`0GOol00`00Oomoo`0AOol00`00Oomoo`0cOol01@00
Oomoogoo000017oo00<007ooOol01Goo00<007ooOol00Woo00<007oo00000Woo00<007ooOol02goo
00<007oo00000goo00<007ooOol00goo0P0027oo0P002Goo00@007ooOol000Uoo`03001oo`0001Mo
o`002goo00<007oo000027oo00<007ooOol00Woo00<007ooOol02goo00<007ooOol02goo00<007oo
Ool0:goo00<007ooOol047oo00<007ooOol0=7oo00<007ooOol03Woo00<007ooOol00Woo00<007oo
00000Woo00<007ooOol037oo00<007ooOol027oo0P0027oo0P002Goo0`002Woo00<007oo00005goo
000;Ool00`00Ool00007Ool00`00Ool00003Ool00`00Oomoo`0;Ool00`00Oomoo`0;Ool00`00Oomo
o`0[Ool00`00Oomoo`0@Ool00`00Oomoo`0dOol00`00Oomoo`0?Ool00`00Oomoo`0200001Goo001o
ogoo00003Woo00<007ooOol02Goo00<007ooOol01Woo00<007ooOol02Woo00<007ooOol027oo00<0
07oo00005goo000<Ool00`00Oomoo`07Ool00`00Oomoo`02Ool00`00Oomoo`0;Ool00`00Oomoo`0;
Ool00`00Oomoo`0[Ool00`00Oomoo`0@Ool00`00Oomoo`0dOol00`00Oomoo`0?Ool00`00Ool00003
Ool01000Oomoo`006Woo00<007ooOol01Woo00<007ooOol05Goo00<007oo00005goo000KOol00`00
Oomoo`0;Ool00`00Oomoo`0;Ool00`00Oomoo`0[Ool00`00Oomoo`0@Ool00`00Oomoo`0dOol00`00
Oomoo`0@Ool00`00Oomoo`02Ool01000Oomoo`00>goo00<007oo00005goo000KOol00`00Oomoo`0;
Ool00`00Oomoo`0;Ool00`00Oomoo`0[Ool00`00Oomoo`0@Ool00`00Oomoo`0UOol00`00Oomoo`02
Ool00`00Oomoo`050002Ool00`00Oomoo`0EOol00`00Ool0000lOol00`00Ool0000GOol001Aoo`D0
009oo`03001oogoo00]oo`03001oogoo00]oo`03001oogoo02]oo`03001oogoo011oo`03001oogoo
02Aoo`03001oo`0000Qoo`03001oogoo009oo`03001oogoo01Eoo`03001oo`0003aoo`03001oo`00
01Moo`005Woo00<007ooOol00Woo00<007ooOol02goo00<007ooOol02goo00<007ooOol0:goo00<0
07ooOol047oo00<007ooOol097oo00<007oo000027oo00<007ooOol00Woo00<007ooOol05Goo00<0
07oo0000?7oo00<007oo00005goo000FOol00`00Oomoo`02Ool2000<Ool00`00Oomoo`0;Ool00`00
Oomoo`0/Ool00`00Oomoo`0?Ool00`00Oomoo`0TOol00`00Ool00008Ool00`00Oomoo`02Ool00`00
Oomoo`0EOol00`00Ool0000lOol00`00Ool0000GOol001Ioo`03001oogoo009oo`03001oogoo00]o
o`03001oogoo00]oo`03001oogoo02aoo`03001oogoo00moo`03001oogoo02Aoo`03001oo`0000Qo
o`03001oogoo009oo`03001oogoo01Ioo`8003aoo`03001oo`0001Moo`005Woo00<007ooOol00Woo
00<007ooOol037oo00<007ooOol02Woo00<007ooOol0;7oo00<007ooOol00`000Woo1@0000Ioo`00
000007oo000WOol00`00Oomoo`06Ool20004Ool00`00Oomoo`0FOol2000mOol2000GOol001Eoo`80
00Aoo`03001oogoo00aoo`03001oogoo00Yoo`03001oogoo02aoo`04001oogoo0002Ool00`00Ool0
0004Ool01000Oomoogoo0P00=Woo00<007ooOol05Woo00<007ooOol0?7oo0P005goo000KOol00`00
Oomoo`0<Ool00`00Oomoo`0:Ool00`00Oomoo`0/Ool01000Oomoo`000Woo0P00@Goo00<007ooOol0
5Woo00<007ooOol0?7oo0P005goo000KOol00`00Oomoo`0<Ool00`00Oomoo`09Ool00`00Oomoo`0]
Ool00`00Ool00004Ool00`00Oomoo`0oOol00`00Oomoo`0FOol00`00Oomoo`0lOol2000GOol001]o
o`03001oogoo00aoo`03001oogoo00Uoo`03001oogoo02eoo`03001oo`0004Ioo`03001oogoo01Io
o`03001oogoo03aoo`8001Moo`002Woo1@000Woo00@007ooOomoo`<000=oo`03001oogoo00aoo`03
001oogoo00Uoo`03001oogoo02eoo`<003Moo`03001oogoo009oo`04001oogooOol30003Ool00`00
Oomoo`1EOol2000GOol000aoo`03001oogoo00Ioo`03001oogoo00=oo`03001oogoo00aoo`03001o
ogoo00Uoo`03001oogoo06Ioo`03001oo`0000Moo`03001oogoo00=oo`03001oogoo05Eoo`03001o
ogoo01Ioo`0037oo00<007ooOol01goo00<007ooOol00Woo0P003Goo00<007ooOol02Goo00<007oo
Ool0IWoo00<007oo000027oo00<007ooOol00Woo00<007ooOol0EGoo00<007ooOol05Woo000<Ool0
0`00Oomoo`07Ool00`00Oomoo`02Ool00`00Oomoo`0<Ool00`00Oomoo`09Ool00`00Oomoo`1VOol0
0`00Ool00008Ool00`00Oomoo`02Ool00`00Oomoo`1EOol00`00Oomoo`0FOol000aoo`03001oogoo
00Ioo`03001oo`0000=oo`03001oogoo00aoo`03001oogoo00Uoo`03001oogoo06Ioo`03001oo`00
00Moo`03001oo`0000=oo`03001oogoo05Eoo`03001oogoo01Ioo`002goo0P002Goo00<007ooOol0
0Woo00<007ooOol037oo00<007ooOol02Goo00<007ooOol0Igoo00<007ooOol01goo00<007ooOol0
0Woo00<007ooOol0EGoo00<007ooOol05Woo000KOol00`00Oomoo`0<Ool00`00Oomoo`09Ool00`00
Oomoo`1fOol00`00Oomoo`1EOol00`00Oomoo`0FOol001]oo`03001oogoo00aoo`03001oogoo00Uo
o`03001oogoo07Ioo`03001oogoo05Eoo`03001oogoo01Ioo`006goo00<007ooOol037oo0P002Woo
00<007ooOol0MWoo00<007ooOol0EGoo00<007ooOol05Woo000:Ool50002Ool00`00Oomoo`02Ool3
0002Ool00`00Oomoo`0>Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`1fOol00`00Oomo
o`1^Ool000aoo`03001oogoo00Qoo`05001oogooOol0000@Ool00`00Oomoo`02Ool00`00Oomoo`02
Ool00`00Oomoo`1fOol00`00Oomoo`1^Ool000aoo`03001oogoo00Ioo`@0009oo`80011oo`05001o
ogoo001oo`05003YOol000aoo`03001oogoo00Ioo`03001oo`0000=oo`03001oogoo00moo`800003
Ool007oo0>ioo`0037oo00<007ooOol01goo0P000goo00<007ooOol04Goo00<007ooOol0kWoo000;
Ool2000:Ool01@00Oomoogoo0000ogoo1Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol0
0?moob5oo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {83.75, 0}} -> {-0.0589635, -0.0147182, 
  0.00737954, 0.00737954}, {{7.9375, 137}, {81.75, 
  1.9375}} -> {-16.335, -0.347641, 0.597884, 0.0233598}, {{149.938, 279}, {
  81.75, 1.9375}} -> {-110.761, -0.467565, 0.632029, 0.0101311}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Inverse Transform (Synthesis)", "Subsection"],

Cell[TextData[{
  "Given the wavelet transform coefficients, we are now interested in \
reconstructing the original signal. The wavelet transform is an orthonormal \
transformation, so we will have perfect reconstruction. The input data must \
be in the form of the output of ",
  StyleBox["DWT", "Program"],
  ". The synthesis operation is a process of up-sampling and filtering.  Each \
level of DWT coefficients has zeros inserted between them. "
}], "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{
            RowBox[{"(", 
              StyleBox[GridBox[{
                    {\(h\_0 + h\_2\)},
                    {\(h\_1 + h\_3\)}
                    }],
                GridBoxOptions->{RowSpacings->1.6,
                ColumnSpacings->0.8,
                ColumnsEqual->False}], 
              StyleBox[")",
                GridBoxOptions->{RowSpacings->1.6,
                ColumnSpacings->0.8,
                ColumnsEqual->False}]}], \((c\_0\%0)\)}], " ", "+", 
          RowBox[{
            RowBox[{"(", 
              StyleBox[GridBox[{
                    {\(g\_0 + g\_2\)},
                    {\(g\_1 + g\_3\)}
                    }],
                GridBoxOptions->{RowSpacings->1.6,
                ColumnSpacings->0.8,
                ColumnsEqual->False}], 
              StyleBox[")",
                GridBoxOptions->{RowSpacings->1.6,
                ColumnSpacings->0.8,
                ColumnsEqual->False}]}], 
            RowBox[{\((\^d\_0\%0)\), " ", "\[LongRightArrow]", 
              RowBox[{"(", GridBox[{
                    {\(c\_0\%1\)},
                    {\(c\_1\%1\)}
                    }], ")"}]}]}]}], ","}], TraditionalForm]], 
  "NumberedEquation"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{
            StyleBox[
              RowBox[{"(", GridBox[{
                    {\(h\_0\), \(h\_2\)},
                    {\(h\_1\), \(h\_3\)},
                    {\(h\_2\), \(h\_0\)},
                    {\(h\_3\), \(h\_1\)}
                    }], ")"}],
              GridBoxOptions->{RowSpacings->1.6,
              ColumnsEqual->True}], 
            RowBox[{"(", GridBox[{
                  {\(c\_0\%1\)},
                  {\(c\_1\%1\)}
                  }], ")"}]}], "+", " ", 
          RowBox[{
            StyleBox[
              RowBox[{"(", GridBox[{
                    {\(g\_0\), \(g\_2\)},
                    {\(g\_1\), \(g\_3\)},
                    {\(g\_2\), \(g\_0\)},
                    {\(g\_3\), \(g\_1\)}
                    }], ")"}],
              GridBoxOptions->{RowSpacings->1.6,
              ColumnsEqual->True}], 
            RowBox[{
              RowBox[{"(", GridBox[{
                    {\(d\_0\%1\)},
                    {\(d\_1\%1\)}
                    }], ")"}], "\[LongRightArrow]", 
              RowBox[{"(", GridBox[{
                    {\(c\_0\%2\)},
                    {\(c\_1\%2\)},
                    {\(c\_2\%2\)},
                    {\(c\_3\%2\)}
                    }], ")"}]}]}]}], ","}], TraditionalForm]], 
  "NumberedEquation"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          StyleBox[
            TagBox[
              RowBox[{"(", GridBox[{
                    {\(h\_0\), "0", "0", \(h\_2\)},
                    {\(h\_1\), "0", "0", \(h\_3\)},
                    {\(h\_2\), \(h\_0\), "0", "0"},
                    {\(h\_3\), \(h\_1\), "0", "0"},
                    {"0", \(h\_2\), \(h\_0\), "0"},
                    {"0", \(h\_3\), \(h\_1\), "0"},
                    {"0", "0", \(h\_2\), \(h\_0\)},
                    {"0", "0", \(h\_3\), \(h\_1\)}
                    }], ")"}],
              (MatrixForm[ #]&)],
            GridBoxOptions->{RowSpacings->1.6}], 
          RowBox[{"(", GridBox[{
                {\(c\_0\%2\)},
                {\(c\_1\%2\)},
                {\(c\_2\%2\)},
                {\(c\_3\%2\)}
                }], ")"}]}], "+", 
        RowBox[{
          StyleBox[
            TagBox[
              RowBox[{"(", GridBox[{
                    {\(g\_0\), "0", "0", \(g\_2\)},
                    {\(g\_1\), "0", "0", \(g\_3\)},
                    {\(g\_2\), \(g\_0\), "0", "0"},
                    {\(g\_3\), \(g\_1\), "0", "0"},
                    {"0", \(g\_2\), \(g\_0\), "0"},
                    {"0", \(g\_3\), \(g\_1\), "0"},
                    {"0", "0", \(g\_2\), \(g\_0\)},
                    {"0", "0", \(g\_3\), \(g\_1\)}
                    }], ")"}],
              (MatrixForm[ #]&)],
            GridBoxOptions->{RowSpacings->1.6}], 
          RowBox[{
            RowBox[{
              RowBox[{"(", GridBox[{
                    {\(d\_0\%3\)},
                    {\(d\_1\%3\)},
                    {\(d\_2\%3\)},
                    {\(d\_3\%3\)}
                    }], ")"}], "\[LongRightArrow]", 
              RowBox[{"(", GridBox[{
                    {\(c\_0\%3\)},
                    {\(c\_1\%3\)},
                    {\(c\_2\%3\)},
                    {\(c\_3\%3\)},
                    {\(c\_4\%3\)},
                    {\(c\_5\%3\)},
                    {\(c\_6\%3\n
                      c\_7\%3\)}
                    }], ")"}]}], "."}]}]}], TraditionalForm]], 
  "NumberedEquation"],

Cell["First, we verify perfect reconstruction.", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(y = InverseDWT[X\_DWT, D\_2]; \n
    IntegerPart[y\ 10^10] == IntegerPart[x\ 10^10]\)], "Input"],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]],

Cell["\<\
Next, we reconstruct an approximation of the original signal from a subset of \
the wavelet coefficients. Note that the signal remains recognizable for all \
but the lowest resolution levels.\
\>", "Text"],

Cell[BoxData[
    \(\(\(y\&~\) = 
      \(InverseDWT[X\_DWT*#1, D\_4]\ &\)\ /@
        \ {{1, 1, 0, 0, 0, 0, 0, 0}, 
          \ {1, 1, 1, 1, 0, 0, 0, 0}, {1, 1, 1, 1, 1, 1, 0, 0}, 1}; \)\)], 
  "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[
      GraphicsArray[
        Map[\nListPlot[#, PlotJoined -> True, \n\t\t\t\t
              DisplayFunction -> Identity]&, \ Partition[\(y\&~\), 2], {2}]\n
        \t]]; \)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0147151 0.47619 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0147151 0.477324 0.295003 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00744048 0.0948998 0.423686 [
[.17262 .0824 -6 -9 ]
[.17262 .0824 6 0 ]
[.32143 .0824 -6 -9 ]
[.32143 .0824 6 0 ]
[.47024 .0824 -6 -9 ]
[.47024 .0824 6 0 ]
[.61905 .0824 -6 -9 ]
[.61905 .0824 6 0 ]
[.76786 .0824 -9 -9 ]
[.76786 .0824 9 0 ]
[.91667 .0824 -9 -9 ]
[.91667 .0824 9 0 ]
[.01131 .01016 -24 -4.5 ]
[.01131 .01016 0 4.5 ]
[.01131 .17964 -18 -4.5 ]
[.01131 .17964 0 4.5 ]
[.01131 .26437 -18 -4.5 ]
[.01131 .26437 0 4.5 ]
[.01131 .34911 -18 -4.5 ]
[.01131 .34911 0 4.5 ]
[.01131 .43385 -18 -4.5 ]
[.01131 .43385 0 4.5 ]
[.01131 .51859 -6 -4.5 ]
[.01131 .51859 0 4.5 ]
[.01131 .60332 -18 -4.5 ]
[.01131 .60332 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.17262 .0949 m
.17262 .10115 L
s
[(20)] .17262 .0824 0 1 Mshowa
.32143 .0949 m
.32143 .10115 L
s
[(40)] .32143 .0824 0 1 Mshowa
.47024 .0949 m
.47024 .10115 L
s
[(60)] .47024 .0824 0 1 Mshowa
.61905 .0949 m
.61905 .10115 L
s
[(80)] .61905 .0824 0 1 Mshowa
.76786 .0949 m
.76786 .10115 L
s
[(100)] .76786 .0824 0 1 Mshowa
.91667 .0949 m
.91667 .10115 L
s
[(120)] .91667 .0824 0 1 Mshowa
.125 Mabswid
.06101 .0949 m
.06101 .09865 L
s
.09821 .0949 m
.09821 .09865 L
s
.13542 .0949 m
.13542 .09865 L
s
.20982 .0949 m
.20982 .09865 L
s
.24702 .0949 m
.24702 .09865 L
s
.28423 .0949 m
.28423 .09865 L
s
.35863 .0949 m
.35863 .09865 L
s
.39583 .0949 m
.39583 .09865 L
s
.43304 .0949 m
.43304 .09865 L
s
.50744 .0949 m
.50744 .09865 L
s
.54464 .0949 m
.54464 .09865 L
s
.58185 .0949 m
.58185 .09865 L
s
.65625 .0949 m
.65625 .09865 L
s
.69345 .0949 m
.69345 .09865 L
s
.73065 .0949 m
.73065 .09865 L
s
.80506 .0949 m
.80506 .09865 L
s
.84226 .0949 m
.84226 .09865 L
s
.87946 .0949 m
.87946 .09865 L
s
.95387 .0949 m
.95387 .09865 L
s
.99107 .0949 m
.99107 .09865 L
s
.25 Mabswid
0 .0949 m
1 .0949 L
s
.02381 .01016 m
.03006 .01016 L
s
[(-0.2)] .01131 .01016 1 0 Mshowa
.02381 .17964 m
.03006 .17964 L
s
[(0.2)] .01131 .17964 1 0 Mshowa
.02381 .26437 m
.03006 .26437 L
s
[(0.4)] .01131 .26437 1 0 Mshowa
.02381 .34911 m
.03006 .34911 L
s
[(0.6)] .01131 .34911 1 0 Mshowa
.02381 .43385 m
.03006 .43385 L
s
[(0.8)] .01131 .43385 1 0 Mshowa
.02381 .51859 m
.03006 .51859 L
s
[(1)] .01131 .51859 1 0 Mshowa
.02381 .60332 m
.03006 .60332 L
s
[(1.2)] .01131 .60332 1 0 Mshowa
.125 Mabswid
.02381 .03135 m
.02756 .03135 L
s
.02381 .05253 m
.02756 .05253 L
s
.02381 .07372 m
.02756 .07372 L
s
.02381 .11608 m
.02756 .11608 L
s
.02381 .13727 m
.02756 .13727 L
s
.02381 .15845 m
.02756 .15845 L
s
.02381 .20082 m
.02756 .20082 L
s
.02381 .22201 m
.02756 .22201 L
s
.02381 .24319 m
.02756 .24319 L
s
.02381 .28556 m
.02756 .28556 L
s
.02381 .30674 m
.02756 .30674 L
s
.02381 .32793 m
.02756 .32793 L
s
.02381 .3703 m
.02756 .3703 L
s
.02381 .39148 m
.02756 .39148 L
s
.02381 .41266 m
.02756 .41266 L
s
.02381 .45503 m
.02756 .45503 L
s
.02381 .47622 m
.02756 .47622 L
s
.02381 .4974 m
.02756 .4974 L
s
.02381 .53977 m
.02756 .53977 L
s
.02381 .56095 m
.02756 .56095 L
s
.02381 .58214 m
.02756 .58214 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.03125 .09538 m
.03869 .08853 L
.04613 .08644 L
.05357 .08308 L
.06101 .08915 L
.06845 .09269 L
.07589 .0937 L
.08333 .09539 L
.09077 .09413 L
.09821 .09366 L
.10565 .09397 L
.1131 .09408 L
.12054 .11116 L
.12798 .12369 L
.13542 .13167 L
.14286 .14087 L
.1503 .30587 L
.15774 .42912 L
.16518 .51063 L
.17262 .60332 L
.18006 .5329 L
.1875 .50618 L
.19494 .52317 L
.20238 .52845 L
.20982 .51864 L
.21726 .51288 L
.2247 .51116 L
.23214 .50836 L
.23958 .50806 L
.24702 .50709 L
.25446 .50544 L
.2619 .50398 L
.26935 .40859 L
.27679 .33836 L
.28423 .29331 L
.29167 .24151 L
.29911 .29274 L
.30655 .31637 L
.31399 .31238 L
.32143 .3158 L
.32887 .30931 L
.33631 .30548 L
.34375 .3043 L
.35119 .30241 L
.35863 .31203 L
.36607 .31856 L
.37351 .32201 L
.38095 .32629 L
.38839 .32214 L
.39583 .32025 L
Mistroke
.40327 .32062 L
.41071 .32038 L
.41815 .31266 L
.4256 .30694 L
.43304 .30323 L
.44048 .29898 L
.44792 .30661 L
.45536 .31106 L
.4628 .31232 L
.47024 .31444 L
.47768 .3016 L
.48512 .29277 L
.49256 .28794 L
.5 .28204 L
.50744 .2503 L
.51488 .22547 L
.52232 .20758 L
.52976 .18783 L
.5372 .19875 L
.54464 .20145 L
.55208 .19594 L
.55952 .19262 L
.56696 .20049 L
.5744 .20536 L
.58185 .20724 L
.58929 .20991 L
.59673 .20219 L
.60417 .19725 L
.61161 .1951 L
.61905 .19221 L
.62649 .20431 L
.63393 .2124 L
.64137 .21647 L
.64881 .22161 L
.65625 .22351 L
.66369 .22627 L
.67113 .22991 L
.67857 .23331 L
.68601 .32651 L
.69345 .39565 L
.70089 .44073 L
.70833 .49225 L
.71577 .4355 L
.72321 .40775 L
.73065 .40903 L
.7381 .40252 L
.74554 .40849 L
.75298 .41112 L
.76042 .41041 L
.76786 .41059 L
Mistroke
.7753 .40772 L
.78274 .40567 L
.79018 .40444 L
.79762 .40299 L
.80506 .40768 L
.8125 .41072 L
.81994 .41212 L
.82738 .41395 L
.83482 .40339 L
.84226 .39615 L
.8497 .39224 L
.85714 .38743 L
.86458 .25324 L
.87202 .15371 L
.87946 .08886 L
.8869 .01472 L
.89435 .07958 L
.90179 .1072 L
.90923 .09757 L
.91667 .09792 L
.92411 .08736 L
.93155 .07972 L
.93899 .075 L
.94643 .0695 L
.95387 .08578 L
.96131 .09622 L
.96875 .10083 L
.97619 .107 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0147151 0.97619 0.295003 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00744048 0.0507485 0.523432 [
[.17262 .03825 -6 -9 ]
[.17262 .03825 6 0 ]
[.32143 .03825 -6 -9 ]
[.32143 .03825 6 0 ]
[.47024 .03825 -6 -9 ]
[.47024 .03825 6 0 ]
[.61905 .03825 -6 -9 ]
[.61905 .03825 6 0 ]
[.76786 .03825 -9 -9 ]
[.76786 .03825 9 0 ]
[.91667 .03825 -9 -9 ]
[.91667 .03825 9 0 ]
[.01131 .15543 -18 -4.5 ]
[.01131 .15543 0 4.5 ]
[.01131 .26012 -18 -4.5 ]
[.01131 .26012 0 4.5 ]
[.01131 .36481 -18 -4.5 ]
[.01131 .36481 0 4.5 ]
[.01131 .46949 -18 -4.5 ]
[.01131 .46949 0 4.5 ]
[.01131 .57418 -6 -4.5 ]
[.01131 .57418 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.17262 .05075 m
.17262 .057 L
s
[(20)] .17262 .03825 0 1 Mshowa
.32143 .05075 m
.32143 .057 L
s
[(40)] .32143 .03825 0 1 Mshowa
.47024 .05075 m
.47024 .057 L
s
[(60)] .47024 .03825 0 1 Mshowa
.61905 .05075 m
.61905 .057 L
s
[(80)] .61905 .03825 0 1 Mshowa
.76786 .05075 m
.76786 .057 L
s
[(100)] .76786 .03825 0 1 Mshowa
.91667 .05075 m
.91667 .057 L
s
[(120)] .91667 .03825 0 1 Mshowa
.125 Mabswid
.06101 .05075 m
.06101 .0545 L
s
.09821 .05075 m
.09821 .0545 L
s
.13542 .05075 m
.13542 .0545 L
s
.20982 .05075 m
.20982 .0545 L
s
.24702 .05075 m
.24702 .0545 L
s
.28423 .05075 m
.28423 .0545 L
s
.35863 .05075 m
.35863 .0545 L
s
.39583 .05075 m
.39583 .0545 L
s
.43304 .05075 m
.43304 .0545 L
s
.50744 .05075 m
.50744 .0545 L
s
.54464 .05075 m
.54464 .0545 L
s
.58185 .05075 m
.58185 .0545 L
s
.65625 .05075 m
.65625 .0545 L
s
.69345 .05075 m
.69345 .0545 L
s
.73065 .05075 m
.73065 .0545 L
s
.80506 .05075 m
.80506 .0545 L
s
.84226 .05075 m
.84226 .0545 L
s
.87946 .05075 m
.87946 .0545 L
s
.95387 .05075 m
.95387 .0545 L
s
.99107 .05075 m
.99107 .0545 L
s
.25 Mabswid
0 .05075 m
1 .05075 L
s
.02381 .15543 m
.03006 .15543 L
s
[(0.2)] .01131 .15543 1 0 Mshowa
.02381 .26012 m
.03006 .26012 L
s
[(0.4)] .01131 .26012 1 0 Mshowa
.02381 .36481 m
.03006 .36481 L
s
[(0.6)] .01131 .36481 1 0 Mshowa
.02381 .46949 m
.03006 .46949 L
s
[(0.8)] .01131 .46949 1 0 Mshowa
.02381 .57418 m
.03006 .57418 L
s
[(1)] .01131 .57418 1 0 Mshowa
.125 Mabswid
.02381 .07692 m
.02756 .07692 L
s
.02381 .10309 m
.02756 .10309 L
s
.02381 .12926 m
.02756 .12926 L
s
.02381 .18161 m
.02756 .18161 L
s
.02381 .20778 m
.02756 .20778 L
s
.02381 .23395 m
.02756 .23395 L
s
.02381 .28629 m
.02756 .28629 L
s
.02381 .31246 m
.02756 .31246 L
s
.02381 .33864 m
.02756 .33864 L
s
.02381 .39098 m
.02756 .39098 L
s
.02381 .41715 m
.02756 .41715 L
s
.02381 .44332 m
.02756 .44332 L
s
.02381 .49567 m
.02756 .49567 L
s
.02381 .52184 m
.02756 .52184 L
s
.02381 .54801 m
.02756 .54801 L
s
.02381 .02458 m
.02756 .02458 L
s
.02381 .60035 m
.02756 .60035 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.03125 .05607 m
.03869 .01943 L
.04613 .04701 L
.05357 .0166 L
.06101 .07995 L
.06845 .08125 L
.07589 .03137 L
.08333 .02836 L
.09077 .04378 L
.09821 .07736 L
.10565 .0706 L
.1131 .04143 L
.12054 .02255 L
.12798 .03786 L
.13542 .0356 L
.14286 .05153 L
.1503 .55601 L
.15774 .54476 L
.16518 .55802 L
.17262 .54715 L
.18006 .58141 L
.1875 .57881 L
.19494 .5766 L
.20238 .60332 L
.20982 .53683 L
.21726 .57087 L
.2247 .54108 L
.23214 .59821 L
.23958 .54689 L
.24702 .57963 L
.25446 .59972 L
.2619 .58135 L
.26935 .33139 L
.27679 .33056 L
.28423 .27889 L
.29167 .2897 L
.29911 .32034 L
.30655 .30419 L
.31399 .33329 L
.32143 .32818 L
.32887 .29925 L
.33631 .29435 L
.34375 .3102 L
.35119 .31595 L
.35863 .33128 L
.36607 .32898 L
.37351 .34704 L
.38095 .32606 L
.38839 .32937 L
.39583 .29304 L
Mistroke
.40327 .34088 L
.41071 .34129 L
.41815 .31741 L
.4256 .32684 L
.43304 .27609 L
.44048 .29486 L
.44792 .33774 L
.45536 .34801 L
.4628 .34892 L
.47024 .27837 L
.47768 .29061 L
.48512 .31703 L
.49256 .28884 L
.5 .30192 L
.50744 .21222 L
.51488 .16502 L
.52232 .1995 L
.52976 .20684 L
.5372 .15414 L
.54464 .18776 L
.55208 .20418 L
.55952 .15398 L
.56696 .17649 L
.5744 .16793 L
.58185 .21502 L
.58929 .16441 L
.59673 .21081 L
.60417 .19281 L
.61161 .21214 L
.61905 .14276 L
.62649 .14628 L
.63393 .19652 L
.64137 .21494 L
.64881 .21611 L
.65625 .20739 L
.66369 .1527 L
.67113 .19931 L
.67857 .18739 L
.68601 .47776 L
.69345 .47026 L
.70089 .48239 L
.70833 .46313 L
.71577 .46596 L
.72321 .42485 L
.73065 .42055 L
.7381 .4515 L
.74554 .43182 L
.75298 .47778 L
.76042 .4264 L
.76786 .42944 L
Mistroke
.7753 .44187 L
.78274 .42732 L
.79018 .43513 L
.79762 .42903 L
.80506 .43794 L
.8125 .45166 L
.81994 .44105 L
.82738 .43379 L
.83482 .45141 L
.84226 .44131 L
.8497 .46261 L
.85714 .46726 L
.86458 .06366 L
.87202 .06105 L
.87946 .07023 L
.8869 .01562 L
.89435 .08028 L
.90179 .04027 L
.90923 .05374 L
.91667 .04669 L
.92411 .05252 L
.93155 .04507 L
.93899 .03141 L
.94643 .02132 L
.95387 .01472 L
.96131 .02181 L
.96875 .07886 L
.97619 .07487 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.323031 0.477324 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00744048 -0.408071 1.63153 [
[.17262 .06889 -6 -9 ]
[.17262 .06889 6 0 ]
[.32143 .06889 -6 -9 ]
[.32143 .06889 6 0 ]
[.47024 .06889 -6 -9 ]
[.47024 .06889 6 0 ]
[.61905 .06889 -6 -9 ]
[.61905 .06889 6 0 ]
[.76786 .06889 -9 -9 ]
[.76786 .06889 9 0 ]
[.91667 .06889 -9 -9 ]
[.91667 .06889 9 0 ]
[.01131 .16296 -24 -4.5 ]
[.01131 .16296 0 4.5 ]
[.01131 .24454 -18 -4.5 ]
[.01131 .24454 0 4.5 ]
[.01131 .32612 -24 -4.5 ]
[.01131 .32612 0 4.5 ]
[.01131 .40769 -18 -4.5 ]
[.01131 .40769 0 4.5 ]
[.01131 .48927 -24 -4.5 ]
[.01131 .48927 0 4.5 ]
[.01131 .57085 -18 -4.5 ]
[.01131 .57085 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.17262 .08139 m
.17262 .08764 L
s
[(20)] .17262 .06889 0 1 Mshowa
.32143 .08139 m
.32143 .08764 L
s
[(40)] .32143 .06889 0 1 Mshowa
.47024 .08139 m
.47024 .08764 L
s
[(60)] .47024 .06889 0 1 Mshowa
.61905 .08139 m
.61905 .08764 L
s
[(80)] .61905 .06889 0 1 Mshowa
.76786 .08139 m
.76786 .08764 L
s
[(100)] .76786 .06889 0 1 Mshowa
.91667 .08139 m
.91667 .08764 L
s
[(120)] .91667 .06889 0 1 Mshowa
.125 Mabswid
.06101 .08139 m
.06101 .08514 L
s
.09821 .08139 m
.09821 .08514 L
s
.13542 .08139 m
.13542 .08514 L
s
.20982 .08139 m
.20982 .08514 L
s
.24702 .08139 m
.24702 .08514 L
s
.28423 .08139 m
.28423 .08514 L
s
.35863 .08139 m
.35863 .08514 L
s
.39583 .08139 m
.39583 .08514 L
s
.43304 .08139 m
.43304 .08514 L
s
.50744 .08139 m
.50744 .08514 L
s
.54464 .08139 m
.54464 .08514 L
s
.58185 .08139 m
.58185 .08514 L
s
.65625 .08139 m
.65625 .08514 L
s
.69345 .08139 m
.69345 .08514 L
s
.73065 .08139 m
.73065 .08514 L
s
.80506 .08139 m
.80506 .08514 L
s
.84226 .08139 m
.84226 .08514 L
s
.87946 .08139 m
.87946 .08514 L
s
.95387 .08139 m
.95387 .08514 L
s
.99107 .08139 m
.99107 .08514 L
s
.25 Mabswid
0 .08139 m
1 .08139 L
s
.02381 .16296 m
.03006 .16296 L
s
[(0.35)] .01131 .16296 1 0 Mshowa
.02381 .24454 m
.03006 .24454 L
s
[(0.4)] .01131 .24454 1 0 Mshowa
.02381 .32612 m
.03006 .32612 L
s
[(0.45)] .01131 .32612 1 0 Mshowa
.02381 .40769 m
.03006 .40769 L
s
[(0.5)] .01131 .40769 1 0 Mshowa
.02381 .48927 m
.03006 .48927 L
s
[(0.55)] .01131 .48927 1 0 Mshowa
.02381 .57085 m
.03006 .57085 L
s
[(0.6)] .01131 .57085 1 0 Mshowa
.125 Mabswid
.02381 .01613 m
.02756 .01613 L
s
.02381 .03244 m
.02756 .03244 L
s
.02381 .04876 m
.02756 .04876 L
s
.02381 .06507 m
.02756 .06507 L
s
.02381 .0977 m
.02756 .0977 L
s
.02381 .11402 m
.02756 .11402 L
s
.02381 .13033 m
.02756 .13033 L
s
.02381 .14665 m
.02756 .14665 L
s
.02381 .17928 m
.02756 .17928 L
s
.02381 .19559 m
.02756 .19559 L
s
.02381 .21191 m
.02756 .21191 L
s
.02381 .22823 m
.02756 .22823 L
s
.02381 .26086 m
.02756 .26086 L
s
.02381 .27717 m
.02756 .27717 L
s
.02381 .29349 m
.02756 .29349 L
s
.02381 .3098 m
.02756 .3098 L
s
.02381 .34243 m
.02756 .34243 L
s
.02381 .35875 m
.02756 .35875 L
s
.02381 .37506 m
.02756 .37506 L
s
.02381 .39138 m
.02756 .39138 L
s
.02381 .42401 m
.02756 .42401 L
s
.02381 .44032 m
.02756 .44032 L
s
.02381 .45664 m
.02756 .45664 L
s
.02381 .47295 m
.02756 .47295 L
s
.02381 .50559 m
.02756 .50559 L
s
.02381 .5219 m
.02756 .5219 L
s
.02381 .53822 m
.02756 .53822 L
s
.02381 .55453 m
.02756 .55453 L
s
.02381 .58716 m
.02756 .58716 L
s
.02381 .60348 m
.02756 .60348 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.03125 .07883 m
.03869 .12434 L
.04613 .15123 L
.05357 .18311 L
.06101 .19637 L
.06845 .21463 L
.07589 .23787 L
.08333 .25977 L
.09077 .26307 L
.09821 .27135 L
.10565 .28461 L
.1131 .29654 L
.12054 .31346 L
.12798 .32904 L
.13542 .34329 L
.14286 .35789 L
.1503 .35388 L
.15774 .35486 L
.16518 .36083 L
.17262 .36545 L
.18006 .37507 L
.1875 .38335 L
.19494 .39029 L
.20238 .3976 L
.20982 .40988 L
.21726 .42084 L
.2247 .43045 L
.23214 .44043 L
.23958 .44907 L
.24702 .45806 L
.25446 .46742 L
.2619 .47667 L
.26935 .46732 L
.27679 .46295 L
.28423 .46357 L
.29167 .46286 L
.29911 .46713 L
.30655 .47006 L
.31399 .47166 L
.32143 .47362 L
.32887 .48056 L
.33631 .48617 L
.34375 .49044 L
.35119 .49507 L
.35863 .49836 L
.36607 .50201 L
.37351 .50602 L
.38095 .50993 L
.38839 .51883 L
.39583 .5264 L
Mistroke
.40327 .53262 L
.41071 .53921 L
.41815 .54446 L
.4256 .55007 L
.43304 .55603 L
.44048 .5619 L
.44792 .56643 L
.45536 .57133 L
.4628 .57657 L
.47024 .58173 L
.47768 .58724 L
.48512 .59265 L
.49256 .59797 L
.5 .60332 L
.50744 .5392 L
.51488 .4937 L
.52232 .46681 L
.52976 .43493 L
.5372 .42166 L
.54464 .40341 L
.55208 .38017 L
.55952 .35826 L
.56696 .35497 L
.5744 .34669 L
.58185 .33342 L
.58929 .32149 L
.59673 .30457 L
.60417 .28899 L
.61161 .27475 L
.61905 .26014 L
.62649 .26415 L
.63393 .26317 L
.64137 .25721 L
.64881 .25258 L
.65625 .24296 L
.66369 .23468 L
.67113 .22774 L
.67857 .22044 L
.68601 .20815 L
.69345 .1972 L
.70089 .18758 L
.70833 .17761 L
.71577 .16897 L
.72321 .15997 L
.73065 .15062 L
.7381 .14136 L
.74554 .15071 L
.75298 .15508 L
.76042 .15446 L
.76786 .15518 L
Mistroke
.7753 .15091 L
.78274 .14797 L
.79018 .14637 L
.79762 .14442 L
.80506 .13747 L
.8125 .13187 L
.81994 .1276 L
.82738 .12297 L
.83482 .11967 L
.84226 .11602 L
.8497 .11201 L
.85714 .1081 L
.86458 .0992 L
.87202 .09164 L
.87946 .08541 L
.8869 .07882 L
.89435 .07358 L
.90179 .06797 L
.90923 .062 L
.91667 .05613 L
.92411 .0516 L
.93155 .04671 L
.93899 .04146 L
.94643 .03631 L
.95387 .0308 L
.96131 .02538 L
.96875 .02006 L
.97619 .01472 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.323031 0.97619 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00744048 0.116574 0.406613 [
[.17262 .10407 -6 -9 ]
[.17262 .10407 6 0 ]
[.32143 .10407 -6 -9 ]
[.32143 .10407 6 0 ]
[.47024 .10407 -6 -9 ]
[.47024 .10407 6 0 ]
[.61905 .10407 -6 -9 ]
[.61905 .10407 6 0 ]
[.76786 .10407 -9 -9 ]
[.76786 .10407 9 0 ]
[.91667 .10407 -9 -9 ]
[.91667 .10407 9 0 ]
[.01131 .03525 -24 -4.5 ]
[.01131 .03525 0 4.5 ]
[.01131 .1979 -18 -4.5 ]
[.01131 .1979 0 4.5 ]
[.01131 .27922 -18 -4.5 ]
[.01131 .27922 0 4.5 ]
[.01131 .36054 -18 -4.5 ]
[.01131 .36054 0 4.5 ]
[.01131 .44186 -18 -4.5 ]
[.01131 .44186 0 4.5 ]
[.01131 .52319 -6 -4.5 ]
[.01131 .52319 0 4.5 ]
[.01131 .60451 -18 -4.5 ]
[.01131 .60451 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.17262 .11657 m
.17262 .12282 L
s
[(20)] .17262 .10407 0 1 Mshowa
.32143 .11657 m
.32143 .12282 L
s
[(40)] .32143 .10407 0 1 Mshowa
.47024 .11657 m
.47024 .12282 L
s
[(60)] .47024 .10407 0 1 Mshowa
.61905 .11657 m
.61905 .12282 L
s
[(80)] .61905 .10407 0 1 Mshowa
.76786 .11657 m
.76786 .12282 L
s
[(100)] .76786 .10407 0 1 Mshowa
.91667 .11657 m
.91667 .12282 L
s
[(120)] .91667 .10407 0 1 Mshowa
.125 Mabswid
.06101 .11657 m
.06101 .12032 L
s
.09821 .11657 m
.09821 .12032 L
s
.13542 .11657 m
.13542 .12032 L
s
.20982 .11657 m
.20982 .12032 L
s
.24702 .11657 m
.24702 .12032 L
s
.28423 .11657 m
.28423 .12032 L
s
.35863 .11657 m
.35863 .12032 L
s
.39583 .11657 m
.39583 .12032 L
s
.43304 .11657 m
.43304 .12032 L
s
.50744 .11657 m
.50744 .12032 L
s
.54464 .11657 m
.54464 .12032 L
s
.58185 .11657 m
.58185 .12032 L
s
.65625 .11657 m
.65625 .12032 L
s
.69345 .11657 m
.69345 .12032 L
s
.73065 .11657 m
.73065 .12032 L
s
.80506 .11657 m
.80506 .12032 L
s
.84226 .11657 m
.84226 .12032 L
s
.87946 .11657 m
.87946 .12032 L
s
.95387 .11657 m
.95387 .12032 L
s
.99107 .11657 m
.99107 .12032 L
s
.25 Mabswid
0 .11657 m
1 .11657 L
s
.02381 .03525 m
.03006 .03525 L
s
[(-0.2)] .01131 .03525 1 0 Mshowa
.02381 .1979 m
.03006 .1979 L
s
[(0.2)] .01131 .1979 1 0 Mshowa
.02381 .27922 m
.03006 .27922 L
s
[(0.4)] .01131 .27922 1 0 Mshowa
.02381 .36054 m
.03006 .36054 L
s
[(0.6)] .01131 .36054 1 0 Mshowa
.02381 .44186 m
.03006 .44186 L
s
[(0.8)] .01131 .44186 1 0 Mshowa
.02381 .52319 m
.03006 .52319 L
s
[(1)] .01131 .52319 1 0 Mshowa
.02381 .60451 m
.03006 .60451 L
s
[(1.2)] .01131 .60451 1 0 Mshowa
.125 Mabswid
.02381 .05558 m
.02756 .05558 L
s
.02381 .07591 m
.02756 .07591 L
s
.02381 .09624 m
.02756 .09624 L
s
.02381 .1369 m
.02756 .1369 L
s
.02381 .15724 m
.02756 .15724 L
s
.02381 .17757 m
.02756 .17757 L
s
.02381 .21823 m
.02756 .21823 L
s
.02381 .23856 m
.02756 .23856 L
s
.02381 .25889 m
.02756 .25889 L
s
.02381 .29955 m
.02756 .29955 L
s
.02381 .31988 m
.02756 .31988 L
s
.02381 .34021 m
.02756 .34021 L
s
.02381 .38087 m
.02756 .38087 L
s
.02381 .4012 m
.02756 .4012 L
s
.02381 .42153 m
.02756 .42153 L
s
.02381 .4622 m
.02756 .4622 L
s
.02381 .48253 m
.02756 .48253 L
s
.02381 .50286 m
.02756 .50286 L
s
.02381 .54352 m
.02756 .54352 L
s
.02381 .56385 m
.02756 .56385 L
s
.02381 .58418 m
.02756 .58418 L
s
.02381 .01492 m
.02756 .01492 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.03125 .07035 m
.03869 .10651 L
.04613 .12319 L
.05357 .1451 L
.06101 .14752 L
.06845 .15517 L
.07589 .16803 L
.08333 .1795 L
.09077 .17149 L
.09821 .1687 L
.10565 .17113 L
.1131 .17216 L
.12054 .17841 L
.12798 .18326 L
.13542 .18671 L
.14286 .19053 L
.1503 .25132 L
.15774 .29685 L
.16518 .32711 L
.17262 .36147 L
.18006 .38056 L
.1875 .40374 L
.19494 .431 L
.20238 .45718 L
.20982 .46809 L
.21726 .48309 L
.2247 .50218 L
.23214 .52017 L
.23958 .54225 L
.24702 .56324 L
.25446 .58313 L
.2619 .60332 L
.26935 .5173 L
.27679 .45974 L
.28423 .43063 L
.29167 .3939 L
.29911 .38563 L
.30655 .36974 L
.31399 .34621 L
.32143 .32473 L
.32887 .33171 L
.33631 .33106 L
.34375 .32279 L
.35119 .31656 L
.35863 .30271 L
.36607 .2909 L
.37351 .28113 L
.38095 .27082 L
.38839 .292 L
.39583 .30475 L
Mistroke
.40327 .30905 L
.41071 .31562 L
.41815 .31374 L
.4256 .31413 L
.43304 .31678 L
.44048 .31882 L
.44792 .31242 L
.45536 .30828 L
.4628 .30641 L
.47024 .30393 L
.47768 .30371 L
.48512 .30288 L
.49256 .30145 L
.5 .30018 L
.50744 .2811 L
.51488 .26679 L
.52232 .25726 L
.52976 .24644 L
.5372 .2404 L
.54464 .23308 L
.55208 .22448 L
.55952 .21622 L
.56696 .21274 L
.5744 .20797 L
.58185 .20193 L
.58929 .19623 L
.59673 .18925 L
.60417 .18262 L
.61161 .17632 L
.61905 .16994 L
.62649 .22198 L
.63393 .25837 L
.64137 .27911 L
.64881 .30403 L
.65625 .31331 L
.66369 .32677 L
.67113 .34443 L
.67857 .36097 L
.68601 .36185 L
.69345 .36693 L
.70089 .3762 L
.70833 .38435 L
.71577 .39669 L
.72321 .40791 L
.73065 .418 L
.7381 .4284 L
.74554 .40472 L
.75298 .39016 L
.76042 .38474 L
.76786 .37688 L
Mistroke
.7753 .37814 L
.78274 .37696 L
.79018 .37333 L
.79762 .37035 L
.80506 .37651 L
.8125 .38022 L
.81994 .38149 L
.82738 .38341 L
.83482 .38288 L
.84226 .38301 L
.8497 .38379 L
.85714 .3844 L
.86458 .32353 L
.87202 .27914 L
.87946 .25121 L
.8869 .21888 L
.89435 .20301 L
.90179 .18273 L
.90923 .15804 L
.91667 .13453 L
.92411 .1275 L
.93155 .11605 L
.93899 .10018 L
.94643 .0855 L
.95387 .0664 L
.96131 .04849 L
.96875 .03176 L
.97619 .01472 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00;Ioo`<000=o
o`03001oogoo00Uoo`<0009oo`03001oogoo00Moo`8000Aoo`03001oogoo00Uoo`03001oogoo009o
o`03001oogoo00Eoo`D0009oo`03001oogoo009oo`04001oogooOol5000017oo000000000goo00<0
07ooOol02goo002fOol00`00Oomoo`02Ool00`00Ool0000;Ool01P00Oomoo`00Ool000Qoo`03001o
o`00009oo`03001oo`0000Uoo`03001oo`00009oo`03001oo`0000Qoo`07001oogooOol007oo0000
0Woo00<007oo000017oo00D007ooOomoo`0000Aoo`03001oo`0000aoo`004Woo00<007ooOol00Woo
00@007ooOomoo`<009Uoo`07001oogooOol007oo00002Goo100000Aoo`00Ool000Qoo`03001oo`00
009oo`03001oo`0000Uoo`03001oo`00009oo`03001oo`0000Qoo`07001oogooOol007oo00000Woo
00<007oo000017oo00<007ooOol00Woo00L007ooOomoo`00Ool0000<Ool0015oo`03001oo`0000Mo
o`03001oogoo009oo`03001oogoo08Ioo`03001oogoo00]oo`07001oogooOol007oo00002Goo00<0
07oo00000Woo00<007oo000027oo0P000goo00<007oo00002Woo00L007ooOomoo`00Ool00008Ool0
1`00Oomoogoo001oo`00009oo`03001oo`0000Aoo`03001oogoo009oo`07001oogooOol007oo0000
37oo000<Ool30002Ool00`00Ool00008Ool01000Oomoogoo0P002Woo0`000goo00<007ooOol027oo
0`000Woo00<007ooOol01goo0P0017oo00<007ooOol027oo00<007ooOol00Woo00<007ooOol00goo
1@000Woo00<007ooOol00Woo00@007ooOomoo`D00004Ool000000003Ool00`00Oomoo`0ROol00`00
Oomoo`0:Ool00`00Ool00002Ool00`00Ool0000:Ool20002Ool00`00Ool00008Ool00`00Oomoo`02
Ool00`00Ool00009Ool00`00Ool00002Ool00`00Ool00008Ool01`00Oomoogoo001oo`00009oo`03
001oo`0000Aoo`07001oogooOol007oo00000Woo00<007oo000037oo000AOol00`00Ool00008Ool0
1@00Oomoogoo00002goo00<007ooOol00Woo00<007oo00002Woo00H007ooOol007oo0008Ool00`00
Ool00002Ool00`00Ool00008Ool00`00Ool00002Ool00`00Ool00006Ool01`00Oomoogoo001oo`00
009oo`03001oo`0000Aoo`05001oo`00Ool00004Ool00`00Ool0000SOol01000Oomoo`002Woo00<0
07ooOol00Woo00<007ooOol02Woo00D007ooOomoo`0000Yoo`8000=oo`03001oogoo00Uoo`03001o
ogoo009oo`03001oogoo00Ioo`8000Aoo`03001oogoo009oo`03001oogoo009oo`80009oo`03001o
o`0000Aoo`03001oogoo00]oo`004Goo00<007oo00001goo00<007oo00000Woo00<007ooOol02Woo
00L007ooOomoo`00Ool00008Ool4000017oo001oo`0027oo00<007oo00000Woo00<007oo000027oo
00<007oo00000Woo00<007oo00001Woo00L007ooOomoo`00Ool00002Ool00`00Ool00004Ool00`00
Ool00002Ool01`00Oomoogoo001oo`0002=oo`04001oo`000007Ool00`00Oomoo`1DOol00`00Oomo
o`03Ool00`00Ool0000<Ool0019oo`03001oogoo00Moo`05001oogooOol0000<Ool01`00Oomoogoo
001oo`0000Qoo`03001oo`00009oo`03001oo`0000Qoo`8000=oo`03001oo`0000Uoo`07001oogoo
Ool007oo00001Woo00L007ooOomoo`00Ool00002Ool00`00Ool00004Ool00`00Ool00002Ool01`00
Oomoogoo001oo`0002=oo`04001oo`000002Ool20002Ool00`00Ool0001EOol00`00Oomoo`02Ool0
1000Oomoo`0037oo000POol00`00Oomoo`09Ool00`00Ool00002Ool00`00Ool00009Ool20002Ool0
0`00Ool00008Ool00`00Oomoo`02Ool00`00Ool00008Ool00`00Ool00002Ool00`00Ool00006Ool0
1`00Oomoogoo001oo`00009oo`03001oo`0000Aoo`07001oo`00Ool007oo00000Woo00<007oo0000
8goo10000Woo0P000Woo00@007oo000005=oo`<000=oo`04001oogoo000<Ool0021oo`03001oogoo
00Yoo`03001oogoo009oo`03001oogoo00Uoo`05001oogooOol0000:Ool20003Ool00`00Oomoo`08
Ool00`00Oomoo`02Ool00`00Oomoo`04Ool20004Ool00`00Oomoo`02Ool00`00Oomoo`02Ool20000
1Goo000007oo000017oo00<007ooOol07gooLP0027oo000POol00`00Oomoo`1IOol2000[Ool20002
Ool20002Ool20003Ool01@00Oomoogoo000047oo00<007ooOol03Goo00<007ooOol03Woo00<007oo
Ool03Woo00<007ooOol02Goo0`000Woo00<007ooOol00goo00<007ooOol02Goo000POol00`00Oomo
o`1IOol20004Ool2000UOol01000Oomoogoo0P000Woo0P000goo00<007ooOol0Cgoo00@007oo0000
00Qoo`03001oogoo00Uoo`0087oo00@007oo000005Qoo`80009oo`800003Ool007oo02Aoo`04001o
ogooOol20002Ool00`00Oomoo`02Ool00`00Oomoo`1?Ool01000Oomoo`0027oo0P002Woo000MOom/
000POol00`00Oomoo`0:Ool00`00Oomoo`1?Ool00`00Oomoo`0EOol0021oo`05001oogooOol00003
Ool01@00Ool007oo00000goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo
00000goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007oo
Oomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00H007ooOomoo`00Ool30002
Ool01@00Ool007oo00008Goo00<007ooOol02Woo00<007ooOol0Cgoo00<007ooOol05Goo000POol0
0`00Oomoo`07Ool00`00Oomoo`1?Ool00`00Ool00007Ool00`00Oomoo`0POol00`00Oomoo`0:Ool0
0`00Oomoo`1?Ool00`00Oomoo`0EOol0021oo`03001oogoo00Qoo`03001oogoo04ioo`03001oogoo
02Yoo`03001oogoo00Yoo`03001oogoo04moo`03001oogoo01Eoo`0087oo00<007ooOol02Goo00<0
07ooOol0C7oo00<007ooOol0:goo00<007ooOol02Woo00<007ooOol0Cgoo00<007ooOol05Goo000P
Ool00`00Oomoo`0:Ool00`00Oomoo`1;Ool00`00Oomoo`0[Ool00`00Oomoo`0:Ool00`00Oomoo`1?
Ool00`00Oomoo`0EOol0021oo`03001oogoo00Yoo`03001oogoo04]oo`03001oogoo01aoo`03001o
ogoo009oo`04001oogooOol30003Ool00`00Oomoo`0:Ool00`00Oomoo`0cOol00`00Oomoo`0IOol0
0`00Oomoo`0EOol0019oo`03001oogoo009oo`04001oogooOol30002Ool00`00Oomoo`0:Ool00`00
Oomoo`1;Ool00`00Oomoo`0KOol00`00Ool00007Ool00`00Oomoo`03Ool00`00Oomoo`0:Ool00`00
Oomoo`0cOol2000JOol00`00Oomoo`0EOol0015oo`03001oo`0000Moo`03001oogoo009oo`03001o
ogoo00Yoo`03001oogoo04]oo`03001oogoo01]oo`03001oo`0000Qoo`03001oogoo009oo`8000]o
o`03001oogoo02Yoo`03001oo`0000Ioo`8000=oo`03001oogoo01Aoo`03001oogoo01Eoo`004Goo
00<007oo000027oo00@007ooOomoo`8000]oo`03001oogoo04]oo`03001oogoo01]oo`03001oo`00
00Qoo`03001oogoo009oo`03001oogoo00Yoo`03001oogoo02Moo`05001oogoo001oo`03000017oo
001oogoo0P000goo00<007ooOol057oo00<007ooOol05Goo000AOol00`00Ool00008Ool01@00Oomo
ogoo000037oo00<007ooOol09Woo00<007ooOol08Woo00<007ooOol06goo00<007oo00001goo00<0
07oo00000goo00<007ooOol02Woo00<007ooOol09goo00<007ooOol01@0000Aoo`00Ool0009oo`04
001oogoo000FOol00`00Oomoo`0EOol0015oo`03001oo`0000Moo`03001oo`00009oo`03001oogoo
00Yoo`03001oogoo02Eoo`03001oo`00008000Aoo`<001Yoo`03001oogoo01aoo`03001oogoo00Mo
o`03001oogoo009oo`03001oogoo00Yoo`03001oogoo02Moo`<00009Ool00000Ool007oo001oo`00
009oo`05001oo`00Ool0000EOol00`00Oomoo`0EOol0019oo`03001oogoo00Moo`05001oogooOol0
000<Ool00`00Oomoo`0UOol01@00Oomoo`00Ool010000Woo00<007ooOol05goo00<007ooOol0;7oo
00<007ooOol02Woo00<007ooOol09goo0`0000=oo`0000000Woo00@007oo0000009oo`04001oo`00
Ool2000DOol00`00Oomoo`0EOol0021oo`03001oogoo00Yoo`03001oogoo02Eoo`03001oogoo00Ao
o`03001oogoo009oo`8001Moo`03001oogoo02aoo`03001oogoo00Yoo`03001oogoo02Moo`<0009o
o`05001oogoo001oo`020002Ool01000Ool007oo0P0057oo00<007ooOol05Goo000POol00`00Oomo
o`0:Ool00`00Oomoo`0UOol00`00Oomoo`0;Ool2000EOol00`00Oomoo`0/Ool00`00Oomoo`0:Ool0
0`00Oomoo`0WOol00`00Ool00005Ool01000Ool000000goo0P000Woo00<007ooOol04Woo00<007oo
Ool05Goo000POol00`00Oomoo`0:Ool00`00Oomoo`0UOol00`00Oomoo`0=Ool2000COol00`00Oomo
o`0/Ool00`00Oomoo`0:Ool00`00Oomoo`0WOol00`00Oomoo`05Ool00`00Oomoo`04Ool20002Ool0
0`00Oomoo`0BOol00`00Oomoo`0EOol0019oo`03001oogoo009oo`03001oogoo009oo`<00003Ool0
07oo00]oo`03001oogoo00eoo`03001oogoo01Aoo`03001oogoo00moo`03001oogoo015oo`03001o
ogoo02aoo`03001oogoo00Yoo`03001oogoo02Moo`03001oogoo011oo`03001oogoo019oo`03001o
ogoo01Eoo`004Goo00<007oo00002Goo00@007ooOol000aoo`03001oogoo00eoo`03001oogoo01Ao
o`03001oogoo00moo`03001oogoo015oo`03001oogoo02aoo`03001oogoo00Yoo`03001oogoo02Mo
o`03001oogoo011oo`03001oogoo019oo`03001oogoo01Eoo`004Goo00<007oo00001goo100000=o
o`0000002goo00<007ooOol03Goo00<007ooOol057oo00<007ooOol03goo00<007ooOol04Goo00<0
07ooOol07Goo00<007ooOol00Woo00<007ooOol00Woo0`000Woo00<007ooOol02Woo00<007ooOol0
9goo00<007ooOol047oo00<007ooOol04Woo00<007ooOol05Goo000AOol00`00Ool00007Ool00`00
Ool00002Ool00`00Oomoo`0:Ool00`00Oomoo`0<Ool2000EOol00`00Oomoo`0@Ool00`00Oomoo`0A
Ool00`00Oomoo`0LOol00`00Ool00009Ool01@00Oomoogoo000037oo00<007ooOol09Woo00<007oo
Ool04Goo00<007ooOol04Woo00<007ooOol05Goo000AOol00`00Ool00008Ool20002Ool00`00Oomo
o`0:Ool00`00Oomoo`0<Ool2000EOol00`00Oomoo`0AOol00`00Oomoo`0@Ool00`00Oomoo`0LOol0
0`00Ool00007Ool40002Ool2000;Ool00`00Oomoo`0VOol00`00Oomoo`0AOol00`00Oomoo`0BOol0
0`00Oomoo`0EOol0019oo`03001oogoo00Qoo`04001oogoo000<Ool00`00Oomoo`0<Ool2000COol2
000DOol00`00Oomoo`0@Ool00`00Oomoo`0LOol00`00Ool00007Ool00`00Ool00003Ool00`00Oomo
o`0:Ool00`00Oomoo`0VOol00`00Oomoo`0AOol00`00Oomoo`0AOol00`00Oomoo`0FOol0021oo`03
001oogoo00Yoo`03001oogoo00aoo`8000Eoo`03001oogoo00Moo`05001oogooOol0000EOol00`00
Oomoo`0@Ool00`00Oomoo`0LOol00`00Ool00008Ool20003Ool00`00Oomoo`0:Ool00`00Oomoo`0=
Ool00`00Oomoo`0>Ool01@00Oomoogoo00000goo00<007ooOol04Goo00<007ooOol04Goo00<007oo
Ool05Woo000POol00`00Oomoo`0:Ool00`00Oomoo`0<Ool00`00Ool00002Ool200000goo001oo`05
Ool400000goo001oo`0EOol00`00Oomoo`0@Ool00`00Oomoo`0MOol00`00Oomoo`08Ool01@00Oomo
ogoo000037oo00<007ooOol03Goo0P002goo00@007ooOomoo`80009oo`800003Ool0000001=oo`03
001oogoo015oo`03001oogoo01Ioo`0087oo00<007ooOol02Woo00<007ooOol02goo00<007ooOol0
0`000goo0P000Woo0`0017oo0P005Woo00<007ooOol047oo00<007ooOol0;7oo00<007ooOol02Woo
00<007ooOol03Goo0P000goo0P001Woo00@007ooOomoo`80009oo`800003Ool0000001=oo`03001o
ogoo015oo`03001oogoo01Ioo`004Woo00<007ooOol00Woo00@007ooOomoo`8000=oo`03001oogoo
00Yoo`03001oogoo00]oo`03001oogoo00Moo`<001moo`03001oogoo00moo`03001oogoo02eoo`03
001oogoo00]oo`03001oogoo00]oo`03001oogoo00800004Ool007oo0005Ool01P00Oomoo`00Ool0
009oo`03001oo`0001Eoo`03001oogoo015oo`03001oogoo01Ioo`004Goo00<007oo00001goo00<0
07oo00000Woo00<007ooOol02Woo00<007ooOol02goo00<007ooOol0:Goo00<007ooOol03goo00<0
07ooOol0;Goo00<007ooOol02goo00<007ooOol02goo00<007ooOol00P0000Eoo`00Oomoo`0000=o
o`03001oo`0000800007Ool007ooOol007oo00005Goo00<007ooOol04Goo00<007ooOol05Woo000A
Ool00`00Ool00007Ool00`00Ool00002Ool2000;Ool00`00Oomoo`0;Ool00`00Oomoo`0YOol00`00
Oomoo`0?Ool00`00Oomoo`0]Ool00`00Oomoo`0;Ool00`00Oomoo`0;Ool01@00Oomoo`00Ool00P00
0goo00D007oo000007oo00<0009oo`03001oo`0001Moo`03001oogoo015oo`03001oogoo01Ioo`00
4Goo00<007oo00001goo0P000goo00<007ooOol02Woo00<007ooOol02goo00<007ooOol0:Goo00<0
07ooOol03goo00<007ooOol0;Goo00<007ooOol02goo00<007ooOol02goo00<007ooOol00Woo00<0
07ooOol00Woo100000=oo`0000000goo00<007oo000067oo00<007ooOol047oo00<007ooOol05Woo
000AOol00`00Ool00007Ool00`00Oomoo`02Ool00`00Oomoo`0:Ool00`00Oomoo`0;Ool00`00Oomo
o`0ZOol00`00Oomoo`0>Ool00`00Oomoo`0]Ool00`00Oomoo`0;Ool00`00Oomoo`0;Ool00`00Oomo
o`08Ool01000Oomoogoo0P000goo00<007oo000067oo00<007ooOol047oo00<007ooOol05Woo000B
Ool00`00Oomoo`07Ool20002Ool00`00Oomoo`0;Ool00`00Oomoo`09Ool00`00Oomoo`0[Ool00`00
Oomoo`0>Ool00`00Oomoo`0NOol00`00Oomoo`02Ool01000Oomoogoo0P0017oo00<007ooOol02goo
00<007ooOol02goo00<007ooOol027oo00<007ooOol01goo0P0067oo00<007ooOol047oo00<007oo
Ool05Woo000POol00`00Oomoo`0;Ool00`00Oomoo`09Ool00`00Oomoo`0[Ool00`00Oomoo`0>Ool0
0`00Oomoo`0MOol00`00Ool00007Ool00`00Ool00003Ool00`00Oomoo`0;Ool00`00Oomoo`0;Ool0
0`00Oomoo`0/Ool00`00Oomoo`0@Ool00`00Oomoo`0FOol0021oo`03001oogoo00]oo`03001oogoo
00Uoo`03001oogoo02]oo`03001oogoo00eoo`8001moo`03001oo`0000Moo`03001oo`0000=oo`80
00aoo`03001oogoo00]oo`03001oogoo02aoo`03001oogoo011oo`03001oogoo01Ioo`0087oo00<0
07ooOol02goo00<007ooOol02Goo00<007ooOol0:goo00D007ooOomoo`0000Eoo`8000=oo`80021o
o`03001oo`0000Moo`8000Aoo`03001oogoo00]oo`03001oogoo00]oo`03001oogoo02aoo`03001o
ogoo011oo`03001oogoo01Ioo`0087oo00<007ooOol02goo00<007ooOol02Goo00<007ooOol0:goo
00<007ooOol01`000Woo0`008Woo00<007oo00001goo00<007ooOol00goo00<007ooOol02goo00<0
07ooOol02goo00<007ooOol0;7oo00<007ooOol047oo00<007ooOol05Woo000BOol00`00Oomoo`02
Ool00`00Oomoo`02Ool01@00Oomoogoo00003Goo00<007ooOol02Goo00<007ooOol0:goo00@007oo
Ool002ioo`03001oogoo00Moo`8000=oo`03001oogoo00]oo`03001oogoo00]oo`03001oogoo02ao
o`03001oogoo011oo`03001oogoo01Ioo`004Goo00<007oo00001goo00<007oo00000Woo00<007oo
Ool02goo00<007ooOol02Goo00<007ooOol0:goo00<007oo0000?Woo00<007ooOol02goo00<007oo
Ool02goo00<007ooOol0;7oo00<007ooOol047oo00<007ooOol05Woo000AOol00`00Ool00007Ool0
0`00Ool00002Ool2000<Ool00`00Oomoo`09Ool00`00Oomoo`0[Ool00`00Ool0000nOol00`00Oomo
o`0;Ool00`00Oomoo`0;Ool00`00Oomoo`0/Ool00`00Oomoo`0@Ool00`00Oomoo`0FOol0015oo`03
001oo`0000Qoo`05001oogooOol0000=Ool00`00Oomoo`09Ool00`00Oomoo`0[Ool00`00Ool0000n
Ool00`00Oomoo`0;Ool00`00Oomoo`0;Ool00`00Oomoo`0/Ool01000Oomoogoo0P003Goo00<007oo
Ool05Woo000AOol00`00Ool00007Ool00`00Ool00002Ool00`00Oomoo`0;Ool00`00Oomoo`08Ool0
0`00Oomoo`0/Ool00`00Ool0000nOol00`00Oomoo`0;Ool00`00Oomoo`0;Ool00`00Oomoo`0/Ool0
1000Oomoogoo0P0000Eoo`00000007oo008000=oo`04001oogoo000HOol0019oo`03001oogoo00Mo
o`05001oogooOol0000=Ool00`00Oomoo`08Ool00`00Oomoo`0]Ool00`00Oomoo`0mOol00`00Oomo
o`0;Ool00`00Oomoo`0;Ool00`00Oomoo`0/Ool01P00Oomoogoo001oo`<00003Ool007oo00800006
Ool007oo001oo`0067oo000POol00`00Oomoo`0<Ool00`00Oomoo`07Ool00`00Oomoo`0]Ool00`00
Oomoo`0^Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`0;Ool00`00
Oomoo`0;Ool00`00Oomoo`0/Ool01000Oomoo`000Woo0`001Goo00H007ooOol007oo000HOol0021o
o`03001oogoo00aoo`03001oogoo00Moo`03001oogoo02eoo`03001oogoo02eoo`03001oo`0000Mo
o`03001oo`0000=oo`03001oogoo00]oo`03001oogoo00Yoo`03001oogoo02eoo`04001oogoo0003
Ool00`00Oomoo`08Ool2000HOol0021oo`03001oogoo00aoo`03001oogoo00Moo`03001oogoo02eo
o`03001oogoo02eoo`03001oo`0000Moo`03001oo`0000=oo`8000aoo`03001oogoo00Yoo`03001o
ogoo02eoo`04001oo`000003Ool00`00Oomoo`08Ool2000HOol001Yoo`D00003Ool007oo00eoo`03
001oo`0000Eoo`<005moo`03001oo`0000Qoo`03001oogoo009oo`03001oogoo00]oo`03001oogoo
00Yoo`03001oogoo02eoo`8000Eoo`03001oogoo029oo`0077oo00D007ooOomoo`0000ioo`04001o
o`000002Ool2001ROol00`00Ool00007Ool00`00Ool00003Ool00`00Oomoo`0;Ool00`00Oomoo`0:
Ool00`00Oomoo`0^Ool00`00Oomoo`0XOol001aoo`04001oogooOol2000=Ool01P00Ool00000Ool0
06Eoo`03001oogoo00Moo`03001oogoo009oo`03001oogoo00]oo`03001oogoo00Yoo`03001oogoo
05Uoo`0077oo00D007ooOomoo`0000ioo`05001oo`00Ool0001eOol00`00Oomoo`0;Ool00`00Oomo
o`0:Ool00`00Oomoo`1IOol001aoo`05001oogooOol0000>Ool00`00Ool0001gOol00`00Oomoo`0;
Ool00`00Oomoo`0:Ool00`00Oomoo`1IOol001]oo`8000=oo`03001oogoo00aoo`03001oo`0007Mo
o`03001oogoo00]oo`03001oogoo00Yoo`03001oogoo05Uoo`0087oo00<007ooOol03Goo0P00Mgoo
00<007ooOol02goo00<007ooOol02Woo00<007ooOol0FGoo000POol00`00Oomoo`0=Ool00`00Oomo
o`1fOol00`00Oomoo`0;Ool00`00Oomoo`04Ool00`00Oomoo`03Ool00`00Oomoo`1IOol0021oo`03
001oogoo00eoo`03001oogoo07Ioo`03001oogoo00]oo`800003Ool007oo009oo`04001oo`000002
Ool00`00Oomoo`1IOol0011oo`D0009oo`04001oogooOol30002Ool00`00Oomoo`0=Ool00`00Oomo
o`1_Ool50002Ool00`00Oomoo`0;Ool01000Ool000000goo10000Woo00<007ooOol0FGoo000BOol0
0`00Oomoo`06Ool00`00Oomoo`02Ool00`00Oomoo`0=Ool00`00Oomoo`1aOol00`00Oomoo`02Ool0
0`00Oomoo`0?Ool00`00Oomoo`0500000goo001oo`1JOol0019oo`03001oogoo00Moo`04001oogoo
Ool2000>Ool00`00Oomoo`1aOol00`00Oomoo`02Ool2000@Ool01000Ool007oo0P0000Aoo`00Ool0
05]oo`004Woo00<007ooOol01goo00D007ooOomoo`0008=oo`03001oogoo009oo`03001oogoo00mo
o`<0009oo`05001oo`00Ool0001KOol0019oo`03001oogoo00Ioo`03001oo`0008Ioo`03001oogoo
009oo`03001oogoo011oo`80009oo`04001oogoo001LOol0015oo`8000Uoo`03001oogoo08Aoo`80
00Aoo`03001oogoo015oo`04001oogoo0002Ool00`00Oomoo`1JOol00:Uoo`03001oogoo015oo`03
001oogoo061oo`00ZGoo00<007ooOol0M7oo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol0
0?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo
8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00:moo`03001oogoo06ioo`00;7oo0`00
0goo00<007ooOol027oo0`000Woo00<007ooOol01goo0P0017oo00<007ooOol027oo00<007ooOol0
0Woo00<007ooOol00goo1@000Woo00<007ooOol00Woo00@007ooOomoo`D00004Ool000000003Ool0
0`00Oomoo`0XOol00`00Oomoo`1^Ool0021oo`03001oogoo00Uoo`03001oogoo009oo`03001oo`00
00Yoo`06001oogoo001oo`0027oo00<007oo00000Woo00<007oo000027oo00<007oo00000Woo00<0
07oo00001Woo00L007ooOomoo`00Ool00002Ool00`00Ool00004Ool01@00Oomoogoo000017oo00<0
07oo00006Woo00<007ooOol00Woo00@007ooOomoo`<000=oo`03001oogoo06=oo`03001oogoo00Qo
o`0087oo00<007ooOol02Woo00L007ooOomoo`00Ool00008Ool4000017oo001oo`0027oo00<007oo
00000Woo00<007oo000027oo00<007oo00000Woo00<007oo00001Woo00L007ooOomoo`00Ool00002
Ool00`00Ool00004Ool00`00Oomoo`02Ool01`00Oomoogoo001oo`0001Uoo`03001oo`0000Moo`03
001oogoo00=oo`03001oogoo00Uoo`<000=oo`03001oogoo00Qoo`<0009oo`03001oogoo00Moo`80
00Aoo`03001oogoo00Moo`03001oogoo009oo`03001oogoo00Aoo`D0009oo`03001oogoo009oo`04
001oogooOol5000017oo000000000goo0P002goo000POol00`00Oomoo`0:Ool01`00Oomoogoo001o
o`0000Qoo`03001oo`00009oo`03001oo`0000Qoo`8000=oo`03001oo`0000Uoo`07001oogooOol0
07oo00001Woo00L007ooOomoo`00Ool00002Ool00`00Ool00004Ool00`00Oomoo`02Ool01P00Oomo
ogoo001oo`8001=oo`<0009oo`03001oo`0000Qoo`03001oogoo009oo`03001oogoo00Uoo`03001o
ogoo009oo`03001oo`0000Yoo`06001oogoo001oo`0027oo00<007oo00000Woo00<007oo00001goo
00<007oo00000Woo00<007oo00001goo00L007ooOomoo`00Ool00002Ool00`00Ool00004Ool01@00
Oomoogoo000017oo0`002goo000POol00`00Oomoo`09Ool00`00Ool00002Ool00`00Ool00009Ool2
0002Ool00`00Ool00008Ool00`00Oomoo`02Ool00`00Ool00008Ool00`00Ool00002Ool00`00Ool0
0006Ool01`00Oomoogoo001oo`00009oo`03001oo`0000Aoo`07001oogooOol007oo00000Woo0`00
6Goo00<007oo000027oo00<007ooOol00Woo00<007ooOol02Woo00L007ooOomoo`00Ool00008Ool4
000017oo001oo`0027oo00<007oo00000Woo00<007oo00001goo00<007oo00000Woo00<007oo0000
1goo00L007ooOomoo`00Ool00002Ool00`00Ool00004Ool00`00Oomoo`02Ool01000Oomoogoo0`00
2goo000POol00`00Oomoo`0:Ool00`00Oomoo`02Ool00`00Oomoo`09Ool01@00Oomoogoo00002Woo
0P000goo00<007ooOol027oo00<007ooOol00Woo00<007ooOol017oo0P0017oo00<007ooOol00Woo
00<007ooOol00Woo0P0017oo00<007ooOol00`006Woo00<007oo00001goo00<007oo00000goo00<0
07ooOol02Woo00L007ooOomoo`00Ool00008Ool00`00Ool00002Ool00`00Ool00008Ool20003Ool0
0`00Ool00008Ool01`00Oomoogoo001oo`0000Moo`07001oogooOol007oo00000Woo00<007oo0000
17oo00<007ooOol00Woo00L007ooOomoo`00Ool0000;Ool0021oo`03001oogoo05eoo`8001ioo`03
001oogoo00Moo`03001oogoo009oo`8000Yoo`03001oo`00009oo`03001oo`0000Uoo`80009oo`03
001oo`0000Qoo`03001oogoo009oo`03001oo`0000Moo`03001oo`00009oo`03001oo`0000Moo`07
001oogooOol007oo00000Woo00<007oo000017oo00L007ooOomoo`00Ool00002Ool00`00Ool0000;
Ool0021oo`03001oogoo05eoo`03001oogoo02aoo`8000]oo`03001oogoo009oo`03001oogoo00Uo
o`05001oogooOol0000:Ool20003Ool00`00Oomoo`07Ool00`00Oomoo`02Ool00`00Oomoo`05Ool2
0004Ool00`00Oomoo`02Ool00`00Oomoo`02Ool20004Ool01P00Oomoo`00Ool000aoo`0087oo00<0
07ooOol0Fgoo0P00;goo0P00H7oo00<007ooOol037oo000POol2001JOol2000aOol2001POol00`00
Oomoo`0<Ool001eoof`002Ioo`80061oo`03001oogoo00aoo`0087oo0P00FGoo00<007ooOol0;Woo
K00027oo000POol00`00Ool0001GOol00`00Oomoo`0bOol01@00Ool007oo00000goo00D007ooOomo
o`0000=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001o
ogooOol00003Ool01@00Oomoogoo00000goo00@007ooOol000=oo`05001oogooOol00003Ool01@00
Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool20002Ool01@00Oomoogoo
00002Goo000POol00`00Ool0001EOol2000eOol01000Oomoo`00Fgoo0P0047oo000POol00`00Ool0
001COol2000gOol01000Oomoo`00Fgoo00<007ooOol03goo000POol00`00Ool0001AOol2000iOol0
1@00Oomoogoo0000FWoo00<007ooOol03goo000=Ool00`00Oomoo`02Ool01000Oomoogoo0P0017oo
00L007ooOomoo`00Ool00019Ool00`00Oomoo`04Ool2000jOol00`00Oomoo`02Ool00`00Oomoo`1G
Ool00`00Oomoo`0?Ool000aoo`03001oo`0000Uoo`06001oogoo001oo`000Woo00<007oo0000BGoo
0P0000=oo`0000000P00?7oo00<007ooOol00Woo00<007oo00000P00=Goo00<007ooOol07Goo00<0
07ooOol03goo000<Ool00`00Ool00008Ool00`00Oomoo`03Ool00`00Oomoo`030018Ool01P00Oomo
o`00Ool002moo`03001oogoo009oo`04001oogooOol30003Ool00`00Oomoo`03Ool01@00Oomoogoo
0000<goo0P007Woo00<007ooOol047oo000<Ool00`00Ool00009Ool00`00Oomoo`020003Ool01000
Oomoo`00AWoo00<007ooOol0<Woo00<007oo00001goo00<007ooOol00goo00<007ooOol027oo0`00
;goo00<007oo00007Woo00<007ooOol047oo000<Ool00`00Ool00007Ool00`00Ool00002Ool00`00
Oomoo`02Ool01000Oomoo`00AGoo00<007ooOol0<goo00<007oo000027oo00<007ooOol00Woo00<0
07ooOol02Woo00<007ooOol0;7oo00D007ooOomoo`0001aoo`03001oogoo015oo`003Goo00<007oo
Ool01goo00@007ooOomoo`<0009oo`04001oogoo0014Ool00`00Oomoo`0dOol00`00Ool00008Ool0
0`00Oomoo`02Ool00`00Oomoo`0:Ool00`00Oomoo`0[Ool00`00Oomoo`02Ool00`00Oomoo`0JOol0
0`00Oomoo`0AOol0021oo`05001oogooOol00013Ool00`00Oomoo`0dOol00`00Ool00007Ool00`00
Ool00003Ool00`00Oomoo`0:Ool00`00Oomoo`0YOol20005Ool00`00Oomoo`0IOol00`00Oomoo`0B
Ool0021oo`03001oogoo009oo`03001oogoo03moo`03001oogoo03Ioo`03001oogoo00Moo`03001o
ogoo009oo`03001oogoo00Yoo`03001oogoo02Qoo`03001oogoo00Eoo`03001oogoo01Uoo`03001o
ogoo019oo`0087oo00<007ooOol00Woo00<007ooOol0?Woo00<007ooOol0AWoo00<007ooOol02Woo
00<007ooOol0:7oo00<007ooOol01Goo00<007ooOol067oo00<007ooOol04goo000BOol00`00Oomo
o`02Ool00`00Oomoo`02Ool300000goo001oo`04Ool00`00Oomoo`0lOol20018Ool00`00Oomoo`0:
Ool00`00Oomoo`0VOol20009Ool00`00Oomoo`0GOol00`00Oomoo`0COol0015oo`03001oo`0000Uo
o`04001oogoo0005Ool00`00Oomoo`0kOol00`00Oomoo`18Ool00`00Oomoo`0:Ool00`00Oomoo`0U
Ool00`00Oomoo`09Ool00`00Oomoo`0GOol00`00Oomoo`0COol0015oo`03001oo`0000Moo`@00003
Ool0000000Aoo`03001oogoo03]oo`03001oogoo03Uoo`03001oogoo009oo`03001oogoo009oo`<0
009oo`03001oogoo00Yoo`03001oogoo02Aoo`03001oogoo00Yoo`03001oogoo01Moo`03001oogoo
01=oo`004Goo00<007oo00001goo00<007oo00000Woo00<007ooOol00goo00<007ooOol0>Goo0P00
>goo00<007oo00002Goo00D007ooOomoo`0000aoo`03001oogoo01Ioo`03001oogoo00]oo`03001o
ogoo00]oo`03001oogoo01Ioo`03001oogoo01=oo`004Goo00<007oo000027oo0P000Woo00<007oo
Ool00goo0P00>7oo0P00?Goo00<007oo00001goo10000Woo00<007ooOol02goo00<007ooOol057oo
00<007oo000037oo00<007ooOol02goo00<007ooOol05Woo00<007ooOol04goo000BOol00`00Oomo
o`08Ool01000Oomoo`001goo00<007ooOol0=7oo00<007ooOol0?Goo00<007oo00001goo00<007oo
00000goo00<007ooOol02goo00<007ooOol04goo00@007ooOol000]oo`03001oogoo00eoo`03001o
ogoo01Eoo`03001oogoo01=oo`0087oo00<007ooOol01Woo00<007ooOol0<Woo00<007ooOol0?Woo
00<007oo000027oo0P000goo00<007ooOol02goo00<007ooOol04goo00D007ooOomoo`0000Moo`@0
00moo`03001oogoo01Eoo`03001oogoo01=oo`0087oo00<007ooOol01goo00<007ooOol0<Goo00<0
07ooOol0?goo00<007ooOol027oo00D007ooOomoo`0000eoo`03001oogoo019oo`03001oogoo009o
o`03001oogoo009oo`<001=oo`03001oogoo01Aoo`03001oogoo01Aoo`0087oo00<007ooOol01goo
00<007ooOol0<7oo00<007ooOol0Cgoo00<007ooOol037oo00<007ooOol047oo0P001Goo10005goo
00<007ooOol04goo00<007ooOol057oo000=Ool00`00Oomoo`02Ool00`00Oomoo`02Ool30002Ool0
1@00Oomoogoo00002Goo00<007ooOol0<7oo00<007ooOol0Cgoo00<007ooOol037oo00<007ooOol0
3Woo0P008Woo00<007ooOol04goo00<007ooOol057oo000<Ool00`00Ool00009Ool01P00Oomoo`00
Ool0009oo`03001oogoo00Qoo`03001oogoo02ioo`03001oogoo051oo`03001oogoo00aoo`03001o
ogoo00eoo`03001oogoo02=oo`03001oogoo019oo`03001oogoo01Aoo`0037oo00<007oo00001goo
10000goo00<007ooOol00P002Goo00<007ooOol0;Woo00<007ooOol0@Goo00<007ooOol00Woo00@0
07ooOomoo`8000Aoo`03001oogoo00eoo`03001oogoo00aoo`03001oogoo02=oo`03001oogoo019o
o`03001oogoo01Aoo`0037oo00<007oo00001goo00<007oo00000Woo0P000goo00<007ooOol02Goo
00<007ooOol0;Goo00<007ooOol0@7oo00<007oo00001goo00<007oo00000goo00<007ooOol03Goo
00<007ooOol037oo00<007ooOol097oo00<007ooOol047oo00<007ooOol05Goo000<Ool00`00Ool0
0008Ool20002Ool00`00Oomoo`02Ool00`00Oomoo`09Ool00`00Oomoo`0/Ool00`00Oomoo`11Ool0
0`00Ool00007Ool00`00Ool00003Ool00`00Oomoo`0=Ool00`00Oomoo`0;Ool00`00Oomoo`0UOol2
000AOol00`00Oomoo`0EOol000eoo`03001oogoo00Qoo`03001oogoo00<0009oo`03001oogoo00Yo
o`8002Yoo`8004Aoo`03001oo`0000Moo`8000Aoo`03001oogoo00eoo`03001oogoo00]oo`03001o
ogoo02Moo`03001oogoo00Aoo`D000Eoo`03001oogoo01Eoo`0087oo00<007ooOol037oo0P00:7oo
00<007ooOol0@goo00<007oo00001goo00<007ooOol00goo00<007ooOol03Goo00<007ooOol02Woo
00<007ooOol0:Goo00<007ooOol00goo00<007ooOol00Woo1P005goo000POol00`00Oomoo`0>Ool0
0`00Oomoo`0TOol00`00Oomoo`15Ool00`00Oomoo`07Ool20003Ool00`00Oomoo`0>Ool00`00Oomo
o`08Ool00`00Oomoo`0[Ool01@00Oomoogoo00008Woo000POol00`00Oomoo`0>Ool00`00Oomoo`0T
Ool00`00Oomoo`1DOol00`00Oomoo`0>Ool00`00Oomoo`08Ool00`00Oomoo`0/Ool00`00Ool0000S
Ool0019oo`03001oogoo009oo`03001oogoo009oo`05001oogooOol0000AOol2000TOol00`00Oomo
o`1DOol00`00Oomoo`0>Ool00`00Oomoo`08Ool00`00Oomoo`0/Ool00`00Ool0000SOol0015oo`03
001oo`0000Moo`03001oo`00009oo`03001oogoo015oo`03001oogoo025oo`03001oogoo04Eoo`03
001oogoo009oo`03001oogoo009oo`03001oogoo009oo`03001oogoo00moo`03001oogoo00Moo`03
001oogoo02aoo`8002Aoo`004Goo00<007oo00002Goo00<007ooOol00P004Woo00<007ooOol087oo
00<007ooOol0AGoo00<007oo00001goo00<007oo00000goo00<007ooOol03goo00<007ooOol01goo
00<007ooOol0;Goo00<007ooOol08Woo000AOol00`00Ool00007Ool20003Ool00`00Oomoo`0BOol0
0`00Oomoo`0OOol00`00Oomoo`15Ool00`00Ool00007Ool00`00Ool00003Ool00`00Oomoo`0?Ool0
0`00Oomoo`07Ool00`00Oomoo`1BOol0015oo`03001oo`0000Moo`03001oogoo009oo`03001oogoo
019oo`03001oogoo01ioo`03001oogoo04Ioo`03001oo`0000Qoo`03001oogoo009oo`03001oogoo
011oo`03001oogoo00Eoo`03001oogoo05=oo`004Woo00<007ooOol01Woo0`000Woo00<007ooOol0
4goo00<007ooOol07Goo00<007ooOol0AWoo00<007oo00001goo00<007oo00000goo00<007ooOol0
47oo00<007ooOol01Goo00<007ooOol0Dgoo000POol00`00Oomoo`0DOol00`00Oomoo`0KOol00`00
Oomoo`18Ool00`00Oomoo`07Ool00`00Oomoo`02Ool00`00Oomoo`0AOol00`00Oomoo`04Ool00`00
Oomoo`1COol0021oo`03001oogoo01Eoo`06001oogoo001oo`005goo00<007ooOol0Egoo00<007oo
Ool04Goo00<007ooOol017oo00<007ooOol0Dgoo000=Ool00`00Oomoo`02Ool00`00Oomoo`02Ool0
0`00Oomoo`02Ool01@00Oomoogoo000067oo0P0000=oo`0000000P005Goo00<007ooOol0Egoo00<0
07ooOol04Goo00<007ooOol00goo00<007ooOol0E7oo000<Ool00`00Ool00007Ool00`00Ool00002
Ool00`00Ool00002Ool00`00Oomoo`0FOol00`00Oomoo`04Ool2000COol00`00Oomoo`1GOol00`00
Oomoo`0BOol00`00Oomoo`02Ool00`00Oomoo`1DOol000aoo`03001oo`0000Uoo`03001oogoo009o
o`03001oogoo008001moo`80019oo`03001oogoo051oo`D0009oo`03001oogoo019oo`03001oogoo
009oo`03001oogoo05Aoo`0037oo00<007oo00001goo0P000goo0P000goo00<007ooOol087oo0P00
47oo00<007ooOol0DWoo00<007ooOol00Woo00<007ooOol04goo00D007ooOomoo`0005Ioo`0037oo
00<007oo00001goo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol08Woo0P003Woo00<007oo
Ool0DWoo00<007ooOol00Woo00<007ooOol04goo00D007ooOomoo`0005Ioo`003Goo00<007ooOol0
1Woo0`000Woo0`000Woo00<007ooOol097oo00<007ooOol02goo00<007ooOol0DWoo00<007ooOol0
0Woo00<007ooOol057oo00@007ooOol005Ioo`0087oo00<007ooOol09Goo00<007ooOol02Goo00<0
07ooOol0Dgoo00<007ooOol00Woo00<007ooOol057oo00@007ooOol005Ioo`0087oo00<007ooOol0
9Woo00<007ooOol027oo00<007ooOol0DWoo0P0017oo00<007ooOol05Goo00<007oo0000EWoo000P
Ool00`00Oomoo`0VOol20009Ool00`00Oomoo`1HOol00`00Oomoo`0EOol2001GOol0019oo`03001o
ogoo009oo`04001oogooOol20003Ool00`00Oomoo`0XOol20007Ool00`00Oomoo`1HOol00`00Oomo
o`0EOol2001GOol0015oo`03001oo`0000Moo`03001oo`00009oo`03001oogoo02Yoo`03001oogoo
00Aoo`03001oogoo05Qoo`03001oogoo01Eoo`8005Moo`004Goo00<007oo00001goo00<007oo0000
0Woo0P00:goo0P0017oo00<007ooOol0B7oo1@000Woo00@007ooOomoo`<000=oo`03001oogoo01Eo
o`8005Moo`004Goo00<007oo00001goo0P000goo00<007ooOol0;7oo0P000Woo00<007ooOol0BWoo
00<007ooOol01Woo00<007ooOol00goo00<007ooOol05Woo00<007ooOol0EGoo000AOol00`00Ool0
0007Ool00`00Oomoo`02Ool00`00Oomoo`0^Ool00`00Ool0001<Ool00`00Oomoo`07Ool00`00Oomo
o`02Ool00`00Oomoo`0FOol00`00Oomoo`1EOol0019oo`03001oogoo00Moo`80009oo`03001oogoo
02moo`8004aoo`03001oogoo00Moo`03001oogoo009oo`03001oogoo06ioo`0087oo00<007ooOol0
OGoo00<007ooOol01Woo00<007oo0000M7oo000POol00`00Oomoo`1lOol20009Ool00`00Oomoo`1c
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.0526045, -0.0309082, 
  0.00733523, 0.00733523}, {{7.125, 137}, {172.688, 
  92.4375}} -> {-40.7756, -0.478839, 1.25607, 0.0220582}, {{149.938, 
  279.813}, {172.688, 92.4375}} -> {-201.151, -0.29525, 1.18776, 
  0.0168838}, {{7.125, 137}, {84.4375, 4.1875}} -> {-40.7756, -0.324851, 
  1.25607, 0.00572821}, {{149.938, 279.813}, {84.4375, 
  4.1875}} -> {-220.158, -2.5483, 1.25607, 0.0229844}}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["2D DISCRETE WAVELET TRANSFORM", "Section"],

Cell[CellGroupData[{

Cell["Introduction", "Subsection"],

Cell["\<\
As with other unitary transforms, we extend the one-dimensional \
representation by considering a separable basis signal. Specifically, in the \
case of the wavelet transform we define a 2D scaling function as a product of \
two 1D scaling functions:\
\>", "Text"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm
    \`\[Phi](x, \ y)\  = \ \(\[Phi](x)\)\ \ \(\[Phi](y)\)\)]]], 
  "NumberedEquation"],

Cell[TextData[{
  "If ",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi](x)\)]],
  " is the companion wavelet function of ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi](x)\)]],
  " then there are three two-dimensional basic wavelets: "
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm
      \`\(\[Psi]\_\(L, H\)\)(x, \ y)\  = \ 
        \(\[Phi](x)\)\ \ \(\[Psi](y)\)\)]],
  ",\t",
  Cell[BoxData[
      \(TraditionalForm
      \`\(\[Psi]\_\(H, L\)\)(x, \ y)\  = \ 
        \(\[Psi](x)\)\ \ \(\[Phi](y)\)\)]],
  ", \t",
  Cell[BoxData[
      \(TraditionalForm
      \`\(\[Psi]\_\(H, H\)\)(x, \ y)\  = \ \(\[Psi](x)\)\ \ \(\[Psi](y)\)\)]]
}], "NumberedEquation"],

Cell[TextData[{
  "The 2D scaling and wavelet functions are simply the outer products of the \
respective 1D sequences. Here are the 2D scaling and wavelet sequences based \
on ",
  Cell[BoxData[
      \(TraditionalForm\`D\_4\)]],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(D\_2 = DaubechiesFIR[2]\)], "Input"],

Cell[BoxData[
    \({0.482962913144534411`, 0.836516303737808186`, 0.224143868042013183`, 
      \(-0.129409522551260614`\)}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[Phi] = ScalingSequence[D\_2, 3]; \n\[Psi] = WaveletSequence[D\_2, 3]; 
    \nShow[GraphicsArray[
        Map[ListPlot3D[#1, PlotRange \[Rule] All, \ 
              DisplayFunction -> Identity]\ &, {{
              Outer[Times, \[Phi], \[Phi], 1], \ 
              Outer[Times, \[Phi], \[Psi], 1]}, {
              Outer[Times, \[Psi], \[Phi], 1], \ 
              Outer[Times, \[Psi], \[Psi], 1]}}, \ {2}]]]; \)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0193128 0.47619 [
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0193128 0.477324 0.387175 MathSubStart
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
5.55112e-017 1.04977 -0.0679587 1.04977 [
[.14021 .20185 -5.9739 -9 ]
[.14021 .20185 .0261 0 ]
[.28836 .14356 -11.3521 -9 ]
[.28836 .14356 .64789 0 ]
[.44535 .08183 -10.7564 -9 ]
[.44535 .08183 1.24358 0 ]
[.61199 .01634 -10.1607 -9 ]
[.61199 .01634 1.83927 0 ]
[.76442 .09239 0 -6.16638 ]
[.76442 .09239 6 2.83362 ]
[.83635 .20254 0 -6.06047 ]
[.83635 .20254 12 2.93953 ]
[.90119 .30183 0 -5.96721 ]
[.90119 .30183 12 3.03279 ]
[.95993 .39179 0 -5.88447 ]
[.95993 .39179 12 3.11553 ]
[.01952 .29389 -24 -2.76664 ]
[.01952 .29389 0 6.23336 ]
[.01207 .34056 -24 -2.80616 ]
[.01207 .34056 0 6.19384 ]
[.0044 .38865 -6 -2.84701 ]
[.0044 .38865 0 6.15299 ]
[-0.00351 .43823 -18 -2.88926 ]
[-0.00351 .43823 0 6.11074 ]
[-0.01167 .48937 -18 -2.93298 ]
[-0.01167 .48937 0 6.06702 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.03716 .25514 m
.68874 0 L
s
.14945 .21117 m
.15407 .21583 L
s
[(5)] .14021 .20185 .9913 1 Mshowa
.2971 .15335 m
.30147 .15825 L
s
[(10)] .28836 .14356 .89202 1 Mshowa
.4535 .09211 m
.45758 .09725 L
s
[(15)] .44535 .08183 .79274 1 Mshowa
.61947 .02712 m
.62321 .03251 L
s
[(20)] .61199 .01634 .69345 1 Mshowa
.125 Mabswid
.17832 .19986 m
.18106 .20269 L
s
.20751 .18843 m
.21022 .19129 L
s
.23703 .17687 m
.23971 .17975 L
s
.26689 .16518 m
.26954 .16809 L
s
.32765 .14139 m
.33024 .14436 L
s
.35857 .12928 m
.36112 .13228 L
s
.38984 .11704 m
.39236 .12006 L
s
.42148 .10465 m
.42397 .1077 L
s
.4859 .07942 m
.48831 .08254 L
s
.51869 .06658 m
.52106 .06973 L
s
.55188 .05359 m
.55421 .05676 L
s
.58547 .04044 m
.58776 .04364 L
s
.12091 .22234 m
.12371 .22511 L
s
.09268 .2334 m
.09551 .23614 L
s
.06477 .24433 m
.06762 .24704 L
s
.65389 .01364 m
.65609 .01691 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.75212 .09695 m
.74596 .09923 L
s
[(5)] .76442 .09239 -1 .37031 Mshowa
.82395 .20683 m
.81775 .20898 L
s
[(10)] .83635 .20254 -1 .34677 Mshowa
.88871 .30589 m
.88247 .30793 L
s
[(15)] .90119 .30183 -1 .32605 Mshowa
.94739 .39565 m
.94112 .39758 L
s
[(20)] .95993 .39179 -1 .30766 Mshowa
.125 Mabswid
.76711 .11988 m
.76341 .12123 L
s
.78177 .14231 m
.77807 .14365 L
s
.79613 .16428 m
.79242 .1656 L
s
.81019 .18578 m
.80647 .18708 L
s
.83744 .22746 m
.83371 .22873 L
s
.85065 .24767 m
.84692 .24893 L
s
.86359 .26746 m
.85986 .26871 L
s
.87628 .28687 m
.87254 .2881 L
s
.90091 .32455 m
.89716 .32575 L
s
.91286 .34284 m
.90911 .34403 L
s
.92459 .36078 m
.92084 .36196 L
s
.9361 .37838 m
.93234 .37955 L
s
.7368 .07352 m
.73311 .0749 L
s
.72113 .04956 m
.71746 .05096 L
s
.70512 .02506 m
.70145 .02648 L
s
.95847 .4126 m
.9547 .41375 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03177 .28918 m
.03789 .28682 L
s
[(-0.2)] .01952 .29389 1 -0.38519 Mshowa
.02436 .33594 m
.0305 .33363 L
s
[(-0.1)] .01207 .34056 1 -0.37641 Mshowa
.01672 .38413 m
.02288 .38187 L
s
[(0)] .0044 .38865 1 -0.36733 Mshowa
.00885 .43381 m
.01502 .4316 L
s
[(0.1)] -0.00351 .43823 1 -0.35794 Mshowa
.00072 .48506 m
.00692 .4829 L
s
[(0.2)] -0.01167 .48937 1 -0.34823 Mshowa
.125 Mabswid
.0303 .29842 m
.03398 .29701 L
s
.02883 .30772 m
.03251 .30631 L
s
.02735 .31707 m
.03103 .31567 L
s
.02586 .32648 m
.02954 .32508 L
s
.02285 .34546 m
.02653 .34408 L
s
.02133 .35504 m
.02502 .35367 L
s
.0198 .36468 m
.02349 .36331 L
s
.01826 .37437 m
.02196 .37301 L
s
.01516 .39394 m
.01886 .39259 L
s
.0136 .40382 m
.0173 .40247 L
s
.01202 .41375 m
.01573 .41242 L
s
.01044 .42375 m
.01414 .42242 L
s
.00724 .44393 m
.01095 .44261 L
s
.00563 .45412 m
.00934 .4528 L
s
.004 .46437 m
.00772 .46306 L
s
.00237 .47468 m
.00608 .47338 L
s
.03322 .27999 m
.03689 .27857 L
s
.03467 .27086 m
.03834 .26943 L
s
.03611 .26178 m
.03977 .26035 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.5 Mabswid
.663 .74 .907 r
.38609 .7026 .40117 .71677 .42641 .71002 .4115 .69491 Metetra
.661 .728 .899 r
.4115 .69491 .42641 .71002 .45189 .70309 .43713 .68734 Metetra
.662 .722 .894 r
.43713 .68734 .45189 .70309 .47762 .69613 .46301 .67964 Metetra
.659 .714 .889 r
.46301 .67964 .47762 .69613 .5036 .68899 .48912 .67207 Metetra
.66 .71 .885 r
.48912 .67207 .5036 .68899 .52982 .68181 .51549 .66437 Metetra
.66 .706 .881 r
.51549 .66437 .52982 .68181 .55631 .67459 .54211 .65654 Metetra
.66 .701 .877 r
.54211 .65654 .55631 .67459 .58305 .66729 .56898 .64866 Metetra
.642 .69 .879 r
.56898 .64866 .58305 .66729 .61003 .6591 .59614 .64213 Metetra
.646 .712 .896 r
.59614 .64213 .61003 .6591 .63727 .65105 .62358 .63515 Metetra
.651 .729 .906 r
.62358 .63515 .63727 .65105 .66478 .64314 .65128 .6277 Metetra
.649 .736 .913 r
.65128 .6277 .66478 .64314 .69256 .6351 .67927 .62029 Metetra
.653 .749 .92 r
.67927 .62029 .69256 .6351 .72062 .6272 .70753 .61241 Metetra
.652 .75 .922 r
.70753 .61241 .72062 .6272 .74895 .61917 .73608 .60456 Metetra
.65 .754 .926 r
.73608 .60456 .74895 .61917 .77756 .611 .76493 .59673 Metetra
.649 .761 .931 r
.76493 .59673 .77756 .611 .80646 .60276 .79408 .58879 Metetra
.659 .771 .932 r
.79408 .58879 .80646 .60276 .83568 .59486 .82346 .58004 Metetra
.657 .761 .926 r
.82346 .58004 .83568 .59486 .8652 .58676 .85315 .5714 Metetra
.655 .754 .923 r
.85315 .5714 .8652 .58676 .895 .57847 .88317 .56286 Metetra
.656 .753 .922 r
.88317 .56286 .895 .57847 .92512 .57012 .91349 .55419 Metetra
.654 .75 .921 r
.91349 .55419 .92512 .57012 .95553 .56157 .94416 .54562 Metetra
.654 .752 .922 r
.94416 .54562 .95553 .56157 .98626 .55297 .97513 .53691 Metetra
.687 .726 .88 r
.37082 .68667 .38609 .7026 .4115 .69491 .39643 .67692 Metetra
.674 .701 .867 r
.39643 .67692 .4115 .69491 .43713 .68734 .42223 .66799 Metetra
.675 .689 .855 r
.42223 .66799 .43713 .68734 .46301 .67964 .44825 .65873 Metetra
.664 .671 .847 r
.44825 .65873 .46301 .67964 .48912 .67207 .47448 .6503 Metetra
.665 .666 .84 r
.47448 .6503 .48912 .67207 .51549 .66437 .50096 .64154 Metetra
.666 .658 .833 r
.50096 .64154 .51549 .66437 .54211 .65654 .52768 .63247 Metetra
.664 .649 .825 r
.52768 .63247 .54211 .65654 .56898 .64866 .55464 .62337 Metetra
.593 .609 .837 r
.55464 .62337 .56898 .64866 .59614 .64213 .58196 .62096 Metetra
.611 .655 .869 r
.58196 .62096 .59614 .64213 .62358 .63515 .60959 .6167 Metetra
.633 .695 .889 r
.60959 .6167 .62358 .63515 .65128 .6277 .63749 .61054 Metetra
.625 .709 .906 r
.63749 .61054 .65128 .6277 .67927 .62029 .66572 .60482 Metetra
.648 .741 .917 r
.66572 .60482 .67927 .62029 .70753 .61241 .69419 .59718 Metetra
.64 .744 .924 r
.69419 .59718 .70753 .61241 .73608 .60456 .72298 .58996 Metetra
.631 .752 .935 r
.72298 .58996 .73608 .60456 .76493 .59673 .75212 .58315 Metetra
.629 .768 .947 r
.75212 .58315 .76493 .59673 .79408 .58879 .78157 .57614 Metetra
.68 .803 .94 r
.78157 .57614 .79408 .58879 .82346 .58004 .81105 .56557 Metetra
.67 .774 .928 r
.81105 .56557 .82346 .58004 .85315 .5714 .84089 .55583 Metetra
.658 .756 .923 r
.84089 .55583 .85315 .5714 .88317 .56286 .87111 .54693 Metetra
.661 .755 .92 r
.87111 .54693 .88317 .56286 .91349 .55419 .90162 .53769 Metetra
.649 .745 .919 r
.90162 .53769 .91349 .55419 .94416 .54562 .93256 .5293 Metetra
.652 .751 .922 r
.93256 .5293 .94416 .54562 .97513 .53691 .96379 .52057 Metetra
.651 .798 .953 r
.35503 .67617 .37082 .68667 .39643 .67692 .38073 .66852 Metetra
.637 .831 .975 r
.38073 .66852 .39643 .67692 .42223 .66799 .40668 .66088 Metetra
.624 .852 .986 r
.40668 .66088 .42223 .66799 .44825 .65873 .43288 .65314 Metetra
.6 .872 .993 r
.43288 .65314 .44825 .65873 .47448 .6503 .45933 .64541 Metetra
.585 .881 .993 r
.45933 .64541 .47448 .6503 .50096 .64154 .48603 .63758 Metetra
.564 .888 .988 r
.48603 .63758 .50096 .64154 .52768 .63247 .513 .62965 Metetra
.529 .891 .975 r
.513 .62965 .52768 .63247 .55464 .62337 .54024 .62165 Metetra
.464 .875 .948 r
.54024 .62165 .55464 .62337 .58196 .62096 .56775 .61418 Metetra
.598 .862 .993 r
.56775 .61418 .58196 .62096 .60959 .6167 .59555 .60647 Metetra
.636 .817 .97 r
.59555 .60647 .60959 .6167 .63749 .61054 .62362 .59851 Metetra
.644 .793 .954 r
.62362 .59851 .63749 .61054 .66572 .60482 .65198 .59052 Metetra
.653 .763 .931 r
.65198 .59052 .66572 .60482 .69419 .59718 .68063 .58228 Metetra
.653 .757 .926 r
.68063 .58228 .69419 .59718 .72298 .58996 .70958 .574 Metetra
.653 .745 .917 r
.70958 .574 .72298 .58996 .75212 .58315 .73882 .56568 Metetra
.654 .728 .903 r
.73882 .56568 .75212 .58315 .78157 .57614 .76837 .55726 Metetra
.658 .714 .89 r
.76837 .55726 .78157 .57614 .81105 .56557 .79821 .54844 Metetra
.657 .737 .909 r
.79821 .54844 .81105 .56557 .84089 .55583 .82836 .53961 Metetra
.655 .751 .92 r
.82836 .53961 .84089 .55583 .87111 .54693 .85883 .53078 Metetra
.655 .754 .922 r
.85883 .53078 .87111 .54693 .90162 .53769 .88962 .52183 Metetra
.653 .759 .927 r
.88962 .52183 .90162 .53769 .93256 .5293 .92075 .51287 Metetra
.654 .754 .923 r
.92075 .51287 .93256 .5293 .96379 .52057 .95221 .50379 Metetra
.635 .771 .945 r
.33901 .66393 .35503 .67617 .38073 .66852 .36483 .65728 Metetra
.637 .788 .954 r
.36483 .65728 .38073 .66852 .40668 .66088 .39092 .65022 Metetra
.632 .798 .962 r
.39092 .65022 .40668 .66088 .43288 .65314 .41728 .64318 Metetra
.634 .812 .968 r
.41728 .64318 .43288 .65314 .45933 .64541 .44392 .63573 Metetra
.63 .818 .973 r
.44392 .63573 .45933 .64541 .48603 .63758 .47082 .6283 Metetra
.624 .825 .978 r
.47082 .6283 .48603 .63758 .513 .62965 .498 .62089 Metetra
.619 .834 .983 r
.498 .62089 .513 .62965 .54024 .62165 .52546 .61337 Metetra
.667 .856 .972 r
.52546 .61337 .54024 .62165 .56775 .61418 .55319 .60325 Metetra
.667 .816 .955 r
.55319 .60325 .56775 .61418 .59555 .60647 .58117 .59371 Metetra
.661 .788 .942 r
.58117 .59371 .59555 .60647 .62362 .59851 .60943 .58477 Metetra
.665 .777 .933 r
.60943 .58477 .62362 .59851 .65198 .59052 .63797 .57555 Metetra
.657 .759 .925 r
.63797 .57555 .65198 .59052 .68063 .58228 .66681 .56693 Metetra
.66 .757 .922 r
.66681 .56693 .68063 .58228 .70958 .574 .69593 .55804 Metetra
.662 .752 .917 r
.69593 .55804 .70958 .574 .73882 .56568 .72535 .54887 Metetra
.662 .743 .91 r
.72535 .54887 .73882 .56568 .76837 .55726 .75506 .53966 Metetra
.646 .729 .909 r
.75506 .53966 .76837 .55726 .79821 .54844 .78517 .53164 Metetra
.649 .742 .918 r
.78517 .53164 .79821 .54844 .82836 .53961 .81559 .52318 Metetra
.653 .751 .922 r
.81559 .52318 .82836 .53961 .85883 .53078 .84631 .51429 Metetra
.652 .752 .923 r
.84631 .51429 .85883 .53078 .88962 .52183 .87736 .50539 Metetra
.656 .757 .924 r
.87736 .50539 .88962 .52183 .92075 .51287 .90871 .49605 Metetra
.655 .754 .922 r
.90871 .49605 .92075 .51287 .95221 .50379 .9404 .48671 Metetra
.387 .773 .99 r
.32235 .65723 .33901 .66393 .36483 .65728 .3481 .65585 Metetra
.294 .783 .9 r
.3481 .65585 .36483 .65728 .39092 .65022 .37429 .65214 Metetra
.086 .644 .705 r
.37429 .65214 .39092 .65022 .41728 .64318 .40079 .649 Metetra
.40079 .649 .41728 .64318 .44392 .63573 .42769 .64347 Metetra
.093 0 0 r
.42769 .64347 .44392 .63573 .47082 .6283 .45488 .63852 Metetra
.202 0 0 r
.45488 .63852 .47082 .6283 .498 .62089 .4824 .63413 Metetra
.27 0 0 r
.4824 .63413 .498 .62089 .52546 .61337 .51025 .62953 Metetra
.51025 .62953 .52546 .61337 .55319 .60325 .53837 .60712 Metetra
.615 .956 .837 r
.53837 .60712 .55319 .60325 .58117 .59371 .56661 .58937 Metetra
.68 .926 .971 r
.56661 .58937 .58117 .59371 .60943 .58477 .59507 .57625 Metetra
.731 .875 .948 r
.59507 .57625 .60943 .58477 .63797 .57555 .62372 .56177 Metetra
.67 .784 .934 r
.62372 .56177 .63797 .57555 .66681 .56693 .65274 .55191 Metetra
.688 .774 .917 r
.65274 .55191 .66681 .56693 .69593 .55804 .68198 .54068 Metetra
.701 .751 .89 r
.68198 .54068 .69593 .55804 .72535 .54887 .71141 .52809 Metetra
.692 .712 .864 r
.71141 .52809 .72535 .54887 .75506 .53966 .74111 .51573 Metetra
.593 .641 .868 r
.74111 .51573 .75506 .53966 .78517 .53164 .77171 .51212 Metetra
.617 .7 .903 r
.77171 .51212 .78517 .53164 .81559 .52318 .80255 .50608 Metetra
.646 .744 .92 r
.80255 .50608 .81559 .52318 .84631 .51429 .83354 .49755 Metetra
.636 .747 .928 r
.83354 .49755 .84631 .51429 .87736 .50539 .86495 .48958 Metetra
.668 .775 .93 r
.86495 .48958 .87736 .50539 .90871 .49605 .89645 .4791 Metetra
.66 .759 .923 r
.89645 .4791 .90871 .49605 .9404 .48671 .92835 .46917 Metetra
.396 0 0 r
.30495 .65622 .32235 .65723 .3481 .65585 .33037 .66462 Metetra
.395 0 0 r
.33037 .66462 .3481 .65585 .37429 .65214 .35657 .66718 Metetra
.493 .026 .073 r
.35657 .66718 .37429 .65214 .40079 .649 .38313 .6714 Metetra
.432 .008 .132 r
.38313 .6714 .40079 .649 .42769 .64347 .41035 .66958 Metetra
.475 .073 .198 r
.41035 .66958 .42769 .64347 .45488 .63852 .4379 .66938 Metetra
.508 .128 .255 r
.4379 .66938 .45488 .63852 .4824 .63413 .46584 .67084 Metetra
.514 .154 .294 r
.46584 .67084 .4824 .63413 .51025 .62953 .49423 .67188 Metetra
0 0 .034 r
.49423 .67188 .51025 .62953 .53837 .60712 .52309 .62651 Metetra
.52309 .62651 .53837 .60712 .56661 .58937 .55174 .59373 Metetra
.666 .973 .826 r
.55174 .59373 .56661 .58937 .59507 .57625 .58047 .57311 Metetra
.83 .954 .896 r
.58047 .57311 .59507 .57625 .62372 .56177 .60922 .54919 Metetra
.697 .813 .937 r
.60922 .54919 .62372 .56177 .65274 .55191 .63841 .53722 Metetra
.734 .795 .9 r
.63841 .53722 .65274 .55191 .68198 .54068 .66772 .52192 Metetra
.753 .754 .853 r
.66772 .52192 .68198 .54068 .71141 .52809 .69706 .50331 Metetra
.726 .693 .818 r
.69706 .50331 .71141 .52809 .74111 .51573 .72659 .48547 Metetra
.504 .546 .833 r
.72659 .48547 .74111 .51573 .77171 .51212 .75785 .48988 Metetra
.558 .646 .893 r
.75785 .48988 .77171 .51212 .80255 .50608 .78922 .48829 Metetra
.633 .734 .921 r
.78922 .48829 .80255 .50608 .83354 .49755 .82053 .48057 Metetra
.607 .736 .936 r
.82053 .48057 .83354 .49755 .86495 .48958 .85237 .4744 Metetra
.69 .796 .931 r
.85237 .4744 .86495 .48958 .89645 .4791 .88396 .46201 Metetra
.67 .765 .922 r
.88396 .46201 .89645 .4791 .92835 .46917 .91603 .45115 Metetra
.505 .599 .882 r
.28859 .63319 .30495 .65622 .33037 .66462 .31441 .6351 Metetra
.576 .58 .82 r
.31441 .6351 .33037 .66462 .35657 .66718 .34083 .63339 Metetra
.568 .552 .796 r
.34083 .63339 .35657 .66718 .38313 .6714 .36757 .63263 Metetra
.602 .547 .766 r
.36757 .63263 .38313 .6714 .41035 .66958 .39484 .62818 Metetra
.593 .533 .757 r
.39484 .62818 .41035 .66958 .4379 .66938 .42242 .62467 Metetra
.585 .517 .745 r
.42242 .62467 .4379 .66938 .46584 .67084 .45034 .6221 Metetra
.586 .507 .732 r
.45034 .6221 .46584 .67084 .49423 .67188 .47865 .61924 Metetra
.715 .574 .694 r
.47865 .61924 .49423 .67188 .52309 .62651 .5075 .5884 Metetra
.719 .615 .74 r
.5075 .5884 .52309 .62651 .55174 .59373 .53629 .56501 Metetra
.703 .653 .797 r
.53629 .56501 .55174 .59373 .58047 .57311 .56522 .54893 Metetra
.73 .696 .817 r
.56522 .54893 .58047 .57311 .60922 .54919 .59429 .53078 Metetra
.679 .735 .892 r
.59429 .53078 .60922 .54919 .63841 .53722 .62373 .51987 Metetra
.703 .757 .894 r
.62373 .51987 .63841 .53722 .66772 .52192 .65336 .50689 Metetra
.729 .796 .905 r
.65336 .50689 .66772 .52192 .69706 .50331 .68315 .49183 Metetra
.725 .848 .94 r
.68315 .49183 .69706 .50331 .72659 .48547 .71317 .47719 Metetra
.374 .759 .989 r
.71317 .47719 .72659 .48547 .75785 .48988 .74434 .4762 Metetra
.563 .765 .973 r
.74434 .4762 .75785 .48988 .78922 .48829 .77572 .47146 Metetra
.64 .754 .931 r
.77572 .47146 .78922 .48829 .82053 .48057 .80722 .46292 Metetra
.627 .74 .929 r
.80722 .46292 .82053 .48057 .85237 .4744 .83918 .45529 Metetra
.676 .745 .902 r
.83918 .45529 .85237 .4744 .88396 .46201 .87113 .44381 Metetra
.664 .753 .917 r
.87113 .44381 .88396 .46201 .91603 .45115 .90352 .43321 Metetra
.582 .654 .886 r
.27186 .61193 .28859 .63319 .31441 .6351 .29805 .60888 Metetra
.611 .623 .838 r
.29805 .60888 .31441 .6351 .34083 .63339 .3247 .60393 Metetra
.605 .598 .818 r
.3247 .60393 .34083 .63339 .36757 .63263 .35164 .59941 Metetra
.621 .585 .792 r
.35164 .59941 .36757 .63263 .39484 .62818 .379 .59296 Metetra
.615 .573 .783 r
.379 .59296 .39484 .62818 .42242 .62467 .40666 .58694 Metetra
.609 .559 .773 r
.40666 .58694 .42242 .62467 .45034 .6221 .43463 .58135 Metetra
.609 .547 .76 r
.43463 .58135 .45034 .6221 .47865 .61924 .46295 .57556 Metetra
.69 .582 .729 r
.46295 .57556 .47865 .61924 .5075 .5884 .49175 .55546 Metetra
.694 .626 .776 r
.49175 .55546 .5075 .5884 .53629 .56501 .52066 .53907 Metetra
.683 .666 .827 r
.52066 .53907 .53629 .56501 .56522 .54893 .54977 .52637 Metetra
.701 .702 .848 r
.54977 .52637 .56522 .54893 .59429 .53078 .5791 .51255 Metetra
.668 .737 .902 r
.5791 .51255 .59429 .53078 .62373 .51987 .60876 .50242 Metetra
.681 .753 .906 r
.60876 .50242 .62373 .51987 .65336 .50689 .63869 .49116 Metetra
.695 .781 .918 r
.63869 .49116 .65336 .50689 .68315 .49183 .66885 .47878 Metetra
.69 .82 .945 r
.66885 .47878 .68315 .49183 .71317 .47719 .6993 .46655 Metetra
.537 .804 .995 r
.6993 .46655 .71317 .47719 .74434 .4762 .73048 .46136 Metetra
.611 .772 .957 r
.73048 .46136 .74434 .4762 .77572 .47146 .76195 .45416 Metetra
.647 .755 .928 r
.76195 .45416 .77572 .47146 .80722 .46292 .79365 .44495 Metetra
.641 .746 .925 r
.79365 .44495 .80722 .46292 .83918 .45529 .82576 .43614 Metetra
.666 .745 .909 r
.82576 .43614 .83918 .45529 .87113 .44381 .85805 .4253 Metetra
.66 .752 .919 r
.85805 .4253 .87113 .44381 .90352 .43321 .89074 .41486 Metetra
.686 .634 .791 r
.25549 .58262 .27186 .61193 .29805 .60888 .28246 .56895 Metetra
.652 .569 .749 r
.28246 .56895 .29805 .60888 .3247 .60393 .30948 .55714 Metetra
.646 .544 .725 r
.30948 .55714 .3247 .60393 .35164 .59941 .33676 .5447 Metetra
.626 .513 .706 r
.33676 .5447 .35164 .59941 .379 .59296 .36417 .53414 Metetra
.625 .505 .696 r
.36417 .53414 .379 .59296 .40666 .58694 .39184 .52294 Metetra
.623 .495 .686 r
.39184 .52294 .40666 .58694 .43463 .58135 .41978 .51113 Metetra
.617 .482 .675 r
.41978 .51113 .43463 .58135 .46295 .57556 .44795 .49935 Metetra
.546 .427 .669 r
.44795 .49935 .46295 .57556 .49175 .55546 .47615 .50225 Metetra
.567 .484 .721 r
.47615 .50225 .49175 .55546 .52066 .53907 .50488 .50119 Metetra
.602 .559 .778 r
.50488 .50119 .52066 .53907 .54977 .52637 .53404 .49609 Metetra
.594 .599 .826 r
.53404 .49609 .54977 .52637 .5791 .51255 .5636 .492 Metetra
.641 .705 .893 r
.5636 .492 .5791 .51255 .60876 .50242 .59349 .48378 Metetra
.625 .723 .917 r
.59349 .48378 .60876 .50242 .63869 .49116 .62375 .47656 Metetra
.594 .767 .962 r
.62375 .47656 .63869 .49116 .66885 .47878 .65443 .47035 Metetra
.535 .84 .999 r
.65443 .47035 .66885 .47878 .6993 .46655 .68549 .46377 Metetra
.623 .944 .949 r
.68549 .46377 .6993 .46655 .73048 .46136 .71651 .4494 Metetra
.681 .844 .961 r
.71651 .4494 .73048 .46136 .76195 .45416 .74792 .43697 Metetra
.661 .766 .928 r
.74792 .43697 .76195 .45416 .79365 .44495 .77979 .42649 Metetra
.669 .756 .916 r
.77979 .42649 .79365 .44495 .82576 .43614 .81195 .41534 Metetra
.643 .72 .904 r
.81195 .41534 .82576 .43614 .85805 .4253 .84467 .40614 Metetra
.65 .745 .919 r
.84467 .40614 .85805 .4253 .89074 .41486 .87771 .39627 Metetra
.746 .625 .725 r
.2396 .54534 .25549 .58262 .28246 .56895 .26781 .51567 Metetra
.681 .549 .698 r
.26781 .51567 .28246 .56895 .30948 .55714 .29541 .49371 Metetra
.673 .526 .677 r
.29541 .49371 .30948 .55714 .33676 .5447 .32321 .46966 Metetra
.632 .484 .663 r
.32321 .46966 .33676 .5447 .36417 .53414 .35062 .45315 Metetra
.634 .479 .655 r
.35062 .45315 .36417 .53414 .39184 .52294 .37828 .43452 Metetra
.634 .473 .646 r
.37828 .43452 .39184 .52294 .41978 .51113 .40614 .4138 Metetra
.626 .46 .638 r
.40614 .4138 .41978 .51113 .44795 .49935 .43406 .39355 Metetra
.39 .286 .615 r
.43406 .39355 .44795 .49935 .47615 .50225 .46097 .4298 Metetra
.418 .346 .669 r
.46097 .4298 .47615 .50225 .50488 .50119 .48912 .45166 Metetra
.503 .456 .738 r
.48912 .45166 .50488 .50119 .53404 .49609 .51815 .45814 Metetra
.422 .458 .793 r
.51815 .45814 .53404 .49609 .5636 .492 .54781 .4691 Metetra
.599 .668 .887 r
.54781 .4691 .5636 .492 .59349 .48378 .57791 .46394 Metetra
.519 .667 .93 r
.57791 .46394 .59349 .48378 .62375 .47656 .60853 .46311 Metetra
.327 .66 .973 r
.60853 .46311 .62375 .47656 .65443 .47035 .63981 .46671 Metetra
.048 .603 .819 r
.63981 .46671 .65443 .47035 .68549 .46377 .67164 .46917 Metetra
.728 .979 .756 r
.67164 .46917 .68549 .46377 .71651 .4494 .70237 .4404 Metetra
.781 .911 .929 r
.70237 .4404 .71651 .4494 .74792 .43697 .73362 .41989 Metetra
.683 .78 .924 r
.73362 .41989 .74792 .43697 .77979 .42649 .76563 .40753 Metetra
.707 .769 .9 r
.76563 .40753 .77979 .42649 .81195 .41534 .79777 .39284 Metetra
.608 .69 .901 r
.79777 .39284 .81195 .41534 .84467 .40614 .83098 .38631 Metetra
.634 .735 .921 r
.83098 .38631 .84467 .40614 .87771 .39627 .86442 .37745 Metetra
.83 .841 .856 r
.22103 .5364 .2396 .54534 .26781 .51567 .24917 .51139 Metetra
.791 .917 .923 r
.24917 .51139 .26781 .51567 .29541 .49371 .27689 .49229 Metetra
.802 .952 .916 r
.27689 .49229 .29541 .49371 .32321 .46966 .30482 .47153 Metetra
.636 .96 .915 r
.30482 .47153 .32321 .46966 .35062 .45315 .33249 .45659 Metetra
.638 .965 .882 r
.33249 .45659 .35062 .45315 .37828 .43452 .36043 .43996 Metetra
.623 .959 .833 r
.36043 .43996 .37828 .43452 .40614 .4138 .3886 .42167 Metetra
.514 .899 .738 r
.3886 .42167 .40614 .4138 .43406 .39355 .41689 .40371 Metetra
.716 .254 .153 r
.41689 .40371 .43406 .39355 .46097 .4298 .44424 .42976 Metetra
.53 0 0 r
.44424 .42976 .46097 .4298 .48912 .45166 .47268 .44444 Metetra
.164 .652 .921 r
.47268 .44444 .48912 .45166 .51815 .45814 .50195 .44715 Metetra
.152 .594 .932 r
.50195 .44715 .51815 .45814 .54781 .4691 .53177 .45324 Metetra
.598 .755 .953 r
.53177 .45324 .54781 .4691 .57791 .46394 .56207 .44689 Metetra
.539 .717 .955 r
.56207 .44689 .57791 .46394 .60853 .46311 .59284 .44384 Metetra
.486 .665 .942 r
.59284 .44384 .60853 .46311 .63981 .46671 .62418 .44413 Metetra
.522 .646 .912 r
.62418 .44413 .63981 .46671 .67164 .46917 .65604 .44352 Metetra
.766 .722 .811 r
.65604 .44352 .67164 .46917 .70237 .4404 .68724 .41895 Metetra
.736 .75 .864 r
.68724 .41895 .70237 .4404 .73362 .41989 .7189 .40067 Metetra
.676 .756 .911 r
.7189 .40067 .73362 .41989 .76563 .40753 .75121 .38861 Metetra
.696 .77 .908 r
.75121 .38861 .76563 .40753 .79777 .39284 .78372 .37473 Metetra
.611 .749 .943 r
.78372 .37473 .79777 .39284 .83098 .38631 .81711 .36709 Metetra
.638 .749 .929 r
.81711 .36709 .83098 .38631 .86442 .37745 .85078 .35763 Metetra
.798 .836 .88 r
.20213 .52624 .22103 .5364 .24917 .51139 .23021 .50526 Metetra
.76 .897 .938 r
.23021 .50526 .24917 .51139 .27689 .49229 .25801 .48863 Metetra
.769 .931 .938 r
.25801 .48863 .27689 .49229 .30482 .47153 .28606 .47072 Metetra
.648 .948 .953 r
.28606 .47072 .30482 .47153 .33249 .45659 .31397 .45712 Metetra
.65 .959 .933 r
.31397 .45712 .33249 .45659 .36043 .43996 .34217 .44224 Metetra
.64 .964 .901 r
.34217 .44224 .36043 .43996 .3886 .42167 .37062 .42608 Metetra
.563 .936 .842 r
.37062 .42608 .3886 .42167 .41689 .40371 .39925 .41012 Metetra
.622 .101 0 r
.39925 .41012 .41689 .40371 .44424 .42976 .42707 .42714 Metetra
.277 0 0 r
.42707 .42714 .44424 .42976 .47268 .44444 .45585 .43552 Metetra
.349 .744 .985 r
.45585 .43552 .47268 .44444 .50195 .44715 .48538 .43492 Metetra
.338 .691 .981 r
.48538 .43492 .50195 .44715 .53177 .45324 .51539 .43678 Metetra
.614 .758 .947 r
.51539 .43678 .53177 .45324 .56207 .44689 .5459 .42937 Metetra
.574 .73 .949 r
.5459 .42937 .56207 .44689 .59284 .44384 .57684 .42437 Metetra
.537 .692 .939 r
.57684 .42437 .59284 .44384 .62418 .44413 .60829 .42181 Metetra
.559 .671 .913 r
.60829 .42181 .62418 .44413 .65604 .44352 .64022 .41853 Metetra
.745 .723 .831 r
.64022 .41853 .65604 .44352 .68724 .41895 .67184 .39752 Metetra
.718 .749 .876 r
.67184 .39752 .68724 .41895 .7189 .40067 .70388 .38111 Metetra
.671 .755 .914 r
.70388 .38111 .7189 .40067 .75121 .38861 .73648 .36927 Metetra
.686 .766 .912 r
.73648 .36927 .75121 .38861 .78372 .37473 .76933 .35605 Metetra
.623 .752 .939 r
.76933 .35605 .78372 .37473 .81711 .36709 .80293 .34742 Metetra
.642 .75 .927 r
.80293 .34742 .81711 .36709 .85078 .35763 .83684 .3374 Metetra
.721 .891 .957 r
.18241 .51966 .20213 .52624 .23021 .50526 .21013 .50556 Metetra
.593 .937 .943 r
.21013 .50556 .23021 .50526 .25801 .48863 .23789 .49323 Metetra
.482 .899 .838 r
.23789 .49323 .25801 .48863 .28606 .47072 .26594 .48028 Metetra
.26594 .48028 .28606 .47072 .31397 .45712 .29409 .46911 Metetra
.29409 .46911 .31397 .45712 .34217 .44224 .32254 .45733 Metetra
.32254 .45733 .34217 .44224 .37062 .42608 .35128 .44493 Metetra
.072 0 0 r
.35128 .44493 .37062 .42608 .39925 .41012 .38028 .43256 Metetra
.443 0 .083 r
.38028 .43256 .39925 .41012 .42707 .42714 .40904 .43422 Metetra
.143 0 0 r
.40904 .43422 .42707 .42714 .45585 .43552 .43842 .43207 Metetra
.399 .835 .949 r
.43842 .43207 .45585 .43552 .48538 .43492 .46834 .42603 Metetra
.49 .818 1 r
.46834 .42603 .48538 .43492 .51539 .43678 .49865 .42095 Metetra
.636 .778 .949 r
.49865 .42095 .51539 .43678 .5459 .42937 .52939 .4119 Metetra
.622 .755 .941 r
.52939 .4119 .5459 .42937 .57684 .42437 .56051 .40379 Metetra
.612 .715 .919 r
.56051 .40379 .57684 .42437 .60829 .42181 .59205 .39662 Metetra
.618 .673 .88 r
.59205 .39662 .60829 .42181 .64022 .41853 .624 .38908 Metetra
.686 .67 .828 r
.624 .38908 .64022 .41853 .67184 .39752 .65608 .37407 Metetra
.681 .719 .879 r
.65608 .37407 .67184 .39752 .70388 .38111 .68853 .3609 Metetra
.661 .749 .915 r
.68853 .3609 .70388 .38111 .73648 .36927 .72144 .34958 Metetra
.668 .76 .919 r
.72144 .34958 .73648 .36927 .76933 .35605 .75468 .33759 Metetra
.641 .767 .94 r
.75468 .33759 .76933 .35605 .80293 .34742 .78846 .32745 Metetra
.649 .755 .926 r
.78846 .32745 .80293 .34742 .83684 .3374 .8226 .31666 Metetra
.341 .802 .935 r
.16175 .51678 .18241 .51966 .21013 .50556 .18877 .51259 Metetra
.18877 .51259 .21013 .50556 .23789 .49323 .21632 .50653 Metetra
.144 0 0 r
.21632 .50653 .23789 .49323 .26594 .48028 .24418 .50089 Metetra
.221 0 0 r
.24418 .50089 .26594 .48028 .29409 .46911 .27254 .49334 Metetra
.279 0 0 r
.27254 .49334 .29409 .46911 .32254 .45733 .30122 .48619 Metetra
.331 0 .072 r
.30122 .48619 .32254 .45733 .35128 .44493 .33023 .47945 Metetra
.365 0 .14 r
.33023 .47945 .35128 .44493 .38028 .43256 .35961 .47248 Metetra
.187 0 .087 r
.35961 .47248 .38028 .43256 .40904 .43422 .38995 .45161 Metetra
.38995 .45161 .40904 .43422 .43842 .43207 .4203 .43431 Metetra
.505 .91 .868 r
.4203 .43431 .43842 .43207 .46834 .42603 .45076 .42058 Metetra
.682 .928 .97 r
.45076 .42058 .46834 .42603 .49865 .42095 .48152 .40574 Metetra
.666 .8 .947 r
.48152 .40574 .49865 .42095 .52939 .4119 .51252 .39446 Metetra
.681 .779 .925 r
.51252 .39446 .52939 .4119 .56051 .40379 .54385 .38207 Metetra
.688 .736 .887 r
.54385 .38207 .56051 .40379 .59205 .39662 .57549 .36856 Metetra
.674 .676 .844 r
.57549 .36856 .59205 .39662 .624 .38908 .60744 .35518 Metetra
.602 .603 .825 r
.60744 .35518 .624 .38908 .65608 .37407 .63995 .34859 Metetra
.625 .681 .883 r
.63995 .34859 .65608 .37407 .68853 .3609 .67285 .34004 Metetra
.648 .741 .917 r
.67285 .34004 .68853 .3609 .72144 .34958 .70607 .32951 Metetra
.641 .75 .928 r
.70607 .32951 .72144 .34958 .75468 .33759 .73973 .31935 Metetra
.665 .784 .938 r
.73973 .31935 .75468 .33759 .78846 .32745 .77367 .30718 Metetra
.659 .76 .925 r
.77367 .30718 .78846 .32745 .8226 .31666 .80804 .29537 Metetra
.577 .723 .943 r
.1422 .49925 .16175 .51678 .18877 .51259 .16939 .49443 Metetra
.609 .728 .93 r
.16939 .49443 .18877 .51259 .21632 .50653 .19711 .4879 Metetra
.602 .722 .929 r
.19711 .4879 .21632 .50653 .24418 .50089 .22515 .48173 Metetra
.629 .727 .918 r
.22515 .48173 .24418 .50089 .27254 .49334 .25369 .47382 Metetra
.622 .723 .919 r
.25369 .47382 .27254 .49334 .30122 .48619 .28254 .46626 Metetra
.616 .718 .919 r
.28254 .46626 .30122 .48619 .33023 .47945 .31172 .45905 Metetra
.618 .716 .916 r
.31172 .45905 .33023 .47945 .35961 .47248 .34129 .45163 Metetra
.752 .752 .852 r
.34129 .45163 .35961 .47248 .38995 .45161 .37182 .43156 Metetra
.727 .756 .876 r
.37182 .43156 .38995 .45161 .4203 .43431 .40238 .41473 Metetra
.695 .755 .898 r
.40238 .41473 .4203 .43431 .45076 .42058 .43307 .40112 Metetra
.705 .762 .896 r
.43307 .40112 .45076 .42058 .48152 .40574 .46406 .38649 Metetra
.666 .755 .917 r
.46406 .38649 .48152 .40574 .51252 .39446 .49529 .37507 Metetra
.678 .76 .913 r
.49529 .37507 .51252 .39446 .54385 .38207 .52687 .36264 Metetra
.689 .765 .91 r
.52687 .36264 .54385 .38207 .57549 .36856 .55877 .34917 Metetra
.686 .768 .914 r
.55877 .34917 .57549 .36856 .60744 .35518 .59098 .33581 Metetra
.598 .738 .942 r
.59098 .33581 .60744 .35518 .63995 .34859 .62373 .32861 Metetra
.625 .744 .933 r
.62373 .32861 .63995 .34859 .67285 .34004 .65687 .3196 Metetra
.649 .751 .924 r
.65687 .3196 .67285 .34004 .70607 .32951 .69036 .30878 Metetra
.643 .748 .926 r
.69036 .30878 .70607 .32951 .73973 .31935 .72428 .29828 Metetra
.664 .756 .918 r
.72428 .29828 .73973 .31935 .77367 .30718 .75851 .28594 Metetra
.659 .754 .921 r
.75851 .28594 .77367 .30718 .80804 .29537 .79318 .27391 Metetra
.587 .726 .94 r
.12226 .48134 .1422 .49925 .16939 .49443 .14964 .47586 Metetra
.614 .729 .928 r
.14964 .47586 .16939 .49443 .19711 .4879 .17754 .46883 Metetra
.608 .724 .927 r
.17754 .46883 .19711 .4879 .22515 .48173 .20576 .46212 Metetra
.632 .727 .916 r
.20576 .46212 .22515 .48173 .25369 .47382 .23447 .45382 Metetra
.626 .723 .917 r
.23447 .45382 .25369 .47382 .28254 .46626 .2635 .44583 Metetra
.62 .719 .917 r
.2635 .44583 .28254 .46626 .31172 .45905 .29287 .43814 Metetra
.622 .716 .914 r
.29287 .43814 .31172 .45905 .34129 .45163 .32261 .43024 Metetra
.743 .749 .856 r
.32261 .43024 .34129 .45163 .37182 .43156 .35333 .41103 Metetra
.72 .754 .879 r
.35333 .41103 .37182 .43156 .40238 .41473 .3841 .39469 Metetra
.691 .754 .9 r
.3841 .39469 .40238 .41473 .43307 .40112 .41501 .38122 Metetra
.7 .76 .898 r
.41501 .38122 .43307 .40112 .46406 .38649 .44623 .36681 Metetra
.665 .755 .917 r
.44623 .36681 .46406 .38649 .49529 .37507 .4777 .35527 Metetra
.675 .759 .914 r
.4777 .35527 .49529 .37507 .52687 .36264 .50952 .34279 Metetra
.685 .764 .912 r
.50952 .34279 .52687 .36264 .55877 .34917 .54168 .32938 Metetra
.683 .767 .915 r
.54168 .32938 .55877 .34917 .59098 .33581 .57417 .31604 Metetra
.605 .741 .941 r
.57417 .31604 .59098 .33581 .62373 .32861 .60714 .30819 Metetra
.628 .746 .932 r
.60714 .30819 .62373 .32861 .65687 .3196 .64053 .29872 Metetra
.649 .751 .924 r
.64053 .29872 .65687 .3196 .69036 .30878 .67429 .28759 Metetra
.644 .749 .925 r
.67429 .28759 .69036 .30878 .72428 .29828 .70849 .27674 Metetra
.663 .755 .919 r
.70849 .27674 .72428 .29828 .75851 .28594 .74301 .26423 Metetra
.658 .754 .921 r
.74301 .26423 .75851 .28594 .79318 .27391 .77798 .25197 Metetra
.594 .73 .939 r
.10191 .4632 .12226 .48134 .14964 .47586 .12947 .45713 Metetra
.618 .733 .928 r
.12947 .45713 .14964 .47586 .17754 .46883 .15756 .44965 Metetra
.613 .728 .928 r
.15756 .44965 .17754 .46883 .20576 .46212 .18596 .44244 Metetra
.634 .731 .918 r
.18596 .44244 .20576 .46212 .23447 .45382 .21485 .4338 Metetra
.629 .728 .919 r
.21485 .4338 .23447 .45382 .2635 .44583 .24406 .42541 Metetra
.623 .724 .919 r
.24406 .42541 .2635 .44583 .29287 .43814 .27361 .41727 Metetra
.625 .722 .916 r
.27361 .41727 .29287 .43814 .32261 .43024 .30354 .40894 Metetra
.737 .752 .864 r
.30354 .40894 .32261 .43024 .35333 .41103 .33446 .39039 Metetra
.715 .756 .884 r
.33446 .39039 .35333 .41103 .3841 .39469 .36544 .37442 Metetra
.688 .755 .903 r
.36544 .37442 .3841 .39469 .41501 .38122 .39656 .36101 Metetra
.696 .76 .901 r
.39656 .36101 .41501 .38122 .44623 .36681 .42802 .34675 Metetra
.664 .755 .918 r
.42802 .34675 .44623 .36681 .4777 .35527 .45972 .33505 Metetra
.673 .759 .915 r
.45972 .33505 .4777 .35527 .50952 .34279 .49179 .32249 Metetra
.682 .763 .913 r
.49179 .32249 .50952 .34279 .54168 .32938 .52421 .30907 Metetra
.68 .765 .916 r
.52421 .30907 .54168 .32938 .57417 .31604 .55697 .2957 Metetra
.611 .742 .939 r
.55697 .2957 .57417 .31604 .60714 .30819 .59019 .28727 Metetra
.631 .746 .931 r
.59019 .28727 .60714 .30819 .64053 .29872 .62383 .27736 Metetra
.65 .751 .924 r
.62383 .27736 .64053 .29872 .67429 .28759 .65786 .26593 Metetra
.645 .749 .925 r
.65786 .26593 .67429 .28759 .70849 .27674 .69234 .25474 Metetra
.662 .755 .919 r
.69234 .25474 .70849 .27674 .74301 .26423 .72716 .24202 Metetra
.658 .754 .921 r
.72716 .24202 .74301 .26423 .77798 .25197 .76244 .22952 Metetra
.6 .733 .938 r
.08113 .44481 .10191 .4632 .12947 .45713 .10888 .43823 Metetra
.622 .736 .929 r
.10888 .43823 .12947 .45713 .15756 .44965 .13714 .43035 Metetra
.616 .732 .929 r
.13714 .43035 .15756 .44965 .18596 .44244 .16572 .4227 Metetra
.636 .736 .92 r
.16572 .4227 .18596 .44244 .21485 .4338 .1948 .41373 Metetra
.631 .733 .921 r
.1948 .41373 .21485 .4338 .24406 .42541 .2242 .40498 Metetra
.626 .729 .921 r
.2242 .40498 .24406 .42541 .27361 .41727 .25393 .39645 Metetra
.627 .728 .919 r
.25393 .39645 .27361 .41727 .30354 .40894 .28406 .38772 Metetra
.732 .756 .871 r
.28406 .38772 .30354 .40894 .33446 .39039 .31517 .36964 Metetra
.711 .758 .889 r
.31517 .36964 .33446 .39039 .36544 .37442 .34637 .35389 Metetra
.685 .756 .905 r
.34637 .35389 .36544 .37442 .39656 .36101 .37772 .34048 Metetra
.693 .761 .904 r
.37772 .34048 .39656 .36101 .42802 .34675 .40941 .32627 Metetra
.663 .755 .918 r
.40941 .32627 .42802 .34675 .45972 .33505 .44135 .3144 Metetra
.672 .758 .916 r
.44135 .3144 .45972 .33505 .49179 .32249 .47367 .30172 Metetra
.68 .762 .913 r
.47367 .30172 .49179 .32249 .52421 .30907 .50635 .28824 Metetra
.678 .764 .916 r
.50635 .28824 .52421 .30907 .55697 .2957 .53938 .27479 Metetra
.615 .742 .936 r
.53938 .27479 .55697 .2957 .59019 .28727 .57285 .26583 Metetra
.633 .746 .93 r
.57285 .26583 .59019 .28727 .62383 .27736 .60676 .25551 Metetra
.65 .751 .924 r
.60676 .25551 .62383 .27736 .65786 .26593 .64107 .24378 Metetra
.646 .749 .925 r
.64107 .24378 .65786 .26593 .69234 .25474 .67582 .23225 Metetra
.662 .755 .919 r
.67582 .23225 .69234 .25474 .72716 .24202 .71095 .21931 Metetra
.658 .754 .921 r
.71095 .21931 .72716 .24202 .76244 .22952 .74653 .20655 Metetra
.612 .732 .931 r
.06 .4256 .08113 .44481 .10888 .43823 .08797 .41818 Metetra
.629 .73 .92 r
.08797 .41818 .10888 .43823 .13714 .43035 .11644 .40968 Metetra
.625 .724 .918 r
.11644 .40968 .13714 .43035 .16572 .4227 .14522 .40134 Metetra
.639 .723 .909 r
.14522 .40134 .16572 .4227 .1948 .41373 .17448 .39191 Metetra
.636 .72 .908 r
.17448 .39191 .1948 .41373 .2242 .40498 .20408 .38263 Metetra
.632 .715 .907 r
.20408 .38263 .2242 .40498 .25393 .39645 .23401 .3735 Metetra
.633 .712 .904 r
.23401 .3735 .25393 .39645 .28406 .38772 .26433 .36418 Metetra
.715 .734 .866 r
.26433 .36418 .28406 .38772 .31517 .36964 .29557 .3473 Metetra
.699 .743 .886 r
.29557 .3473 .31517 .36964 .34637 .35389 .32693 .33227 Metetra
.678 .747 .903 r
.32693 .33227 .34637 .35389 .37772 .34048 .35849 .31909 Metetra
.685 .754 .904 r
.35849 .31909 .37772 .34048 .40941 .32627 .3904 .30524 Metetra
.661 .753 .918 r
.3904 .30524 .40941 .32627 .44135 .3144 .42258 .29324 Metetra
.668 .757 .916 r
.42258 .29324 .44135 .3144 .47367 .30172 .45514 .28057 Metetra
.675 .762 .916 r
.45514 .28057 .47367 .30172 .50635 .28824 .48808 .26721 Metetra
.674 .765 .92 r
.48808 .26721 .50635 .28824 .53938 .27479 .5214 .25385 Metetra
.623 .75 .938 r
.5214 .25385 .53938 .27479 .57285 .26583 .55512 .24409 Metetra
.638 .75 .93 r
.55512 .24409 .57285 .26583 .60676 .25551 .58929 .23318 Metetra
.651 .752 .924 r
.58929 .23318 .60676 .25551 .64107 .24378 .62388 .22112 Metetra
.648 .75 .924 r
.62388 .22112 .64107 .24378 .67582 .23225 .65892 .20918 Metetra
.66 .754 .919 r
.65892 .20918 .67582 .23225 .71095 .21931 .69436 .19606 Metetra
.657 .754 .921 r
.69436 .19606 .71095 .21931 .74653 .20655 .73026 .18306 Metetra
.622 .736 .929 r
.03841 .40612 .06 .4256 .08797 .41818 .06662 .39793 Metetra
.634 .734 .92 r
.06662 .39793 .08797 .41818 .11644 .40968 .09528 .38886 Metetra
.631 .729 .918 r
.09528 .38886 .11644 .40968 .14522 .40134 .12428 .37989 Metetra
.642 .728 .911 r
.12428 .37989 .14522 .40134 .17448 .39191 .15373 .37002 Metetra
.639 .725 .91 r
.15373 .37002 .17448 .39191 .20408 .38263 .18352 .36024 Metetra
.636 .721 .909 r
.18352 .36024 .20408 .38263 .23401 .3735 .21365 .35055 Metetra
.637 .718 .906 r
.21365 .35055 .23401 .3735 .26433 .36418 .24417 .34069 Metetra
.704 .736 .876 r
.24417 .34069 .26433 .36418 .29557 .3473 .27554 .32481 Metetra
.69 .744 .892 r
.27554 .32481 .29557 .3473 .32693 .33227 .30708 .31037 Metetra
.674 .747 .906 r
.30708 .31037 .32693 .33227 .35849 .31909 .33884 .29735 Metetra
.679 .753 .907 r
.33884 .29735 .35849 .31909 .3904 .30524 .37097 .28378 Metetra
.66 .753 .919 r
.37097 .28378 .3904 .30524 .42258 .29324 .40338 .27163 Metetra
.665 .756 .918 r
.40338 .27163 .42258 .29324 .45514 .28057 .4362 .25892 Metetra
.671 .76 .917 r
.4362 .25892 .45514 .28057 .48808 .26721 .4694 .24563 Metetra
.67 .763 .92 r
.4694 .24563 .48808 .26721 .5214 .25385 .50299 .2323 Metetra
.63 .752 .935 r
.50299 .2323 .5214 .25385 .55512 .24409 .53698 .22179 Metetra
.641 .751 .928 r
.53698 .22179 .55512 .24409 .58929 .23318 .57142 .21034 Metetra
.652 .752 .923 r
.57142 .21034 .58929 .23318 .62388 .22112 .6063 .19793 Metetra
.649 .751 .924 r
.6063 .19793 .62388 .22112 .65892 .20918 .64163 .18558 Metetra
.659 .753 .92 r
.64163 .18558 .65892 .20918 .69436 .19606 .67738 .17227 Metetra
.656 .753 .921 r
.67738 .17227 .69436 .19606 .73026 .18306 .7136 .159 Metetra
.636 .735 .92 r
.01645 .38579 .03841 .40612 .06662 .39793 .04494 .37649 Metetra
.642 .728 .91 r
.04494 .37649 .06662 .39793 .09528 .38886 .07384 .36663 Metetra
.64 .721 .907 r
.07384 .36663 .09528 .38886 .12428 .37989 .10308 .35677 Metetra
.646 .717 .899 r
.10308 .35677 .12428 .37989 .15373 .37002 .13273 .34633 Metetra
.644 .713 .897 r
.13273 .34633 .15373 .37002 .18352 .36024 .16272 .33589 Metetra
.642 .708 .895 r
.16272 .33589 .18352 .36024 .21365 .35055 .19306 .32545 Metetra
.642 .703 .891 r
.19306 .32545 .21365 .35055 .24417 .34069 .22379 .31484 Metetra
.68 .712 .872 r
.22379 .31484 .24417 .34069 .27554 .32481 .25519 .3007 Metetra
.674 .728 .89 r
.25519 .3007 .27554 .32481 .30708 .31037 .28684 .28732 Metetra
.665 .738 .904 r
.28684 .28732 .30708 .31037 .33884 .29735 .31878 .27471 Metetra
.669 .746 .908 r
.31878 .27471 .33884 .29735 .37097 .28378 .3511 .26171 Metetra
.658 .751 .919 r
.3511 .26171 .37097 .28378 .40338 .27163 .38376 .24948 Metetra
.661 .754 .919 r
.38376 .24948 .40338 .27163 .4362 .25892 .41681 .23685 Metetra
.664 .759 .92 r
.41681 .23685 .4362 .25892 .4694 .24563 .45028 .22383 Metetra
.664 .764 .925 r
.45028 .22383 .4694 .24563 .50299 .2323 .48414 .21071 Metetra
.64 .761 .936 r
.48414 .21071 .50299 .2323 .53698 .22179 .51841 .19916 Metetra
.647 .755 .928 r
.51841 .19916 .53698 .22179 .57142 .21034 .55313 .18699 Metetra
.653 .753 .923 r
.55313 .18699 .57142 .21034 .6063 .19793 .5883 .17419 Metetra
.651 .751 .923 r
.5883 .17419 .6063 .19793 .64163 .18558 .62393 .16136 Metetra
.657 .752 .92 r
.62393 .16136 .64163 .18558 .67738 .17227 .66 .14789 Metetra
.656 .753 .921 r
.66 .14789 .67738 .17227 .7136 .159 .69654 .13438 Metetra
0 g
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.14945 .21117 m
.15407 .21583 L
s
[(5)] .14021 .20185 .9913 1 Mshowa
.2971 .15335 m
.30147 .15825 L
s
[(10)] .28836 .14356 .89202 1 Mshowa
.4535 .09211 m
.45758 .09725 L
s
[(15)] .44535 .08183 .79274 1 Mshowa
.61947 .02712 m
.62321 .03251 L
s
[(20)] .61199 .01634 .69345 1 Mshowa
.125 Mabswid
.17832 .19986 m
.18106 .20269 L
s
.20751 .18843 m
.21022 .19129 L
s
.23703 .17687 m
.23971 .17975 L
s
.26689 .16518 m
.26954 .16809 L
s
.32765 .14139 m
.33024 .14436 L
s
.35857 .12928 m
.36112 .13228 L
s
.38984 .11704 m
.39236 .12006 L
s
.42148 .10465 m
.42397 .1077 L
s
.4859 .07942 m
.48831 .08254 L
s
.51869 .06658 m
.52106 .06973 L
s
.55188 .05359 m
.55421 .05676 L
s
.58547 .04044 m
.58776 .04364 L
s
.12091 .22234 m
.12371 .22511 L
s
.09268 .2334 m
.09551 .23614 L
s
.06477 .24433 m
.06762 .24704 L
s
.65389 .01364 m
.65609 .01691 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0193128 0.97619 0.387175 MathSubStart
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1.04977 -0.0679587 1.04977 [
[.14021 .20185 -5.9739 -9 ]
[.14021 .20185 .0261 0 ]
[.28836 .14356 -11.3521 -9 ]
[.28836 .14356 .64789 0 ]
[.44535 .08183 -10.7564 -9 ]
[.44535 .08183 1.24358 0 ]
[.61199 .01634 -10.1607 -9 ]
[.61199 .01634 1.83927 0 ]
[.76442 .09239 0 -6.16638 ]
[.76442 .09239 6 2.83362 ]
[.83635 .20254 0 -6.06047 ]
[.83635 .20254 12 2.93953 ]
[.90119 .30183 0 -5.96721 ]
[.90119 .30183 12 3.03279 ]
[.95993 .39179 0 -5.88447 ]
[.95993 .39179 12 3.11553 ]
[.02182 .27948 -24 -2.75445 ]
[.02182 .27948 0 6.24555 ]
[.00949 .35678 -6 -2.81992 ]
[.00949 .35678 0 6.18008 ]
[-0.00348 .43805 -18 -2.8891 ]
[-0.00348 .43805 0 6.1109 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.03716 .25514 m
.68874 0 L
s
.14945 .21117 m
.15407 .21583 L
s
[(5)] .14021 .20185 .9913 1 Mshowa
.2971 .15335 m
.30147 .15825 L
s
[(10)] .28836 .14356 .89202 1 Mshowa
.4535 .09211 m
.45758 .09725 L
s
[(15)] .44535 .08183 .79274 1 Mshowa
.61947 .02712 m
.62321 .03251 L
s
[(20)] .61199 .01634 .69345 1 Mshowa
.125 Mabswid
.17832 .19986 m
.18106 .20269 L
s
.20751 .18843 m
.21022 .19129 L
s
.23703 .17687 m
.23971 .17975 L
s
.26689 .16518 m
.26954 .16809 L
s
.32765 .14139 m
.33024 .14436 L
s
.35857 .12928 m
.36112 .13228 L
s
.38984 .11704 m
.39236 .12006 L
s
.42148 .10465 m
.42397 .1077 L
s
.4859 .07942 m
.48831 .08254 L
s
.51869 .06658 m
.52106 .06973 L
s
.55188 .05359 m
.55421 .05676 L
s
.58547 .04044 m
.58776 .04364 L
s
.12091 .22234 m
.12371 .22511 L
s
.09268 .2334 m
.09551 .23614 L
s
.06477 .24433 m
.06762 .24704 L
s
.65389 .01364 m
.65609 .01691 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.75212 .09695 m
.74596 .09923 L
s
[(5)] .76442 .09239 -1 .37031 Mshowa
.82395 .20683 m
.81775 .20898 L
s
[(10)] .83635 .20254 -1 .34677 Mshowa
.88871 .30589 m
.88247 .30793 L
s
[(15)] .90119 .30183 -1 .32605 Mshowa
.94739 .39565 m
.94112 .39758 L
s
[(20)] .95993 .39179 -1 .30766 Mshowa
.125 Mabswid
.76711 .11988 m
.76341 .12123 L
s
.78177 .14231 m
.77807 .14365 L
s
.79613 .16428 m
.79242 .1656 L
s
.81019 .18578 m
.80647 .18708 L
s
.83744 .22746 m
.83371 .22873 L
s
.85065 .24767 m
.84692 .24893 L
s
.86359 .26746 m
.85986 .26871 L
s
.87628 .28687 m
.87254 .2881 L
s
.90091 .32455 m
.89716 .32575 L
s
.91286 .34284 m
.90911 .34403 L
s
.92459 .36078 m
.92084 .36196 L
s
.9361 .37838 m
.93234 .37955 L
s
.7368 .07352 m
.73311 .0749 L
s
.72113 .04956 m
.71746 .05096 L
s
.70512 .02506 m
.70145 .02648 L
s
.95847 .4126 m
.9547 .41375 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03406 .27473 m
.04017 .27236 L
s
[(-0.2)] .02182 .27948 1 -0.3879 Mshowa
.02178 .35219 m
.02793 .3499 L
s
[(0)] .00949 .35678 1 -0.37335 Mshowa
.00887 .43363 m
.01505 .43142 L
s
[(0.2)] -0.00348 .43805 1 -0.35798 Mshowa
.125 Mabswid
.03104 .29374 m
.03472 .29233 L
s
.02799 .31298 m
.03167 .31158 L
s
.02491 .33247 m
.02859 .33108 L
s
.01861 .37217 m
.02231 .3708 L
s
.01541 .39239 m
.01911 .39104 L
s
.01216 .41288 m
.01586 .41154 L
s
.03703 .25595 m
.0407 .25452 L
s
.00554 .45464 m
.00925 .45333 L
s
.00217 .47593 m
.00589 .47463 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.5 Mabswid
.659 .747 .915 r
.38721 .67409 .40219 .68754 .42723 .68048 .4124 .66673 Metetra
.659 .744 .913 r
.4124 .66673 .42723 .68048 .45251 .67333 .43783 .65934 Metetra
.659 .743 .912 r
.43783 .65934 .45251 .67333 .47802 .66612 .4635 .65187 Metetra
.658 .741 .911 r
.4635 .65187 .47802 .66612 .50378 .65881 .48941 .64437 Metetra
.659 .74 .91 r
.48941 .64437 .50378 .65881 .52978 .65144 .51556 .63678 Metetra
.659 .739 .909 r
.51556 .63678 .52978 .65144 .55603 .64401 .54197 .62911 Metetra
.659 .738 .908 r
.54197 .62911 .55603 .64401 .58253 .63651 .56863 .62138 Metetra
.638 .73 .914 r
.56863 .62138 .58253 .63651 .60927 .62813 .59558 .61496 Metetra
.64 .76 .936 r
.59558 .61496 .60927 .62813 .63626 .61989 .6228 .6081 Metetra
.641 .785 .951 r
.6228 .6081 .63626 .61989 .66352 .61178 .65029 .60079 Metetra
.634 .798 .961 r
.65029 .60079 .66352 .61178 .69103 .60354 .67807 .5935 Metetra
.681 .83 .955 r
.67807 .5935 .69103 .60354 .7189 .59689 .70598 .58324 Metetra
.676 .773 .923 r
.70598 .58324 .7189 .59689 .74703 .58973 .73418 .57367 Metetra
.667 .738 .904 r
.73418 .57367 .74703 .58973 .77543 .58203 .76269 .56478 Metetra
.669 .726 .892 r
.76269 .56478 .77543 .58203 .80413 .57438 .79146 .55561 Metetra
.642 .699 .888 r
.79146 .55561 .80413 .57438 .833 .56537 .8207 .54856 Metetra
.648 .728 .907 r
.8207 .54856 .833 .56537 .86219 .55662 .8502 .54084 Metetra
.655 .746 .917 r
.8502 .54084 .86219 .55662 .8917 .54813 .87995 .53244 Metetra
.653 .749 .92 r
.87995 .53244 .8917 .54813 .9215 .53946 .91003 .52412 Metetra
.66 .759 .923 r
.91003 .52412 .9215 .53946 .95164 .53104 .94036 .5151 Metetra
.658 .752 .919 r
.94036 .5151 .95164 .53104 .98209 .52245 .97101 .50616 Metetra
.665 .744 .909 r
.37199 .66008 .38721 .67409 .4124 .66673 .39734 .65217 Metetra
.663 .738 .905 r
.39734 .65217 .4124 .66673 .43783 .65934 .42292 .64438 Metetra
.664 .734 .902 r
.42292 .64438 .43783 .65934 .4635 .65187 .44874 .63646 Metetra
.661 .729 .9 r
.44874 .63646 .4635 .65187 .48941 .64437 .4748 .62867 Metetra
.662 .728 .898 r
.4748 .62867 .48941 .64437 .51556 .63678 .50111 .62075 Metetra
.662 .725 .896 r
.50111 .62075 .51556 .63678 .54197 .62911 .52767 .6127 Metetra
.662 .722 .894 r
.52767 .6127 .54197 .62911 .56863 .62138 .55448 .60459 Metetra
.558 .681 .921 r
.55448 .60459 .56863 .62138 .59558 .61496 .58166 .60303 Metetra
.559 .756 .97 r
.58166 .60303 .59558 .61496 .6228 .6081 .60917 .59966 Metetra
.559 .819 .994 r
.60917 .59966 .6228 .6081 .65029 .60079 .63696 .59445 Metetra
.501 .834 .999 r
.63696 .59445 .65029 .60079 .67807 .5935 .6651 .58966 Metetra
.781 .947 .93 r
.6651 .58966 .67807 .5935 .70598 .58324 .69289 .57092 Metetra
.744 .814 .907 r
.69289 .57092 .70598 .58324 .73418 .57367 .721 .55582 Metetra
.694 .73 .878 r
.721 .55582 .73418 .57367 .76269 .56478 .74953 .54432 Metetra
.699 .705 .852 r
.74953 .54432 .76269 .56478 .79146 .55561 .77822 .53173 Metetra
.585 .624 .857 r
.77822 .53173 .79146 .55561 .8207 .54856 .80801 .52954 Metetra
.613 .689 .897 r
.80801 .52954 .8207 .54856 .8502 .54084 .83796 .52449 Metetra
.647 .739 .916 r
.83796 .52449 .8502 .54084 .87995 .53244 .86799 .51653 Metetra
.635 .743 .926 r
.86799 .51653 .87995 .53244 .91003 .52412 .89843 .50924 Metetra
.673 .775 .927 r
.89843 .50924 .91003 .52412 .94036 .5151 .92887 .49901 Metetra
.664 .757 .919 r
.92887 .49901 .94036 .5151 .97101 .50616 .95971 .48945 Metetra
.657 .759 .925 r
.35644 .64707 .37199 .66008 .39734 .65217 .38193 .63951 Metetra
.656 .766 .931 r
.38193 .63951 .39734 .65217 .42292 .64438 .40766 .6319 Metetra
.655 .771 .934 r
.40766 .6319 .42292 .64438 .44874 .63646 .43364 .62421 Metetra
.654 .776 .938 r
.43364 .62421 .44874 .63646 .4748 .62867 .45987 .61647 Metetra
.654 .778 .94 r
.45987 .61647 .4748 .62867 .50111 .62075 .48636 .60864 Metetra
.653 .782 .942 r
.48636 .60864 .50111 .62075 .52767 .6127 .5131 .60073 Metetra
.653 .786 .945 r
.5131 .60073 .52767 .6127 .55448 .60459 .54011 .59275 Metetra
.641 .787 .952 r
.54011 .59275 .55448 .60459 .58166 .60303 .56739 .58528 Metetra
.653 .711 .89 r
.56739 .58528 .58166 .60303 .60917 .59966 .59495 .57758 Metetra
.652 .667 .852 r
.59495 .57758 .60917 .59966 .63696 .59445 .62279 .56963 Metetra
.649 .644 .832 r
.62279 .56963 .63696 .59445 .6651 .58966 .65091 .56165 Metetra
.656 .626 .808 r
.65091 .56165 .6651 .58966 .69289 .57092 .67926 .55235 Metetra
.665 .713 .884 r
.67926 .55235 .69289 .57092 .721 .55582 .70791 .54329 Metetra
.655 .794 .948 r
.70791 .54329 .721 .55582 .74953 .54432 .73685 .53448 Metetra
.643 .836 .975 r
.73685 .53448 .74953 .54432 .77822 .53173 .76608 .52548 Metetra
.572 .875 .994 r
.76608 .52548 .77822 .53173 .80801 .52954 .79569 .51735 Metetra
.642 .802 .959 r
.79569 .51735 .80801 .52954 .83796 .52449 .82558 .50887 Metetra
.655 .757 .924 r
.82558 .50887 .83796 .52449 .86799 .51653 .85577 .50005 Metetra
.655 .747 .918 r
.85577 .50005 .86799 .51653 .89843 .50924 .88628 .4912 Metetra
.659 .731 .903 r
.88628 .4912 .89843 .50924 .92887 .49901 .91709 .482 Metetra
.658 .746 .915 r
.91709 .482 .92887 .49901 .95971 .48945 .94823 .47278 Metetra
.654 .754 .923 r
.34064 .63348 .35644 .64707 .38193 .63951 .36627 .62604 Metetra
.654 .757 .925 r
.36627 .62604 .38193 .63951 .40766 .6319 .39215 .61845 Metetra
.654 .759 .927 r
.39215 .61845 .40766 .6319 .43364 .62421 .41829 .61081 Metetra
.655 .762 .929 r
.41829 .61081 .43364 .62421 .45987 .61647 .44468 .60301 Metetra
.654 .763 .93 r
.44468 .60301 .45987 .61647 .48636 .60864 .47134 .59516 Metetra
.654 .765 .931 r
.47134 .59516 .48636 .60864 .5131 .60073 .49826 .58725 Metetra
.654 .767 .933 r
.49826 .58725 .5131 .60073 .54011 .59275 .52546 .57926 Metetra
.689 .778 .919 r
.52546 .57926 .54011 .59275 .56739 .58528 .5529 .56874 Metetra
.68 .737 .894 r
.5529 .56874 .56739 .58528 .59495 .57758 .58059 .55878 Metetra
.67 .71 .878 r
.58059 .55878 .59495 .57758 .62279 .56963 .60855 .54939 Metetra
.67 .696 .866 r
.60855 .54939 .62279 .56963 .65091 .56165 .63677 .53974 Metetra
.61 .657 .871 r
.63677 .53974 .65091 .56165 .67926 .55235 .66547 .53508 Metetra
.623 .716 .913 r
.66547 .53508 .67926 .55235 .70791 .54329 .69446 .52899 Metetra
.637 .764 .94 r
.69446 .52899 .70791 .54329 .73685 .53448 .72372 .52145 Metetra
.625 .782 .956 r
.72372 .52145 .73685 .53448 .76608 .52548 .75332 .5142 Metetra
.683 .831 .955 r
.75332 .5142 .76608 .52548 .79569 .51735 .78295 .50296 Metetra
.673 .783 .932 r
.78295 .50296 .79569 .51735 .82558 .50887 .81294 .49266 Metetra
.661 .755 .92 r
.81294 .49266 .82558 .50887 .85577 .50005 .84332 .48332 Metetra
.665 .752 .915 r
.84332 .48332 .85577 .50005 .88628 .4912 .87399 .47359 Metetra
.651 .737 .913 r
.87399 .47359 .88628 .4912 .91709 .482 .9051 .46483 Metetra
.654 .747 .918 r
.9051 .46483 .91709 .482 .94823 .47278 .93651 .45568 Metetra
.63 .766 .945 r
.32447 .62091 .34064 .63348 .36627 .62604 .3502 .6145 Metetra
.635 .785 .954 r
.3502 .6145 .36627 .62604 .39215 .61845 .37623 .60753 Metetra
.629 .795 .962 r
.37623 .60753 .39215 .61845 .41829 .61081 .40252 .60061 Metetra
.635 .81 .967 r
.40252 .60061 .41829 .61081 .44468 .60301 .4291 .59312 Metetra
.629 .816 .972 r
.4291 .59312 .44468 .60301 .47134 .59516 .45595 .58568 Metetra
.622 .823 .977 r
.45595 .58568 .47134 .59516 .49826 .58725 .48308 .57831 Metetra
.618 .832 .982 r
.48308 .57831 .49826 .58725 .52546 .57926 .51049 .57082 Metetra
.836 .862 .864 r
.51049 .57082 .52546 .57926 .5529 .56874 .53813 .5463 Metetra
.75 .703 .807 r
.53813 .5463 .5529 .56874 .58059 .55878 .56583 .52626 Metetra
.692 .619 .77 r
.56583 .52626 .58059 .55878 .60855 .54939 .59372 .51064 Metetra
.685 .59 .743 r
.59372 .51064 .60855 .54939 .63677 .53974 .62173 .49373 Metetra
.413 .405 .741 r
.62173 .49373 .63677 .53974 .66547 .53508 .65121 .51146 Metetra
.398 .537 .879 r
.65121 .51146 .66547 .53508 .69446 .52899 .68102 .52011 Metetra
.403 .756 .994 r
.68102 .52011 .69446 .52899 .72372 .52145 .71093 .51932 Metetra
.025 .592 .782 r
.71093 .51932 .72372 .52145 .75332 .5142 .74146 .52111 Metetra
.614 .924 .677 r
.74146 .52111 .75332 .5142 .78295 .50296 .77049 .49554 Metetra
.768 .918 .938 r
.77049 .49554 .78295 .50296 .81294 .49266 .80014 .47719 Metetra
.682 .777 .923 r
.80014 .47719 .81294 .49266 .84332 .48332 .83061 .46601 Metetra
.704 .763 .898 r
.83061 .46601 .84332 .48332 .87399 .47359 .86117 .45276 Metetra
.617 .688 .894 r
.86117 .45276 .87399 .47359 .9051 .46483 .8928 .4467 Metetra
.639 .732 .916 r
.8928 .4467 .9051 .46483 .93651 .45568 .9246 .43859 Metetra
.578 .771 .971 r
.30791 .60936 .32447 .62091 .3502 .6145 .3337 .60494 Metetra
.591 .808 .983 r
.3337 .60494 .3502 .6145 .37623 .60753 .35985 .59917 Metetra
.566 .822 .994 r
.35985 .59917 .37623 .60753 .40252 .60061 .38628 .59369 Metetra
.581 .852 .995 r
.38628 .59369 .40252 .60061 .4291 .59312 .41306 .58686 Metetra
.558 .856 .997 r
.41306 .58686 .4291 .59312 .45595 .58568 .44012 .5803 Metetra
.526 .859 .995 r
.44012 .5803 .45595 .58568 .48308 .57831 .46748 .57401 Metetra
.5 .864 .986 r
.46748 .57401 .48308 .57831 .51049 .57082 .49515 .56756 Metetra
.939 .865 .74 r
.49515 .56756 .51049 .57082 .53813 .5463 .52315 .51794 Metetra
.805 .685 .731 r
.52315 .51794 .53813 .5463 .56583 .52626 .55085 .48022 Metetra
.713 .582 .708 r
.55085 .48022 .56583 .52626 .59372 .51064 .57852 .45387 Metetra
.702 .554 .683 r
.57852 .45387 .59372 .51064 .62173 .49373 .6061 .42459 Metetra
.141 .163 .623 r
.6061 .42459 .62173 .49373 .65121 .51146 .63653 .4815 Metetra
0 .161 .698 r
.63653 .4815 .65121 .51146 .68102 .52011 .6675 .51681 Metetra
.322 0 0 r
.6675 .51681 .68102 .52011 .71093 .51932 .69836 .52852 Metetra
.634 .126 .024 r
.69836 .52852 .71093 .51932 .74146 .52111 .73036 .54726 Metetra
.73036 .54726 .74146 .52111 .77049 .49554 .75823 .4953 Metetra
.879 .989 .813 r
.75823 .4953 .77049 .49554 .80014 .47719 .78715 .46246 Metetra
.719 .804 .917 r
.78715 .46246 .80014 .47719 .83061 .46601 .81762 .44809 Metetra
.762 .779 .867 r
.81762 .44809 .83061 .46601 .86117 .45276 .84783 .42868 Metetra
.556 .628 .879 r
.84783 .42868 .86117 .45276 .8928 .4467 .8802 .4276 Metetra
.61 .711 .917 r
.8802 .4276 .8928 .4467 .9246 .43859 .91249 .42151 Metetra
.625 .718 .913 r
.29135 .59284 .30791 .60936 .3337 .60494 .31734 .58691 Metetra
.638 .705 .895 r
.31734 .58691 .3337 .60494 .35985 .59917 .34366 .58014 Metetra
.635 .695 .888 r
.34366 .58014 .35985 .59917 .38628 .59369 .37026 .57349 Metetra
.646 .687 .875 r
.37026 .57349 .38628 .59369 .41306 .58686 .39718 .56599 Metetra
.643 .681 .871 r
.39718 .56599 .41306 .58686 .44012 .5803 .42438 .55862 Metetra
.64 .674 .867 r
.42438 .55862 .44012 .5803 .46748 .57401 .45187 .55138 Metetra
.64 .667 .86 r
.45187 .55138 .46748 .57401 .49515 .56756 .47966 .54401 Metetra
.811 .714 .758 r
.47966 .54401 .49515 .56756 .52315 .51794 .5079 .51016 Metetra
.852 .877 .858 r
.5079 .51016 .52315 .51794 .55085 .48022 .53602 .48342 Metetra
.688 .981 .856 r
.53602 .48342 .55085 .48022 .57852 .45387 .5642 .46361 Metetra
.488 .855 .619 r
.5642 .46361 .57852 .45387 .6061 .42459 .59245 .44188 Metetra
.733 .311 .247 r
.59245 .44188 .6061 .42459 .63653 .4815 .62236 .47366 Metetra
.38 0 0 r
.62236 .47366 .63653 .4815 .6675 .51681 .65277 .49165 Metetra
.491 .583 .874 r
.65277 .49165 .6675 .51681 .69836 .52852 .6833 .49506 Metetra
.471 .51 .816 r
.6833 .49506 .69836 .52852 .73036 .54726 .71462 .50259 Metetra
.751 .615 .708 r
.71462 .50259 .73036 .54726 .75823 .4953 .74375 .4673 Metetra
.754 .688 .788 r
.74375 .4673 .75823 .4953 .78715 .46246 .77359 .44344 Metetra
.693 .745 .891 r
.77359 .44344 .78715 .46246 .81762 .44809 .80446 .4308 Metetra
.728 .78 .894 r
.80446 .4308 .81762 .44809 .84783 .42868 .83532 .41502 Metetra
.555 .765 .976 r
.83532 .41502 .84783 .42868 .8802 .4276 .86759 .41044 Metetra
.625 .748 .935 r
.86759 .41044 .8802 .4276 .91249 .42151 .89997 .40274 Metetra
.641 .728 .911 r
.27447 .57649 .29135 .59284 .31734 .58691 .30066 .56938 Metetra
.647 .717 .899 r
.30066 .56938 .31734 .58691 .34366 .58014 .32716 .56178 Metetra
.646 .709 .893 r
.32716 .56178 .34366 .58014 .37026 .57349 .35393 .55422 Metetra
.651 .702 .884 r
.35393 .55422 .37026 .57349 .39718 .56599 .381 .54617 Metetra
.649 .698 .881 r
.381 .54617 .39718 .56599 .42438 .55862 .40835 .53815 Metetra
.648 .692 .877 r
.40835 .53815 .42438 .55862 .45187 .55138 .43599 .53015 Metetra
.648 .686 .872 r
.43599 .53015 .45187 .55138 .47966 .54401 .46392 .52203 Metetra
.762 .717 .81 r
.46392 .52203 .47966 .54401 .5079 .51016 .49229 .50018 Metetra
.777 .857 .91 r
.49229 .50018 .5079 .51016 .53602 .48342 .52073 .48191 Metetra
.665 .956 .946 r
.52073 .48191 .53602 .48342 .5642 .46361 .54933 .46717 Metetra
.54 .925 .825 r
.54933 .46717 .5642 .46361 .59245 .44188 .57811 .45135 Metetra
.561 .045 0 r
.57811 .45135 .59245 .44188 .62236 .47366 .60778 .46346 Metetra
.217 .636 .954 r
.60778 .46346 .62236 .47366 .65277 .49165 .6379 .46818 Metetra
.575 .645 .882 r
.6379 .46818 .65277 .49165 .6833 .49506 .66826 .46527 Metetra
.559 .585 .837 r
.66826 .46527 .6833 .49506 .71462 .50259 .69919 .4644 Metetra
.716 .62 .749 r
.69919 .4644 .71462 .50259 .74375 .4673 .72924 .44153 Metetra
.717 .692 .825 r
.72924 .44153 .74375 .4673 .77359 .44344 .7598 .42444 Metetra
.676 .743 .901 r
.7598 .42444 .77359 .44344 .80446 .4308 .79102 .41306 Metetra
.696 .768 .907 r
.79102 .41306 .80446 .4308 .83532 .41502 .82242 .40001 Metetra
.609 .774 .959 r
.82242 .40001 .83532 .41502 .86759 .41044 .8547 .3927 Metetra
.641 .752 .929 r
.8547 .3927 .86759 .41044 .89997 .40274 .88722 .38371 Metetra
.672 .717 .882 r
.25743 .55816 .27447 .57649 .30066 .56938 .28391 .54861 Metetra
.664 .691 .865 r
.28391 .54861 .30066 .56938 .32716 .56178 .31061 .5394 Metetra
.663 .677 .853 r
.31061 .5394 .32716 .56178 .35393 .55422 .33759 .52999 Metetra
.656 .66 .842 r
.33759 .52999 .35393 .55422 .381 .54617 .3648 .52092 Metetra
.656 .653 .836 r
.3648 .52092 .381 .54617 .40835 .53815 .39229 .51164 Metetra
.655 .645 .828 r
.39229 .51164 .40835 .53815 .43599 .53015 .42006 .50215 Metetra
.653 .635 .819 r
.42006 .50215 .43599 .53015 .46392 .52203 .4481 .4926 Metetra
.474 .538 .842 r
.4481 .4926 .46392 .52203 .49229 .50018 .47622 .49755 Metetra
.063 .62 .808 r
.47622 .49755 .49229 .50018 .52073 .48191 .50489 .49863 Metetra
.341 0 0 r
.50489 .49863 .52073 .48191 .54933 .46717 .53404 .49574 Metetra
.446 .042 .179 r
.53404 .49574 .54933 .46717 .57811 .45135 .56362 .49388 Metetra
.123 0 .143 r
.56362 .49388 .57811 .45135 .60778 .46346 .59302 .46118 Metetra
.821 .973 .894 r
.59302 .46118 .60778 .46346 .6379 .46818 .62256 .43669 Metetra
.697 .642 .791 r
.62256 .43669 .6379 .46818 .66826 .46527 .65246 .42026 Metetra
.679 .576 .733 r
.65246 .42026 .66826 .46527 .69919 .4644 .68245 .40155 Metetra
.537 .447 .701 r
.68245 .40155 .69919 .4644 .72924 .44153 .71395 .40568 Metetra
.572 .558 .8 r
.71395 .40568 .72924 .44153 .7598 .42444 .74564 .40364 Metetra
.637 .711 .901 r
.74564 .40364 .7598 .42444 .79102 .41306 .77734 .39531 Metetra
.608 .738 .937 r
.77734 .39531 .79102 .41306 .82242 .40001 .80958 .38855 Metetra
.684 .861 .966 r
.80958 .38855 .82242 .40001 .8547 .3927 .84162 .37541 Metetra
.672 .775 .927 r
.84162 .37541 .8547 .3927 .88722 .38371 .87415 .36383 Metetra
.705 .708 .85 r
.24024 .53783 .25743 .55816 .28391 .54861 .26712 .52459 Metetra
.681 .671 .833 r
.26712 .52459 .28391 .54861 .31061 .5394 .29408 .51297 Metetra
.68 .653 .817 r
.29408 .51297 .31061 .5394 .33759 .52999 .3213 .5008 Metetra
.66 .628 .807 r
.3213 .5008 .33759 .52999 .3648 .52092 .34865 .49024 Metetra
.662 .621 .798 r
.34865 .49024 .3648 .52092 .39229 .51164 .37628 .47912 Metetra
.662 .612 .788 r
.37628 .47912 .39229 .51164 .42006 .50215 .40417 .46744 Metetra
.658 .599 .778 r
.40417 .46744 .42006 .50215 .4481 .4926 .4323 .45578 Metetra
0 0 .511 r
.4323 .45578 .4481 .4926 .47622 .49755 .45954 .50257 Metetra
.76 .285 .115 r
.45954 .50257 .47622 .49755 .50489 .49863 .48821 .53501 Metetra
.612 .236 .307 r
.48821 .53501 .50489 .49863 .53404 .49574 .51796 .55184 Metetra
.618 .283 .379 r
.51796 .55184 .53404 .49574 .56362 .49388 .54854 .57369 Metetra
0 0 .066 r
.54854 .57369 .56362 .49388 .59302 .46118 .57796 .46714 Metetra
.983 .904 .641 r
.57796 .46714 .59302 .46118 .62256 .43669 .60685 .39727 Metetra
.772 .642 .717 r
.60685 .39727 .62256 .43669 .65246 .42026 .6361 .36056 Metetra
.746 .579 .669 r
.6361 .36056 .65246 .42026 .68245 .40155 .6648 .31573 Metetra
.321 .267 .64 r
.6648 .31573 .68245 .40155 .71395 .40568 .69799 .35992 Metetra
.351 .381 .752 r
.69799 .35992 .71395 .40568 .74564 .40364 .73112 .38104 Metetra
.571 .665 .902 r
.73112 .38104 .74564 .40364 .77734 .39531 .76339 .37753 Metetra
.415 .646 .953 r
.76339 .37753 .77734 .39531 .80958 .38855 .79675 .38074 Metetra
.791 .94 .925 r
.79675 .38074 .80958 .38855 .84162 .37541 .82834 .35857 Metetra
.718 .803 .917 r
.82834 .35857 .84162 .37541 .87415 .36383 .86077 .34305 Metetra
.707 .778 .907 r
.2222 .5235 .24024 .53783 .26712 .52459 .24919 .51119 Metetra
.691 .79 .926 r
.24919 .51119 .26712 .52459 .29408 .51297 .2763 .5001 Metetra
.696 .8 .93 r
.2763 .5001 .29408 .51297 .3213 .5008 .30368 .48855 Metetra
.675 .807 .946 r
.30368 .48855 .3213 .5008 .34865 .49024 .33122 .47823 Metetra
.68 .814 .947 r
.33122 .47823 .34865 .49024 .37628 .47912 .35905 .46745 Metetra
.685 .822 .949 r
.35905 .46745 .37628 .47912 .40417 .46744 .38715 .45622 Metetra
.682 .831 .955 r
.38715 .45622 .40417 .46744 .4323 .45578 .41551 .44497 Metetra
.73 .211 0 r
.41551 .44497 .4323 .45578 .45954 .50257 .44302 .47861 Metetra
0 .266 .774 r
.44302 .47861 .45954 .50257 .48821 .53501 .47178 .50098 Metetra
.399 .475 .822 r
.47178 .50098 .48821 .53501 .51796 .55184 .5015 .51132 Metetra
.383 .429 .784 r
.5015 .51132 .51796 .55184 .54854 .57369 .53193 .52535 Metetra
.847 .656 .644 r
.53193 .52535 .54854 .57369 .57796 .46714 .56202 .4419 Metetra
.875 .737 .706 r
.56202 .4419 .57796 .46714 .60685 .39727 .59163 .38579 Metetra
.861 .862 .839 r
.59163 .38579 .60685 .39727 .6361 .36056 .62147 .355 Metetra
.911 .923 .81 r
.62147 .355 .6361 .36056 .6648 .31573 .65099 .31779 Metetra
.719 .193 0 r
.65099 .31779 .6648 .31573 .69799 .35992 .68377 .34959 Metetra
0 .401 .802 r
.68377 .34959 .69799 .35992 .73112 .38104 .71665 .36334 Metetra
.577 .732 .948 r
.71665 .36334 .73112 .38104 .76339 .37753 .74906 .35806 Metetra
.494 .671 .943 r
.74906 .35806 .76339 .37753 .79675 .38074 .78235 .3579 Metetra
.743 .746 .854 r
.78235 .3579 .79675 .38074 .82834 .35857 .81447 .33824 Metetra
.701 .759 .897 r
.81447 .33824 .82834 .35857 .86077 .34305 .84729 .32365 Metetra
.695 .773 .912 r
.20383 .50866 .2222 .5235 .24919 .51119 .23093 .49712 Metetra
.682 .783 .927 r
.23093 .49712 .24919 .51119 .2763 .5001 .25819 .48646 Metetra
.686 .792 .93 r
.25819 .48646 .2763 .5001 .30368 .48855 .28572 .47543 Metetra
.67 .798 .943 r
.28572 .47543 .30368 .48855 .33122 .47823 .31345 .46528 Metetra
.674 .804 .944 r
.31345 .46528 .33122 .47823 .35905 .46745 .34147 .45477 Metetra
.677 .81 .946 r
.34147 .45477 .35905 .46745 .38715 .45622 .36978 .44389 Metetra
.675 .817 .951 r
.36978 .44389 .38715 .45622 .41551 .44497 .39836 .43298 Metetra
.491 0 0 r
.39836 .43298 .41551 .44497 .44302 .47861 .42622 .45528 Metetra
.175 .441 .872 r
.42622 .45528 .44302 .47861 .47178 .50098 .45513 .46908 Metetra
.469 .532 .84 r
.45513 .46908 .47178 .50098 .5015 .51132 .4849 .47392 Metetra
.453 .489 .806 r
.4849 .47392 .5015 .51132 .53193 .52535 .51526 .48138 Metetra
.828 .658 .671 r
.51526 .48138 .53193 .52535 .56202 .4419 .54583 .41735 Metetra
.852 .741 .741 r
.54583 .41735 .56202 .4419 .59163 .38579 .57602 .37303 Metetra
.825 .853 .869 r
.57602 .37303 .59163 .38579 .62147 .355 .60637 .34735 Metetra
.872 .916 .856 r
.60637 .34735 .62147 .355 .65099 .31779 .6366 .31678 Metetra
.566 0 0 r
.6366 .31678 .65099 .31779 .68377 .34959 .66911 .33773 Metetra
.152 .581 .932 r
.66911 .33773 .68377 .34959 .71665 .36334 .70187 .34507 Metetra
.6 .74 .942 r
.70187 .34507 .71665 .36334 .74906 .35806 .73442 .33823 Metetra
.543 .696 .939 r
.73442 .33823 .74906 .35806 .78235 .3579 .76773 .33515 Metetra
.724 .744 .868 r
.76773 .33515 .78235 .3579 .81447 .33824 .80032 .3176 Metetra
.69 .756 .902 r
.80032 .3176 .81447 .33824 .84729 .32365 .83352 .30376 Metetra
.673 .78 .93 r
.185 .49437 .20383 .50866 .23093 .49712 .21215 .48421 Metetra
.665 .799 .946 r
.21215 .48421 .23093 .49712 .25819 .48646 .23952 .47437 Metetra
.665 .813 .954 r
.23952 .47437 .25819 .48646 .28572 .47543 .26719 .46432 Metetra
.654 .826 .966 r
.26719 .46432 .28572 .47543 .31345 .46528 .29511 .45457 Metetra
.654 .834 .969 r
.29511 .45457 .31345 .46528 .34147 .45477 .32332 .44462 Metetra
.653 .844 .974 r
.32332 .44462 .34147 .45477 .36978 .44389 .35184 .43445 Metetra
.647 .855 .979 r
.35184 .43445 .36978 .44389 .39836 .43298 .38065 .4242 Metetra
.157 .633 .926 r
.38065 .4242 .39836 .43298 .42622 .45528 .40927 .42781 Metetra
.526 .597 .869 r
.40927 .42781 .42622 .45528 .45513 .46908 .43854 .42769 Metetra
.58 .54 .775 r
.43854 .42769 .45513 .46908 .4849 .47392 .46838 .42375 Metetra
.569 .502 .74 r
.46838 .42375 .4849 .47392 .51526 .48138 .49865 .42079 Metetra
.706 .558 .685 r
.49865 .42079 .51526 .48138 .54583 .41735 .52936 .38834 Metetra
.754 .691 .791 r
.52936 .38834 .54583 .41735 .57602 .37303 .56007 .36372 Metetra
.738 .896 .95 r
.56007 .36372 .57602 .37303 .60637 .34735 .59101 .34679 Metetra
.684 .975 .908 r
.59101 .34679 .60637 .34735 .6366 .31678 .6221 .32766 Metetra
.354 0 0 r
.6221 .32766 .6366 .31678 .66911 .33773 .65428 .33033 Metetra
.378 .789 .98 r
.65428 .33033 .66911 .33773 .70187 .34507 .6868 .32709 Metetra
.633 .762 .94 r
.6868 .32709 .70187 .34507 .73442 .33823 .71947 .31781 Metetra
.614 .727 .926 r
.71947 .31781 .73442 .33823 .76773 .33515 .75268 .31002 Metetra
.683 .71 .868 r
.75268 .31002 .76773 .33515 .80032 .3176 .78583 .29611 Metetra
.671 .744 .905 r
.78583 .29611 .80032 .3176 .83352 .30376 .81947 .28368 Metetra
.636 .783 .952 r
.16569 .48061 .185 .49437 .21215 .48421 .19281 .47248 Metetra
.636 .813 .968 r
.19281 .47248 .21215 .48421 .23952 .47437 .22027 .46386 Metetra
.627 .83 .979 r
.22027 .46386 .23952 .47437 .26719 .46432 .24803 .45525 Metetra
.624 .852 .986 r
.24803 .45525 .26719 .46432 .29511 .45457 .27614 .44615 Metetra
.615 .86 .989 r
.27614 .44615 .29511 .45457 .32332 .44462 .30454 .43706 Metetra
.602 .87 .993 r
.30454 .43706 .32332 .44462 .35184 .43445 .33326 .42797 Metetra
.587 .881 .992 r
.33326 .42797 .35184 .43445 .38065 .4242 .36231 .41875 Metetra
.81 .926 .912 r
.36231 .41875 .38065 .4242 .40927 .42781 .39223 .39619 Metetra
.713 .655 .79 r
.39223 .39619 .40927 .42781 .43854 .42769 .42213 .37708 Metetra
.651 .547 .724 r
.42213 .37708 .43854 .42769 .46838 .42375 .45212 .36138 Metetra
.639 .513 .693 r
.45212 .36138 .46838 .42375 .49865 .42079 .48234 .34462 Metetra
.484 .389 .672 r
.48234 .34462 .49865 .42079 .52936 .38834 .51268 .35489 Metetra
.49 .54 .835 r
.51268 .35489 .52936 .38834 .56007 .36372 .54371 .35798 Metetra
.374 .805 .966 r
.54371 .35798 .56007 .36372 .59101 .34679 .57525 .35365 Metetra
.129 0 0 r
.57525 .35365 .59101 .34679 .6221 .32766 .60734 .35126 Metetra
.60734 .35126 .6221 .32766 .65428 .33033 .63919 .32756 Metetra
.677 .965 .933 r
.63919 .32756 .65428 .33033 .6868 .32709 .67142 .30942 Metetra
.676 .787 .933 r
.67142 .30942 .6868 .32709 .71947 .31781 .70419 .29679 Metetra
.693 .757 .901 r
.70419 .29679 .71947 .31781 .75268 .31002 .73722 .28252 Metetra
.624 .666 .87 r
.73722 .28252 .75268 .31002 .78583 .29611 .77101 .27377 Metetra
.643 .728 .91 r
.77101 .27377 .78583 .29611 .81947 .28368 .80513 .26338 Metetra
.642 .745 .923 r
.14632 .46341 .16569 .48061 .19281 .47248 .17361 .455 Metetra
.648 .745 .92 r
.17361 .455 .19281 .47248 .22027 .46386 .20125 .44613 Metetra
.646 .744 .92 r
.20125 .44613 .22027 .46386 .24803 .45525 .22918 .43726 Metetra
.652 .744 .918 r
.22918 .43726 .24803 .45525 .27614 .44615 .25746 .42794 Metetra
.65 .744 .918 r
.25746 .42794 .27614 .44615 .30454 .43706 .28605 .4186 Metetra
.649 .743 .918 r
.28605 .4186 .30454 .43706 .33326 .42797 .31496 .40926 Metetra
.649 .742 .917 r
.31496 .40926 .33326 .42797 .36231 .41875 .34419 .39978 Metetra
.771 .77 .852 r
.34419 .39978 .36231 .41875 .39223 .39619 .37433 .37817 Metetra
.75 .779 .877 r
.37433 .37817 .39223 .39619 .42213 .37708 .40447 .35967 Metetra
.721 .782 .901 r
.40447 .35967 .42213 .37708 .45212 .36138 .43469 .34426 Metetra
.731 .791 .9 r
.43469 .34426 .45212 .36138 .48234 .34462 .46517 .32786 Metetra
.194 .551 .931 r
.46517 .32786 .48234 .34462 .51268 .35489 .49566 .33606 Metetra
.424 .656 .956 r
.49566 .33606 .51268 .35489 .54371 .35798 .52685 .33769 Metetra
.572 .71 .936 r
.52685 .33769 .54371 .35798 .57525 .35365 .55859 .33256 Metetra
.542 .69 .935 r
.55859 .33256 .57525 .35365 .60734 .35126 .59085 .32918 Metetra
.767 .766 .851 r
.59085 .32918 .60734 .35126 .63919 .32756 .62303 .30642 Metetra
.728 .767 .883 r
.62303 .30642 .63919 .32756 .67142 .30942 .65557 .28869 Metetra
.674 .755 .912 r
.65557 .28869 .67142 .30942 .70419 .29679 .68862 .27597 Metetra
.69 .763 .907 r
.68862 .27597 .70419 .29679 .73722 .28252 .72195 .26172 Metetra
.625 .74 .929 r
.72195 .26172 .73722 .28252 .77101 .27377 .756 .25248 Metetra
.644 .745 .923 r
.756 .25248 .77101 .27377 .80513 .26338 .79039 .24174 Metetra
.644 .745 .923 r
.12658 .44586 .14632 .46341 .17361 .455 .15404 .43716 Metetra
.649 .745 .92 r
.15404 .43716 .17361 .455 .20125 .44613 .18185 .42804 Metetra
.647 .744 .92 r
.18185 .42804 .20125 .44613 .22918 .43726 .20996 .4189 Metetra
.652 .744 .917 r
.20996 .4189 .22918 .43726 .25746 .42794 .23842 .40934 Metetra
.651 .744 .917 r
.23842 .40934 .25746 .42794 .28605 .4186 .26719 .39975 Metetra
.65 .743 .917 r
.26719 .39975 .28605 .4186 .31496 .40926 .29628 .39014 Metetra
.65 .742 .917 r
.29628 .39014 .31496 .40926 .34419 .39978 .32571 .3804 Metetra
.762 .768 .858 r
.32571 .3804 .34419 .39978 .37433 .37817 .35605 .3598 Metetra
.742 .778 .882 r
.35605 .3598 .37433 .37817 .40447 .35967 .38641 .34195 Metetra
.715 .782 .905 r
.38641 .34195 .40447 .35967 .43469 .34426 .41687 .32685 Metetra
.724 .79 .905 r
.41687 .32685 .43469 .34426 .46517 .32786 .44761 .31085 Metetra
.261 .594 .949 r
.44761 .31085 .46517 .32786 .49566 .33606 .47827 .31685 Metetra
.457 .673 .957 r
.47827 .31685 .49566 .33606 .52685 .33769 .50964 .31695 Metetra
.582 .714 .933 r
.50964 .31695 .52685 .33769 .55859 .33256 .54158 .31098 Metetra
.557 .696 .933 r
.54158 .31098 .55859 .33256 .59085 .32918 .57402 .30655 Metetra
.757 .762 .857 r
.57402 .30655 .59085 .32918 .62303 .30642 .60653 .2848 Metetra
.721 .764 .887 r
.60653 .2848 .62303 .30642 .65557 .28869 .63938 .26751 Metetra
.672 .754 .912 r
.63938 .26751 .65557 .28869 .68862 .27597 .67271 .25468 Metetra
.687 .762 .908 r
.67271 .25468 .68862 .27597 .72195 .26172 .70634 .24048 Metetra
.629 .742 .929 r
.70634 .24048 .72195 .26172 .756 .25248 .74065 .23073 Metetra
.646 .746 .922 r
.74065 .23073 .756 .25248 .79039 .24174 .77532 .21961 Metetra
.645 .746 .922 r
.10644 .42799 .12658 .44586 .15404 .43716 .13407 .41901 Metetra
.65 .746 .92 r
.13407 .41901 .15404 .43716 .18185 .42804 .16205 .40964 Metetra
.648 .745 .92 r
.16205 .40964 .18185 .42804 .20996 .4189 .19034 .40023 Metetra
.653 .745 .918 r
.19034 .40023 .20996 .4189 .23842 .40934 .21898 .39044 Metetra
.652 .745 .918 r
.21898 .39044 .23842 .40934 .26719 .39975 .24794 .3806 Metetra
.65 .744 .918 r
.24794 .3806 .26719 .39975 .29628 .39014 .27722 .37074 Metetra
.651 .743 .917 r
.27722 .37074 .29628 .39014 .32571 .3804 .30684 .36074 Metetra
.754 .768 .864 r
.30684 .36074 .32571 .3804 .35605 .3598 .33739 .34092 Metetra
.734 .775 .886 r
.33739 .34092 .35605 .3598 .38641 .34195 .36797 .32357 Metetra
.709 .778 .905 r
.36797 .32357 .38641 .34195 .41687 .32685 .39867 .30869 Metetra
.718 .785 .905 r
.39867 .30869 .41687 .32685 .44761 .31085 .42966 .29298 Metetra
.324 .624 .958 r
.42966 .29298 .44761 .31085 .47827 .31685 .4605 .29711 Metetra
.483 .684 .955 r
.4605 .29711 .47827 .31685 .50964 .31695 .49207 .29589 Metetra
.59 .719 .933 r
.49207 .29589 .50964 .31695 .54158 .31098 .52421 .28917 Metetra
.568 .703 .933 r
.52421 .28917 .54158 .31098 .57402 .30655 .55685 .28383 Metetra
.75 .764 .864 r
.55685 .28383 .57402 .30655 .60653 .2848 .58968 .26286 Metetra
.716 .764 .89 r
.58968 .26286 .60653 .2848 .63938 .26751 .62283 .24589 Metetra
.671 .754 .913 r
.62283 .24589 .63938 .26751 .67271 .25468 .65644 .23292 Metetra
.684 .761 .909 r
.65644 .23292 .67271 .25468 .70634 .24048 .69038 .21869 Metetra
.632 .742 .927 r
.69038 .21869 .70634 .24048 .74065 .23073 .72495 .20847 Metetra
.647 .746 .922 r
.72495 .20847 .74065 .23073 .77532 .21961 .7599 .19699 Metetra
.646 .746 .922 r
.08589 .40978 .10644 .42799 .13407 .41901 .11369 .40054 Metetra
.65 .746 .92 r
.11369 .40054 .13407 .41901 .16205 .40964 .14184 .39092 Metetra
.649 .746 .92 r
.14184 .39092 .16205 .40964 .19034 .40023 .17031 .38126 Metetra
.653 .746 .918 r
.17031 .38126 .19034 .40023 .21898 .39044 .19913 .37123 Metetra
.652 .746 .918 r
.19913 .37123 .21898 .39044 .24794 .3806 .22828 .36115 Metetra
.651 .745 .918 r
.22828 .36115 .24794 .3806 .27722 .37074 .25776 .35103 Metetra
.651 .745 .918 r
.25776 .35103 .27722 .37074 .30684 .36074 .28758 .34077 Metetra
.747 .768 .87 r
.28758 .34077 .30684 .36074 .33739 .34092 .31833 .32152 Metetra
.728 .773 .888 r
.31833 .32152 .33739 .34092 .36797 .32357 .34914 .30451 Metetra
.705 .773 .905 r
.34914 .30451 .36797 .32357 .39867 .30869 .38008 .28974 Metetra
.712 .779 .905 r
.38008 .28974 .39867 .30869 .42966 .29298 .41132 .2742 Metetra
.371 .643 .961 r
.41132 .2742 .42966 .29298 .4605 .29711 .44235 .27681 Metetra
.503 .692 .953 r
.44235 .27681 .4605 .29711 .49207 .29589 .47411 .27449 Metetra
.597 .723 .932 r
.47411 .27449 .49207 .29589 .52421 .28917 .50648 .26713 Metetra
.576 .709 .933 r
.50648 .26713 .52421 .28917 .55685 .28383 .53932 .26101 Metetra
.744 .766 .87 r
.53932 .26101 .55685 .28383 .58968 .26286 .57246 .24058 Metetra
.711 .764 .894 r
.57246 .24058 .58968 .26286 .62283 .24589 .60591 .22381 Metetra
.67 .754 .914 r
.60591 .22381 .62283 .24589 .65644 .23292 .63981 .21067 Metetra
.682 .76 .91 r
.63981 .21067 .65644 .23292 .69038 .21869 .67405 .19636 Metetra
.634 .743 .926 r
.67405 .19636 .69038 .21869 .72495 .20847 .7089 .18569 Metetra
.648 .746 .921 r
.7089 .18569 .72495 .20847 .7599 .19699 .74414 .17386 Metetra
.648 .746 .92 r
.06493 .39111 .08589 .40978 .11369 .40054 .09291 .38152 Metetra
.652 .745 .918 r
.09291 .38152 .11369 .40054 .14184 .39092 .12125 .3716 Metetra
.651 .744 .918 r
.12125 .3716 .14184 .39092 .17031 .38126 .1499 .36163 Metetra
.654 .743 .916 r
.1499 .36163 .17031 .38126 .19913 .37123 .17891 .35133 Metetra
.653 .743 .916 r
.17891 .35133 .19913 .37123 .22828 .36115 .20825 .34097 Metetra
.652 .742 .915 r
.20825 .34097 .22828 .36115 .25776 .35103 .23792 .33054 Metetra
.652 .741 .915 r
.23792 .33054 .25776 .35103 .28758 .34077 .26794 .31998 Metetra
.732 .761 .876 r
.26794 .31998 .28758 .34077 .31833 .32152 .29884 .30213 Metetra
.717 .775 .898 r
.29884 .30213 .31833 .32152 .34914 .30451 .32983 .28606 Metetra
.697 .783 .917 r
.32983 .28606 .34914 .30451 .38008 .28974 .36099 .27177 Metetra
.704 .793 .92 r
.36099 .27177 .38008 .28974 .41132 .2742 .39248 .25682 Metetra
.425 .694 .976 r
.39248 .25682 .41132 .2742 .44235 .27681 .42378 .25651 Metetra
.537 .713 .953 r
.42378 .25651 .44235 .27681 .47411 .27449 .45578 .25219 Metetra
.61 .723 .926 r
.45578 .25219 .47411 .27449 .50648 .26713 .48836 .24376 Metetra
.595 .708 .923 r
.48836 .24376 .50648 .26713 .53932 .26101 .52142 .23629 Metetra
.726 .747 .869 r
.52142 .23629 .53932 .26101 .57246 .24058 .55486 .21727 Metetra
.7 .755 .894 r
.55486 .21727 .57246 .24058 .60591 .22381 .58861 .20115 Metetra
.667 .752 .914 r
.58861 .20115 .60591 .22381 .63981 .21067 .6228 .18793 Metetra
.677 .758 .912 r
.6228 .18793 .63981 .21067 .67405 .19636 .65736 .17373 Metetra
.639 .747 .927 r
.65736 .17373 .67405 .19636 .7089 .18569 .69247 .16244 Metetra
.65 .748 .921 r
.69247 .16244 .7089 .18569 .74414 .17386 .72801 .15017 Metetra
.65 .746 .92 r
.04354 .37208 .06493 .39111 .09291 .38152 .07171 .36215 Metetra
.653 .746 .918 r
.07171 .36215 .09291 .38152 .12125 .3716 .10022 .35195 Metetra
.652 .745 .918 r
.10022 .35195 .12125 .3716 .1499 .36163 .12906 .34167 Metetra
.654 .744 .916 r
.12906 .34167 .1499 .36163 .17891 .35133 .15826 .3311 Metetra
.654 .744 .916 r
.15826 .3311 .17891 .35133 .20825 .34097 .18778 .32045 Metetra
.653 .743 .916 r
.18778 .32045 .20825 .34097 .23792 .33054 .21766 .30972 Metetra
.653 .742 .915 r
.21766 .30972 .23792 .33054 .26794 .31998 .24788 .29886 Metetra
.719 .759 .885 r
.24788 .29886 .26794 .31998 .29884 .30213 .27891 .28219 Metetra
.706 .771 .903 r
.27891 .28219 .29884 .30213 .32983 .28606 .3101 .2669 Metetra
.689 .778 .919 r
.3101 .2669 .32983 .28606 .36099 .27177 .34148 .25299 Metetra
.695 .786 .921 r
.34148 .25299 .36099 .27177 .39248 .25682 .37321 .23853 Metetra
.49 .719 .973 r
.37321 .23853 .39248 .25682 .42378 .25651 .40479 .23564 Metetra
.567 .724 .948 r
.40479 .23564 .42378 .25651 .45578 .25219 .43704 .22952 Metetra
.62 .729 .924 r
.43704 .22952 .45578 .25219 .48836 .24376 .46986 .22012 Metetra
.608 .716 .921 r
.46986 .22012 .48836 .24376 .52142 .23629 .50314 .21144 Metetra
.713 .747 .878 r
.50314 .21144 .52142 .23629 .55486 .21727 .53687 .19359 Metetra
.692 .753 .899 r
.53687 .19359 .55486 .21727 .58861 .20115 .57092 .17799 Metetra
.665 .752 .915 r
.57092 .17799 .58861 .20115 .6228 .18793 .6054 .16466 Metetra
.673 .756 .914 r
.6054 .16466 .6228 .18793 .65736 .17373 .64027 .15051 Metetra
.643 .748 .925 r
.64027 .15051 .65736 .17373 .69247 .16244 .67567 .13863 Metetra
.651 .748 .921 r
.67567 .13863 .69247 .16244 .72801 .15017 .7115 .12593 Metetra
.653 .746 .918 r
.02172 .35255 .04354 .37208 .07171 .36215 .05008 .34222 Metetra
.654 .744 .916 r
.05008 .34222 .07171 .36215 .10022 .35195 .07879 .33166 Metetra
.654 .743 .915 r
.07879 .33166 .10022 .35195 .12906 .34167 .10782 .32102 Metetra
.655 .742 .913 r
.10782 .32102 .12906 .34167 .15826 .3311 .1372 .31014 Metetra
.655 .741 .913 r
.1372 .31014 .15826 .3311 .18778 .32045 .16693 .29917 Metetra
.654 .74 .912 r
.16693 .29917 .18778 .32045 .21766 .30972 .197 .28809 Metetra
.654 .739 .912 r
.197 .28809 .21766 .30972 .24788 .29886 .22743 .27688 Metetra
.694 .749 .894 r
.22743 .27688 .24788 .29886 .27891 .28219 .25851 .26224 Metetra
.687 .771 .915 r
.25851 .26224 .27891 .28219 .3101 .2669 .28983 .24834 Metetra
.677 .786 .932 r
.28983 .24834 .3101 .2669 .34148 .25299 .32141 .23518 Metetra
.68 .798 .938 r
.32141 .23518 .34148 .25299 .37321 .23853 .35336 .22163 Metetra
.562 .773 .977 r
.35336 .22163 .37321 .23853 .40479 .23564 .38535 .21474 Metetra
.607 .746 .943 r
.38535 .21474 .40479 .23564 .43704 .22952 .41791 .20591 Metetra
.636 .73 .916 r
.41791 .20591 .43704 .22952 .46986 .22012 .45098 .19511 Metetra
.629 .716 .909 r
.45098 .19511 .46986 .22012 .50314 .21144 .48449 .18465 Metetra
.688 .725 .878 r
.48449 .18465 .50314 .21144 .53687 .19359 .51848 .16882 Metetra
.677 .742 .9 r
.51848 .16882 .53687 .19359 .57092 .17799 .55283 .15423 Metetra
.662 .749 .915 r
.55283 .15423 .57092 .17799 .6054 .16466 .5876 .14087 Metetra
.666 .754 .916 r
.5876 .14087 .6054 .16466 .64027 .15051 .62279 .12697 Metetra
.649 .753 .925 r
.62279 .12697 .64027 .15051 .67567 .13863 .65847 .11431 Metetra
.654 .75 .92 r
.65847 .11431 .67567 .13863 .7115 .12593 .69461 .1011 Metetra
0 g
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.14945 .21117 m
.15407 .21583 L
s
[(5)] .14021 .20185 .9913 1 Mshowa
.2971 .15335 m
.30147 .15825 L
s
[(10)] .28836 .14356 .89202 1 Mshowa
.4535 .09211 m
.45758 .09725 L
s
[(15)] .44535 .08183 .79274 1 Mshowa
.61947 .02712 m
.62321 .03251 L
s
[(20)] .61199 .01634 .69345 1 Mshowa
.125 Mabswid
.17832 .19986 m
.18106 .20269 L
s
.20751 .18843 m
.21022 .19129 L
s
.23703 .17687 m
.23971 .17975 L
s
.26689 .16518 m
.26954 .16809 L
s
.32765 .14139 m
.33024 .14436 L
s
.35857 .12928 m
.36112 .13228 L
s
.38984 .11704 m
.39236 .12006 L
s
.42148 .10465 m
.42397 .1077 L
s
.4859 .07942 m
.48831 .08254 L
s
.51869 .06658 m
.52106 .06973 L
s
.55188 .05359 m
.55421 .05676 L
s
.58547 .04044 m
.58776 .04364 L
s
.12091 .22234 m
.12371 .22511 L
s
.09268 .2334 m
.09551 .23614 L
s
.06477 .24433 m
.06762 .24704 L
s
.65389 .01364 m
.65609 .01691 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.423961 0.477324 0.791823 MathSubStart
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1.04977 -0.0679587 1.04977 [
[.14021 .20185 -5.9739 -9 ]
[.14021 .20185 .0261 0 ]
[.28836 .14356 -11.3521 -9 ]
[.28836 .14356 .64789 0 ]
[.44535 .08183 -10.7564 -9 ]
[.44535 .08183 1.24358 0 ]
[.61199 .01634 -10.1607 -9 ]
[.61199 .01634 1.83927 0 ]
[.76442 .09239 0 -6.16638 ]
[.76442 .09239 6 2.83362 ]
[.83635 .20254 0 -6.06047 ]
[.83635 .20254 12 2.93953 ]
[.90119 .30183 0 -5.96721 ]
[.90119 .30183 12 3.03279 ]
[.95993 .39179 0 -5.88447 ]
[.95993 .39179 12 3.11553 ]
[.01755 .30622 -6 -2.77706 ]
[.01755 .30622 0 6.22294 ]
[.00465 .38707 -18 -2.84567 ]
[.00465 .38707 0 6.15433 ]
[-0.00893 .47223 -18 -2.91831 ]
[-0.00893 .47223 0 6.08169 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.03716 .25514 m
.68874 0 L
s
.14945 .21117 m
.15407 .21583 L
s
[(5)] .14021 .20185 .9913 1 Mshowa
.2971 .15335 m
.30147 .15825 L
s
[(10)] .28836 .14356 .89202 1 Mshowa
.4535 .09211 m
.45758 .09725 L
s
[(15)] .44535 .08183 .79274 1 Mshowa
.61947 .02712 m
.62321 .03251 L
s
[(20)] .61199 .01634 .69345 1 Mshowa
.125 Mabswid
.17832 .19986 m
.18106 .20269 L
s
.20751 .18843 m
.21022 .19129 L
s
.23703 .17687 m
.23971 .17975 L
s
.26689 .16518 m
.26954 .16809 L
s
.32765 .14139 m
.33024 .14436 L
s
.35857 .12928 m
.36112 .13228 L
s
.38984 .11704 m
.39236 .12006 L
s
.42148 .10465 m
.42397 .1077 L
s
.4859 .07942 m
.48831 .08254 L
s
.51869 .06658 m
.52106 .06973 L
s
.55188 .05359 m
.55421 .05676 L
s
.58547 .04044 m
.58776 .04364 L
s
.12091 .22234 m
.12371 .22511 L
s
.09268 .2334 m
.09551 .23614 L
s
.06477 .24433 m
.06762 .24704 L
s
.65389 .01364 m
.65609 .01691 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.75212 .09695 m
.74596 .09923 L
s
[(5)] .76442 .09239 -1 .37031 Mshowa
.82395 .20683 m
.81775 .20898 L
s
[(10)] .83635 .20254 -1 .34677 Mshowa
.88871 .30589 m
.88247 .30793 L
s
[(15)] .90119 .30183 -1 .32605 Mshowa
.94739 .39565 m
.94112 .39758 L
s
[(20)] .95993 .39179 -1 .30766 Mshowa
.125 Mabswid
.76711 .11988 m
.76341 .12123 L
s
.78177 .14231 m
.77807 .14365 L
s
.79613 .16428 m
.79242 .1656 L
s
.81019 .18578 m
.80647 .18708 L
s
.83744 .22746 m
.83371 .22873 L
s
.85065 .24767 m
.84692 .24893 L
s
.86359 .26746 m
.85986 .26871 L
s
.87628 .28687 m
.87254 .2881 L
s
.90091 .32455 m
.89716 .32575 L
s
.91286 .34284 m
.90911 .34403 L
s
.92459 .36078 m
.92084 .36196 L
s
.9361 .37838 m
.93234 .37955 L
s
.7368 .07352 m
.73311 .0749 L
s
.72113 .04956 m
.71746 .05096 L
s
.70512 .02506 m
.70145 .02648 L
s
.95847 .4126 m
.9547 .41375 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.02981 .30153 m
.03594 .29918 L
s
[(0)] .01755 .30622 1 -0.38288 Mshowa
.01697 .38255 m
.02313 .38028 L
s
[(0.1)] .00465 .38707 1 -0.36763 Mshowa
.00345 .46788 m
.00964 .46571 L
s
[(0.2)] -0.00893 .47223 1 -0.35149 Mshowa
.125 Mabswid
.02729 .3174 m
.03097 .316 L
s
.02475 .33344 m
.02844 .33205 L
s
.02218 .34964 m
.02587 .34826 L
s
.01959 .36601 m
.02328 .36464 L
s
.01432 .39926 m
.01802 .39791 L
s
.01165 .41614 m
.01535 .41481 L
s
.00894 .43321 m
.01265 .43188 L
s
.00621 .45045 m
.00992 .44914 L
s
.0323 .28581 m
.03597 .28439 L
s
.03476 .27025 m
.03843 .26883 L
s
.00065 .4855 m
.00437 .4842 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.5 Mabswid
.657 .751 .92 r
.38902 .62825 .40381 .6412 .42853 .63382 .41387 .62111 Metetra
.658 .757 .923 r
.41387 .62111 .42853 .63382 .45348 .62643 .43897 .61382 Metetra
.657 .76 .926 r
.43897 .61382 .45348 .62643 .47866 .61895 .4643 .60648 Metetra
.658 .764 .928 r
.4643 .60648 .47866 .61895 .50407 .61146 .48987 .59898 Metetra
.657 .766 .93 r
.48987 .59898 .50407 .61146 .52971 .60388 .51569 .59144 Metetra
.656 .768 .932 r
.51569 .59144 .52971 .60388 .5556 .59622 .54175 .58385 Metetra
.656 .771 .934 r
.54175 .58385 .5556 .59622 .58173 .58848 .56806 .57618 Metetra
.666 .777 .932 r
.56806 .57618 .58173 .58848 .60812 .58104 .59461 .56781 Metetra
.664 .764 .924 r
.59461 .56781 .60812 .58104 .63476 .57342 .62142 .55953 Metetra
.662 .756 .92 r
.62142 .55953 .63476 .57342 .66165 .56564 .64848 .55134 Metetra
.663 .752 .916 r
.64848 .55134 .66165 .56564 .68881 .5578 .67581 .54303 Metetra
.661 .747 .914 r
.67581 .54303 .68881 .5578 .71623 .54979 .7034 .53481 Metetra
.662 .746 .913 r
.7034 .53481 .71623 .54979 .74391 .54173 .73127 .52646 Metetra
.663 .745 .911 r
.73127 .52646 .74391 .54173 .77187 .53362 .7594 .51798 Metetra
.663 .742 .909 r
.7594 .51798 .77187 .53362 .8001 .52542 .78781 .50943 Metetra
.658 .737 .908 r
.78781 .50943 .8001 .52542 .8286 .51695 .81653 .50111 Metetra
.659 .742 .911 r
.81653 .50111 .8286 .51695 .85738 .50846 .84554 .49263 Metetra
.66 .745 .912 r
.84554 .49263 .85738 .50846 .88645 .49992 .87482 .48397 Metetra
.66 .745 .913 r
.87482 .48397 .88645 .49992 .91582 .49129 .90441 .47525 Metetra
.661 .746 .913 r
.90441 .47525 .91582 .49129 .94548 .48262 .93429 .46635 Metetra
.661 .745 .913 r
.93429 .46635 .94548 .48262 .97544 .47385 .96447 .45739 Metetra
.641 .757 .933 r
.37394 .61574 .38902 .62825 .41387 .62111 .39891 .60932 Metetra
.646 .771 .94 r
.39891 .60932 .41387 .62111 .43897 .61382 .42415 .60244 Metetra
.642 .779 .946 r
.42415 .60244 .43897 .61382 .4643 .60648 .44964 .5956 Metetra
.647 .79 .951 r
.44964 .5956 .4643 .60648 .48987 .59898 .47538 .58829 Metetra
.644 .794 .955 r
.47538 .58829 .48987 .59898 .51569 .59144 .50138 .58102 Metetra
.64 .8 .96 r
.50138 .58102 .51569 .59144 .54175 .58385 .52763 .57378 Metetra
.638 .807 .964 r
.52763 .57378 .54175 .58385 .56806 .57618 .55415 .56645 Metetra
.69 .828 .949 r
.55415 .56645 .56806 .57618 .59461 .56781 .58088 .55606 Metetra
.681 .795 .935 r
.58088 .55606 .59461 .56781 .62142 .55953 .60785 .54638 Metetra
.671 .773 .927 r
.60785 .54638 .62142 .55953 .64848 .55134 .63509 .53742 Metetra
.674 .765 .919 r
.63509 .53742 .64848 .55134 .67581 .54303 .66257 .52816 Metetra
.664 .75 .915 r
.66257 .52816 .67581 .54303 .7034 .53481 .69035 .51962 Metetra
.667 .749 .912 r
.69035 .51962 .7034 .53481 .73127 .52646 .71839 .51078 Metetra
.67 .745 .907 r
.71839 .51078 .73127 .52646 .7594 .51798 .74668 .50163 Metetra
.669 .738 .902 r
.74668 .50163 .7594 .51798 .78781 .50943 .77525 .49246 Metetra
.649 .725 .904 r
.77525 .49246 .78781 .50943 .81653 .50111 .80422 .48471 Metetra
.654 .736 .91 r
.80422 .48471 .81653 .50111 .84554 .49263 .83347 .47647 Metetra
.659 .744 .912 r
.83347 .47647 .84554 .49263 .87482 .48397 .86298 .46773 Metetra
.658 .744 .914 r
.86298 .46773 .87482 .48397 .90441 .47525 .8928 .45902 Metetra
.663 .749 .914 r
.8928 .45902 .90441 .47525 .93429 .46635 .92289 .4498 Metetra
.662 .746 .913 r
.92289 .4498 .93429 .46635 .96447 .45739 .95329 .44061 Metetra
.66 .727 .899 r
.3587 .60053 .37394 .61574 .39891 .60932 .38385 .593 Metetra
.66 .715 .889 r
.38385 .593 .39891 .60932 .42415 .60244 .40924 .58536 Metetra
.66 .708 .883 r
.40924 .58536 .42415 .60244 .44964 .5956 .43488 .57766 Metetra
.66 .699 .876 r
.43488 .57766 .44964 .5956 .47538 .58829 .46075 .56985 Metetra
.659 .695 .872 r
.46075 .56985 .47538 .58829 .50138 .58102 .48688 .56197 Metetra
.659 .69 .868 r
.48688 .56197 .50138 .58102 .52763 .57378 .51326 .55403 Metetra
.658 .684 .863 r
.51326 .55403 .52763 .57378 .55415 .56645 .5399 .546 Metetra
.661 .68 .857 r
.5399 .546 .55415 .56645 .58088 .55606 .5668 .53764 Metetra
.662 .703 .877 r
.5668 .53764 .58088 .55606 .60785 .54638 .59396 .52926 Metetra
.662 .72 .892 r
.59396 .52926 .60785 .54638 .63509 .53742 .62138 .52087 Metetra
.662 .729 .899 r
.62138 .52087 .63509 .53742 .66257 .52816 .64908 .51238 Metetra
.661 .741 .909 r
.64908 .51238 .66257 .52816 .69035 .51962 .67705 .50388 Metetra
.661 .743 .911 r
.67705 .50388 .69035 .51962 .71839 .51078 .7053 .49528 Metetra
.661 .749 .915 r
.7053 .49528 .71839 .51078 .74668 .50163 .73383 .48656 Metetra
.661 .757 .921 r
.73383 .48656 .74668 .50163 .77525 .49246 .76265 .47777 Metetra
.658 .763 .927 r
.76265 .47777 .77525 .49246 .80422 .48471 .79177 .46902 Metetra
.66 .752 .918 r
.79177 .46902 .80422 .48471 .83347 .47647 .82119 .46015 Metetra
.661 .746 .913 r
.82119 .46015 .83347 .47647 .86298 .46773 .8509 .45115 Metetra
.66 .745 .912 r
.8509 .45115 .86298 .46773 .8928 .45902 .88093 .44207 Metetra
.661 .742 .91 r
.88093 .44207 .8928 .45902 .92289 .4498 .91126 .43285 Metetra
.661 .745 .912 r
.91126 .43285 .92289 .4498 .95329 .44061 .9419 .42355 Metetra
.667 .738 .903 r
.34318 .58572 .3587 .60053 .38385 .593 .3685 .57757 Metetra
.665 .731 .899 r
.3685 .57757 .38385 .593 .40924 .58536 .39404 .56948 Metetra
.665 .727 .896 r
.39404 .56948 .40924 .58536 .43488 .57766 .41982 .56127 Metetra
.663 .722 .893 r
.41982 .56127 .43488 .57766 .46075 .56985 .44585 .55314 Metetra
.663 .72 .891 r
.44585 .55314 .46075 .56985 .48688 .56197 .47213 .54489 Metetra
.664 .717 .888 r
.47213 .54489 .48688 .56197 .51326 .55403 .49866 .53651 Metetra
.663 .714 .886 r
.49866 .53651 .51326 .55403 .5399 .546 .52545 .52807 Metetra
.649 .706 .888 r
.52545 .52807 .5399 .546 .5668 .53764 .5525 .52064 Metetra
.653 .72 .898 r
.5525 .52064 .5668 .53764 .59396 .52926 .57984 .51284 Metetra
.657 .731 .904 r
.57984 .51284 .59396 .52926 .62138 .52087 .60744 .50467 Metetra
.656 .735 .908 r
.60744 .50467 .62138 .52087 .64908 .51238 .63533 .49649 Metetra
.66 .743 .911 r
.63533 .49649 .64908 .51238 .67705 .50388 .6635 .48793 Metetra
.659 .743 .913 r
.6635 .48793 .67705 .50388 .7053 .49528 .69195 .47936 Metetra
.657 .746 .915 r
.69195 .47936 .7053 .49528 .73383 .48656 .7207 .47078 Metetra
.657 .75 .918 r
.7207 .47078 .73383 .48656 .76265 .47777 .74975 .4621 Metetra
.665 .756 .918 r
.74975 .4621 .76265 .47777 .79177 .46902 .77905 .45276 Metetra
.663 .75 .915 r
.77905 .45276 .79177 .46902 .82119 .46015 .80867 .44348 Metetra
.661 .746 .913 r
.80867 .44348 .82119 .46015 .8509 .45115 .8386 .43426 Metetra
.662 .745 .912 r
.8386 .43426 .8509 .45115 .88093 .44207 .86883 .4249 Metetra
.66 .743 .912 r
.86883 .4249 .88093 .44207 .91126 .43285 .8994 .4156 Metetra
.66 .745 .912 r
.8994 .4156 .91126 .43285 .9419 .42355 .93029 .40615 Metetra
.692 .714 .865 r
.32754 .56816 .34318 .58572 .3685 .57757 .3531 .55753 Metetra
.677 .686 .851 r
.3531 .55753 .3685 .57757 .39404 .56948 .37882 .54781 Metetra
.677 .673 .838 r
.37882 .54781 .39404 .56948 .41982 .56127 .40477 .53775 Metetra
.664 .654 .829 r
.40477 .53775 .41982 .56127 .44585 .55314 .43091 .52859 Metetra
.665 .647 .822 r
.43091 .52859 .44585 .55314 .47213 .54489 .4573 .51908 Metetra
.666 .64 .814 r
.4573 .51908 .47213 .54489 .49866 .53651 .48393 .50922 Metetra
.663 .629 .806 r
.48393 .50922 .49866 .53651 .52545 .52807 .5108 .49935 Metetra
.589 .586 .817 r
.5108 .49935 .52545 .52807 .5525 .52064 .53794 .4969 Metetra
.61 .636 .852 r
.53794 .4969 .5525 .52064 .57984 .51284 .56542 .49239 Metetra
.635 .679 .875 r
.56542 .49239 .57984 .51284 .60744 .50467 .59321 .48579 Metetra
.627 .695 .894 r
.59321 .48579 .60744 .50467 .63533 .49649 .62132 .47966 Metetra
.654 .732 .907 r
.62132 .47966 .63533 .49649 .6635 .48793 .64969 .4714 Metetra
.646 .735 .914 r
.64969 .4714 .6635 .48793 .69195 .47936 .67838 .46361 Metetra
.636 .744 .927 r
.67838 .46361 .69195 .47936 .7207 .47078 .70742 .45629 Metetra
.635 .764 .941 r
.70742 .45629 .7207 .47078 .74975 .4621 .73677 .44874 Metetra
.691 .802 .934 r
.73677 .44874 .74975 .4621 .77905 .45276 .76617 .43722 Metetra
.678 .769 .92 r
.76617 .43722 .77905 .45276 .80867 .44348 .79592 .42665 Metetra
.664 .749 .913 r
.79592 .42665 .80867 .44348 .8386 .43426 .82605 .41701 Metetra
.668 .747 .91 r
.82605 .41701 .8386 .43426 .86883 .4249 .85647 .40699 Metetra
.655 .736 .909 r
.85647 .40699 .86883 .4249 .8994 .4156 .88731 .39792 Metetra
.658 .743 .912 r
.88731 .39792 .8994 .4156 .93029 .40615 .91846 .38846 Metetra
.723 .698 .826 r
.3118 .54781 .32754 .56816 .3531 .55753 .33772 .53287 Metetra
.692 .655 .809 r
.33772 .53287 .3531 .55753 .37882 .54781 .36365 .52036 Metetra
.69 .637 .791 r
.36365 .52036 .37882 .54781 .40477 .53775 .3898 .50708 Metetra
.665 .609 .782 r
.3898 .50708 .40477 .53775 .43091 .52859 .41603 .49623 Metetra
.667 .602 .773 r
.41603 .49623 .43091 .52859 .4573 .51908 .44251 .48461 Metetra
.668 .593 .762 r
.44251 .48461 .4573 .51908 .48393 .50922 .4692 .47223 Metetra
.662 .58 .753 r
.4692 .47223 .48393 .50922 .5108 .49935 .49609 .45993 Metetra
.502 .481 .767 r
.49609 .45993 .5108 .49935 .53794 .4969 .52318 .46641 Metetra
.542 .553 .816 r
.52318 .46641 .53794 .4969 .56542 .49239 .55075 .46788 Metetra
.597 .628 .852 r
.55075 .46788 .56542 .49239 .59321 .48579 .57869 .46421 Metetra
.574 .647 .884 r
.57869 .46421 .59321 .48579 .62132 .47966 .60704 .46188 Metetra
.642 .72 .904 r
.60704 .46188 .62132 .47966 .64969 .4714 .63561 .4543 Metetra
.621 .723 .919 r
.63561 .4543 .64969 .4714 .67838 .46361 .66457 .44803 Metetra
.593 .734 .942 r
.66457 .44803 .67838 .46361 .70742 .45629 .69394 .4431 Metetra
.585 .769 .967 r
.69394 .4431 .70742 .45629 .73677 .44874 .72368 .43773 Metetra
.738 .854 .935 r
.72368 .43773 .73677 .44874 .76617 .43722 .7531 .42241 Metetra
.704 .792 .919 r
.7531 .42241 .76617 .43722 .79592 .42665 .78294 .40963 Metetra
.67 .753 .913 r
.78294 .40963 .79592 .42665 .82605 .41701 .81326 .39938 Metetra
.679 .751 .906 r
.81326 .39938 .82605 .41701 .85647 .40699 .84382 .38832 Metetra
.645 .727 .908 r
.84382 .38832 .85647 .40699 .88731 .39792 .87497 .3798 Metetra
.654 .74 .913 r
.87497 .3798 .88731 .39792 .91846 .38846 .90639 .37047 Metetra
.721 .805 .917 r
.2952 .53655 .3118 .54781 .33772 .53287 .32116 .52413 Metetra
.697 .843 .953 r
.32116 .52413 .33772 .53287 .36365 .52036 .34723 .51316 Metetra
.698 .87 .963 r
.34723 .51316 .36365 .52036 .3898 .50708 .37353 .50168 Metetra
.649 .892 .983 r
.37353 .50168 .3898 .50708 .41603 .49623 .39998 .49167 Metetra
.647 .906 .982 r
.39998 .49167 .41603 .49623 .44251 .48461 .42669 .48114 Metetra
.639 .92 .977 r
.42669 .48114 .44251 .48461 .4692 .47223 .45363 .47011 Metetra
.606 .928 .966 r
.45363 .47011 .4692 .47223 .49609 .45993 .4808 .4591 Metetra
.012 .586 .738 r
.4808 .4591 .49609 .45993 .52318 .46641 .50815 .45963 Metetra
.415 .794 .992 r
.50815 .45963 .52318 .46641 .55075 .46788 .53593 .45703 Metetra
.583 .8 .982 r
.53593 .45703 .55075 .46788 .57869 .46421 .56405 .45121 Metetra
.581 .767 .967 r
.56405 .45121 .57869 .46421 .60704 .46188 .59254 .44618 Metetra
.648 .753 .926 r
.59254 .44618 .60704 .46188 .63561 .4543 .6213 .43789 Metetra
.636 .741 .925 r
.6213 .43789 .63561 .4543 .66457 .44803 .65041 .43037 Metetra
.625 .723 .917 r
.65041 .43037 .66457 .44803 .69394 .4431 .67989 .42362 Metetra
.63 .705 .9 r
.67989 .42362 .69394 .4431 .72368 .43773 .70971 .41656 Metetra
.697 .716 .863 r
.70971 .41656 .72368 .43773 .7531 .42241 .7395 .40339 Metetra
.685 .736 .89 r
.7395 .40339 .7531 .42241 .78294 .40963 .76965 .39172 Metetra
.666 .745 .909 r
.76965 .39172 .78294 .40963 .81326 .39938 .80023 .38155 Metetra
.672 .75 .909 r
.80023 .38155 .81326 .39938 .84382 .38832 .83108 .37085 Metetra
.65 .749 .921 r
.83108 .37085 .84382 .38832 .87497 .3798 .86242 .36166 Metetra
.657 .745 .915 r
.86242 .36166 .87497 .3798 .90639 .37047 .89407 .35193 Metetra
.677 .805 .943 r
.27823 .52543 .2952 .53655 .32116 .52413 .3042 .51582 Metetra
.658 .847 .973 r
.3042 .51582 .32116 .52413 .34723 .51316 .33038 .50659 Metetra
.646 .874 .983 r
.33038 .50659 .34723 .51316 .37353 .50168 .35682 .49715 Metetra
.605 .895 .988 r
.35682 .49715 .37353 .50168 .39998 .49167 .38348 .48809 Metetra
.588 .904 .983 r
.38348 .48809 .39998 .49167 .42669 .48114 .41041 .47881 Metetra
.561 .909 .969 r
.41041 .47881 .42669 .48114 .45363 .47011 .4376 .46932 Metetra
.51 .903 .939 r
.4376 .46932 .45363 .47011 .4808 .4591 .46506 .45977 Metetra
.288 .788 .838 r
.46506 .45977 .4808 .4591 .50815 .45963 .49275 .45363 Metetra
.549 .865 .996 r
.49275 .45363 .50815 .45963 .53593 .45703 .52077 .44648 Metetra
.628 .823 .975 r
.52077 .44648 .53593 .45703 .56405 .45121 .54911 .43829 Metetra
.635 .79 .957 r
.54911 .43829 .56405 .45121 .59254 .44618 .57776 .43027 Metetra
.657 .757 .924 r
.57776 .43027 .59254 .44618 .6213 .43789 .60671 .42121 Metetra
.653 .748 .919 r
.60671 .42121 .6213 .43789 .65041 .43037 .63598 .41231 Metetra
.651 .732 .909 r
.63598 .41231 .65041 .43037 .67989 .42362 .66557 .40356 Metetra
.651 .711 .891 r
.66557 .40356 .67989 .42362 .70971 .41656 .69549 .39466 Metetra
.671 .702 .87 r
.69549 .39466 .70971 .41656 .7395 .40339 .72563 .38385 Metetra
.668 .728 .894 r
.72563 .38385 .7395 .40339 .76965 .39172 .75611 .37342 Metetra
.662 .743 .91 r
.75611 .37342 .76965 .39172 .80023 .38155 .78694 .36337 Metetra
.664 .747 .912 r
.78694 .36337 .80023 .38155 .83108 .37085 .81809 .35308 Metetra
.658 .752 .92 r
.81809 .35308 .83108 .37085 .86242 .36166 .84962 .34316 Metetra
.659 .746 .914 r
.84962 .34316 .86242 .36166 .89407 .35193 .88149 .333 Metetra
.645 .779 .945 r
.26102 .5127 .27823 .52543 .3042 .51582 .28703 .50495 Metetra
.644 .808 .962 r
.28703 .50495 .3042 .51582 .33038 .50659 .31333 .49685 Metetra
.636 .826 .973 r
.31333 .49685 .33038 .50659 .35682 .49715 .33989 .48873 Metetra
.632 .847 .982 r
.33989 .48873 .35682 .49715 .38348 .48809 .36675 .48027 Metetra
.623 .856 .987 r
.36675 .48027 .38348 .48809 .41041 .47881 .39387 .47178 Metetra
.611 .867 .991 r
.39387 .47178 .41041 .47881 .4376 .46932 .42128 .46328 Metetra
.596 .879 .992 r
.42128 .46328 .4376 .46932 .46506 .45977 .44898 .45467 Metetra
.634 .905 .984 r
.44898 .45467 .46506 .45977 .49275 .45363 .477 .44393 Metetra
.663 .847 .97 r
.477 .44393 .49275 .45363 .52077 .44648 .50528 .43363 Metetra
.665 .802 .949 r
.50528 .43363 .52077 .44648 .54911 .43829 .53384 .42379 Metetra
.669 .782 .934 r
.53384 .42379 .54911 .43829 .57776 .43027 .56269 .41369 Metetra
.663 .755 .919 r
.56269 .41369 .57776 .43027 .60671 .42121 .59183 .40405 Metetra
.665 .75 .914 r
.59183 .40405 .60671 .42121 .63598 .41231 .62128 .39415 Metetra
.667 .741 .906 r
.62128 .39415 .63598 .41231 .66557 .40356 .65103 .38401 Metetra
.665 .726 .895 r
.65103 .38401 .66557 .40356 .69549 .39466 .6811 .3738 Metetra
.652 .709 .889 r
.6811 .3738 .69549 .39466 .72563 .38385 .71154 .36452 Metetra
.656 .73 .904 r
.71154 .36452 .72563 .38385 .75611 .37342 .7423 .35485 Metetra
.66 .743 .911 r
.7423 .35485 .75611 .37342 .78694 .36337 .77338 .3448 Metetra
.659 .745 .914 r
.77338 .3448 .78694 .36337 .81809 .35308 .80481 .33472 Metetra
.662 .751 .916 r
.80481 .33472 .81809 .35308 .84962 .34316 .83655 .32424 Metetra
.661 .747 .913 r
.83655 .32424 .84962 .34316 .88149 .333 .86866 .31372 Metetra
.631 .756 .938 r
.24358 .49834 .26102 .5127 .28703 .50495 .26967 .49145 Metetra
.64 .772 .943 r
.26967 .49145 .28703 .50495 .31333 .49685 .2961 .48384 Metetra
.635 .78 .951 r
.2961 .48384 .31333 .49685 .33989 .48873 .3228 .47632 Metetra
.644 .793 .954 r
.3228 .47632 .33989 .48873 .36675 .48027 .34983 .46807 Metetra
.64 .797 .958 r
.34983 .46807 .36675 .48027 .39387 .47178 .37714 .45991 Metetra
.635 .803 .964 r
.37714 .45991 .39387 .47178 .42128 .46328 .40474 .45183 Metetra
.633 .811 .968 r
.40474 .45183 .42128 .46328 .44898 .45467 .43265 .44361 Metetra
.713 .837 .941 r
.43265 .44361 .44898 .45467 .477 .44393 .46096 .43043 Metetra
.696 .802 .931 r
.46096 .43043 .477 .44393 .50528 .43363 .48948 .41845 Metetra
.678 .777 .925 r
.48948 .41845 .50528 .43363 .53384 .42379 .51825 .40767 Metetra
.683 .769 .916 r
.51825 .40767 .53384 .42379 .56269 .41369 .54731 .39643 Metetra
.665 .751 .914 r
.54731 .39643 .56269 .41369 .59183 .40405 .57666 .3864 Metetra
.67 .75 .911 r
.57666 .3864 .59183 .40405 .62128 .39415 .60631 .37591 Metetra
.674 .747 .905 r
.60631 .37591 .62128 .39415 .65103 .38401 .63625 .36496 Metetra
.673 .739 .9 r
.63625 .36496 .65103 .38401 .6811 .3738 .6665 .35399 Metetra
.641 .721 .905 r
.6665 .35399 .6811 .3738 .71154 .36452 .6972 .34537 Metetra
.65 .734 .911 r
.6972 .34537 .71154 .36452 .7423 .35485 .72822 .33599 Metetra
.658 .743 .913 r
.72822 .33599 .7423 .35485 .77338 .3448 .75954 .32584 Metetra
.656 .744 .914 r
.75954 .32584 .77338 .3448 .80481 .33472 .79123 .31575 Metetra
.665 .749 .913 r
.79123 .31575 .80481 .33472 .83655 .32424 .82322 .30488 Metetra
.662 .746 .913 r
.82322 .30488 .83655 .32424 .86866 .31372 .85557 .29407 Metetra
.455 .774 .997 r
.22533 .48887 .24358 .49834 .26967 .49145 .25122 .48668 Metetra
.441 .833 .983 r
.25122 .48668 .26967 .49145 .2961 .48384 .27765 .48202 Metetra
.307 .789 .907 r
.27765 .48202 .2961 .48384 .3228 .47632 .30439 .47796 Metetra
.29 .789 .825 r
.30439 .47796 .3228 .47632 .34983 .46807 .33162 .47139 Metetra
.179 .71 .725 r
.33162 .47139 .34983 .46807 .37714 .45991 .35915 .4654 Metetra
.35915 .4654 .37714 .45991 .40474 .45183 .38699 .46 Metetra
.043 0 0 r
.38699 .46 .40474 .45183 .43265 .44361 .4152 .45435 Metetra
.599 .922 .689 r
.4152 .45435 .43265 .44361 .46096 .43043 .44423 .43008 Metetra
.744 .978 .92 r
.44423 .43008 .46096 .43043 .48948 .41845 .47322 .4107 Metetra
.718 .895 .96 r
.47322 .4107 .48948 .41845 .51825 .40767 .50231 .39613 Metetra
.743 .847 .928 r
.50231 .39613 .51825 .40767 .54731 .39643 .53162 .38014 Metetra
.678 .772 .921 r
.53162 .38014 .54731 .39643 .57666 .3864 .56119 .36895 Metetra
.694 .765 .906 r
.56119 .36895 .57666 .3864 .60631 .37591 .59102 .35633 Metetra
.706 .746 .883 r
.59102 .35633 .60631 .37591 .63625 .36496 .62109 .34228 Metetra
.696 .713 .862 r
.62109 .34228 .63625 .36496 .6665 .35399 .65142 .32846 Metetra
.591 .644 .871 r
.65142 .32846 .6665 .35399 .6972 .34537 .68247 .32373 Metetra
.621 .698 .9 r
.68247 .32373 .6972 .34537 .72822 .33599 .71383 .31644 Metetra
.652 .737 .912 r
.71383 .31644 .72822 .33599 .75954 .32584 .74543 .30656 Metetra
.643 .739 .919 r
.74543 .30656 .75954 .32584 .79123 .31575 .77744 .29724 Metetra
.675 .764 .918 r
.77744 .29724 .79123 .31575 .82322 .30488 .80962 .2853 Metetra
.667 .75 .913 r
.80962 .2853 .82322 .30488 .85557 .29407 .8422 .27391 Metetra
.327 .693 .98 r
.2068 .47779 .22533 .48887 .25122 .48668 .2325 .47934 Metetra
.4 .784 .991 r
.2325 .47934 .25122 .48668 .27765 .48202 .25894 .47703 Metetra
.275 .746 .941 r
.25894 .47703 .27765 .48202 .30439 .47796 .2857 .47574 Metetra
.369 .823 .933 r
.2857 .47574 .30439 .47796 .33162 .47139 .31311 .4705 Metetra
.264 .768 .869 r
.31311 .4705 .33162 .47139 .35915 .4654 .34083 .46625 Metetra
.135 .682 .766 r
.34083 .46625 .35915 .4654 .38699 .46 .36887 .463 Metetra
.36887 .463 .38699 .46 .4152 .45435 .39733 .45942 Metetra
.873 .992 .811 r
.39733 .45942 .4152 .45435 .44423 .43008 .4271 .42606 Metetra
.84 .939 .89 r
.4271 .42606 .44423 .43008 .47322 .4107 .45658 .40064 Metetra
.762 .87 .927 r
.45658 .40064 .47322 .4107 .50231 .39613 .48601 .383 Metetra
.779 .833 .894 r
.48601 .383 .50231 .39613 .53162 .38014 .51561 .36316 Metetra
.688 .77 .914 r
.51561 .36316 .53162 .38014 .56119 .36895 .5454 .351 Metetra
.712 .768 .896 r
.5454 .351 .56119 .36895 .59102 .35633 .57544 .33664 Metetra
.729 .756 .874 r
.57544 .33664 .59102 .35633 .62109 .34228 .60567 .32008 Metetra
.718 .729 .859 r
.60567 .32008 .62109 .34228 .65142 .32846 .63614 .30396 Metetra
.544 .634 .891 r
.63614 .30396 .65142 .32846 .68247 .32373 .66749 .30225 Metetra
.594 .692 .911 r
.66749 .30225 .68247 .32373 .71383 .31644 .69916 .29657 Metetra
.647 .736 .914 r
.69916 .29657 .71383 .31644 .74543 .30656 .73102 .28686 Metetra
.633 .734 .921 r
.73102 .28686 .74543 .30656 .77744 .29724 .76334 .2781 Metetra
.684 .765 .913 r
.76334 .2781 .77744 .29724 .80962 .2853 .79573 .26526 Metetra
.67 .751 .911 r
.79573 .26526 .80962 .2853 .8422 .27391 .82855 .25335 Metetra
.286 0 0 r
.18732 .47172 .2068 .47779 .2325 .47934 .21244 .48105 Metetra
.201 0 0 r
.21244 .48105 .2325 .47934 .25894 .47703 .23872 .48372 Metetra
.382 0 0 r
.23872 .48372 .25894 .47703 .2857 .47574 .26531 .4883 Metetra
.257 0 0 r
.26531 .4883 .2857 .47574 .31311 .4705 .29291 .48598 Metetra
.35 0 0 r
.29291 .48598 .31311 .4705 .34083 .46625 .3208 .48551 Metetra
.422 0 .028 r
.3208 .48551 .34083 .46625 .36887 .463 .34905 .48693 Metetra
.438 0 .095 r
.34905 .48693 .36887 .463 .39733 .45942 .37782 .48785 Metetra
.71 .866 .457 r
.37782 .48785 .39733 .45942 .4271 .42606 .40898 .43582 Metetra
.857 .993 .743 r
.40898 .43582 .4271 .42606 .45658 .40064 .43932 .39826 Metetra
.813 .965 .905 r
.43932 .39826 .45658 .40064 .48601 .383 .46923 .37455 Metetra
.848 .893 .87 r
.46923 .37455 .48601 .383 .51561 .36316 .49925 .34715 Metetra
.708 .792 .916 r
.49925 .34715 .51561 .36316 .5454 .351 .52928 .33324 Metetra
.744 .782 .884 r
.52928 .33324 .5454 .351 .57544 .33664 .55954 .31559 Metetra
.764 .755 .845 r
.55954 .31559 .57544 .33664 .60567 .32008 .58991 .29421 Metetra
.741 .709 .821 r
.58991 .29421 .60567 .32008 .63614 .30396 .62044 .27371 Metetra
.466 .545 .853 r
.62044 .27371 .63614 .30396 .66749 .30225 .65214 .27822 Metetra
.545 .646 .9 r
.65214 .27822 .66749 .30225 .69916 .29657 .68417 .27598 Metetra
.637 .728 .914 r
.68417 .27598 .69916 .29657 .73102 .28686 .71631 .26683 Metetra
.61 .726 .927 r
.71631 .26683 .73102 .28686 .76334 .2781 .74899 .25941 Metetra
.7 .781 .914 r
.74899 .25941 .76334 .2781 .79573 .26526 .78155 .24497 Metetra
.677 .756 .911 r
.78155 .24497 .79573 .26526 .82855 .25335 .8146 .23225 Metetra
.695 .172 0 r
.16675 .47084 .18732 .47172 .21244 .48105 .19082 .49225 Metetra
.551 .05 .017 r
.19082 .49225 .21244 .48105 .23872 .48372 .21667 .50277 Metetra
.599 .154 .165 r
.21667 .50277 .23872 .48372 .26531 .4883 .24285 .51666 Metetra
.47 .048 .156 r
.24285 .51666 .26531 .4883 .29291 .48598 .27059 .51907 Metetra
.515 .114 .218 r
.27059 .51907 .29291 .48598 .3208 .48551 .29862 .52472 Metetra
.547 .165 .27 r
.29862 .52472 .3208 .48551 .34905 .48693 .32703 .53372 Metetra
.541 .177 .299 r
.32703 .53372 .34905 .48693 .37782 .48785 .35612 .54204 Metetra
.35612 .54204 .37782 .48785 .40898 .43582 .38959 .4603 Metetra
.829 .926 .543 r
.38959 .4603 .40898 .43582 .43932 .39826 .42127 .40389 Metetra
.848 .998 .804 r
.42127 .40389 .43932 .39826 .46923 .37455 .4519 .37095 Metetra
.913 .922 .807 r
.4519 .37095 .46923 .37455 .49925 .34715 .48251 .33212 Metetra
.737 .815 .913 r
.48251 .33212 .49925 .34715 .52928 .33324 .51283 .31567 Metetra
.784 .796 .862 r
.51283 .31567 .52928 .33324 .55954 .31559 .54333 .29316 Metetra
.803 .755 .809 r
.54333 .29316 .55954 .31559 .58991 .29421 .57384 .26468 Metetra
.767 .695 .783 r
.57384 .26468 .58991 .29421 .62044 .27371 .60439 .23777 Metetra
.346 .436 .811 r
.60439 .23777 .62044 .27371 .65214 .27822 .63644 .25164 Metetra
.466 .583 .888 r
.63644 .25164 .65214 .27822 .68417 .27598 .66885 .25466 Metetra
.621 .718 .915 r
.66885 .25466 .68417 .27598 .71631 .26683 .7013 .24645 Metetra
.574 .71 .935 r
.7013 .24645 .71631 .26683 .74899 .25941 .73439 .24115 Metetra
.724 .799 .911 r
.73439 .24115 .74899 .25941 .78155 .24497 .76709 .22443 Metetra
.688 .762 .908 r
.76709 .22443 .78155 .24497 .8146 .23225 .80034 .2106 Metetra
0 .216 .723 r
.14789 .44981 .16675 .47084 .19082 .49225 .1722 .46816 Metetra
.283 .507 .895 r
.1722 .46816 .19082 .49225 .21667 .50277 .19823 .4766 Metetra
.222 .451 .869 r
.19823 .4766 .21667 .50277 .24285 .51666 .22457 .48806 Metetra
.499 .58 .868 r
.22457 .48806 .24285 .51666 .27059 .51907 .25243 .48911 Metetra
.452 .547 .862 r
.25243 .48911 .27059 .51907 .29862 .52472 .28056 .49307 Metetra
.405 .509 .852 r
.28056 .49307 .29862 .52472 .32703 .53372 .30906 .50002 Metetra
.429 .509 .839 r
.30906 .50002 .32703 .53372 .35612 .54204 .33822 .50632 Metetra
.863 .692 .668 r
.33822 .50632 .35612 .54204 .38959 .4603 .37183 .43139 Metetra
.849 .715 .714 r
.37183 .43139 .38959 .4603 .42127 .40389 .40373 .37917 Metetra
.802 .732 .787 r
.40373 .37917 .42127 .40389 .4519 .37095 .43458 .34814 Metetra
.833 .752 .774 r
.43458 .34814 .4519 .37095 .48251 .33212 .46548 .31172 Metetra
.72 .754 .879 r
.46548 .31172 .48251 .33212 .51283 .31567 .49603 .2956 Metetra
.768 .771 .855 r
.49603 .2956 .51283 .31567 .54333 .29316 .52681 .27395 Metetra
.809 .789 .834 r
.52681 .27395 .54333 .29316 .57384 .26468 .55767 .24685 Metetra
.807 .806 .851 r
.55767 .24685 .57384 .26468 .60439 .23777 .58859 .22115 Metetra
.11 .493 .902 r
.58859 .22115 .60439 .23777 .63644 .25164 .62072 .23257 Metetra
.432 .656 .954 r
.62072 .23257 .63644 .25164 .66885 .25466 .65327 .23407 Metetra
.624 .733 .925 r
.65327 .23407 .66885 .25466 .7013 .24645 .68595 .22534 Metetra
.584 .711 .931 r
.68595 .22534 .7013 .24645 .73439 .24115 .71923 .21925 Metetra
.713 .759 .888 r
.71923 .21925 .73439 .24115 .76709 .22443 .75226 .20276 Metetra
.685 .753 .904 r
.75226 .20276 .76709 .22443 .80034 .2106 .78581 .18887 Metetra
0 .321 .805 r
.12873 .42821 .14789 .44981 .1722 .46816 .15334 .44335 Metetra
.348 .539 .9 r
.15334 .44335 .1722 .46816 .19823 .4766 .17957 .44961 Metetra
.3 .491 .878 r
.17957 .44961 .19823 .4766 .22457 .48806 .20611 .45852 Metetra
.521 .586 .861 r
.20611 .45852 .22457 .48806 .25243 .48911 .23409 .45816 Metetra
.482 .557 .856 r
.23409 .45816 .25243 .48911 .28056 .49307 .26234 .46034 Metetra
.443 .525 .847 r
.26234 .46034 .28056 .49307 .30906 .50002 .29094 .46515 Metetra
.462 .522 .833 r
.29094 .46515 .30906 .50002 .33822 .50632 .32018 .46936 Metetra
.851 .686 .678 r
.32018 .46936 .33822 .50632 .37183 .43139 .35384 .40155 Metetra
.837 .71 .724 r
.35384 .40155 .37183 .43139 .40373 .37917 .38589 .35374 Metetra
.79 .728 .794 r
.38589 .35374 .40373 .37917 .43458 .34814 .41694 .32473 Metetra
.821 .75 .784 r
.41694 .32473 .43458 .34814 .46548 .31172 .4481 .29086 Metetra
.714 .752 .881 r
.4481 .29086 .46548 .31172 .49603 .2956 .47889 .2751 Metetra
.759 .769 .861 r
.47889 .2751 .49603 .2956 .52681 .27395 .50995 .25437 Metetra
.798 .788 .843 r
.50995 .25437 .52681 .27395 .55767 .24685 .54114 .22874 Metetra
.796 .806 .86 r
.54114 .22874 .55767 .24685 .58859 .22115 .57241 .20433 Metetra
.185 .545 .929 r
.57241 .20433 .58859 .22115 .62072 .23257 .60465 .21314 Metetra
.462 .674 .955 r
.60465 .21314 .62072 .23257 .65327 .23407 .63736 .21304 Metetra
.628 .735 .924 r
.63736 .21304 .65327 .23407 .68595 .22534 .67026 .20377 Metetra
.593 .716 .929 r
.67026 .20377 .68595 .22534 .71923 .21925 .70376 .19684 Metetra
.708 .757 .89 r
.70376 .19684 .71923 .21925 .75226 .20276 .7371 .1806 Metetra
.682 .752 .905 r
.7371 .1806 .75226 .20276 .78581 .18887 .77096 .16667 Metetra
.029 .396 .852 r
.10915 .40697 .12873 .42821 .15334 .44335 .13402 .41942 Metetra
.381 .57 .912 r
.13402 .41942 .15334 .44335 .17957 .44961 .16045 .42386 Metetra
.335 .528 .896 r
.16045 .42386 .17957 .44961 .20611 .45852 .18718 .43064 Metetra
.532 .609 .875 r
.18718 .43064 .20611 .45852 .23409 .45816 .2153 .42907 Metetra
.495 .583 .872 r
.2153 .42907 .23409 .45816 .26234 .46034 .24368 .42977 Metetra
.458 .554 .865 r
.24368 .42977 .26234 .46034 .29094 .46515 .27241 .4328 Metetra
.475 .55 .853 r
.27241 .4328 .29094 .46515 .32018 .46936 .30174 .43525 Metetra
.851 .697 .691 r
.30174 .43525 .32018 .46936 .35384 .40155 .33547 .37321 Metetra
.834 .72 .738 r
.33547 .37321 .35384 .40155 .38589 .35374 .3677 .32897 Metetra
.785 .735 .806 r
.3677 .32897 .38589 .35374 .41694 .32473 .39896 .30157 Metetra
.814 .754 .796 r
.39896 .30157 .41694 .32473 .4481 .29086 .43037 .26976 Metetra
.71 .752 .885 r
.43037 .26976 .4481 .29086 .47889 .2751 .46139 .25424 Metetra
.751 .768 .867 r
.46139 .25424 .47889 .2751 .50995 .25437 .49272 .23423 Metetra
.788 .785 .85 r
.49272 .23423 .50995 .25437 .54114 .22874 .52423 .20977 Metetra
.785 .8 .865 r
.52423 .20977 .54114 .22874 .57241 .20433 .55585 .18639 Metetra
.263 .584 .945 r
.55585 .18639 .57241 .20433 .60465 .21314 .58821 .19299 Metetra
.489 .684 .953 r
.58821 .19299 .60465 .21314 .63736 .21304 .62109 .19151 Metetra
.632 .736 .923 r
.62109 .19151 .63736 .21304 .67026 .20377 .65424 .18175 Metetra
.6 .719 .928 r
.65424 .18175 .67026 .20377 .70376 .19684 .68795 .17407 Metetra
.704 .757 .893 r
.68795 .17407 .70376 .19684 .7371 .1806 .72162 .15799 Metetra
.68 .752 .906 r
.72162 .15799 .7371 .1806 .77096 .16667 .75578 .14396 Metetra
.101 .451 .883 r
.08911 .38606 .10915 .40697 .13402 .41942 .11422 .39636 Metetra
.405 .597 .923 r
.11422 .39636 .13402 .41942 .16045 .42386 .14084 .39932 Metetra
.36 .559 .911 r
.14084 .39932 .16045 .42386 .18718 .43064 .16775 .40439 Metetra
.54 .631 .89 r
.16775 .40439 .18718 .43064 .2153 .42907 .19601 .40184 Metetra
.505 .608 .889 r
.19601 .40184 .2153 .42907 .24368 .42977 .22454 .40133 Metetra
.47 .582 .885 r
.22454 .40133 .24368 .42977 .27241 .4328 .25339 .40292 Metetra
.484 .579 .874 r
.25339 .40292 .27241 .4328 .30174 .43525 .28284 .40396 Metetra
.853 .71 .704 r
.28284 .40396 .30174 .43525 .33547 .37321 .3167 .34634 Metetra
.833 .73 .752 r
.3167 .34634 .33547 .37321 .3677 .32897 .34912 .30484 Metetra
.781 .742 .817 r
.34912 .30484 .3677 .32897 .39896 .30157 .38059 .27865 Metetra
.808 .759 .807 r
.38059 .27865 .39896 .30157 .43037 .26976 .41227 .24841 Metetra
.706 .753 .888 r
.41227 .24841 .43037 .26976 .46139 .25424 .44352 .23303 Metetra
.745 .767 .871 r
.44352 .23303 .46139 .25424 .49272 .23423 .47511 .21352 Metetra
.779 .783 .856 r
.47511 .21352 .49272 .23423 .52423 .20977 .50694 .18993 Metetra
.775 .793 .868 r
.50694 .18993 .52423 .20977 .55585 .18639 .53888 .1673 Metetra
.322 .61 .952 r
.53888 .1673 .55585 .18639 .58821 .19299 .57139 .17209 Metetra
.51 .69 .949 r
.57139 .17209 .58821 .19299 .62109 .19151 .60447 .16946 Metetra
.634 .736 .922 r
.60447 .16946 .62109 .19151 .65424 .18175 .63786 .15925 Metetra
.606 .722 .927 r
.63786 .15925 .65424 .18175 .68795 .17407 .6718 .15092 Metetra
.7 .756 .896 r
.6718 .15092 .68795 .17407 .72162 .15799 .70579 .13489 Metetra
.678 .751 .906 r
.70579 .13489 .72162 .15799 .75578 .14396 .74025 .12073 Metetra
.308 .538 .911 r
.06909 .36206 .08911 .38606 .11422 .39636 .09472 .36815 Metetra
.493 .59 .88 r
.09472 .36815 .11422 .39636 .14084 .39932 .12167 .3683 Metetra
.47 .556 .862 r
.12167 .3683 .14084 .39932 .16775 .40439 .1489 .37009 Metetra
.569 .583 .828 r
.1489 .37009 .16775 .40439 .19601 .40184 .17734 .36574 Metetra
.548 .563 .822 r
.17734 .36574 .19601 .40184 .22454 .40133 .20604 .36299 Metetra
.528 .541 .812 r
.20604 .36299 .22454 .40133 .25339 .40292 .23507 .36187 Metetra
.535 .531 .798 r
.23507 .36187 .25339 .40292 .28284 .40396 .26465 .36028 Metetra
.797 .651 .701 r
.26465 .36028 .28284 .40396 .3167 .34634 .29813 .31187 Metetra
.787 .682 .748 r
.29813 .31187 .3167 .34634 .34912 .30484 .33045 .27618 Metetra
.749 .704 .809 r
.33045 .27618 .34912 .30484 .38059 .27865 .362 .25271 Metetra
.779 .733 .811 r
.362 .25271 .38059 .27865 .41227 .24841 .39381 .22593 Metetra
.697 .743 .887 r
.39381 .22593 .41227 .24841 .44352 .23303 .42527 .21107 Metetra
.73 .761 .877 r
.42527 .21107 .44352 .23303 .47511 .21352 .45711 .19285 Metetra
.763 .784 .871 r
.45711 .19285 .47511 .21352 .50694 .18993 .48923 .1713 Metetra
.762 .809 .89 r
.48923 .1713 .50694 .18993 .53888 .1673 .52151 .15048 Metetra
.373 .675 .975 r
.52151 .15048 .53888 .1673 .57139 .17209 .55421 .1518 Metetra
.54 .718 .955 r
.55421 .1518 .57139 .17209 .60447 .16946 .58748 .14709 Metetra
.64 .74 .921 r
.58748 .14709 .60447 .16946 .63786 .15925 .62112 .13621 Metetra
.618 .726 .924 r
.62112 .13621 .63786 .15925 .6718 .15092 .65528 .12681 Metetra
.692 .749 .895 r
.65528 .12681 .6718 .15092 .70579 .13489 .6896 .11118 Metetra
.675 .749 .907 r
.6896 .11118 .70579 .13489 .74025 .12073 .72438 .09702 Metetra
.407 .597 .923 r
.04862 .33838 .06909 .36206 .09472 .36815 .07475 .3408 Metetra
.531 .619 .885 r
.07475 .3408 .09472 .36815 .12167 .3683 .10202 .33849 Metetra
.513 .591 .87 r
.10202 .33849 .12167 .3683 .1489 .37009 .12959 .33743 Metetra
.586 .605 .839 r
.12959 .33743 .1489 .37009 .17734 .36574 .15821 .33151 Metetra
.569 .588 .833 r
.15821 .33151 .17734 .36574 .20604 .36299 .1871 .32681 Metetra
.553 .569 .825 r
.1871 .32681 .20604 .36299 .23507 .36187 .21632 .32334 Metetra
.557 .559 .812 r
.21632 .32334 .23507 .36187 .26465 .36028 .24605 .31946 Metetra
.784 .656 .722 r
.24605 .31946 .26465 .36028 .29813 .31187 .27918 .27888 Metetra
.772 .687 .769 r
.27918 .27888 .29813 .31187 .33045 .27618 .3114 .24815 Metetra
.736 .708 .825 r
.3114 .24815 .33045 .27618 .362 .25271 .34303 .22699 Metetra
.762 .735 .828 r
.34303 .22699 .362 .25271 .39381 .22593 .37496 .20316 Metetra
.69 .743 .892 r
.37496 .20316 .39381 .22593 .42527 .21107 .40664 .18872 Metetra
.717 .758 .884 r
.40664 .18872 .42527 .21107 .45711 .19285 .43871 .17158 Metetra
.745 .779 .881 r
.43871 .17158 .45711 .19285 .48923 .1713 .4711 .15177 Metetra
.744 .8 .897 r
.4711 .15177 .48923 .1713 .52151 .15048 .5037 .13249 Metetra
.456 .709 .977 r
.5037 .13249 .52151 .15048 .55421 .1518 .53662 .13074 Metetra
.57 .728 .949 r
.53662 .13074 .55421 .1518 .58748 .14709 .5701 .12416 Metetra
.644 .741 .92 r
.5701 .12416 .58748 .14709 .62112 .13621 .604 .11266 Metetra
.627 .731 .922 r
.604 .11266 .62112 .13621 .65528 .12681 .6384 .1023 Metetra
.686 .748 .898 r
.6384 .1023 .65528 .12681 .6896 .11118 .67304 .08696 Metetra
.672 .748 .908 r
.67304 .08696 .6896 .11118 .72438 .09702 .70814 .07275 Metetra
.543 .631 .888 r
.02822 .31158 .04862 .33838 .07475 .3408 .05517 .3083 Metetra
.587 .605 .838 r
.05517 .3083 .07475 .3408 .10202 .33849 .08295 .30224 Metetra
.576 .577 .817 r
.08295 .30224 .10202 .33849 .12959 .33743 .11103 .29682 Metetra
.602 .567 .788 r
.11103 .29682 .12959 .33743 .15821 .33151 .13988 .28856 Metetra
.592 .552 .779 r
.13988 .28856 .15821 .33151 .1871 .32681 .16902 .28092 Metetra
.583 .535 .767 r
.16902 .28092 .1871 .32681 .21632 .32334 .19849 .27393 Metetra
.582 .522 .753 r
.19849 .27393 .21632 .32334 .24605 .31946 .22842 .26664 Metetra
.705 .581 .713 r
.22842 .26664 .24605 .31946 .27918 .27888 .26057 .23837 Metetra
.709 .627 .764 r
.26057 .23837 .27918 .27888 .3114 .24815 .29233 .21559 Metetra
.693 .665 .817 r
.29233 .21559 .3114 .24815 .34303 .22699 .32387 .19822 Metetra
.716 .702 .835 r
.32387 .19822 .34303 .22699 .37496 .20316 .35575 .17923 Metetra
.676 .732 .892 r
.35575 .17923 .37496 .20316 .40664 .18872 .38761 .16559 Metetra
.695 .748 .893 r
.38761 .16559 .40664 .18872 .43871 .17158 .41987 .15033 Metetra
.714 .776 .901 r
.41987 .15033 .43871 .17158 .4711 .15177 .45249 .13345 Metetra
.715 .811 .925 r
.45249 .13345 .4711 .15177 .5037 .13249 .4854 .1168 Metetra
.538 .784 .989 r
.4854 .1168 .5037 .13249 .53662 .13074 .5186 .11028 Metetra
.61 .758 .949 r
.5186 .11028 .53662 .13074 .5701 .12416 .55233 .10087 Metetra
.652 .746 .919 r
.55233 .10087 .5701 .12416 .604 .11266 .58649 .08853 Metetra
.642 .736 .917 r
.58649 .08853 .604 .11266 .6384 .1023 .62112 .07679 Metetra
.675 .739 .899 r
.62112 .07679 .6384 .1023 .67304 .08696 .65609 .06209 Metetra
.667 .745 .909 r
.65609 .06209 .67304 .08696 .70814 .07275 .69152 .04797 Metetra
0 g
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.14945 .21117 m
.15407 .21583 L
s
[(5)] .14021 .20185 .9913 1 Mshowa
.2971 .15335 m
.30147 .15825 L
s
[(10)] .28836 .14356 .89202 1 Mshowa
.4535 .09211 m
.45758 .09725 L
s
[(15)] .44535 .08183 .79274 1 Mshowa
.61947 .02712 m
.62321 .03251 L
s
[(20)] .61199 .01634 .69345 1 Mshowa
.125 Mabswid
.17832 .19986 m
.18106 .20269 L
s
.20751 .18843 m
.21022 .19129 L
s
.23703 .17687 m
.23971 .17975 L
s
.26689 .16518 m
.26954 .16809 L
s
.32765 .14139 m
.33024 .14436 L
s
.35857 .12928 m
.36112 .13228 L
s
.38984 .11704 m
.39236 .12006 L
s
.42148 .10465 m
.42397 .1077 L
s
.4859 .07942 m
.48831 .08254 L
s
.51869 .06658 m
.52106 .06973 L
s
.55188 .05359 m
.55421 .05676 L
s
.58547 .04044 m
.58776 .04364 L
s
.12091 .22234 m
.12371 .22511 L
s
.09268 .2334 m
.09551 .23614 L
s
.06477 .24433 m
.06762 .24704 L
s
.65389 .01364 m
.65609 .01691 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.423961 0.97619 0.791823 MathSubStart
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
5.55112e-017 1.04977 -0.0679587 1.04977 [
[.14021 .20185 -5.9739 -9 ]
[.14021 .20185 .0261 0 ]
[.28836 .14356 -11.3521 -9 ]
[.28836 .14356 .64789 0 ]
[.44535 .08183 -10.7564 -9 ]
[.44535 .08183 1.24358 0 ]
[.61199 .01634 -10.1607 -9 ]
[.61199 .01634 1.83927 0 ]
[.76442 .09239 0 -6.16638 ]
[.76442 .09239 6 2.83362 ]
[.83635 .20254 0 -6.06047 ]
[.83635 .20254 12 2.93953 ]
[.90119 .30183 0 -5.96721 ]
[.90119 .30183 12 3.03279 ]
[.95993 .39179 0 -5.88447 ]
[.95993 .39179 12 3.11553 ]
[.01952 .29389 -24 -2.76664 ]
[.01952 .29389 0 6.23336 ]
[.01207 .34056 -24 -2.80616 ]
[.01207 .34056 0 6.19384 ]
[.0044 .38865 -6 -2.84701 ]
[.0044 .38865 0 6.15299 ]
[-0.00351 .43823 -18 -2.88926 ]
[-0.00351 .43823 0 6.11074 ]
[-0.01167 .48937 -18 -2.93298 ]
[-0.01167 .48937 0 6.06702 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.03716 .25514 m
.68874 0 L
s
.14945 .21117 m
.15407 .21583 L
s
[(5)] .14021 .20185 .9913 1 Mshowa
.2971 .15335 m
.30147 .15825 L
s
[(10)] .28836 .14356 .89202 1 Mshowa
.4535 .09211 m
.45758 .09725 L
s
[(15)] .44535 .08183 .79274 1 Mshowa
.61947 .02712 m
.62321 .03251 L
s
[(20)] .61199 .01634 .69345 1 Mshowa
.125 Mabswid
.17832 .19986 m
.18106 .20269 L
s
.20751 .18843 m
.21022 .19129 L
s
.23703 .17687 m
.23971 .17975 L
s
.26689 .16518 m
.26954 .16809 L
s
.32765 .14139 m
.33024 .14436 L
s
.35857 .12928 m
.36112 .13228 L
s
.38984 .11704 m
.39236 .12006 L
s
.42148 .10465 m
.42397 .1077 L
s
.4859 .07942 m
.48831 .08254 L
s
.51869 .06658 m
.52106 .06973 L
s
.55188 .05359 m
.55421 .05676 L
s
.58547 .04044 m
.58776 .04364 L
s
.12091 .22234 m
.12371 .22511 L
s
.09268 .2334 m
.09551 .23614 L
s
.06477 .24433 m
.06762 .24704 L
s
.65389 .01364 m
.65609 .01691 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.75212 .09695 m
.74596 .09923 L
s
[(5)] .76442 .09239 -1 .37031 Mshowa
.82395 .20683 m
.81775 .20898 L
s
[(10)] .83635 .20254 -1 .34677 Mshowa
.88871 .30589 m
.88247 .30793 L
s
[(15)] .90119 .30183 -1 .32605 Mshowa
.94739 .39565 m
.94112 .39758 L
s
[(20)] .95993 .39179 -1 .30766 Mshowa
.125 Mabswid
.76711 .11988 m
.76341 .12123 L
s
.78177 .14231 m
.77807 .14365 L
s
.79613 .16428 m
.79242 .1656 L
s
.81019 .18578 m
.80647 .18708 L
s
.83744 .22746 m
.83371 .22873 L
s
.85065 .24767 m
.84692 .24893 L
s
.86359 .26746 m
.85986 .26871 L
s
.87628 .28687 m
.87254 .2881 L
s
.90091 .32455 m
.89716 .32575 L
s
.91286 .34284 m
.90911 .34403 L
s
.92459 .36078 m
.92084 .36196 L
s
.9361 .37838 m
.93234 .37955 L
s
.7368 .07352 m
.73311 .0749 L
s
.72113 .04956 m
.71746 .05096 L
s
.70512 .02506 m
.70145 .02648 L
s
.95847 .4126 m
.9547 .41375 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03177 .28918 m
.03789 .28682 L
s
[(-0.2)] .01952 .29389 1 -0.38519 Mshowa
.02436 .33594 m
.0305 .33363 L
s
[(-0.1)] .01207 .34056 1 -0.37641 Mshowa
.01672 .38413 m
.02288 .38187 L
s
[(0)] .0044 .38865 1 -0.36733 Mshowa
.00885 .43381 m
.01502 .4316 L
s
[(0.1)] -0.00351 .43823 1 -0.35794 Mshowa
.00072 .48506 m
.00692 .4829 L
s
[(0.2)] -0.01167 .48937 1 -0.34823 Mshowa
.125 Mabswid
.0303 .29842 m
.03398 .29701 L
s
.02883 .30772 m
.03251 .30631 L
s
.02735 .31707 m
.03103 .31567 L
s
.02586 .32648 m
.02954 .32508 L
s
.02285 .34546 m
.02653 .34408 L
s
.02133 .35504 m
.02502 .35367 L
s
.0198 .36468 m
.02349 .36331 L
s
.01826 .37437 m
.02196 .37301 L
s
.01516 .39394 m
.01886 .39259 L
s
.0136 .40382 m
.0173 .40247 L
s
.01202 .41375 m
.01573 .41242 L
s
.01044 .42375 m
.01414 .42242 L
s
.00724 .44393 m
.01095 .44261 L
s
.00563 .45412 m
.00934 .4528 L
s
.004 .46437 m
.00772 .46306 L
s
.00237 .47468 m
.00608 .47338 L
s
.03322 .27999 m
.03689 .27857 L
s
.03467 .27086 m
.03834 .26943 L
s
.03611 .26178 m
.03977 .26035 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.5 Mabswid
.654 .754 .923 r
.38606 .70335 .40119 .71634 .42643 .70927 .41145 .69621 Metetra
.654 .755 .924 r
.41145 .69621 .42643 .70927 .45191 .70214 .43709 .689 Metetra
.654 .755 .924 r
.43709 .689 .45191 .70214 .47764 .69494 .46297 .68171 Metetra
.654 .756 .925 r
.46297 .68171 .47764 .69494 .5036 .68768 .4891 .67435 Metetra
.654 .756 .925 r
.4891 .67435 .5036 .68768 .52982 .68034 .51548 .66691 Metetra
.654 .757 .925 r
.51548 .66691 .52982 .68034 .55629 .67294 .54212 .65941 Metetra
.654 .757 .926 r
.54212 .65941 .55629 .67294 .58302 .66547 .56902 .65183 Metetra
.661 .76 .923 r
.56902 .65183 .58302 .66547 .61001 .65818 .59617 .64372 Metetra
.66 .749 .917 r
.59617 .64372 .61001 .65818 .63726 .65075 .62359 .63565 Metetra
.658 .742 .912 r
.62359 .63565 .63726 .65075 .66478 .64318 .65128 .62763 Metetra
.659 .738 .908 r
.65128 .62763 .66478 .64318 .69258 .63555 .67924 .6195 Metetra
.646 .729 .909 r
.67924 .6195 .69258 .63555 .72062 .6273 .70752 .61224 Metetra
.648 .745 .92 r
.70752 .61224 .72062 .6273 .74895 .61912 .73609 .60466 Metetra
.651 .757 .927 r
.73609 .60466 .74895 .61912 .77756 .611 .76493 .59673 Metetra
.649 .761 .931 r
.76493 .59673 .77756 .611 .80646 .60276 .79408 .58879 Metetra
.659 .771 .932 r
.79408 .58879 .80646 .60276 .83568 .59486 .82346 .58004 Metetra
.657 .761 .926 r
.82346 .58004 .83568 .59486 .8652 .58676 .85315 .5714 Metetra
.655 .754 .923 r
.85315 .5714 .8652 .58676 .895 .57847 .88317 .56286 Metetra
.656 .753 .922 r
.88317 .56286 .895 .57847 .92512 .57012 .91349 .55419 Metetra
.654 .75 .921 r
.91349 .55419 .92512 .57012 .95553 .56157 .94416 .54562 Metetra
.654 .752 .922 r
.94416 .54562 .95553 .56157 .98626 .55297 .97513 .53691 Metetra
.651 .755 .925 r
.37067 .69024 .38606 .70335 .41145 .69621 .39621 .68312 Metetra
.652 .757 .926 r
.39621 .68312 .41145 .69621 .43709 .689 .42199 .67586 Metetra
.652 .758 .928 r
.42199 .67586 .43709 .689 .46297 .68171 .44803 .66855 Metetra
.653 .76 .928 r
.44803 .66855 .46297 .68171 .4891 .67435 .47433 .6611 Metetra
.652 .761 .929 r
.47433 .6611 .4891 .67435 .51548 .66691 .50088 .6536 Metetra
.652 .761 .93 r
.50088 .6536 .51548 .66691 .54212 .65941 .52769 .64604 Metetra
.652 .763 .931 r
.52769 .64604 .54212 .65941 .56902 .65183 .55477 .6384 Metetra
.684 .772 .918 r
.55477 .6384 .56902 .65183 .59617 .64372 .58208 .62851 Metetra
.676 .748 .905 r
.58208 .62851 .59617 .64372 .62359 .63565 .60965 .61911 Metetra
.668 .73 .896 r
.60965 .61911 .62359 .63565 .65128 .62763 .63748 .61021 Metetra
.67 .722 .888 r
.63748 .61021 .65128 .62763 .67924 .6195 .66557 .60107 Metetra
.611 .689 .899 r
.66557 .60107 .67924 .6195 .70752 .61224 .69415 .59638 Metetra
.623 .729 .923 r
.69415 .59638 .70752 .61224 .73609 .60466 .72301 .59042 Metetra
.637 .759 .936 r
.72301 .59042 .73609 .60466 .76493 .59673 .75212 .58315 Metetra
.629 .768 .947 r
.75212 .58315 .76493 .59673 .79408 .58879 .78157 .57614 Metetra
.68 .803 .94 r
.78157 .57614 .79408 .58879 .82346 .58004 .81105 .56557 Metetra
.67 .774 .928 r
.81105 .56557 .82346 .58004 .85315 .5714 .84089 .55583 Metetra
.658 .756 .923 r
.84089 .55583 .85315 .5714 .88317 .56286 .87111 .54693 Metetra
.661 .755 .92 r
.87111 .54693 .88317 .56286 .91349 .55419 .90162 .53769 Metetra
.649 .745 .919 r
.90162 .53769 .91349 .55419 .94416 .54562 .93256 .5293 Metetra
.652 .751 .922 r
.93256 .5293 .94416 .54562 .97513 .53691 .96379 .52057 Metetra
.655 .75 .92 r
.35502 .67649 .37067 .69024 .39621 .68312 .38071 .66908 Metetra
.655 .748 .918 r
.38071 .66908 .39621 .68312 .42199 .67586 .40666 .66159 Metetra
.655 .746 .917 r
.40666 .66159 .42199 .67586 .44803 .66855 .43285 .65402 Metetra
.655 .745 .916 r
.43285 .65402 .44803 .66855 .47433 .6611 .45931 .64638 Metetra
.655 .744 .915 r
.45931 .64638 .47433 .6611 .50088 .6536 .48602 .63866 Metetra
.655 .743 .914 r
.48602 .63866 .50088 .6536 .52769 .64604 .513 .63087 Metetra
.655 .742 .913 r
.513 .63087 .52769 .64604 .55477 .6384 .54025 .623 Metetra
.658 .741 .911 r
.54025 .623 .55477 .6384 .58208 .62851 .56776 .61486 Metetra
.655 .767 .932 r
.56776 .61486 .58208 .62851 .60965 .61911 .59555 .60668 Metetra
.651 .786 .946 r
.59555 .60668 .60965 .61911 .63748 .61021 .62362 .59848 Metetra
.648 .799 .955 r
.62362 .59848 .63748 .61021 .66557 .60107 .65197 .59018 Metetra
.636 .811 .967 r
.65197 .59018 .66557 .60107 .69415 .59638 .68063 .58221 Metetra
.65 .766 .934 r
.68063 .58221 .69415 .59638 .72301 .59042 .70958 .57404 Metetra
.654 .74 .912 r
.70958 .57404 .72301 .59042 .75212 .58315 .73882 .56568 Metetra
.654 .728 .903 r
.73882 .56568 .75212 .58315 .78157 .57614 .76837 .55726 Metetra
.658 .714 .89 r
.76837 .55726 .78157 .57614 .81105 .56557 .79821 .54844 Metetra
.657 .737 .909 r
.79821 .54844 .81105 .56557 .84089 .55583 .82836 .53961 Metetra
.655 .751 .92 r
.82836 .53961 .84089 .55583 .87111 .54693 .85883 .53078 Metetra
.655 .754 .922 r
.85883 .53078 .87111 .54693 .90162 .53769 .88962 .52183 Metetra
.653 .759 .927 r
.88962 .52183 .90162 .53769 .93256 .5293 .92075 .51287 Metetra
.654 .754 .923 r
.92075 .51287 .93256 .5293 .96379 .52057 .95221 .50379 Metetra
.656 .752 .921 r
.33908 .66261 .35502 .67649 .38071 .66908 .36493 .65498 Metetra
.655 .75 .92 r
.36493 .65498 .38071 .66908 .40666 .66159 .39104 .6473 Metetra
.656 .75 .919 r
.39104 .6473 .40666 .66159 .43285 .65402 .41739 .63954 Metetra
.655 .749 .919 r
.41739 .63954 .43285 .65402 .45931 .64638 .44401 .63172 Metetra
.655 .749 .918 r
.44401 .63172 .45931 .64638 .48602 .63866 .47089 .62383 Metetra
.655 .748 .918 r
.47089 .62383 .48602 .63866 .513 .63087 .49804 .61584 Metetra
.655 .747 .918 r
.49804 .61584 .513 .63087 .54025 .623 .52546 .60778 Metetra
.644 .743 .921 r
.52546 .60778 .54025 .623 .56776 .61486 .55316 .60045 Metetra
.645 .757 .93 r
.55316 .60045 .56776 .61486 .59555 .60668 .58115 .59282 Metetra
.647 .767 .936 r
.58115 .59282 .59555 .60668 .62362 .59848 .60943 .58489 Metetra
.645 .773 .941 r
.60943 .58489 .62362 .59848 .65197 .59018 .63801 .57694 Metetra
.67 .788 .937 r
.63801 .57694 .65197 .59018 .68063 .58221 .66682 .56722 Metetra
.666 .764 .923 r
.66682 .56722 .68063 .58221 .70958 .57404 .69593 .55787 Metetra
.66 .748 .915 r
.69593 .55787 .70958 .57404 .73882 .56568 .72535 .54887 Metetra
.662 .743 .91 r
.72535 .54887 .73882 .56568 .76837 .55726 .75506 .53966 Metetra
.646 .729 .909 r
.75506 .53966 .76837 .55726 .79821 .54844 .78517 .53164 Metetra
.649 .742 .918 r
.78517 .53164 .79821 .54844 .82836 .53961 .81559 .52318 Metetra
.653 .751 .922 r
.81559 .52318 .82836 .53961 .85883 .53078 .84631 .51429 Metetra
.652 .752 .923 r
.84631 .51429 .85883 .53078 .88962 .52183 .87736 .50539 Metetra
.656 .757 .924 r
.87736 .50539 .88962 .52183 .92075 .51287 .90871 .49605 Metetra
.655 .754 .922 r
.90871 .49605 .92075 .51287 .95221 .50379 .9404 .48671 Metetra
.662 .748 .914 r
.32289 .64806 .33908 .66261 .36493 .65498 .34891 .63991 Metetra
.66 .742 .911 r
.34891 .63991 .36493 .65498 .39104 .6473 .37517 .63184 Metetra
.66 .739 .908 r
.37517 .63184 .39104 .6473 .41739 .63954 .4017 .62366 Metetra
.658 .735 .906 r
.4017 .62366 .41739 .63954 .44401 .63172 .42847 .61555 Metetra
.659 .733 .905 r
.42847 .61555 .44401 .63172 .47089 .62383 .45552 .60732 Metetra
.659 .731 .903 r
.45552 .60732 .47089 .62383 .49804 .61584 .48283 .59897 Metetra
.659 .728 .901 r
.48283 .59897 .49804 .61584 .52546 .60778 .51041 .59055 Metetra
.573 .695 .924 r
.51041 .59055 .52546 .60778 .55316 .60045 .53829 .58762 Metetra
.576 .761 .966 r
.53829 .58762 .55316 .60045 .58115 .59282 .56653 .58315 Metetra
.58 .816 .989 r
.56653 .58315 .58115 .59282 .60943 .58489 .59509 .57711 Metetra
.54 .834 .999 r
.59509 .57711 .60943 .58489 .63801 .57694 .624 .57141 Metetra
.76 .927 .943 r
.624 .57141 .63801 .57694 .66682 .56722 .65282 .55394 Metetra
.729 .809 .914 r
.65282 .55394 .66682 .56722 .69593 .55787 .68193 .53951 Metetra
.687 .734 .887 r
.68193 .53951 .69593 .55787 .72535 .54887 .71141 .52809 Metetra
.692 .712 .864 r
.71141 .52809 .72535 .54887 .75506 .53966 .74111 .51573 Metetra
.593 .641 .868 r
.74111 .51573 .75506 .53966 .78517 .53164 .77171 .51212 Metetra
.617 .7 .903 r
.77171 .51212 .78517 .53164 .81559 .52318 .80255 .50608 Metetra
.646 .744 .92 r
.80255 .50608 .81559 .52318 .84631 .51429 .83354 .49755 Metetra
.636 .747 .928 r
.83354 .49755 .84631 .51429 .87736 .50539 .86495 .48958 Metetra
.668 .775 .93 r
.86495 .48958 .87736 .50539 .90871 .49605 .89645 .4791 Metetra
.66 .759 .923 r
.89645 .4791 .90871 .49605 .9404 .48671 .92835 .46917 Metetra
.672 .744 .905 r
.30643 .63284 .32289 .64806 .34891 .63991 .33264 .62385 Metetra
.666 .734 .901 r
.33264 .62385 .34891 .63991 .37517 .63184 .35908 .6152 Metetra
.667 .729 .896 r
.35908 .6152 .37517 .63184 .4017 .62366 .38577 .60635 Metetra
.661 .722 .894 r
.38577 .60635 .4017 .62366 .42847 .61555 .4127 .59784 Metetra
.663 .719 .891 r
.4127 .59784 .42847 .61555 .45552 .60732 .4399 .58913 Metetra
.664 .716 .887 r
.4399 .58913 .45552 .60732 .48283 .59897 .46737 .58022 Metetra
.663 .711 .884 r
.46737 .58022 .48283 .59897 .51041 .59055 .49511 .57126 Metetra
.41 .597 .922 r
.49511 .57126 .51041 .59055 .53829 .58762 .52312 .5764 Metetra
.382 .707 .985 r
.52312 .5764 .53829 .58762 .56653 .58315 .55161 .57778 Metetra
.359 .786 .972 r
.55161 .57778 .56653 .58315 .59509 .57711 .58051 .57531 Metetra
.157 .693 .84 r
.58051 .57531 .59509 .57711 .624 .57141 .60984 .57384 Metetra
.866 .993 .817 r
.60984 .57384 .624 .57141 .65282 .55394 .63859 .5424 Metetra
.816 .847 .872 r
.63859 .5424 .65282 .55394 .68193 .53951 .66759 .51894 Metetra
.722 .726 .853 r
.66759 .51894 .68193 .53951 .71141 .52809 .69706 .50331 Metetra
.726 .693 .818 r
.69706 .50331 .71141 .52809 .74111 .51573 .72659 .48547 Metetra
.504 .546 .833 r
.72659 .48547 .74111 .51573 .77171 .51212 .75785 .48988 Metetra
.558 .646 .893 r
.75785 .48988 .77171 .51212 .80255 .50608 .78922 .48829 Metetra
.633 .734 .921 r
.78922 .48829 .80255 .50608 .83354 .49755 .82053 .48057 Metetra
.607 .736 .936 r
.82053 .48057 .83354 .49755 .86495 .48958 .85237 .4744 Metetra
.69 .796 .931 r
.85237 .4744 .86495 .48958 .89645 .4791 .88396 .46201 Metetra
.67 .765 .922 r
.88396 .46201 .89645 .4791 .92835 .46917 .91603 .45115 Metetra
.665 .763 .923 r
.28957 .6189 .30643 .63284 .33264 .62385 .31592 .61021 Metetra
.66 .768 .93 r
.31592 .61021 .33264 .62385 .35908 .6152 .34251 .6017 Metetra
.661 .773 .932 r
.34251 .6017 .35908 .6152 .38577 .60635 .36937 .59303 Metetra
.657 .776 .937 r
.36937 .59303 .38577 .60635 .4127 .59784 .39648 .58453 Metetra
.657 .779 .938 r
.39648 .58453 .4127 .59784 .4399 .58913 .42387 .57588 Metetra
.658 .782 .94 r
.42387 .57588 .4399 .58913 .46737 .58022 .45153 .56707 Metetra
.657 .785 .942 r
.45153 .56707 .46737 .58022 .49511 .57126 .47947 .55819 Metetra
.464 .718 .979 r
.47947 .55819 .49511 .57126 .52312 .5764 .50765 .55792 Metetra
.563 .685 .922 r
.50765 .55792 .52312 .5764 .55161 .57778 .53626 .5553 Metetra
.608 .661 .876 r
.53626 .5553 .55161 .57778 .58051 .57531 .56524 .55027 Metetra
.602 .637 .858 r
.56524 .55027 .58051 .57531 .60984 .57384 .5946 .54581 Metetra
.746 .677 .784 r
.5946 .54581 .60984 .57384 .63859 .5424 .62382 .52304 Metetra
.745 .747 .854 r
.62382 .52304 .63859 .5424 .66759 .51894 .65329 .50506 Metetra
.708 .806 .926 r
.65329 .50506 .66759 .51894 .69706 .50331 .68315 .49183 Metetra
.725 .848 .94 r
.68315 .49183 .69706 .50331 .72659 .48547 .71317 .47719 Metetra
.374 .759 .989 r
.71317 .47719 .72659 .48547 .75785 .48988 .74434 .4762 Metetra
.563 .765 .973 r
.74434 .4762 .75785 .48988 .78922 .48829 .77572 .47146 Metetra
.64 .754 .931 r
.77572 .47146 .78922 .48829 .82053 .48057 .80722 .46292 Metetra
.627 .74 .929 r
.80722 .46292 .82053 .48057 .85237 .4744 .83918 .45529 Metetra
.676 .745 .902 r
.83918 .45529 .85237 .4744 .88396 .46201 .87113 .44381 Metetra
.664 .753 .917 r
.87113 .44381 .88396 .46201 .91603 .45115 .90352 .43321 Metetra
.657 .762 .927 r
.27239 .60476 .28957 .6189 .31592 .61021 .29888 .59642 Metetra
.655 .769 .933 r
.29888 .59642 .31592 .61021 .34251 .6017 .32562 .58806 Metetra
.655 .773 .936 r
.32562 .58806 .34251 .6017 .36937 .59303 .35264 .57961 Metetra
.653 .778 .94 r
.35264 .57961 .36937 .59303 .39648 .58453 .37993 .57114 Metetra
.653 .78 .941 r
.37993 .57114 .39648 .58453 .42387 .57588 .40751 .56256 Metetra
.653 .783 .943 r
.40751 .56256 .42387 .57588 .45153 .56707 .43536 .55388 Metetra
.652 .787 .946 r
.43536 .55388 .45153 .56707 .47947 .55819 .4635 .54511 Metetra
.604 .777 .963 r
.4635 .54511 .47947 .55819 .50765 .55792 .49191 .53885 Metetra
.631 .708 .902 r
.49191 .53885 .50765 .55792 .53626 .5553 .52067 .53181 Metetra
.64 .668 .862 r
.52067 .53181 .53626 .5553 .56524 .55027 .54975 .52399 Metetra
.636 .645 .842 r
.54975 .52399 .56524 .55027 .5946 .54581 .57916 .51627 Metetra
.679 .642 .806 r
.57916 .51627 .5946 .54581 .62382 .52304 .60878 .50305 Metetra
.685 .726 .88 r
.60878 .50305 .62382 .52304 .65329 .50506 .63869 .49116 Metetra
.668 .799 .945 r
.63869 .49116 .65329 .50506 .68315 .49183 .66893 .48062 Metetra
.666 .841 .967 r
.66893 .48062 .68315 .49183 .71317 .47719 .69947 .46958 Metetra
.535 .851 .998 r
.69947 .46958 .71317 .47719 .74434 .4762 .73056 .46256 Metetra
.623 .795 .964 r
.73056 .46256 .74434 .4762 .77572 .47146 .76196 .45434 Metetra
.65 .758 .929 r
.76196 .45434 .77572 .47146 .80722 .46292 .79364 .4449 Metetra
.647 .748 .923 r
.79364 .4449 .80722 .46292 .83918 .45529 .82571 .43566 Metetra
.662 .737 .906 r
.82571 .43566 .83918 .45529 .87113 .44381 .85804 .4252 Metetra
.658 .75 .918 r
.85804 .4252 .87113 .44381 .90352 .43321 .89075 .41492 Metetra
.652 .758 .927 r
.2549 .59013 .27239 .60476 .29888 .59642 .28152 .58196 Metetra
.653 .763 .93 r
.28152 .58196 .29888 .59642 .32562 .58806 .30843 .57366 Metetra
.652 .765 .932 r
.30843 .57366 .32562 .58806 .35264 .57961 .33561 .56529 Metetra
.652 .769 .934 r
.33561 .56529 .35264 .57961 .37993 .57114 .36308 .55679 Metetra
.652 .77 .936 r
.36308 .55679 .37993 .57114 .40751 .56256 .39083 .54821 Metetra
.652 .772 .937 r
.39083 .54821 .40751 .56256 .43536 .55388 .41888 .53955 Metetra
.651 .775 .939 r
.41888 .53955 .43536 .55388 .4635 .54511 .44722 .5308 Metetra
.674 .783 .932 r
.44722 .5308 .4635 .54511 .49191 .53885 .47588 .52045 Metetra
.668 .733 .898 r
.47588 .52045 .49191 .53885 .52067 .53181 .50482 .5104 Metetra
.661 .7 .875 r
.50482 .5104 .52067 .53181 .54975 .52399 .53405 .50066 Metetra
.66 .683 .861 r
.53405 .50066 .54975 .52399 .57916 .51627 .56359 .4907 Metetra
.625 .65 .855 r
.56359 .4907 .57916 .51627 .60878 .50305 .59349 .48378 Metetra
.635 .719 .909 r
.59349 .48378 .60878 .50305 .63869 .49116 .62373 .47593 Metetra
.641 .775 .945 r
.62373 .47593 .63869 .49116 .66893 .48062 .6543 .46713 Metetra
.63 .799 .964 r
.6543 .46713 .66893 .48062 .69947 .46958 .68524 .45847 Metetra
.66 .847 .972 r
.68524 .45847 .69947 .46958 .73056 .46256 .71638 .4473 Metetra
.663 .79 .943 r
.71638 .4473 .73056 .46256 .76196 .45434 .74789 .43667 Metetra
.657 .758 .925 r
.74789 .43667 .76196 .45434 .79364 .4449 .77979 .42656 Metetra
.659 .754 .92 r
.77979 .42656 .79364 .4449 .82571 .43566 .81203 .41617 Metetra
.651 .739 .914 r
.81203 .41617 .82571 .43566 .85804 .4252 .84468 .40632 Metetra
.653 .75 .921 r
.84468 .40632 .85804 .4252 .89075 .41492 .8777 .39617 Metetra
.65 .755 .926 r
.23709 .57498 .2549 .59013 .28152 .58196 .26387 .56683 Metetra
.651 .757 .927 r
.26387 .56683 .28152 .58196 .30843 .57366 .29093 .55848 Metetra
.651 .758 .928 r
.29093 .55848 .30843 .57366 .33561 .56529 .31828 .55007 Metetra
.652 .76 .929 r
.31828 .55007 .33561 .56529 .36308 .55679 .34593 .54146 Metetra
.652 .761 .93 r
.34593 .54146 .36308 .55679 .39083 .54821 .37386 .5328 Metetra
.651 .762 .93 r
.37386 .5328 .39083 .54821 .41888 .53955 .40209 .52406 Metetra
.651 .763 .931 r
.40209 .52406 .41888 .53955 .44722 .5308 .43062 .51523 Metetra
.7 .777 .911 r
.43062 .51523 .44722 .5308 .47588 .52045 .45954 .50272 Metetra
.687 .75 .9 r
.45954 .50272 .47588 .52045 .50482 .5104 .48869 .49107 Metetra
.674 .73 .892 r
.48869 .49107 .50482 .5104 .53405 .50066 .5181 .48026 Metetra
.676 .721 .884 r
.5181 .48026 .53405 .50066 .56359 .4907 .54781 .4691 Metetra
.579 .672 .903 r
.54781 .4691 .56359 .4907 .59349 .48378 .57793 .46525 Metetra
.602 .719 .927 r
.57793 .46525 .59349 .48378 .62373 .47593 .60843 .45933 Metetra
.628 .757 .94 r
.60843 .45933 .62373 .47593 .6543 .46713 .63927 .45133 Metetra
.616 .766 .951 r
.63927 .45133 .6543 .46713 .68524 .45847 .67051 .44377 Metetra
.699 .811 .935 r
.67051 .44377 .68524 .45847 .71638 .4473 .70182 .4304 Metetra
.679 .779 .925 r
.70182 .4304 .71638 .4473 .74789 .43667 .73352 .41844 Metetra
.66 .757 .922 r
.73352 .41844 .74789 .43667 .77979 .42656 .76566 .40789 Metetra
.665 .757 .918 r
.76566 .40789 .77979 .42656 .81203 .41617 .79811 .39681 Metetra
.646 .743 .92 r
.79811 .39681 .81203 .41617 .84468 .40632 .83106 .38715 Metetra
.651 .75 .922 r
.83106 .38715 .84468 .40632 .8777 .39617 .86436 .37697 Metetra
.635 .762 .939 r
.21886 .5604 .23709 .57498 .26387 .56683 .24574 .55288 Metetra
.641 .774 .944 r
.24574 .55288 .26387 .56683 .29093 .55848 .27295 .54487 Metetra
.637 .78 .95 r
.27295 .54487 .29093 .55848 .31828 .55007 .30045 .53689 Metetra
.643 .79 .953 r
.30045 .53689 .31828 .55007 .34593 .54146 .32828 .52841 Metetra
.64 .793 .956 r
.32828 .52841 .34593 .54146 .37386 .5328 .3564 .51996 Metetra
.637 .797 .96 r
.3564 .51996 .37386 .5328 .40209 .52406 .38483 .51151 Metetra
.636 .803 .963 r
.38483 .51151 .40209 .52406 .43062 .51523 .41357 .50295 Metetra
.799 .833 .878 r
.41357 .50295 .43062 .51523 .45954 .50272 .44297 .48086 Metetra
.74 .726 .838 r
.44297 .48086 .45954 .50272 .48869 .49107 .4724 .46227 Metetra
.694 .658 .81 r
.4724 .46227 .48869 .49107 .5181 .48026 .50195 .44715 Metetra
.69 .632 .786 r
.50195 .44715 .5181 .48026 .54781 .4691 .53173 .43096 Metetra
.412 .456 .796 r
.53173 .43096 .54781 .4691 .57793 .46525 .56202 .44225 Metetra
.44 .596 .909 r
.56202 .44225 .57793 .46525 .60843 .45933 .59289 .44627 Metetra
.512 .765 .988 r
.59289 .44627 .60843 .45933 .63927 .45133 .62414 .44275 Metetra
.368 .762 .987 r
.62414 .44275 .63927 .45133 .67051 .44377 .65595 .44123 Metetra
.779 .981 .906 r
.65595 .44123 .67051 .44377 .70182 .4304 .6872 .41805 Metetra
.745 .863 .934 r
.6872 .41805 .70182 .4304 .73352 .41844 .71889 .40054 Metetra
.674 .772 .924 r
.71889 .40054 .73352 .41844 .76566 .40789 .75121 .38864 Metetra
.692 .765 .907 r
.75121 .38864 .76566 .40789 .79811 .39681 .78374 .37508 Metetra
.622 .71 .909 r
.78374 .37508 .79811 .39681 .83106 .38715 .81712 .36717 Metetra
.64 .74 .921 r
.81712 .36717 .83106 .38715 .86436 .37697 .85077 .35759 Metetra
.625 .757 .941 r
.2003 .5453 .21886 .5604 .24574 .55288 .22728 .53824 Metetra
.634 .767 .943 r
.22728 .53824 .24574 .55288 .27295 .54487 .25464 .53048 Metetra
.63 .772 .948 r
.25464 .53048 .27295 .54487 .30045 .53689 .28229 .52279 Metetra
.64 .78 .948 r
.28229 .52279 .30045 .53689 .32828 .52841 .31029 .51439 Metetra
.637 .783 .951 r
.31029 .51439 .32828 .52841 .3564 .51996 .3386 .50606 Metetra
.633 .786 .955 r
.3386 .50606 .3564 .51996 .38483 .51151 .36722 .4978 Metetra
.633 .79 .958 r
.36722 .4978 .38483 .51151 .41357 .50295 .39617 .48941 Metetra
.839 .818 .828 r
.39617 .48941 .41357 .50295 .44297 .48086 .42609 .45963 Metetra
.779 .743 .82 r
.42609 .45963 .44297 .48086 .4724 .46227 .45585 .43552 Metetra
.724 .686 .814 r
.45585 .43552 .4724 .46227 .50195 .44715 .48559 .41697 Metetra
.724 .665 .792 r
.48559 .41697 .50195 .44715 .53173 .43096 .51551 .39681 Metetra
.154 .323 .782 r
.51551 .39681 .53173 .43096 .56202 .44225 .54584 .41996 Metetra
.236 .492 .895 r
.54584 .41996 .56202 .44225 .59289 .44627 .57696 .43184 Metetra
.43 .711 .982 r
.57696 .43184 .59289 .44627 .62414 .44275 .60855 .43189 Metetra
.253 .665 .964 r
.60855 .43189 .62414 .44275 .65595 .44123 .64081 .43521 Metetra
.87 .944 .862 r
.64081 .43521 .65595 .44123 .6872 .41805 .67214 .40407 Metetra
.788 .852 .899 r
.67214 .40407 .6872 .41805 .71889 .40054 .70393 .38206 Metetra
.685 .773 .918 r
.70393 .38206 .71889 .40054 .75121 .38864 .73647 .36904 Metetra
.712 .772 .899 r
.73647 .36904 .75121 .38864 .78374 .37508 .76913 .35346 Metetra
.6 .706 .918 r
.76913 .35346 .78374 .37508 .81712 .36717 .80288 .34687 Metetra
.631 .738 .925 r
.80288 .34687 .81712 .36717 .85077 .35759 .83687 .33772 Metetra
.597 .76 .957 r
.18127 .53075 .2003 .5453 .22728 .53824 .20831 .52481 Metetra
.615 .782 .962 r
.20831 .52481 .22728 .53824 .25464 .53048 .23578 .51769 Metetra
.605 .791 .97 r
.23578 .51769 .25464 .53048 .28229 .52279 .26355 .51078 Metetra
.623 .809 .971 r
.26355 .51078 .28229 .52279 .31029 .51439 .29174 .50268 Metetra
.614 .813 .976 r
.29174 .50268 .31029 .51439 .3386 .50606 .32023 .49478 Metetra
.604 .818 .982 r
.32023 .49478 .3386 .50606 .36722 .4978 .34904 .48709 Metetra
.6 .827 .986 r
.34904 .48709 .36722 .4978 .39617 .48941 .37821 .47922 Metetra
.902 .833 .768 r
.37821 .47922 .39617 .48941 .42609 .45963 .40904 .43422 Metetra
.812 .721 .764 r
.40904 .43422 .42609 .45963 .45585 .43552 .43929 .39935 Metetra
.733 .639 .754 r
.43929 .39935 .45585 .43552 .48559 .41697 .46924 .37422 Metetra
.727 .611 .728 r
.46924 .37422 .48559 .41697 .51551 .39681 .49925 .34651 Metetra
0 .088 .622 r
.49925 .34651 .51551 .39681 .54584 .41996 .52937 .39317 Metetra
0 .208 .735 r
.52937 .39317 .54584 .41996 .57696 .43184 .5607 .42102 Metetra
.085 .559 .904 r
.5607 .42102 .57696 .43184 .60855 .43189 .59271 .42849 Metetra
.354 0 0 r
.59271 .42849 .60855 .43189 .64081 .43521 .62563 .44192 Metetra
.902 .979 .697 r
.62563 .44192 .64081 .43521 .67214 .40407 .65692 .39475 Metetra
.864 .914 .863 r
.65692 .39475 .67214 .40407 .70393 .38206 .68869 .36389 Metetra
.707 .789 .915 r
.68869 .36389 .70393 .38206 .73647 .36904 .72139 .34885 Metetra
.747 .781 .881 r
.72139 .34885 .73647 .36904 .76913 .35346 .75409 .32942 Metetra
.56 .665 .908 r
.75409 .32942 .76913 .35346 .80288 .34687 .78831 .32572 Metetra
.614 .725 .925 r
.78831 .32572 .80288 .34687 .83687 .33772 .8227 .31766 Metetra
.549 .757 .974 r
.16175 .51678 .18127 .53075 .20831 .52481 .18877 .51259 Metetra
.579 .793 .981 r
.18877 .51259 .20831 .52481 .23578 .51769 .21632 .50653 Metetra
.557 .803 .991 r
.21632 .50653 .23578 .51769 .26355 .51078 .24418 .50089 Metetra
.59 .833 .991 r
.24418 .50089 .26355 .51078 .29174 .50268 .27254 .49334 Metetra
.571 .836 .995 r
.27254 .49334 .29174 .50268 .32023 .49478 .30122 .48619 Metetra
.546 .84 .999 r
.30122 .48619 .32023 .49478 .34904 .48709 .33023 .47945 Metetra
.534 .85 .998 r
.33023 .47945 .34904 .48709 .37821 .47922 .35961 .47248 Metetra
.943 .823 .697 r
.35961 .47248 .37821 .47922 .40904 .43422 .39188 .40461 Metetra
.842 .706 .713 r
.39188 .40461 .40904 .43422 .43929 .39935 .42288 .35392 Metetra
.748 .613 .709 r
.42288 .35392 .43929 .39935 .46924 .37422 .45308 .31931 Metetra
.738 .585 .684 r
.45308 .31931 .46924 .37422 .49925 .34651 .4832 .28077 Metetra
0 0 .429 r
.4832 .28077 .49925 .34651 .52937 .39317 .51265 .36187 Metetra
0 0 .423 r
.51265 .36187 .52937 .39317 .5607 .42102 .54404 .4139 Metetra
.426 0 0 r
.54404 .4139 .5607 .42102 .59271 .42849 .57651 .43289 Metetra
.688 .16 0 r
.57651 .43289 .59271 .42849 .62563 .44192 .61022 .46217 Metetra
.883 .907 .499 r
.61022 .46217 .62563 .44192 .65692 .39475 .64147 .39027 Metetra
.931 .939 .781 r
.64147 .39027 .65692 .39475 .68869 .36389 .67313 .34605 Metetra
.737 .807 .907 r
.67313 .34605 .68869 .36389 .72139 .34885 .70599 .32804 Metetra
.789 .791 .854 r
.70599 .32804 .72139 .34885 .75409 .32942 .73861 .30296 Metetra
.498 .613 .897 r
.73861 .30296 .75409 .32942 .78831 .32572 .77339 .30369 Metetra
.586 .708 .927 r
.77339 .30369 .78831 .32572 .8227 .31766 .80822 .29739 Metetra
.577 .723 .943 r
.1422 .49925 .16175 .51678 .18877 .51259 .16939 .49443 Metetra
.609 .728 .93 r
.16939 .49443 .18877 .51259 .21632 .50653 .19711 .4879 Metetra
.602 .722 .929 r
.19711 .4879 .21632 .50653 .24418 .50089 .22515 .48173 Metetra
.629 .727 .918 r
.22515 .48173 .24418 .50089 .27254 .49334 .25369 .47382 Metetra
.622 .723 .919 r
.25369 .47382 .27254 .49334 .30122 .48619 .28254 .46626 Metetra
.616 .718 .919 r
.28254 .46626 .30122 .48619 .33023 .47945 .31172 .45905 Metetra
.618 .716 .916 r
.31172 .45905 .33023 .47945 .35961 .47248 .34129 .45163 Metetra
.892 .753 .702 r
.34129 .45163 .35961 .47248 .39188 .40461 .37383 .3888 Metetra
.888 .795 .751 r
.37383 .3888 .39188 .40461 .42288 .35392 .40515 .34149 Metetra
.861 .842 .825 r
.40515 .34149 .42288 .35392 .45308 .31931 .4357 .30879 Metetra
.885 .86 .811 r
.4357 .30879 .45308 .31931 .4832 .28077 .46622 .27247 Metetra
.889 .463 .141 r
.46622 .27247 .4832 .28077 .51265 .36187 .49557 .34541 Metetra
.727 .24 0 r
.49557 .34541 .51265 .36187 .54404 .4139 .52689 .39156 Metetra
.087 .415 .864 r
.52689 .39156 .54404 .4139 .57651 .43289 .55939 .40759 Metetra
0 .262 .771 r
.55939 .40759 .57651 .43289 .61022 .46217 .59302 .43286 Metetra
.892 .741 .688 r
.59302 .43286 .61022 .46217 .64147 .39027 .62492 .36647 Metetra
.856 .774 .77 r
.62492 .36647 .64147 .39027 .67313 .34605 .6571 .32506 Metetra
.725 .773 .89 r
.6571 .32506 .67313 .34605 .70599 .32804 .69028 .30745 Metetra
.782 .796 .864 r
.69028 .30745 .70599 .32804 .73861 .30296 .72333 .28337 Metetra
.474 .683 .958 r
.72333 .28337 .73861 .30296 .77339 .30369 .75827 .28277 Metetra
.59 .727 .939 r
.75827 .28277 .77339 .30369 .80822 .29739 .79333 .27575 Metetra
.587 .726 .94 r
.12226 .48134 .1422 .49925 .16939 .49443 .14964 .47586 Metetra
.614 .729 .928 r
.14964 .47586 .16939 .49443 .19711 .4879 .17754 .46883 Metetra
.608 .724 .927 r
.17754 .46883 .19711 .4879 .22515 .48173 .20576 .46212 Metetra
.632 .727 .916 r
.20576 .46212 .22515 .48173 .25369 .47382 .23447 .45382 Metetra
.626 .723 .917 r
.23447 .45382 .25369 .47382 .28254 .46626 .2635 .44583 Metetra
.62 .719 .917 r
.2635 .44583 .28254 .46626 .31172 .45905 .29287 .43814 Metetra
.622 .716 .914 r
.29287 .43814 .31172 .45905 .34129 .45163 .32261 .43024 Metetra
.883 .755 .715 r
.32261 .43024 .34129 .45163 .37383 .3888 .35536 .37277 Metetra
.88 .799 .766 r
.35536 .37277 .37383 .3888 .40515 .34149 .38697 .32908 Metetra
.851 .848 .84 r
.38697 .32908 .40515 .34149 .4357 .30879 .41785 .29844 Metetra
.875 .869 .828 r
.41785 .29844 .4357 .30879 .46622 .27247 .44875 .26449 Metetra
.871 .427 .101 r
.44875 .26449 .46622 .27247 .49557 .34541 .47809 .32872 Metetra
.658 .159 0 r
.47809 .32872 .49557 .34541 .52689 .39156 .50939 .36863 Metetra
.174 .47 .891 r
.50939 .36863 .52689 .39156 .55939 .40759 .54195 .38153 Metetra
.026 .338 .819 r
.54195 .38153 .55939 .40759 .59302 .43286 .57553 .40259 Metetra
.879 .738 .702 r
.57553 .40259 .59302 .43286 .62492 .36647 .60803 .34201 Metetra
.843 .771 .782 r
.60803 .34201 .62492 .36647 .6571 .32506 .64071 .3036 Metetra
.718 .77 .893 r
.64071 .3036 .6571 .32506 .69028 .30745 .67423 .2864 Metetra
.771 .793 .871 r
.67423 .2864 .69028 .30745 .72333 .28337 .7077 .26341 Metetra
.497 .696 .958 r
.7077 .26341 .72333 .28337 .75827 .28277 .74281 .26139 Metetra
.597 .731 .938 r
.74281 .26139 .75827 .28277 .79333 .27575 .77811 .25361 Metetra
.594 .73 .939 r
.10191 .4632 .12226 .48134 .14964 .47586 .12947 .45713 Metetra
.618 .733 .928 r
.12947 .45713 .14964 .47586 .17754 .46883 .15756 .44965 Metetra
.613 .728 .928 r
.15756 .44965 .17754 .46883 .20576 .46212 .18596 .44244 Metetra
.634 .731 .918 r
.18596 .44244 .20576 .46212 .23447 .45382 .21485 .4338 Metetra
.629 .728 .919 r
.21485 .4338 .23447 .45382 .2635 .44583 .24406 .42541 Metetra
.623 .724 .919 r
.24406 .42541 .2635 .44583 .29287 .43814 .27361 .41727 Metetra
.625 .722 .916 r
.27361 .41727 .29287 .43814 .32261 .43024 .30354 .40894 Metetra
.877 .759 .728 r
.30354 .40894 .32261 .43024 .35536 .37277 .3365 .35586 Metetra
.869 .798 .778 r
.3365 .35586 .35536 .37277 .38697 .32908 .36839 .31513 Metetra
.836 .837 .847 r
.36839 .31513 .38697 .32908 .41785 .29844 .39958 .28617 Metetra
.859 .855 .837 r
.39958 .28617 .41785 .29844 .44875 .26449 .43085 .25416 Metetra
.846 .384 .027 r
.43085 .25416 .44875 .26449 .47809 .32872 .46021 .31108 Metetra
.569 .067 0 r
.46021 .31108 .47809 .32872 .50939 .36863 .49154 .34579 Metetra
.231 .513 .91 r
.49154 .34579 .50939 .36863 .54195 .38153 .5242 .35606 Metetra
.09 .393 .85 r
.5242 .35606 .54195 .38153 .57553 .40259 .55777 .37361 Metetra
.875 .747 .718 r
.55777 .37361 .57553 .40259 .60803 .34201 .59083 .31775 Metetra
.834 .775 .796 r
.59083 .31775 .60803 .34201 .64071 .3036 .62397 .28176 Metetra
.713 .769 .897 r
.62397 .28176 .64071 .3036 .67423 .2864 .65782 .26486 Metetra
.761 .79 .877 r
.65782 .26486 .67423 .2864 .7077 .26341 .69168 .24271 Metetra
.517 .703 .955 r
.69168 .24271 .7077 .26341 .74281 .26139 .727 .23947 Metetra
.604 .733 .936 r
.727 .23947 .74281 .26139 .77811 .25361 .76255 .231 Metetra
.6 .733 .938 r
.08113 .44481 .10191 .4632 .12947 .45713 .10888 .43823 Metetra
.622 .736 .929 r
.10888 .43823 .12947 .45713 .15756 .44965 .13714 .43035 Metetra
.616 .732 .929 r
.13714 .43035 .15756 .44965 .18596 .44244 .16572 .4227 Metetra
.636 .736 .92 r
.16572 .4227 .18596 .44244 .21485 .4338 .1948 .41373 Metetra
.631 .733 .921 r
.1948 .41373 .21485 .4338 .24406 .42541 .2242 .40498 Metetra
.626 .729 .921 r
.2242 .40498 .24406 .42541 .27361 .41727 .25393 .39645 Metetra
.627 .728 .919 r
.25393 .39645 .27361 .41727 .30354 .40894 .28406 .38772 Metetra
.872 .764 .74 r
.28406 .38772 .30354 .40894 .3365 .35586 .31725 .33804 Metetra
.858 .795 .788 r
.31725 .33804 .3365 .35586 .36839 .31513 .34942 .29961 Metetra
.822 .825 .851 r
.34942 .29961 .36839 .31513 .39958 .28617 .38091 .27191 Metetra
.843 .84 .842 r
.38091 .27191 .39958 .28617 .43085 .25416 .41252 .2414 Metetra
.813 .334 0 r
.41252 .2414 .43085 .25416 .46021 .31108 .44193 .29246 Metetra
0 .021 .524 r
.44193 .29246 .46021 .31108 .49154 .34579 .47332 .32302 Metetra
.275 .545 .923 r
.47332 .32302 .49154 .34579 .5242 .35606 .50609 .33117 Metetra
.139 .437 .874 r
.50609 .33117 .5242 .35606 .55777 .37361 .53972 .34591 Metetra
.873 .757 .732 r
.53972 .34591 .55777 .37361 .59083 .31775 .57328 .29369 Metetra
.827 .78 .808 r
.57328 .29369 .59083 .31775 .62397 .28176 .60686 .25953 Metetra
.708 .769 .9 r
.60686 .25953 .62397 .28176 .65782 .26486 .64103 .2428 Metetra
.754 .788 .881 r
.64103 .2428 .65782 .26486 .69168 .24271 .67528 .22125 Metetra
.532 .708 .952 r
.67528 .22125 .69168 .24271 .727 .23947 .71081 .21698 Metetra
.609 .735 .935 r
.71081 .21698 .727 .23947 .76255 .231 .74663 .20791 Metetra
.612 .732 .931 r
.06 .4256 .08113 .44481 .10888 .43823 .08797 .41818 Metetra
.629 .73 .92 r
.08797 .41818 .10888 .43823 .13714 .43035 .11644 .40968 Metetra
.625 .724 .918 r
.11644 .40968 .13714 .43035 .16572 .4227 .14522 .40134 Metetra
.639 .723 .909 r
.14522 .40134 .16572 .4227 .1948 .41373 .17448 .39191 Metetra
.636 .72 .908 r
.17448 .39191 .1948 .41373 .2242 .40498 .20408 .38263 Metetra
.632 .715 .907 r
.20408 .38263 .2242 .40498 .25393 .39645 .23401 .3735 Metetra
.633 .712 .904 r
.23401 .3735 .25393 .39645 .28406 .38772 .26433 .36418 Metetra
.847 .753 .76 r
.26433 .36418 .28406 .38772 .31725 .33804 .29741 .32178 Metetra
.846 .816 .82 r
.29741 .32178 .31725 .33804 .34942 .29961 .32969 .28833 Metetra
.813 .877 .893 r
.32969 .28833 .34942 .29961 .38091 .27191 .36143 .26353 Metetra
.836 .911 .888 r
.36143 .26353 .38091 .27191 .41252 .2414 .39336 .23638 Metetra
.764 .252 0 r
.39336 .23638 .41252 .2414 .44193 .29246 .42316 .27551 Metetra
0 .187 .663 r
.42316 .27551 .44193 .29246 .47332 .32302 .45475 .29774 Metetra
.391 .589 .922 r
.45475 .29774 .47332 .32302 .50609 .33117 .48767 .30179 Metetra
.317 .507 .885 r
.48767 .30179 .50609 .33117 .53972 .34591 .52133 .31105 Metetra
.825 .712 .74 r
.52133 .31105 .53972 .34591 .57328 .29369 .55534 .26654 Metetra
.794 .753 .815 r
.55534 .26654 .57328 .29369 .60686 .25953 .58936 .23643 Metetra
.698 .762 .901 r
.58936 .23643 .60686 .25953 .64103 .2428 .62385 .22033 Metetra
.737 .784 .89 r
.62385 .22033 .64103 .2428 .67528 .22125 .65853 .20029 Metetra
.555 .731 .957 r
.65853 .20029 .67528 .22125 .71081 .21698 .69426 .19418 Metetra
.618 .741 .935 r
.69426 .19418 .71081 .21698 .74663 .20791 .73033 .18415 Metetra
.622 .736 .929 r
.03841 .40612 .06 .4256 .08797 .41818 .06662 .39793 Metetra
.634 .734 .92 r
.06662 .39793 .08797 .41818 .11644 .40968 .09528 .38886 Metetra
.631 .729 .918 r
.09528 .38886 .11644 .40968 .14522 .40134 .12428 .37989 Metetra
.642 .728 .911 r
.12428 .37989 .14522 .40134 .17448 .39191 .15373 .37002 Metetra
.639 .725 .91 r
.15373 .37002 .17448 .39191 .20408 .38263 .18352 .36024 Metetra
.636 .721 .909 r
.18352 .36024 .20408 .38263 .23401 .3735 .21365 .35055 Metetra
.637 .718 .906 r
.21365 .35055 .23401 .3735 .26433 .36418 .24417 .34069 Metetra
.827 .757 .785 r
.24417 .34069 .26433 .36418 .29741 .32178 .27714 .30459 Metetra
.821 .813 .842 r
.27714 .30459 .29741 .32178 .32969 .28833 .3095 .27549 Metetra
.787 .864 .906 r
.3095 .27549 .32969 .28833 .36143 .26353 .34147 .25321 Metetra
.807 .896 .906 r
.34147 .25321 .36143 .26353 .39336 .23638 .37368 .229 Metetra
.646 .089 0 r
.37368 .229 .39336 .23638 .42316 .27551 .40393 .25757 Metetra
0 .381 .825 r
.40393 .25757 .42316 .27551 .45475 .29774 .4358 .2725 Metetra
.457 .63 .928 r
.4358 .2725 .45475 .29774 .48767 .30179 .46891 .27296 Metetra
.399 .565 .901 r
.46891 .27296 .48767 .30179 .52133 .31105 .50266 .27745 Metetra
.807 .716 .765 r
.50266 .27745 .52133 .31105 .55534 .26654 .53705 .23955 Metetra
.774 .753 .834 r
.53705 .23955 .55534 .26654 .58936 .23643 .57146 .21291 Metetra
.689 .76 .905 r
.57146 .21291 .58936 .23643 .62385 .22033 .60628 .1973 Metetra
.722 .779 .898 r
.60628 .1973 .62385 .22033 .65853 .20029 .64136 .17854 Metetra
.579 .739 .951 r
.64136 .17854 .65853 .20029 .69426 .19418 .67731 .17077 Metetra
.626 .744 .932 r
.67731 .17077 .69426 .19418 .73033 .18415 .71365 .15986 Metetra
.636 .735 .92 r
.01645 .38579 .03841 .40612 .06662 .39793 .04494 .37649 Metetra
.642 .728 .91 r
.04494 .37649 .06662 .39793 .09528 .38886 .07384 .36663 Metetra
.64 .721 .907 r
.07384 .36663 .09528 .38886 .12428 .37989 .10308 .35677 Metetra
.646 .717 .899 r
.10308 .35677 .12428 .37989 .15373 .37002 .13273 .34633 Metetra
.644 .713 .897 r
.13273 .34633 .15373 .37002 .18352 .36024 .16272 .33589 Metetra
.642 .708 .895 r
.16272 .33589 .18352 .36024 .21365 .35055 .19306 .32545 Metetra
.642 .703 .891 r
.19306 .32545 .21365 .35055 .24417 .34069 .22379 .31484 Metetra
.772 .736 .82 r
.22379 .31484 .24417 .34069 .27714 .30459 .2562 .28896 Metetra
.776 .834 .896 r
.2562 .28896 .27714 .30459 .3095 .27549 .2884 .26703 Metetra
.731 .913 .956 r
.2884 .26703 .3095 .27549 .34147 .25321 .32049 .24899 Metetra
.723 .955 .948 r
.32049 .24899 .34147 .25321 .37368 .229 .35291 .22973 Metetra
.401 0 0 r
.35291 .22973 .37368 .229 .40393 .25757 .38413 .24132 Metetra
.273 .641 .965 r
.38413 .24132 .40393 .25757 .4358 .2725 .41654 .24471 Metetra
.556 .658 .904 r
.41654 .24471 .4358 .2725 .46891 .27296 .44989 .23962 Metetra
.53 .6 .868 r
.44989 .23962 .46891 .27296 .50266 .27745 .48379 .23674 Metetra
.733 .654 .771 r
.48379 .23674 .50266 .27745 .53705 .23955 .51839 .20943 Metetra
.723 .716 .843 r
.51839 .20943 .53705 .23955 .57146 .21291 .55315 .18848 Metetra
.675 .75 .908 r
.55315 .18848 .57146 .21291 .60628 .1973 .58829 .17383 Metetra
.696 .771 .91 r
.58829 .17383 .60628 .1973 .64136 .17854 .62379 .15728 Metetra
.611 .765 .953 r
.62379 .15728 .64136 .17854 .67731 .17077 .65996 .14703 Metetra
.638 .752 .931 r
.65996 .14703 .67731 .17077 .71365 .15986 .69657 .13488 Metetra
0 g
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.14945 .21117 m
.15407 .21583 L
s
[(5)] .14021 .20185 .9913 1 Mshowa
.2971 .15335 m
.30147 .15825 L
s
[(10)] .28836 .14356 .89202 1 Mshowa
.4535 .09211 m
.45758 .09725 L
s
[(15)] .44535 .08183 .79274 1 Mshowa
.61947 .02712 m
.62321 .03251 L
s
[(20)] .61199 .01634 .69345 1 Mshowa
.125 Mabswid
.17832 .19986 m
.18106 .20269 L
s
.20751 .18843 m
.21022 .19129 L
s
.23703 .17687 m
.23971 .17975 L
s
.26689 .16518 m
.26954 .16809 L
s
.32765 .14139 m
.33024 .14436 L
s
.35857 .12928 m
.36112 .13228 L
s
.38984 .11704 m
.39236 .12006 L
s
.42148 .10465 m
.42397 .1077 L
s
.4859 .07942 m
.48831 .08254 L
s
.51869 .06658 m
.52106 .06973 L
s
.55188 .05359 m
.55421 .05676 L
s
.58547 .04044 m
.58776 .04364 L
s
.12091 .22234 m
.12371 .22511 L
s
.09268 .2334 m
.09551 .23614 L
s
.06477 .24433 m
.06762 .24704 L
s
.65389 .01364 m
.65609 .01691 L
s
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{287.875, 233.5},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004O0000jA000`40O003h00Oogoo87oo003oOolP
Ool00?moob1oo`00ogoo87oo003oOolPOol00?moob1oo`00ogoo87oo003oOolPOol00?moob1oo`00
ogoo87oo003oOolPOol00?moob1oo`00ogoo87oo003oOolPOol00?moob1oo`00DWoo0`000goo00<0
07ooOol0QWoo0`000goo00<007ooOol0=Goo001BOol00`00Oomoo`02Ool00`00Ool00027Ool00`00
Oomoo`02Ool00`00Ool0000fOol005=oo`07001oogooOol007oo0000R7oo00L007ooOomoo`00Ool0
000fOol005=oo`07001oogooOol007oo0000R7oo00L007ooOomoo`00Ool0000fOol0059oo`03001o
o`00009oo`03001oo`0008Moo`03001oo`00009oo`03001oo`0003Ioo`00Dgoo00<007ooOol00Woo
00<007ooOol0Qgoo00<007ooOol00Woo00<007ooOol0=Goo003_Ool2000^Ool0041oo`D0009oo`03
001oogoo01Moo`8006aoo`D0009oo`03001oogoo01Aoo`800003Ool0000002eoo`00@Woo00L007oo
Oomoo`00Ool0000EOol300000goo0000001]Ool01`00Oomoogoo001oo`00019oo`@0009oo`8002eo
o`00@Woo00<007ooOol00goo00<007ooOol047oo10000goo0P00KGoo00<007ooOol00goo00<007oo
Ool03Woo0P001Woo0`00;7oo0012Ool01000Oomoogoo0P004Goo0`001Woo00<007oo0000K7oo00@0
07ooOomoo`8000ioo`<0009oo`03001oogoo00=oo`04001oogoo000[Ool0049oo`05001oogooOol0
000@Ool20009Ool01000Oomoo`00Jgoo00D007ooOomoo`0000eoo`800003Ool007oo00Qoo`04001o
ogoo0006Ool00`00Oomoo`0ROol0045oo`8000=oo`<000]oo`<000]oo`04001oo`000005Ool00`00
Oomoo`1ROol20003Ool30008Ool4000<Ool01@00Oomoogoo000017oo00<007oo00008goo000`Ool5
0002Ool00`00Oomoo`0GOol3000>Ool01@00Oomoogoo00000goo00<007oo0000DWoo1@000Woo00<0
07ooOol05Goo0P004Goo00D007ooOomoo`0000Eoo`03001oogoo025oo`00<Woo00L007ooOomoo`00
Ool0000FOol3000@Ool01@00Oomoogoo00001Goo00<007ooOol0DWoo00L007ooOomoo`00Ool0000C
Ool3000COol01@00Oomoogoo00000goo0P0097oo000bOol01`00Oomoogoo001oo`0001=oo`<001=o
o`03001oogoo009oo`03001oogoo008005Eoo`07001oogooOol007oo00004Goo0P0000=oo`00Ool0
4goo00<007ooOol00Woo00@007ooOol002Eoo`00<Woo00L007ooOomoo`00Ool0000AOol2000FOol0
0`00Oomoo`03Ool00`00Ool0001FOol01`00Oomoogoo001oo`0000ioo`@001Moo`03001oogoo009o
o`800004Ool00000000SOol0039oo`07001oogooOol007oo00003Woo0`0067oo00<007ooOol00Woo
0P0000Aoo`00000005Aoo`07001oogooOol007oo000037oo0`0067oo100017oo00<007ooOol09Goo
000aOol20004Ool00`00Oomoo`0:Ool3000KOol00`00Oomoo`04Ool00`00Oomoo`1DOol20004Ool0
0`00Oomoo`08Ool3000HOol30002D_d20005Ool00`00Oomoo`0TOol002Qoo`03001oogoo01Moo`<0
01eoo`03001oogoo00Aoo`8004]oo`03001oogoo01Ioo`8001Qoo`<0009C7@03001BoE;m00<000Ao
o`03001oogoo02Aoo`009goo00<007oo00005Goo0`007goo0`001Woo00<007ooOol0B7oo00<007oo
000057oo10005Woo0`0000=G7@00Dad00U<M100000=Bo@00Ool017oo00<007ooOol08goo000YOol0
0`00Oomoo`0AOol2000POol20002Dad00`00Oomoo`04Ool2001;Ool00`00Oomoo`0@Ool3000GOol2
00000eKm001G7@02Ead30002D_d20002D_d00`00Oomoo`02Ool2000TOol002Moo`80015oo`<0021o
o`<000=C7@03001oogoo00Ioo`03001oogoo04Ioo`80011oo`<001Qoo`8000=Fo@06001G7@00001G
7@000e;m100000=Bo@00Ool00goo00<007ooOol08Woo000WOol00`00Oomoo`0>Ool2000POol30003
Ead00`00DaeC7@020007Ool01000Oomoogoo1@000Woo00<007ooOol0>goo00<007ooOol03Goo0P00
67oo0`0000=Fo000E_d00UKm0P000eLM00@005;mD_eBo@8000=Bo@03001oogoo00=oo`04001oogoo
Ool50002Ool00`00Oomoo`0FOol002Moo`<000]oo`<001moo`<0009C7@03001G7ELM00D00003Dad0
07oo00Ioo`03001oogoo009oo`07001oogooOol007oo0000?7oo0`002Woo0`0067oo0P0000=Jo000
E_`00UKl0`000ULM00<005LMEad0100000=Bo@00D_d00U;m0P001Goo00<007ooOol00Woo00L007oo
Oomoo`00Ool0000GOol0039oo`@001eoo`@00003Dad005<M009C7@<0009G7@04001C7@00Dad20006
Ool20003Ool01`00Oomoogoo001oo`0004Moo`8001Uoo`8000=Jo006001Fo000001K70000eLM0`00
0ULM00<005;mD_d0100000=Bo@00Ool017oo00<007ooOol00Woo00L007ooOomoo`00Ool0000GOol0
031oo`<001ioo`80009C7@04001C7E<MDad30002Dad00`00EaeG7@0400000eLM001oo`06Ool01@00
Oomoogoo00000goo00<007oo0000A7oo10005Woo10000U;M00D005[lF_aJo00000AK70<00003Ead0
05LM009G7@<00003D_d00000009Bo@8000Eoo`05001oogooOol00003Ool00`00Ool0000GOol002eo
o`<001moo`<000=C7@06001C7@00001C7@0015<M0P000ULM00<005LMEad00P001Woo0P000Woo00L0
07ooOomoo`00Ool00011Ool4000FOol30002D_d01P00D]eBgE;M001Jo0800003F_`005/L00800003
Fa`005LM009G7@<00004Ead005;mD_d40002D_d00`00Oomoo`02Ool20002Ool01`00Oomoogoo001o
o`0001Moo`00:goo0`007Woo0`000e<M00<005<MDad00P000e<M00<005<MDad00`000eLM0`000ULM
00<007ooOol017oo00@007oo000000Aoo`03001oogoo03ioo`@001Eoo`<0009>oP03001BoE;m00H0
00AJo006001K75/LFa`005LM0P0000=G7@00Ead00ULM0`0000=Bo@00D_d00U;m0P0017oo00@007oo
000000Aoo`03001oogoo01Ioo`00:7oo0`007Woo0`000ULM00<005<MDad010000U<M00<005<MDad0
0`000e;m00<005LM00000P000eLM00<007ooOol01Goo00<007ooOol0@goo0`005Goo0`000TLO00<0
04knC_h00`000Tkm00@004kMC]d0009Jo0800004G_/005/LFa`20003Ead01@00Ead00000Ead00P00
00=Bo@0000000P0000=Bo@00Ool017oo00<007ooOol07Goo000UOol3000NOol30002Ead00`00EaeG
7@030002Dad01000DaeC7E<M0`000U<M00<005;mD_d00`0000AG7@00Ead0009G7@8000Moo`03001o
ogoo03moo`<001Aoo`@0009G?PH0009:oP04001>oDkm0002C]d30004G_/20002Fa`00`00EaeG7@02
0004Ead20002D_d01@00D_eBoE;m00001Goo00<007ooOol077oo000SOol2000NOol30002Ead00`00
EaeG7@030002Ead00`00DaeC7@0400000e;m001C7@02Dad30002D_d700000eLM001oo`06Ool2000n
Ool2000EOol20002Ecd00`00EciG?P0200001E/m000nocko00000T[n00<004kmC_d00`000TkM00<0
05kkG_/00`0015/L0P000ULM00<005LM00000`000U;m00<005;mD_d00P001Goo00<007ooOol077oo
000QOol2000NOol200000eLM001G7@03Ead20002Ead00`00EaeG7@030002C_h00`00D_eBo@040000
0e<M001Bo@06000015LM001G7ELM0P001goo00<007ooOol0>Woo0P005Goo0P0000AG7@00EceG?@<0
00AK?@P0009>o@03001>gDkM00<000=O6`03001K7000008000=G7@<0009G7@03001BoE;m00<0009B
o@03001oogoo00=oo`03001oogoo01]oo`008Goo0P0077oo0P000eLM00<005LMEad00`0015LM0P00
0ULM00<004knC_h00`000U;m00<005<M000010000U;m0P0000AG7@000000009G7@03001oogoo00Eo
o`04001oogooOol50002Ool00`00Oomoo`0^Ool2000COol20004Ead20002Fad00`00FceK?@030003
=]l01000A]i6gP000Tkm0`000T[M00@005lKGa]O6`8000=K70<00003Ead005LM009G7@<00003C_d0
05;m009Bo@8000Aoo`80009oo`D0009oo`03001oogoo011oo`008Goo00<007oo000067oo0`000UKm
00<005LMEad00`000eLM00<005LM00000P000eLM0`000Tkm00<005;m00000`000U<M00@005;mD_eB
o@<00003Ead005LM009G7@8000Ioo`03001oogoo00=oo`07001oogooOol007oo0000;goo00<007oo
00003goo0`000U[l00H005LM000005/L0002Fad30002Fcd:0002C_d01@00B]e:g@00Ga/00P0000=O
6`0000000P0000AO7000EaeG7@@00004Fad004kmC_d400000e;m001oo`04Ool00`00Oomoo`02Ool0
1`00Oomoogoo001oo`00015oo`0087oo0P000Woo00<007ooOol04goo0P000UKl00<005KmE_d00`00
0ULM00<005LMEad00`000eLM0`0000AG7@00C_e>o@@0009Bo@03001C7E<M00@00003D_d005LM00D0
0003Ead007oo00Ioo`03001oogoo009oo`03001oogoo00=oo`03001oogoo01ioo`03001oogoo009o
o`04001oogooOol30002Ool01@00Oomoogoo00002goo0`000U;m00<005[lF_`00P0015/L0P000U/m
0`000U/L00@002jN;Yh000=2gP03001>oDkm00D00003Ga/00000008000AO7080009G7@03001K7E/M
00<0009>^`03001BoE;m008000Eoo`05001oogooOol00005Ool00`00Oomoo`0?Ool0019oo`03001o
ogoo009oo`04001oogooOol30002Ool20003Ool00`00Oomoo`0@Ool200000eKl001Fo002E_`20002
Ead00`00EaeG7@030002Ead01P00Ead00000Ead0009G7@@00003C_h005;m009Bo@<0009C7@03001B
oE;m00@00004Ead005LMEad20007Ool01@00Oomoogoo00000goo0P0087oo00<007oo00001goo00<0
07ooOol00Woo0P000goo00<007ooOol01Goo0`000U;m00<005;mD_d00`000UlL00L005/L000005/L
001K?@02000015/L001K75/L2P0000=:o@00B]d00`0000IO6`00001S6`00Ga`30003Ead30002Fa`0
0`00C[]>^`030002E_`00`00Oomoo`03Ool01000Oomoo`000goo0P004Woo000AOol00`00Ool00007
Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`0=Ool20003E_`01P00E_`00000E_`0009G
7@<0009G7@03001G7ELM008000AG7@80009G7@03001>oTkn00@00003D_d005<M009C7@<0009Bo@80
0004Ead000000002Ead00`00Oomoo`04Ool01@00Oomoogoo00000goo00<007ooOol06Woo0`000Woo
00<007oo000027oo00D007ooOomoo`0000Eoo`04001oogooOol30002D_d00`00D_eBo@030002D_d0
0`00GaaO70020004Fa`00`00FaaK7002Fa`20002Fc`40002?[h00`00B_d000060004Ha/01000GaaO
75lL0`0000=G?@00Fa`00U/L0`0000=Ff`00E_`00UKl0P0017oo00@007ooOol000=oo`03001oogoo
015oo`0037oo0`000Woo00<007oo000027oo00D007ooOomoo`0000Ioo`03001oogoo00Qoo`@0009F
f`03001Fo5Kl008000AFo080009G7003001G7ELM00<0009G7@@00004Ead005LMEad30002C_h00`00
D_eBo@0400000e<M001Bo@02D_d300000eLn001G7@02Ead20006Ool01000Ool000000goo0`007goo
00<007oo000027oo00D007ooOomoo`0000Ioo`<0009Bo@04001BoE;mD_d20002D_d00`00D_eBo@03
0002Ga`01`00Fa`00000Ga`005/L00800003Fa`005/l00800003Gc`0000000D0009:g@040016gDKM
0002Ha/300001ElL000005OM00000ULm100000=>o@00E]/00UKK0`0000=K7000Ool017oo0`000goo
0`004Goo000AOol00`00Ool00008Ool01@00Oomoogoo00001goo00<007ooOol017oo0`000U;L00<0
05KKE]/00UKK0P000U[l00H005Kl000005Kl0003Ea`20002Ead50004Ead20002Ead00`00C_i>oP03
0002C_d00`00DaeC7@0400000e;m001G?P0500000e<M001oo`05Ool2000WOol00`00Ool00007Ool0
0`00Ool00002Ool00`00Oomoo`03Ool200001U;m001BoE;m001Bo@800004D_d005;mD_d30002D_d0
0`00GaaO70020003Ga`20004Fa`01000GcaO?5ll10000SZn00@004[MB]d00096g@<000=S6`L0009C
7P04001>oDkmC_d3000015kk001K75/L0P0017oo00<007ooOol05goo000AOol00`00Ool00007Ool0
0`00Ool00002Ool00`00Oomoo`06Ool00`00Oomoo`030002D]`01000D]aBg0000UKK0P0000AJo000
F_aJo08000=Fo005001G7000001K70060002Ead01P00Ead00000Ead0009G7@<0009>oP03001>oDkm
00<0009Bo@03001BoE;m00<0009C7P03001C7E<M008000Ioo`03001oogoo02Ioo`03001oogoo00Mo
o`05001oogooOol00003Ool20003D_d00`00D_eBo@020004D_d20002D_d00`00D_eBo@030002Ga/3
0002Ga`01@00Fa`00000Fc`0100000=O?000000020000TKM00L006<KHa/007Ni001NE@02000013<o
001C7U<N1@0015kk0P0000=K7000Ool017oo00<007ooOol05Woo000AOol20003Ool00`00Oomoo`05
00000goo00000008Ool30002D]`01000D]aBg0000U;L0`0015[l0P000U[l00<005KlE_`00P0000=K
700000000`000ULM00<005LMEad00P0015LM0P0000=G7@00C_h00Tkn0`000Tjl00@005;mD_eBo@80
009G7@800004Dah000000002D_d00`00Oomoo`03Ool2000dOol50002D_d00`00D_eBo@030002D_d0
1P00D_d00000D_d000=Bo@80009Bo@06001O6`00001S6`000UlL1`0015ll0`000SJN00@004[MB]d0
0096g@06001S6`00001g^@000UiE1@0000=>oP00A]h00TKN00<005kk00000P000U/L0P0017oo0P00
5goo000@Ool00`00Ool00008Ool01000Oomoogoo0P001Woo0P000U;L00<005;LD]`01P000U;L00<0
05[lF_`00`000e[l1P0000AK7000000000=G7@<00004Ead005LMEad30002Ead400000dij001>_002
C[`00`00D_d000020003Ead300000dlN001Bo@02D_d20005Ool00`00Oomoo`02Ool30003Ool00`00
Oomoo`0SOol01000Oomoogoo0P000U;m00<005;mD_d00`000U;m00<005;mD_d00P000e;m00H005;m
000005;m0002D_d20004Ha/70002Gc`00`00Gc`0000200000cfE0000000<0003GUD01000:A@00000
0Tkn1P000ekk0P000U/m00<007ooOol00Woo0P000goo0`000goo00<007ooOol02Woo000;Ool30002
Ool00`00Ool00008Ool01000Oomoogoo0P000goo0`0000=Bo@0000000U;L0P000U;m00@005;mD_d0
009Bg0<000=Jn`H0009G708000=K70<00004Ead005LMEad30003Fad20002E[/01@00CWY>NTij0000
0Tjl0P000eKm0`0000AG7@00001?7P@00003D_d007oo00Eoo`05001oogooOol00004Ool00`00Ool0
000SOol00`00Ool00002Ool30002D_d20002D_d00`00D_eBo@030002D_d00`00D_eBo@020003D_d3
0002D_d00`00Ha/0000300001ElL000005lL00000Ull0P000U8F00@003fE?ID000<n>P07001OWUnN
001[N`00KgX00P000eiE00<002TD00000`000T[n00D003jn?[h005kk00800004Imd005/mFcd20003
Ool20003Ool00`00Oomoo`02Ool00`00Ool0000;Ool0011oo`03001oo`0000Qoo`06001oogooOol0
07oo0`000U;m00<005;mD_d00`0000EBo@00D_eBo@00009Bo@<0009Bg003001Jn`0000@00003Fa`0
000000800003Fa`005/L00800004Fa`005LMEad30002Ead01P00Fad00000F_`0009F^`03001>NTij
00@00003E_`005Km00800004Ead005LMEad30002C_h00`00D_eBo@020006Ool01@00Oomoogoo0000
0goo00<007oo00008goo00<007oo00000Woo00<007ooOol00P0000=Bo@0000000U;m0P000U;m00<0
05;mD_d00`000U;m0`000U;m00<005;mD_d00`000f<K00<005lLGa`00UlL0P0000EB=`00DQIB5P00
00<mU@<00007H]T00000Jg/006mj00000V:F00@005iEGUD0008Y508000=:oPD000=Wg@<00003Ead0
07oo00Aoo`05001oogooOol00003Ool00`00Ool0000;Ool0011oo`03001oo`0000Qoo`04001oogoo
Ool20002D_d00`00D_eBo@030002D_d01000D_eBo@000U;m0P000U;M00<005;LD]`010000UlK0P00
0U/L00<005/LFa`00P0015/L0P000ULM00<005LMEad00P000e[l00<005JkE[/00`000UJj00<005Kl
E_`00P000eLM0`0000EK7@00C_h004kn00<00003D_d007oo00Eoo`05001oogooOol00003Ool00`00
Ool0000SOol00`00Ool00002Ool01@00Oomoogoo00000U;m0`0000=Bo@00000010000U;m0`000U;m
00<005;mD_d00`000U;m00L006<K000006<K001O70030002DSL01@00DQIB5U8F00000SfE00L006;I
H]URf@00K_L00002KgX01000HYIRUP000eiE00@002TD000]V0<00004B[`003JN=Yh4000015Mn001G
7ELM0P0017oo00D007ooOomoo`0000=oo`03001oo`0000]oo`004Goo00<007ooOol01Woo0P000goo
0P000U;m0`000U;m00@005;mD_d0009Bo@<00004D_d005;MD]d400000e;m001O6`0200000elK001K
7002Fa`20002Fa`01P00Fa`00000Fa`0009G7@<0009G7@03001Jo5[l00<0009>_004001F^UJjE[X2
0002F_`3000015LM001K7E/M100000A>g000D_eBo@8000Ioo`05001oo`00Ool00002Ool00`00Ool0
000SOol00`00Ool00002Ool00`00Oomoo`02Ool20002D_d3000015;m001BoE;m0`000U;m00<005;m
D_d00`000U;m00<005;mD_d00P0016<K00@005ZIFYT0009B=`0;001B5U8FDQH003fE001J=@00H]T0
0002K_L30003HYH01@00GUENEEiE00000RTD00<002fH00000TZl0`000Tkm1P0000=C7@00Ool00goo
0P0000Aoo`00Ool0009oo`03001oo`0000]oo`006Woo00@007oo001oo`800003Ool00000009>o@03
001BoE;m00H0009Bo@03001BoE;m00<00004D_d005;mD_d20003Ga/01P00Fa`00000Ga`0009K7080
00=K70<0009G?P03001G7ELM00<0009>g@05001>_4jl001F^P030002F_`30002Ead30002Fa`20000
14kL000000000U;m00<007ooOol017oo00<007oo000017oo00<007ooOol08goo00@007ooOol000Io
o`<0009Bo@03001BoE;m0080009Bo@03001BoE;m00<0009Bo@03001BoE;m00<0009Bo@03001S6`00
008000=JV@04001B=e8g0002DQH20002FSD01@00H]T006kg00000Vkf00<006:FHYH00V:F00<005iE
0000200000ABg000C_e>o@<0009?7PD000Eoo`03001oo`0000Aoo`03001oogoo00Yoo`006Woo00@0
07oo001oo`80009oo`03001>oDkm00<0009Bo@04001>oDkm0002D_d3000015;m001BoE;m0`000Tkm
00<005lKGa/00P0015lL0P000U/L0`000UNo1P0000=?7P00C]d00TkM00<004jlC[`00P000ekj0P00
0ekk0P000ULM00<005/LFa`00`0000=Bo000D_d00U;m0P001Goo00<007ooOol0;Goo0P001goo00<0
05;mD_d00`0000ABo@00D_eBo@<0009Bo@03001BoE;m00<0009Bo@03001BoE;m008000=W_@04001J
VEZI0002DSL01000DQH0000015Xe00P006kgK_L006kf001oU0000f:F0P0000EFE`00AMI5eP00009:
>@03001Bg5;L00<0009K7@<00003Aal004km009>o@03001oogoo009oo`03001oogoo015oo`006Woo
00@007oo001oo`8000=oo`80009>o@03001BoE;m00H0009Bo@03001BoE;m0080009>o@03001>oDkm
00<0009Nn`07001O7000001O7000Fa`00P0000I3^`00000003mO0002Dah:000024Jm001NnUkj001R
n@00G_/30003Ead300000eLM001Bo00500000eLM001oo`04Ool2000^Ool00`00Oomoo`07Ool20002
D_d00`00D_d000020002D_d00`00D_eBo@030002D_d00`00D_eBo@0300000d^O0000000:00000dXG
001J=@03FSD200001fkg001^mP00Oi@006:F00<0009FE`040015eTGF0003BST20002E_`300000elL
000000070003Ool2000BOol0011oo`03001oogoo009oo`03001oogoo00D00003Ool0000000Aoo`03
001>oDkm00<00006C_d00000001>o@000U;m0`0000ABo@00C_e>o@<0009>g@05001NnekkG_/00004
Ga`;0002Cah01000B_i:oP000TKN00@004JmA[e6_@8000=Rn@03001S_F>m00@00004Ead005LMEad3
0002E_d00`00EaeG7@0200001Woo00000000Ool0021oo`03001oogoo009oo`04001oogooOol30002
Ool20009Ool00`00D_d00003000015;m001BoE;m0`000U;m00<005;mD_d00`000Tmo0P000U=o0P00
00@FW@00@W/0009:>005001:5dXGBQL00002FSD01P00J[D00000K_H000=oU004001JVEZI0002EUL0
1000AMI5eTGF0`0000=JfP00E_`00`0000AO7000000000=6W003001>gDkM00@00003Ool007oo015o
o`003goo00<007oo000027oo0P000Woo00<007ooOol017oo0P0000E>oP00000004km00H00004D_d0
05;mD_d30002C_d01@00C]e>g@00G_/00P0000=S6`00Ga`00P000U7D00<0034c00001P000TlN2`00
0f;i00@005oh0000009GOP03001G7ELM00<00005D_d005Km001Fo@030002Ead00`00Oomoo`02Ool0
0`00Oomoo`0MOol00`00Ool00007Ool00`00Oomoo`02Ool00`00Oomoo`07Ool40002D_d00`00D_eB
o@020002D_d00`00D_eBo@030002Cgl3000015=o000000000UMN0P000T9k00@004XhBSP0009:5`04
001J=EXe0002J[D00`00K_H00002Oi@20003FYT01000EUMFE`000TGF00<005[JF]X00U[J00D005[l
F_aJo000009S6`800096W0<00003D_d007oo009oo`03001oogoo011oo`003goo00<007oo000027oo
00D007ooOomoo`0000Ioo`<00004C_h000000002C_d01000C_e>o@000U;m0P000U;m00<004kmC_d0
1@0016<K00<0057d00000U7D00@0034c000eM@L0009?7P040016gTKN0002?[h01@00@Ye2W@00H_T0
0`0000A?gP00EgiGOP<00004Dad005;mD_d400000eKl001G7@030004Ool00`00Oomoo`0MOol00`00
Ool00008Ool01@00Oomoogoo00001Woo0`000goo00<005;mD_d00`0000ABo@00D_eBo@<0009?O`<0
009CG`80009G?P<0009GGP<0009:>006001:5dXG001J=@000fZe0P000WnD00@006_lJo`0009JV@03
001FEeIG00<00003FWL005[J00<00004F_`000000002Ha/4000014kL001BoE;m0P000Woo00<007oo
Ool047oo000?Ool00`00Ool00008Ool00`00Oomoo`020003Ool30002Ool20002C_h00`00C_e>o@06
000015;m001BoE;m0`000TkM00D004kMC]d006<K008000=Am005001Ae000<C<00002=GD01@00@MM1
e`00=MT05@0000A?7P00DaeC7@<0009Bo@03001Fo0000080009G7@8000Aoo`03001oogoo01aoo`03
001oo`0000Qoo`04001oogoo0004Ool30007Ool20002D_d00`00D_eBo@020002Del30002Deh30000
15Ln000000000UMN0`0000=FN00000000P0000I:>000BQL005Xe0002J[D00`00KY@0000<0004FWL0
1@00H]URfF;I00000Ulm0`000U/L00<004kLC]`00`0000=Bo@00Ool00Woo00<007ooOol03goo000?
Ool00`00Ool00008Ool00`00Oomoo`050006Ool60002C_d01000C_e>o@000U;m0P000Tkm00<004kM
C]d01@0000=Am000DO@00U7d00P0057DDM@0034c000eM@000T7G00@003GI=MT0009>_0030012_D:m
00<0009?7P<0009KGPP0009C7@H00004Fcd000000002Ead01@00Oomoogoo00007Woo00<007oo0000
1goo00@007oo001oo`D000]oo`H00004Deh000000002Eeh30002Ech20002Eeh3000015Ii001FN5Ih
0`0000Hn>P00000004XG0003J[D01000KY@000000UXe0P0000LJWP00BYa:W000AUX00003FWL20002
H]T01000LoX000000ULM00<005/LFa`00`0000ABo@00D_eBo@80009oo`03001oogoo00moo`003goo
0P000goo00@007ooOomoo`<0009oo`8000]oo`04001:oT[n0002C_d6000015;m001>oDkm10000U7e
00D0057dDOAAm000009Am006001Ae57D000a<`000SEe00@0047G@ML0008ef@03001>_0000080009>
o@<00003Fad005]N00800003Ggh0000000L00004D_d004kmC_d300000eLM001G7@02Ead20002Ool0
0`00Oomoo`0MOol00`00Oomoo`07Ool00`00Oomoo`02000@Ool00`00DciC?P020002Ech30002Ecd3
00001ULn00000000EWT0009FN@04001FN5IhEWP20002?SX01000>OT000000VZe00<006jD00000P00
0eXe0`000TZL00H004IJAUX005Yg0002HWH4000016>n001G7ELM0`0000AG7@00D_eBo@<00005E_d0
0000Ool0000AOol000ioo`03001oo`0000Moo`03001oogoo00=oo`03001oogoo00Yoo`D0009>o@03
001>oDkm00L0009F5@03001Am@0000=Am005001Am57d001Ae00200000c4c000eM@090002D]`00`00
C_d000020002Fad200001Emn000005kJ00000T8j00@004JLAY`0009Bo@<00003D_d005LM00D00005
Dad007ooOol0000]Ool00`00Oomoo`0?Ool2000015LM000000000ULm0`000U/m0P0000=FV@00EWT0
0UIi00D005IiEWT005Ih00@00005?SX003Wi>OT00002J[D00`00KY@00002FUH00`00FSD000090000
15Yg001RMV9f0P000f>n0`0000=G7@000000100000QFo000000005LM001oo`004Goo000>Ool00`00
Ool00008Ool00`00Oomoo`03Ool2000;Ool01000B_i:oP000Tkm1P0000AW_@000000009F5@04001A
mE7e0002DO@00`00DOAAm00200000dge0000000200000dWg001>>002CSP01000CWY>NP000U;L0P00
0ULL0`000Ull00D005kJG]YNfP000092>P030016W4JL00<00004D_d005;mD_d30002Dad00`00DaeC
7@0200000goo001oo`0]Ool2000@Ool300000e/M001G?@0200001U/m001K?@00EYX0009FV@04001F
NEIi0002EWT20002DYX300002Chj000inCWi001Z]@00KY@00002FUH200000eIG000000020002?U/0
1000?QX000000V9f0P0000E?]@00000005Lm00<00004Dad005;mD_d3000015LM001G7ELM0`004Goo
000>Ool00`00Ool00008Ool00`00Oomoo`05Ool00`00Oomoo`09Ool700000fML001[F`020002ESH0
1000EQEF5@000U7e00<0057dDO@010000Tge00<004Fe00000dWg00@004hhCSP0009>NP<00007E_`0
0000001K7000Gc`00P0000AS6`00G]YNfPH00004C]`005;mD_d300000e<M00000005000015<M0000
0000<7oo00<007ooOol03goo00@005/MFad000=K?@80009FVP04001FVEJI0002EWT3000015:J001B
VU:J1P0000<in@0000000VjD10000UIG00<003FG00000`0000@nF`00?QX0009RMP<00006Eeh00000
001C?P000U<M0`0000ABo@00EaeG7@<0009G7@03001oogoo00moo`003Woo00<007oo00001goo00<0
07oo00001goo00<007ooOol02goo0P000VML00<006]KJe/00P000UHf00@005HEEQD0009Am@04001A
m0000002COD01000COE=m@000TFe00@004WgBOL0009>>0<0009Jf`80009Fo004001K75/L0003Ha/3
000015[K001:VdZK1P0000AC7@000000009C7@800005Dad00000001C7@02000aOol00`00Oomoo`0?
Ool200001U/M00000000E[X0009FVPH00004DYX005:JDYX600000c7j000a^@0300000fjD00000002
FWP01`00EUMFEeIG000eU`00008b?0800003?QX0069f00D00003Bgl0000000@00004D_d005;mD_d3
0002Ead00`00EaeG7@02000@Ool000moo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00ao
o`80009[F`03001NM`0000=F=P05001F5EHE001Am@0200001DhF001=mDge00000Tge00@004FeAKD0
00=9m`800003E[X005[K00800004G]X005KlE_`300001Ull00000000Fa`0009Jf`<00004D_d005;m
D_d30002Dad00`00DaeC7@03000015;m001C7E<M0P00<Woo00<007ooOol03goo0P000U[K00<005Jj
E[X00P000UJk00<005:j00000U:J0`000U;L00L005:k001Rf@00<OX00002<KT01000KY@000000eYh
00<005IG00001@0000=>g@000000100000ICG`00000004Yk0002C]`00`00D_eBo@030002D_d7000A
Ool002Aoo`8000ioo`8000=NM`05001F=UHf001F5@040003CQH01000COE=m@000Tge00<004FeAKD0
10000eJj00<005kJG]X00UkJ0P0000IKG@00000005/M0002Fa`3000015Km001BoE;m0`000UKm00<0
05<MDad00`0000AG7@00001Bo@<00003Dad00000039oo`03001oogoo00moo`03001Jfe[K00<00005
E]/005JkE[/00002D[X20002D]`01000D]aBg0000U:k00@006KH0000008a^@06001^U000G]T005Yh
0`0000EFf`00C[]>^`00009>g@L0009Jf`03001:NdYk00D0009Bo@@000Ioo`03001oogoo00ioo`00
9Woo00<007ooOol037oo00H005igGWMNM`00ESH300001E8g001B5U8F00000ThF00@004geCOD0009=
m@040015]DFe0003FYP300001UZI001NfUkJ001[g0800004Ecd005/MFad30002Ead00`00E_eFo@02
0002E]`00`00E_eFo@03000015LM001G7ELM0`0000=Bo@0000000`00<goo0P0047oo0P0000EFg000
E]]Ff`00009F^`<00004D]`005;LD]`600000e:k001Vf0020002<KT200000ekI00000002E]`01@00
E]]Ff`00C[/00`000UKL0P000U[l00<005[KF]/00`0000ABg000D_eBo@<000Aoo`03001oogoo00=o
o`03001oogoo00ioo`009goo00<007ooOol037oo00<005igGWL00P0000EBE`00DSMB=`00009B5P04
001>5ThF0002COD00`00COE=m@0300001EYG001JV5ZH00000eZI00<005kJ00000P0000AOOP00EceG
?@80009G7@03001G7ELM00<00004D_`005KLE]`300000eLM00000004000015<M0000000017oo00<0
07ooOol0<goo00<007ooOol03Woo00<005KLE]`01@0000ABg000D]aBg0<00005D[/005:kD[/00002
D[/200000g]g00000004000015Kl001Fg5KL1@000U:I00D005KL001OG@00009Jo0<00004E_`005;L
D]`30008Ool00`00Oomoo`02Ool00`00Oomoo`0>Ool002Qoo`03001oogoo00]oo`04001NM`000002
DUL01`00DSMB=e8g001B5P0000=>5P03001=m@0000<000=JE`05001JV000GWL00003FYT20003Ggh3
00000eLM00000004000015;m001Bo5;l0`0000IG?P00000005LM0002Dad30002Ool00`00Oomoo`02
Ool00`00Oomoo`0dOol00`00Oomoo`0>Ool2000015;m001Bg5;L1@000U:k00<005:kD[/03@000UKl
0`0000EB^`00DYYBVP00009BV@80009OG@<00004E_`005KlE_`3000;Ool00`00Oomoo`02Ool00`00
Oomoo`0>Ool002Uoo`8000aoo`04001FVEJI0002DUL01000DSMB=`000U8F00<004hF00000`000Thh
00<005YGFUL00UYG00D005igGWL005ZI0080009G_`<00006Ead00000001C7@000U<M1P0000IC7P00
000005LM0002Ead30006Ool01@00Oomoogoo0000=goo00<007ooOol03Goo00<005;mD_d00`0000EB
g000D]aBg000009B^`<00005Agl00000001?G`03000015<M001K7E/M0`0000=Bg000D[/00U:k00<0
05:J00000P0000ESg@00000005LM00H000moo`05001oogooOol0000@Ool002]oo`03001oogoo00Uo
o`04001FVEJI0002DUL00`00DSL0000500001DiI001>>4hh00000Thh00<005YGFUL00P000eig00<0
04oJ00000P0000IG?P00000005<n0002Dad3000015;m001C7E<M0`0000AC7@00EaeG7@<000Yoo`04
001oogoo000hOol00`00Oomoo`0=Ool20002C]d00`00D]aBg0090002Del20002Dad00`00DaeC7@02
000015<n001Bg5;L1P0000E3G`00000005MN00<001Ioo`04001oogoo000@Ool002aoo`03001oogoo
00Uoo`L0009>NP03001>F@00009>F@04001>>4hh0002CSP01@00FUL005YF00000Uig0`000UMN0P00
0U=O1@000U;m1@000U<M1@003Goo00@007ooOol003Uoo`8000ioo`H00006Bcl00000001C?P000U<n
0`0000=C7@000000100000=C?P0000000`000TLO1@000U<n0P006Goo00@007ooOol0011oo`00;Goo
00<007ooOol02Goo00<004ZL00000Tij00@004ijCWX0009>F@05001>FDiI001>>0050003FUH;0000
15;L001>g4kL0`0000ABo@00D_eBo@<001=oo`03001oo`0003]oo`03001oogoo00eoo`03001;7d/O
0080009C?PD0009C7@800004Dah005<nDch3000015Kl0016_DJm0`0000=C7@000000100077oo00<0
07oo000047oo000^Ool20009Ool01P00BYa:W000CWX0009>NPP00005BQL004XGBQL00003FUH50000
1DYj001>VdjK00000U;L0`0000ABo@00D_eBo@<001Moo`03001oo`0003]oo`03001oogoo00eoo`80
0006Dah00000001C7@000U<M0`0000=C7P0000000`000UKl1@000U;m0P008goo00<007oo00003goo
000`Ool00`00Oomoo`07Ool7000014Xi001>>0000TXh00@004XGBQL0009:5`06001JEUYF001F^P00
0UJJ00<004YjBWX01@0000ABo000D_eBo@<001]oo`8003aoo`03001oogoo00eoo`80009C7@D0009C
7@800004E_`005KlE_`3000015Km001FoEKm0`009Woo0P003goo000aOol00`00Oomoo`06Ool01000
@Wa2O0000TYJ00<004Xi00000Thh00@004XhBSP0009:5`03001:5dXG008000=F^P03001FVP000080
0004D]`005;LD]`5000NOol2000mOol00`00Oomoo`0=Ool3000015LM001C7E<M0`0000AFo000E_aF
o0800004E_d005KmE_d3000YOol2000?Ool0039oo`03001oogoo00Ioo`<0009:FP06001:>DXi001>
>0000TXh00@004XGBQL0009:5`<00006E[X00000001Fg0000U;L0`008goo0P00?Woo0P003goo1@00
0UKl1@0000=Fo@0000000`00;7oo0P003goo000cOol20008OolE000015KL001Fg5KL0`008Woo1000
@Woo00<007ooOol03Goo00<005KmE_d00`0000AFo@00E_eFo@8002eoo`@0015oo`00=Goo00<007oo
Ool027oo0P000U<n0`0000AFf`00E]]Ff`800004E]`005KLE]`5000QOol40017Ool00`00Oomoo`0=
Ool20002E_d5000[Ool4000EOol003Ioo`03001oogoo00Qoo`<00004E_`005KKE]/3000015Kl001F
g5KL0P008Woo1000C7oo00<007ooOol03Goo0`00;7oo10006Goo000gOol00`00Oomoo`09Ool50002
E_`5000POol4001AOol2000>Ool00`00Oomoo`0XOol3000MOol003Qoo`8000Yoo`03001FoEKm00<0
025oo`@005Moo`03001oogoo00Yoo`03001oogoo02Eoo`@0021oo`00>Woo00<007ooOol027oo0P00
87oo1000G7oo00<007ooOol02Goo00<007ooOol08Goo100097oo000kOol00`00Oomoo`07Ool00`00
Oomoo`0KOol4001QOol00`00Oomoo`08Ool00`00Oomoo`0MOol4000XOol003aoo`03001oogoo00Io
o`03001oogoo01Moo`@006Ioo`03001oogoo00Moo`03001oogoo01Yoo`<002aoo`00?Goo0P001Woo
00<007ooOol04goo1000Jgoo0P001goo00<007ooOol05Woo1000;goo000oOol00`00Oomoo`03Ool0
0`00Oomoo`0?Ool4001aOol00`00Oomoo`04Ool00`00Oomoo`0BOol4000cOol0041oo`03001oogoo
009oo`03001oogoo00]oo`@007Ioo`03001oogoo00=oo`03001oogoo00ioo`@003Moo`00@Goo00D0
07ooOomoo`0000Uoo`@007]oo`03001oogoo009oo`03001oogoo00]oo`<003]oo`00@Woo0P0000=o
o`00Ool017oo1000P7oo00D007ooOomoo`0000Uoo`@003ioo`00A7oo0P0000=oo`0000000P00QGoo
0P0000=oo`00Ool017oo1000@Woo0015Ool2002;Ool200000goo000000020016Ool00==oo`8004Yo
o`00ogoo87oo003oOolPOol00?moob1oo`00ogoo87oo003oOolPOol00?moob1oo`00ogoo87oo003o
OolPOol00?moob1oo`00ogoo87oo003oOolPOol00?moob1oo`00ogoo87oo003oOolPOol00?moob1o
o`00ogoo87oo003oOolPOol00?moob1oo`00ogoo87oo003oOolPOol00?moob1oo`00ogoo87oo003o
OolPOol00?moob1oo`00ogoo87oo003oOolPOol0055oo`<000=oo`03001oogoo0<Eoo`00DGoo00<0
07ooOol00Woo00<007oo0000R7oo0`000goo00<007ooOol0=Goo001BOol01`00Oomoogoo001oo`00
08Qoo`03001oogoo009oo`03001oo`0003Ioo`00DWoo00L007ooOomoo`00Ool00029Ool01`00Oomo
ogoo001oo`0003Ioo`00DGoo00<007oo00000Woo00<007oo0000RGoo00L007ooOomoo`00Ool0000f
Ool0059oo`03001oogoo009oo`03001oogoo08Moo`03001oo`00009oo`03001oo`0003Ioo`00Ggoo
0P00PGoo00<007ooOol00Woo00<007ooOol0=Goo000nOol50002Ool00`00Oomoo`0EOol200000goo
0000002mOol0041oo`07001oogooOol007oo00004goo10000Woo0P00KGoo1@000Woo00<007ooOol0
5goo0P00;Goo0010Ool00`00Oomoo`03Ool00`00Oomoo`0>Ool40005Ool00`00Ool0001^Ool01`00
Oomoogoo001oo`0001Eoo`<00003Ool0000002aoo`00@7oo00@007ooOomoo`8000moo`8000Uoo`04
001oogoo001]Ool00`00Oomoo`03Ool00`00Oomoo`0@Ool40003Ool2000/Ool0041oo`05001oogoo
Ool0000=Ool300000goo001oo`08Ool200000goo00000005Ool00`00Oomoo`1TOol01000Oomoogoo
0P004Goo0`001Woo00<007oo0000:goo000oOol20003Ool30009Ool40009Ool50002Ool00`00Oomo
o`02Ool00`00Ool0001UOol01@00Oomoogoo000047oo0P002Goo00@007ooOol002Yoo`00;Woo1@00
0Woo00<007ooOol05Goo0`002goo0P0000AFo000E_eFo@80009oo`03001oogoo00=oo`03001oogoo
069oo`8000=oo`<000]oo`<000]oo`04001oo`000005Ool00`00Oomoo`0ROol0031oo`07001oogoo
Ool007oo000057oo0P002goo0`000eKl00<005KmE_d00P000Woo00@007ooOomoo`8005Aoo`D0009o
o`03001oogoo01Moo`<000ioo`05001oogooOol00003Ool00`00Ool0000SOol0031oo`07001oogoo
Ool007oo00004Goo0`0000=oo`00Ool01goo0`000U;m00<005KlE_`00UKl0`0000EFo@00Oomoo`00
009oo`03001oogoo05Eoo`07001oogooOol007oo00005Woo0`0047oo00D007ooOomoo`0000Eoo`03
001oogoo025oo`00<7oo00L007ooOomoo`00Ool0000>Ool50007Ool40002D_d01000D_eBo@000UKl
0P0000=Fo00000000UKm00D007oo000007oo00<005Eoo`07001oogooOol007oo00004goo0`004goo
00<007ooOol00Woo00<007ooOol00P0097oo000`Ool01`00Oomoogoo001oo`0000aoo`<000Qoo`<0
009?7P05001BoE;mD_d00002D_d30003E_`4000015Km001oo`00FGoo00L007ooOomoo`00Ool0000A
Ool2000FOol00`00Oomoo`03Ool00`00Ool0000UOol002moo`8000Aoo`03001oogoo00Qoo`<000Qo
o`<00097?`04001?7TlN0003D_d30002D_d01000E_aFo5Kl0P000eKm00<007ooOol00P00Egoo00L0
07ooOomoo`00Ool0000>Ool3000HOol00`00Oomoo`02Ool2000017oo000000008goo000UOol00`00
Oomoo`0FOol20009Ool200000e/m0017?`02Acl00`00Cai?7P0400000e;m001Bo@02D_d400000e[l
001Fo@02E_d200000goo0000001FOol20004Ool00`00Oomoo`0:Ool3000KOol00`00Oomoo`04Ool0
0`00Oomoo`0TOol002Aoo`03001oo`0001Aoo`<00003Ool007oo00Moo`03001K?E/m009K?@H0009:
oP03001BoE;m00@0009>o@03001Jo5[l00@00005Ea`007ooOol0001=Ool00`00Oomoo`0GOol3000M
Ool00`00Oomoo`04Ool2000UOol002Ioo`03001oogoo011oo`<000Yoo`800003Fa`005/m00800003
Gc`003[O008jg`03001:oT[n00<0009Bo@06001>oDkmC_d005[l0P0000AK7000EaaG7080009oo`03
001oogoo04Uoo`03001oo`0001Eoo`<001moo`<000Ioo`03001oogoo02=oo`0097oo0P0047oo0`00
2goo0P0015/L00<005llGc`00Ull1P000TKN00@005;mD_d000=>o@800004Fa`005/LFa`20002Ea`0
1000Oomoo`00C7oo00<007ooOol04Goo0P007goo0`000U<M00<007ooOol017oo0P0097oo000TOol0
0`00Oomoo`0<Ool3000;Ool30002F_`01`00Fa`00000Ga`005ll00800003Hc`00000008000=6gP03
001BoE;m00@00003C_d005/L00@000AG7004001oo`000003Ool50002Ool00`00Oomoo`0lOol2000A
Ool3000NOol300000dlN001C7@02Dad00`00Oomoo`06Ool00`00Oomoo`0QOol002Aoo`<000Yoo`80
00aoo`800003E_`005[l00=Jo003001O75lL009O7006001S?6<lHc`006<k20000U;m00<004kmC_d0
0`000e/L00<005LL00000P000Woo00<007ooOol00goo00L007ooOomoo`00Ool0000mOol00`00Oomo
o`0>Ool2000OOol200000e/M001?7P02Cah00`00DaeC7@020007Ool01000Oomoogoo1@000Woo00<0
07ooOol05Woo000^Ool300000goo001oo`0:Ool01@00E_aFo5Kl00000U[l0P0000=K7000Ga`00P00
00AS>`00Hc`000=S>`<00092gP04001BoE;mD_d30002C_d2000015/L000000000eLL00@007ooOol0
00Aoo`07001oogooOol007oo0000?Goo0`002goo0`007goo0P0015/M1`0000=Bo@00Ool01Woo00<0
07ooOol00Woo00L007ooOomoo`00Ool0000GOol002aoo`800003Ool007oo00]oo`800004F]X005Kl
E_`30004Fa`00`00Hc]S>`02Hc/01000Hc]S>f<k0P0000<RGP0000001@000U;m00<004kmC_d00`00
0U/L00<005LLEa`00P000Woo00<007ooOol00Woo00L007ooOomoo`00Ool00018Ool4000NOol30000
15Km001K7E/M0P0000QO7000B_i:oP00D_d005;m0P001Woo0P000goo00L007ooOomoo`00Ool0000G
Ool002Uoo`@000eoo`8000AJfP80009Jo003001K75/L00<0009S>`<00003Hc/00000009W>`800005
8Uh003jn?[h00003D_d300000d[M00000003Fa`20002Ea`01000Oomoo`000goo00L007ooOomoo`00
Ool00016Ool3000POol00`00G]X00003E_d20003Ga`00`00B_i:oP0400000dkm001oo`06Ool01@00
Oomoogoo00000goo00<007oo00005goo000WOol3000>Ool20002F[X01P00F]YJfP00H_X0009Jo0<0
00=O708000=S>`06001W>fLkIc/006Lk2@0000ABo@00B]e:g@800005Fa`00000Fa`00002Ea`20000
17oo001oogoo0P0017oo00<007ooOol0@Woo0`008Woo00D005kJG]X005Km00800003Fa`005lL00=O
70800096oP03001>oDkm008000Ioo`80009oo`07001oogooOol007oo00005goo000TOol3000@Ool2
0003F[X00`00F]X00003H_X20002F_`01`00Ga`00000Ga/006<k00800004Ic/006Lk0003Ic/30003
>[h00`00D_eBo@060004Fa`200001E/M001oogoo0000BWoo0`008goo00<005kJG]X00UkJ00D005/L
FaaK7000009O70<000=6oP<0009>o@03001oogoo00Aoo`04001oo`000004Ool00`00Oomoo`0FOol0
025oo`<0015oo`80009JV005001J^UZjF[X00003H_X00`00H_T00003F_`00`00Ga]O6`02Ga/00`00
Ic]W>`02Ic/01P00Ic]W>fLk001W>`P0009>o@800004B]d005/LFa`30002Fad200000goo00000016
Ool3000GOol00`00Oomoo`0:Ool30003G]X00`00HaX00002Fa`30003Gc`50003C_d00`00Oomoo`05
Ool00`00Oomoo`0MOol001moo`8001=oo`03001JV5ZH009JV008001J^P00001NfP00H_X0009Rn@07
001Jo000001K7000Ga/00P0000=S6`00Ic/00P0000AW>P00Ic/000=W>`<0008fWP04001>oDkmC_d2
000014[M000000000elm0P000ULM00<007oo0000@goo0`005goo0`0000<`000000001goo0`000ejH
0`000f<J0P000U/L00X005ll000006<l0016gP00A]h0009>o@8000Moo`03001oogoo01aoo`007Goo
0P0000=oo`00Ool04Goo0P001EZH00<005kJG]X00UkJ00<006;iH_T00V;i00<005/LFa`00U/L00<0
06<KHa/00V<K00<006LjIcX00VLj00<006LkIc/00`0000<]^@00000020000T[M00<005lm00000P00
0eLM0P0000=oo`00Ool0?goo0P0067oo0P0000=OgP00Ii`02P0000=2N`00GYP00ejH00<006<JHaX0
0V<J0P000e/L0P0016<l1P0000=>o@00Ool01Woo0P007Goo000MOol2000COol01000FUIJEP000eZH
0P000ekJ00<005kI00000V;i00@006LI001K70800003Fa`006<K00800003Ha/006Lj00800003IcX0
000000=Rf@03000]^@0000800004>U`004kMC]d20002B]d20003Fad300001ELM001oogoo00000goo
1@000Woo00<007ooOol0<7oo0P0067oo0P0000=O_P0000000VNL00H006^l000002:N0003A[`01000
@W]2N`000UjH00@006KH001S6P80009W6P<00003Fa`006<l00@00004@]h004;N0002C_d20007Ool0
0`00Oomoo`0KOol001eoo`03001oo`0000eoo`D000=JEP04001JV0000002H[P30002G]T00`00H_T0
0003IaT00`00FaaK7002Fa`00`00Ha]S6`02Ha/01000IcYW>VLj0P000f;I0P0000D]^@00>U`jG000
009>g@@00003C_d005/M00800003Ead005LM009G7@03001oo`0000Eoo`07001oogooOol007oo0000
<Goo0P005goo00<005nnGkh00P0000=WO00000000V^l00<006]J00000P000TJl00H0049k@W/005jH
0003I]P02000IaYW6VLJ001[6@00Fa`40003Hc`60002C_h00`00Oomoo`04Ool20003Ool50002Ool0
0`00Oomoo`0?Ool001eoo`04001oogoo0009Ool300001DXh001:64XH000015YF00<006:hH[P00V:h
00<005kIG]T00ekI00P006LIIaUW6@00JaT005/L0P0000AK7000Ha]S6`800003IcX00000009W6@<0
0003G]X0000000H0009Bo@800003C_d0000000=G7@08001G7@00001Fo@00Ool000Aoo`03001oogoo
00=oo`03001oogoo02moo`03001oo`0001Aoo`800003He`00000009WO0800003Ji`00000009[FPX0
00=Vf006001Ze`00IaX006/I1@0000=K7000Hc`00P0000ES>`00000ngP0000=>oP8000Ioo`03001o
ogoo00=oo`07001oogooOol007oo000047oo000LOol20003Ool00`00Oomoo`03Ool300000dXh001:
>002BSP01000BQQ:60000UYF00<006JG00000V:h00<006Jg00000ekI00D006;j001W6@0000=[6@07
001K75/LFa`006<K00000V<K00<006LI00000`000ekJ00@003Xk>S/000=6W003001BoE;m00<0009B
o@03001G7ELM008000AFo@<000=oo`04001oogooOol2000aOol20002Ool00`00Oomoo`0@Ool01P00
HeaSG6=L001[FP80009[W0800003Je/00000009_NP8000<jW@03000bG00000=Vf003001Ze`0000<0
009[6@03001K75/L009K7003001S>f<k009S>`H00003B_h007oo00Ioo`03001oogoo009oo`03001o
ogoo00=oo`03001oogoo00ioo`0077oo0P000goo1P0000=>F@00BSP00TXh00@004XhBSP0009:6003
001JEP00009VU`03001R^000009V]`04001Nf@000003H_X01000JaU[6F/I0P000e/L0P000V<K0`00
0VLI00<006<K00000ekJ2@0000=Bo@0000000U;m0`0000AG7@00E_eFo@<00003Ool007oo009oo`05
001oogooOol0000TOol00`00Oomoo`02Ool01000Oomoogoo0`000Woo0P000goo00<007ooOol03Woo
00D006;j001SG000009[FP04001_FP000003Je/01@00Je/00000KgX00`0000HjW@00<U`bG000I]P5
0003JaT01000JaT005/L0P0000=K7000Hc/00`0000@n_P00?[h0009:oP8000Moo`05001oogooOol0
0003Ool2000AOol001Qoo`04001oogooOol500001DYj001:FTYJ00000diI00@004XhBSP000=:>003
001:64XH008000=VU`03001V]fJg009V]`03001RnV;j009RnP80009[6@03001ZnF[i00<00004Ga`0
00000002Ic/00`00IaT00002Ha/01P00G]X00000F_/00096W004001>gDkM0002D_d4000015;m001G
7ELM0`000eKm0`0000=oo`0000000goo0`008Goo00<007oo00001goo00<007ooOol00Woo00<007oo
Ool00goo00<007ooOol02goo0P000f;j00@006]JJeX0009_FP05001_>@00Je/00002Je/01000KgX0
07=i2@000V[G00D006lG001[6@0000=[6@03001K75/L009K7004001W>fLkIc/60002B]d00`00Oomo
o`04Ool01@00Oomoogoo00000goo00<007ooOol047oo000GOol00`00Ool00002Ool20002AY`01000
BWY:NP000TYJ00@004iICUT000=:>003001:>00000@000=VU`8000=V]`04001Zn000H_X20002I_T2
0002J_T00`00JaP000040003Ic/20004Ha/01@00F_]Jne[k00000TJL1P000U;m0P0000ABo@000000
009Fo@03001Fo@000080009oo`03001oogoo029oo`<0009oo`03001oo`0000Qoo`05001oogooOol0
0006Ool00`00Oomoo`08Ool20004H_X01`00JaT006]J001_FP0000=_>@07001[Ff]K001_NP00KeX0
0`000S9M10000f[G00@006lGKaL000=[6@80009K70<00004Ic/00000Ic/200000cil001:g@02B]d2
0006Ool01000Ool000000goo0`0047oo000GOol00`00Ool00002Ool20002AY`01000BWY:NP000TYJ
00<004iICUT01P0000E6FP00ASU6>@0000=VU`05001VUP00I[L00003J_P00`00I_UVn@02I_T00`00
J_UZn@060002Ged30002Gc`00`00Ha/000020003F_/300000dZK001>g002C]`00`00D_eBo@030000
0e;m001Fo@02E_d20002E_d200000goo001oo`0XOol00`00Ool00008Ool01@00Oomoogoo00001goo
00<007ooOol017oo0`000U;L00@006;jH_X000=[6@04001_FVmJ0002KcT01P00KcP00000KgX0009_
FPD00007<Ud002XL:Q`006[G00000VlG00D006kf001[6@00009[6@8000=O7003001W>fLk009W>`H0
0003C_d007oo00Eoo`8001Qoo`005goo00<007oo00000Woo00<007oo00002P0000E:NP00BUY:FP00
00=6FP060016>DHi001VU`000VJF00<006Jg00000V[h00<006[g00000VKi00<006Ki00000P000V/H
00@007Ni001OG@800004Fcd005llGc`20003Ga/300000e[K001:V`02BY/00`00C]a>g003000015Km
000005;m10000ULM0P000UKm00@007oo000002Moo`03001oo`0000Moo`03001oo`00009oo`03001o
ogoo00Ioo`03001oogoo00<0009Bg006001Bg5;L001RnP000f/I00@006lH0000009_>@03001_>6lh
00800003KgX006mJ00@00003GUD0000000800004:Q`006[G0002KaL02P00K_H006/I001[6@00KaP0
05lL0P0000=O?@00Ic/010000TJm00<004kmC_d00P001Woo00<007ooOol05Woo000GOol01000Ool0
07oo0P000Woo00@003Im=Wd00092O0040012Fd9K0002BWX01000BUY:FP000TIJ00H004HiAST006JG
0003IYH02000J_QZn6[h001Zm`00I_T300001FKi001[66/H00000gNi00<005/mFcd00U/m0P0000=K
7000Ga/00P0000=Jo000F]/00U[K00<004ZK00000`0000ABo@00E_eFo@<0009Fo@03001G7@000080
00=Fo@@002Moo`8000=oo`03001oogoo00D00003Ool0000000Qoo`<0009Bg004001Bg5;L0002D]`2
0003JaT02P00KaQ_6000KaL006li001_>0000W<h10000Uif00<005iEGUD01P000VlG00L006kfK_I^
mP00JaT00003KaP00`00GceO?@02Gcd01000GaaO75lL0P0000A6_@000000009Bo@03001oogoo00=o
o`8001Moo`0067oo00@007ooOol000Aoo`<00092O0040012Fd9K0002BWX01000BUY:FP000TIJ1@00
0fJF00H006kF001Zn000J_L30003I_T01@00I_T006/H00000WNi00@006nK001K?@<0009K708000=J
o003001Jfe[K00<0009Bo003001BoE;m00<0009Fo@800003E_d00000009G7@@00003E_d007oo0080
00=oo`<000=oo`03001oogoo01Uoo`03001oo`0000Qoo`04001oogooOol20006Ool20002D]`00`00
D]aBg0060002D]`00`00JaT00002KaP01@00KaM_5flG00000Vlh0`0000=c>00000000eif00<005iE
GUD010000Q6k00<006lG00000Vkf0P0000A[6@00KaQ_6080009O?@<0009O70@00003C]d005;m009B
o@8000Eoo`03001oogoo009oo`<000=oo`03001oogoo00Yoo`006goo0P0017oo400000E2>@00AQU6
6@0000=VUP04001^eP00J_P200001V[g001Ze`00I_T000=Vn@04001g^GNi0003Ki/00`00FaeK7@03
0002Fa`00`00F_aJo0030002E_`00`00D_aBo00300000e;l001Fo@02E_d3000015Km000000000U;m
00<005KmE_d00P0000=oo`00Ool00Woo00<007ooOol00Woo00<007oo00005Goo0`000Woo00<007oo
000027oo00@007ooOomoo`8000=oo`<00003D_d00000009Bg080009Bo@04001BoE;m0002D]`20003
KaP00`00KaM_5`04000017<h001c>7<h0P0015if0P0000ANM`00000N7@@000=^mP03001bmP00009_
6003001gf7OH008000=K?@80009K70800003C]d0000000800003D_d007oo00Eoo`05001oogooOol0
0004Ool00`00Ool0000;Ool001]oo`8000Eoo`03000V?@00008nG003000n>`00009:FP050016FTIJ
AUX00002@ST01`00AQU66@00IYH006kF00<000=Zm`04001Zef[G0003I_T01000KoT000000VnK0P00
00=SG00000000ULM00<005/LFa`00`000UKl00<005KlE_`00`0000ABg000D_aBo0@0009Fo@800003
E_d005;m009Bo@<00005D_d007ooOol00003Ool01`00Oomoogoo001oo`0001Yoo`03001oo`0000Qo
o`06001oogooOol007oo0`000U;m00<005;mD_d00`0000EBo@00D_eBo@00009Bo@<0009Bg004001_
6000KaL300001G<G001c>7<h00000W<h00<006[F00000eif00@005igGWMNM`<000032I/00000009^
mP03001bmW;f00800007KaP007OH001_^`00Fcd00P0000AG7@00FaaK70<0009>g@03001BoE;m0080
00Ioo`05001oogooOol00003Ool00`00Ool0000;Ool000eoo`03001oogoo009oo`03001oogoo00D0
0003Ool007oo00Ioo`80008nG004000n>chk0002BUX01000AUY6FP000T8i00<004HIAQT0100000I^
eP00K]H006[g0002J]L01P00K]H006Ki001_n@800004Jm`00000He`2000015mm001G7ELM0`0000=F
o@00E_`00UKl0`0000AFo000D]aBg0<0009Fo003001Fo@0000<00003E_d0000000800004D_d005;m
D_d200000goo001oo`02Ool01`00Oomoogoo001oo`0001Yoo`03001oo`0000Qoo`04001oogooOol2
0002D_d00`00D_eBo@030002D_d01000D_eBo@000U;m0P000U;M00<005;LD]`0100000E_5`00LaL0
07<F0080009c>005001ZeV[F001NMP030003GWL200001QGl0009V`00K_H0009bmP06001bmW;f001g
f0000fnk00@005LMEaeG7@<00005Fad004kM001>g@0300000e;m001oo`05Ool01@00Oomoogoo0000
0goo00<007oo00002goo000<Ool00`00Ool00008Ool01@00Oomoogoo000027oo1`000TYJ00<004IJ
AUX00`0000=2>@0000000P000fkF00D006kF001Zm`00009Ze`04001^eP00I_T500000f=m00000003
Ggd3000015LM001FoEKm100000AFo000E_aFo0<0009Ff`03001Fo5Kl0080009Fo@<0009G7003001B
oE;m00<00003E_d007oo00800004Ool007oo0002Ool00`00Ool0000KOol00`00Oomoo`06Ool20003
Ool20002D_d30002D_d01000D_eBo@000U;m0`0000ABo@00D]eBg@@00004D_d006lG0002LaL00`00
LaIc5P0200000g<h001ZeP02J]H01000GYQNV0000eig0`0000<Eo00000000P000W;f00<007;fL_H0
0P000Vnk0P0000IWO000000005LM0002Fad4000015;m001BoE;m0P001Woo00D007oo001oo`00009o
o`03001oo`0000]oo`0037oo00<007oo000027oo00@007ooOol000Yoo`80008bO@L00003@W`00000
00D0009^eP05001^eVkFK]H00002J]L01000K]I^eVkF0`0000A[g0000000009KWP<00004Ead005LM
Ead30002E_d00`00E_aFo0030002D]`00`00E]]Ff`030002E_`20002Ead00`00EaaG7003000015;m
001FoEKm0P000Woo00<007oo000017oo00<007ooOol08goo00@007oo001oo`800003Ool00000009>
o@03001BoE;m00H0009Bo@03001BoE;m00<00004D_d005;mD_d20002LaL01000LaIc5P000W<F00@0
06[FJ]IZeP8000=NV0<00003G[T0000000@0009bmP03001bmW;f00800004LoH00000Ig`2000015mm
001G7ELM0`000ULM0P0000ABo@000000009Bo@03001oogoo00Aoo`03001oo`0000Aoo`03001oogoo
00Yoo`0037oo00<007oo000027oo00<007ooOol00P002Woo10000Rhm00<004JLAY`00P0000A2O000
?U`000<nF`03001^eP00009^eP05001^]@00J]L00002K]H3000016_L000005om0`0000AG7@00EaeG
7@<0009G7@03001FoEKm00<0009Bo@03001Bg5;L00<00003F]/005Kl00800004Fcd005LMEad30000
15Km001BoE;m0`000UKm00<007oo0000;7oo00@007oo001oo`80009oo`03001>oDkm00<0009Bo@04
001>oDkm0002D_d3000015;m001BoE;m0`000Tkm00<007<G00000W<F00<007<FLaH00P0000AZeP00
I_P000=NV008001N^EjiG[T0015I0009^`<00004L_H007;fL_H2000017?f001_f`000emm0`000ULM
00<005LMEad00`0000=Bo@00D_d00U;m0P001Goo00<007ooOol04Goo000<Ool00`00Ool00008Ool0
1000Oomoo`0037oo3@0000@nG000?U/nF`8000=^eP04001^]@000003K]H40002God2000015/m001G
7ELM0P000ULm1P0000=Bo@0000001@0000ABg000F]]Jf`8000=K?@<00004E_d00000E_d300000eKm
001Fo@02E_d4000[Ool01000Ool007oo0P000goo0P000Tkm00<005;mD_d01P000U;m00<005;mD_d0
0P000Tkm00<004kmC_d00P000W<F00P007<FLaH007]F001ZeP000VKh0`0000=N^P00G[T00Uji00<0
015I000010000W;f0P0000EcmP00Km/006?l00<00003Ead005LM009G7@<00003Ead005;m00D00003
E_d007oo00Aoo`80019oo`003Goo00<007ooOol01Woo0P000Woo0P0037oo1`000TIk00<003iK0000
1P000VkF00D006jeK[E^]@00009^eP800003KoT004nf008000=K?@<00004Ech000000002Dch00`00
EaeG7@020002D_d01000C_e>o@000U;L0`0000=OO@0000000P0000AG7@00E_eFo@<00004E_d005Km
E_d4000015Km001oo`008Goo00<007ooOol00Woo00<007ooOol01@0000=oo`00000017oo00<004km
C_d00`0000I>o@00000004km0002D_d3000015;m001>oDkm0`000TkM00<007<F00000W<F00@007]F
NeH000=Vn006001N^UjjG[X005ji1@0000@Mo0000AP0009bmP<00003Km/006?l00<0009G7@@00004
Ead005LMEad30002E_`00`00E_eFo@0200001Woo00000000Ool0019oo`006Woo00<007ooOol02Goo
2@000TIk00<003iK00000SXk00@003hk?S/0009^eP09001^]Fje001^e@00K]H006oi00<0009KGP<0
0004Egl000000002Del00`00DciC?P03000015<M001BoE;m1P0000A;7P000000009K?@03001G7ELM
00<00004E_d00000E_d30002E_d00`00E_eFo@03000POol00`00Ool00008Ool20002Ool00`00Oomo
o`04Ool200001Dkn00000000C_d01P0000ABo@00D_eBo@<0009>o@03001>gDkM0080009c5P03001k
EW]F00800005I_P00000H_X00003G[X01P00FYUJVEZI000ef@<000030AP007;f00H0009K?@<0009G
?P03001G7ELM00<00005D_d005Kl001Fo0030002Ead00`00Oomoo`02Ool00`00Oomoo`0@Ool001Yo
o`03001oogoo00Ioo`<000=oo`80008^?0H00004?U/003Xk0002?S/00`00K]H00003K[D00`00K]D0
000400001E<n00000000Dil00`000TMo1P0000A;7P00DaeC7@<00004C_d004[nB_h30002Dah00`00
FceK?@03000015Km001FoEKm0`000UKm1P0000=Fo@00000087oo00<007oo000027oo00D007ooOomo
o`0000Ioo`<00004C_h000000002C_d01000C_e>o@000U;m0P000U;m00<004kmC_d01@000W<F00<0
07]F00000W=H00H006;jH_YRnP00G[X200001EZi001JVEZI00000SGI00<003Ym00001P0000A?7P00
0000009GO`03001G?ULn00<00004Dad005;mD_d400000eKl001G7@030004Ool00`00Oomoo`0@Ool0
01Uoo`8000Ioo`8000Moo`@0008Uo0030012F`0000H00003?S/00000009^]@06001^eFkEK]D005<n
0`000TnO0P0000=?_P000000300000ABo000C_e>o@<0009Bo@03001C7U<N00<00003Ead0000000@0
0003E_d0000000800004E_d005KmE_d300000eKm0000000OOol00`00Ool00008Ool00`00Oomoo`02
0003Ool30002Ool20002C_h00`00C_e>o@06000015;m001BoE;m0`000TkM00<004kMC]d00P000W]F
00D007=H001[FP00009RnP8000=J^@03001JVEZI00H00004C_d005<NDah30002Dch600000dln0000
00040002D_d00`00E_`000020002Ead20004Ool00`00Oomoo`0?Ool000]oo`03001oogoo009oo`04
001oogooOol30002Ool00`00Oomoo`02Ool3000:Ool60000249K000n>chk000j6`00>QX20003K[D0
0`00K]E^e@0;00001EIH0011n47h00000THj00H004jKCY/004ZL0002D_`30002D_d00`00D_eBo@03
00001UKm00000000Ead0009G7@<0009Fo@03001FoEKm00<00004E_d005KmE_d2000OOol00`00Ool0
0008Ool00`00Oomoo`050006Ool60002C_d01000C_e>o@000U;m0P000Tkm00<004kMC]d01`000W=H
00<006]JJeX00P000Ukj00<005ZiF[T00`0000EFo000B[a:_000009>o@<0009C7P<0009GGPD00003
Bal005<M009C7@H00006Fcd00000001G7@0017oo00<007ooOol03goo000:Ool00`00Ool00007Ool0
0`00Oomoo`02Ool5000>Ool00`009Q`V70030000149K000n>`000SXK00H003XJ>QX006je0003K]D2
0002Bil400001EIH001FF5IH00000T7h00@004HjASX0009>V`D0009Bo@H00006E_d00000001G7@00
0ULM0`000U;m00<005KmE_d00`0000AFo@00E_eFo@<00003Ool007oo01ioo`8000=oo`04001oogoo
Ool30002Ool2000;Ool01000B_i:oP000Tkm1P0000ABo@00C_e>o@<00097G`<0009?G`80009[FP03
001WG00000=NnP800004E_`005KlE_`60002D_d300000eLn001GGP0200000emn00000007000015;m
001>oDkm0`0000AG7@00EaeG7@8000=oo`03001oogoo00moo`002Woo00<007oo000027oo00@007oo
Oomoo`80019oo`<000037M/0000000H0008j6P03001^]@00009^e@03001?W`0000<00005EWP005IH
EUP00003EUP00`00@OP00005000015:k001Bg5;L0`0000AFo@00E_eFo@<00004E_d005LMEad30002
D_`00`00D_eBo@03000015Km000005Km0`0017oo00<007ooOol077oo00<007oo00001goo00<007oo
Ool00goo00<007ooOol02Woo1@000Tkm00<004kmC_d01@000T]O0`000TmO0`0000AC?P00JeX0009W
G003001NnP000080009Fo0<0009F^`05001>VdjK001Bo@030002Ech200001Emn000005kJ00000T8j
00@004JLAY`0009Bo@<00003D_d005LM00@0009C7@04001oogoo000AOol000Yoo`03001oo`0000Qo
o`03001oogoo009oo`03001oogoo019oo`8000047M/003iK0002>S/60003K]D50003EWP01@00EUQF
F000EUP00`0000E:FP00CY]>V`00009B^`<00004D_d005KmE_d30002E_d00`00E_eFo@020002E_`0
0`00D_aBo003000015Km001FoEKm0`001goo00<007ooOol077oo00<007oo000027oo00<007ooOol0
0goo0P002goo00@004[nB_h0009>o@<00003Acl0000000@0009?G`<0009C?P@000=WG080009Fo0<0
009Ff`04001F^eJk0002CY/20003E_`200000e/m00000003G]X01000@SY2>P000TJL0`0000ABo@00
D_eBo@<00003Dad005<M009C7@800003Ool007oo011oo`002Woo00<007oo00001goo00<007oo0000
17oo0P0057oo10000SXk00H0038K<Q/003HJ0002K]D40002EWT01000EWQFN0000UIH0P000UJI00D0
04YJBUX004jK00<00004E_`005;mD_d30002E_d00`00E_eFo@03000015Km001Fo5Kl0`0000=Fo@00
000010000Woo00<007ooOol01Goo00<007ooOol077oo00<007oo000027oo00<007ooOol01Goo00<0
07ooOol02Goo1@000T/o0`0000A??`00Ccm??`<0009C?P<00004Dch005<nDch30002Fad20002E_`0
1000E]]Ff`000UJk0`0000=FV@00E_`00P0000=Nn`0000000Ukk00<005kJG]X01P0000A>g000D_eB
o@<00003Dad0000000D00004Dad00000000AOol000]oo`03001oogoo00Moo`03001oogoo00Eoo`03
001oogoo01Aoo`L0008f6P03001^e@00009JV@04001FNEIi0002EWP300001EJJ001FVEJI00000TYJ
0P000U;l00<005KlE_`00P000UKl00<005KmE_d00`0000=Fo@000000100000AFo@00000000Uoo`03
001oogoo00Eoo`03001oogoo01]oo`03001oo`0000Moo`03001oo`0000Moo`03001oogoo00Uoo`H0
009??PD0009C7P<00004Dch005<nDch30002Dad3000015Lm001Fo5Kl1P0000=BVP00EYT00UJI00H0
05kkG_/006]k0002G_/3000015[K001:VdZK1P0000AC7@000000009C7@800005Dad00000001C7@02
000AOol001ioo`03001oogoo01Ioo`T000=JV@03001FN@0000800004EYX005JJEYX6000015;L001B
o5;l0`0000AFo000E_aFo0<00006E_d00000001Fo@000UKm0`003Goo00<007ooOol017oo00<007oo
Ool077oo00<007ooOol01goo00<007ooOol01goo00<007ooOol02Woo00<004lNCah00`0000AC7P00
DaiC7P<0009C?PD0009C7@<00004Dah005LmEcd300001E;L001B^e:k00000e:J0`0000AN^@00G_/0
009[N`800004E_`005[KF]/3000015;m001BoE;m0`000U<M00<005<MDad00`0000ABo@00DaeC7@80
015oo`007goo00<007ooOol05goo00@005lm001NfP800003FYT005ZI00<00004EYX005JJEYX30000
15KL001Fg5KL1P0000=Fg0000000100000IG7@00000005Km0002E_d3000@Ool00`00Oomoo`04Ool0
0`00Oomoo`0aOol2000;Ool20002Cah00`00DaiC7P020002Dah3000015<M001C7E<M0`0000AC7@00
DaiC7P<0009?7P05001Bg5;L001B^`050004G[T00`00Jg/000020002E_`3000015Km001BoE;m0`00
0UKm00<005<MDad00`0000AG7@00001Bo@<00003Dad00000011oo`0087oo0P0067oo00@005kJG]X0
009JV@80009F^P03001FVUJJ0080009Fo003001Fg5KL0080009F^`03001F^eJk0080009G?@03001G
7ELM00800004Ead005KmE_d3000DOol00`00Oomoo`03Ool00`00Oomoo`0cOol00`00Oomoo`09Ool6
000015<N000000000U<M00<005<MDad00P000U<M00<005<MDad00P000U<n20000Tjl00@004jKCY/0
009N^@<0009O?@<00004E_d005KmE_d30002E]`00`00E_eFo@03000015LM001G7ELM0`0000=Bo@00
00000`0047oo000ROol00`00Oomoo`0EOol00`00G]YNfP03000015Jk001F^UJj0`0000AFo000E_aF
o0<00009E]/005JkE[/005Jk001KGP00009G?@<00003Ead0000000<001Qoo`03001oogoo009oo`03
001oogoo03Aoo`03001oogoo00Yoo`03001C7U<N0080009C7@03001C7E<M00<00003Dad0000000@0
0004Dch000000002Ech30002B[d01000C[a>_0000TjK00D005ji000006>n00<0009G7@03001FoEKm
0080009Bo003001Fg5KL00<00003Ead0000000@00004Dad000000004Ool00`00Oomoo`0>Ool002=o
o`03001oogoo01Eoo`800004F]/005JkE[/3000015Kl001Fo5Kl0`0000AFf`00E]]Ff`D0009KGP<0
0004Ead00000000NOol01@00Oomoogoo0000=goo00<007ooOol02Woo0P0000=C7@00000010000U<M
0P000U<N00<005<NDah00P000ULn0`0000=Fg00000002P0000=7G`0000000ULm1P0000ABo@00D_aB
o0<00006Ech00000001G7@000U<M0`000Woo00<007ooOol00Woo00<007ooOol03Woo000TOol00`00
Oomoo`0EOol00`00F]]Jf`020002E_`5000015KL001FfeKK0`000U<n1@0000AG7@000000025oo`03
001oogoo009oo`03001oogoo03Eoo`8000]oo`<00004Dad005<MDad3000015<M001C7U<N0`0000IG
7P00000005KL0002E]`80002Bel300001U<N00000000Dch0009C7@H00006Dah00000001G7@000ULM
0`001Woo00D007ooOomoo`00011oo`009Goo0P005Woo0P0000IFo000000005KL0002E]`00`00E]aF
g0020002Dch3000015<M001C7E<M0P009Goo00D007ooOomoo`0003Uoo`03001oogoo00Uoo`03001C
7E<M00<0009C7@D00006Ead00000001Fo0000UKL0`0000AFo000B]e:g@H00005Dad00000001C?P06
000014km001C7E<M0`0000AC7@00EaeG7@<000Yoo`04001oogoo000@Ool002Moo`03001oogoo01Ao
o`80009Fo003001Fg5KL00D00005Dch00000001G7@06000XOol01000Oomoo`00>Woo00<007ooOol0
2Goo0P000ULM0`0000AG7@00EaeG7@80009Fo003001Fo5Kl0080009Fo003001Fo5Kl0080009Bo@03
001C7E<M0080009C?P80009Fo003001>g4kL00D00003Dad0000000@000eoo`04001oogoo000@Ool0
02Qoo`03001oogoo01Aoo`03001Fo5Kl00<00003Dah0000000<0009G7@8002ioo`04001oogoo000k
Ool00`00Oomoo`09Ool3000015LM001G7ELM0`0000AFo000E_aFo0<00004E_`005KlE_`3000015;m
001BoE;m0`0000IC7@00000005Kl0002E_`3000015;m001BoE;m0P0057oo00<007oo000047oo000Y
Ool00`00Oomoo`0DOol20002Dad2000015LM001G7ELM0`00<Goo00<007oo0000?7oo0P002goo1@00
0UKl1@000UKl1@0000=Bo@000000100000IFo@00000005Kl0002E_`3000015Km001BoE;m0`005goo
00<007oo00003goo000ZOol2000EOol300000eLM00000003000eOol2000nOol00`00Oomoo`09Ool0
0`00E_aFo003000015Km001FoEKm0`0000ABo@00D_eBo@80009Bo@03001BoE;m00800004Ead005Kl
E_`3000015Km001FoEKm0`006goo0P003goo000/Ool00`00Oomoo`0DOol2000kOol2000nOol00`00
Oomoo`09Ool2000015Km001FoEKm0`0000ABo@00D_eBo@<00004D_d005;mD_d300000e<M00000003
0002E_d5000NOol2000?Ool002eoo`03001oogoo01=oo`03001oogoo03Yoo`8003moo`03001oogoo
00Uoo`D0009Bo@D0009Bo@D00006Dad00000001C7@000ULM0`008goo0P003goo000^Ool00`00Oomo
o`0BOol00`00Oomoo`0jOol20010Ool2000:Ool00`00DaeC7@03000015;m001BoE;m0`0000AC7@00
DaeC7@80009C7@D0029oo`@0015oo`00;goo00<007ooOol04Goo00<007ooOol0=Woo1000A7oo00<0
07ooOol027oo0P000U;m1@000U<M1@0000AC7@00000002=oo`@001Eoo`00<7oo0P004Goo00<007oo
Ool0<Woo1000BGoo00<007ooOol027oo0`0000AC7@00DaeC7@<00004Dad005<MDad2000ROol4000I
Ool0039oo`03001oogoo00ioo`03001oogoo02ioo`@004ioo`03001oogoo00Uoo`D0009C7@D0021o
o`@001eoo`00<goo00<007ooOol03Goo00<007ooOol0:Woo1000Dgoo0P002Woo00<005<MDad00`00
8Goo10008Goo000dOol00`00Oomoo`0;Ool00`00Oomoo`0WOol4001IOol00`00Oomoo`08Ool2000P
Ool4000UOol003Eoo`8000]oo`03001oogoo02=oo`@005ioo`03001oogoo00Moo`03001oogoo01]o
o`@002Uoo`00=goo00<007ooOol027oo00<007ooOol07goo1000Hgoo00<007ooOol01Woo00<007oo
Ool05goo1000;Goo000hOol00`00Oomoo`07Ool00`00Oomoo`0KOol4001XOol20006Ool00`00Oomo
o`0COol4000aOol003Uoo`03001oogoo00Ioo`03001oogoo01Moo`@006ioo`03001oogoo00=oo`03
001oogoo00moo`@003Eoo`00>Woo0P001Woo00<007ooOol04goo1000Lgoo00<007ooOol00Woo00<0
07ooOol02goo1000>Goo000lOol00`00Oomoo`03Ool00`00Oomoo`0?Ool4001hOol01@00Oomoogoo
00002Goo1000?Goo000mOol00`00Oomoo`02Ool00`00Oomoo`0;Ool4001mOol200000goo001oo`04
Ool40011Ool003ioo`05001oogooOol00009Ool40023Ool200000goo000000020015Ool003moo`80
0003Ool007oo00Aoo`@008Qoo`8004Uoo`00@Goo0P0000=oo`0000000P00egoo0012Ool2003KOol0
0?moob1oo`00ogoo87oo003oOolPOol00?moob1oo`00ogoo87oo003oOolPOol00?moob1oo`00ogoo
87oo003oOolPOol00?moob1oo`00ogoo87oo003oOolPOol00001\
\>"],
  ImageRangeCache->{{{0, 286.875}, {232.5, 0}} -> {-0.0508947, -0.0405654, 
  0.00732651, 0.00732651}, {{6.9375, 136.938}, {226.938, 
  121.5}} -> {-0.285681, -0.144193, 0.00960565, 0.00960565}, {{149.938, 
  279.875}, {226.938, 121.5}} -> {-1.63391, -0.138387, 0.00951316, 
  0.00951316}, {{6.9375, 136.938}, {110.938, 5.5}} -> {-0.238668, -1.19117, 
  0.00922935, 0.00922935}, {{149.938, 279.875}, {110.938, 
  5.5}} -> {-1.6604, -1.25959, 0.00961204, 0.00961204}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["2D Forward Transform", "Subsection"],

Cell["\<\
The wavelet transform is separable, so a 2D transformation can be implemented \
as a sequence of row and column operations. We begin with an 8 by 8 image and \
demonstrate its one step decomposition.\
\>", "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"(", "\[NegativeThinSpace]", GridBox[{
            {\(c\_\(0, 0\)\%3\), \(c\_\(0, 1\)\%3\), ".", 
              \(c\_\(0, 7\)\%3\)},
            {\(c\_\(1, 0\)\%3\), \(c\_\(1, 1\)\%3\), "..", 
              \(c\_\(1, 7\)\%3\)},
            {".", "..", "...", "."},
            {\(c\_\(1, 0\)\%3\), \(c\_\(1, 0\)\%3\), ".", \(c\_\(7, 7\)\%3\)}
            }], "\[NegativeThinSpace]", ")"}], "\[LongRightArrow]", 
      RowBox[{"(", "\[NegativeThinSpace]", GridBox[{
            {
              SubscriptBox[
                RowBox[{"(", "\[NegativeThinSpace]", GridBox[{
                      {\(c\_\(0, 0\)\%2\), \(c\_\(0, 1\)\%2\), 
                        \(c\_\(0, 2\)\%2\), \(c\_\(0, 3\)\%2\)},
                      {\(c\_\(1, 0\)\%2\), \(c\_\(1, 1\)\%2\), ".", 
                        \(c\_\(1, 3\)\%2\)},
                      {".", ".", ".", "."},
                      {\(c\_\(3, 0\)\%2\), \(c\_\(3, 1\)\%2\), ".", 
                        \(c\_\(3, 3\)\%2\)}
                      }], "\[NegativeThinSpace]", ")"}], \(L, L\)], 
              SubscriptBox[
                RowBox[{"(", "\[NegativeThinSpace]", GridBox[{
                      {\(d\_\(0, 0\)\%2\), \(d\_\(0, 1\)\%2\), 
                        \(d\_\(0, 2\)\%2\), \(d\_\(0, 3\)\%2\)},
                      {\(d\_\(1, 0\)\%2\), \(d\_\(1, 1\)\%2\), ".", 
                        \(d\_\(1, 3\)\%2\)},
                      {".", ".", ".", "."},
                      {\(d\_\(3, 0\)\%2\), ".", ".", \(d\_\(3, 3\)\%2\)}
                      }], "\[NegativeThinSpace]", ")"}], \(L, H\)]},
            {
              SubscriptBox[
                RowBox[{"(", "\[NegativeThinSpace]", GridBox[{
                      {\(e\_\(0, 0\)\%2\), ".", \(e\_\(0, 3\)\%2\)},
                      {".", ".", "."},
                      {\(e\_\(3, 0\)\%2\), ".", \(e\_\(3, 3\)\%2\)}
                      }], "\[NegativeThinSpace]", ")"}], \(H, L\)], 
              SubscriptBox[
                RowBox[{"(", "\[NegativeThinSpace]", GridBox[{
                      {\(f\_\(0, 0\)\%2\), ".", \(f\_\(0, 3\)\%2\)},
                      {".", ".", "."},
                      {\(f\_\(3, 0\)\%2\), ".", \(f\_\(3, 3\)\%2\)}
                      }], "\[NegativeThinSpace]", ")"}], \(H, H\)]}
            }], "\[NegativeThinSpace]", ")"}]}]], "NumberedEquation"],

Cell[TextData[{
  "As in the 1D case, at ",
  Cell[BoxData[
      \(TraditionalForm\`j = 2\)]],
  " the iteration continues with a decomposition of the 2D sequence ",
  Cell[BoxData[
      \(TraditionalForm\`c\^2\)]],
  " (so-called low-low image) into four quadrants ",
  Cell[BoxData[
      FormBox[
        RowBox[{"(", "\[NegativeThinSpace]", GridBox[{
              {\(c\^1\), \(d\^1\)},
              {\(e\^1\), \(f\^1\)}
              }], "\[NegativeThinSpace]", ")"}], TraditionalForm]]],
  ", each of dimensions 2 by 2. At each scale ",
  Cell[BoxData[
      \(TraditionalForm\`j\)]],
  ", the image ",
  Cell[BoxData[
      \(TraditionalForm\`c\^j\)]],
  " contains the low-frequency information from the previous stage, while ",
  Cell[BoxData[
      \(TraditionalForm\`d\^j\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`e\^j\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`f\^j\)]],
  " contain the horizontal, vertical and both directions edge information \
(high-frequency), respectively. Consider now an example using a real image."
}], "Text"],

Cell[BoxData[
    \(A = 
      SubMatrix[Partition[ReadImage["\<coke128.bin\>", \ "\<RAW\>"], 128], 
        \ {32, 32}, \ {64, 64}]; \nD\_2 = DaubechiesFIR[2]; \)], "Input"],

Cell["\<\
Here we take the 2D discrete wavelet transform of image A. We use a 2-level \
decomposition.\
\>", "Text"],

Cell[BoxData[
    \(\(\[ScriptCapitalA] = DWT[A, D\_2, 2]; \)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[
      GraphicsArray[
        \(ListDensityPlot[#1, PlotRange \[Rule] All, Mesh \[Rule] False, 
              FrameTicks \[Rule] None, DisplayFunction \[Rule] Identity]\ &
            \)\ /@\ {A, \ FromDWT[\[ScriptCapitalA], \ AutoScale -> True]}]]; 
    \)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .47619 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0113379 0.47619 [
[ 0 0 0 0 ]
[ 1 .47619 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .47619 L
0 .47619 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0113379 0.477324 0.464853 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.015024 0.0192308 0.015024 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
64 string
64 64 8 [64 0 0 64 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
B5AEB3A89C918F8F7D807570635447424C42978C457A7D6B
614F5E66639C9E404040453A3D4540383D3D3A3030788F3A
42A19C9C99A19CA19E9E9EA3A1A8A3A3
111C1E14191E1E28283D3A454A5C595E5E2B8C875E3A2B40
5E8F8C9197A1404240404040473D403D353D332B284C9C45
4FA1A1A39CA3A3A1A1A6A8A1A3A3A1A1
B0B0A6A89EA39C9997918F8C8787808275388C7D85512335
359E94A197543A3D423D4247423D4240383533232B308F4F
4F9E999C9EA39CA199A1A19EA3A1A19E
B5B3AEABA39E99979994918F8C87857A733A858A8075478A
9191999E993540404040424A7D99999794402B231C2B9154
4A9E999C9E979E9C99A1999E9EA1A1A3
B8B8AEABA6A199919794948F8C877D7D753A8A858A85708A
8A8C9C994F3840403D45859EA3B59E9E999733211C289459
47A1949E99979C9E999C9E9C9CA19EA1
B5B8ABA8B09C9C8F8F948F948C8285857830828C8C85857D
7A919494333D404254A19E9E9EA1A39E91996E191C237361
4797979C99A3979E9E94A39EA69EA1A3
B3B3B3A8A3A3999797948F8F8A85877D7A3382788A878787
877A8C6B3035355194A8A19EA1A19C979E8F85171E28516B
4C9797999E9C9C979C9E9EA6A1A1A19E
B8AEBDB0ABA6998F97918F8C858A807D783D7A8A75828A8A
8A8C8A422635409C9CA19EAE9E9E97978C7D801C1C2E666E
4599949999999C9CA19C9EA1A3A6A3A3
B5BAB3B0A6999C9999948F918787877A78387D8787787D82
8A8A8C2B303D6E9C99A1A19EA3A697948F858221194F666B
459999979C97999C9EA19EA1A3A6A3A1
B5C2B3AEA8A199919C978C978F8C877D80407A8A8A7D856B
858A87212B38A19E9C9E9C9C999CA38A4C2E261C19785C73
4599949797949C9E9EA39E9EA1A3A69E
BABAB3B3ABA39C949499948F8A8C85827D428082878F8585
78808F21232E9C9CB3A19C999999542E212119191C6E667A
3D949797919C999E979EA19CA1A19CA1
B5B8BAB5B0A3979C9799918F8C8C85827D3A8082758A8282
878A801C233399949C9CAE9C943D332B211E171C1E80637D
3A9791919794979C9799999CA19E9E9E
B8BAB5B3AEAE9C97999494918C85827D7D3A7A8285688085
878A821E1E2B9794999C99A1453530281E1C1C1C194C6E7D
3A97918F919994979C979C999E9C9E9E
B5BAB8B5ABA89C978F8C978F858A827A7A357A8085876B78
808A8F171E219C999C919C633A33302823211C1919288080
3A8F94918A8F8F9794979C9797A19999
B8B0B0B0A8A6A199978C919187828280753D808280858280
708C8C2823265EA3A197913D3A3830232121302614197D7A
338F8A8F8C918C9497979499999C9C9E
B8B5B5B0ABABA3999194918C8780857A75407D7A7D808785
85918F301C23338299A65E383A33304C6E7A827A2B1C597D
38948F94949191949C9797999E9C9E9E
B8B0B3AEABA39C97949194918585807D78387A7D756E8282
828A8C471E26283D6E913D3535458287807D6E804A147378
3D8C8F91918F999497999C9C99A19C9E
B5B0ABABAEA3A3999799918A828580827A407D8580806385
8C918C5421263D6E8F9E303347998A858782825E3D0C7378
3A8F8C918C918F9799979999A39C9C9E
B0B0B5B5AEABABA39797948F8787827D753A8087827D8266
7A8C8A59577A85978F8A303887917A80807D7D751919596B
388C8C8F8F979499949197979C9E9E9E
AEAEB0ABAEAEA6A69C94918F8A85857A754082738082807D
788270352328738F998F3340978A877A6B7D7326191C6873
388A878C8F9191949794999E9C9C9E9E
ABB0B3B0ABB5A6A39E8F918F8785807D75407A7A687A7D7A
80472E231C2126878A8A3338918F828273541C1419307380
388C878F8F978F94949797979999999C
ABAEB0B3B0B3ABA8A397948F8C8280787545808078736B7D
422626231E1E2868878A3530427A6E4A211E141C19687D7D
408C828A91978F949799979797A19C9C
AEABABB0B0A6A6A69E8F8F8A8578807D7A407D7D7878755E
141426231E1E235C8A853330332B28231E19191421807D7D
3D87878C8C97919194979797979C9499
ABAEABB0AEB0ABA3A19E8F87827D7D787845827875827A4F
0C192640422126668A8A422E3328231C1919191759687D78
428A878A8C949191919797979C97999C
A8A6B0ABA8AEA3A19C978F8A8A82827D7047827A6B757A23
113D78807D611E7D8280702E332821171719193080596670
4A87808C8A8A8F8F918F979499999E9C
ABB3A6A8A8B0A8A39C91918582857D7D6B45807375617514
2B8580736E421E6887788A472B26141719212E786B1C7A66
57858A8585918F91918C9494949C9C9E
A8ABA3ABA6A8A6A89E978F8A80857D787542827A75735E14
5E7D785121171E578C85878A63231E1723596623111E7361
5C858A878C8C8F8F919197979799999C
AEABA8A6A8A6A3A1A399918C82827D75734F807878757511
30231E1C1C191C4C808285808A7D6B512E191411171C7361
6187878C8C8C918C919794979797A19C
A8A6A8A8A6A6A3A69E9C978C8587807A734F87705E784F0F
11191E1919171E4C3D857D7A63351E1411111414111C685C
6B858A878C8C8A8C919197979794A697
ABABA6A8A6B0A6A69C9E978A8A827A70705C7A784014140F
111C2317171E2B423030402B1E231C141119171714146B4C
758787828A94918F948F9C919C949E99
A8AEAEA8A6A3A6A3A399998F857D7D73756180783A141411
11191E30516675422E212E1E1C1C1C171717141714196B40
8085828585948A8F918A97949799A1A1
A6A8ABA1A8A6A6A6A199978C877D7A7373687A753A0C1114
1C456B756E592B3D30282621191E1C190F111726425E6833
828A85878C8C8C8C8C97999C9E9E9CA1
ABA8A6A6A6A3A3A3A19E948F85857373706E78683D071942
6168683D191919353023261C1E1C1E14171417547A61732B
82827D8A8C8A8F8C91949799979EA19C
A8A8A8A6A1A89EA19CA199948A8580706E707A753A406859
281721191417143535262B1E1E263D14170F111426756338
85857D858587878F9197979799AB9799
A6A3A3A1A1A1A19C999E99918C807D786E7580736E574557
0214111411141933382E3D5468732B0F141111111114594A
8082858A8C858A919494979C9CA1A19C
A8A6A1A1A1A1A19C999791948A7D80756B7A7075683D0F2B
0F111419213A574A6B7578736E3519170F140C0C1419425C
80828787878A8F9197919C9497A19C97
A6A69EA3A3A1A19C999997918C857D7570757D6B6B171128
0C1138473A3A686B7575547354171C2B230F0C0F1114456B
7D8585828C8791919197979C9C9E979E
A8A3A6A3A3A39EA197978C949187807A73787D6E5E211159
47541E1119141C667868451C1714216B54510C0C0A193A75
7A828C8A87918C91979C979C999C9E99
A6A39EA3A1A3A1A19E9494998C808078707D706E61514C68
610C1114141117237A784A17171947756B6354230F144070
7D7D858A8C8C9494979E979C9C979E99
A3A1A399A19C9E99949794949187877D7378736E66665763
300A11111414112173754C17171C73736E665C4A3A0F3D78
7A8285878C8F919494999C9799999997
A39EA69EA19E979797979491918F857A787570706B6E6851
050C141C1E1714196B78471714576666330C0F0C144A3575
75827D8C8F949199979199999C9E949C
A1A6A1A39E99999C9E919494949182807A78736E666E6B57
02111C616B510F175C704C14267359140C140C0F0A116375
7A75858F8F948C9197979194919C9999
9EA39EA19E94A1999797918F8A8C857D7875736E546B683D
0C4519736B6E11176E6B5114594A190F0C110F0A110F5170
7878858C8A8F8C918F94919C9191979C
A6A39EA19CA199999999998F878C8A857D75706E6657613A
1E5C176E616614237070541E5411170F11070C0A0F112E6B
7880858C8C91918F9194999797979797
A19EA3A39E9C9C979497918C8F82878080756E6B5E615E30
0719196E6B570F476E704F47170C140C0A0A0F0C0F0F1973
6E75828A8A8A8F918F8F979997949794
A19EA3A1A19C9E94999799918F87827D82756E686368634F
000C1C706B3828686B736B3D0A110F0F234F63350A0F146E
78788C8A8A8F8A8F8F94949797979797
A69E9E9EA19C99979199948C8C8C807D7A736B66596E685E
050C146E63405E6666636B14140C190F4F6B6B331C0A146E
7078878787948C8A8F8F8F9191949797
949C97A19C999E99918F94948A8C827D7D75686659576163
380C28544A28191C686B57140F38470A6654570A380C1C61
705785878F8A8C8F94978F9794979494
9C9799999CA191999497918F8A85827D78706868595C5161
23472E19140F11174A70470A1461450A616630214C0A2E66
6E518285858C8C8C91948A918C97918C
978F8F94A3979C8F979791978782807A7A6E636361615E40
0A0C0C110F110F14476B33142B61400A5E630F42350C4068
706B80858A8A87948A948F948C8F918A
97858C8F999C99979194918F858A80827D75635C5C5E5105
05070A0F0F1114145466380C114C260C5C54145E3A056161
6E637D878A8F8A8C8C8A8A91948C918C
948A918A949C97949194918F8787827D7A6B66614A574000
070C0A193551421761544A0A0C11140A54211C611E28515E
706878858A8A8A8A878F8A8C8F948C8C
9794878C919C949194948F8A878785807A736361574C3502
07194C515E5E3351635E610F170F0A0A590A2B610F616159
6B617D82878C87878A8F8A8F8F918F91
99998F8F9499978F948C8787878278807568595E5C59261E
113D63685E5168686866702B17260F0F591482707D757375
70577882808782858A918A8C948F8C91
979E9797949797918F8C8A87857D7D7D7A75666866707378
4C7DB8D9B38A8A8F878A919497F5422638639E918A82807D
7A5C857D7D87878A878C8A8F8F878C8F
94978F9497948C8F8C8A878782857D7A707A6E7373737878
7A97919CA89C807D787A807D806B61661EEBAE7A7A667575
5C787D808285858A878F8C918C8F8F8A
918F94918C918C8A8A8A85858285827D75756B68635E6673
809975737373737073736373757A7A631EFF807570686B6E
61757A808082878585858C8C8C8C8C8C
918C8F8C97918C8A8C878A8780827D7D75756E636368636E
6E8F756E68637068686E686670707047118F6B6E6E706370
687A8282808C878A8587858787858F8F
94918F948F8C8C8A85878A8585827D7A75786E635E5C5E61
6168686863636168666663666E6168280F5773666E68666B
737A7A7D808787808285878787878585
8C8C8F8C91858C8F8787858A85827D7A7878756359575761
5E595E636361635E5E6363666666591411576B6B63666E6B
75787D807D85828280858A858C858C8A
8C878C8C878F8C8C878C87877D857D7D707870665C545759
5C59545C5C5457595957575C5961570C0F4057544C4C454A
737A7D78827A8082807D808A85878582
8C87878F8A87828A8A8080827D827D78786B70614A453842
424047454C4A575757635E68616B6354515445423833353A
5E787D7A82807D827880808582858A8A
8A82858A8A8A878A8A828580807A7D787870704C2E232121
23333D404C5157545E5C666870827A736B68665954475157
6678757A7A807A7D7880828282828287
8C8A8F878787858082827A807D7A7A757073704C474A515C
6E6882807A7354457859614A336E7870686E6B6E6B6B7373
787578757D7D7A7A80827D8285828582
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0113379 0.97619 0.464853 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.015024 0.0192308 0.015024 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
64 string
64 64 8 [64 0 0 64 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
E8E0DDD5D8C8EAC1BDD1B1C4EBF1F2F25053525457514E6D
4C42545B5A5A5B593F413E4146494D4A555A5D856150605F
5A597B7F6A585F59595B57595A59595A
FDEFE9DED7E3D6C2EFFAC5C0E8EFF2F55A5B585A575D604B
5B3D5859595957585859595A585A595E565B544C57596058
734743504960575658595E59595C5B5B
FFF0EAE0D8E4C3DBF5CBA3CAE5EEF0F4585A5A5A5A5D5F4F
556F7B575B5C5B5C5A5D5C57595959585A5F55576258596A
495B5A5A51565D5E5959585D59575B5C
FEF1E9DDD5E3C8CDD4B5B9C4E3EAEEF25B5C5A5A595D4C6E
6A4A3F57595959595A595E565A5A5C5A5D585E57575D5758
595A5559364A5C5A5959595B5A595859
FCF5E9DED5E0CAD0C8E5C9BFE1EBEEF2595758595C546C63
5A486D585A595A5A595B585B595A5A59565A535660565D54
5361436F6A5F5D575B59585959595A59
FBF8E9DCD6CEAFC3C2B2A6D0DFEAECF05A595C595B662A47
637E42565C5A5C59595B565957585B5A59576653595A595D
5C4E685C5C595A5C585C565959595A58
F8F6E9DCD9C1B8B9DEB3AAC3E1E7EBF0595958595A5F8368
5B5E69615A585A5B5D5C5C585B585A585A57565B5F58594E
575D56667B7660565D5D5B5C5B5B5B59
F7F6ECDBD4A4B6B6ACA2A3C1E2E7ECF1585957595F43556F
7B5B4D4F5B5B595959585C5C5C57595B5D5C62565E58587D
6A5C6D44544A52585A59595859595959
F5F3EDDCD7B3A5B4C4A99BBEE2E7EDF158585A5A596B4E45
56616C5C595A5959595458575959585A5D535663594B2742
5E5A505B5A455E63595957575C5D595A
F3F1ECDFD6C2A1B1B8C2B0BFE2E9EEF0595B595959535F5F
5E4D63525A585B59595A595C5D5B5A585B5E5C525666685D
5B554A444B6A64575A58595B5A5A5C5B
F3EFEBE3D8BFB9B8C0AA95BCE2E8ECEE575A595A57615C4A
506E565E575B59595A595F5A5F5A5D575B595B5D65635F61
5D5C6F6A606053585C59595A5A5A5A5C
F2EFEBE1D4C4B3BBBDA9B3B4DEE7EAEC595A595C5B4C6371
5B4556585B59595C5E585B5C5A5857585859585E67413F51
595E575A5C67495E5B595D5B5A595959
E9EDEAE1D3B09DADB0A5B1BDDBE5E7E95A595A595D796558
697B6A525C5B5A575C5A5B575A5B5A595C585B5E2F496B5A
574572763752675B5A5A5A5A5A595A5C
EBEAE5DFD4C8E1DDD8C1DCD5DAE3E7E85A5B5B595B4E555A
5945515B59585B595C595D5A595958555A5D3D5668615D5F
4A3D5665655F5A585B585C5C5A595A59
E7E6E4DFD3CCCFCED3BCCBCEDCE1E3E5625D5B5757667064
575F6E765A5B5C5B57575C5A59585B595958615B69733F46
65655F59565E70595A5C59595D5D5B58
E3E1DDD7CEBBC6CAC8C8C7C7DCDFE2E4918C80765862564C
65836557504E4D585A5A5A59595C5A5C585D6D5F284B6E5F
5B5B5E5E5B37445C5C5858595A595C58
5B595A7D575A5067515162565759585A5B5858575E515956
5D6454595A58595F5C5A5B5B585959585857444A68626969
735F345A595C70585A575B5A5A575957
585A5C7E554C804C53357E56565B595158595B595C60575B
5C535D5A585C5A5C5A5A5A5A58595A5B5A59616C723B4042
523E5B666F585A57595D5B595C595A59
59595A7B53359050515F525D585958505A585A585B5D5551
54565C59595A5A5A5A59585659575E5D595C5547565F5E67
55625E544B5C5E5B5C595A5858595A58
575D5D795637912B70577F5C58585951595C585856586064
55565459595A5A5A5B59585E595B585A5B59545F5E6C705A
575C5A446E6E4662585B58565C575759
575C5C79563F832C4A4C8C5B565B59545A575B59515D565B
62555B5A5B5B5A595B595D585B5C5B5C5B5C595E59504A5C
5B5A4D6859595B545C5A5C5B5C595E59
56595E744D766F255A5E4F62545959565B595A585B5B6058
4F505C5958585A5A5B585A5A5B5C5C595A5A5B63615B565E
5D55645A736E5B5B5F5B5C585C585A5B
58575B72375C733F5A617255575A5B545B5A5B5959595557
5B5E4B5D5A5A595A555A595C575C595B5C5C535764574D36
5C5B665F47485E5A525B575C5D5D5B57
59565A646B5C575B5A61554A575B5A555A5B5B5B4C624E5C
58587257595B5C595759595A595C5A595A575F5839606763
59605158565D5459635B5A5A595D585B
5858595D666365584C625E495B59565559595B5950675058
5163545A5A5A59595E5B59585A5B5958555C5363625F7161
585F505A51525D545B5857595C585B58
595B575A656468257F48814C5958595658595D5A5F46605E
6C505E565B5A5B595A5C5A5A5759575855575E6060504F5C
595D635C67716464595957595A595A58
5A58585A4E7B3C2F5363784F575A5B565A5B585B604D534F
4C56545F5858595A5655595759595D59575B564351234A45
4B3D00616C47474E595A5A585B5A5D5A
585A58575B875A31603A8354565959585B5A585956634E61
6F635858585A59595B595D5B5A5C58585A596159516A615C
5C5E5E50325B5E5D5C5B5C5B5C58575B
54585A57466C50295653785B545958595A5A595A6150545E
4B4468545B5B595C5757595B5A5A595A5A5B595C5F5A5C59
5A5A5D596B5B595B585C585B5A5A5A5E
575959585468555444545D6557595A555C5A59595869555A
5667595A5A5958595B5B575855585A59595753515255595B
60625D736C59585C565B5C595B59595E
595A585660545D5A3E625957575B5A59595A5A575B595557
5E59576059585A575E5B595658585A58585E727E7B796857
5D4C464A4F5962605C5A5A5B5B5A5B59
5A595955665C4D57555A5954575B595B585A5A51595C7056
545B67585A5A5C4A0F12242B3D496374624D3C336A714F49
6362646B666A4C665852515053514E4A
555C5C605B5C5C493E645F6558625D5D58575860566D2083
525F5A5B575A5A7256575A5B5A59575C5D6A5A3F5B5E535D
5958594E6061585C595956595B5B5A61
5C5C5B57595A5A4647517F61583864575B57584665601F85
5457595F5B5A5A535A57595B5C5957595C5858615C555C60
5D575557465A6356575B5C585956595B
5C54585B5B575A4149545E5F55735869515B595D51643485
545C5D5856585A545A575859595B5D5C605F595F595A5E64
5A5B5B5E625A4C5F5B5C5B5857595B58
535B5A575A5D58424E5D59584070744F5D5B5C542E6B4D84
535859575B5A5A51585B5A595B595C595B5D545A5D5B5358
5C5B545D665760595C5B585A595A5859
5B5859575F5B5641535254582F6744585B5D535F4D7F5A87
5159595B5A5A575757595C585C5859585A5B575560595D62
544F5857575D5C595B5559585C59575C
59585E5B5A5B5B414E5F595C306938545649615E5D7E608F
515A5B5C59575B535959595C585D5A5A58635F5A54585857
4D4E5B5A5B585759595A5A5D595C5B5A
595C5C59565D593F4F55615C2A663756476B575C59654192
4F5E5C59575C5A53585A5A5D585958585A575B525A5C535C
6A595F565D5E6657585958595859595C
585B585B585A56464C5B5463316B6D50515B5E5656674D91
53595B575B595A505B59575B5A59595C5A5B645959585F55
585F64574C605A5C5B5B5E575B55595B
5A56575C585E5B435059635941716454756C51575857458C
525B5A5859575B505A585C575A59595A575A645959585855
5A5F515F504C555B5B5859595A595A59
575B5A5B595B5746495A535A486A57527A395D5E496A498C
535B5B585A5959555A57595B5A58585A58525E6B505B4959
596A52654D645B575A5859595A5B5959
595C5B55595859464E5E5E555D5E754B735A516063774A8D
565A5D595A5C5B56595E595B5A5B5A5C585C5A5460535E5D
565B575C5D4658595A585A5A5A58585C
5B5959595B5858454B614B75595077486955585B585A5489
555B595B59585B545E585859585C5B5859535E5B61594B54
615C5C595D674B59555D5B5A5B5B5C5B
5B5D5A59575B5A4D4859337D484F8B4540615F5E66384876
545D5A57575B5957575959585958595E5A584F63614D605D
5162565175465E5B5C5B595A5A595759
5B595A565B5F594A495D3758555E6F4A584D5B634E61396C
5558585A5A5A55555B5B595A5A57595A604F5C55585D5644
5961545D575955595A5B575A58595E5A
5B5D5B5C575A59504C60565E555C5C664E5A5B5D595C355B
555C5A56545652555A595B5C5A595B5B5A59585E515A7458
5C5A5B5C5A59615C5856575D5A585A58
56585957575959555157626152565E5B565D5A5C6154374B
5C5A5A5A58595959585C5A5A5858545A5B654A656250595B
595D545B4C745D5B585C5C5A595A5E5B
595C5B5C595B595C5263546051606950575D4A5963603E48
5F585B5A5A5F5B555B5A5B585C5B585A5E5B594A585D525B
5456555B5C5B63595A5C5859575C5B58
5B59575B5A575762584B7069585F4E555D48645B59594E4D
59575957575D5955575B5B5A5D58595B5C64625A60596953
4B635F5E5F5C5A59595E5C58595B5558
5B5A5B5B5D575A5F51437A595E58664B5F56715565616153
565B5A5B5D5A59555658595D59595A5856565D6F565A5D5E
5C57535B654F5D5C595A5B59575B5B59
5758595B5B5757605A5A644E5C5A5D3F52634C56535A6A54
5A59595B585859555D5958585A595B5B585A5E516355625A
5653535E574F4757565A595B5B5B555B
59585A565A595C5B5A61507B6A4B6C494D7846625C635555
5C5A5D585B5D5B58595D5E58585A5A595B4F5D555558575E
5C614E585B5E63595B59595856595A57
5C5B595B575D585A5A5E477F88557A3F4E3C5F585A576354
5A5B595B595A5A565A595958585D5B5A59595D605C59525B
4C535E5C51605357585B5B5A5A5A5B5A
5758575A575759555B604E7A7A417E534E6A5A6346687C51
555C5B5B595959545A5B57575A5A58595B54594D525B6851
666352565A51575458555A5A5B595A5E
5C59595D585C5B585C6159646C495E4C3D6F41463C497947
515959585E5B5A585C5553595A5B5A585A584F5062555B56
5D505C595D67585E5C575C5C5858595B
5C53595A5C5B59575E5B5371595B5D59557446497C3D614D
535A5D5C5D5C5653585A5A595A585758595D625C5B5A5559
54525655506466585A58595D595E5B5C
585A595C595D5A565B6241615D5A54474867543486654B50
59585A5C5C595A52565858595B595D585A5C605C5F5C465B
5F6259614C3A5E595C5A5A5A59575A58
5D5B57575B585D57605A5D6F4A565F553C6D62214B69574E
545C5B5B5C565C575B585C595A5B5A5C59565A4F5C5B5A58
52444A675E5C58655F575B5A5A5C5958
5C5A5B5A5B5A5A5E5F5B596B5951615C596169A843585862
535B5A5C5B5A59595B555A58585A5B5A595B595F55575A5C
535B5E404D5A5C57575C5C5B5C59585A
59595A58595C5A5C5A5B5E635C5A565B5D574AAF59596063
575D595B5A59585657575A585C5B5959585A5C5A5B58555B
5A5E5E62625D585B585B5C5A5958585C
5956595D5A5A5B5D555C5C595B595A5A5A573E82485B5957
595C585B575758575B565B565A575954585C5D5A565B585D
5A5962545E59575F5A5D5A5C5758595B
5C5B5D575A5E5959545F5F595A56575E5D5C4E65565B5C56
55565C5D5B5B5956575B595B5D5B5A5C5C585A5359595C54
5963545D5C5C5956575759585C59575A
585A59595B58585B4A685755545C514A5370515D585C565C
58595B5B5C5959505A5A5A585B5C57565E40685D574C7F4F
5B5B595D5B4D614C5C59585B5757596E
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 137.125},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000RA000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo0007Oon2000=Oon20008Ool000Moo`03001oogoo07ioo`03001oogoo
00]oo`03001oogoo07ioo`03001oogoo00Ioo`001goo00<007ooOol0OWoo00<007ooOol02goo00<0
07ooOol0OWoo00<007ooOol01Woo0007Ool01000OomJeU[F0UJe0U[F0UJe0Tic0TYB14Ha0Sg_0T8@
0cW>0S6<0RU:12480RDY0R480TYB0THa0R4813g_0SF]0S6<0RDY0Re[136<14ic1b4811cW124821cW
11S60Sg_0THa0QcW0R480U:D1Tic00=BU4icCW<00U:D1Tic15:D0UJe15:D0Woo00<007ooOol02goo
00@007ooMkeg_@9cW09_N`9[FP9_N`9W>@9g_@9S609Nm`9[FP03F]IS66<H009g_@IkgP`YBP8U:@8e
[@8U:@8Q208YBPT]J`8Li`8Q208Li`@Q20HU:@8YBP@]J`92408aS08YBP8aS0H]J`@mk`8e[@T]J`8Y
BPX]J`9oo`03001oogoo00Ioo`001goo00@007ooF]IJeP9F]@9JeP9F]@9>L`9:DPA6<@8mk`9240<i
cP8aS08YBP@Q208U:@8Q209:DP96<@8Q20@mk`8e[@8aS08U:@8]J`@aS0A>L`LQ20@Li`@Q20PLi`@H
aP8mk`96<@8Li`8Q209BU0I>L`03DYA>Ldic009BU0I>L`ABU09F]@ABU09oo`03001oogoo00]oo`04
001oogNmMkd2Li`2Kg/2JeX2Kg/2IcT2Mkd2HaP2G_L2JeX00e[FHaQS6002Mkd6Nmh<:DX29BT2=Jd2
9BT28@P2:DX9;F/27>L28@P27>L48@P69BT2:DX4;F/2@Q02<H`2:DX2<H`6;F/4?Nl2=Jd9;F/2:DX:
;F/2Ool00`00Oomoo`06Ool000Moo`04001oo`Q2248436<2248636<45:D37>L28@P29BT8;F/25:D2
AS42@Q02;F/27>L25:D28@P2;F/4AS44BU82DY@=8@P27>L28@P27>L26<H27>L26<H45:D29BT2CW<2
8@P29BT6DY@2CW<9DY@2E[D:DY@2Ool00`00Oomoo`0;Ool01000Oomoogoo17Nm0Vmk0V]J0W>L0V]J
0V<H0WNm0Woo0f<H17Nm17_N22e[0RU:0Re[0S6<0RDY0Re[0QcW22e[0RU:4Be[0RU:0Re[0RU:0RDY
0RU:0Re[0S6<0Re[0SW>12480RU:0RDY00<aS2U::DX00RU:42e[0Woo00<007ooOol01Woo0007Ool0
1000Ool8@PQ210aS0PQ21PaS11BU0acW0R480RDY22e[0QBU0THa0T8@0Re[0QcW0QBU0R480Re[14Ha
14YB0U:D3B480QcW0R480QcW0QS60QcW0QS611BU0RDY0Tic0R480RDY1U:D0Tic2E:D0UJe2U:D0Woo
00<007ooOol02goo00@007ooOomoo`Ag_@9_N`9[FP9cW09[FP9S609g_@9oo`=S60Ag_@AkgPP]J`8Y
BP8]J`8aS08U:@8]J`8Li`P]J`8YBQ4]J`8YBP8]J`8YBP8U:@8YBP8]J`8aS08]J`8icP@Q208YBP8U
:@03<H`YBRU:008YBQ0]J`9oo`03001oogoo00Ioo`001goo00<007ooF]H00e[F0U:D0UJe0Tic0U:D
14ic14YB0dHa248@0SW>0QcW0THa0Sg_0T8@0RU:0Q2411S60Tic0TYB0U:D0TYB0RU:0acW0R480QcW
1R480QcW12480QcW11S60Q240QBU0QS60THa12DY24ic00=BU4icCW<00U:D0Tic15:D0Tic1U:D0Tic
0Woo00<007ooOol02goo00@007ooOomoo`9kgP9g_@9cW09_N`9cW09S609_N`9kgP9W>@03DYAW>FLi
009cW09g_@AkgPh]J`8U:@8YBP8e[@8mk`8YBPd]J`8YBP`]J`@YBP8aS0@]J`8e[@8U:@H]J`<YBPh]
J`8YBP@]J`9oo`03001oogoo00Ioo`001goo00<007ooF]H00e[F0U:D0UJe0Tic0U:D14ic14YB0dHa
248@0SW>0QcW0THa0Sg_0T8@0RU:0Q2411S60Tic0TYB0U:D0TYB0RU:0acW0R480QcW1R480QcW1248
0QcW11S60Q240QBU0QS60THa12DY24ic00=BU4icCW<00U:D0Tic15:D0Tic1U:D0Tic0Woo00<007oo
Ool02goo00@007ooOomoo`9kgP9g_@9cW09_N`9cW09S609_N`9kgP9W>@03DYAW>FLi009cW09g_@Ak
gPh]J`8U:@8YBP8e[@8mk`8YBPd]J`8YBP`]J`@YBP8aS0@]J`8e[@8U:@H]J`<YBPh]J`8YBP@]J`9o
o`03001oogoo00Ioo`001goo00<007ooF]H00e[F15Je0U:D14ic0TYB0Tic0dYB14Ha148@0Sg_0SW>
0QcW0T8@0THa0T8@0SW>0R480THa14YB1Tic0QS62B480RDY0Sg_14ic14YB0R480QBU0Q240PaS0QBU
0TYB0RU:0RDY24ic00=:DTicCW<014ic0U:D1Tic1U:D0Woo00<007ooOol02goo00@007ooOomoo`9k
gP9g_@9_N`9[FP9cW0AW>@9[FP9JeP03G_MS66<H009cW0Ag_@9kgP`]J`8U:@@e[@8U:@8Li`8YBPd]
J`8YBPh]J`@YBP8]J`8YBPH]J`8YBP8]J`8HaP039BT]Jbe[018]J`9oo`03001oogoo00Ioo`001goo
00<007ooF]H00e[F15Je0U:D14ic0TYB0Tic0dYB14Ha148@0Sg_0SW>0QcW0T8@0THa0T8@0SW>0R48
0THa14YB1Tic0QS62B480RDY0Sg_14ic14YB0R480QBU0Q240PaS0QBU0TYB0RU:0RDY24ic00=:DTic
CW<014ic0U:D1Tic1U:D0Woo00<007ooOol02goo00@007ooOomoo`9kgP9g_@9_N`9[FP9cW0AW>@9[
FP9JeP03G_MS66<H009cW0Ag_@9kgP`]J`8U:@@e[@8U:@8Li`8YBPd]J`8YBPh]J`@YBP8]J`8YBPH]
J`8YBP8]J`8HaP039BT]Jbe[018]J`9oo`03001oogoo00Ioo`001goo00<007ooG_L00ekg15Je15:D
0Tic1dYB14Ha0T8@13g_0SW>0QcW0THa0T8@0THa0T8@0SW>1THa14ic0RDY0QcW0b480QcW0R480T8@
0Tic0U:D0U[F1Tic0TYB0QS60Q240PaS0QBU0TYB0Re[0R480U:D0TYB14ic00=:DTicCW<034ic0U:D
0Tic0U:D0Woo00<007ooOol02goo00@007ooOomoo`9kgP9g_@9_N`9[FP9cW09W>@9[FP9W>@9cW003
IcUNmekg009cW0Ag_@9kgP8]J`8YBPH]J`8YBP8e[@8aS08]J`8U:@8e[AT]J`8YBP8]J`@YBP8aS08Y
BP8]J`@YBP8aS08Q20@e[@<]J`8YBQ0]J`9oo`03001oogoo00Ioo`001goo00<007ooG_L00ekg15Je
15:D0Tic1dYB14Ha0T8@13g_0SW>0QcW0THa0T8@0THa0T8@0SW>1THa14ic0RDY0QcW0b480QcW0R48
0T8@0Tic0U:D0U[F1Tic0TYB0QS60Q240PaS0QBU0TYB0Re[0R480U:D0TYB14ic00=:DTicCW<034ic
0U:D0Tic0U:D0Woo00<007ooOol02goo00@007ooOomoo`9kgP9g_@9_N`9[FP9cW09W>@9[FP9W>@9c
W003IcUNmekg009cW0Ag_@9kgP8]J`8YBPH]J`8YBP8e[@8aS08]J`8U:@8e[AT]J`8YBP8]J`@YBP8a
S08YBP8]J`@YBP8aS08Q20@e[@<]J`8YBQ0]J`9oo`03001oogoo00Ioo`001goo00@007ooF]IJeP9N
m`AF]@9JePA>L`A6<@9:DP03AS5:DTYB0096<@I2408mk`8HaP9240A6<@A240@mk`I:DP8HaP8Li`<Q
208YBP9BU0I>L`ABU09>L`9:DP9>L`8e[@@<H`8@Q08icP8aS08Q20A:DPA>L`03DYA:DTYB00A>L`9:
DP9BU09>L`9BU09>L`ABU09oo`03001oogoo00]oo`03001oogoo00=oo`9g_@9_N`9[FP9W>@9F]@AS
609JeP03DYA[FV]J009_N`Ag_@9kgPX]J`8aS08DY@8Q208aS08mk`8Q208YBP/]J`8YBP8]J`8YBPP]
J`8YBP8aS08YBPX]J`8U:@8e[@d]J`8YBPX]J`9oo`03001oogoo00Ioo`001goo00@007ooF]IJeP9N
m`AF]@9JePA>L`A6<@9:DP03AS5:DTYB0096<@I2408mk`8HaP9240A6<@A240@mk`I:DP8HaP8Li`<Q
208YBP9BU0I>L`ABU09>L`9:DP9>L`8e[@@<H`8@Q08icP8aS08Q20A:DPA>L`03DYA:DTYB00A>L`9:
DP9BU09>L`9BU09>L`ABU09oo`03001oogoo00]oo`03001oogoo00=oo`9g_@9_N`9[FP9W>@9F]@AS
609JeP03DYA[FV]J009_N`Ag_@9kgPX]J`8aS08DY@8Q208aS08mk`8Q208YBP/]J`8YBP8]J`8YBPP]
J`8YBP8aS08YBPX]J`8U:@8e[@d]J`8YBPX]J`9oo`03001oogoo00Ioo`001goo00<007ooF]H01E[F
0UJe15:D0Tic1TYB1DHa148@13g_0QS60T8@0Sg_0THa248@0Sg_0THa0SF]1QS600<YBTYBBU800UJe
0U:D0Tic15:D0Tic0TYB0Tic0THa0T8@0PQ20PaS0QBU0RU:0SF]0RDY14YB1dic0TYB1Tic25:D0Tic
0Woo00<007ooOol02goo00@007ooOomoo`9kgP9g_@A_N`9S60ANm`9_N`9JeP03E[ES66<H00AcW09g
_@9kgP`]J`92408e[@@]J`8e[@8aS1T]J`@YBPP]J`8U:@8YBP8]J`8YBP8aS08mk`03>LhaS36<008Y
BQ0]J`9oo`03001oogoo00Ioo`001goo00<007ooF]H01E[F0UJe15:D0Tic1TYB1DHa148@13g_0QS6
0T8@0Sg_0THa248@0Sg_0THa0SF]1QS600<YBTYBBU800UJe0U:D0Tic15:D0Tic0TYB0Tic0THa0T8@
0PQ20PaS0QBU0RU:0SF]0RDY14YB1dic0TYB1Tic25:D0Tic0Woo00<007ooOol02goo00@007ooOomo
o`9kgP9g_@A_N`9S60ANm`9_N`9JeP03E[ES66<H00AcW09g_@9kgP`]J`92408e[@@]J`8e[@8aS1T]
J`@YBPP]J`8U:@8YBP8]J`8YBP8aS08mk`03>LhaS36<008YBQ0]J`9oo`03001oogoo00Ioo`001goo
00@007ooG_MNm`9F]@9Nm`9JeP9F]@9BU09>L`96<@A:DP=6<@924096<@9240@mk`8Li`8mk`96<@8i
cP9240Y6<@8Q208@Q08HaP8Q20=>L`9BU09>L`9F]@A>L`A:DP96<@8mk`9240@<H`8DY@8aS08e[@8Q
209>L`9:DPU>L`9BU0A>L`YBU09oo`03001oogoo00]oo`03001oog_N00=kgP9g_@9_N`9[FP9BU0AJ
eP9F]@=BU09S60AcW09g_@9kgP@]J`8YBP@]J`8Q208YBP8e[@8mk`8]J`@U:A4]J`8YBPP]J`8aS08Y
BPH]J`8mk`8e[@8]J`8e[@8Q208YBP039BTYBRU:018]J`9oo`03001oogoo00Ioo`001goo00@007oo
G_MNm`9F]@9Nm`9JeP9F]@9BU09>L`96<@A:DP=6<@924096<@9240@mk`8Li`8mk`96<@8icP9240Y6
<@8Q208@Q08HaP8Q20=>L`9BU09>L`9F]@A>L`A:DP96<@8mk`9240@<H`8DY@8aS08e[@8Q209>L`9:
DPU>L`9BU0A>L`YBU09oo`03001oogoo00]oo`03001oog_N00=kgP9g_@9_N`9[FP9BU0AJeP9F]@=B
U09S60AcW09g_@9kgP@]J`8YBP@]J`8Q208YBP8e[@8mk`8]J`@U:A4]J`8YBPP]J`8aS08YBPH]J`8m
k`8e[@8]J`8e[@8Q208YBP039BTYBRU:018]J`9oo`03001oogoo00Ioo`001goo00@007ooF]IJeP9N
m`AJeP9BU0Q>L`9:DP03AS5:DTYB00I240@mk`8Li`8mk`A240@mk`9240I6<@8DY@8HaP8Li`8e[@=>
L`ABU09>L`ABU0A:DP96<@A2408@Q08<H`8U:@8aS08e[@8Q20A>L`9:DP9>L`03BU9>Ldic00A>L`9B
U09>L`YBU09oo`03001oogoo00]oo`03001oog_N00=kgP9g_@9_N`9[FP9JeP9BU09JeP9S609F]@03
CW=Nmekg00AcW09g_@9kgPX]J`8e[@8U:@8Q208YBP8aS08e[@/]J`8YBP8]J`8YBPX]J`@YBP8aS08]
J`8U:@8@Q08Q20@]J`8YBP@]J`038@P]Jbe[008aS0@]J`@YBPP]J`9oo`03001oogoo00Ioo`001goo
00@007ooF]IJeP9Nm`AJeP9BU0Q>L`9:DP03AS5:DTYB00I240@mk`8Li`8mk`A240@mk`9240I6<@8D
Y@8HaP8Li`8e[@=>L`ABU09>L`ABU0A:DP96<@A2408@Q08<H`8U:@8aS08e[@8Q20A>L`9:DP9>L`03
BU9>Ldic00A>L`9BU09>L`YBU09oo`03001oogoo00]oo`03001oog_N00=kgP9g_@9_N`9[FP9JeP9B
U09JeP9S609F]@03CW=Nmekg00AcW09g_@9kgPX]J`8e[@8U:@8Q208YBP8aS08e[@/]J`8YBP8]J`8Y
BPX]J`@YBP8aS08]J`8U:@8@Q08Q20@]J`8YBP@]J`038@P]Jbe[008aS0@]J`@YBPP]J`9oo`03001o
ogoo00Ioo`001goo00@007ooF]IJeP9S609JePAF]@9BU09>L`9:DP9>L`9:DP03AS5:DTYB00A6<@92
408mk`92408Q208mk`A6<@8mk`92408e[@924096<@92408@Q08DY@8Li`9BU0e>L`9BU096<@8U:@8D
Y@8@Q0@<H`8mk`8]J`8icP8Q209>L`M:DPI>L`9BU0A>L`IBU09>L`9oo`03001oogoo00]oo`03001o
og_N00=kgP9g_@9_N`9[FP9S609BU09JeP9Nm`9S6003F]INmekg009cW0Ag_@9kgPX]J`8YBPH]J`8U
:@8aS08YBQd]J`@YBP8aS08e[@@]J`8YBP8U:@8Q208U:@03=JdaS36<008YBQ0]J`9oo`03001oogoo
00Ioo`001goo00@007ooF]IJeP9S609JePAF]@9BU09>L`9:DP9>L`9:DP03AS5:DTYB00A6<@92408m
k`92408Q208mk`A6<@8mk`92408e[@924096<@92408@Q08DY@8Li`9BU0e>L`9BU096<@8U:@8DY@8@
Q0@<H`8mk`8]J`8icP8Q209>L`M:DPI>L`9BU0A>L`IBU09>L`9oo`03001oogoo00]oo`03001oog_N
00=kgP9g_@9_N`9[FP9S609BU09JeP9Nm`9S6003F]INmekg009cW0Ag_@9kgPX]J`8YBPH]J`8U:@8a
S08YBQd]J`@YBP8aS08e[@@]J`8YBP8U:@8Q208U:@03=JdaS36<008YBQ0]J`9oo`03001oogoo00Io
o`001goo00<007ooG_L00ekg15[F0UJe0U:D0Tic14YB0Tic00=:DTHaAS4014Ha148@0Sg_0R481T8@
0THa148@0Sg_0T8@0THa11240QBU0dic0U[F0U:D24ic0RU:0QBU11241PaS0SF]0S6<0Sg_0QcW24YB
1Dic0TYB0Tic0U:D0Tic15:D0Tic0U:D0Woo00<007ooOol02goo00@007ooNmikgPAg_@9cW09_N`IN
m`9S609F]@03BU9Nmekg009cW0Ig_@8YBPH]J`8YBP8aS08]J`8U:@8YBP8e[@8YBP8]J`8YBQ<]J`8Y
BPP]J`@aS08]J`8aS0@]J`@e[@<aS08YBQ8]J`9oo`03001oogoo00Ioo`001goo00@007ooF]IJePAN
m`AJeP9BU09:DP9>L`9:DP9>L`03BU96<DHa00A6<@A2408mk`8Li`A2408icP96<@I24096<@92408<
H`8@Q08HaP9>L`03BU9>Ldic009>L`9F]@9>L`9:DP8Li`8HaP8DY@8@Q08<H`88@P@<H`92408aS08m
k`8Li`]:DP9>L`9:DPI>L`9BU0I>L`9oo`03001oogoo00]oo`04001oog_NNmh4Mkd2Li`2JeX2HaP2
F]H4G_L2E[D3F]H2Kg/2Li`4Mkd:;F/29BT2<H`2>Lh2;F/28@P2:DXE;F/2:DX:;F/2<H`28@P27>L2
:DX4;F/2:DX4;F/00c6<9BTU:@0B;F/2Ool00`00Oomoo`06Ool000Moo`04001ooe[FF]H4G_L4F]H2
DY@2BU82CW<2BU82CW<00dYBAS56<@04AS44@Q02?Nl27>L4@Q02>Lh2AS46@Q02AS42@Q0236<248@2
6<H2CW<00dYBCW=>L`02CW<2E[D2CW<2BU827>L26<H25:D248@236<2248436<2@Q02<H`2?Nl27>L;
BU82CW<2BU86CW<2DY@6CW<2Ool00`00Oomoo`0;Ool01000OomkgW_N17Nm0W>L0V]J0V<H0U[F15kg
0UJe0e[F0Vmk0W>L17Nm2Re[0RDY0S6<0SW>0Re[0R480RU:5Be[0RU:2Re[0S6<0R480QcW0RU:12e[
0RU:12e[00<aS2DY9BT04Re[0Woo00<007ooOol01Woo0007Ool00`00OomNm`03G_L4F]H4E[D2CW<2
BU82CW<5BU82AS44@Q04?Nl27>L2?Nl4@Q02=Jd6@Q02AS42@Q0436<25:D3BU86CW<2DY@28@P46<H2
5:D:36<29BT2=Jd2?Nl27>L4BU82AS42BU800dicBU9:DP02BU82CW<2BU8<CW<2Ool00`00Oomoo`0;
Ool00`00Oomg_@05Mkd2Li`2JeX2F]H2CW<2E[D2F]H2DY@00e[FG_MNm`02Kg/4Li`2Mkd:;F/2?Nl2
<H`2;F/2=Jd2?Nl2=Jd2:DX6;F/00bU:;F/]J`04;F/2:DX@;F/25:D29BT2=Jd2;F/2:DX28@P4>Lh2
6<H00bU:<H`aS00B;F/2Ool00`00Oomoo`06Ool000Moo`03001ooekg00=Nm`AJePAF]@9>L`9:DP9>
L`E:DP96<@A240@mk`8Li`8mk`A2408e[@I24096<@9240@<H`8DY@=:DPI>L`9BU08Q20@HaP8DY@X<
H`8U:@8e[@8mk`8Li`A:DP96<@9:DP03CW=:DTYB009:DP9>L`9:DPa>L`9oo`03001oogoo00]oo`03
001oogNm00Eg_@9cW09[FP9JeP9>L`9F]@9JeP9BU003F]INmekg009_N`AcW09g_@X]J`8mk`8aS08]
J`8e[@8mk`8e[@8YBPH]J`03:DX]Jbe[00@]J`8YBQ0]J`8DY@8U:@8e[@8]J`8YBP8Q20@icP8HaP03
:DXaS36<018]J`9oo`03001oogoo00Ioo`001goo00@007ooF]IJePANm`9JePAF]@9>L`9:DPA6<@03
BU96<DHa00924096<@9240@mk`8HaP8mk`I2408e[@8mk`9240A6<@88@P8<H`8@Q0E>L`9:DP9>L`8a
S08Li`@HaP8DY@@@Q0H<H`8DY@A2408Li`96<@A:DPE6<@I:DP9>L`A:DP9BU0A>L`9oo`03001oogoo
00]oo`03001oogNm00=g_@9cW09_N`9[FP9W>@9cW0A_N`9S6003Kg][FV]J009_N`AcW09g_@X]J`8U
:@8YBP@]J`8Q208YBQL]J`8YBP@]J`8Li`8YBP8e[@8aS0@]J`8U:@8Li`8YBP@aS1D]J`9oo`03001o
ogoo00Ioo`001goo00@007ooF]IJePANm`9JePAF]@9>L`9:DPA6<@03BU96<DHa00924096<@9240@m
k`8HaP8mk`I2408e[@8mk`9240A6<@88@P8<H`8@Q0E>L`9:DP9>L`8aS08Li`@HaP8DY@@@Q0H<H`8D
Y@A2408Li`96<@A:DPE6<@I:DP9>L`A:DP9BU0A>L`9oo`03001oogoo00]oo`03001oogNm00=g_@9c
W09_N`9[FP9W>@9cW0A_N`9S6003Kg][FV]J009_N`AcW09g_@X]J`8U:@8YBP@]J`8Q208YBQL]J`8Y
BP@]J`8Li`8YBP8e[@8aS0@]J`8U:@8Li`8YBP@aS1D]J`9oo`03001oogoo00Ioo`001goo00@007oo
G_MNm`IJeP9F]@ABU09>L`9:DP96<@=:DPQ2408icP8Li`a2408icPA6<@8DY@@@Q08]J`=BU0A:DPHL
i`8HaPH@Q08HaP8@Q088@P8<H`@mk`8HaPQ6<@03BU96<DHa00Q:DPY>L`9oo`03001oogoo00]oo`03
001oog>L00EcW09_N`9[FPIW>@9[FP9Nm`=W>@9_N`IcW08aS0@]J`@YBP8aS08icP8aS08YBP8]J`8e
[@8icPL]J`@YBQ0]J`8aS08]J`8e[@8icP8Li`8Q20@aS0@]J`8YBP03;F/icSW>018]J`9oo`03001o
ogoo00Ioo`001goo00@007ooG_MNm`IJeP9F]@ABU09>L`9:DP96<@=:DPQ2408icP8Li`a2408icPA6
<@8DY@@@Q08]J`=BU0A:DPHLi`8HaPH@Q08HaP8@Q088@P8<H`@mk`8HaPQ6<@03BU96<DHa00Q:DPY>
L`9oo`03001oogoo00]oo`03001oog>L00EcW09_N`9[FPIW>@9[FP9Nm`=W>@9_N`IcW08aS0@]J`@Y
BP8aS08icP8aS08YBP8]J`8e[@8icPL]J`@YBQ0]J`8aS08]J`8e[@8icP8Li`8Q20@aS0@]J`8YBP03
;F/icSW>018]J`9oo`03001oogoo00Ioo`001goo00@007ooG_MNm`IJePAF]@9BU09>L`E:DP96<@I2
408mk`8icP8Q20Hmk`Q2409:DP96<@8HaP8<H`8@Q08HaP03@Q1>Ldic009BU08]J`@Li`@HaP8U:@8e
[@8mk`92408mk`8DY@8<H`8]J`8mk`8Li`9:DP96<@U:DP9>L`A:DPY>L`9oo`03001oogoo00]oo`03
001oog>L00=cW09_N`9[FP9W>@9Nm`9S60IW>@=S60A_N`AcW09:DP96<@92408icP8]J`8aS08YBP8U
:@8aS092408aS0@YBP@U:AD]J`8e[@8]J`8DY@8U:@8e[@`]J`036<HQ2248018]J`9oo`03001oogoo
00Ioo`001goo00@007ooG_MNm`IJePAF]@9BU09>L`E:DP96<@I2408mk`8icP8Q20Hmk`Q2409:DP96
<@8HaP8<H`8@Q08HaP03@Q1>Ldic009BU08]J`@Li`@HaP8U:@8e[@8mk`92408mk`8DY@8<H`8]J`8m
k`8Li`9:DP96<@U:DP9>L`A:DPY>L`9oo`03001oogoo00]oo`03001oog>L00=cW09_N`9[FP9W>@9N
m`9S60IW>@=S60A_N`AcW09:DP96<@92408icP8]J`8aS08YBP8U:@8aS092408aS0@YBP@U:AD]J`8e
[@8]J`8DY@8U:@8e[@`]J`036<HQ2248018]J`9oo`03001oogoo00Ioo`001goo00@007ooG_MNm`AJ
ePAF]@9BU09>L`U:DPI240@mk`8Li`@mk`8icP8e[@I240A6<@8Q208<H`8@Q08DY@037>Le[CF]009:
DP8Li`@HaP8Q20I2408mk`8e[@92408U:@88@P8icP8mk`8Li`A6<@A:DP03AS5>Ldic00A:DPQ>L`9B
U0A>L`9oo`03001oogoo00]oo`03001oobe[00D]J`8mk`8YBP8]J`8YBP8aS0@YBP03<H`YBRU:008Y
BP`]J`8YBP8]J`8YBP8]J`8YBP8]J`8aS08YBQ/]J`8YBP8Q208U:@8e[@8aS0@e[@8icP8]J`8HaPD]
J`8icP@]J`8YBPH]J`8YBP8]J`8YBP9oo`03001oogoo00Ioo`001goo00@007ooG_MNm`AJePAF]@9B
U09>L`U:DPI240@mk`8Li`@mk`8icP8e[@I240A6<@8Q208<H`8@Q08DY@037>Le[CF]009:DP8Li`@H
aP8Q20I2408mk`8e[@92408U:@88@P8icP8mk`8Li`A6<@A:DP03AS5>Ldic00A:DPQ>L`9BU0A>L`9o
o`03001oogoo00]oo`03001oobe[00D]J`8mk`8YBP8]J`8YBP8aS0@YBP03<H`YBRU:008YBP`]J`8Y
BP8]J`8YBP8]J`8YBP8]J`8aS08YBQ/]J`8YBP8Q208U:@8e[@8aS0@e[@8icP8]J`8HaPD]J`8icP@]
J`8YBPH]J`8YBP8]J`8YBP9oo`03001oogoo00Ioo`001goo00<007ooF]H00e[F1UJe15:D0Tic0TYB
0Tic00=:DTHaAS40248@0Sg_0R480Sg_1T8@0S6<0T8@0THa0TYB0THa0RU:11240QcW00<e[DHaAS40
0Tic11S60R480Tic0THa248@0Re[0QcW0P@Q0SW>0Sg_0QcW14Ha0TYB0THa00=:DTHaAS400TYB0Tic
0TYB14ic0U:D1Tic0Woo00<007ooOol02goo00<007oo;F/01Be[0Sg_0RU:0RDY0T8@0RDY0RU:0QS6
00<mkbU::DX00RU:12e[0RU:2Re[0S6<0RU:12e[0RU:7be[0S6<0SF]0SW>0QcW12480RU:0QcW0Re[
0S6<0SF]0be[0RU:42e[0Woo00<007ooOol01Woo0007Ool00`00OomJeP03F]H6E[D4DY@2CW<2BU82
CW<00dYBAS56<@08@Q02?Nl28@P2?Nl6@Q02<H`2@Q02AS42BU82AS42:DX448@27>L00cF]AS56<@02
CW<46<H28@P2CW<2AS48@Q02;F/27>L21242>Lh2?Nl27>L4AS42BU82AS400dYBAS56<@02BU82CW<2
BU84CW<2DY@6CW<2Ool00`00Oomoo`0;Ool00`00Ool]J`05;F/2?Nl2:DX29BT2@Q029BT2:DX26<H0
0cg_:DXYBP02:DX4;F/2:DX:;F/2<H`2:DX4;F/2:DXO;F/2<H`2=Jd2>Lh27>L48@P2:DX27>L2;F/2
<H`2=Jd3;F/2:DX@;F/2Ool00`00Oomoo`06Ool000Moo`03001ooe[F00MJePIF]@9BU0E:DP96<@I2
408mk`8icP8Li`I2408mk`92408aS08mk`A6<@8]J`8YBP8mk`924003BU96<DHa0096<@8HaP8Li`92
409:DP8mk`A240@mk`8icP@<H`8]J`8e[@8Li`Q6<@=:DP9>L`Q:DPQ>L`9oo`03001oogoo00]oo`03
001oobe[00D]J`8mk`8YBP8HaP9:DP@YBP8]J`03:DX]Jbe[00H]J`8YBP`]J`PYBQ4]J`8YBP8]J`8Y
BPP]J`8YBP8Q208YBP@]J`8aS08YBP8aS08]J`8YBP8U:AD]J`9oo`03001oogoo00Ioo`001goo00<0
07ooF]H01e[F1UJe0U:D1DYB0THa1T8@0Sg_0SW>0QcW1T8@0Sg_0T8@0S6<0Sg_14Ha0Re[0RU:0Sg_
0T8@00=:DTHaAS400THa0QS60QcW0T8@0TYB0Sg_148@13g_0SW>10aS0Re[0SF]0QcW24Ha0dYB0Tic
24YB24ic0Woo00<007ooOol02goo00<007oo;F/01Be[0Sg_0RU:0QS60TYB12U:0Re[00<YBRe[;F/0
1Re[0RU:32e[22U:4Be[0RU:0Re[0RU:22e[0RU:0R480RU:12e[0S6<0RU:0S6<0Re[0RU:0RDY5Be[
0Woo00<007ooOol01Woo0007Ool00`00OomF]@03E[D2F]H6E[D4DY@2CW<3BU84AS44@Q02?Nl2>Lh2
8@P2@Q02>Lh6@Q04?Nl2@Q02>Lh26<H248@25:D2>Lh00dHaCW=>L`02AS426<H28@P2BU82AS42@Q02
?Nl2=Jd2?Nl2>Lh248@436<2=Jd2>Lh27>L2AS42@Q04AS49BU8<CW<2Ool00`00Oomoo`0;Ool01000
OolYBRU:12e[0Sg_0RU:0QS60TYB0QBU0SW>0RU:00<mkbe[;F/01Re[0RU:22e[0RU:0Re[136<1RU:
7Be[0RU:12e[0SF]0SW>0Re[0RU:12e[0R480cF]0R480S6<1Re[0RU:0Re[12U:0Re[0Woo00<007oo
Ool01Woo0007Ool00`00OomF]@03E[D2F]H6E[D4DY@2CW<3BU84AS44@Q02?Nl2>Lh28@P2@Q02>Lh6
@Q04?Nl2@Q02>Lh26<H248@25:D2>Lh00dHaCW=>L`02AS426<H28@P2BU82AS42@Q02?Nl2=Jd2?Nl2
>Lh248@436<2=Jd2>Lh27>L2AS42@Q04AS49BU8<CW<2Ool00`00Oomoo`0;Ool01000OolYBRU:12e[
0Sg_0RU:0QS60TYB0QBU0SW>0RU:00<mkbe[;F/01Re[0RU:22e[0RU:0Re[136<1RU:7Be[0RU:12e[
0SF]0SW>0Re[0RU:12e[0R480cF]0R480S6<1Re[0RU:0Re[12U:0Re[0Woo00<007ooOol01Woo0007
Ool01000OomF]EJe1U[F0UJe0U[F15:D0Tic0THa00=:DTHaAS401T8@0Sg_0SW>0R4813g_0SF]1Sg_
0T8@0R480QBU0Q240PaS112400=244HaAS400THa0QS60QcW0TYB0THa148@0SW>0RU:0PaS0PQ20PaS
0QS60SW>0T8@0QcW0THa0T8@14Ha00=:DTHaAS402TYB24ic0Woo00<007ooOol02goo00@007oo:DXY
BP@]J`8mk`8YBP8Li`92408DY@@U:@03AS4]Jbe[008YBP@]J`8YBP8]J`8YBP@]J`8YBP8]J`8YBP8]
J`8aS08YBRD]J`8YBP8U:@H]J`8U:@8e[@D]J`8YBQ0]J`9oo`03001oogoo00Ioo`001goo00@007oo
E[EF]@IJeP9F]@9JePABU09>L`96<@03BU96<DHa00I2408mk`8icP8Q20@mk`8e[@Hmk`92408Q208D
Y@8@Q08<H`@@Q003@Q16<DHa0096<@8HaP8Li`9:DP96<@A2408icP8YBP8<H`88@P8<H`8HaP8icP92
408Li`96<@9240A6<@03BU96<DHa00Y:DPQ>L`9oo`03001oogoo00]oo`04001oobU::DX4;F/2?Nl2
:DX27>L2@Q025:D49BT00dHa;F/]J`02:DX4;F/2:DX2;F/2:DX4;F/2:DX2;F/2:DX2;F/2<H`2:DXU
;F/2:DX29BT6;F/29BT2=Jd5;F/2:DX@;F/2Ool00`00Oomoo`06Ool000Moo`03001ooeJe00=F]@QJ
ePAF]@9BU0=:DPA6<@A2408mk`8icP8Q20A2408mk`8icP8e[@8mk`8Q20H@Q0@<H`8DY@03=Je2448@
0096<@@HaP8Q208mk`8e[@8U:@8@Q08<H`88@P@<H`8e[@@mk`8Q2096<@924096<@=:DP96<@A:DP9>
L`I:DP9BU0A>L`9oo`03001oogoo00]oo`04001oobU::DX4;F/2>Lh29BT2>Lh2=Jd248@4;F/00bDY
<H`aS002:DX4;F/2:DX<;F/2<H`2;F/29BT2:DXQ;F/4<H`2;F/2:DX4;F/2:DX2<H`2;F/2>Lh00cF]
;F/]J`0B;F/2Ool00`00Oomoo`06Ool000Moo`03001ooeJe00=F]@QJePAF]@9BU0=:DPA6<@A2408m
k`8icP8Q20A2408mk`8icP8e[@8mk`8Q20H@Q0@<H`8DY@03=Je2448@0096<@@HaP8Q208mk`8e[@8U
:@8@Q08<H`88@P@<H`8e[@@mk`8Q2096<@924096<@=:DP96<@A:DP9>L`I:DP9BU0A>L`9oo`03001o
ogoo00]oo`04001oobU::DX4;F/2>Lh29BT2>Lh2=Jd248@4;F/00bDY<H`aS002:DX4;F/2:DX<;F/2
<H`2;F/29BT2:DXQ;F/4<H`2;F/2:DX4;F/2:DX2<H`2;F/2>Lh00cF];F/]J`0B;F/2Ool00`00Oomo
o`06Ool000Moo`03001ooeJe00EF]@AJePIBU09>L`E6<@92408mk`9240@mk`8Q20Pmk`8icP8]J`@8
@P@@Q0@<H`8@Q003;F]6<DHa009240HHaP@DY@8@Q0H<H`88@P8@Q09240@mk`8Li`A240A6<@m:DP9>
L`9:DP9>L`9oo`03001oogoo00]oo`04001oobe[;F/2:DX2;F/2>Lh26<H2;F/2>Lh27>L2;F/2<H`0
0cW>:DXYBP02:DX4;F/2:DX<;F/4:DX4;F/29BT9;F/2:DX6;F/2:DX:;F/4:DX2<H`2:DX29BT26<H4
;F/2<H`2;F/28@P00bDY;F/]J`02;F/2:DX2;F/2:DX8;F/2:DX2Ool00`00Oomoo`06Ool000Moo`03
001ooeJe00EF]@AJePIBU09>L`E6<@92408mk`9240@mk`8Q20Pmk`8icP8]J`@8@P@@Q0@<H`8@Q003
;F]6<DHa009240HHaP@DY@8@Q0H<H`88@P8@Q09240@mk`8Li`A240A6<@m:DP9>L`9:DP9>L`9oo`03
001oogoo00]oo`04001oobe[;F/2:DX2;F/2>Lh26<H2;F/2>Lh27>L2;F/2<H`00cW>:DXYBP02:DX4
;F/2:DX<;F/4:DX4;F/29BT9;F/2:DX6;F/2:DX:;F/4:DX2<H`2:DX29BT26<H4;F/2<H`2;F/28@P0
0bDY;F/]J`02;F/2:DX2;F/2:DX8;F/2:DX2Ool00`00Oomoo`06Ool000Moo`03001ooeJe00EF]@9J
eP9F]@9JeP9F]@ABU09>L`03AS52448@009240Pmk`8Q2092408mk`8icP92408mk`8U:@848@8<H`8@
Q0@Q20@@Q003<Ha6<DHa0096<@8Q208DY@8HaP8DY@8@Q0P<H`88@P8]J`8e[@@mk`8Q2096<@9240A6
<@e:DP9>L`9:DPA>L`9oo`03001oogoo00]oo`04001oobe[;F/2:DX2;F/2<H`2=Jd2;F/2:DX4;F/2
<H`00bU:9BTU:@02:DX4;F/2:DX8;F/29BT2<H`29BT6;F/2>Lh2:DX7;F/2:DX@;F/2:DX4;F/27>L6
<H`2;F/2<H`2:DX2;F/2:DX00be[:DXYBP02;F/2<H`>;F/2Ool00`00Oomoo`06Ool000Moo`03001o
oeJe00EF]@9JeP9F]@9JeP9F]@ABU09>L`03AS52448@009240Pmk`8Q2092408mk`8icP92408mk`8U
:@848@8<H`8@Q0@Q20@@Q003<Ha6<DHa0096<@8Q208DY@8HaP8DY@8@Q0P<H`88@P8]J`8e[@@mk`8Q
2096<@9240A6<@e:DP9>L`9:DPA>L`9oo`03001oogoo00]oo`04001oobe[;F/2:DX2;F/2<H`2=Jd2
;F/2:DX4;F/2<H`00bU:9BTU:@02:DX4;F/2:DX8;F/29BT2<H`29BT6;F/2>Lh2:DX7;F/2:DX@;F/2
:DX4;F/27>L6<H`2;F/2<H`2:DX2;F/2:DX00be[:DXYBP02;F/2<H`>;F/2Ool00`00Oomoo`06Ool0
00Moo`04001ooeJeE[D2DY@2F]H6E[D4DY@2CW<2BU85AS44@Q02?Nl2>Lh28@P2@Q02?Nl2=Jd2>Lh2
?Nl248@224827>L2?Nl2@Q02?Nl2<H`236<00cg_@Q124002@Q02>Lh25:D26<H25:D248@4248436<2
6<H2@Q02;F/2<H`2>Lh29BT4@Q09AS42BU82AS44BU88CW<2Ool00`00Oomoo`0;Ool00`00Ool]J`07
;F/6<H`2;F/29BT2<H`00be[9BTU:@04;F/4:DX8;F/2:DX2<H`2:DX2;F/2:DX2<H`2:DXI;F/2:DX2
;F/2:DX4<H`2;F/2>Lh2<H`4;F/2:DX2;F/3:DX2;F/2:DX4;F/2:DX:;F/2Ool00`00Oomoo`06Ool0
00Moo`04001ooeJeE[D2DY@2F]H6E[D4DY@2CW<2BU85AS44@Q02?Nl2>Lh28@P2@Q02?Nl2=Jd2>Lh2
?Nl248@224827>L2?Nl2@Q02?Nl2<H`236<00cg_@Q124002@Q02>Lh25:D26<H25:D248@4248436<2
6<H2@Q02;F/2<H`2>Lh29BT4@Q09AS42BU82AS44BU88CW<2Ool00`00Oomoo`0;Ool00`00Ool]J`07
;F/6<H`2;F/29BT2<H`00be[9BTU:@04;F/4:DX8;F/2:DX2<H`2:DX2;F/2:DX2<H`2:DXI;F/2:DX2
;F/2:DX4<H`2;F/2>Lh2<H`4;F/2:DX2;F/3:DX2;F/2:DX4;F/2:DX:;F/2Ool00`00Oomoo`06Ool0
00Moo`04001ooeJeE[D2F]H2DY@4E[D2F]H2E[D2DY@2CW<3BU86@Q04?Nl2=Jd28@P2@Q04>Lh2<H`2
>Lh224825:D4@Q02>Lh2=Jd28@P236<00cF]@Q124002?Nl2AS428@P25:D248@4248236<248@25:D2
?Nl2=Jd236<2?Nl2<H`2:DX2@Q02AS44@Q000dYBAS56<@04BU82AS46BU86CW<2Ool00`00Oomoo`0;
Ool00`00Ool]J`03;F/2:DX2;F/4<H`2=Jd248@2?Nl29BT00d8@9BTU:@06;F/2:DX:;F/28@P2<H`2
;F/2=Jd2:DX2;F/2:DX?;F/2:DX2;F/2:DX2;F/4:DX2;F/4<H`2:DX29BT6;F/2<H`2;F/2<H`00cW>
<H`aS002<H`4;F/2:DX:;F/2Ool00`00Oomoo`06Ool000Moo`04001ooeJeE[D2F]H2DY@4E[D2F]H2
E[D2DY@2CW<3BU86@Q04?Nl2=Jd28@P2@Q04>Lh2<H`2>Lh224825:D4@Q02>Lh2=Jd28@P236<00cF]
@Q124002?Nl2AS428@P25:D248@4248236<248@25:D2?Nl2=Jd236<2?Nl2<H`2:DX2@Q02AS44@Q00
0dYBAS56<@04BU82AS46BU86CW<2Ool00`00Oomoo`0;Ool00`00Ool]J`03;F/2:DX2;F/4<H`2=Jd2
48@2?Nl29BT00d8@9BTU:@06;F/2:DX:;F/28@P2<H`2;F/2=Jd2:DX2;F/2:DX?;F/2:DX2;F/2:DX2
;F/4:DX2;F/4<H`2:DX29BT6;F/2<H`2;F/2<H`00cW><H`aS002<H`4;F/2:DX:;F/2Ool00`00Oomo
o`06Ool000Moo`03001ooeJe00=F]@9BU09F]@9BU09F]@9BU09F]@9>L`9:DP=6<@A240@mk`8icP8Q
2092408mk`@icP8]J`88@P8]J`@mk`8YBP8@Q088@P8<H`03:DY6<DHa00A24096<@8aS08@Q08<H`88
@P8@Q08]J`8aS08@Q088@P8<H`8icP8aS08]J`924096<@9240M6<@Y:DPI>L`9oo`03001oogoo00]o
o`03001oobe[00L]J`8U:@8mk`8Li`8DY@8YBP8aS003?NlU:BDY008YBP@]J`8YBPP]J`8aS08U:@8Y
BP@U:@@YBPT]J`@YBP8]J`8YBPP]J`8YBP8]J`8YBP8Q208YBP8@Q08U:@8Q208U:@8Li`80008aS08e
[@<Q208U:A0]J`9oo`03001oogoo00Ioo`001goo00<007ooE[D00eJe0U:D0UJe0U:D0UJe0U:D0UJe
0Tic0TYB0dHa148@13g_0SW>0R480T8@0Sg_13W>0Re[0PQ20Re[13g_0RU:0Q240PQ20PaS00<YBTHa
AS40148@0THa0S6<0Q240PaS0PQ20Q240Re[0S6<0Q240PQ20PaS0SW>0S6<0Re[0T8@0THa0T8@1dHa
2TYB1Tic0Woo00<007ooOol02goo00<007oo;F/01be[0RDY0Sg_0QcW0QBU0RU:0S6<00<mkbDY9BT0
0RU:12e[0RU:22e[0S6<0RDY0RU:12DY12U:2Be[12U:0Re[0RU:22e[0RU:0Re[0RU:0R480RU:0Q24
0RDY0R480RDY0QcW0P000S6<0SF]0b480RDY42e[0Woo00<007ooOol01Woo0007Ool00`00OomF]@05
E[D2DY@2E[D8DY@2CW<00dYBAS56<@04@Q02?Nl4>Lh29BT2@Q04?Nl4>Lh224826<H248@:36<00bDY
@Q124006@Q02AS42?Nl2=Jd2:DX25:D236<6248236<2>Lh4<H`4@Q05AS42BU82AS4<BU82DY@2CW<2
Ool00`00Oomoo`0;Ool00`00Ool]J`05;F/2:DX2;F/2@Q02;F/26<H2<H`27>L00d8@:DXYBP02:DX>
;F/2:DX2<H`29BT2<H`2=Jd2<H`O;F/2<H`2;F/2:DX2=Jd2<H`8;F/2:DX26<HA;F/2:DX2;F/2Ool0
0`00Oomoo`06Ool000Moo`03001ooeJe00EF]@9BU09F]@QBU09>L`03BU96<DHa00A2408mk`@icP8U
:@9240@mk`@icP88@P8HaP8@Q0X<H`039BU2448@00I24096<@8mk`8e[@8YBP8DY@8<H`H8@P8<H`8i
cP@aS0A240E6<@9:DP96<@a:DP9BU09>L`9oo`03001oogoo00]oo`03001oobe[00D]J`8YBP8]J`92
408]J`8HaP8aS08Li`03@Q0YBRU:008YBPh]J`8YBP8aS08U:@8aS08e[@8aS1l]J`8aS08]J`8YBP8e
[@8aS0P]J`8YBP8HaQ4]J`8YBP8]J`9oo`03001oogoo00Ioo`001goo00@007ooE[EF]@9BU0AF]@QB
U0A>L`03BU96<DHa00I2408mk`8icP8U:@92408icP8]J`8mk`8U:@848@88@PP<H`88@P8<H`039BTL
iacW009240@mk`8aS08HaP8<H``8@P8<H`8e[@8]J`8e[@924096<@9240M6<@a:DP9BU09:DP9oo`03
001oogoo00]oo`04001oobU::DX4;F/2:DX28@P2=Jd2:DX25:D4:DX00cg_;F/]J`02:DX>;F/2<H`4
:DX2;F/29BT28@P2=Jd2:DX7;F/4:DXT;F/2=JdE;F/2Ool00`00Oomoo`06Ool000Moo`04001ooeJe
E[D2DY@4E[D8DY@4CW<00dYBAS56<@06@Q02?Nl2>Lh29BT2@Q02>Lh2;F/2?Nl29BT21242248836<2
248236<00bDY7>LLi`02@Q04?Nl2<H`26<H236<<248236<2=Jd2;F/2=Jd2@Q02AS42@Q07AS4<BU82
DY@2BU82Ool00`00Oomoo`0;Ool01000OolYBRU:12e[0RU:0R480SF]0RU:0QBU12U:00<mkbe[;F/0
0RU:3Re[0S6<12U:0Re[0RDY0R480SF]0RU:1be[12U:92e[0SF]5Be[0Woo00<007ooOol01Woo0007
Ool00`00OomF]@03E[D2DY@2E[D2DY@2F]H4DY@4CW<00dYBAS56<@02AS42@Q02?Nl4>Lh2;F/4?Nl2
8@P424821242248236<248@4248236<25:D00b486<HHaP026<H28@P25:D236<248@236<4248236<8
2482=Jd29BT2>Lh6@Q02AS43BU82AS42BU82AS42CW<2BU82CW<2BU84CW<2Ool00`00Oomoo`0;Ool0
1000OolYBRU:1Re[0RU:0SF]12U:0R480RU:00<]Jc6<<H`00RU:12e[0RU:2Re[0SF]0RU:0Re[0RU:
0S6<3be[0RU:0Re[0RU:22e[2RU:12e[136<0Re[0SW>0SF]1Be[0RU:3Re[0Woo00<007ooOol01Woo
0007Ool00`00OomF]@03E[D2DY@2E[D2DY@2F]H4DY@4CW<00dYBAS56<@02AS42@Q02?Nl4>Lh2;F/4
?Nl28@P424821242248236<248@4248236<25:D00b486<HHaP026<H28@P25:D236<248@236<42482
36<82482=Jd29BT2>Lh6@Q02AS43BU82AS42BU82AS42CW<2BU82CW<2BU84CW<2Ool00`00Oomoo`0;
Ool01000OolYBRU:1Re[0RU:0SF]12U:0R480RU:00<]Jc6<<H`00RU:12e[0RU:2Re[0SF]0RU:0Re[
0RU:0S6<3be[0RU:0Re[0RU:22e[2RU:12e[136<0Re[0SW>0SF]1Be[0RU:3Re[0Woo00<007ooOol0
1Woo0007Ool00`00OomF]@07E[D:DY@3CW<2AS42@Q04?Nl4>Lh2<H`2@Q02?Nl27>L8248436<26<H2
:DX2<H`2>Lh00b485:DDY@0248@25:D836<<248236<2=Jd28@P:@Q000dYBAS56<@02AS42BU82AS46
BU82CW<4DY@2Ool00`00Oomoo`0;Ool00`00Ool]J`05;F/2:DX2<H`2:DX4;F/27>L2<H`00be[:DXY
BP02:DX<;F/2:DX4;F/4:DX4;F/2:DX2<H`6;F/00bU:;F/]J`04;F/2:DX<;F/2>Lh6?Nl2=Jd2:DX2
;F/29BT28@P49BT00be[<H`aS002<H`@;F/2Ool00`00Oomoo`06Ool000Moo`03001ooeJe00MF]@YB
U0=>L`96<@9240@mk`@icP8aS092408mk`8Li`P8@P@<H`8HaP8YBP8aS08icP038@PDYABU008@Q08D
Y@P<H``8@P8<H`8e[@8Q20Y24003BU96<DHa0096<@9:DP96<@I:DP9>L`ABU09oo`03001oogoo00]o
o`03001oobe[00D]J`8YBP8aS08YBP@]J`8Li`8aS003;F/YBRU:008YBP`]J`8YBP@]J`@YBP@]J`8Y
BP8aS0H]J`03:DX]Jbe[00@]J`8YBP`]J`8icPHmk`8e[@8YBP8]J`8U:@8Q20@U:@03;F/aS36<008a
S10]J`9oo`03001oogoo00Ioo`001goo00@007ooDYABU0AF]@9BU09F]@QBU09>L`03BU96<DHa0092
40@mk`@icP8e[@8mk`8icP8Li`848@@8@P8<H`8Q208e[@8icP8e[@8]J`8DY@037>LHaQS6008DY@@@
Q0P<H`848@@8@P8@Q08Q208]J`8e[@8HaP924096<@A240U6<@9:DPY>L`9BU09oo`03001oogoo00]o
o`03001oobe[00D]J`8YBP8aS08]J`8U:@@YBP<]J`@YBP`]J`8YBP@]J`8icP@YBP8]J`8aS0P]J`03
9BT48@@Q0088@P8@Q08DY@8Li`8U:@8aS08icP8aS08U:@8Li`8HaP8e[@8icP@U:@HaS08e[@8aS003
=JdU:BDY008aS08]J`XYBP@U:@9oo`03001oogoo00Ioo`001goo00@007ooDYABU0AF]@9BU09F]@QB
U09>L`03BU96<DHa009240@mk`@icP8e[@8mk`8icP8Li`848@@8@P8<H`8Q208e[@8icP8e[@8]J`8D
Y@037>LHaQS6008DY@@@Q0P<H`848@@8@P8@Q08Q208]J`8e[@8HaP924096<@A240U6<@9:DPY>L`9B
U09oo`03001oogoo00]oo`03001oobe[00D]J`8YBP8aS08]J`8U:@@YBP<]J`@YBP`]J`8YBP@]J`8i
cP@YBP8]J`8aS0P]J`039BT48@@Q0088@P8@Q08DY@8Li`8U:@8aS08icP8aS08U:@8Li`8HaP8e[@8i
cP@U:@HaS08e[@8aS003=JdU:BDY008aS08]J`XYBP@U:@9oo`03001oogoo00Ioo`001goo00<007oo
E[D00eJe3U:D0Tic00=:DTHaAS40148@1SW>0SF]0Sg_0SF]0QcW0P000PaS0R480S6<13F]0QcW1PaS
0aS6112420aS20Q20RU:0Sg_0S6<0SW>0QBU148@0Sg_2DHa1TYB0Tic0TYB0Tic0U:D0Tic0Woo00<0
07ooOol02goo00@007oo:DXYBP@]J`8aS0H]J`8U:@8Li`8aS003;F/aS36<008]J`8aS0H]J`8YBP8]
J`8aS08YBP8e[@8@Q092408YBPH]J`8YBP@]J`03>LhYBRU:008YBPP]J`8YBP@]J`8e[@8]J`8Li`@]
J`8YBPP]J`8U:@<aS0P]J`8YBPP]J`8aS09oo`03001oogoo00Ioo`001goo00<007ooE[D01EJe15:D
0UJe0Tic0U:D0Tic0U:D00=>LdYBBU800THa148@0SW>0SF]0SW>0Sg_0SW>0QcW0R480SF]0Re[0QBU
0PQ20Q240PaS1PQ20aS60Q240QBU10aS0Q240QcW10Q20P@Q10Q20Q240SW>0S6<0QcW148@0Sg_1d8@
0THa24YB0Tic0UJe0TYB0Tic0Woo00<007ooOol02goo00<007oo;F/01Be[0RU:1Re[12480RU:00<m
kc6<<H`00Re[0QcW0S6<0RU:0Re[0RU:0Re[0R48136<0PaS0T8@12U:2Re[00<YBRe[;F/00RU:22e[
0RU:22e[0S6<0Re[0RU:0Re[0S6<0Re[1RU:0R4800<]Jc6<<H`012U:22e[0RU:12e[0Woo00<007oo
Ool01Woo0007Ool00`00OomF]@05E[D4DY@2E[D2CW<2DY@2CW<2DY@00dicBU9:DP02AS44@Q02>Lh2
=Jd2>Lh2?Nl2>Lh27>L28@P2=Jd2;F/25:D2248248@236<624836<H248@25:D436<248@27>L42482
1244248248@2>Lh2<H`27>L4@Q02?Nl7@Q02AS48BU82CW<2E[D2BU82CW<2Ool00`00Oomoo`0;Ool0
0`00Ool]J`05;F/2:DX6;F/48@P2:DX00cg_<H`aS002;F/27>L2<H`2:DX2;F/2:DX2;F/28@P4<H`2
36<2@Q04:DX:;F/00bU:;F/]J`02:DX8;F/2:DX8;F/2<H`2;F/2:DX2;F/2<H`2;F/6:DX28@P00be[
<H`aS004:DX8;F/2:DX4;F/2Ool00`00Oomoo`06Ool000Moo`03001ooe:D00eBU0M>L`9:DP96<@92
40@mk`8e[@8icP92408icP8e[@8YBP8Q208YBP8000X8@P8<H`036<HLiacW008DY@8Li`8YBP8e[@8i
cP8DY@848@`8@P8]J`8U:@I240A6<@03@Q16<DHa00Q:DPA>L`ABU09>L`9oo`03001oogoo00]oo`04
001oobe[;F/2:DX6;F/2:DX2;F/28@P29BT2:DX3;F/2:DX2>Lh2;F/2=Jd2:DX6;F/2:DX2<H`26<H2
@Q02:DX6;F/2:DX4;F/00bU:;F/]J`02:DX<;F/2<H`<;F/2<H`8;F/2<H`00be[9BTU:@0:;F/2:DX6
;F/2Ool00`00Oomoo`06Ool000Moo`03001ooe:D00eBU0M>L`9:DP96<@9240@mk`8e[@8icP92408i
cP8e[@8YBP8Q208YBP8000X8@P8<H`036<HLiacW008DY@8Li`8YBP8e[@8icP8DY@848@`8@P8]J`8U
:@I240A6<@03@Q16<DHa00Q:DPA>L`ABU09>L`9oo`03001oogoo00]oo`04001oobe[;F/2:DX6;F/2
:DX2;F/28@P29BT2:DX3;F/2:DX2>Lh2;F/2=Jd2:DX6;F/2:DX2<H`26<H2@Q02:DX6;F/2:DX4;F/0
0bU:;F/]J`02:DX<;F/2<H`<;F/2<H`8;F/2<H`00be[9BTU:@0:;F/2:DX6;F/2Ool00`00Oomoo`06
Ool000Moo`04001ooeJeE[D<DY@4CW<5BU82AS42?Nl2@Q02>Lh2=Jd2?Nl4>Lh2=Jd27>L212425:D2
1244248236<248@27>L2:DX00bDY=Jde[@02>Lh2?Nl2>Lh2=Jd26<H236<224821242248412422482
36<28@P2;F/:@Q03AS46BU82CW<4BU82DY@2CW<2BU82Ool00`00Oomoo`0;Ool01000OolYBRU:12e[
0RU:1Re[0R480RDY1Be[0R4813W>0RDY1Re[0RU:0QBU0SF]0RDY0T8@0RU:12e[0RU:1Re[00<YBRe[
;F/04Re[0RU:1Re[0RU:1Re[0RU:0Re[0S6<00<YBS6<<H`04Re[0Woo00<007ooOol01Woo0007Ool0
1000OomF]EJe35:D14ic1DYB0THa0Sg_0T8@0SW>0SF]0Sg_13W>0SF]0QcW0P@Q0QBU0P@Q10Q20PaS
0Q240QcW0RU:00<U:CF]=Jd00SW>0Sg_0SW>0SF]0QS60PaS0PQ20P@Q0PQ210@Q0PQ20PaS0R480Re[
2T8@0dHa1TYB0Tic14YB0U:D0Tic0TYB0Woo00<007ooOol02goo00@007oo:DXYBP@]J`8YBPH]J`8Q
208U:@D]J`8Q20@icP8U:@H]J`8YBP8DY@8e[@8U:@92408YBP@]J`8YBPH]J`03:DX]Jbe[018]J`8Y
BPH]J`8YBPH]J`8YBP8]J`8aS003:DXaS36<018]J`9oo`03001oogoo00Ioo`001goo00<007ooDY@0
0e:D0Tic25:D1Tic0dYB0THa0T8@0Sg_1SW>0Sg_13F]10Q20QBU0P@Q0PQ20QcW0R4811cW0cF]13W>
0RU:0SW>0RU:0PQ20PaS0QBU0Q241P@Q10Q20R480SF]0Sg_1T8@0THa00=244YBBU8024YB1Tic0TYB
0Tic0Woo00<007ooOol02goo00<007oo;F/01Be[0RU:12e[0RU:0R481BU:0Re[0QBU0S6<0R481Re[
0RU:0Re[0RDY0Sg_0Re[0T8@0RU:2Re[1BU:4Re[12U:0S6<12e[0S6<0RU:0RDY0Re[12U:1be[0RU:
22e[0RU:0Re[0Woo00<007ooOol01Woo0007Ool00`00OomBU003DY@2CW<8DY@6CW<3BU82AS42@Q02
?Nl6>Lh2?Nl4=Jd424825:D2124224827>L28@P47>L3=Jd4>Lh2:DX2>Lh2:DX2248236<25:D248@6
124424828@P2=Jd2?Nl6@Q02AS400d8@BU9:DP08BU86CW<2BU82CW<2Ool00`00Oomoo`0;Ool00`00
Ool]J`05;F/2:DX4;F/2:DX28@P5:DX2;F/25:D2<H`28@P6;F/2:DX2;F/29BT2?Nl2;F/2@Q02:DX:
;F/5:DXB;F/4:DX2<H`4;F/2<H`2:DX29BT2;F/4:DX7;F/2:DX8;F/2:DX2;F/2Ool00`00Oomoo`06
Ool000Moo`04001ooeJeE[D:DY@2CW<2DY@4BU800dHaBU9:DP02BU84@Q02?Nl2>Lh4?Nl2=Jd2;F/2
48@22482;F/28@P2:DX236<2248236<2248236<00c6<?Nlmk`02=Jd28@P236<4248248@2=Jd4:DX6
124236<27>L2>Lh2?Nl2@Q04AS42@Q000dYBAS56<@04BU82CW<2BU8:CW<2Ool00`00Oomoo`0;Ool0
0`00Ool]J`0=;F/28@P29BT5;F/26<H2=Jd27>L4:DX29BT2<H`4;F/2?Nl2<H`2AS42:DX8;F/2:DX2
;F/00bU:;F/]J`0@;F/2<H`4;F/2:DX4;F/2:DX49BT7;F/2:DXB;F/2Ool00`00Oomoo`06Ool000Mo
o`04001ooeJeE[D:DY@2CW<2DY@4BU800dHaBU9:DP02BU84@Q02?Nl2>Lh4?Nl2=Jd2;F/248@22482
;F/28@P2:DX236<2248236<2248236<00c6<?Nlmk`02=Jd28@P236<4248248@2=Jd4:DX6124236<2
7>L2>Lh2?Nl2@Q04AS42@Q000dYBAS56<@04BU82CW<2BU8:CW<2Ool00`00Oomoo`0;Ool00`00Ool]
J`0=;F/28@P29BT5;F/26<H2=Jd27>L4:DX29BT2<H`4;F/2?Nl2<H`2AS42:DX8;F/2:DX2;F/00bU:
;F/]J`0@;F/2<H`4;F/2:DX4;F/2:DX49BT7;F/2:DXB;F/2Ool00`00Oomoo`06Ool000Moo`03001o
oe:D00=BU09>L`YBU09>L`=:DP9>L`96<@A2408mk`8icP8mk`8icP8e[@8aS08YBP8U:@8e[@8aS084
8@X8@P0348@mkcg_008mk`8U:@@8@P8<H`8Q208icP8e[@8aS08YBP8@Q0848@88@P8Q208icP@mk`92
40E6<@I:DP9>L`9:DPA>L`9:DPA>L`9oo`03001oogoo00]oo`03001oobe[00L]J`8YBP@]J`8Li`8U
:@8YBP03<H`]Jbe[008DY@8aS08HaP8YBP8Q208e[@8YBP@]J`8aS08Q209:DP8U:@H]J`8YBP@]J`03
:DX]Jbe[010]J`8YBP8]J`8YBP@]J`8YBP8]J`8e[@@]J`8YBP<]J`8aS08YBQ0]J`9oo`03001oogoo
00Ioo`001goo00<007ooDY@00e:D0Tic2U:D0Tic0dYB0Tic0THa148@0Sg_0SW>0Sg_0SW>0SF]0S6<
0RU:0RDY0SF]0S6<0P@Q2PQ200<@Q3g_?Nl00Sg_0RDY10Q20PaS0R480SW>0SF]0S6<0RU:0Q240P@Q
0PQ20R480SW>13g_0T8@1DHa1TYB0Tic0TYB14ic0TYB14ic0Woo00<007ooOol02goo00<007oo;F/0
1be[0RU:12e[0QcW0RDY0RU:00<aS2e[;F/00QBU0S6<0QS60RU:0R480SF]0RU:12e[0S6<0R480TYB
0RDY1Re[0RU:12e[00<YBRe[;F/042e[0RU:0Re[0RU:12e[0RU:0Re[0SF]12e[0RU:0be[0S6<0RU:
42e[0Woo00<007ooOol01Woo0007Ool00`00OomBU005DY@2CW<2DY@6CW<9BU84@Q02?Nl2>Lh2?Nl2
>Lh2=Jd4<H`2:DX2<H`26<H2124:24800a24>LhicP02>Lh29BT4248236<4>Lh2=Jd2<H`2;F/29BT2
7>L212427>L4?Nl6@Q03AS46BU84CW<2BU86CW<2BU82Ool00`00Oomoo`0;Ool00`00Ool]J`0;;F/2
:DX28@P29BT2;F/00bU:<H`aS0026<H4=Jd4:DX4;F/4:DX2<H`29BT2BU82:DX4;F/2:DX6;F/00bU:
;F/]J`02;F/2:DX>;F/2<H`8;F/2:DX4;F/2<H`2:DX29BT00c6<;F/]J`08;F/2:DX2;F/2:DX4;F/2
Ool00`00Oomoo`06Ool000Moo`03001ooe:D00EBU09>L`9BU0I>L`U:DPA2408mk`8icP8mk`8icP8e
[@@aS08YBP8aS08HaP848@X8@P0348@icSW>008icP8U:@@8@P8<H`@icP8e[@8aS08]J`8U:@8Li`84
8@8Li`@mk`I240=6<@I:DPA>L`9:DPI>L`9:DP9oo`03001oogoo00]oo`03001oobe[00/]J`8YBP8Q
208U:@8]J`03:DXaS36<008HaP@e[@@YBP@]J`@YBP8aS08U:@9:DP8YBP@]J`8YBPH]J`03:DX]Jbe[
008]J`8YBPh]J`8aS0P]J`8YBP@]J`8aS08YBP8U:@03<H`]Jbe[00P]J`8YBP8]J`8YBP@]J`9oo`03
001oogoo00Ioo`001goo00@007ooDYABU09>L`9BU09>L`9BU09>L`e:DP96<@9240@mk`HicPHe[@8Y
BP8000848@88@P@<H`@8@P0336<e[CF]008mk`8Q20@8@P8YBP@aS08HaPH48@88@P8U:@8HaP@icP92
408mk`A6<@=:DP9>L`A:DPQ>L`9:DP9>L`9oo`03001oogoo00]oo`04001oobe[;F/4:DX8;F/28@P2
:DX2;F/00c6<;F/]J`028@P2>Lh2<H`2:DX2>Lh2=Jd4:DX2;F/2:DX28@P2AS42:DX8;F/2:DX2;F/0
0bU:;F/]J`04;F/2:DX8;F/2:DX2;F/2<H`8;F/2:DX4;F/2:DX2;F/2:DX00bDY:DXYBP0B;F/2Ool0
0`00Oomoo`06Ool000Moo`04001ooe:DDY@2CW<2DY@2CW<2DY@2CW<=BU82AS42@Q04?Nl6>Lh6=Jd2
:DX200021242248436<424800`aS=Jde[@02?Nl28@P42482:DX4<H`26<H6124224829BT26<H4>Lh2
@Q02?Nl4AS43BU82CW<4BU88CW<2BU82CW<2Ool00`00Oomoo`0;Ool01000Ool]Jbe[12U:22e[0R48
0RU:0Re[00<aS2e[;F/00R480SW>0S6<0RU:0SW>0SF]12U:0Re[0RU:0R480THa0RU:22e[0RU:0Re[
00<YBRe[;F/012e[0RU:22e[0RU:0Re[0S6<22e[0RU:12e[0RU:0Re[0RU:00<U:BU::DX04Re[0Woo
00<007ooOol01Woo0007Ool00`00OomBU007DY@:CW<9BU84@Q04?Nl2>Lh2=Jd2<H`4=Jd2:DX20002
248236<2<H`2=Jd2:DX212400`Q2;F/]J`02>Lh29BT2248248@2>Lh2;F/224821242248612422482
<H`2>Lh2?Nl2>Lh2@Q04AS400dYBAS56<@0<BU86CW<2Ool00`00Oomoo`0;Ool01000OolYBRU:2Re[
0RU:0R480RDY0Re[00<YBRe[;F/00RDY0SF]12U:0Sg_0QcW12e[0RDY0SF]0RDY0THa0RU:32e[00<Y
BRe[;F/00RU:3Re[0RU:0Re[0SF]0RU:0Re[0RDY12e[0SF]0RU:0S6<0RDY00<aS2e[;F/00RU:42e[
0Woo00<007ooOol01Woo0007Ool00`00OomBU007DY@:CW<9BU84@Q04?Nl2>Lh2=Jd2<H`4=Jd2:DX2
0002248236<2<H`2=Jd2:DX212400`Q2;F/]J`02>Lh29BT2248248@2>Lh2;F/22482124224861242
2482<H`2>Lh2?Nl2>Lh2@Q04AS400dYBAS56<@0<BU86CW<2Ool00`00Oomoo`0;Ool01000OolYBRU:
2Re[0RU:0R480RDY0Re[00<YBRe[;F/00RDY0SF]12U:0Sg_0QcW12e[0RDY0SF]0RDY0THa0RU:32e[
00<YBRe[;F/00RU:3Re[0RU:0Re[0SF]0RU:0Re[0RDY12e[0SF]0RU:0S6<0RDY00<aS2e[;F/00RU:
42e[0Woo00<007ooOol01Woo0007Ool01000Oom>Ldic0U:D0Tic0U:D0Tic0TYB0U:D0Tic1DYB1THa
0T8@13g_13W>0SF]0RU:13F]0QcW0P@Q0R480PaS0SW>13F]0`Q213F]0RU:0PQ20Re[0RDY0PaS10@Q
0PQ210@Q0PQ20P@Q0RU:0SW>13g_0T8@1dHa0TYB0THa14YB0Tic1TYB0Tic0Woo00<007ooOol02goo
00<007oo;F/01Be[0RU:1Re[0R480RDY0be[0RU:12e[0SW>0RDY0SW>0Re[0RU:136<0SW>0RDY0THa
0RU:32e[00<YBRe[;F/052e[0RU:0S6<0RU:12e[0RU:0Re[0RU:12e[00<Q22e[;F/04Re[0Woo00<0
07ooOol01Woo0007Ool01000Oom>Ldic0U:D0Tic0U:D0Tic0TYB0U:D0Tic1DYB1THa0T8@13g_13W>
0SF]0RU:13F]0QcW0P@Q0R480PaS0SW>13F]0`Q213F]0RU:0PQ20Re[0RDY0PaS10@Q0PQ210@Q0PQ2
0P@Q0RU:0SW>13g_0T8@1dHa0TYB0THa14YB0Tic1TYB0Tic0Woo00<007ooOol02goo00<007oo;F/0
1Be[0RU:1Re[0R480RDY0be[0RU:12e[0SW>0RDY0SW>0Re[0RU:136<0SW>0RDY0THa0RU:32e[00<Y
BRe[;F/052e[0RU:0S6<0RU:12e[0RU:0Re[0RU:12e[00<Q22e[;F/04Re[0Woo00<007ooOol01Woo
0007Ool00`00OomBU003DY@2CW<2DY@2CW<2DY@9CW<2AS42@Q04AS42@Q02?Nl4>Lh2=Jd2<H`2:DX2
<H`27>L236<2;F/22482=Jd4<H`224800a24>LhicP02>Lh2:DX236<2:DX424821242248200061242
24825:D2=Jd2?Nl4@Q04AS43BU82AS44BU82CW<:BU82Ool00`00Oomoo`0;Ool00`00Ool]J`0=;F/2
8@P29BT2<H`00bDY>LhicP02;F/2:DX2>Lh29BT2=Jd2:DX8;F/2:DX2AS42:DX<;F/00bU:;F/]J`0@
;F/2:DX4;F/2<H`2;F/29BT2:DX2<H`8;F/00c6<9BTU:@02;F/2:DX>;F/2Ool00`00Oomoo`06Ool0
00Moo`03001ooe:D00=BU09>L`9BU09>L`9BU0U>L`96<@9240A6<@92408mk`@icP8e[@8aS08YBP8a
S08Li`8<H`8]J`88@P8e[@@aS088@P0348@icSW>008icP8YBP8<H`8YBP@8@P848@88@P8000H48@88
@P8DY@8e[@8mk`A240A6<@=:DP96<@A:DP9>L`Y:DP9oo`03001oogoo00]oo`03001oobe[00d]J`8Q
208U:@8aS0039BTicSW>008]J`8YBP8icP8U:@8e[@8YBPP]J`8YBP96<@8YBP`]J`03:DX]Jbe[010]
J`8YBP@]J`8aS08]J`8U:@8YBP8aS0P]J`03<H`U:BDY008]J`8YBPh]J`9oo`03001oogoo00Ioo`00
1goo00@007ooDYABU09>L`ABU0I>L`M:DPA6<@Q2408icP@e[@8]J`8aS08]J`8HaP8000@<H`@e[@8Y
BP848@038@Pe[CF]008icP8U:@8Q2088@P848@88@Ph48@8<H`8icP8e[@8icP9240M6<@9:DPA6<@9:
DP9>L`Q:DP9oo`03001oogoo00]oo`03001oobe[00L]J`8YBP@]J`@U:@8]J`036<Hmkcg_00@U:@96
<@@Q208aS0@]J`8aS08Li`8U:@8icP8YBP@]J`@YBP@]J`<YBQ8]J`8U:@@aS08U:@8aS08]J`8YBP8a
S0@YBP8icP038@P]Jbe[00h]J`8YBP8]J`9oo`03001oogoo00Ioo`001goo00@007ooDYABU09>L`AB
U0I>L`M:DPA6<@Q2408icP@e[@8]J`8aS08]J`8HaP8000@<H`@e[@8YBP848@038@Pe[CF]008icP8U
:@8Q2088@P848@88@Ph48@8<H`8icP8e[@8icP9240M6<@9:DPA6<@9:DP9>L`Q:DP9oo`03001oogoo
00]oo`03001oobe[00L]J`8YBP@]J`@U:@8]J`036<Hmkcg_00@U:@96<@@Q208aS0@]J`8aS08Li`8U
:@8icP8YBP@]J`@YBP@]J`<YBQ8]J`8U:@@aS08U:@8aS08]J`8YBP8aS0@YBP8icP038@P]Jbe[00h]
J`8YBP8]J`9oo`03001oogoo00Ioo`001goo00@007ooDYABU09>L`IBU0A>L`9:DP9>L`9:DP03CW=:
DTYB0096<@A2408mk`92408icP@e[@8aS08e[@8aS08U:@8000848@8<H`8icP8e[@8Li`8DY@<e[@8i
cP8e[@8Li`848@88@P@48@8@Q08U:@8aS08HaP@48@88@P8e[@@mk`e6<@i:DP9oo`03001oogoo00]o
o`03001oobe[00D]J`8YBPH]J`@U:@8]J`036<H]Jbe[008YBP8]J`8e[@8U:@8]J`8U:@8]J`8aS08U
:@8aS08Li`8e[@8YBPX]J`<YBPX]J`8YBP@]J`8aS08U:@8]J`8YBP@]J`8YBP8Q208]J`8aS08YBP8]
J`8YBP03;F/YBRU:00H]J`8YBPX]J`9oo`03001oogoo00Ioo`001goo00@007ooDYABU09>L`IBU0A>
L`9:DP9>L`9:DP03CW=:DTYB0096<@A2408mk`92408icP@e[@8aS08e[@8aS08U:@8000848@8<H`8i
cP8e[@8Li`8DY@<e[@8icP8e[@8Li`848@88@P@48@8@Q08U:@8aS08HaP@48@88@P8e[@@mk`e6<@i:
DP9oo`03001oogoo00]oo`03001oobe[00D]J`8YBPH]J`@U:@8]J`036<H]Jbe[008YBP8]J`8e[@8U
:@8]J`8U:@8]J`8aS08U:@8aS08Li`8e[@8YBPX]J`<YBPX]J`8YBP@]J`8aS08U:@8]J`8YBP@]J`8Y
BP8Q208]J`8aS08YBP8]J`8YBP03;F/YBRU:00H]J`8YBPX]J`9oo`03001oogoo00Ioo`001goo00@0
07ooDYABU0I>L`9BU0A>L`A:DP9>L`03BU96<DHa00A6<@9240@mk`8icP8e[@8aS08]J`@e[@8]J`80
00848@88@P8e[@8aS08Q208]J`DaS08e[@@8@P848@8<H`848@8U:@@e[@8HaP8<H`848@88@P8e[@8i
cP8mk`I24003BU96<DHa00Q6<@Y:DP9oo`03001oogoo00]oo`03001oobe[00L]J`8YBP@]J`8YBP8U
:@8aS003:DX]Jbe[008YBP@]J`8aS08U:@X]J`8HaP8]J`8YBP@]J`TYBQP]J`8YBP8]J`8icPd]J`8a
S0@]J`@YBPX]J`9oo`03001oogoo00Ioo`001goo00@007ooDYABU0I>L`9BU0A>L`A:DP9>L`03BU96
<DHa00A6<@9240@mk`8icP8e[@8aS08]J`@e[@8]J`8000848@88@P8e[@8aS08Q208]J`DaS08e[@@8
@P848@8<H`848@8U:@@e[@8HaP8<H`848@88@P8e[@8icP8mk`I24003BU96<DHa00Q6<@Y:DP9oo`03
001oogoo00]oo`03001oobe[00L]J`8YBP@]J`8YBP8U:@8aS003:DX]Jbe[008YBP@]J`8aS08U:@X]
J`8HaP8]J`8YBP@]J`TYBQP]J`8YBP8]J`8icPd]J`8aS0@]J`@YBPX]J`9oo`03001oogoo00Ioo`00
1goo00@007ooBU9:DP9>L`9:DP9BU0Q>L`9:DP96<@=:DPA6<@9240@mk`8icP8e[@8aS08]J`8YBP@a
S08Li`848@8DY@8YBP8U:@8DY@<<H`@e[@8YBP88@P848@8Li`8Q20848@8aS0@YBP848@8Li`848@8<
H`8aS08icP8YBPA240M6<@A:DP96<@Y:DP9oo`03001oogoo00]oo`04001oobU::DX4;F/4:DX4;F/6
:DX3<H`4:DX4;F/2:DX6;F/2<H`2:DX26<H29BTK;F/2:DX4;F/2<H`29BT4<H`2:DX8;F/2:DX2;F/2
9BT00cW>;F/]J`0B;F/2Ool00`00Oomoo`06Ool000Moo`04001oodYBBU82CW<2BU82DY@8CW<2BU82
AS43BU84AS42@Q04?Nl2>Lh2=Jd2<H`2;F/2:DX4<H`27>L212425:D2:DX29BT25:D336<4=Jd2:DX2
248212427>L28@P21242<H`4:DX212427>L2124236<2<H`2>Lh2:DX4@Q07AS44BU82AS4:BU82Ool0
0`00Oomoo`0;Ool01000OolYBRU:12e[12U:12e[1RU:0c6<12U:12e[0RU:1Re[0S6<0RU:0QS60RDY
6be[0RU:12e[0S6<0RDY136<0RU:22e[0RU:0Re[0RDY00<icRe[;F/04Re[0Woo00<007ooOol01Woo
0007Ool01000Oom>Ldic0TYB1Tic0U:D0TYB0Tic1DYB14Ha148@13g_0SW>13F]12e[0RU:0S6<0Q24
0R480QBU0PaS0PQ20P@Q0`Q20RDY0SW>0R480P@Q0PQ20S6<0R480P@Q136<0QS60Q240RDY0P@Q0QBU
0S6<0SF]0RU:1T8@1DHa14YB0THa0TYB0THa14YB0THa0Woo00<007ooOol02goo00<007oo;F/03be[
0RU:0S6<00<YBS6<<H`00RU:0S6<0SF]12U:0Re[0RDY0Re[136<0QcW0RDY3Re[00<YBRe[;F/052e[
0RDY12e[0RU:0Re[1RU:1Be[0S6<2Re[0RU:1Re[0Woo00<007ooOol01Woo0007Ool01000Oom>Ldic
0TYB1Tic0U:D0TYB0Tic1DYB14Ha148@13g_0SW>13F]12e[0RU:0S6<0Q240R480QBU0PaS0PQ20P@Q
0`Q20RDY0SW>0R480P@Q0PQ20S6<0R480P@Q136<0QS60Q240RDY0P@Q0QBU0S6<0SF]0RU:1T8@1DHa
14YB0THa0TYB0THa14YB0THa0Woo00<007ooOol02goo00<007oo;F/03be[0RU:0S6<00<YBS6<<H`0
0RU:0S6<0SF]12U:0Re[0RDY0Re[136<0QcW0RDY3Re[00<YBRe[;F/052e[0RDY12e[0RU:0Re[1RU:
1Be[0S6<2Re[0RU:1Re[0Woo00<007ooOol01Woo0007Ool01000Oom:DTYB14Ha0TYB0U:D0TYB0Tic
0THa1dYB1T8@13g_0SF]236<0Re[0R481P@Q0PQ20P@Q0PQ20P@Q00<8@R488@P00SF]0QS60PQ20QBU
0S6<0R480P@Q0Re[0S6<0P@Q0R480QS60P@Q0R480SF]0SW>0SF]148@0dHa0T8@0TYB0THa0TYB0THa
0TYB14Ha0TYB0THa0Woo00<007ooOol02goo00<007oo;F/00be[0RU:12e[12U:0S6<0Re[0RDY00<i
cSF]=Jd012e[0RDY0RU:0Re[0RDY0S6<1Re[12DY0Re[0RU:0Re[12U:12e[0bU:42e[136<0Re[0S6<
0Re[0SF]0RU:0RDY0S6<5be[0RU:0Re[0Woo00<007ooOol01Woo0007Ool01000Oom:DTYB14Ha0TYB
0U:D0TYB0Tic0THa1dYB1T8@13g_0SF]236<0Re[0R481P@Q0PQ20P@Q0PQ20P@Q00<8@R488@P00SF]
0QS60PQ20QBU0S6<0R480P@Q0Re[0S6<0P@Q0R480QS60P@Q0R480SF]0SW>0SF]148@0dHa0T8@0TYB
0THa0TYB0THa0TYB14Ha0TYB0THa0Woo00<007ooOol02goo00<007oo;F/00be[0RU:12e[12U:0S6<
0Re[0RDY00<icSF]=Jd012e[0RDY0RU:0Re[0RDY0S6<1Re[12DY0Re[0RU:0Re[12U:12e[0bU:42e[
136<0Re[0S6<0Re[0SF]0RU:0RDY0S6<5be[0RU:0Re[0Woo00<007ooOol01Woo0007Ool01000Oom:
DTYB0T8@14Ha1Tic1dYB0THa0T8@0THa148@0Sg_0SW>0S6<1Re[0RU:1P001P@Q1@Q20RU:0S6<0QcW
0P@Q0PQ20RDY0Q240P@Q0Re[0RU:0PQ20Re[0QcW0P00136<0SF]0S6<0Sg_0T8@3DHa14YB0THa0TYB
0THa0Woo00<007ooOol02goo00<007oo;F/02Be[0RU:12e[0RU:0R4800<mkbe[;F/012e[0S6<0RDY
0Re[0RU:0SW>0RU:1S6<12U:32e[0bU:3Re[12U:0Re[0SF]0RU:22e[12U:0Re[0S6<00<U:Be[;F/0
2Re[0RU:1Re[0Woo00<007ooOol01Woo0007Ool01000Oom:DTYB0T8@14Ha1Tic1dYB0THa0T8@0THa
148@0Sg_0SW>0S6<1Re[0RU:1P001P@Q1@Q20RU:0S6<0QcW0P@Q0PQ20RDY0Q240P@Q0Re[0RU:0PQ2
0Re[0QcW0P00136<0SF]0S6<0Sg_0T8@3DHa14YB0THa0TYB0THa0Woo00<007ooOol02goo00<007oo
;F/02Be[0RU:12e[0RU:0R4800<mkbe[;F/012e[0S6<0RDY0Re[0RU:0SW>0RU:1S6<12U:32e[0bU:
3Re[12U:0Re[0SF]0RU:22e[12U:0Re[0S6<00<U:Be[;F/02Re[0RU:1Re[0Woo00<007ooOol01Woo
0007Ool01000Oom:DTYB0THa0TYB0THa0TYB0Tic2DYB0THa1T8@13g_0SF]136<0RDY0RU:0R481000
10@Q0PaS0QS60RU:0R4800<8@S6<<H`00RU:0RDY10@Q10Q20P@Q0RU:0Q240PaS0S6<0PaS0QBU0RU:
0Re[0SW>0SF]0Sg_0T8@1dHa0T8@24Ha0TYB14Ha0Woo00<007ooOol02goo00@007oo:DXYBPP]J`@Y
BP8aS0@]J`03<H`U:BDY00H]J`8Li`8YBP8aS08U:@@YBP8]J`8e[@8YBPh]J`03:DX]Jbe[01@]J`8Y
BP8aS08YBP8aS08]J`HYBP8]J`8YBP039BTQ224800@YBPX]J`8YBP8]J`9oo`03001oogoo00Ioo`00
1goo00@007ooBU9:DP96<@9:DP96<@9:DP9>L`U:DP96<@I240@mk`8e[@@aS08U:@8YBP8Q20@000@4
8@8<H`8HaP8YBP8Q2003248aS36<008YBP8U:@@48@@8@P848@8YBP8@Q08<H`8aS08<H`8DY@8YBP8]
J`8icP8e[@8mk`9240M6<@9240Q6<@9:DPA6<@9oo`03001oogoo00]oo`04001oobU::DX8;F/4:DX2
<H`4;F/00c6<9BTU:@06;F/27>L2:DX2<H`29BT4:DX2;F/2=Jd2:DX>;F/00bU:;F/]J`0D;F/2:DX2
<H`2:DX2<H`2;F/6:DX2;F/2:DX00bDY8@PQ2004:DX:;F/2:DX2;F/2Ool00`00Oomoo`06Ool000Mo
o`03001oodYB00=:DP924096<@9:DP9>L`Q:DP=6<@Q2408mk`8icP@aS08YBP8U:@8HaP@0008<H`8U
:@8YBP@]J`8HaP03:DXaS36<008]J`8aS0848@88@PH48@8]J`848@8DY@8aS0848@@aS08]J`8e[@8a
S08mk`A24003AS52448@009240Y6<@9:DP96<@9:DP9oo`03001oogoo00]oo`03001oobe[00D]J`8Y
BPX]J`8aS003:DXmkcg_008e[@8U:@8e[@@U:@8mk`8Q208aS08]J`8aS0@YBR4]J`8U:@8]J`@YBP8]
J`8YBP@]J`8aS08U:@D]J`8aS0X]J`8YBP@]J`8YBP9oo`03001oogoo00Ioo`001goo00<007ooBU80
0dYB0T8@0THa0TYB0Tic24YB0dHa248@0Sg_0SW>136<0RU:0RDY0QS610000PaS0RDY0RU:12e[0QS6
00<YBS6<<H`00Re[0S6<0P@Q0PQ21P@Q0Re[0P@Q0QBU0S6<0P@Q136<0Re[0SF]0S6<0Sg_148@00=6
<D8@@Q000T8@2THa0TYB0THa0TYB0Woo00<007ooOol02goo00<007oo;F/01Be[0RU:2Re[0S6<00<Y
BSg_?Nl00SF]0RDY0SF]12DY0Sg_0R480S6<0Re[0S6<12U:8Be[0RDY0Re[12U:0Re[0RU:12e[0S6<
0RDY1Be[0S6<2Re[0RU:12e[0RU:0Woo00<007ooOol01Woo0007Ool00`00Oom>L`03CW<4AS42BU82
CW<2BU82AS42BU82AS47@Q02?Nl2@Q02>Lh2=Jd8;F/248@236<224827>L2<H`2=Jd2;F/2:DX5=Jd2
<H`2>Lh25:D2248248@41242;F/22482@Q02>Lh2?Nl8>Lh2:DX2?Nl9@Q02AS42BU84AS42BU84AS42
BU82Ool00`00Oomoo`0;Ool00`00Ool]J`07;F/2:DX:;F/00b48?Nlmk`02AS42:DX2?Nl27>L29BT2
7>L6;F/2:DX2<H`2:DX>;F/00bU:;F/]J`0D;F/2<H`4;F/2:DX2;F/29BT2:DX4;F/2:DX00c6<:DXY
BP02:DX@;F/2Ool00`00Oomoo`06Ool000Moo`04001oodYBBU82CW<<BU85AS44@Q08?Nl2>Lh2<H`2
=Jd2<H`4>Lh2?Nl29BT2?Nl2G_L2Kg/2F]H5AS42@Q02AS46BU82Nmh28@P248@27>L2<H`2CW<2BU82
AS44@Q04?Nl2;F/2@Q04?Nl3@Q02AS42@Q08AS42@Q04AS42Ool00`00Oomoo`0;Ool01000OolYBRU:
0Re[0RU:0Re[12U:0Re[0RU:0Re[0S6<00<U:Cg_?Nl00Sg_0R480Sg_0RU:0RDY0SF]0Re[0S6<0R48
0SF]0Sg_12U:32e[00<YBRe[;F/00Re[12U:2Re[0RU:0Re[0RDY0RU:0Re[0SF]0RU:136<12U:0Re[
1BU:0Re[0RU:32e[0Woo00<007ooOol01Woo0007Ool01000Oom:DTYB0Tic34YB1DHa148@23g_0SW>
0S6<0SF]0S6<13W>0Sg_0RDY0Sg_0Ukg0Vmk0U[F1DHa0T8@0THa1TYB0W_N0R480Q240QcW0S6<0Tic
0TYB0THa148@13g_0Re[0T8@13g_0d8@0THa0T8@24Ha0T8@14Ha0Woo00<007ooOol02goo00@007oo
:DXYBP8]J`8YBP8]J`@YBP8]J`8YBP8]J`8aS0039BTmkcg_008mk`8Q208mk`8YBP8U:@8e[@8]J`8a
S08Q208e[@8mk`@YBP`]J`03:DX]Jbe[008]J`@YBPX]J`8YBP8]J`8U:@8YBP8]J`8e[@8YBP@aS0@Y
BP8]J`DYBP8]J`8YBP`]J`9oo`03001oogoo00Ioo`001goo00<007ooBU800dYB0THa1TYB24Ha1d8@
13g_0SW>0Sg_0SF]1SW>1Sg_14YB0Tic0UJe0Tic0T8@1Cg_0T8@0Sg_0T8@0SF]136<0PaS0WNm0UJe
13g_0S6<13W>0Re[13g_1d8@0THa0T8@14Ha0TYB24Ha0Woo00<007ooOol02goo00<007oo;F/04Be[
0S6<00<]Jc6<<H`00SF]0RDY0Re[0RDY0QcW0SF]12480QcW0RDY0Sg_0R480RU:3be[12U:3Re[0RDY
0RU:0S6<0RU:0Re[0RU:0Re[0RU:1Re[00<aS2e[;F/012e[0RU:32e[0Woo00<007ooOol01Woo0007
Ool00`00Oom:DP03BU82AS46BU88AS47@Q04?Nl2>Lh2?Nl2=Jd6>Lh6?Nl4BU82CW<2E[D2CW<2@Q05
?Nl2@Q02?Nl2@Q02=Jd4<H`236<2Mkd2E[D4?Nl2<H`4>Lh2;F/4?Nl7@Q02AS42@Q04AS42BU88AS42
Ool00`00Oomoo`0;Ool00`00Ool]J`0A;F/2<H`00be[<H`aS002=Jd29BT2;F/29BT27>L2=Jd48@P2
7>L29BT2?Nl28@P2:DX?;F/4:DX>;F/29BT2:DX2<H`2:DX2;F/2:DX2;F/2:DX6;F/00c6<;F/]J`04
;F/2:DX<;F/2Ool00`00Oomoo`06Ool000Moo`04001oodYBBU82AS44BU82AS42BU88AS49@Q02?Nl4
>Lh4=Jd2<H`2;F/2<H`2>Lh2@Q02CW<?>Lh2<H`4>Lh4?Nl2<H`236<2Ool2@Q04>Lh6=Jd2<H`2>Lh2
?Nl=@Q0<AS42Ool00`00Oomoo`0;Ool01000Ool]Jbe[0RU:2Re[0RU:12e[00<YBSW>>Lh022e[0RU:
0SW>0R480RDY0Sg_0QcW0S6<0RDY0RU:2Re[0bU:32e[0RU:1Re[0S6<1Re[0RU:0Re[2RU:0c6<4Re[
0Woo00<007ooOol01Woo0007Ool01000Oom:DTYB0THa14YB0THa0TYB24Ha2D8@0Sg_13W>13F]0S6<
0Re[0S6<0SW>0T8@0Tic3cW>0S6<13W>13g_0S6<0PaS0Woo0T8@13W>1SF]0S6<0SW>0Sg_3D8@34Ha
0Woo00<007ooOol02goo00@007oo;F/]J`8YBPX]J`8YBP@]J`03:DXicSW>00P]J`8YBP8icP8Q208U
:@8mk`8Li`8aS08U:@8YBPX]J`<YBP`]J`8YBPH]J`8aS0H]J`8YBP8]J`XYBP<aS18]J`9oo`03001o
ogoo00Ioo`001goo00@007ooBU9:DPI6<@A:DPI6<@924003AS52448@00A240@mk`@icP8e[@@aS08e
[@8aS0@e[@96<@8icP@e[@8aS08icPLe[@8aS0HicP8Q2088@P96<@He[@8icP8aS08icP8e[@8mk`I2
4003AS52448@0096<@a240A6<@9oo`03001oogoo00]oo`03001oobe[00d]J`8YBP8]J`8aS0038@Pa
S36<00@]J`8YBP8Q208U:@8aS08YBP8HaP92408aS08U:@8YBPh]J`<YBQ8]J`8aS0H]J`8Q20@]J`8a
S08]J`8aS08U:@037>L]Jbe[00`]J`8YBP@]J`9oo`03001oogoo00Ioo`001goo00@007ooBU9:DPI6
<@A:DPI6<@924003AS52448@00A240@mk`@icP8e[@@aS08e[@8aS0@e[@96<@8icP@e[@8aS08icPLe
[@8aS0HicP8Q2088@P96<@He[@8icP8aS08icP8e[@8mk`I24003AS52448@0096<@a240A6<@9oo`03
001oogoo00]oo`03001oobe[00d]J`8YBP8]J`8aS0038@PaS36<00@]J`8YBP8Q208U:@8aS08YBP8H
aP92408aS08U:@8YBPh]J`<YBQ8]J`8aS0H]J`8Q20@]J`8aS08]J`8aS08U:@037>L]Jbe[00`]J`8Y
BP@]J`9oo`03001oogoo00Ioo`001goo00<007ooBU800dYB0THa0TYB24Ha148@00=6<D8@@Q00148@
13g_0SW>0Sg_0SF]0S6<1Re[136<1SF]1S6<00<e[C6<<H`01S6<0SF]0S6<0SF]0QBU0P@Q0RU:0SW>
0S6<13F]0S6<0SF]0SW>1Sg_5d8@0Woo00<007ooOol02goo00<007oo;F/00be[12U:1Re[0RU:0S6<
0be[0SF]0RDY0RU:0Re[0RU:0QcW0SF]0S6<0Q240RDY0SF]0RU:0RDY0RU:22e[0RU:0Re[00<YBRe[
;F/042e[0RU:0Re[0RDY22e[0RU:0R480RDY0S6<1Be[0S6<0Re[0RU:32e[0Woo00<007ooOol01Woo
0007Ool00`00Oom:DP03BU82AS42BU88AS44@Q000dHa@Q124004@Q04?Nl2>Lh2?Nl2=Jd2<H`6;F/4
<H`6=Jd6<H`00cF]<H`aS006<H`2=Jd2<H`2=Jd25:D21242:DX2>Lh2<H`4=Jd2<H`2=Jd2>Lh6?NlG
@Q02Ool00`00Oomoo`0;Ool00`00Ool]J`03;F/4:DX6;F/2:DX2<H`3;F/2=Jd29BT2:DX2;F/2:DX2
7>L2=Jd2<H`248@29BT2=Jd2:DX29BT2:DX8;F/2:DX2;F/00bU:;F/]J`0@;F/2:DX2;F/29BT8;F/2
:DX28@P29BT2<H`5;F/2<H`2;F/2:DX<;F/2Ool00`00Oomoo`06Ool000Moo`03001oodHa00M6<@9:
DP9240A6<@E24096<@A240Pmk`8icP8aS08]J`@YBP8aS0H]J`PaS0<]J`XaS08]J`@8@P8YBP@e[@@a
S0@e[@8icP@mk`92408mk`U24096<@924096<@9240A6<@9oo`03001oogoo00]oo`03001oobe[01@]
J`8e[@8]J`8YBP8aS0@]J`8aS08e[@9F]@8Q20@]J`8aS08YBPl]J`8YBQ@]J`@YBP@]J`8YBP@]J`8Q
208U:@<]J`@YBPh]J`9oo`03001oogoo00Ioo`001goo00<007ooAS401dHa0TYB0T8@14Ha1D8@0THa
148@23g_0SW>0S6<0Re[12U:0S6<1Re[236<0be[2S6<0Re[10Q20RU:13F]136<13F]0SW>13g_0T8@
0Sg_2D8@0THa0T8@0THa0T8@14Ha0Woo00<007ooOol02goo00<007oo;F/052e[0SF]0Re[0RU:0S6<
12e[0S6<0SF]0UJe0R4812e[0S6<0RU:3be[0RU:52e[12U:12e[0RU:12e[0R480RDY0be[12U:3Re[
0Woo00<007ooOol01Woo0007Ool01000Oom6<DHa0T8@14Ha0T8@1THa0T8@0THa0d8@0Sg_0T8@13g_
0SW>0Sg_0SW>0S6<0Re[12U:1Re[0RU:12e[12U:0be[12U:12e[0S6<0RU:10@Q0R4812U:12DY0R48
0RDY0SW>1Sg_0T8@00<mkd8@@Q00148@0Sg_0T8@0THa248@0Woo00<007ooOol02goo00<007oo;F/0
52e[0S6<12e[0RU:12e[0RU:0RDY0UJe12e[136<0RU:32e[1BU:62e[0RU:22e[136<5Be[0Woo00<0
07ooOol01Woo0007Ool01000Oom6<DHa0T8@14Ha0T8@1THa0T8@0THa0d8@0Sg_0T8@13g_0SW>0Sg_
0SW>0S6<0Re[12U:1Re[0RU:12e[12U:0be[12U:12e[0S6<0RU:10@Q0R4812U:12DY0R480RDY0SW>
1Sg_0T8@00<mkd8@@Q00148@0Sg_0T8@0THa248@0Woo00<007ooOol02goo00<007oo;F/052e[0S6<
12e[0RU:12e[0RU:0RDY0UJe12e[136<0RU:32e[1BU:62e[0RU:22e[136<5Be[0Woo00<007ooOol0
1Woo0007Ool01000Oom6<DHa148@14Ha148@14Ha1D8@0Sg_0T8@1Sg_0SF]0SW>0S6<0RDY0R480QcW
2R4812DY1BU:0S6<0Re[0SF]0S6<0SF]0S6<1RU:12480QcW11S60QcW0Re[1Sg_0d8@0Sg_0T8@0Sg_
2T8@14Ha0Woo00<007ooOol02goo00@007oo;F/]J`8YBP`]J`8YBPl]J`8YBP8Li`92408U:@@]J`8Y
BPP]J`@YBP8]J`03:DX]Jbe[008YBP8]J`8YBP8]J`8YBP8]J`8YBPP]J`8YBPX]J`8aS08YBP<]J`8Y
BPX]J`8YBPH]J`9oo`03001oogoo00Ioo`001goo00@007ooAS56<@A240A6<@A240A6<@E2408mk`92
40Hmk`8e[@8icP8aS08U:@8Q208Li`XQ20@U:@DYBP8aS08]J`8e[@8aS08e[@8aS0HYBP@Q208Li`@H
aP8Li`8]J`Hmk`=2408mk`92408mk`Y240A6<@9oo`03001oogoo00]oo`04001oobe[;F/2:DX<;F/2
:DX?;F/2:DX27>L2@Q029BT4;F/2:DX8;F/4:DX2;F/00bU:;F/]J`02:DX2;F/2:DX2;F/2:DX2;F/2
:DX8;F/2:DX:;F/2<H`2:DX3;F/2:DX:;F/2:DX6;F/2Ool00`00Oomoo`06Ool000Moo`04001oodHa
AS44@Q06AS42@Q04AS47@Q08?Nl4>Lh29BT25:D848@26<H27>L28@P29BT5:DX4;F/2<H`2=Jd2>Lh2
@Q02?Nl2>Lh4=Jd2<H`2;F/2:DX28@P4:DX2<H`2?Nl2>Lh4?Nl00d8@?Nlmk`04?Nl>@Q02Ool00`00
Oomoo`0;Ool00`00Ool]J`05;F/2:DX8;F/2:DX7;F/4:DX6;F/29BT2<H`2:DX4;F/6:DX:;F/3:DXD
;F/2:DX6;F/2:DX2;F/2<H`2:DX7;F/6:DX8;F/2:DX2;F/2Ool00`00Oomoo`06Ool000Moo`04001o
odHaAS44@Q06AS42@Q04AS47@Q08?Nl4>Lh29BT25:D848@26<H27>L28@P29BT5:DX4;F/2<H`2=Jd2
>Lh2@Q02?Nl2>Lh4=Jd2<H`2;F/2:DX28@P4:DX2<H`2?Nl2>Lh4?Nl00d8@?Nlmk`04?Nl>@Q02Ool0
0`00Oomoo`0;Ool00`00Ool]J`05;F/2:DX8;F/2:DX7;F/4:DX6;F/29BT2<H`2:DX4;F/6:DX:;F/3
:DXD;F/2:DX6;F/2:DX2;F/2<H`2:DX7;F/6:DX8;F/2:DX2;F/2Ool00`00Oomoo`06Ool000Moo`03
001oodHa00E6<@i24003?Nm2448@00Hmk`PicP8U:@8Q208U:@8YBP8]J`@e[@A2408mk`8icP8YBP03
8@Pmkcg_008]J`8aS08U:@8HaP8e[@8mk`8icP`e[@@icP8mk`8icP8mk`8icPLmk`A2408mk`Y2409o
o`03001oogoo00]oo`03001oobe[00l]J`8U:@8e[@DYBP8]J`8YBP8U:@8YBP8icP8YBPH]J`8YBQ0]
J`03:DX]Jbe[00X]J`@YBP8]J`8Q208e[@8]J`8YBP8U:@8mk`8U:@X]J`039BTaS36<008U:@P]J`@Y
BP8]J`8e[@9oo`03001oogoo00Ioo`001goo00<007ooAS401DHa3T8@00<mkd8@@Q001Sg_23W>0RDY
0R480RDY0RU:0Re[13F]148@0Sg_0SW>0RU:00<Q23g_?Nl00Re[0S6<0RDY0QS60SF]0Sg_0SW>33F]
13W>0Sg_0SW>0Sg_0SW>1cg_148@0Sg_2T8@0Woo00<007ooOol02goo00<007oo;F/03be[0RDY0SF]
1BU:0Re[0RU:0RDY0RU:0SW>0RU:1Re[0RU:42e[00<YBRe[;F/02Re[12U:0Re[0R480SF]0Re[0RU:
0RDY0Sg_0RDY2Re[00<U:C6<<H`00RDY22e[12U:0Re[0SF]0Woo00<007ooOol01Woo0007Ool00`00
Oomoo`1nOol00`00Oomoo`0;Ool00`00Oomoo`1nOol00`00Oomoo`06Ool000Mooh8000eooh8000Qo
o`00ogoo8Goo003oOolQOol00?moob5oo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {136.125, 0}} -> {-0.0541876, -0.0238146, 
  0.00734626, 0.00734626}, {{7.375, 137}, {132.875, 
  3.1875}} -> {-5.13894, -3.03279, 0.51448, 0.51448}, {{149.938, 279.625}, {
  132.875, 3.1875}} -> {-78.4472, -3.01587, 0.514232, 0.514232}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["2D Inverse Transform", "Subsection"],

Cell["\<\
As in the 1D case, the inverse transform is a up-sampling and superposition \
iterative operation that begins at the lowest level of the decomposition. \
Here we demonstrate the compression capabilities of the DWT, by \
reconstructing an approximation to the original from the lowpass coefficients \
only.\
\>", "Text"],

Cell[BoxData[
    \(\[ScriptCapitalA] = DWT[A, \ D\_2, \ 1]; \n
    \[ScriptCapitalA]\&~ = \[ScriptCapitalA]\ \ *\ {1, 0}; \)], "Input"],

Cell[BoxData[
    \(\(A\&~ = InverseDWT[\[ScriptCapitalA]\&~, D\_2]; \)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[
      GraphicsArray[
        \(ListDensityPlot[#1, Mesh \[Rule] False, \n\t\t\t\t
              FrameTicks \[Rule] None, DisplayFunction \[Rule] Identity]\ &
            \)\ /@\ {A\&~\ , \ A - A\&~\ }]]; \)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .47619 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0113379 0.47619 [
[ 0 0 0 0 ]
[ 1 .47619 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .47619 L
0 .47619 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0113379 0.477324 0.464853 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.015024 0.0192308 0.015024 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
64 string
64 64 8 [64 0 0 64 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
A38B92918D8A8B8A8B8C8B8B8B8A89887F7897AC80666A67
80929AA4ADB686666F6C6A67696A6968696A625C75868181
9DB1B9C5C3C5C4C4C6C7C7C8C9CAC6C3
8D5C6A68656265676B6F707276797A7C695CA1CF8E6B695E
89A6AAB4C2CF8A5A60575C5E554F4A444B4F433B66837979
A0BCCBDDD7D8D8D8D9DADADADBDCD3CD
C8C2BFBBB6B1AFACACACA9A7A5A3A19F826BA0C097817D73
9BB5BFCDA68E745B5F5A666D80918D8F7767513C58677889
A0B6C2D2CDCDCDCECFCFCFCFD1D2D1D0
EDFFF2ECE6E0DBD5D3D1CBC7C2BEBAB68E6FA2BFA1938B81
AAC5D2E3976466595A5769759BBAB6BB8F7053354A517693
A2B4C1D0CACACBCCCCCDCCCBCED0D3D5
E2EDE0DAD6D1C9C2C3C2C0BEB7B2B3B2886AA0BFACA7A19A
AEBAC1C986586059798EA0B4BECAC4C2B5AB6B384C4D7390
9EB0BFCFCBCCCCCCCBCACED0D0D0D2D3
E3F0E2DBD7D3C7BEC1C1C1C1B7B0B4B588669FC0B8BBB4B1
B4B6B9BC764357588EB5CAE3DEE1D9D3D7D97C3949437190
9CADBECFCBCDCCCBC9C8CED2D0D0D2D3
E1EBE4E1D9D3C9C1C2C1BEBBB6B2B2B1886A9CB9AEAFB1B3
B7BAA39267437189ABCACBD5D2D2CCC8C9C97E474D437190
9CADBDCECACBCBCBCBCCCFD2D2D3D4D4
E1E9E6E6DBD3CAC2C3C2BCB8B5B2B1AF896D9AB4ABABB4BB
BABC9071583D81ACC5E4D8D7D2CDC9C5C8CA84514F40708F
9BADBDCDC9CACACACCCED0D2D4D6D5D5
E5F2E6E2D8D1CAC3C4C4C0BDB9B6B3B08B6F9EBAAEAEABA9
B7C08A655E4F98C9C7D3CECED2D5C6BBA18B613D5A657A8C
9CACBCCCC7C7CACCCED1D0D0D3D5D4D3
E8F8E7E0D7CFCAC4C6C5C2C0BCB8B5B18D72A1BDB0AFA69F
B5C481535E5AACE7D0CFCBC7D3DAC3B4845D4A316280818A
9CACBCCBC5C4CACED0D3D0CED3D6D3D1
E5F3E9E6DCD3CCC4C7C7C1BDBAB7B5B38E729EB6AEAFADAC
B7BF80545A52A3DDCED2D3D4B8A384685A483B2D61838590
9BA7B8C8C4C6C9CBCBCCCDCDD0D2D1D1
E3F1EBEADFD6CDC4C8C8C1BCBAB7B6B58F729CB2ADAFB1B3
B8BD7D4F5650A2DDCFD4D7DBA47C552E332C2A27628D8A93
9BA3B6C6C4C6C8CAC8C7CACCCDCFD0D1
E3F2E9E7DFD8CEC4C3C0C0BEB9B4B3B18A6E9BB5ABABA8A6
B6C17E505348A2E1CCCDC0B7855E54433C322F2A4C6483A1
9B9FB4C4BFC0C3C6C6C7C8C9CCCECECE
E2F2E9E7E0DACEC4C1BBBFC0B7B1B1AE886B9AB5A9A7A39F
B5C47F504F42A1E4CAC9B09E693D4742382F2E2A3D4980AC
9C9CB2C3BCBBC0C2C4C6C6C7CACCCBCC
E1EFE7E4DED9CFC7C3BEBFBEB5AFB0AF8A6E99B1A9AAAAAA
B8C2865C4D3685B9C0D39A76624A5658626A68694F3C79A1
999DB3C4BEBEC1C3C5C7C7C8CACDCED0
E1ECE5E3DEDAD1C9C4BEBEBDB4ACAFAF8B7098AFA9ABAEB1
BAC28B654A2C719BB8D98652554A5D6880949297582C749C
969DB3C5BFBFC1C2C5C7C7C8CACCCFD2
DFEBE4E1DCD8D0C8C6C2BEBBB4ADB0B08B6F9BB4A7A3A7A8
B8C49677593A6F8DABC9794671838F9D9DA19A965D32779E
979CB3C4BEBEC2C4C5C7C8C9CCCECFD0
DEE9E2E0DBD7CFC8C8C5BEB9B3AEB1B28B6F9DB7A59EA2A3
B7C69F866342687B9FBF6A3582ADB6C8BAB5ABA26232789E
979CB2C4BEBEC2C6C6C7C8CACDCFCFD0
DDE7E2E2DFDCD6D1C9C2BFBBB6B0B0AF8B709AB1A9A9A5A3
B1BB8E7064538CB0B0B9784B96C0AFAEAEAD8E78512E7198
939AAFC1BDC0C2C4C3C4C7CACBCDCED0
DBE5E2E3E1E0DBD7CBC1C0BDB7B2B0AD8B7198ADABB0A7A1
ACB384646862A4D3B9B27E56A8DAB5A7ACAC7E5C452C6C94
9098ADBFBDC1C2C4C2C1C7CBCACBCED0
DAE4E2E4E2E2DCD7CCC2C1BDB6B0AEAC8B7399AFA3A0A3A3
86715D49453E779FA6B773468EB69A907A685039505A809F
9698ADBCBEC3C1C1C4C5C6C6C9CCCCCD
D9E3E2E5E4E4DDD9CDC3C1BDB5AEADAB8C759AB09E97A0A5
693E3D312D275D829BB86D3E7FA2887E56362A18547C8EA6
9A97ACBABEC5C0BFC4C8C5C3C9CCCBCA
D8E1E1E3E1E0DBD6CEC7BFB7B1AAACAC8D769AADA6A59386
542C4954443C66839FBA70415F695A52453A32296690919D
9898ACBBBDC2BFBFC3C5C5C6C8C9CACB
D7E0DFE2DFDED9D5CFC9BDB3ADA6ABAC8E7899ACAAAE8A70
3E124A664F45677C9EBC71424439342D30302E2D75A89798
9898ACBBBCC0BEBEC2C4C5C7C7C7C9CB
D8E1DDDCDEDFD9D5CCC4BCB4B1ACACAB8C7598ACA3A17554
656883987159727EA0BC8564523B362D363B5467707C8995
989DACB8B8BCBDBFBFBFC2C4C7C9CBCD
D9E1DBD8DDDFD8D4CAC1BBB3B2B0ADAB8B7398AC9F9A633A
7BA0AEC28C6A7A7DA1BB947E54302E2336416E9371628092
98A2ABB5B6B9BCBFBCBBC0C3C6C9CCCE
D8E0DBD9DADAD7D5CDC7BEB6B2ADABA88D7999ACA8AB6F44
65716E6E513C5E719CC0ABA5866E5B4749464C4F4D4D7797
9AA5AFB9B8BABBBDBFC1C3C5C6C8CBCE
D7DEDAD8D7D6D6D5CFCAC0B7B2ACAAA68F7D9AABAEB57344
5A5E4A3C2D1E4B6899C4C0C8AB987A5F584B3A2A33366F99
9BA8B1BCB9BABABBC0C4C4C6C6C7CBCF
D7DEDAD9DADAD7D5D0CBC1B9B4AEA8A391839AA886715032
3F413C3938365266758684876D5B4A3A3B38353135376B91
9CAFAFB5B9BDBCBCBFC1C3C5C6C7CBCE
D7DEDAD9DBDCD8D5D1CDC3BBB5B0A7A093889AA56A423825
2826292A363F52615A595D60493930252A2B2C2D3032668C
9EB5AEB0B9BFBDBDBEBFC3C5C6C6CACE
D8DEDAD8D8D8D7D7D0CBC3BBB3ABA59F978F9CA461313328
41505E6D696A635E564F4F4C433B36302F2C363D51606C7A
9CB9B0B2B8BDBBBBBEC0C4C8C8CACDD0
D8DED9D7D7D6D7D8D0CBC3BCB1A7A39E9A959EA352182926
4C67809A8E8C6F5A4C3B3934343333332D293C486781706B
9CBEB2B2B7BCB9B9BDC0C5CACBCCCFD2
D6DDD8D7D6D6D4D2D0CEC5BEB5ADA49C9A979C9E663D5861
5955595B4C424C5047423F3C42463C362F2938426A89736C
9ABAB0B1B4B7B8BABFC3C5C7CCD1CECD
D5DCD8D6D6D5D1CED0D0C7C0B8B1A59A9C9A9A9A7052788B
654E45392614354842423E3B495242393027373F71987769
99B9AFB0B2B3B7BBC0C5C4C5CED5CDC9
D4DAD5D2D3D3D0CDCCCAC5C1B6ACA59D9D9C9FA0795D5C54
3E2C393E404255646970777D706744292B262C304453697D
9CB7B1B3B4B5BABFC1C3C5C7CCD1CCCA
D3D8D2CFD1D1CECBC9C7C4C2B5AAA59F9F9EA1A4836B5137
26122B39485767768492A0AE8E7A481E2824252424245F8B
9DB6B2B5B4B5BCC1C1C3C5C7CBCFCCCA
D3D8D4D3D3D3D0CEC9C5C3C1B8B0A89FA1A0A1A2704C5451
4A45413D4041657F89977C6D564250554E4A321F2B2F6791
9FB4B1B5B6B8BCC0C3C7C7C9CBCDCCCC
D3D8D5D5D4D4D1CFC9C3C3C1BAB4AAA0A2A1A1A16539545C
5F634E3F3C36688B94A46E4A361D577B69663918272A6A9A
A0B2B2B6B8BBBDBFC5C9C9CACACBCCCD
D1D6D2D0D1D1CECCC8C4C4C3BAB3ABA3A2A09D9A806D7678
5339362D2E2C465987AE683F3E32709A817B5E483C2E6C96
9FB1B1B5B8BCBFC2C5C8C8C9CACACACA
D0D5D0CDCFD0CCCAC7C4C5C4BBB4ADA6A39F9994918E8F90
5022282023222E3781B9602E3B3884BB9A917B694B306E95
9EB0B0B4B9BDC1C4C6C8C9C9C9C9C9C9
D0D5D2D1CECCCBCAC6C4C3C2BEBBAFA6A4A09A95938F837A
431840524F513F327BAD5D2F596C6E7458453F353938739F
9EA9B0B8BBBFC0C2C3C5C5C5C7C9C9C9
D0D5D3D3CDC8CAC9C6C4C2C0C0C0B1A6A4A09A9498998170
390B4F746C71452575A8582C6F9463492E141B182F3F78A6
9DA3B0BBBCC1C0C0C2C3C2C2C6C8C8C9
CFD5D2D1CDCBCAC9C7C6C1BEBBB9B2ACA59F9A94908B7461
4D3A5F74777F4E2C7BAB67415A6347362C202220292F6A97
9AA9B0B9BABEBEBFC0C2C4C6C5C4C7C8
CFD5D1CFCDCCCAC8C8C8C1BBB8B5B3B0A69E9A948B846954
5A586E7E8792572E7DAC70505149301C1F1C1E1E2226628F
98ABB0B8B9BCBCBDBFC0C5C9C4C1C5C8
CED4D2D2CFCDC9C6C7C7C2BEB9B5B0ACA6A098908F8D7461
3E2060877776685E88A4755A442C2C253A4842412B1A5D89
96ABB0B9B8BBBBBCBEBFC3C6C4C4C6C7
CDD2D3D4D0CEC9C4C7C7C3BFB9B4AFAAA6A2968D91917967
2E005A9070667882919F7C66370F22254B675C5B2F0F5783
93ACAFB9B8B9BABBBDBEC2C5C4C5C6C7
CACFCFD0CDCCC9C7C4C2C0BFBAB6AFA9A49F948B8985817D
461C5B7E665D605F86A268464236373464865F4C351F5A80
8A9CAAB9B8BBBABABEC1C1C1C3C4C4C4
C8CBCCCDCCCBC9C8C3BEBFBFBBB8AFA7A39E9389847D888F
52285A735C52525080A35C31474B443F7AA569483B285B7C
8290A6BAB8BCBABABFC2BFBEC2C4C3C3
C2C5C6C8CBCDC7C4C4C3C1BFB7B1ADA8A19B918988857A71
492A3E453932383A729C542B586D4A376F93634A3D2D6488
8993A6B6B5B9BABBBDBFBFBFBFC0BFBE
BEC0C2C3CACFC6C1C4C5C2C0B5ADABA8A098908789887161
462E2A201D18212666964B21658B53336C8E624A40336B91
8B91A5B4B3B7B9BCBCBDBEBEBDBDBCBB
BDBDBDBDC6CCC6C2C3C3BFBDB7B1AEAAA19A8E8484815839
30212B2F3F4C3E376E944F2745503D33556B5F5C46356B8E
8C94A5B3B5B9B8B8B9BABBBCBEBFBDBC
BAB9B8B7C3CBC5C3C2C1BEBBB7B3AFACA29B8D81807D4318
1F182730516B4D3F70905029312C303143505C684A386D8E
8D95A4B2B5BBB7B6B7B7B9BABDC0BDBC
C1C4BDB9C3CAC4C1C0BFBAB7B3B0ADAA9F968B817F7B4D2B
393A617D74747271879767484A44392F4350708B7A758996
8E8BA1B0B1B6B3B3B7BBBABABCBEBEBE
C5CAC0B9C3C9C3C0BFBDB8B3B0ADABA99D938A807D794F2F
47518AB692839197999C785E584C3C2C3F497EA79EA29E9D
8E849EAFAFB3B0B0B7BDBABABCBDBEBF
C2C8C2BFC3C5C0BDBCBAB6B3B0AEAAA6A09B948E8F8E837A
8890B3CFB8AFA79FA3A59A93999C6B4884A7A9B3A1979C9E
958EA2AEAEB1B2B3B7B9BBBCBBBBBBBB
C1C8C4C3C2C1BEBBB9B6B4B2AFADA8A3A2A09B979B9DA9B2
BBC5DCF0DDD3C0AEB0ACB8C0CDD88E5CB6EACCC4AD9BA1A1
9A94A3ADACAFB2B5B6B7BBBEBBBAB9B8
BEC1BFBFC0C1BCB8B8B6B4B2AFADA9A6A29D958E8F8E9295
A8B6B0AFA7A29F9C9C9C9B9AA5AC7F5F97B8A7A49C969695
989AA5ADAFB2B3B4B3B3B6B8B7B6B9BB
BCBCBDBDBFC0B9B5B6B5B3B2AFADAAA7A29D938A89878C8F
A7B99A888A878E9292928E8B959C7D678EA596919393908E
99A0A6ADB0B4B3B3B1B0B3B4B4B4B9BC
BABDBDBEBCBABAB9B6B4B4B3B0ADA9A5A3A1958C8781878B
919692908E8B8C8C8C8C8D8D93986743687A8A9B92909292
9CA3A6AAADB1AFAFB0B0B3B5B4B4B6B7
B9BDBDBDB9B6B9BBB6B3B4B5B1AEA8A3A4A3978D847A8286
817E868C888786858585888A8E91562B4A547D9D8F8D9194
9EA6A6A8ABAFADACAEAFB2B5B4B4B4B3
B6B7B9BBB8B6B7B8B4B2B1B0AEACA8A4A19D938B796A6E6D
6E6F727576787D818283878B90956F546468737C70696E70
8FA6A4A8AAACABACAAA9AFB2B1B2B4B5
B3B2B6B8B6B5B6B7B3B1AFACACABA8A59F999189705C5D59
5D5E6163686C757C7D7F868B90957D6C6F6D6863584E5456
84A7A2A8A8AAAAAAA7A5ACB0AFB0B3B6
BEC5C3C3C0BEBCBAB6B3B1AEA9A5A19D9D9C8C7F6F606A6D
6F717B8284887F7982877F7C89918B89868382807D7A7D7E
93A3A2A5A8ABA9A8AAABAEB0B0B1B4B5
C5D1CCCBC7C4C0BCB9B5B1ADA7A19C979C9D88786C5F6E76
777A899595998475848B7A70838E99A49A95928F92939495
9CA1A1A3A8ABA8A7ABAEAEAFB1B2B4B5
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0113379 0.97619 0.464853 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.015024 0.0192308 0.015024 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
64 string
64 64 8 [64 0 0 64 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFE6EEC6B27E3F0E004938FFB224FFFFFF
990F332E04CEFF6C4E567553567362445654675100E5FF00
00F4C09692AC9AB19F9A99AC9DBAB3BD
000000000000000B00433457609F909FE13BD91C5C460E8B
6ED1B9A98C8800A184A3918BCAB5D3DCA2B5B6B30E3AFF3D
00CB976055727266627580606764798E
E1F8D8F1D9FFE6E6DAC7C6C3B4BBA2B5E939DD28DD560012
00DB8E90F1342489938D7974180000000F40848E4A2AFF2D
00D89569869A788C6986887E8C7B8179
7024404940403D46584D555B605B5F43B336B563A4AC09FF
CD6A5C35FF486F9D9AA36D60AEB5C2A4FF475DA93D62FF20
00DF9A708F708C7F7290738A80837A7C
A47C7E8984817E78898289798887585BD14BD14BA4A365E5
A07EA67E3981849C2000BBE0D1EEA6ACC5DD27913669FF40
00F68B7C76687E897683827070837378
94726F7EAB668E7A6F8670858978736FDE2BB46A875C7260
47A1A29900E0A2A933E490344746706F2943DC6F3F75FF5F
00D79B74769B698A916C9672997B7E84
906C87676D857C918A837A84817C865FE628BF2E9D928881
7434D2822AC11C3AD5BA94687D7C7C769152FF323D8D918C
00D69D6D9080826D7F887C927B78776A
A860AB75868D796E887881866F8F6A67DA4BA78B5589886F
7278FF5036D60BF0953E5D9F748372824A05FF222BADE999
00E295707E7885859175787B80847C7D
8F757E857B6285948E7B74896B788156D12CA16B9255738F
7F5DFF1B4AB67A8983788A8187867E99E2FFFF8100B0C598
00E5AC68907A7A7D7F827A858486827A
84807B818B897B719580619482847C5FEA428D6A9667A857
6F4FFF303478FF256F7E828E5B4BBF8A3643699700FA80C0
00E7986A8279858279847B817A7A9075
A471747F84827E7A7186857E72876F6CDE4EAF6193B08D91
3336FF2F246AFF41D77C6656BCFF561B1959689B00C49DCC
00E3AF756E937F8B6B899179857E6B80
946D8E7B8E77639977817B837E886B66DB2CB66F4C99746E
6F69FF2B3089FF2074629F46EE1273E0A4B39ABC00EC82CB
00FCA269867277867684797C8D7D7A76
A1747E7A849C77849187898383746D5FE93BA36794208AA6
7759FF302884FF1273799EDF13606D8D7B939FB12AA9C299
00FFA863809E7D7F92798B7D89768281
99748A8876807584717A97736893765DE931A65A9BAC488C
5B4FFF11356FFF1D845EE1384DCB9E8F9FB4A3A46275FF7B
00F5BA746C83758B7A7D927B6F917474
A555727B70778685897182847A7C7871CC44BE7385988D81
0F60FF3053AF7CE0BD4FFF2966B3682A000026000B63FF8D
00F18C636F84657F827A6F82787B767B
A7738E817D8C8D7E71908473807B875DC948B75C7B80947E
5D77FF303DC911C3B9797A96949D4D9BD0BCE2B349A9A7AA
00FFA2768C807B81977979828E7C7C72
AD64887B8272707574768E90758B6C60D32DA35464509A94
5A4EFF5012A00000355E1EB41A19EDD2B29A72CAB974FF8D
00E9A46F8579987A80858C88748B7278
A76B6E759276927F788B83786C8A6971DD4EA76896AD2AB0
8968E04E00835CE3EAB81FEA27E2822C68668A156F55FF8D
00F59B7171866B7F8A7B807A9A72727A
967397998482998C728B8B84798B7665C834BD89927B9D31
547CFFB3D4FFFFCCAE7700AFEB7C5A73766EDBFF1A96B06C
00F2A5707C94818F7C71786E8085807A
906F836B7B7F728181857E7F7D7A8161C846CF417E798E97
5B6ECB4A001D6330B8A500A5E8017B772570EB2543AAFF9B
00ED976D7D7A777B8C84858C8380827B
8B7C8D7D6D9A7075886A7C7F78847271C63FA95A3B919385
FF6744624D7E00CBBA8008BFFF99C7EAF8BB28591D57E3A9
00F898807B886F847B7F7F7C7C73737B
907582847D887E849988847D907E7761C54EBB6E8E93528B
6E9295B6AFC42FB2D77B29BD1E8AB442289091F00CC9DC86
00FA86738582718C8381828874928283
9E717380875F7483815B777D80637C72D632B36B7273A979
00876A3A5B790079D65D13B1500F3840586C889200DFD2A7
00E49B7A758D80817F80817F77876577
9781778482918F7E89927C818186755BC841C95B577FE188
29FC696BCB6300BCD86B50A5B2AEADA69191968FA328BDA4
00EF9B6F788984837885817C90797D82
875D958271836F747E83818994858574AF57CD654777FF37
005BEDC2FFFF00FFB343C82981A699916E680E28FF89908D
00D07C86796C7D7782778B78867E8C7A
8F907386768D8680847891766F836C769D54C547813AFF56
00BC7400A46A00C5C424FE3857C481B57B7404B5FB00FF6E
18B6A86F6D9881808B7A897D72867E80
8877698F77818193847A7B83658C746ABF33C9675E4ACD33
F2FFFF9A395B00A5EA479FC08F000A335FFFFF49063EFF48
27AA9B6B857E847F827B89827D827574
9F7B817C8B857A7193797E8970857966AF5ABA5E5331FF28
5815486EA5CF389AC02F4915A9B9DBD2562D57867984FF3F
37A88879817E927C7E85797F7D7B9572
8B668084777676887B808F8274938888A746DB4B79FFFC5E
3954796E74702BA32CFFFFECEA6B465847536A765C7FFF46
5E869A7C83736C76827B88807E70AC60
977C7684739A7E886D858972847977689568A5755D385F8D
8BBED59C706E6188585C8C2D4A999BA385A294917B71FF19
857C9377788A897F8F769F6A94728D6C
888797877C727F778E759485787589759E64B3776B766F8D
341D0015ADFFFF955C40773E587485848A9363550500FF27
B461767C65947187865F836B757B8E83
7B728D6A8B84807D847888778881857A886D9871A0B1889D
347EC4939E50008D8CA6A3A2819B8F856E885A6D748CF427
C1657C868778808273948A838D88717C
98757C81837B8187848176796E8C62817B7C964D6315008B
FFFFFF8A2B502C909B798E71634A7965889568FFFF78FF03
C5526395937E8E7D827F838567778C7B
937889847093758A6F8485887A80967D6C7CA69132B6D852
1119636F9FE869AEC684A97F4B49E35A848458430097C543
D46267837D8172867E8284816B9D647D
8C6B7E7C7A7A8679738E8C7B8D798A92658CAC70E7ECA5FF
00874E4837390A3F4300276FF5FF907F8B957C702900CD45
B65D808D95717383867D82917D829183
9B7C7C8781808C807E7B6F8287769380549A626FB04F00C2
8BDB8B70588DCA5EB7AE87409E003AC782A58386A5BB8F5D
B162877A7D8682798F74966E6B897E6E
8E7B6A85847A84767D8B877A8681807E647D984BFD20005A
0024D1FFE1DDFFC7CF9C71FFFA4526544E0654A382807F86
A0747D648B6F8C80737B798982856888
9972867E7F81758774885F86947E849069819758F08F00FC
A7CD3A3A64640088B33A673B70BD22D7B7B839B26FA74992
8F709C8270917482838773857982886F
9679738F808A8A92987B7B937E617F7B5E9D7373999E67D6
FF3B5A86827D3527EB54914E52876992C0B8DE653881578C
9F5E808685788D818095758786708F79
9073906E8870877A7086787891809987678B8A87717D386C
7B828DAAABAB7595E222B98D5C7ED7127071958EB96544AF
9778837D827D7C79737F89717E7E7F74
8F6892758B896B6F7C867E788686867D797D7C8E8197AD70
00AF3F1E350D4588D657AE8700B7F1DB6A0D2F485BFF1281
84916285868C7F98876B8C8B8F946987
8588788285807B879D718188877E7390818687865873BFA8
11F32CC5FF901BABAA4AD389009DE32161E0A8BA533AC268
9B70838780866A7D8D8976816A8B807D
7B7C73828362997E797E797C6E827C71738087862B9CE673
00FF00FFE4D20392E32AB63BFFA33B5169A897898867A886
9B678382727B708272826F916D6F7B8A
9C7C768778947A8080829C856E908D8185827D868662EC99
0FFF00D7806D00C2E53C9F30FF1484ADAC8D9C9096943290
A37E8384818C8B7C82878C74858F8077
8B6D88877D7B877D6F7A77708B668B7C917B7A8B586DBB40
11C800B6E49300A9B25776B73F6A8A822A00241C77B300C4
815479787971858C7B768887847B7E6F
8E71857584779479867A95808C807C789C767F8C687DBFAA
2DFF029FFF4B00B38775D46336E6988D5AA8FF6B52DA00C6
B45DA4787C8B74867F8F818083827F7C
AE7F7E7A8E7E7D7B6E97876D7E8C717D82747B875ABEB79A
00A300D6FF8DFFFF9A2AFF2C39447756B5AFFF96878B00D0
B697A36C719B7E727A70707873798483
6C7F688E7F779181757A8C8E71877C829184768E6D7A7C6F
94783892BB551428B947F17613AEFF19C300C300E97600A9
D136A76A916E7E898D8B759982847E7F
A0808781828E64917B897A757D7E838082797C9B5F7470CE
5FFFB245595C54616D76CD6100DEE638D86C3752FF5A2991
B0179C6B7083807A888B63826B93816E
9B736E7DA65F9471858177937A837E7593776C8A797DC480
006171A9A9C59CA08D7498AF1B71B343D67400DBCA505B7E
B18696738C806B966B927C8F727F8D70
A055747D897C8A8A737F807E6A93748D97917177778BE919
3B7C60682E0A4860A7699F7925F39550FFB100FFCC29E668
A45D8B81878B7B858173708D916C8876
9D789A7D7E81817E7584868574817A7288648197387AEA7B
83B16F8E8EA5D050D42BE868577E7B4BFF3D00EF46B3A05C
AB6D767C85707F837593797F7D887276
8F7C5D8071857B7A878B8780818E8E8394947C9772569B43
256BB563BCBA0C918A3BF410261D3054FF00007400C37A29
93739876888D81837D86748980857B86
8A78748B7D7F8A748D7272828B815E868774578F8E9355A8
1BAF81004F4F7C655F4AF63300603B72FF20FF4DA4757888
A6628C7B728376837D8A7380987E7081
8A978C967E82928783808283816B7986918E678979A6DBFF
28D5FFFFFF9AB7EBBAC0FFFFFFFF666E0017FFACCDD2B3A3
BA51B66A6B8A878C7580718084647A85
8477647C8A836F8382817E867A8D808560936D91827B6747
2F821800776235684E65502A060066FF00FFC811614F787A
28B0907985877B8577927A847A8A8C79
846F8A81687A787B7C81747C7A8D9087768578876E5D6D98
8BC2443C566A74757E8043866B66FFFF00FF8C6D746C7483
429180787271847476768C85898B817A
8D767F73987E80868D7A8C877083798376868B8082A27998
438C92B2948AA6777B8E88888D75E68800D375918B956BA8
61919B836D94828B7D8C787D7F758D80
9C877E91837D80786C7F897682817C807184827776837473
5C697980737C6E8E838377818942FF890086C04E8E807083
81877C78778B8F6F7882827A7D7D6D69
82747F72976D81867884728680807E85787B9E756D846684
8C81787B87808E7D7C91878A7D71FF8B13FFD05B6F80917E
8370878B7387848674858F719473958B
8D74827C719787857D9C898E6A907F8C649195889EB5B0BF
C4B695ADA7807A767464545C404FAD0000659F7580966675
AF7B8F698E667D87827A728F7D867565
9684778E827B62808C6A7284708980758C6A9D7973A66CA6
998AA08D9B81977C7AA77B925F77B1AD98AA7C81808D8393
806E94749484788C6D957C8179828C83
652D3E525E676274806B8076857E98929174AF46020E0000
00101806353D747E896DB1CABAE6DDC6AFAEA87970456576
697B757E747F717E6380807876726A79
5620492C3B464A4259655376838E9F9C777BBF6178B19AA9
EFCFFFCFB78A574CEC53AE73009B9F595E84839985819D99
96798170817474797F7F697B80707464
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 137.125},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000RA000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo0007Oon2000=Oon20008Ool000Moo`03001oogoo07ioo`03001oogoo
00]oo`03001oogoo07ioo`03001oogoo00Ioo`001goo00<007ooOol0OWoo00<007ooOol02goo00<0
07ooOol0OWoo00<007ooOol01Woo0007Ool01000OomBU5:D0THa14YB5dHa13g_0TYB0UJe0T8@0S6<
0SF]0S6<0T8@0TYB0Tic0U:D0UJe0U[F0T8@00<aS3F]=Jd013F]0S6<33F]0S6<0Re[0SW>1T8@0Tic
0U[F0Ukg3f<H1VLi16<H0Woo00<007ooOol02goo00<007ooOol03goo0W>L0WNm00=S65[FF]H00Sg_
0QcW0P@Q0P000RDY0QcW0Woo0U[F0Q241Woo0Tic0P@Q0QS60QBU0P000VLi0Woo00<e[BDY9BT00RU:
0SW>12U:0SW>0S6<0R4812U:0S6<0RU:0P000W>L0Woo10000W_N0V<H14YB00=F]DicCW<00U[F1Tic
0UJe0Tic0Ukg0U[F0Ukg0Woo00<007ooOol01Woo0007Ool01000OomBU5:D0THa14YB5dHa13g_0TYB
0UJe0T8@0S6<0SF]0S6<0T8@0TYB0Tic0U:D0UJe0U[F0T8@00<aS3F]=Jd013F]0S6<33F]0S6<0Re[
0SW>1T8@0Tic0U[F0Ukg3f<H1VLi16<H0Woo00<007ooOol02goo00<007ooOol03goo0W>L0WNm00=S
65[FF]H00Sg_0QcW0P@Q0P000RDY0QcW0Woo0U[F0Q241Woo0Tic0P@Q0QS60QBU0P000VLi0Woo00<e
[BDY9BT00RU:0SW>12U:0SW>0S6<0R4812U:0S6<0RU:0P000W>L0Woo10000W_N0V<H14YB00=F]Dic
CW<00U[F1Tic0UJe0Tic0Ukg0U[F0Ukg0Woo00<007ooOol01Woo0007Ool01000Oom6<DHa0Re[13F]
236<13F]1CW>1Sg_0SF]0Re[0U:D0VLi0THa13F]0Re[0THa0U:D0UJe0U[F0V<H0VLi0THa00<]Jc6<
<H`00RU:12e[0RU:12DY0R4812DY0R480QcW0S6<0T8@13g_0U:D0Ukg0VLi0Vmk0V]J4Fmk0V]J0VLi
0Woo00<007ooOol02goo00<007oo00003@000P@Q0P000R4800<HaRU::DX00S6<0Tic0TYB0Tic0W>L
0QcW0Vmk0PaS0Re[0R480P@Q0THa0SF]0V]J0Ukg0UJe14Ha0P0000=BU48@@Q000U:D0TYB0THa0VLi
0U[F0V]J0Vmk0U:D1U[F0P@Q0QcW0Woo0QcW0P000VLi0TYB0S6<0RU:0cW>136<0SW>0T8@1S6<0Sg_
0THa0Woo00<007ooOol01Woo0007Ool01000Oom6<DHa0Re[13F]236<13F]1CW>1Sg_0SF]0Re[0U:D
0VLi0THa13F]0Re[0THa0U:D0UJe0U[F0V<H0VLi0THa00<]Jc6<<H`00RU:12e[0RU:12DY0R4812DY
0R480QcW0S6<0T8@13g_0U:D0Ukg0VLi0Vmk0V]J4Fmk0V]J0VLi0Woo00<007ooOol02goo00<007oo
00003@000P@Q0P000R4800<HaRU::DX00S6<0Tic0TYB0Tic0W>L0QcW0Vmk0PaS0Re[0R480P@Q0THa
0SF]0V]J0Ukg0UJe14Ha0P0000=BU48@@Q000U:D0TYB0THa0VLi0U[F0V]J0Vmk0U:D1U[F0P@Q0QcW
0Woo0QcW0P000VLi0TYB0S6<0RU:0cW>136<0SW>0T8@1S6<0Sg_0THa0Woo00<007ooOol01Woo0007
Ool01000OomW>FLi0V<H15kg15[F2EJe25:D0Tic0T8@0SF]0U:D0V<H0TYB0T8@0Sg_0SW>0Tic0U[F
0Ukg0VLi0U:D0THa0SW>1Be[0S6<0SF]0T8@0TYB14Ha0SW>0S6<0RU:0QcW0Re[0S6<0Sg_0THa0U:D
0U[F0V<H0V]J3fLi26]J0Woo00<007ooOol02goo00@007ooLiacW09oo`9_N`9kgP9_N`9oo`AcW09_
N`ES609JeP9Nm`9BU09JeP9g_@8Li`9_N`8DY@9_N`8YBP800088@P80009_N`96<@9:DP9kgP8HaP8@
Q003AS5:DTYB0096<@8mk`8icP8<H`H000848@8Q20924096<@8U:@8DY@9oo`8DY@80009_N`9:DP8e
[@924003CW<mkcg_0096<@8e[@924096<@8mk`96<@8mk`92408mk`9oo`03001oogoo00Ioo`001goo
00@007ooIcUW>@9S60ANm`AJePUF]@QBU09>L`92408e[@9BU09S609:DP92408mk`8icP9>L`9JeP9N
m`9W>@9BU096<@8icPD]J`8aS08e[@92409:DPA6<@8icP8aS08YBP8Li`8]J`8aS08mk`96<@9BU09J
eP9S609[FPmW>@Q[FP9oo`03001oogoo00]oo`04001oog>LLi`2Ool2Kg/2Nmh2Kg/2Ool4Li`2Kg/5
HaP2F]H2G_L2DY@2F]H2Mkd27>L2Kg/25:D2Kg/2:DX2000224820002Kg/2AS42BU82Nmh26<H248@0
0dHaBU9:DP02AS42?Nl2>Lh236<6000212428@P2@Q02AS429BT25:D2Ool25:D20002Kg/2BU82=Jd2
@Q000dic?Nlmk`02AS42=Jd2@Q02AS42?Nl2AS42?Nl2@Q02?Nl2Ool00`00Oomoo`06Ool000Moo`04
001oogNmMkd2Ool2Nmh2Mkd4Li`2Kg/6JeX00fLiHaQS6002HaP4G_L2F]H2AS42=Jd2DY@2G_L2DY@2
BU82AS42@Q02E[D2HaP2JeX2Li`2BU84<H`3;F/2:DX2=Jd2>Lh2CW<2G_L2F]H2G_L2AS42>Lh2:DX2
6<H29BT2:DX2>Lh2BU82DY@2F]H2HaP2JeXAIcT6JeX2Ool00`00Oomoo`0;Ool01000OolicSW>0Q24
0R480RDY12480QcW0R480Re[0RDY00<YBRe[;F/00S6<12e[0R480U[F0QS60U[F0S6<0U:D0UJe0P@Q
0Woo0VLi0SF]0Re[0QS60Woo0RDY0SF]0dic0U:D0SF]0S6<0UJe0U[F0V<H0U:D0Woo0R480Re[0UJe
0QcW0S6<0Woo0Q240P000Vmk0Tic0SW>0THa00<icTHaAS400Sg_0SW>0TYB0SW>0THa148@13g_0Woo
00<007ooOol01Woo0007Ool01000Oomg_GNm0Woo0W_N0WNm17>L0Vmk1V]J00=W>F<HHaP00V<H15kg
0U[F0THa0SF]0U:D0Ukg0U:D0TYB0THa0T8@0UJe0V<H0V]J0W>L0TYB136<0be[0RU:0SF]0SW>0Tic
0Ukg0U[F0Ukg0THa0SW>0RU:0QS60RDY0RU:0SW>0TYB0U:D0U[F0V<H0V]J4FLi1V]J0Woo00<007oo
Ool02goo00@007oo>LhicP8@Q08Q208U:@@Q208Li`8Q208]J`8U:@03:DX]Jbe[008aS0@]J`8Q209J
eP8HaP9JeP8aS09BU09F]@848@9oo`9W>@8e[@8]J`8HaP9oo`8U:@8e[@=>L`9BU08e[@8aS09F]@9J
eP9S609BU09oo`8Q208]J`9F]@8Li`8aS09oo`8@Q080009_N`9>L`8icP96<@03>Li6<DHa008mk`8i
cP9:DP8icP96<@A240@mk`9oo`03001oogoo00Ioo`001goo00@007ooLiacW09g_@9cW09_N`A[FP9W
>@MS609Nm`QJeP96<@8e[@9BU09Nm`9F]@ABU09>L`9F]@9Nm`9S609W>@92408]J`8aS003;F/mkcg_
0096<@9BU09JeP9Nm`9W>@AS609JeP9F]@8e[@8Li`@U:@8icP9:DP9>L`9JeP9Nm`mW>@Y[FP9oo`03
001oogoo00]oo`04001ooe:DDY@4?Nl2AS44@Q04?Nl2AS42@Q000dHa?Nlmk`02AS42@Q04;F/2JeX2
9BT2JeX29BT4DY@2<H`2Li`2DY@2?Nl2DY@2?Nl27>L4@Q000dic48@@Q0020002G_L2Li`2JeX2Mkd2
DY@2E[D2HaP2Kg/248@2BU826<H2=Jd2Ool28@P20002Nmh2AS42?Nl2>Lh00cF]?Nlmk`02AS42>Lh4
@Q04>Lh2@Q02>Lh2?Nl2Ool00`00Oomoo`06Ool000Moo`04001oog>LLi`2Mkd2Li`2Kg/4JeX2IcT7
HaP2G_L8F]H2AS42=Jd2DY@2G_L2E[D4DY@2CW<2E[D2G_L2HaP2IcT2@Q02;F/2<H`00be[?Nlmk`02
AS42DY@2F]H2G_L2IcT4HaP2F]H2E[D2=Jd27>L49BT2>Lh2BU82CW<2F]H2G_L?IcT:JeX2Ool00`00
Oomoo`0;Ool01000OomBU5:D13g_0THa148@13g_0THa0T8@00=6<Cg_?Nl00THa0T8@12e[0V]J0RDY
0V]J0RDY15:D0S6<0W>L0U:D0Sg_0U:D0Sg_0QcW148@00=>La2448@00P000Ukg0W>L0V]J0WNm0U:D
0UJe0V<H0Vmk0Q240TYB0QS60SF]0Woo0R480P000W_N0THa0Sg_0SW>00<e[Cg_?Nl00THa0SW>148@
13W>0T8@0SW>0Sg_0Woo00<007ooOol01Woo0007Ool01000OomcW7>L0W_N0W>L0Vmk16]J0V<H0Ukg
1f<H25[F0THa0S6<0Tic0V<H15kg25[F15kg0SW>0R480RU:00<]JdHaAS400U[F0VLi0W>L0Vmk0W>L
0Vmk16]J0Vmk0Sg_0QcW0RDY0R480SW>0TYB0Tic0UJe0Ukg3fLi2V]J0Woo00<007ooOol02goo00@0
07ooBU9:DP8icP8e[@8mk`9F]@8aS096<@8mk`8e[@924003>Li2448@0096<@8mk`8icP8e[@9_N`8D
Y@9JeP8e[@92408]J`8icP8aS08Q20ABU09>L`80009cW09BU003E[DHaQS6009cW09:DP8HaP@Q208i
cP8e[@8DY@8Q209_N`8e[@8Li`8icP9oo`8]J`80009[FP9>L`@icP03CW<e[CF]0096<@9:DP8e[@9:
DP8icP9>L`@mk`92409oo`03001oogoo00Ioo`001goo00@007ooLiacW09kgP9cW09_N`A[FP9S609N
m`MS60QJeP96<@8aS09>L`9S60ANm`QJePANm`8icP8Q208YBP03;F]6<DHa009JeP9W>@9cW09_N`9c
W09_N`A[FP9_N`8mk`8Li`8U:@8Q208icP9:DP9>L`9F]@9Nm`mW>@Y[FP9oo`03001oogoo00]oo`04
001oodYBBU82>Lh2=Jd2?Nl2E[D2<H`2AS42?Nl2=Jd2@Q000cW>@Q124002AS42?Nl2>Lh2=Jd2Kg/2
5:D2F]H2=Jd2@Q02;F/2>Lh2<H`28@P4DY@2CW<20002Li`2DY@00eJe6<HHaP02Li`2BU826<H48@P2
>Lh2=Jd25:D28@P2Kg/2=Jd27>L2>Lh2Ool2;F/20002JeX2CW<4>Lh00dic=Jde[@02AS42BU82=Jd2
BU82>Lh2CW<4?Nl2@Q02Ool00`00Oomoo`06Ool000Moo`04001oog>LLi`2Mkd4Li`2Kg/2JeX2IcT6
HaP3G_L8F]H2AS42=Jd2CW<2G_L4E[D6F]H2G_L2DY@2BU82<H`28@P2>Lh00dHaE[EF]@04IcT6JeX8
IcT2?Nl28@P29BT28@P2>Lh2BU82CW<2E[D2G_L?IcT:JeX2Ool00`00Oomoo`0;Ool01000Oom:DTYB
0SF]0T8@0S6<0SF]0T8@0Sg_0TYB0THa0T8@00<mkd8@@Q000T8@0Sg_0T8@0Re[0W>L0QBU0Ukg0QBU
0Tic0TYB0THa0T8@0SW>0QS60V]J0T8@0QBU0V<H0PaS00<Lif]JJeX00Ukg0TYB0SF]1Sg_0SW>0TYB
0RU:0Woo0QS60QcW0THa0TYB0THa0P000V]J0Tic0SF]0TYB0d8@0SF]0Sg_0THa0Sg_0TYB13g_0SW>
0SF]0Woo00<007ooOol01Woo0007Ool01000OomcW7>L0WNm17>L0Vmk0V]J0VLi1V<H0ekg25[F0THa
0SF]0Tic0Ukg15Je1U[F0Ukg0U:D0TYB0S6<0R480SW>00=6<EJeE[D016Li1V]J26Li0Sg_0R480RDY
0R480SW>0TYB0Tic0UJe0Ukg3fLi2V]J0Woo00<007ooOol02goo00@007ooBU9:DP8e[@92408aS08e
[@92408mk`9:DP96<@924003?Nm2448@0092408mk`92408]J`9cW08DY@9Nm`8DY@9>L`9:DP96<@92
408icP8HaP9[FP92408DY@9S608<H`037>M[FV]J009Nm`9:DP8e[@Hmk`8icP9:DP8YBP9oo`8HaP8L
i`96<@9:DP96<@80009[FP9>L`8e[@9:DP=2408e[@8mk`96<@8mk`9:DP@mk`8icP8e[@9oo`03001o
ogoo00Ioo`001goo00@007ooLiacW09g_@AcW09_N`9[FP9W>@IS60=Nm`IJeP9F]@96<@8e[@9>L`9J
ePAF]@9JePINm`9:DP8icP8]J`8Li`924003E[ES66<H009cW09_N`A[FPAW>@9S60AW>@92408YBP8U
:@8Q208icP96<@9>L`9F]@9Nm`eW>@a[FP9oo`03001oogoo00]oo`04001ooeJeE[D2<H`2E[D2>Lh2
@Q02AS42?Nl2=Jd2AS42?Nl3@Q02=Jd2AS42=Jd2<H`2Kg/29BT2DY@2AS42:DX4AS42=Jd2>Lh2?Nl2
Ool2:DX26<H2JeX212400g_NBU9:DP027>L2;F/2CW<2>Lh2@Q02>Lh2@Q029BT20002Ool248@25:D2
E[D2Mkd2CW<20002Li`2BU82>Lh3?Nl4@Q02BU82>Lh4?Nl4@Q04?Nl2Ool00`00Oomoo`06Ool000Mo
o`04001oog>LLi`2Mkd4Li`2Kg/2JeX2IcT6HaP3G_L6F]H2E[D2AS42=Jd2CW<2F]H4E[D2F]H6G_L2
BU82>Lh2;F/27>L2@Q000eJeHaQS6002Li`2Kg/4JeX4IcT2HaP4IcT2@Q02:DX29BT28@P2>Lh2AS42
CW<2E[D2G_L=IcT<JeX2Ool00`00Oomoo`0;Ool01000OomF]EJe0S6<0UJe0SW>0T8@0THa0Sg_0SF]
0THa0Sg_0d8@0SF]0THa0SF]0S6<0Vmk0RDY0U:D0THa0RU:14Ha0SF]0SW>0Sg_0Woo0RU:0QS60V]J
0P@Q00=kgTYBBU800QcW0Re[0Tic0SW>0T8@0SW>0T8@0RDY0P000Woo0Q240QBU0UJe0WNm0Tic0P00
0W>L0TYB0SW>0cg_148@0TYB0SW>13g_148@13g_0Woo00<007ooOol01Woo0007Ool01000OomcW7>L
0W_N17>L0Vmk0V]J0VLi1f<H15kg1U[F0THa0SF]0Tic0Ukg25Je0U[F0V<H0THa0S6<0Re[0RDY0Tic
00=W>F<HHaP00V]J16Li16]J0V<H0Ukg0U:D0THa0S6<0QcW0Re[0S6<0Sg_0THa0Tic0UJe0Ukg0VLi
0f<H1VLi3V]J0Woo00<007ooOol02goo00@007ooAS56<@8icP8mk`92408mk`8aS092409:DP96<@8m
k`03>Li6<DHa008e[@8mk`92408YBP9[FP8DY@9BU08e[@9:DP8YBP8icP96<@8mk`8]J`9oo`8<H`8U
:@9JeP8mk`03AS52448@008mk`96<@I2408mk`9>L`9cW0Aoo`924080009JeP9S609>L`80009cW09F
]@8e[@9:DPLmk`92408mk`Q2408mk`9oo`03001oogoo00Ioo`001goo00@007ooLiacW09kgPAcW09_
N`9[FP9W>@MS60ANm`IJeP96<@8e[@9>L`9Nm`QF]@9JeP9S6096<@8aS08]J`8U:@9>L`03IcUS66<H
009[FPAW>@A[FP9S609Nm`9BU096<@8aS08Li`8]J`8aS08mk`96<@9>L`9F]@9Nm`9W>@=S60IW>@i[
FP9oo`03001oogoo00]oo`04001oodHaAS42>Lh2?Nl2@Q02?Nl2<H`2@Q02BU82AS42?Nl00cW>AS56
<@02=Jd2?Nl2@Q02:DX2JeX25:D2DY@2=Jd2BU82:DX2>Lh2AS42?Nl2;F/2Ool236<29BT2F]H2?Nl0
0dHa@Q124002?Nl2AS46@Q02?Nl2CW<2Li`4Ool2@Q020002F]H2HaP2CW<20002Li`2E[D2=Jd2BU87
?Nl2@Q02?Nl8@Q02?Nl2Ool00`00Oomoo`06Ool000Moo`04001oogNmMkd2Ool4Li`2JeX4IcT9HaP4
G_L4F]H2AS42>Lh2DY@2G_L2F]H2E[D2DY@2CW<2F]H2HaP2@Q02:DX4;F/2E[D00g>LJeY[FP04IcT2
HaP2JeX2Kg/2HaP2F]H2@Q02;F/29BT26<H2<H`4@Q02AS42CW<2E[D2G_L2IcT3HaP4IcT6JeX2IcT8
JeX2Ool00`00Oomoo`0;Ool00`00Oom24003@Q02?Nl2@Q04AS42?Nl2>Lh2BU82@Q000c6<BU9:DP04
@Q02?Nl2;F/2Mkd28@P2AS42=Jd2BU82<H`2E[D2:DX2=Jd29BT2Ool46<H2?Nl2Ool00a24=Jde[@02
?Nl2@Q02AS42;F/29BT2G_L2AS426<H28@P2=Jd2BU820002Ool2@Q02HaP20002Li`2CW<2=Jd2@Q00
0cg_@Q124002@Q02?Nl2@Q02?Nl2@Q04?Nl2BU82>Lh2Ool00`00Oomoo`06Ool000Moo`04001oogNm
Mkd2Ool4Li`2JeX4IcT9HaP4G_L4F]H2AS42>Lh2DY@2G_L2F]H2E[D2DY@2CW<2F]H2HaP2@Q02:DX4
;F/2E[D00g>LJeY[FP04IcT2HaP2JeX2Kg/2HaP2F]H2@Q02;F/29BT26<H2<H`4@Q02AS42CW<2E[D2
G_L2IcT3HaP4IcT6JeX2IcT8JeX2Ool00`00Oomoo`0;Ool00`00Oom24003@Q02?Nl2@Q04AS42?Nl2
>Lh2BU82@Q000c6<BU9:DP04@Q02?Nl2;F/2Mkd28@P2AS42=Jd2BU82<H`2E[D2:DX2=Jd29BT2Ool4
6<H2?Nl2Ool00a24=Jde[@02?Nl2@Q02AS42;F/29BT2G_L2AS426<H28@P2=Jd2BU820002Ool2@Q02
HaP20002Li`2CW<2=Jd2@Q000cg_@Q124002@Q02?Nl2@Q02?Nl2@Q04?Nl2BU82>Lh2Ool00`00Oomo
o`06Ool000Moo`04001oog>LLi`2Nmh2Mkd2Li`2Kg/2JeX2IcT7HaP4G_L6F]H2AS42>Lh2CW<2F]H8
E[D2F]H2G_L2@Q02:DX2;F/2:DX2DY@00fmkIcUW>@06JeX2G_L2DY@2@Q02=Jd2;F/29BT27>L25:D2
<H`4@Q02BU82CW<2DY@2G_L2IcT3HaP<IcT8JeX2Ool00`00Oomoo`0;Ool01000OomBU5:D13W>0Sg_
148@13g_0SW>0d8@0Sg_0SW>0T8@13F]0Vmk0RDY0UJe0S6<0TYB0U[F0THa0TYB11S60Woo0QBU0Q24
0SF]0Woo00<Q26]JJeX00Sg_0S6<0RU:0Ukg0Woo0RU:10aS0Re[0SF]0Tic0P000V<H0Tic0VLi0P00
0W>L0UJe0SW>0SF]00=:DSg_?Nl00THa0SF]0THa0TYB0Sg_0T8@0Sg_0SF]0T8@0Woo00<007ooOol0
1Woo0007Ool01000OomcW7>L0W_N17Nm0Vmk0V]J0VLi0V<H16Li00=S65kgG_L00Ukg1U[F0THa0SW>
0Tic0U[F15Je15[F15kg0Sg_0RDY12U:0U:D00=_NfLiIcT016]J0Vmk0U:D0Sg_0RU:0QBU0QS611BU
0Q240S6<14Ha0TYB0Tic0U:D0U[F1F<H1VLi0V<H26Li16]J0Woo00<007ooOol02goo00@007ooBU9:
DP8e[@96<@8mk`96<@8icP8aS09>L`8icP924003?Nm2448@008mk`96<@8e[@8aS09_N`8DY@9JeP8e
[@8U:@9>L`8icPHe[@9oo`8DY@8HaP96<@9oo`0348@icSW>008aS09>L`8Q209g_@88@P8icP9cW09B
U09JeP9>L`9Nm`80009g_@92409W>@80009oo`9BU08e[@9240<icP92408icP9240@mk`96<@@mk`8i
cP9oo`03001oogoo00Ioo`001goo00@007ooLiacW09kgPAg_@9_N`9[FP9W>@9S60AW>@03HaQNmekg
009Nm`IJeP96<@8icP9>L`9JePAF]@AJePANm`8mk`8U:@@YBP9BU003Kg]W>FLi00A[FP9_N`9BU08m
k`8YBP8DY@8HaP@DY@8@Q08aS0A6<@9:DP9>L`9BU09JePES60IW>@9S60QW>@A[FP9oo`03001oogoo
00]oo`04001oodYBBU82=Jd2AS42?Nl2AS42>Lh2<H`2CW<2>Lh2@Q000cg_@Q124002?Nl2AS42=Jd2
<H`2Kg/25:D2F]H2=Jd29BT2CW<2>Lh6=Jd2Ool25:D26<H2AS42Ool00a24>LhicP02<H`2CW<28@P2
Mkd22482>Lh2Li`2DY@2F]H2CW<2G_L20002Mkd2@Q02IcT20002Ool2DY@2=Jd2@Q03>Lh2@Q02>Lh2
@Q04?Nl2AS44?Nl2>Lh2Ool00`00Oomoo`06Ool000Moo`04001oog>LLi`2Nmh2Mkd2Li`4Kg/2IcT7
HaP4G_L6F]H2AS42=Jd2CW<2F]H6E[D2DY@2F]H2HaP2?Nl4:DX29BT2DY@00g>LIcUW>@02IcT2HaP2
F]H2@Q02;F/2:DX28@P27>L26<H45:D29BT2<H`2@Q02DY@4CW<2F]H2HaP2G_L9HaP<IcT2Ool00`00
Oomoo`0;Ool01000OomBU5:D0SW>13g_0T8@0Tic0SW>0T8@0TYB0T8@00=6<D8@@Q000T8@0SW>0SF]
0Re[0WNm0QcW0U:D0S6<0TYB0Q240THa0U:D0SW>0Re[0Woo0QS60QBU0T8@0Woo00<8@SW>>Lh00Sg_
0Tic0Vmk0PQ20S6<0SF]0THa0Sg_0TYB0Tic0U[F0QBU0UJe0V<H0Tic0P000Woo0UJe0S6<0T8@00=>
Lcg_?Nl00Sg_0TYB0Sg_0THa0Sg_0THa0SW>148@0Woo00<007ooOol01Woo0007Ool01000OomcW7>L
0W_N0WNm0W>L16mk0VLi1f<H15kg1U[F0THa0SF]0Tic0U[F1UJe0U:D0U[F0V<H0Sg_12U:0RDY0U:D
00=cW6LiIcT00VLi0V<H0U[F0T8@0Re[0RU:0R480QcW0QS611BU0RDY0S6<0T8@0U:D14ic0U[F0V<H
0Ukg2F<H36Li0Woo00<007ooOol02goo00@007ooDYABU08icP@mk`92409>L`8icP92409:DP924003
AS52448@0092408icP8e[@8]J`9g_@8Li`9BU08aS09:DP8@Q096<@9BU08icP8]J`9oo`8HaP8DY@92
409oo`03248icSW>008mk`9>L`9_N`88@P8aS08e[@96<@8mk`9:DP9>L`9JeP8DY@9F]@9S609>L`80
009oo`9F]@8aS0924003CW<mkcg_008mk`9:DP8mk`96<@8mk`96<@8icPA2409oo`03001oogoo00Io
o`001goo00@007ooLiacW09kgP9g_@AcW09_N`9W>@AS60=Nm`9S60IJeP9F]@96<@8e[@9>L`9JeP9F
]@ABU09>L`9JeP9S608mk`8YBP8U:@8Q209BU003LiaW>FLi009W>@9JeP9>L`8e[@8Li`@Q208Li`HD
Y@8Li`8U:@92409F]@A>L`9JeP9S60=Nm`aS60QW>@9oo`03001oogoo00]oo`04001oodicCW<2>Lh4
AS42>Lh2@Q02>Lh2@Q02>Lh2?Nl00dYB>LhicP02=Jd2BU82>Lh2;F/2Mkd26<H2DY@2;F/2CW<2E[D2
9BT2AS42;F/29BT2Ool224826<H2=Jd2Ool00`aS@Q124002;F/2Li`27>L29BT2IcT2CW<2AS42CW<2
F]H4DY@2<H`2>Lh2Ool2?Nl20002Nmh2G_L2>Lh2=Jd00d8@>LhicP02AS44?Nl2BU82?Nl2=Jd2BU84
>Lh2Ool00`00Oomoo`06Ool000Moo`04001oog>LLi`2Nmh2Mkd4Li`2Kg/2IcT4HaP3G_L2HaP6F]H2
E[D2AS42=Jd2CW<2F]H2E[D4DY@2CW<2F]H2HaP2?Nl2:DX29BT28@P2DY@00g>LIcUW>@02IcT2F]H2
CW<2=Jd27>L48@P27>L65:D27>L29BT2@Q02E[D4CW<2F]H2HaP3G_L<HaP8IcT2Ool00`00Oomoo`0;
Ool01000Oom>Ldic0SW>14Ha0SW>0T8@0SW>0T8@0SW>0Sg_00=:DSW>>Lh00SF]0TYB0SW>0Re[0WNm
0QS60U:D0Re[0Tic0UJe0RDY0THa0Re[0RDY0Woo0PQ20QS60SF]0Woo00<<Hd8@@Q000Re[0W>L0QcW
0RDY0VLi0Tic0THa0Tic0U[F15:D0S6<0SW>0Woo0Sg_0P000W_N0Ukg0SW>0SF]00=243W>>Lh00THa
13g_0TYB0Sg_0SF]0TYB13W>0Woo00<007ooOol01Woo0007Ool01000OomcW7>L0WNm17>L16mk0VLi
16<H1Ekg0U[F0UJe0U[F0UJe0THa0SF]0Tic0U[F25Je0Ukg0V<H0T8@0Re[0RDY0QS60T8@00=Nmf<H
HaP00V]J0Tic0SW>0S6<0RDY0RU:0Re[0S6<1SF]0RDY0QcW0Sg_0U:D14ic0U[F0V<H0ekg2V<H26Li
0V]J0Woo00<007ooOol02goo00@007ooDYABU08YBP8icP8mk`@icPA24096<@8icP=240Hmk`8icP9W
>@8Q209Nm`8icP92409>L`96<@9240848@8aS09oo`8HaP8YBP9F]@8mk`03LiaNmekg008U:@9oo`8D
Y@8aS09JeP8e[@8DY@@0008@Q08000848@8aS09oo`96<@80009kgP96<@8aS08e[@03@Q0aS36<008m
k`92408mk`8e[@9240@mk`8icP8mk`9oo`03001oogoo00Ioo`001goo00@007ooLiacW09g_@AcW0A_
N`9W>@AS60ENm`9JeP9F]@9JeP9F]@96<@8e[@9>L`9JePQF]@9Nm`9S6092408]J`8U:@8HaP924003
G_MS66<H009[FP9>L`8icP8aS08U:@8YBP8]J`8aS0He[@8U:@8Li`8mk`9BU0A>L`9JeP9S60=Nm`YS
60QW>@9[FP9oo`03001oogoo00]oo`04001ooe:DDY@2:DX2>Lh2?Nl4>Lh4@Q02AS42>Lh3@Q06?Nl2
>Lh2IcT28@P2G_L2>Lh2@Q02CW<2AS42@Q021242<H`2Ool26<H2:DX2E[D2?Nl00g>LG_MNm`029BT2
Ool25:D2<H`2F]H2=Jd25:D4000248@200021242<H`2Ool2AS420002Nmh2AS42<H`2=Jd00d8@<H`a
S002?Nl2@Q02?Nl2=Jd2@Q04?Nl2>Lh2?Nl2Ool00`00Oomoo`06Ool000Moo`04001oog>LLi`2Mkd4
Li`4Kg/2JeX2IcT2HaP5G_L2F]H6E[D2AS42>Lh2CW<8E[D2F]H2G_L2HaP2AS42<H`29BT25:D2>Lh0
0dicG_MNm`02Kg/2@Q04:DX29BT2;F/2=Jd2@Q06BU82;F/25:D2>Lh2CW<2BU82CW<2F]H2HaP3G_L:
HaP8IcT2JeX2Ool00`00Oomoo`0;Ool01000OomBU5:D0SW>0THa0T8@0Sg_14Ha0Sg_0SW>0TYB00=2
43W>>Lh00T8@0Sg_0T8@0Re[0VLi0RDY0U[F0Re[0Sg_0T8@0TYB0Sg_0Re[0SW>0Woo0QS60QcW0VLi
0PQ200=S65kgG_L013g_14YB0Tic0RDY0Tic0V]J0Ukg0W>L0U[F0RDY0UJe0U:D0UJe0P000Woo0U:D
0SW>0THa00=243g_?Nl00T8@0TYB13g_0T8@0THa13g_0SW>0Woo00<007ooOol01Woo0007Ool01000
OomcW7>L0WNm17>L16mk0V]J0VLi0V<H1Ekg0U[F1UJe0THa0SW>0Tic25Je0U[F0Ukg0V<H0THa0S6<
0RDY0QBU0SW>00=>LekgG_L00Vmk0T8@12U:0RDY0Re[0SF]0T8@1TYB0Re[0QBU0SW>0Tic0TYB0Tic
0U[F0V<H0ekg2V<H26Li0V]J0Woo00<007ooOol02goo00@007ooDYABU08icP96<@92408mk`A6<@8m
k`8icP9:DP03@Q0icSW>0092408mk`92408]J`9W>@8U:@9JeP8]J`8mk`92409:DP8mk`8]J`8icP9o
o`8HaP8Li`9W>@88@P03HaQNmekg00@mk`A:DP9>L`8U:@9>L`9[FP9Nm`9cW09JeP8U:@9F]@9BU09F
]@80009oo`9BU08icP96<@03@Q0mkcg_0092409:DP@mk`924096<@@mk`8icP9oo`03001oogoo00Io
o`001goo00@007ooKg]_N`9g_@AcW0A_N`9[FP9W>@AS60=Nm`9JeP9F]@AJeP96<@8e[@9>L`9JePIB
U09F]@9Nm`9S609:DP8icP8]J`8Li`8e[@03AS5F]EJe009W>@8mk`8Q208icP924096<@A>L`9BU09>
L`9:DP8]J`8HaP8icP9>L`9:DP9>L`9JeP9S60=Nm`QS60YW>@9[FP9oo`03001oogoo00]oo`04001o
oeJeE[D2<H`2AS42?Nl2@Q0:>Lh00dHaBU9:DP02>Lh2AS42=Jd2<H`2JeX25:D2DY@2:DX2<H`2:DX2
CW<2BU82;F/29BT2Ool2:DX22482DY@300026<H2;F/236<2F]H436<2Mkd2JeX2F]H2CW<2>Lh2IcT2
G_L2>Lh2Ool2AS420002Mkd2DY@2=Jd2@Q000cg_CW=>L`02?Nl4@Q04AS42>Lh2AS42>Lh2?Nl2Ool0
0`00Oomoo`06Ool000Moo`04001oofmkKg/2Mkd4Li`4Kg/2JeX2IcT4HaP3G_L2F]H2E[D4F]H2AS42
=Jd2CW<2F]H6DY@2E[D2G_L2HaP2BU82>Lh2;F/27>L2=Jd00dHaE[EF]@02IcT2?Nl28@P2>Lh2@Q02
AS44CW<2DY@2CW<2BU82;F/26<H2>Lh2CW<2BU82CW<2F]H2HaP3G_L8HaP:IcT2JeX2Ool00`00Oomo
o`0;Ool01000OomF]EJe0S6<0THa0Sg_0T8@2SW>00=6<DYBBU800SW>0THa0SF]0S6<0V]J0QBU0U:D
0RU:0S6<0RU:0Tic0TYB0Re[0RDY0Woo0RU:0PQ20U:D0`000QS60Re[0PaS0U[F10aS0WNm0V]J0U[F
0Tic0SW>0VLi0Ukg0SW>0Woo0THa0P000WNm0U:D0SF]0T8@00<mkdicCW<00Sg_148@14Ha0SW>0THa
0SW>0Sg_0Woo00<007ooOol01Woo0007Ool01000Oom_Nfmk0WNm17>L0Vmk0V]J1VLi0V<H0ekg0U[F
0UJe15[F0THa0SF]0Tic0U[F0U:D0Tic15:D0U[F0V<H0Tic0T8@0S6<0R480SF]00<mkdicCW<00Ukg
0SF]0QS60T8@0UJe0U[F0VLi0Ukg0U[F0UJe0U:D0S6<0QS60Sg_0Tic0TYB0Tic0U[F0V<H0ekg26<H
2VLi0V]J0Woo00<007ooOol02goo00@007ooDYABU0@e[@8icP9:DP8icP9:DP@mk`96<@03@Q0mkcg_
008e[@96<@8e[@8icP9_N`8U:@9BU08e[@9:DP9F]@8DY@9JeP96<@8e[@9cW08U:@800092408]J`03
Liag_GNm009Nm`8<H`9g_@8@Q09cW092408DY@8e[@8aS096<@88@P8e[@8YBP9oo`96<@80009kgP9>
L`@icP03@Q0e[CF]008mk`96<@8mk`92408mk`9>L`@icP8mk`9oo`03001oogoo00Ioo`001goo00@0
07ooKg]_N`9g_@AcW09_N`9[FPIW>@9S60=Nm`9JeP9F]@AJeP96<@8e[@9>L`9JeP9BU09>L`ABU09J
eP9S609>L`92408aS08Q208e[@03?Nm>Ldic009Nm`8e[@8HaP92409F]@9JeP9W>@9Nm`9JeP9F]@9B
U08aS08HaP8mk`9>L`9:DP9>L`9JeP9S60=Nm`QS60YW>@9[FP9oo`03001oogoo00]oo`04001ooe:D
DY@4=Jd2>Lh2BU82>Lh2BU84?Nl2AS400d8@?Nlmk`02=Jd2AS42=Jd2>Lh2Kg/29BT2DY@2=Jd2BU82
E[D25:D2F]H2AS42=Jd2Li`29BT20002@Q02;F/00g>LMkeg_@02G_L236<2Mkd248@2Li`2@Q025:D2
=Jd2<H`2AS422482=Jd2:DX2Ool2AS420002Nmh2CW<4>Lh00d8@=Jde[@02?Nl2AS42?Nl2@Q02?Nl2
CW<4>Lh2?Nl2Ool00`00Oomoo`06Ool000Moo`04001oofmkKg/6Li`4Kg/4JeX2IcT2HaP3G_L6F]H2
E[D2AS42>Lh2CW<2F]H4E[D4DY@2F]H2G_L2AS42>Lh2<H`2:DX2AS43F]H2G_L2?Nl29BT2BU82HaP8
E[D2AS42?Nl2:DX25:D2>Lh2CW<2BU82CW<2E[D2HaP2G_L;HaP8IcT2JeX2Ool00`00Oomoo`0;Ool0
1000Oom:DTYB0SW>0TYB0Tic148@0Tic0THa0SW>0dHa0T8@0Sg_0THa0SW>0S6<0VLi0QS60Ukg0THa
0TYB0Sg_0Tic0QS60RU:0Sg_0Woo0U[F0V]J17oo00=W>EJeE[D00SW>0P000UJe0WNm0Sg_0Re[13W>
0SF]0Vmk0Woo0PaS0TYB0U[F0SF]0P000W_N0U:D0SW>0Sg_00=:DT8@@Q000THa0Sg_0SW>0Sg_0SF]
1T8@0Sg_0Woo00<007ooOol01Woo0007Ool01000Oom_Nfmk1W>L16mk16]J0VLi0V<H0ekg1U[F0UJe
0THa0SW>0Tic0U[F15Je15:D0U[F0Ukg0THa0SW>0S6<0RU:0THa0e[F0Ukg0Sg_0RDY0TYB0V<H25Je
0THa0Sg_0RU:0QBU0SW>0Tic0TYB0Tic0UJe0V<H0Ukg2f<H26Li0V]J0Woo00<007ooOol02goo00@0
07ooBU9:DP8icP9:DP9>L`A2409>L`96<@8icP=6<@92408mk`96<@8icP8aS09W>@8HaP9Nm`96<@9:
DP8mk`9>L`8HaP8YBP8mk`9oo`9JeP9[FPAoo`03IcUF]EJe008icP80009F]@9g_@8mk`8]J`@icP8e
[@9_N`9oo`8<H`9:DP9JeP8e[@80009kgP9BU08icP8mk`03BU92448@0096<@8mk`8icP8mk`8e[@I2
408mk`9oo`03001oogoo00Ioo`001goo00@007ooKg]_N`YcW09_N`9[FP9W>@=S609Nm`IJeP9F]@96
<@8icP9>L`AF]@9JePABU09F]@9JeP92408aS08e[@8aS09BU003JeYNmekg009JeP8mk`8YBP9F]@9_
N`9JeP9BU0AF]@8mk`8]J`8Q208DY@8e[@A:DP9>L`9F]@ANm`]S60QW>@9[FP9oo`03001oogoo00]o
o`04001oodYBBU82=Jd2@Q02=Jd4?Nl2>Lh6@Q07?Nl2@Q02<H`2IcT28@P2IcT28@P4?Nl2AS42BU82
;F/2=Jd2IcT29BT2000236<2<H`00aS6G_MNm`02DY@20002DY@2Mkd20002?Nl2>Lh248@2>Lh2Mkd2
48@28@P2E[D2Ool2CW<20002Mkd2BU82=Jd3?Nl2>Lh2?Nl2AS44@Q02AS46@Q02?Nl2Ool00`00Oomo
o`06Ool000Moo`04001oofmkKg/:Li`2Kg/2JeX2IcT3HaP2G_L6F]H2E[D2AS42>Lh2CW<4E[D2F]H4
DY@2E[D2F]H2@Q02<H`2=Jd2<H`2DY@00f]JG_MNm`02F]H2?Nl2:DX2E[D2Kg/2F]H2DY@4E[D2?Nl2
;F/28@P25:D2=Jd4BU82CW<2E[D4G_L;HaP8IcT2JeX2Ool00`00Oomoo`0;Ool01000Oom:DTYB0SF]
0T8@0SF]13g_0SW>1T8@1cg_0T8@0S6<0VLi0R480VLi0R4813g_0THa0TYB0Re[0SF]0VLi0RDY0P00
0PaS0S6<00<HaUkgG_L00U:D0P000U:D0WNm0P000Sg_0SW>0Q240SW>0WNm0Q240R480UJe0Woo0Tic
0P000WNm0TYB0SF]0cg_0SW>0Sg_0THa148@0THa1T8@0Sg_0Woo00<007ooOol01Woo0007Ool01000
Oom_Nfmk2W>L0Vmk0V]J0VLi0f<H0Ukg15[F15Je0THa0SW>0Tic0UJe25:D0T8@0SW>0Re[0RDY0R48
0QcW0SW>00=>Le:DDY@00U[F0SW>0R480THa0U[F0Tic0TYB0Sg_0SF]0RU:0QcW0RU:0Re[0T8@0Tic
0TYB0Tic0UJe15kg3F<H26Li0Woo00<007ooOol02goo00@007ooAS56<@8mk`96<@8mk`8e[@9>L`@i
cP96<@8e[@Dmk`9240@icP9S608Li`9F]@8]J`8Li`A:DP92409oo`8aS08Q208aS08U:@8mk`800003
IcUNmekg009240848@9Nm`9oo`9>L`9S609g_@9oo`9Nm`8DY@8]J`8<H`8YBP9cW09F]@80009oo`9>
L`92408mk`03AS4e[CF]009240Xmk`@icP8mk`9oo`03001oogoo00Ioo`001goo00@007ooKg]_N`Yc
W09_N`9[FP9W>@=S609Nm`AJePAF]@96<@8icP9>L`9F]@QBU092408icP8]J`8U:@8Q208Li`8icP03
CW=BU5:D009JeP8icP8Q2096<@9JeP9>L`9:DP8mk`8e[@8YBP8Li`8YBP8]J`92409>L`9:DP9>L`9F
]@ANm`eS60QW>@9oo`03001oogoo00]oo`04001oodHaAS42?Nl2AS42?Nl2=Jd2CW<4>Lh2AS42=Jd5
?Nl2@Q04>Lh2HaP27>L2E[D2;F/27>L4BU82@Q02Ool2<H`28@P2<H`29BT2?Nl200000fLiG_MNm`02
@Q021242G_L2Ool2CW<2HaP2Mkd2Ool2G_L25:D2;F/236<2:DX2Li`2E[D20002Ool2CW<2@Q02?Nl0
0dHa=Jde[@02@Q0:?Nl4>Lh2?Nl2Ool00`00Oomoo`06Ool000Moo`04001oofmkKg/:Li`4Kg/2IcT3
HaP2G_L2F]H6E[D2AS42>Lh2CW<2F]H2CW<2BU84DY@2=Jd47>L26<H25:D248@2;F/00d8@CW=>L`02
G_L2=Jd27>L2?Nl2DY@2AS42?Nl2:DX26<H25:D236<2:DX2?Nl2AS42DY@2CW<2BU82E[D4G_L3HaP2
G_L2HaP2IcT4HaP8IcT2Ool00`00Oomoo`0;Ool01000Oom:DTYB0SW>148@0Sg_0THa0Sg_0T8@0Tic
0THa00=243g_?Nl00TYB0Sg_0SW>0S6<0V<H0RDY0Ukg0SF]0THa0TYB0RU:0THa0SF]14YB0U[F0UJe
0V<H0QBU00=JeV]JJeX00Sg_0QBU0Ukg0PaS0THa0U[F0R480QBU14YB0W_N0P@Q0VLi0Vmk0T8@0P00
0Woo0T8@0SW>0d8@0SW>0THa1T8@0THa0SW>0TYB148@0Woo00<007ooOol01Woo0007Ool01000Oom_
Nfmk2W>L16mk0VLi0f<H0Ukg0U[F1UJe0THa0SW>0Tic0U[F0Tic0TYB15:D0SF]11cW0QS60QBU0Q24
0Re[00=244icCW<00Ukg0SF]0QcW0Sg_0U:D0THa0Sg_0RU:0QS60QBU0PaS0RU:0Sg_0THa0U:D0Tic
0TYB0UJe15kg0f<H0Ukg0V<H0VLi16<H26Li0Woo00<007ooOol02goo00@007ooBU9:DP8icPA2408m
k`96<@8mk`92409>L`96<@03@Q0mkcg_009:DP8mk`8icP8aS09S608U:@9Nm`8e[@96<@9:DP8YBP96
<@8e[@A:DP9JeP9F]@9S608DY@03F]I[FV]J008mk`8DY@9Nm`8<H`96<@9JeP8Q208DY@A:DP9kgP84
8@9W>@9_N`924080009oo`92408icP=2408icP96<@I24096<@8icP9:DPA2409oo`03001oogoo00Io
o`001goo00@007ooKg]_N`YcW09_N`9[FP9W>@9S6003G_MJeU[F009JePIF]@96<@8icP9>L`9F]@AB
U09:DP92408YBP8DY@8U:@8YBP8Q208Li`8aS003@Q1>Ldic009Nm`8icP8Q208]J`8e[@8]J`8YBP8Q
208Li`8HaP8DY@8aS0A:DPI>L`9F]@ANm`03HaQNmekg009Nm`QS60QW>@9oo`03001oogoo00]oo`04
001oodicCW<4>Lh4@Q02;F/2>Lh4@Q02;F/00cW>?Nlmk`02@Q02<H`2?Nl2>Lh2JeX26<H2F]H2=Jd4
>Lh2E[D2?Nl20002@Q02=Jd27>L2;F/2?Nl200000cg_JeY[FP02;F/22482F]H2:DX212427>L28@P2
;F/2=Jd2AS42BU820002Kg/2JeX2DY@20002Li`2CW<2?Nl2>Lh00dHa@Q124002@Q02?Nl4@Q02?Nl2
>Lh2@Q02<H`2>Lh2Ool00`00Oomoo`06Ool000Moo`04001oofmkKg/:Li`2Kg/2JeX2IcT2HaP00ekg
F]IJeP02F]H6E[D2AS42>Lh2CW<2E[D4DY@2BU82@Q02:DX25:D29BT2:DX28@P27>L2<H`00d8@CW=>
L`02G_L2>Lh28@P2;F/2=Jd2;F/2:DX28@P27>L26<H25:D2<H`4BU86CW<2E[D4G_L00f<HG_MNm`02
G_L8HaP8IcT2Ool00`00Oomoo`0;Ool01000Oom>Ldic13W>148@0Re[0SW>148@0Re[00<icSg_?Nl0
0T8@0S6<0Sg_0SW>0V]J0QS60U[F0SF]13W>0UJe0Sg_0P000T8@0SF]0QcW0Re[0Sg_0P0000<mkf]J
JeX00Re[0PQ20U[F0RU:0P@Q0QcW0R480Re[0SF]0THa0TYB0P000Vmk0V]J0U:D0P000W>L0Tic0Sg_
0SW>00=6<D8@@Q000T8@0Sg_148@0Sg_0SW>0T8@0S6<0SW>0Woo00<007ooOol01Woo0007Ool01000
Oom[FV]J0W>L0Vmk0W>L1Vmk0V]J16Li00=Nme[FF]H00UJe0U:D15Je0THa0Sg_0Tic1UJe0THa0SW>
0QcW0PQ20RDY0S6<0RDY0R480S6<00<mkdicCW<00Ukg0SW>12480QcW0QS60QBU11S611BU0SW>0UJe
0TYB1Tic0UJe15kg00=S65kgG_L00Ukg36<H16Li0Woo00<007ooOol02goo00@007ooBU9:DP92408i
cPA2409:DP96<@8mk`96<@9:DP03?Nm2448@00A2408icP8]J`9W>@8Q209W>@8]J`8YBP8mk`9cW096
<@8DY@9oo`@e[@9W>@8aS0800003G_M_Nfmk008e[@8YBP9BU09JePAF]@9BU0I:DP96<@9BU08DY@9N
m`9BU080009g_@9>L`8e[@8mk`03AS52448@0092408mk`A2408mk`9:DP@mk`92409oo`03001oogoo
00Ioo`001goo00@007ooJeY[FP9cW09_N`9cW0I_N`9[FPAW>@03G_MJeU[F009F]@9BU0AF]@96<@8m
k`9>L`IF]@96<@8icP8Li`88@P8U:@8aS08U:@8Q208aS003?Nm>Ldic009Nm`8icP@Q208Li`8HaP8D
Y@@HaP@DY@8icP9F]@9:DPI>L`9F]@ANm`03HaQNmekg009Nm`aS60AW>@9oo`03001oogoo00]oo`04
001oodYBBU82@Q02>Lh4@Q02BU82AS42?Nl2AS42BU800cg_@Q124004@Q02>Lh2;F/2IcT28@P2IcT2
;F/2:DX2?Nl2Li`2AS425:D2Ool4=Jd2IcT2<H`200000ekgKg]_N`02=Jd2:DX2DY@2F]H4E[D2DY@6
BU82AS42DY@25:D2G_L2DY@20002Mkd2CW<2=Jd2?Nl00dHa@Q124002@Q02?Nl4@Q02?Nl2BU84?Nl2
@Q02Ool00`00Oomoo`06Ool000Moo`04001oofmkKg/2Li`:Kg/2JeX2IcT2HaP00ekgF]IJeP02F]H6
E[D2AS42>Lh2CW<2E[D4DY@2>Lh2:DX2<H`2=Jd2@Q02CW<2>Lh2;F/2>Lh00cg_DYABU002G_L2@Q02
<H`2:DX27>L26<H25:D26<H27>L2:DX2<H`2>Lh2?Nl2AS42BU84CW<2E[D=G_L6HaP6IcT2Ool00`00
Oomoo`0;Ool01000Oom2448@0Re[0TYB0T8@0SW>0T8@0SF]0SW>0Sg_0d8@0THa0TYB148@0SW>0UJe
0RU:0VLi0S6<0R480SW>0Woo0QS60P000Re[0WNm0V<H17oo0P0000=ooe[FF]H00R480VLi0QBU0T8@
0U:D0Tic0TYB13F]0P@Q0QBU0Woo0THa0TYB0THa0P000V]J0Sg_0T8@0Sg_00<e[Cg_?Nl00SW>0T8@
0SW>0THa0Sg_0T8@0Sg_0THa0Sg_0Woo00<007ooOol01Woo0007Ool01000Oom_Nfmk0W>L2Vmk0V]J
0VLi0V<H00=Nme[FF]H00U[F1UJe0THa0SW>0Tic0UJe15:D0SW>0RU:0S6<0SF]0T8@0Tic0SW>0Re[
0SW>00<mke:DDY@00Ukg0T8@0S6<0RU:0QcW0QS60QBU0QS60QcW0RU:0S6<0SW>0Sg_0THa0TYB14ic
0UJe3Ekg1V<H1VLi0Woo00<007ooOol02goo00@007oo@Q12408]J`9:DP92408icP92408e[@8icP8m
k`=24096<@9:DPA2408icP9F]@8YBP9W>@8aS08Q208icP9oo`8HaP80008]J`9g_@9S60Aoo`800003
OomJeU[F008Q209W>@8DY@92409BU09>L`9:DP@e[@848@8DY@9oo`96<@9:DP96<@80009[FP8mk`92
408mk`03=Jdmkcg_008icP92408icP96<@8mk`92408mk`96<@8mk`9oo`03001oogoo00Ioo`001goo
00@007ooKg]_N`9cW0Y_N`9[FP9W>@9S6003G_MJeU[F00AJePAF]@96<@8icP9>L`9F]@A>L`8aS08L
i`8mk`9BU09F]@9S6096<@8e[@<mk`9BU09Nm`9:DP8mk`8YBP8HaP8DY@8@Q08HaP8Q208e[@9:DP8i
cP8aS092409:DP9>L`9BU09F]@AJePUNm`IS60IW>@9oo`03001oogoo00]oo`04001oodHaAS42BU82
>Lh2@Q02>Lh2AS46@Q02?Nl00dYB>LhicP02=Jd2@Q02=Jd2>Lh2CW<2:DX2HaP28@P2@Q027>L2Ool2
:DX20002G_L2>Lh20002DY@2=Jd20003HaP248@2Ool27>L2:DX2HaP2@Q02F]H2?Nl2>Lh20002F]H2
Ool20002Ool2=Jd236<2F]H2E[D4=Jd00dic@Q124002@Q02AS42?Nl2AS42?Nl2>Lh2@Q02?Nl2@Q02
Ool00`00Oomoo`06Ool000Moo`04001oofmkKg/2Li`:Kg/2JeX2IcT2HaP00ekgF]IJeP04F]H4E[D2
AS42>Lh2CW<2E[D4CW<2<H`27>L2?Nl2DY@2E[D2HaP2AS42=Jd3?Nl2DY@2G_L2BU82?Nl2:DX26<H2
5:D248@26<H28@P2=Jd2BU82>Lh2<H`2@Q02BU82CW<2DY@2E[D4F]H9G_L6HaP6IcT2Ool00`00Oomo
o`0;Ool01000Oom6<DHa0TYB0SW>0T8@0SW>0THa1T8@0Sg_00=:DSW>>Lh00SF]0T8@0SF]0SW>0Tic
0RU:0V<H0R480T8@0QcW0Woo0RU:0P000Ukg0SW>0P000U:D0SF]0P000f<H0Q240Woo0QcW0RU:0V<H
0T8@0U[F0Sg_0SW>0P000U[F0Woo0P000Woo0SF]0PaS0U[F0UJe13F]00=>Ld8@@Q000T8@0THa0Sg_
0THa0Sg_0SW>0T8@0Sg_0T8@0Woo00<007ooOol01Woo0007Ool01000Oom_Nfmk0W>L26mk16]J0VLi
0V<H00=Nme[FF]H00U[F1UJe0THa0Sg_0Tic1UJe0SF]0R480S6<0SW>13F]0RU:0QcW0Re[00<icTic
CW<00V<H0UJe0U:D0T8@0SF]0Re[0R480RDY0R4822DY0SW>0TYB0Tic0U:D0UJe2ekg26<H1VLi0Woo
00<007ooOol02goo00@007ooAS56<@8icP8e[@96<@8icPA2409:DP9240<mk`92408aS096<@8icP8e
[@9Nm`8HaP9W>@8aS08]J`8U:@9W>@8HaP9kgPAoo`9>L`8Li`8]J`800003DYAg_GNm008Q209>L`9S
6096<@8000848@8HaP8]J`Aoo`8U:@80008Li`9oo`8U:@8@Q09F]@9>L`8e[@924003?Nm2448@008m
k`92408mk`96<@92408mk`9240@icP9oo`03001oogoo00Ioo`001goo00@007ooKg]_N`9cW0Q_N`A[
FP9W>@9S6003G_MJeU[F009JePIF]@96<@8mk`9>L`IF]@8e[@8Q208aS08icP@e[@8YBP8Li`8]J`03
>Li>Ldic009S609F]@9BU092408e[@8]J`8Q208U:@8Q20PU:@8icP9:DP9>L`9BU09F]@]Nm`QS60IW
>@9oo`03001oogoo00]oo`04001oodHaAS42>Lh2=Jd2AS42>Lh4@Q02BU82@Q03?Nl2@Q02<H`2AS42
>Lh2=Jd2G_L26<H2IcT2<H`2;F/29BT2IcT26<H2Nmh4Ool2CW<27>L2;F/200000e:DMkeg_@028@P2
CW<2HaP2AS42000212426<H2;F/4Ool29BT200027>L2Ool29BT248@2E[D2CW<2=Jd2@Q000cg_@Q12
4002?Nl2@Q02?Nl2AS42@Q02?Nl2@Q04>Lh2Ool00`00Oomoo`06Ool000Moo`04001oof]JJeX6Kg/8
JeX4IcT00f<HF]IJeP02F]H4E[D2DY@2AS42?Nl2CW<4E[D2F]H2>Lh28@P4;F/29BT27>L25:D236<2
9BT00cF]CW=>L`04HaP2IcT2E[D2CW<2?Nl4;F/29BT27>L25:D46<H2=Jd4CW<2E[D2F]H9G_L<HaP4
IcT2Ool00`00Oomoo`0;Ool01000Oom>Ldic0Sg_0T8@0Sg_0THa0T8@0Sg_0SW>0TYB0cg_0THa0SW>
0T8@0Sg_0S6<0UJe0Re[0Ukg0Re[0RU:0QS60Woo0QBU0Re[0PQ20RDY0SF]0U:D0VLi0QcW00=>Lf<H
HaP00QBU0RDY0PQ20UJe0Ukg0Vmk0V]J0RU:0QBU0RU:0T8@0Sg_0T8@0Woo0QcW0QS60UJe0THa0Sg_
0T8@00<mkdYBBU8013g_0T8@23g_0TYB0SW>0Woo00<007ooOol01Woo0007Ool01000Oom[FV]J1Vmk
26]J16Li00=S65[FF]H00U[F15Je0U:D0THa0Sg_0Tic15Je0U[F0SW>0R4812e[0RDY0QcW0QBU0PaS
0RDY00<e[DicCW<016<H0VLi0UJe0Tic0Sg_12e[0RDY0QcW0QBU11S60SF]14ic0UJe0U[F2Ekg36<H
16Li0Woo00<007ooOol02goo00@007ooCW=>L`8mk`92408mk`96<@92408mk`8icP9:DP<mk`96<@8i
cP92408mk`8aS09F]@8]J`9Nm`8]J`8YBP8HaP9oo`8DY@8]J`88@P8U:@8e[@9BU09W>@8Li`03CW=S
66<H008DY@8U:@88@P9F]@9Nm`9_N`9[FP8YBP8DY@8YBP92408mk`92409oo`8Li`8HaP9F]@96<@8m
k`924003?Nm:DTYB00@mk`9240Pmk`9:DP8icP9oo`03001oogoo00Ioo`001goo00@007ooJeY[FPY_
N`I[FP9W>@03HaQNmekg009JePAF]@9BU09:DP92409>L`9F]@92408icP8YBP8HaP8Li`8Q20HLi`8H
aP8YBP03<H`icSW>00I2408e[@8]J`8U:@HLi`PHaP8e[@9:DP9>L`AF]@9JePUNm`YS60AW>@9oo`03
001oogoo00]oo`04001oodHaAS42<H`4@Q06>Lh2AS42?Nl2@Q000dHa@Q124002>Lh2BU84AS42DY@2
8@P2Kg/29BT2?Nl4Ool2;F/27>L2:DX2?Nl2=Jd4>Lh25:D00e:D5:DDY@04Ool4Mkd2=Jd28@P2;F/2
8@P2:DX2=Jd2>Lh2;F/2?Nl2Ool28@P2;F/2@Q02CW<2?Nl2@Q000cW>=Jde[@02>Lh2@Q02?Nl2AS42
@Q02?Nl2>Lh2E[D2<H`2Ool00`00Oomoo`06Ool000Moo`04001oof]JJeX:Kg/6JeX2IcT00f<HG_MN
m`02F]H4E[D2DY@2BU82@Q02CW<2E[D2@Q02>Lh2:DX26<H27>L28@P67>L26<H2:DX00c6<>LhicP06
@Q02=Jd2;F/29BT67>L86<H2=Jd2BU82CW<4E[D2F]H9G_L:HaP4IcT2Ool00`00Oomoo`0;Ool01000
Oom6<DHa0S6<148@1SW>0THa0Sg_0T8@00=6<D8@@Q000SW>0TYB14Ha0U:D0R480Vmk0RDY0Sg_17oo
0Re[0QcW0RU:0Sg_0SF]13W>0QBU00=BU1BU5:D017oo17Nm0SF]0R480Re[0R480RU:0SF]0SW>0Re[
0Sg_0Woo0R480Re[0T8@0Tic0Sg_0T8@00<icSF]=Jd00SW>0T8@0Sg_0THa0T8@0Sg_0SW>0UJe0S6<
0Woo00<007ooOol01Woo0007Ool01000Oom[FV]J36mk16]J0VLi00=S65kgG_L015[F15:D0TYB0THa
0Tic0U:D0SF]0R480QcW0Q240QBU0Q2411BU0QS60QcW0RU:00<aS2e[;F/012e[0S6<0RDY0QcW0QS6
0Q2421BU11S60S6<0THa0Tic0U[F0UJe0U[F2ekg26<H16Li0Woo00<007ooOol02goo00@007ooBU9:
DP8mk`8icP92408icP9>L`8mk`96<@8e[@924003AS4icSW>0092408mk`8icP8e[@9:DP8e[@9BU08i
cP8]J`8Li`8]J`A6<@9Nm`9[FP9>L`8icP8e[@8aS003AS4]Jbe[008]J`96<@8DY@8U:@A>L`9BU092
409BU0A:DP8mk`8icP9oo`8<H`92408mk`9:DP8icP8mk`=6<@8mk`96<@8icP9>L`8e[@9:DP8icP96
<@8e[@9oo`03001oogoo00Ioo`001goo00@007ooJeY[FPa_N`A[FP9W>@03HaQNmekg00AJePABU09:
DP96<@9>L`9BU08e[@8Q208Li`8@Q08DY@8@Q0@DY@8HaP8Li`8YBP03<H`]Jbe[00@]J`8aS08U:@8L
i`8HaP8@Q0PDY@@HaP8aS096<@9>L`9JeP9F]@9JeP]Nm`QS60AW>@9oo`03001oogoo00]oo`04001o
odYBBU82?Nl2>Lh2@Q02>Lh2CW<2?Nl2AS42=Jd2@Q000dHa>LhicP02@Q02?Nl2>Lh2=Jd2BU82=Jd2
DY@2>Lh2;F/27>L2;F/4AS42G_L2JeX2CW<2>Lh2=Jd2<H`00dHa;F/]J`02;F/2AS425:D29BT4CW<2
DY@2@Q02DY@4BU82?Nl2>Lh2Ool236<2@Q02?Nl2BU82>Lh2?Nl3AS42?Nl2AS42>Lh2CW<2=Jd2BU82
>Lh2AS42=Jd2Ool00`00Oomoo`06Ool000Moo`03001oofmk00]_N`I[FP9W>@03HaQNmekg009JeP9F
]@9BU09>L`9:DP96<@9>L`9BU08aS0@HaP8DY@8Q208YBP8]J`He[@8aS003;F/YBRU:00HU:@8Q208L
i`@HaP@DY@8HaP8Li`8YBP8aS08e[@8mk`9>L`9Nm`AJePUNm`AS60QW>@9[FP9oo`03001oogoo00]o
o`04001oodHaAS42@Q02BU82@Q02?Nl2>Lh2?Nl2>Lh2AS42>Lh00dYB@Q124002?Nl2>Lh2AS42>Lh2
CW<2<H`2F]H2>Lh2=Jd2>Lh2=Jd2AS426<H236<200022482E[D4Ool00dYB;F/]J`028@P2>Lh27>L2
;F/2>Lh4@Q02AS42BU82<H`2:DX40002Ool248@2F]H2<H`2>Lh2?Nl2<H`00dYB>LhicP04@Q02;F/2
@Q02=Jd2>Lh2?Nl2AS42@Q02Ool00`00Oomoo`06Ool000Moo`03001oofmk00]_N`I[FP9W>@03HaQN
mekg009JeP9F]@9BU09>L`9:DP96<@9>L`9BU08aS0@HaP8DY@8Q208YBP8]J`He[@8aS003;F/YBRU:
00HU:@8Q208Li`@HaP@DY@8HaP8Li`8YBP8aS08e[@8mk`9>L`9Nm`AJePUNm`AS60QW>@9[FP9oo`03
001oogoo00]oo`04001oodHaAS42@Q02BU82@Q02?Nl2>Lh2?Nl2>Lh2AS42>Lh00dYB@Q124002?Nl2
>Lh2AS42>Lh2CW<2<H`2F]H2>Lh2=Jd2>Lh2=Jd2AS426<H236<200022482E[D4Ool00dYB;F/]J`02
8@P2>Lh27>L2;F/2>Lh4@Q02AS42BU82<H`2:DX40002Ool248@2F]H2<H`2>Lh2?Nl2<H`00dYB>Lhi
cP04@Q02;F/2@Q02=Jd2>Lh2?Nl2AS42@Q02Ool00`00Oomoo`06Ool000Moo`03001oofmk00E_N`Q[
FP9_N`9[FP9W>@03HaQNmekg009JePABU0A>L`9:DP9>L`9BU08YBP8<H`8DY@8@Q08U:@8aS092409>
L`A6<@8e[@03;F/U:BDY00@Li`XHaP@DY@8Li`8U:@8aS092408icP8e[@9>L`9Nm`IJePMNm`AS60QW
>@9[FP9oo`03001oogoo00]oo`04001oocg_?Nl2>Lh2AS42=Jd2AS44@Q02?Nl2@Q02?Nl00dHa>Lhi
cP02AS44@Q02?Nl2AS42=Jd2CW<2>Lh2DY@2F]H2AS42CW<26<H2?Nl2HaP2BU82CW<2:DX20003AS46
DY@2@Q02CW<2AS42@Q02=Jd2AS42;F/2=Jd2>Lh2AS42Nmh248@2HaP2<H`2?Nl4@Q000cg_@Q124002
@Q02>Lh2BU82AS42@Q04AS42>Lh2?Nl2Ool00`00Oomoo`06Ool000Moo`03001oofmk00E_N`Q[FP9_
N`9[FP9W>@03HaQNmekg009JePABU0A>L`9:DP9>L`9BU08YBP8<H`8DY@8@Q08U:@8aS092409>L`A6
<@8e[@03;F/U:BDY00@Li`XHaP@DY@8Li`8U:@8aS092408icP8e[@9>L`9Nm`IJePMNm`AS60QW>@9[
FP9oo`03001oogoo00]oo`04001oocg_?Nl2>Lh2AS42=Jd2AS44@Q02?Nl2@Q02?Nl00dHa>LhicP02
AS44@Q02?Nl2AS42=Jd2CW<2>Lh2DY@2F]H2AS42CW<26<H2?Nl2HaP2BU82CW<2:DX20003AS46DY@2
@Q02CW<2AS42@Q02=Jd2AS42;F/2=Jd2>Lh2AS42Nmh248@2HaP2<H`2?Nl4@Q000cg_@Q124002@Q02
>Lh2BU82AS42@Q04AS42>Lh2?Nl2Ool00`00Oomoo`06Ool000Moo`04001oof]JJeX4Kg/<JeX2IcT0
0f<HG_MNm`02F]H2E[D2DY@4CW<2BU84CW<2<H`27>L2;F/2<H`2;F/2:DX4;F/29BT28@P29BT00bU:
8@PQ20028@P47>L48@P27>L26<H45:D27>L28@P2=Jd2AS42>Lh2=Jd2CW<2G_L7F]H6G_L6HaP2IcT2
JeX4IcT2Ool00`00Oomoo`0;Ool01000Oom>Ldic0SW>0Sg_148@0Sg_248@00<icSg_?Nl00SF]0THa
0S6<0T8@13g_0TYB0RDY0S6<0PQ20P000THa1Woo0THa0QBU0RU:0QBU00=:DTicCW<00Sg_0THa0SW>
0S6<0RDY0Sg_0S6<0THa0TYB0SF]17oo0Sg_0Woo0P000V<H0RU:0S6<14YB00<mkdHaAS400Sg_0T8@
0Sg_148@0S6<0SW>0THa0Sg_0Woo00<007ooOol01Woo0007Ool01000Oom[FV]J16mk26]J0VLi16]J
0f<H0Ukg0U[F0U:D2Tic0SW>0RU:0Sg_0THa0S6<0RDY0R480QcW0Q240PQ20QS600<U:B488@P00R48
11cW0RDY0RU:0R480QcW0QS60Q240QS60QcW0SW>0Tic0SW>0SF]0Tic0Ukg0UJe1e[F0Ukg26<H0VLi
0V]J16Li0Woo00<007ooOol02goo00@007ooBU9:DP8mk`96<@92408icP9:DP8icP96<@8e[@=24096
<@8mk`92409:DP8mk`8e[@8mk`9BU09:DP8HaP9JeP9_N`8YBP88@P8<H`8aS08e[@9>L`9g_@8e[@03
E[ES66<H0092409F]@8mk`@U:@9cW08]J`A2408]J`8Q2080009:DP9S608Q209[FP@aS092408mk`03
@Q0icSW>0092408mk`I2408e[@9>L`8aS08mk`9oo`03001oogoo00Ioo`001goo00@007ooJeY[FPA_
N`Q[FP9W>@A[FP=S609Nm`9JeP9BU0Y>L`8icP8YBP8mk`96<@8aS08U:@8Q208Li`8@Q088@P8HaP03
9BTQ2248008Q20@Li`8U:@8YBP8Q208Li`8HaP8@Q08HaP8Li`8icP9>L`8icP8e[@9>L`9Nm`9F]@MJ
eP9Nm`QS609W>@9[FPAW>@9oo`03001oogoo00]oo`04001oodYBBU82?Nl2AS42@Q02>Lh2BU82>Lh2
AS42=Jd3@Q02AS42?Nl2@Q02BU82?Nl2=Jd2?Nl2DY@2BU826<H2F]H2Kg/2:DX2248236<2<H`2=Jd2
CW<2Mkd2=Jd00eJeHaQS6002@Q02E[D2?Nl49BT2Li`2;F/4@Q02;F/28@P20002BU82HaP28@P2JeX4
<H`2@Q02?Nl00d8@>LhicP02@Q02?Nl6@Q02=Jd2CW<2<H`2?Nl2Ool00`00Oomoo`06Ool000Moo`04
001oof]JJeX2Kg/:JeX6IcT3HaP2F]H2E[D2DY@8CW<2DY@2?Nl4;F/2:DX27>L25:D47>L48@P2:DX0
0c6<=Jde[@04>Lh2?Nl2>Lh2<H`28@P45:D248@25:D26<H28@P2:DX2=Jd2?Nl2CW<9F]H4G_L8HaP2
IcT2JeX4IcT2Ool00`00Oomoo`0;Ool01000Oom6<DHa0SF]23g_0T8@0Sg_0SW>0dHa0Sg_0THa0Sg_
0THa0TYB0S6<0THa0UJe0SW>0W>L0WNm0U:D0Woo0P000T8@12DY0QS60QcW0P@Q00<Lib488@P00P00
0Q240SF]0W_N0Woo0TYB0Sg_0THa0TYB0Sg_0SW>0QBU0P000VLi0R480U[F0Re[0T8@0THa0TYB0cW>
148@0Sg_0T8@0TYB0Sg_0T8@0TYB0T8@0Woo00<007ooOol01Woo0007Ool01000Oom[FV]J0Vmk2V]J
1VLi0f<H0U[F0UJe0U:D24ic0U:D0Sg_12e[0RU:0QcW0QBU11cW12480RU:00<aS3F]=Jd013W>0Sg_
0SW>0S6<0R4811BU0Q240QBU0QS60R480RU:0SF]0Sg_0Tic2E[F15kg26<H0VLi0V]J16Li0Woo00<0
07ooOol02goo00@007ooAS56<@8e[@Pmk`92408mk`8icP=6<@8mk`96<@8mk`96<@9:DP8aS096<@9F
]@8icP9cW09g_@9BU09oo`80009240@U:@8HaP8Li`848@037>LQ22480080008@Q08e[@9kgP9oo`9:
DP8mk`96<@9:DP8mk`8icP8DY@80009W>@8Q209JeP8]J`924096<@9:DP<icPA2408mk`92409:DP8m
k`92409:DP92409oo`03001oogoo00Ioo`001goo00@007ooJeY[FP9_N`9[FP9W>@A[FPIW>@ES609J
eP9F]@9BU0I>L`ABU092408e[@8YBP8HaP8@Q088@P8DY@8Li`8U:@8YBP8aS003>Li2448@009:DP9B
U09F]@96<@8mk`8U:@8<H`8DY@X@Q08]J`96<@9>L`UJeP9Nm`YS60QW>@9oo`03001oogoo00]oo`04
001oodicCW<4?Nl6@Q02AS42@Q04?Nl00cF]@Q124002@Q02>Lh2BU82@Q02:DX2CW<2<H`2=Jd2F]H2
9BT20002HaP2AS42Kg/2AS42>Lh2;F/2AS42IcT00be[F]IJeP02E[D2@Q028@P2CW<200027>L2HaP2
@Q02DY@4@Q02DY@2G_L2AS42;F/2F]H2<H`2@Q04?Nl3@Q02?Nl2AS42>Lh2BU84=Jd2AS42?Nl2=Jd2
Ool00`00Oomoo`06Ool000Moo`04001oof]JJeX2Kg/2JeX2IcT4JeX6IcT5HaP2F]H2E[D2DY@6CW<4
DY@2@Q02=Jd2:DX26<H248@224825:D27>L29BT2:DX2<H`00cW>@Q124002BU82DY@2E[D2AS42?Nl2
9BT236<25:D:48@2;F/2AS42CW<9F]H2G_L:HaP8IcT2Ool00`00Oomoo`0;Ool01000Oom>Ldic13g_
1T8@0THa0T8@13g_00<e[D8@@Q000T8@0SW>0TYB0T8@0RU:0Tic0S6<0SF]0U[F0RDY0P000V<H0THa
0Vmk0THa0SW>0Re[0THa0VLi00<]Je[FF]H00UJe0T8@0R480Tic0P000QcW0V<H0T8@0U:D148@0U:D
0Ukg0THa0Re[0U[F0S6<0T8@13g_0d8@0Sg_0THa0SW>0TYB13F]0THa0Sg_0SF]0Woo00<007ooOol0
1Woo0007Ool01000Oom[FV]J0Vmk2V]J16Li1F<H0Ukg0U[F0UJe0Tic25:D0SW>0RDY12U:0RDY1248
0QcW12480S6<00<mkdHaAS400TYB0Sg_0SF]0RU:0R4812U:12DY0QS60PaS11BU0S6<0TYB0Tic25[F
0ekg26<H2VLi0Woo00<007ooOol02goo00@007ooAS56<@8mk`8e[@A2408mk`92408icP8mk`96<@03
@Q0mkcg_00I2408mk`8aS08mk`9>L`8U:@9oo`8@Q080008]J`80008@Q09[FP9oo`9cW09_N`9oo`03
HaQW>FLi009>L`8icPAoo`8Q208@Q08YBP8U:@80008YBP9BU0A2408mk`92409BU08icP8mk`8aS096
<@03=Je6<DHa0092408icP@mk`96<@A2408e[@96<@9oo`03001oogoo00Ioo`001goo00@007ooJeY[
FP9_N`Y[FPAW>@ES609Nm`9JeP9F]@9>L`QBU08icP8U:@@YBP8U:@@Q208Li`@Q208aS003?Nm6<DHa
009:DP8mk`8e[@8YBP8Q20@YBP@U:@8HaP8<H`@DY@8aS09:DP9>L`QJeP=Nm`QS60YW>@9oo`03001o
ogoo00]oo`04001oodHaAS42?Nl2=Jd4@Q02?Nl2@Q02>Lh2?Nl2AS400d8@?Nlmk`06@Q02?Nl2<H`2
?Nl2CW<29BT2Ool248@20002;F/2000248@2JeX2Ool2Li`2Kg/2Ool00f<HIcUW>@02CW<2>Lh4Ool2
8@P248@2:DX29BT20002:DX2DY@4@Q02?Nl2@Q02DY@2>Lh2?Nl2<H`2AS400cF]AS56<@02@Q02>Lh4
?Nl2AS44@Q02=Jd2AS42Ool00`00Oomoo`06Ool000Moo`04001oof]JJeX2Kg/:JeX4IcT5HaP2G_L2
F]H2E[D:DY@2<H`27>L2:DX4;F/2<H`29BT47>L26<H2=Jd00dHaBU9:DP02DY@2=Jd29BT26<H236<2
:DX2?Nl2=Jd2<H`27>L236<248@25:D2=Jd2CW<2DY@6F]H7G_L2HaP>IcT2Ool00`00Oomoo`0;Ool0
1000Oom>Ldic0SW>0T8@13g_0T8@0SW>0T8@0SW>0THa00<]Jd8@@Q000TYB0Sg_0T8@0TYB0SF]0T8@
0TYB0Re[0W_N0THa0P000Woo0U:D0VLi11cW136<0P0000=6<E[FF]H00QcW0S6<0QcW0SW>0Ukg0Q24
0V]J0U[F0Ukg0QcW0U[F0SF]0U:D0RDY0TYB0THa0SW>0Tic0T8@0SW>00=:DSW>>Lh01T8@0SW>0T8@
0Sg_0T8@0THa0SF]0Woo00<007ooOol01Woo0007Ool01000Oom[FV]J0Vmk2V]J16Li1F<H0Ukg0U[F
0UJe2U:D0S6<0QcW0RU:12e[0S6<0RDY11cW0QS60SF]00=6<DYBBU800U:D0SF]0RDY0QS60PaS0RU:
0Sg_0SF]0S6<0QcW0PaS0Q240QBU0SF]0Tic0U:D1U[F1ekg0V<H3VLi0Woo00<007ooOol02goo00@0
07ooCW=>L`8icP9240@mk`92408icP92408icP96<@03;F]2448@009:DP8mk`92409:DP8e[@92409:
DP8]J`9kgP96<@80009oo`9BU09W>@@Li`@aS0800003AS5JeU[F008Li`8aS08Li`8icP9Nm`8@Q09[
FP9JeP9Nm`8Li`9JeP8e[@9BU08U:@9:DP96<@8icP9>L`92408icP03BU8icSW>00I2408icP92408m
k`924096<@8e[@9oo`03001oogoo00Ioo`001goo00<007ooJeX02f]J1VLi1F<H0Ukg0U[F0UJe1U:D
14ic0T8@0SF]0SW>0Sg_0RU:0QcW0QS61QBU0R4800<]Jd8@@Q000UJe0SF]11cW0QS60SW>0Tic0T8@
0Sg_0Re[0RDY0QcW0QBU0SF]0TYB0Tic1U[F1Ekg16<H3VLi0Woo00<007ooOol02goo00@007ooBU9:
DP8mk`8icP96<@9240A6<@9:DP9>L`<mk`9:DP8mk`8aS0@mk`8]J`9>L`@icPA>L`8aS09[FP9oo`8L
i`8]J`A2408mk`8HaP0348Ag_GNm008YBP9:DP8U:@8YBP92408e[@9:DP9S609Nm`9_N`8aS08Li`92
408YBP96<@9>L`8]J`I24003?Nm6<DHa00A2409:DP8icPA2408icP96<@8mk`9oo`03001oogoo00Io
o`001goo00<007ooJeX02f]J1VLi1F<H0Ukg0U[F0UJe1U:D14ic0T8@0SF]0SW>0Sg_0RU:0QcW0QS6
1QBU0R4800<]Jd8@@Q000UJe0SF]11cW0QS60SW>0Tic0T8@0Sg_0Re[0RDY0QcW0QBU0SF]0TYB0Tic
1U[F1Ekg16<H3VLi0Woo00<007ooOol02goo00@007ooBU9:DP8mk`8icP96<@9240A6<@9:DP9>L`<m
k`9:DP8mk`8aS0@mk`8]J`9>L`@icPA>L`8aS09[FP9oo`8Li`8]J`A2408mk`8HaP0348Ag_GNm008Y
BP9:DP8U:@8YBP92408e[@9:DP9S609Nm`9_N`8aS08Li`92408YBP96<@9>L`8]J`I24003?Nm6<DHa
00A2409:DP8icPA2408icP96<@8mk`9oo`03001oogoo00Ioo`001goo00<007ooJeX01F]J16Li0V]J
16Li1f<H0Ukg0U[F0UJe15:D14ic14YB14Ha0TYB0RU:0Q240QBU1Q240QBU00<HaT8@@Q000Ukg0S6<
0QBU11cW0T8@0Ukg0Tic0TYB0Sg_0SF]0RDY0QS60SF]0TYB0Tic1U[F0ekg1V<H3VLi0Woo00<007oo
Ool02goo00@007ooBU9:DP8icP9:DP8e[@96<@8icP92408mk`8icP9240<mk`9:DP92409>L`92408a
S0A6<@92408icP8mk`8Li`8e[@8mk`924096<@IF]@8icP03BU9cW7>L008@Q09Nm`96<@8]J`8mk`9[
FP88@P@icP9:DP96<@9Nm`8aS08Q209F]@9:DP8mk`92408mk`9240Dmk`8icP8mk`96<@8icPHmk`8i
cP9oo`03001oogoo00Ioo`001goo00<007ooJeX01F]J16Li0V]J16Li1f<H0Ukg0U[F0UJe15:D14ic
14YB14Ha0TYB0RU:0Q240QBU1Q240QBU00<HaT8@@Q000Ukg0S6<0QBU11cW0T8@0Ukg0Tic0TYB0Sg_
0SF]0RDY0QS60SF]0TYB0Tic1U[F0ekg1V<H3VLi0Woo00<007ooOol02goo00@007ooBU9:DP8icP9:
DP8e[@96<@8icP92408mk`8icP9240<mk`9:DP92409>L`92408aS0A6<@92408icP8mk`8Li`8e[@8m
k`924096<@IF]@8icP03BU9cW7>L008@Q09Nm`96<@8]J`8mk`9[FP88@P@icP9:DP96<@9Nm`8aS08Q
209F]@9:DP8mk`92408mk`9240Dmk`8icP8mk`96<@8icPHmk`8icP9oo`03001oogoo00Ioo`001goo
00<007ooJeX01f]J26Li1f<H15kg0UJe1U:D0Tic14YB0THa0T8@0Sg_0R480PaS0R480RU:0RDY0RU:
0QcW00<HaSg_?Nl00UJe0Re[0QBU0Re[13F]0SW>0Re[0R480QcW0QS611cW0SW>14ic0UJe0U[F1Ekg
3V<H1VLi0Woo00<007ooOol02goo00@007ooAS56<@8e[@9:DP8icPA6<@@e[@8mk`9240<mk`I240Pm
k`96<@92409:DP9F]@8icP80009F]@8Li`8<H`8HaP848@8Q2003AS5[FV]J008YBP9F]@924080009J
eP9kgP9_N`8e[@848@8DY@8U:@8]J`9oo`88@PA2409:DP8aS0A24003AS4mkcg_009>L`92408e[@I6
<@9:DP8e[@92409oo`03001oogoo00Ioo`001goo00<007ooJeX01f]J26Li1f<H15kg0UJe1U:D0Tic
14YB0THa0T8@0Sg_0R480PaS0R480RU:0RDY0RU:0QcW00<HaSg_?Nl00UJe0Re[0QBU0Re[13F]0SW>
0Re[0R480QcW0QS611cW0SW>14ic0UJe0U[F1Ekg3V<H1VLi0Woo00<007ooOol02goo00@007ooAS56
<@8e[@9:DP8icPA6<@@e[@8mk`9240<mk`I240Pmk`96<@92409:DP9F]@8icP80009F]@8Li`8<H`8H
aP848@8Q2003AS5[FV]J008YBP9F]@924080009JeP9kgP9_N`8e[@848@8DY@8U:@8]J`9oo`88@PA2
409:DP8aS0A24003AS4mkcg_009>L`92408e[@I6<@9:DP8e[@92409oo`03001oogoo00Ioo`001goo
00<007ooJeX01f]J26Li2f<H0U[F1U:D0Tic0TYB14ic0T8@0SW>0QcW0P@Q0RDY0SW>0SF]0SW>0R48
00<@Q3W>>Lh00UJe0Re[0QBU0SF]0TYB0S6<0RDY0QBU0PQ210aS0QBU0QcW0Sg_0U:D0Tic0U:D0U[F
15kg3f<H1VLi0Woo00<007ooOol02goo00@007oo@Q124096<@8mk`I2408mk`92409>L`8icP03@Q16
<DHa0092408mk`8icP9:DPQ2408]J`8icP9Nm`9F]@88@P9kgP8DY@9S609oo`9:DP8<H`=F]@8U:@9[
FP96<@80009>L`9cW08@Q08aS09cW09F]@9Nm`8YBP8Li`9S608e[@9>L`8icPM2408e[@8mk`A6<@8i
cP92408e[@96<@92408mk`9oo`03001oogoo00Ioo`001goo00<007ooJeX01f]J26Li2f<H0U[F1U:D
0Tic0TYB14ic0T8@0SW>0QcW0P@Q0RDY0SW>0SF]0SW>0R4800<@Q3W>>Lh00UJe0Re[0QBU0SF]0TYB
0S6<0RDY0QBU0PQ210aS0QBU0QcW0Sg_0U:D0Tic0U:D0U[F15kg3f<H1VLi0Woo00<007ooOol02goo
00@007oo@Q124096<@8mk`I2408mk`92409>L`8icP03@Q16<DHa0092408mk`8icP9:DPQ2408]J`8i
cP9Nm`9F]@88@P9kgP8DY@9S609oo`9:DP8<H`=F]@8U:@9[FP96<@80009>L`9cW08@Q08aS09cW09F
]@9Nm`8YBP8Li`9S608e[@9>L`8icPM2408e[@8mk`A6<@8icP92408e[@96<@92408mk`9oo`03001o
ogoo00Ioo`001goo00@007ooIcUW>@I[FPQW>@ES60INm`9JeP9F]@9BU0A>L`A:DP96<@8icP8aS08U
:@8Li`8]J`@icP8mk`8U:@035:Dmkcg_009F]@8aS08Q208]J`8aS08Q208HaP8DY@H@Q0@DY@8e[@9:
DP9>L`9F]@9JePUNm`iS609W>@9oo`03001oogoo00]oo`03001oocg_00<mk`8icPA2408aS09>L`Tm
k`8e[@92408mk`@icPI2408DY@9>L`9cW08icP80009oo`80009oo`9cW09[FP800003BU9cW7>L008D
Y@9JeP8Li`9oo`9BU08Li`8YBP8e[@9F]@9:DPA6<@8aS09F]@92409>L`8aS0A2408icP03?NlicSW>
0092408icP92408e[@9:DP@e[@8mk`96<@9oo`03001oogoo00Ioo`001goo00@007ooIcUW>@I[FPQW
>@ES60INm`9JeP9F]@9BU0A>L`A:DP96<@8icP8aS08U:@8Li`8]J`@icP8mk`8U:@035:Dmkcg_009F
]@8aS08Q208]J`8aS08Q208HaP8DY@H@Q0@DY@8e[@9:DP9>L`9F]@9JePUNm`iS609W>@9oo`03001o
ogoo00]oo`03001oocg_00<mk`8icPA2408aS09>L`Tmk`8e[@92408mk`@icPI2408DY@9>L`9cW08i
cP80009oo`80009oo`9cW09[FP800003BU9cW7>L008DY@9JeP8Li`9oo`9BU08Li`8YBP8e[@9F]@9:
DPA6<@8aS09F]@92409>L`8aS0A2408icP03?NlicSW>0092408icP92408e[@9:DP@e[@8mk`96<@9o
o`03001oogoo00Ioo`001goo00@007ooIcUW>@A[FPiW>@03HaQNmekg009Nm`IJeP9BU0A>L`9:DP96
<@92408e[@8YBP@]J`8e[@8mk`92409:DP8YBP035:Dmkcg_009F]@8icP@YBP8U:@8HaPX<H`@@Q08a
S096<@9>L`9F]@9JeP]Nm`AS609W>@IS609W>@9oo`03001oogoo00]oo`04001oodicCW<2?Nl2>Lh2
@Q02?Nl2BU82?Nl6@Q000dic@Q124002=Jd2BU82AS46@Q02?Nl4@Q02<H`2Mkd2CW<21242Ool20002
JeX2@Q02=Jd200000f<HLiacW0027>L2CW<26<H2Ool22482@Q04E[D2AS42CW<6BU826<H2BU82DY@2
?Nl6@Q03AS42?Nl4@Q02AS42>Lh2@Q02AS42@Q02>Lh2Ool00`00Oomoo`06Ool000Moo`04001oofLi
IcT4JeX>IcT00f<HG_MNm`02G_L6F]H2DY@4CW<2BU82AS42@Q02=Jd2:DX4;F/2=Jd2?Nl2@Q02BU82
:DX00aBU?Nlmk`02E[D2>Lh4:DX29BT26<H:36<448@2<H`2AS42CW<2E[D2F]H;G_L4HaP2IcT6HaP2
IcT2Ool00`00Oomoo`0;Ool01000Oom>Ldic0Sg_0SW>0T8@0Sg_0TYB0Sg_1T8@00=>Ld8@@Q000SF]
0TYB0THa1T8@0Sg_148@0S6<0WNm0Tic0P@Q0Woo0P000V]J0T8@0SF]0P0000=S67>LLi`00QcW0Tic
0QS60Woo0PQ20T8@15Je0THa0Tic1TYB0QS60TYB0U:D0Sg_1T8@0dHa0Sg_148@0THa0SW>0T8@0THa
0T8@0SW>0Woo00<007ooOol01Woo0007Ool01000OomW>FLi1V]J1VLi1f<H15kg15[F0UJe15:D0Tic
0TYB14Ha0SW>0S6<0QcW0Q240S6<0T8@13W>0SF]00<]JdHaAS400U:D0SW>0Re[0R4811BU0Q240QcW
0RDY12480QBU0PaS0Re[0THa0TYB0UJe0U[F3Ekg36<H0Woo00<007ooOol02goo00@007ooAS56<@8e
[@96<@9240@mk`92408mk`8e[@8mk`<icP96<@8aS096<@8mk`9:DP@mk`96<@8]J`8e[@9Nm`8Q2088
@P9W>@80009JeP9cW09:DP800003E[EJeU[F008YBP8icP9JeP8Li`8e[@96<@92408DY@80008@Q08<
H`8icP9JeP80009S6092408YBPHmk`03>Li2448@0096<@8mk`8icP96<@A240@mk`8e[@9oo`03001o
ogoo00Ioo`001goo00@007ooIcUW>@I[FPIW>@MS60ANm`AJeP9F]@ABU09>L`9:DPA6<@8icP8aS08L
i`8@Q08aS09240@icP8e[@03;F]6<DHa009BU08icP8]J`8Q20@DY@8@Q08Li`8U:@@Q208DY@8<H`8]
J`96<@9:DP9F]@9JePeNm`aS609oo`03001oogoo00]oo`04001oodHaAS42=Jd2AS42@Q04?Nl2@Q02
?Nl2=Jd2?Nl3>Lh2AS42<H`2AS42?Nl2BU84?Nl2AS42;F/2=Jd2G_L28@P22482IcT20002F]H2Li`2
BU8200000eJeF]IJeP02:DX2>Lh2F]H27>L2=Jd2AS42@Q025:D2000248@236<2>Lh2F]H20002HaP2
@Q02:DX6?Nl00cW>@Q124002AS42?Nl2>Lh2AS44@Q04?Nl2=Jd2Ool00`00Oomoo`06Ool000Moo`04
001oofLiIcT8JeX4IcT7HaP4G_L2F]H4E[D4DY@2BU82AS44BU82?Nl2<H`25:D20002;F/2BU82>Lh2
<H`2?Nl00d8@BU9:DP02CW<2?Nl2<H`26<H2124448@29BT2<H`4;F/25:D21242:DX2@Q02BU84E[D=
G_L<HaP2Ool00`00Oomoo`0;Ool01000Oom6<DHa0SW>0T8@0SW>0T8@0SW>0TYB0Sg_0T8@0Sg_00=:
DT8@@Q000THa0T8@13g_0Tic0SW>0Sg_0THa0SF]0Sg_0Ukg0UJe0QBU0Woo0P000Tic0Woo0RDY0P00
00=JeT8@@Q000SW>0V]J0S6<0QS60W>L0Tic0THa0Re[0UJe0Woo0SF]0RU:0Vmk0P000V<H0U[F0Re[
0U:D13g_00=6<CW>>Lh00T8@0Sg_0THa248@13g_0Woo00<007ooOol01Woo0007Ool01000OomW>FLi
26]J16Li1f<H15kg0U[F15Je15:D0TYB0THa14YB0Sg_0S6<0QBU0P000Re[0TYB0SW>0S6<0Sg_00=2
44YBBU800Tic0Sg_0S6<0QS60P@Q11240RDY0S6<12e[0QBU0P@Q0RU:0T8@0TYB15Je3Ekg36<H0Woo
00<007ooOol02goo00@007ooAS56<@8icP92408icP92408icP9:DP8mk`92408mk`03BU92448@0096
<@9240@mk`9>L`8icP8mk`96<@8e[@8mk`9Nm`9F]@8DY@9oo`80009>L`9oo`8U:@800003F]I2448@
008icP9[FP8aS08HaP9cW09>L`96<@8]J`9F]@9oo`8e[@8YBP9_N`80009S609JeP8]J`9BU0@mk`03
AS4icSW>0092408mk`96<@Q240@mk`9oo`03001oogoo00Ioo`001goo00<007ooIcT01FLi0V]J1VLi
1f<H15kg0U[F15Je0U:D0Tic0TYB14Ha148@0Sg_0R480PaS0Re[0Sg_0S6<0Re[0S6<00<]Jd8@@Q00
0U:D0SF]12481QS60S6<0T8@0Re[0RDY0QS60PaS0Re[0T8@0THa0Tic0UJe2ekg3V<H0Woo00<007oo
Ool02goo00@007ooE[EF]@Hmk`96<@Hmk`8e[@9:DP03@Q0e[CF]008mk`96<@8icP8mk`92408icP8m
k`92408]J`9Nm`9JeP9>L`80009BU080009[FP9oo`96<@=oo`9>L`8DY@9oo`8DY@8Li`8Q208icP8Y
BP9JeP9F]@9oo`9:DP924096<@80009[FP9JeP9:DP9BU08e[@8icP03CW<mkcg_008icP8mk`@icP8m
k`8icP8mk`A2409oo`03001oogoo00Ioo`001goo00<007ooIcT01FLi0V]J1VLi1f<H15kg0U[F15Je
0U:D0Tic0TYB14Ha148@0Sg_0R480PaS0Re[0Sg_0S6<0Re[0S6<00<]Jd8@@Q000U:D0SF]12481QS6
0S6<0T8@0Re[0RDY0QS60PaS0Re[0T8@0THa0Tic0UJe2ekg3V<H0Woo00<007ooOol02goo00@007oo
E[EF]@Hmk`96<@Hmk`8e[@9:DP03@Q0e[CF]008mk`96<@8icP8mk`92408icP8mk`92408]J`9Nm`9J
eP9>L`80009BU080009[FP9oo`96<@=oo`9>L`8DY@9oo`8DY@8Li`8Q208icP8YBP9JeP9F]@9oo`9:
DP924096<@80009[FP9JeP9:DP9BU08e[@8icP03CW<mkcg_008icP8mk`@icP8mk`8icP8mk`A2409o
o`03001oogoo00Ioo`001goo00<007ooIcT03fLi0V<H2Ekg0UJe15:D0Tic0TYB0THa0T8@0Sg_14Ha
0RU:0QBU0Re[0SW>0Re[1BU:0T8@0U:D0Re[0QS60R480RDY0R480QcW0Sg_0U:D0SF]0RDY0QcW0QBU
0Re[0Sg_0T8@0TYB0U:D2ekg0V<H15kg26<H0Woo00<007ooOol02goo00@007oo=Jde[@8mk`8e[@96
<@8mk`8icP9:DP92408icP8mk`=6<@8icP92408mk`92409:DP92408icP96<@8e[@@mk`8e[@9:DP8m
k`8Li`9:DP9Nm`8YBP88@P035:ENmekg008Q209kgP8icP88@P9F]@9oo`8<H`9S6080009S6080009g
_@8icP80009F]@9[FP8HaP9BU08e[@9:DP03=Jdmkcg_00I6<@8icP9>L`A240@mk`9oo`03001oogoo
00Ioo`001goo00<007ooIcT03fLi0V<H2Ekg0UJe15:D0Tic0TYB0THa0T8@0Sg_14Ha0RU:0QBU0Re[
0SW>0Re[1BU:0T8@0U:D0Re[0QS60R480RDY0R480QcW0Sg_0U:D0SF]0RDY0QcW0QBU0Re[0Sg_0T8@
0TYB0U:D2ekg0V<H15kg26<H0Woo00<007ooOol02goo00@007oo=Jde[@8mk`8e[@96<@8mk`8icP9:
DP92408icP8mk`=6<@8icP92408mk`92409:DP92408icP96<@8e[@@mk`8e[@9:DP8mk`8Li`9:DP9N
m`8YBP88@P035:ENmekg008Q209kgP8icP88@P9F]@9oo`8<H`9S6080009S6080009g_@8icP80009F
]@9[FP8HaP9BU08e[@9:DP03=Jdmkcg_00I6<@8icP9>L`A240@mk`9oo`03001oogoo00Ioo`001goo
00<007ooHaP01F<H1VLi2F<H0Ukg15[F15Je0U:D0Tic0TYB14Ha0T8@0Sg_0SW>0RDY0QBU0QcW0R48
0QcW0QS60acW0SW>0Tic0RU:0QBU0Re[0SF]0RDY0QS60SF]0TYB0S6<0RDY0QcW0QBU0S6<14Ha0TYB
0U:D15[F3ekg0V<H15kg0Woo00<007ooOol02goo00@007ooDYABU0Q24096<@8aS09:DP8mk`96<@03
?NlicSW>00@mk`I240@mk`9>L`8]J`@icP9W>@8]J`9oo`9JeP8Q20@]J`8YBP03<H`e[CF]008icP9W
>@8aS080009_N`9cW08Li`9_N`8e[@8HaP8YBP9oo`8]J`8DY@9:DP9JeP88@P9>L`8e[@8icP=2408m
k`A6<@8aS092408e[@9:DP92408e[@9oo`03001oogoo00Ioo`001goo00<007ooHaP01F<H1VLi2F<H
0Ukg15[F15Je0U:D0Tic0TYB14Ha0T8@0Sg_0SW>0RDY0QBU0QcW0R480QcW0QS60acW0SW>0Tic0RU:
0QBU0Re[0SF]0RDY0QS60SF]0TYB0S6<0RDY0QcW0QBU0S6<14Ha0TYB0U:D15[F3ekg0V<H15kg0Woo
00<007ooOol02goo00@007ooDYABU0Q24096<@8aS09:DP8mk`96<@03?NlicSW>00@mk`I240@mk`9>
L`8]J`@icP9W>@8]J`9oo`9JeP8Q20@]J`8YBP03<H`e[CF]008icP9W>@8aS080009_N`9cW08Li`9_
N`8e[@8HaP8YBP9oo`8]J`8DY@9:DP9JeP88@P9>L`8e[@8icP=2408mk`A6<@8aS092408e[@9:DP92
408e[@9oo`03001oogoo00Ioo`001goo00@007ooG_MNm`IS60AW>@]S609JePIF]@9BU09>L`9:DP92
40A6<@8icP8aS08Q20@DY@8@Q0@<H`<@Q08aS09:DP8U:@8@Q08aS096<@8YBP8HaP8e[@96<@8aS08U
:@8Q208HaP8e[@9:DP96<@9:DP9BU0EJeQANm`9oo`03001oogoo00]oo`04001oodicCW<2>Lh2=Jd2
?Nl2DY@2;F/2BU82>Lh4@Q000cW>BU9:DP02?Nl2@Q02?Nl2>Lh2BU82>Lh2=Jd2AS44?Nl2HaP2@Q02
0002<H`2>Lh4E[D2HaP2CW<00e:DAS56<@02>Lh2CW<2E[D236<2>Lh2F]H28@P2JeX2>Lh20002Kg/2
IcT2:DX2;F/2?Nl2F]H2@Q02BU82>Lh2AS400d8@=Jde[@02BU82=Jd2BU82?Nl2AS42>Lh2?Nl2AS42
>Lh2Ool00`00Oomoo`06Ool000Moo`04001ooekgG_L6HaP4IcT;HaP2F]H6E[D2DY@2CW<2BU82@Q04
AS42>Lh2<H`28@P45:D248@436<348@2<H`2BU829BT248@2<H`2AS42:DX26<H2=Jd2AS42<H`29BT2
8@P26<H2=Jd2BU82AS42BU82DY@5F]HDG_L2Ool00`00Oomoo`0;Ool01000Oom>Ldic0SW>0SF]0Sg_
0U:D0Re[0TYB0SW>148@00<icTYBBU800Sg_0T8@0Sg_0SW>0TYB0SW>0SF]0THa13g_0V<H0T8@0P00
0S6<0SW>15Je0V<H0Tic00=BU4HaAS400SW>0Tic0UJe0PaS0SW>0U[F0R480V]J0SW>0P000Vmk0VLi
0RU:0Re[0Sg_0U[F0T8@0TYB0SW>0THa00=243F]=Jd00TYB0SF]0TYB0Sg_0THa0SW>0Sg_0THa0SW>
0Woo00<007ooOol01Woo0007Ool00`00OomNm`07G_L2HaP2IcT8HaP3G_L4F]H4E[D2DY@2CW<2AS46
@Q02;F/27>L26<H248@45:D27>L29BT27>L00aS6=Jde[@02BU829BT248@28@P2:DX27>L26<H2:DX2
=Jd4;F/28@P26<H2=Jd4AS42BU82DY@4F]HEG_L2Ool00`00Oomoo`0;Ool01000OomBU5:D0RU:0SW>
0Sg_0THa0Sg_14Ha0SW>0Sg_00=243g_?Nl00SF]0TYB0SW>0THa14YB1SW>0THa0WNm0PaS0QcW0Sg_
0S6<0SF]0QBU0P@Q0RDY00<aS5:DDY@00SF]0Tic0Sg_0Q240W_N0TYB0RU:0Woo0U[F0P000Woo0VLi
0QBU0W>L0SF]0U:D0Re[0THa148@00=6<Cg_?Nl0148@13W>0THa0TYB0SF]0THa0SW>0Woo00<007oo
Ool01Woo0007Ool00`00OomNm`07G_L2HaP2IcT8HaP3G_L4F]H4E[D2DY@2CW<2AS46@Q02;F/27>L2
6<H248@45:D27>L29BT27>L00aS6=Jde[@02BU829BT248@28@P2:DX27>L26<H2:DX2=Jd4;F/28@P2
6<H2=Jd4AS42BU82DY@4F]HEG_L2Ool00`00Oomoo`0;Ool01000OomBU5:D0RU:0SW>0Sg_0THa0Sg_
14Ha0SW>0Sg_00=243g_?Nl00SF]0TYB0SW>0THa14YB1SW>0THa0WNm0PaS0QcW0Sg_0S6<0SF]0QBU
0P@Q0RDY00<aS5:DDY@00SF]0Tic0Sg_0Q240W_N0TYB0RU:0Woo0U[F0P000Woo0VLi0QBU0W>L0SF]
0U:D0Re[0THa148@00=6<Cg_?Nl0148@13W>0THa0TYB0SF]0THa0SW>0Woo00<007ooOol01Woo0007
Ool00`00OomNm`05G_L2F]H2HaP2IcT8HaP3G_L4F]H4E[D2DY@2CW<2AS44@Q02?Nl28@P636<248@2
6<H2:DX2=Jd29BT00acW>LhicP02BU82:DX25:D26<H25:D46<H28@P2:DX2;F/2=Jd29BT27>L2=Jd4
AS42BU82DY@4F]H00ekgF]IJeP06F]H6G_L2HaP4G_L2Ool00`00Oomoo`0;Ool01000Oom>Ldic0Sg_
0Tic13g_148@0Sg_0SW>1D8@0SW>0T8@0Sg_0SW>0THa0S6<0T8@0TYB0QcW0Sg_0WNm0Sg_0T8@0U[F
0SF]14Ha0U:D0V]J00<YBV]JJeX00QBU0WNm0SF]0RU:13g_0RDY0Woo0QcW0P000WNm0R480U[F0U:D
0Re[0UJe0SF]0SW>0Sg_0T8@00<icSg_?Nl00T8@0SW>0TYB1Sg_0THa13W>0Woo00<007ooOol01Woo
0007Ool00`00OomNm`05G_L2F]H2HaP2IcT8HaP3G_L4F]H4E[D2DY@2CW<2AS44@Q02?Nl28@P636<2
48@26<H2:DX2=Jd29BT00acW>LhicP02BU82:DX25:D26<H25:D46<H28@P2:DX2;F/2=Jd29BT27>L2
=Jd4AS42BU82DY@4F]H00ekgF]IJeP06F]H6G_L2HaP4G_L2Ool00`00Oomoo`0;Ool01000Oom>Ldic
0Sg_0Tic13g_148@0Sg_0SW>1D8@0SW>0T8@0Sg_0SW>0THa0S6<0T8@0TYB0QcW0Sg_0WNm0Sg_0T8@
0U[F0SF]14Ha0U:D0V]J00<YBV]JJeX00QBU0WNm0SF]0RU:13g_0RDY0Woo0QcW0P000WNm0R480U[F
0U:D0Re[0UJe0SF]0SW>0Sg_0T8@00<icSg_?Nl00T8@0SW>0TYB1Sg_0THa13W>0Woo00<007ooOol0
1Woo0007Ool00`00OomS6003HaP4G_L2HaP2IcT6HaP3G_L6F]H4E[D2CW<2BU82AS42@Q04?Nl29BT2
5:D47>L2<H`2?Nl7>Lh2@Q02BU82<H`49BT28@P27>L25:D28@P2:DX2>Lh2AS42?Nl2>Lh2AS42BU84
AS42DY@;F]H>G_L2Ool00`00Oomoo`0;Ool01000Oom6<DHa0Sg_0Re[0T8@0SW>0T8@13g_0T8@0THa
1D8@14Ha0T8@14YB0Sg_0TYB0SW>0RU:0Tic0R480Q240SF]0U[F0S6<15kg0P@Q00=:DTHaAS400QcW
0W_N0PQ20Q240PaS0QS60RU:0Woo10000SW>0P000V<H0Sg_0QBU0TYB0SW>0Tic0SW>0dHa148@0Sg_
0T8@0SW>0THa148@0Sg_0T8@0Woo00<007ooOol01Woo0007Ool00`00OomS6003HaP4G_L2HaP2IcT6
HaP3G_L6F]H4E[D2CW<2BU82AS42@Q04?Nl29BT25:D47>L2<H`2?Nl7>Lh2@Q02BU82<H`49BT28@P2
7>L25:D28@P2:DX2>Lh2AS42?Nl2>Lh2AS42BU84AS42DY@;F]H>G_L2Ool00`00Oomoo`0;Ool01000
Oom6<DHa0Sg_0Re[0T8@0SW>0T8@13g_0T8@0THa1D8@14Ha0T8@14YB0Sg_0TYB0SW>0RU:0Tic0R48
0Q240SF]0U[F0S6<15kg0P@Q00=:DTHaAS400QcW0W_N0PQ20Q240PaS0QS60RU:0Woo10000SW>0P00
0V<H0Sg_0QBU0TYB0SW>0Tic0SW>0dHa148@0Sg_0T8@0SW>0THa148@0Sg_0T8@0Woo00<007ooOol0
1Woo0007Ool01000OomS66<H0VLi0V<H0Ukg0V<H0VLi16<H1Ekg15[F1UJe0Tic0TYB0THa0T8@13g_
0RDY0QBU0R480RU:0THa0U[F0TYB0T8@0dYB14ic0Sg_12e[0RDY0QcW0QBU0QcW0RDY0Sg_0U:D0Tic
0U:D14ic0THa0T8@0Tic15Je1e[F3Ukg0Woo00<007ooOol02goo00@007ooAS56<@8mk`8icP96<@@m
k`96<@8icP96<@<icP924096<@92408]J`A2408icP8YBPA6<@9:DP8YBP9F]@8<H`9F]@92408000@U
:@8mk`03<H`]Jbe[008U:@9kgP8HaP80008aS08Li`8icP9oo`8@Q09oo`8U:@9BU08icP8mk`96<@9B
U08aS096<@8mk`8icP03@Q0icSW>0092408mk`96<@8icP92409>L`8mk`8icP92409oo`03001oogoo
00Ioo`001goo00@007ooHaQS609W>@9S609Nm`IS60INm`EJePAF]@ABU09>L`9:DPI6<@92408mk`96
<@9:DP9JeP9W>@9Nm`9F]@9BU003CW=BU5:D009BU09>L`9:DPA>L`8e[@8U:@92409BU09F]@9JeP9B
U09:DPA>L`9:DP96<@9BU0AF]@MJePiNm`9oo`03001oogoo00]oo`04001oodHaAS42BU82AS42BU82
?Nl2@Q02BU8;@Q02=Jd2?Nl2@Q02BU82AS42<H`2AS42?Nl2DY@2Kg/2Ool25:D2JeX6Ool2CW<2F]H0
0gNmG_MNm`02HaP8Ool2<H`2=Jd200022482Ool2E[D2IcT2JeX2F]H2DY@2G_L2:DX2F]H4=Jd00dHa
@Q124002AS42>Lh2@Q02>Lh4@Q02<H`2?Nl2@Q02Ool00`00Oomoo`06Ool000Moo`04001oof<HHaP2
IcT2HaP2G_L6HaP6G_L5F]H4E[D4DY@2CW<2BU86AS42@Q02?Nl2AS42BU82F]H2IcT2G_L2E[D2DY@0
0dicDYABU002DY@2CW<2BU84CW<2=Jd29BT2@Q02DY@2E[D2F]H2DY@2BU84CW<2BU82AS42DY@4E[D7
F]H>G_L2Ool00`00Oomoo`0;Ool01000Oom6<DHa0TYB0THa0TYB0Sg_0T8@0TYB2d8@0SF]0Sg_0T8@
0TYB0THa0S6<0THa0Sg_0U:D0Vmk0Woo0QBU0V]J1Woo0Tic0U[F00=g_EkgG_L00V<H27oo0S6<0SF]
0P000PQ20Woo0UJe0VLi0V]J0U[F0U:D0Ukg0RU:0U[F13F]00=6<D8@@Q000THa0SW>0T8@0SW>148@
0S6<0Sg_0T8@0Woo00<007ooOol01Woo0007Ool01000OomS66<H0VLi26<H1Ukg1E[F1UJe1U:D0Tic
0TYB14ic0UJe0U[F0Ukg0V<H0Vmk0W_N0Vmk0V]J0V<H00=F]E[FF]H00UJe0Ukg0V<H0VLi0Vmk0THa
0Re[0U[F0WNm0VLi0V<H0UJe0Tic15:D0Tic0TYB0U:D1EJe25[F35kg0Woo00<007ooOol02goo00@0
07oo@Q12408icP8aS08mk`96<@92408e[@I24003?Nm2448@008mk`96<@A2408aS09:DP8e[@9:DP92
408mk`8aS08Q208DY@92408<H`80008icP8aS08HaP03=JdU:BDY008aS08YBP8DY@@0008aS09oo`80
009oo`9W>@88@P8aS08U:@@mk`8DY@9JeP9:DP8mk`=2408mk`92408icP9:DP8mk`92408mk`A6<@8m
k`9oo`03001oogoo00Ioo`001goo00@007ooHaQS609W>@QS60INm`EJePIF]@IBU09>L`9:DPA>L`9F
]@9JeP9Nm`9S609_N`9kgP9_N`9[FP9S6003E[EJeU[F009F]@9Nm`9S609W>@9_N`96<@8]J`9JeP9g
_@9W>@9S609F]@9>L`ABU09>L`9:DP9BU0EF]@QJePaNm`9oo`03001oogoo00]oo`04001ood8@@Q02
>Lh2<H`2?Nl2AS42@Q02=Jd6@Q000cg_@Q124002?Nl2AS44@Q02<H`2BU82=Jd2BU82@Q02?Nl2<H`2
8@P25:D2@Q0236<20002>Lh2<H`26<H00cF]9BTU:@02<H`2:DX25:D40002<H`2Ool20002Ool2IcT2
2482<H`29BT4?Nl25:D2F]H2BU82?Nl3@Q02?Nl2@Q02>Lh2BU82?Nl2@Q02?Nl4AS42?Nl2Ool00`00
Oomoo`06Ool000Moo`04001ooekgG_L2HaP4G_L4HaP6G_L5F]H6E[D4DY@2CW<2BU86AS44BU82E[D4
F]H2E[D4DY@;CW<2DY@2E[D2?Nl2;F/2BU82G_L4DY@2CW<6BU84CW<2DY@4E[D;F]H2G_L4F]H4G_L2
Ool00`00Oomoo`0;Ool01000Oom2448@0SF]0THa0T8@0SF]23g_0T8@00<icSg_?Nl00Sg_0THa0TYB
0T8@0SW>0T8@0Sg_0T8@0SF]0Re[0SF]0Tic0THa0V<H0R480QcW0RU:0SF]0cW>0Sg_0T8@0R480T8@
0SF]0S6<17oo0P000Woo0THa0SF]0SW>0SF]0SW>0T8@0R480TYB0T8@0Sg_0cW>0T8@1SW>0THa0T8@
14Ha0T8@0Sg_0Woo00<007ooOol01Woo0007Ool01000OomNmekg0V<H15kg16<H1Ukg1E[F1UJe15:D
0Tic0TYB1THa14YB0UJe15[F0UJe15:D2dic0U:D0UJe0Sg_0Re[0TYB0Ukg15:D0Tic1TYB14ic0U:D
15Je2e[F0Ukg15[F15kg0Woo00<007ooOol02goo00@007oo@Q12408e[@96<@92408e[@Pmk`924003
>Lhmkcg_008mk`96<@9:DP92408icP92408mk`92408e[@8]J`8e[@9>L`96<@9S608Q208Li`8YBP8e
[@<icP8mk`92408Q2092408e[@8aS0Aoo`80009oo`96<@8e[@8icP8e[@8icP92408Q209:DP92408m
k`<icP9240HicP96<@9240A6<@92408mk`9oo`03001oogoo00Ioo`001goo00<007ooG_L02Ekg0V<H
0Ukg2E[F1UJe15:D0Tic0TYB14Ha0T8@14Ha0U:D0Ukg0Tic14Ha0T8@0THa1DYB14Ha0TYB0Tic0Sg_
0S6<0THa0U:D2TYB0THa0Tic15:D0UJe4e[F15kg0Woo00<007ooOol02goo00@007ooAS56<@8icP8m
k`8icP9>L`8mk`A24096<@8mk`03AS52448@008icP92408mk`92408icP924096<@A2409BU08mk`9>
L`8Q2096<@9:DP9JeP9:DP96<@9BU003>Lhmkcg_00Q6<@8icP9cW096<@80009[FP8icP9:DP96<@9:
DP8e[@9F]@8aS09:DP9>L`92408e[@03BU92448@0096<@8mk`96<@Hmk`8icP96<@92409oo`03001o
ogoo00Ioo`001goo00<007ooG_L02Ekg0V<H0Ukg2E[F1UJe15:D0Tic0TYB14Ha0T8@14Ha0U:D0Ukg
0Tic14Ha0T8@0THa1DYB14Ha0TYB0Tic0Sg_0S6<0THa0U:D2TYB0THa0Tic15:D0UJe4e[F15kg0Woo
00<007ooOol02goo00@007ooAS56<@8icP8mk`8icP9>L`8mk`A24096<@8mk`03AS52448@008icP92
408mk`92408icP924096<@A2409BU08mk`9>L`8Q2096<@9:DP9JeP9:DP96<@9BU003>Lhmkcg_00Q6
<@8icP9cW096<@80009[FP8icP9:DP96<@9:DP8e[@9F]@8aS09:DP9>L`92408e[@03BU92448@0096
<@8mk`96<@Hmk`8icP96<@92409oo`03001oogoo00Ioo`001goo00<007ooG_L03ekg2E[F15Je1U:D
0TYB0THa1T8@0THa24YB3dHa0TYB0Tic0S6<0R480SF]0Sg_0THa0Tic24YB0Tic15:D15Je00=JeUJe
E[D00UJe45[F0Woo00<007ooOol02goo00@007ooCW=>L`92408mk`9:DP92408mk`92408mk`8e[@8m
k`03AS4icSW>00A2408mk`92408icPA240@icP9240@icP8]J`8e[@8mk`92408icP8mk`8e[@03AS52
448@0092408icP924096<@8Q209oo`96<@800092409S608U:@96<@92408icPI240@mk`8icP=6<@8e
[@8mk`A240Hmk`@e[@9oo`03001oogoo00Ioo`001goo00<007ooG_L03ekg2E[F15Je1U:D0TYB0THa
1T8@0THa24YB3dHa0TYB0Tic0S6<0R480SF]0Sg_0THa0Tic24YB0Tic15:D15Je00=JeUJeE[D00UJe
45[F0Woo00<007ooOol02goo00@007ooCW=>L`92408mk`9:DP92408mk`92408mk`8e[@8mk`03AS4i
cSW>00A2408mk`92408icPA240@icP9240@icP8]J`8e[@8mk`92408icP8mk`8e[@03AS52448@0092
408icP924096<@8Q209oo`96<@800092409S608U:@96<@92408icPI240@mk`8icP=6<@8e[@8mk`A2
40Hmk`@e[@9oo`03001oogoo00Ioo`001goo00<007ooG_L02Ekg0U[F15kg2E[F15Je1U:D0TYB0THa
0T8@0Sg_1T8@0Sg_0T8@14Ha2D8@1THa0TYB0RU:0QBU0RDY0RU:0Sg_0Tic14Ha14YB0Tic15:D3EJe
35[F0Woo00<007ooOol02goo00@007oo@Q12408icP8mk`8icP9:DP8e[@A2408mk`924003>Li2448@
00A2408mk`9240@mk`9>L`8icP8e[@92408aS0924096<@9240@mk`A24096<@<mk`9:DP924096<@8m
k`8icP9oo`96<@88@P9oo`9[FP8]J`8e[@92409:DP8mk`92408icP924096<@8icPE2408icP924096
<@8icP9:DP8icP9:DP96<@9oo`03001oogoo00Ioo`001goo00<007ooG_L02Ekg0U[F15kg2E[F15Je
1U:D0TYB0THa0T8@0Sg_1T8@0Sg_0T8@14Ha2D8@1THa0TYB0RU:0QBU0RDY0RU:0Sg_0Tic14Ha14YB
0Tic15:D3EJe35[F0Woo00<007ooOol02goo00@007oo@Q12408icP8mk`8icP9:DP8e[@A2408mk`92
4003>Li2448@00A2408mk`9240@mk`9>L`8icP8e[@92408aS0924096<@9240@mk`A24096<@<mk`9:
DP924096<@8mk`8icP9oo`96<@88@P9oo`9[FP8]J`8e[@92409:DP8mk`92408icP924096<@8icPE2
408icP924096<@8icP9:DP8icP9:DP96<@9oo`03001oogoo00Ioo`001goo00<007ooF]H00e[F1Ukg
15[F0Ukg1e[F1UJe15:D0Tic0TYB0THa0Sg_2SF]1SW>13g_1d8@0THa14YB0SF]0RU:0S6<0SF]0SW>
0Sg_0SW>13F]0SW>0THa15:D3eJe2U[F0Woo00<007ooOol02goo00@007ooAS56<@8icP92408mk`8i
cP9:DPA2408mk`9>L`=6<@8e[@9:DP8mk`96<@8aS0A:DP96<@9>L`AJeP9Nm`9S609JeP9:DP9F]@9B
U092408mk`<icP8aS08YBP8]J`8Q208U:@9F]@@0008aS09>L`8icP92409:DP8aS08icP9F]@8mk`96
<@8e[@96<@03<H`mkcg_00A2408mk`8icP96<@8mk`92408icP8aS09oo`03001oogoo00Ioo`001goo
00<007ooF]H00e[F1Ukg15[F0Ukg1e[F1UJe15:D0Tic0TYB0THa0Sg_2SF]1SW>13g_1d8@0THa14YB
0SF]0RU:0S6<0SF]0SW>0Sg_0SW>13F]0SW>0THa15:D3eJe2U[F0Woo00<007ooOol02goo00@007oo
AS56<@8icP92408mk`8icP9:DPA2408mk`9>L`=6<@8e[@9:DP8mk`96<@8aS0A:DP96<@9>L`AJeP9N
m`9S609JeP9:DP9F]@9BU092408mk`<icP8aS08YBP8]J`8Q208U:@9F]@@0008aS09>L`8icP92409:
DP8aS08icP9F]@8mk`96<@8e[@96<@03<H`mkcg_00A2408mk`8icP96<@8mk`92408icP8aS09oo`03
001oogoo00Ioo`001goo00<007ooF]H01E[F0Ukg35[F2EJe0U:D14ic0TYB0THa0SW>2Re[136<13F]
0SW>1Cg_0T8@0THa14YB0Sg_23F]0S6<0Re[0RDY12U:0T8@15:D2EJe15:D0UJe0U[F0UJe1U[F0Woo
00<007ooOol02goo00@007ooBU9:DP92408icP96<@92408mk`8aS0924096<@8e[@03>Li2448@008i
cP96<@92408icP96<@8e[@9>L`8mk`8icP9BU08e[@9BU09>L`96<@9BU096<@9>L`92409:DP<mk`9B
U08mk`9:DP8]J`8icP9JeP9F]@9>L`9F]@8mk`A24096<@92409:DP92408e[@9:DP8icP9:DP03@Q0m
kcg_0096<@8e[@9:DP8mk`92408mk`924096<@92409oo`03001oogoo00Ioo`001goo00<007ooF]H0
1E[F0Ukg35[F2EJe0U:D14ic0TYB0THa0SW>2Re[136<13F]0SW>1Cg_0T8@0THa14YB0Sg_23F]0S6<
0Re[0RDY12U:0T8@15:D2EJe15:D0UJe0U[F0UJe1U[F0Woo00<007ooOol02goo00@007ooBU9:DP92
408icP96<@92408mk`8aS0924096<@8e[@03>Li2448@008icP96<@92408icP96<@8e[@9>L`8mk`8i
cP9BU08e[@9BU09>L`96<@9BU096<@9>L`92409:DP<mk`9BU08mk`9:DP8]J`8icP9JeP9F]@9>L`9F
]@8mk`A24096<@92409:DP92408e[@9:DP8icP9:DP03@Q0mkcg_0096<@8e[@9:DP8mk`92408mk`92
4096<@92409oo`03001oogoo00Ioo`001goo00@007ooG_MNm`QS60INm`EJePAF]@ABU0I>L`96<@8m
k`8e[@8aS0He[@8icP8mk`A24096<@<mk`A240@mk`96<@9:DPA6<@Q240Pmk`9:DPIBU0eF]@YJeP9o
o`03001oogoo00]oo`04001ooc6<<H`25:D27>L2:DX2;F/4<H`2>Lh2@Q02=Jd00d8@>LhicP02@Q02
?Nl2CW<4BU82>Lh2E[D28@P2000212460002248236<200026<H27>L2>Lh00cg_AS56<@02=Jd2F]H2
IcT2G_L2Li`2Kg/2HaP6E[D2?Nl2>Lh28@P2<H`2>Lh2=Jd2?Nl2>Lh2?Nl2>Lh00cg_>LhicP02?Nl2
<H`4@Q02?Nl4>Lh2=Jd2?Nl2Ool00`00Oomoo`06Ool000Moo`04001ooekgG_L8HaP6G_L5F]H4E[D4
DY@6CW<2AS42?Nl2=Jd2<H`6=Jd2>Lh2?Nl4@Q02AS43?Nl4@Q04?Nl2AS42BU84AS48@Q08?Nl2BU86
DY@=E[D:F]H2Ool00`00Oomoo`0;Ool01000OolaS36<0QBU0QcW0RU:0Re[136<0SW>0T8@0SF]00=2
43W>>Lh00T8@0Sg_0Tic14YB0SW>0UJe0R480P000P@Q1P000PQ20PaS0P000QS60QcW0SW>00<mkdHa
AS400SF]0U[F0VLi0Ukg0W>L0Vmk0V<H1UJe0Sg_0SW>0R480S6<0SW>0SF]0Sg_0SW>0Sg_0SW>00<m
kcW>>Lh00Sg_0S6<148@0Sg_13W>0SF]0Sg_0Woo00<007ooOol01Woo0007Ool01000OomS66<H0V]J
16Li1V<H15kg0e[F0UJe15:D0Tic0TYB14ic0THa0Sg_0SF]0Re[0SF]13W>0Sg_0THa14YB0Tic0T8@
00<icT8@@Q000THa0Sg_0SW>0T8@0THa0Tic0U:D0Tic14YB0THa24YB0Tic1U:D1EJe0U:D25Je25[F
0Woo00<007ooOol02goo00@007oo:DXYBP8@Q08U:@8DY@8Li`8Q208U:@8Q208]J`8aS003:DXicSW>
00924096<@A>L`8icP8mk`9Nm`8aS08mk`9JeP9>L`9F]@9g_@9W>@9oo`9W>@9JeP96<@8YBP039BUg
_GNm008YBP9F]@8icP8000A>L`@]J`A2409>L`A240A>L`9:DP8mk`92408icP9240<icPHmk`8e[@8m
k`9240@icP8aS09oo`03001oogoo00Ioo`001goo00@007ooHaQS609[FPAW>@IS60ANm`=JeP9F]@AB
U09>L`9:DPA>L`96<@8mk`8e[@8]J`8e[@@icP8mk`96<@A:DP9>L`924003>Li2448@0096<@8mk`8i
cP924096<@9>L`9BU09>L`A:DP96<@Q:DP9>L`IBU0EF]@9BU0QF]@QJeP9oo`03001oogoo00]oo`04
001oobU::DX248@29BT25:D27>L28@P29BT28@P2;F/2<H`00bU:>LhicP02@Q02AS44CW<2>Lh2?Nl2
G_L2<H`2?Nl2F]H2CW<2E[D2Mkd2IcT2Ool2IcT2F]H2AS42:DX00bDYMkeg_@02:DX2E[D2>Lh20004
CW<4;F/4@Q02CW<4@Q04CW<2BU82?Nl2@Q02>Lh2@Q03>Lh6?Nl2=Jd2?Nl2@Q04>Lh2<H`2Ool00`00
Oomoo`06Ool000Moo`03001oogoo07ioo`03001oogoo00]oo`03001oogoo07ioo`03001oogoo00Io
o`001gooPP003GooPP0027oo003oOolQOol00?moob5oo`00ogoo8Goo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {136.125, 0}} -> {-0.0541876, -0.0238146, 
  0.00734626, 0.00734626}, {{7.375, 137}, {132.875, 
  3.1875}} -> {-5.13894, -3.03279, 0.51448, 0.51448}, {{149.938, 279.625}, {
  132.875, 3.1875}} -> {-78.4472, -3.01587, 0.514232, 0.514232}}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"Microsoft Windows 3.0",
ScreenRectangle->{{0, 1280}, {0, 968}},
WindowToolbars->"EditBar",
CellGrouping->Manual,
WindowSize->{484, 580},
WindowMargins->{{367, Automatic}, {Automatic, 11}},
PrintingCopies->1,
PrintingPageRange->{Automatic, Automatic},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, -1}},
ShowCellLabel->True,
ShowCellTags->False,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False},
StyleDefinitions -> "ArticleClassic.nb"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "D4"->{
    Cell[204357, 6346, 472, 14, 71, "Text",
      CellTags->"D4"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"D4", 715400, 19706}
  }
*)

(*NotebookFileOutline
Notebook[{
Cell[1709, 49, 43, 0, 111, "Title"],
Cell[1755, 51, 35, 0, 41, "Author"],
Cell[1793, 53, 112, 4, 55, "Address"],
Cell[1908, 59, 77, 2, 31, "Input"],
Cell[1988, 63, 72, 2, 31, "Input"],

Cell[CellGroupData[{
Cell[2085, 69, 31, 0, 56, "Section"],
Cell[2119, 71, 604, 9, 129, "Text"],
Cell[2726, 82, 55027, 1549, 158, 15610, 1058, "GraphicsData", 
"PostScript", "NumberedFigure"],
Cell[57756, 1633, 296, 7, 61, "Text"],
Cell[58055, 1642, 141, 4, 27, "NumberedEquation"],
Cell[58199, 1648, 664, 19, 78, "Text"],
Cell[58866, 1669, 386, 12, 40, "NumberedEquation"],
Cell[59255, 1683, 140, 5, 27, "Text"],
Cell[59398, 1690, 182, 6, 27, "NumberedEquation"],
Cell[59583, 1698, 484, 14, 44, "Text"],

Cell[CellGroupData[{
Cell[60092, 1716, 29, 0, 25, "Exercise"],
Cell[60124, 1718, 423, 9, 59, "ExerciseText"],
Cell[60550, 1729, 28945, 648, 213, 5082, 349, "GraphicsData", 
"PostScript", "NumberedFigure"]
}, Open  ]],
Cell[89510, 2380, 126, 3, 44, "Text"],
Cell[89639, 2385, 195, 7, 28, "NumberedEquation"],
Cell[89837, 2394, 964, 23, 148, "Text"],
Cell[90804, 2419, 179, 6, 28, "Text"],
Cell[90986, 2427, 429, 15, 78, "Text"],
Cell[91418, 2444, 64738, 2151, 391, 24935, 1655, "GraphicsData", 
"PostScript", "NumberedFigure"],
Cell[156159, 4597, 1147, 23, 197, "Text"],
Cell[157309, 4622, 377, 10, 32, "NumberedEquation"]
}, Open  ]],

Cell[CellGroupData[{
Cell[157723, 4637, 48, 0, 56, "Section"],
Cell[157774, 4639, 477, 14, 61, "Text"],
Cell[158254, 4655, 277, 8, 28, "NumberedEquation"],
Cell[158534, 4665, 179, 5, 27, "Text"],
Cell[158716, 4672, 267, 8, 28, "NumberedEquation"],
Cell[158986, 4682, 424, 9, 78, "Text"],
Cell[159413, 4693, 217, 6, 27, "NumberedEquation"],
Cell[159633, 4701, 702, 22, 78, "Text"],
Cell[160338, 4725, 200, 4, 91, "Input"],
Cell[160541, 4731, 186, 5, 44, "Text"],

Cell[CellGroupData[{
Cell[160752, 4740, 427, 8, 151, "Input"],
Cell[161182, 4750, 17076, 545, 186, 5910, 402, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],
Cell[178273, 5298, 660, 14, 112, "Text"],
Cell[178936, 5314, 106, 2, 51, "Input"],
Cell[179045, 5318, 311, 8, 44, "Text"],
Cell[179359, 5328, 307, 7, 97, "Input"],
Cell[179669, 5337, 601, 20, 70, "Text"],

Cell[CellGroupData[{
Cell[180295, 5361, 77, 1, 43, "Input"],
Cell[180375, 5364, 150, 2, 52, "Output"]
}, Open  ]],
Cell[180540, 5369, 91, 2, 27, "Text"],

Cell[CellGroupData[{
Cell[180656, 5375, 77, 1, 43, "Input"],
Cell[180736, 5378, 669, 13, 281, "Output"]
}, Open  ]],
Cell[181420, 5394, 141, 5, 27, "Text"],

Cell[CellGroupData[{
Cell[181586, 5403, 293, 6, 119, "Input"],
Cell[181882, 5411, 20152, 848, 93, 10416, 723, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],
Cell[202049, 6262, 104, 3, 27, "Text"],

Cell[CellGroupData[{
Cell[202178, 6269, 221, 3, 98, "Input"],
Cell[202402, 6274, 35, 1, 30, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[202486, 6281, 51, 0, 56, "Section"],
Cell[202540, 6283, 630, 13, 163, "Text"],

Cell[CellGroupData[{
Cell[203195, 6300, 45, 0, 25, "Definition"],
Cell[203243, 6302, 97, 2, 51, "NumberedEquation"]
}, Open  ]],

Cell[CellGroupData[{
Cell[203377, 6309, 43, 0, 25, "Definition"],
Cell[203423, 6311, 127, 3, 50, "NumberedEquation"]
}, Open  ]],

Cell[CellGroupData[{
Cell[203587, 6319, 46, 0, 25, "Definition"],
Cell[203636, 6321, 334, 7, 40, "NumberedEquation"]
}, Open  ]],

Cell[CellGroupData[{
Cell[204007, 6333, 70, 0, 25, "Definition"],
Cell[204080, 6335, 262, 8, 30, "NumberedEquation"]
}, Open  ]],
Cell[204357, 6346, 472, 14, 71, "Text",
  CellTags->"D4"],
Cell[204832, 6362, 178, 7, 28, "Text"],
Cell[205013, 6371, 195, 7, 27, "Text"],
Cell[205211, 6380, 185, 7, 27, "Text"],
Cell[205399, 6389, 176, 7, 27, "Text"],
Cell[205578, 6398, 194, 7, 27, "Text"],
Cell[205775, 6407, 687, 22, 95, "Text"],

Cell[CellGroupData[{
Cell[206487, 6433, 422, 9, 95, "Input"],
Cell[206912, 6444, 410, 9, 145, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[207359, 6458, 150, 3, 31, "Input"],
Cell[207512, 6463, 164, 3, 77, "Output"]
}, Open  ]],
Cell[207691, 6469, 482, 14, 79, "Text"],

Cell[CellGroupData[{
Cell[208198, 6487, 56, 1, 31, "Input"],
Cell[208257, 6490, 375, 6, 68, "Output"]
}, Open  ]],
Cell[208647, 6499, 95, 2, 27, "Text"],
Cell[208745, 6503, 521, 10, 215, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[209303, 6518, 45, 0, 56, "Section"],

Cell[CellGroupData[{
Cell[209373, 6522, 34, 0, 43, "Subsection"],
Cell[209410, 6524, 106, 3, 27, "Text"],
Cell[209519, 6529, 370, 8, 61, "NumberedEquation"],
Cell[209892, 6539, 60, 0, 27, "Text"],
Cell[209955, 6541, 363, 12, 29, "NumberedEquation"],
Cell[210321, 6555, 419, 7, 95, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[210777, 6567, 50, 0, 43, "Subsection"],
Cell[210830, 6569, 829, 25, 95, "Text"],
Cell[211662, 6596, 1727, 43, 183, "NumberedEquation"],
Cell[213392, 6641, 1633, 45, 97, "NumberedEquation"],
Cell[215028, 6688, 94, 2, 25, "Warning"],
Cell[215125, 6692, 1354, 39, 189, "NumberedEquation"],
Cell[216482, 6733, 2471, 74, 231, "Text"],
Cell[218956, 6809, 341, 7, 52, "NumberedEquation"],

Cell[CellGroupData[{
Cell[219322, 6820, 29, 0, 25, "Exercise"],
Cell[219354, 6822, 1197, 39, 127, "ExerciseText"]
}, Open  ]],
Cell[220566, 6864, 1118, 30, 146, "Text"],
Cell[221687, 6896, 252, 5, 91, "Input"],

Cell[CellGroupData[{
Cell[221964, 6905, 100, 2, 31, "Input"],
Cell[222067, 6909, 25848, 619, 186, 5298, 360, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],
Cell[247930, 7531, 85, 2, 27, "Text"],
Cell[248018, 7535, 60, 1, 31, "Input"],
Cell[248081, 7538, 102, 3, 27, "Text"],

Cell[CellGroupData[{
Cell[248208, 7545, 55, 1, 31, "Input"],
Cell[248266, 7548, 77, 1, 30, "Output"]
}, Open  ]],
Cell[248358, 7552, 222, 8, 27, "Text"],

Cell[CellGroupData[{
Cell[248605, 7564, 259, 5, 91, "Input"],
Cell[248867, 7571, 20354, 754, 93, 8693, 606, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],
Cell[269236, 8328, 258, 9, 44, "Text"],

Cell[CellGroupData[{
Cell[269519, 8341, 238, 5, 91, "Input"],
Cell[269760, 8348, 23666, 872, 93, 10041, 699, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[293475, 9226, 51, 0, 43, "Subsection"],
Cell[293529, 9228, 461, 8, 95, "Text"],
Cell[293993, 9238, 1271, 35, 51, "NumberedEquation"],
Cell[295267, 9275, 1366, 39, 94, "NumberedEquation"],
Cell[296636, 9316, 2148, 57, 180, "NumberedEquation"],
Cell[298787, 9375, 56, 0, 27, "Text"],

Cell[CellGroupData[{
Cell[298868, 9379, 116, 2, 51, "Input"],
Cell[298987, 9383, 38, 1, 30, "Output"]
}, Open  ]],
Cell[299040, 9387, 215, 4, 61, "Text"],
Cell[299258, 9393, 203, 5, 51, "Input"],

Cell[CellGroupData[{
Cell[299486, 9402, 213, 5, 91, "Input"],
Cell[299702, 9409, 48956, 1855, 186, 22247, 1520, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[348719, 11271, 48, 0, 56, "Section"],

Cell[CellGroupData[{
Cell[348792, 11275, 34, 0, 43, "Subsection"],
Cell[348829, 11277, 274, 5, 61, "Text"],
Cell[349106, 11284, 136, 3, 25, "NumberedEquation"],
Cell[349245, 11289, 251, 8, 44, "Text"],
Cell[349499, 11299, 432, 14, 43, "NumberedEquation"],
Cell[349934, 11315, 248, 7, 44, "Text"],

Cell[CellGroupData[{
Cell[350207, 11326, 56, 1, 31, "Input"],
Cell[350266, 11329, 138, 2, 30, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[350441, 11336, 444, 8, 151, "Input"],
Cell[350888, 11346, 211175, 5751, 242, 162150, 5141, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[562112, 17103, 42, 0, 43, "Subsection"],
Cell[562157, 17105, 223, 4, 61, "Text"],
Cell[562383, 17111, 2354, 44, 246, "NumberedEquation"],
Cell[564740, 17157, 1076, 31, 131, "Text"],
Cell[565819, 17190, 174, 3, 91, "Input"],
Cell[565996, 17195, 116, 3, 44, "Text"],
Cell[566115, 17200, 74, 1, 31, "Input"],

Cell[CellGroupData[{
Cell[566214, 17205, 297, 6, 91, "Input"],
Cell[566514, 17213, 68063, 1148, 146, 18848, 536, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[634626, 18367, 42, 0, 43, "Subsection"],
Cell[634671, 18369, 329, 6, 78, "Text"],
Cell[635003, 18377, 136, 2, 51, "Input"],
Cell[635142, 18381, 84, 1, 32, "Input"],

Cell[CellGroupData[{
Cell[635251, 18386, 247, 5, 73, "Input"],
Cell[635501, 18393, 78941, 1282, 146, 18848, 536, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

