(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    408020,      10407]*)
(*NotebookOutlinePosition[    408994,      10440]*)
(*  CellTagsIndexPosition[    408950,      10436]*)
(*WindowFrame->Normal*)



Notebook[{
Cell["IMAGE ENHANCEMENT", "Title"],

Cell["\<\
Mariusz Jankowski \[Copyright]
Department of Electrical Engineering
University of Southern Maine
mjkcc@usm.maine.edu\
\>", "Address"],

Cell["This loads the package and sets some useful options.", "Caption"],

Cell[BoxData[
    \(<< ImageProcessing`\)], "Input"],

Cell[BoxData[
    \(\(SetOptions[ListDensityPlot, FrameTicks \[Rule] None, 
      Mesh \[Rule] False]; \)\)], "Input"],

Cell[CellGroupData[{

Cell["INTRODUCTION", "Section"],

Cell["\<\
Image enhancement refers to any technique that improves or modifies the image \
data, either for puposes of subsequent visual evaluation or further numerical \
processing. The greatest difficulty in image enhancement is quantifying the \
criterion for enhancement. Indeed, there is no universal metric of image \
quality available. Therefore, a large number of image enhancement techniques \
are empirical and require interactive procedures to obtain satisfactory \
results.  Image enhancement techniques include gray level and contrast \
manipulation, noise reduction, edge sharpening, linear and non-linear \
filtering, magnification, pseudocoloring, and so on. One useful, broad \
categorization of enhancement techniques divides them into point- and \
region-based operations. Point operations modify pixels of an image based on \
the value of the pixel. These are also called zero memory operations. In \
contrast, region-based operations calculate a new pixel value based on the \
values in a local neighborhood (typically small).\
\>", "Text"],

Cell[CellGroupData[{

Cell["Initialize", "Subsection"],

Cell["\<\
Get an example image. In order to improve speed of subsequent calculations \
only the upper-right corner of the image cell will be used. \
\>", "Text"],

Cell[BoxData[
    \(A = 
      Partition[ReadImage["\<c:\\mjkcc\\Data\\rcell128.bin\>", \ "\<Raw\>"], 
        \ 128]; \nB = SubMatrix[A, \ {65, 65}, {64, 64}]; \)], "Input"],

Cell["\<\
Below, both the full size and the upper-right quadrant are shown.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[
      GraphicsArray[
        \(ListDensityPlot[#1, PlotRange -> {0, 255}, 
              DisplayFunction \[Rule] Identity]\ &\)\ /@\ {A, \ B}]]; \)\)], 
  "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .47619 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0113379 0.47619 [
[ 0 0 0 0 ]
[ 1 .47619 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .47619 L
0 .47619 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0113379 0.477324 0.464853 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00751202 0.0192308 0.00751202 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
128 string
128 128 8 [128 0 0 128 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
343636353434343334323436343434363635343535343634
353434343334343436353736363636373536373736373737
373635373538393937383738383938383A3B4149505C7F99
A5AAA9A39A85634B4342414142424448525C61646668676A
6B6A696865605B58544E48403C3B38373837383836363738
39383D3D4345484F
323334343333343333333334333233343536333333353432
323433343334343535353636363535343537363735363535
34363535343637383736383837373738383A3E47525F869C
ACAEAEA7A18B714D434141404245464B525C626566646768
6969696763605C5A554F48403B3B38383737383634353635
37393B3E43474D52
343534323332323031313232333334333334333233333434
333232333433343434353635343634363637373736363535
343535343435373737373836383736373A3C3E474F6490A4
B0B6B5AAA28E7A5144404142464D5152585E616664636666
68696A64625D5C5A554E47403B3B39383838373535353635
37393D42484B5055
323433323232313131303033323333333233323131333333
343233343333323433353534353634343635353435363634
363436343635353636373635373736393A3C3F454D6391A4
B3B6B6AAA5927852424142454D5A5E5F6162666866666767
666868635F5E5B57504B463E3A3838373637363635353436
373A3F44484A5156
343432323233323232303232323433333233333132313332
323333343333333435363334333435353535363434353435
35353736353535363637363737373739383B3D414C6088A3
ADB4B4AEA590744E454242475763696A6D6C6C6D6B676867
676863605F5C58564E4B443C3B3937363836353534353537
373B40464A4D5056
323332323232323230303233323333333132313031313232
323233333332323434333332333435333435343335343535
353534353435353535363636363637383A3A3C3F485C7699
A4B1B0AAA18C6A4A434243495B676C727576766F6D696766
656463605E5A56514E473F3B383836383736363534333537
373940454D4E5255
323333333231323131313133333332313131313131303233
323334353333333333333333333335353636343535353536
343535353636343536363637353635383A3B3B3D46556B86
99A6A6A197805B474340444F5E6B737C7C7F807970696A69
666260605C59544F49433C3A383737363635343334353635
363A40444B4F5153
313231313231313231313131323231323232313232313232
313333343334323331323235343434353537353536363635
34353433353435353637363535373638393B393C44515E72
8691968E846A4D47424145515F6C767F7F83867F7A736D69
625F5D5C5A56514C463E3B39373637353636343434353637
36393D42484B4D51
303132323331303132323131333132323334323231323232
323234313232323231333234333436363735363634353635
3636343335343636373736363536373839393B3E444D5660
6D787672645246434140465463727B807D86877F7E7E786F
685D595654504D46413D3A37373837363535353535343638
37373A42474B4D4F
323233323331303031313132323232323232303031313132
333332333233343331323334353435363535343534353535
3735343435333536363536363535373538393A3B42495154
5B5E5F574D4641413E41455465717B80828486807D7F7D75
706055504B4945403C3A3837373636363536363534353534
3737393D42494C4F
313232323230313131313031333232313131313031323233
343332323434343333323435363434343535353535353637
353533343634343636353636363736373737393B3E42464E
4F53524E4440413F3E3F4353636F7A818685878382837E7B
756A594D49433F3D3C393737363735343535363634353536
3737383B3F434A4D
303231313130313232313131323231313232303333313335
333232333333343333333334333334353536353637363434
33343435343535353536353535363636373638393B403F43
484B4945403E3D3D3E3E424E5F6C767C83828284837E7C78
77705D4E433F3D3C3B3A3837363735353536373635363536
373737383B404448
323231333230313231323332323233313131313232353533
333233343434363434333535343634353434343436363534
343635353435343535353636363536383838393A3C3E3E40
414141403E3E3F3D3E3E414A556672777F7A7A7C7F787472
7370635043403D3D3B383838363636353636373636363535
36363639393D4044
313231323332313231313131333131323232313132323433
323333333335363534343535343535343433333434343434
343534343434343635353636353736363739393A3C3B3B3E
3C3C3D3D3C3C3D3D3D3E404651626A71757A76787C74706F
6E6B6355453E3B3C39393636363535353736363735363735
363536383A3A3E40
323232313231313032323132333231323130303332333433
333434343433343433333435353433353234343535343435
35343434343535363737363735363737363738393A3A393B
3A3B3A3B3B3C3C3D3D3D3E434A59646B6E7474767A726C68
68696455453F3D3A3A383636363636373635373736363636
3535373739393C3E
323031313231303030313131333232313130313232313333
333333343534343433333434353534353433333434363436
353433363436363636363637353437363638383938373A39
3A3A3B3A3A3A3B3D3E3C3C4045505E676B6E6F7170696560
64696255453F3B3B3A393736373536363536373836353636
35353737383A3A3D
323131313131303031313232313031313130333232333334
333332343232333334343335353434343334353435363636
36353534373535353535363737373736383838383938393A
3A3B3A39393A3B3B3B3C3D3E424B555C65686C6B67636160
656A6154443E3D3B3A393737363635373635373739373635
3435363639393A3C
313132313131313131323232323131313231313132323233
333332333233343433343434353434343535343434353536
363536333334363536363537373737363839383837383839
3938393A393B3A3C3A3B3D3D3E454A54565F6465625E5B62
63625C4D413D3C3A39383736353636363735363838363635
36353837393A393A
313231323031323131313232333331313031303231303231
323332323233333334343434363335343536343536363537
353635343435363635353437353635373838383A38383939
3839383939393A3A393C3B3E3D4143474F585B605F58585B
5E5B52473F3D3C3A38383737363736363635363538363535
3535383638383838
313331313130313130313031333331323231323232323333
323233333232333534353534353435353436353434353636
3535363535383636353636373738363637393937383A3737
3938383939393A393A3B3D3B3D3C4043484E505456555156
56534A423D3B3B3938383738363636363636363535353535
3636373636383636
313232313131323031323132323130333231313233343333
343133333332333535353734343435353534363535363637
3736363535383738373835373836373738393A3939393939
3B3A3839393B39393A3B3D3A3C3B3E404247484A4D4F4B50
4D4945403C3B383837363838373636383835373535353635
3635363635373634
2F3231313032303031303232323232333131323132333332
333234333232323434343534353535353536363435353636
3537373738363837383737363637373739373A3938393839
3A383A383939393A393A3B383B3B3B3E4140424343444546
45433F3C3A3A393835383837363536353535353534343534
3435363636373534
303131313130303030313231323333323131313231313233
323332323233323434343435363435353535353534343637
383737383936383637373836383636373837383A38383A38
373A3A3939383A3A3A3C393B3A3A3B3C3E3E404140403F3F
3F3F3D3A3A3A373736363536363436363535353535343536
3436363536343535
313131313131303030313132313231313131313231313334
333131323232343433343536353535363535343635363837
373738383836383738373737363637373738383838393838
3939393939383A3A3A3A38393A3B3A3A3C3D3D3E3E3C3D3B
3C3D3B39393A393635363636343535373534363536353537
3736373736353534
313132323131312F31313131313131313231313232323032
343333333432333434333535353434363635363636363836
36363839363537383737363738373837383738383A393A3A
3939373B3A38393B393B39383B3B3B3B3B3B3D3C3D3C3C3C
3A3B3B3A3939383636353636363536353536363636353636
3736373736373436
313232323031302F31313132323230313032323231313131
333433323332333332343435353636363435363636373837
353536373734383436383736383737363837373A3A3A3B3A
3B38383C3B39393A3A38393A393A3A3C3A3A3D3C3A3C3A3A
3A393A393938383637363737353636363637363535363536
3837373737363535
303231313130313130313231323132313131333233313232
333333323232333233343534353535353535363635353837
36363837373636363637373838383735373B38393A3A3B3A
3A39373839393A3A39393A3A3B3B3A383B3C3C3C3B3B3A3C
393A38393A39383837383637373637373736363536363635
3638373736363635
303131313131313030313131323131313032323231323232
333232343231333334353434333433353636353537373638
3636353836373736373937383838383637393737393A3A39
393A3938393A3B3938383A39393A383A3A3A393A3A39393A
3B393A393937393837373737353536373636363437363636
3636363737363536
313231313231313131303032313131303031323232323233
343433323332333334353634353334343634343736383737
3736373837383638393938383939383938383A383A393A38
3A3B3B39393B3B3A3B39393B3A3A393A3938393A3A3B3A39
393B383A3A393A383A383837373837373636363737363637
3737373636363637
303231323230313030303030313231313131313133323333
333434333333343235353635353433353534343737363736
37383737363637383837393736373738373939393A3A3A39
3B393B39393A393A393839393A39393B3A38393A3A3A3A38
3A383939393A393A38363637373536373636373736363537
3637373636363637
303032313130303130303031313131313231323232323434
333234333333333233343534353536333534363637383937
353637353637363738393838383A38363A393A393A3A3938
39393A3A3A3A3C3A3B3A39393A3A3939383A3B3B3A3C3B3B
3A3838393A39383938373737363737383837363636363838
3836373737373638
303232313030302F2F303032313130303131313132333233
313333333332323234343635353534333535373536383836
36373935373737373737393839393937393839393A393839
3A3A39383B3B3B3A393A383A3A393A3A3A3A3A3B3A3B3A3C
393A39393939383739373737373736363837373736363737
3737373739383739
3032323232313030302F3032313130323132313132333432
333433323333333433343534353534353435353737363737
38383937363738383838373939393638383A39393A3A393B
3A3A3B393A3A3A3A3A3C3B3A3A393A3A3A3C3B3A393A3B39
39383938383B393838393736363736383939373738373737
383A39383738393B
313232323130303130313232303132333231313131333433
333333323334323432353434343435353537363835363437
3838373737373636393737383939383935373B393A3A3B3A
3839383A393A3A3A3B3B3A3B383939393A3B3A393A39393A
3938393A3A38383636373936373737373837363738373738
3938383838393B3F
313132313131312F2F313131303231313031313031333332
323333333334333334333534353436363535363637373535
3737373637373837383838383839383638393A393A393B3A
3A3C3B3C3B3B3A3B3A3B3939393839383A3A3B3A3A3A3A3A
383838393938383739373738383837383837373638373737
37363637393A3F45
313332313031303031313130323231313131313131323234
333434343433333434343335343535363536373635353736
3636353536363738393837383837373A39393838383A3939
39383B3A393B3A3B3C3A3A39383A3738393A393B38383839
393837383737383837383637373938383737373637373736
363737383A3E4448
323331303132303030313230323231303132313031333232
333534343233343535333535363638373636353837383835
373535363737383938373B3A39383939383A39393939373B
383A3A3A383B393D3C3B393B3B39383A3B3A3A3A3A393837
393839393938383939373736373638383737353636373737
393737393C43494C
303131313131303030303131313131313131323132323332
333434333234343334333335353637353635363635353737
363637363737383839383A38393637383A3A393B3B3A3B3A
3C3B393A393B3B3A373B393A393A3A393A3A383739383938
383939383938393836363736373637363637373636363637
383738393C45484B
2F313132312F2F2E2F2F3132323030313131323232323332
323435333333323533343333343636363637363836373937
373735363636383837383A39383A3838383A39393A39393A
3A3B393B3B3A3A39393B3939383A3A393A39393A3B3A3938
383A3B393A39373938373636383838373636363638373637
393839394047494C
303131303030302F30303032323132313231313131323132
343435343332343335343433343636363737353538373736
3536373737373837373A383838373939393A39383A38393A
3B3A393A3B383839393B3A39393A3A393939383939383A3A
393A3A38393A383838383736373738383738363637373738
3838383A4147494C
313130303130312F31313132313132303131313232313232
343434333435343436333535343635353838353536373737
363536353737373838383B393A39373A2E3C3A3A393A3B3B
3B3B393B393A3A3B3A3B3A3B393939393A3938393A393839
39383839373939393939373738393A393737373635373938
3839393B41474B4C
2F303130302F2F2E30303131303030323131313233323334
343434333333333435353536353735353737363537383636
3836363737363936393A3C3A393939393A3B3A3A3C3A3A38
3A3A393B3C3B3B3A3A3A393839393B393A3B393839393A39
39393838393938383A3B3939393939383738383637353638
38393B3940484A4C
2F31303030302F2F2F303131323131323130313332323333
333334343233343434353535363334363535363739373838
36363735363737383A38373B38393A393A3A3B3B3A3A3B3A
3A393B3C3C3B3A3B3A3A3A393A3A39393B3A3C3C3C3B3939
39393A39383A383A39393738393939383938373737373739
3939383C3F46494B
3030303030302F3030303032313131323130313233333333
333432333333343333333435353434363637353738373738
3637373839383A3A3837393B3A3A3A3A3C3B3B3B3B3B3A3A
3A393C393C393A3B3C3C3C393A383B3A3E3A3A3B3B3B3939
3A3737383838383A3A363739373738393839383736363738
3838393B3F424649
3031313130312F3130303132303131313132313231323134
343532333435353434343536363735363737383935363637
37363839393737383A37383A393839393A3B3B3D3C3C3C3A
3B3C3C3B3A3B3B3B3B3A3B3B3A383A3B3B3B3C3B3A393A38
3B3837393939383838373738383838393839373635363637
38383A3D3E424549
3031313030302F302F2F3130313132323132303131323033
333433333433343336343535363637373636383837383738
373537373638383A3939393939383A3A3B3B3A3C3A3C3B3C
3A3A3B3A3B3A3C3B3A3B3B3A3A39393A3A3A3B3B3A383939
37383A37393738393A383738373837373637383636373839
39383B3F41454648
313231303030302F2F313230313132313232313231323332
33353333333334333434353736353435363637363A383736
3837363737373839393937393B393A3B3A3B3B3A3B393C3B
3B3C3B3C3B3D3B3C3A3C3A3A3C3A3A393A3A3C3A3A3A3938
373938383A393A3938393938373738383736373738373839
3A3A3E4446484848
3031313030302F302F303131313132333231313232333231
333333333433323333343534343535353736373538373737
39373635383739393A3A393A39393A3A3A3A3B3B3D3A3A3C
3A393D3D3C3C3A3B3A3C3B393B3B3B3A3A393A393A393937
383739393839393A3837373736373739383838383838383A
3A3B42464849494B
31313130303130302F303130303031323131323131323435
343335333334343334343434373536383635373637383738
37373837383939373A3A39393A3A3A3B3B39393A3B3D3C3C
3B3C3B3E3D3C3C3D3E3F3C3B3B3C3A3B3A393C3A39393A39
3938393839383939393837383638373A3A3A37393838383B
3B3E44484B494A49
313131313031302F2F303031303031303030303132323334
333235343234343435353535353535373636353539363737
3839383836383838393A3A3B3738393B3A3A3C3A3B3B3B3A
3B3B3A3B393D3B3B3D3D3C3D3A3B3B3A3A3B3A3B393A3939
3738373939383A3737393637363737393838383738383939
3B3F444849474A4A
303131313030302E2E2F3031313031323130303232323333
343434333333343335343535353433353737363638373737
373838383738393A393A3A393B3C3C393B3D3B3B3C393B3A
3B3B3B3A3B3D3D3B3B3C3A3B3C393C3B3B3B3A3A3B393938
373A3939383A383737393736363637393837383839393A39
39404548484A494B
2F3030302F31302F302E3030313031313230313132333334
333434353435343333333434353735373637373837383839
383839393738393A38393B3A393939383A3B3A3E3A3B3C3B
3C3C3C3A3B3D3C3D3A3B3C3C3B3A3B3B3D3C393B393A3938
3838383839383838383938373837383738393939393B3A39
3A404648494A494A
303130313130303031303132323031323232313233343435
34333534333334333335353437373737353736383738393A
3A3A39393A383A3A3A3A3B3B3D3A3B393A3A3C393B3C3B3A
3C3D3D3A3B3C3D3C3B3B3A3D3A3C3C3D3A3A3A3A39393939
383A3938383939373738393838363839383839383A393B3B
3B414748484A4A4A
303030303030313131303130323130323232313132343234
333533333335353434353535353436373637363636373837
38393838373A3B3839383A3A3A393B3B3A3A3B3C3C3A3F3C
3E3D3C3C3A393B3A3B3D3C3B3B3A3A3B3D3A393939393A38
38393939383A38383837383939383839383838373838393A
3C404548484A4A4A
303131303130303030303031313231313131313033323233
353435343534333535353635363635363638353637363837
38383B393C393939373939393939393C3A3C3C3B3B3D3D3C
3C3D3C383C3D3C3C3D3C3C3A393B3A3B3B3B39393A393A38
38383939393938373837383939383737383938383739383A
3B3F434646484B4A
2F302F3030302F3030303032313131303132303132333235
353335343534363436353634373638373637363736363839
383A373838383A39383A3A3A393A393A3A3C3C3D3D3B3A3A
3E3D3B3C3D3C3B3C3B3B3A393A3B393B3A3C3B3C3B3B3B39
3A393839393A38393838393837383838383838373839383A
3A3C404346494849
2F303130303031302F303131313132313231323233333333
343635333535343536353737363737353735363636373937
383838383A3B3B3B383B3A3B3B3C3C3B3B3B3E403F3B3C3C
3D3C3D3D3A3C3A3C3B3C3A393A3939393C3A3A3C393A3839
393B393A3B3B3A3937373837373839393938373939383939
393A3D4145474947
2E2F302F30302F2F2F303132303132323132313133333334
333533343335353535353635363636363637363636363736
3738383938383939383B3C3A3C3A3A3A3C3C3B3C3C3C3C3A
3B3C3C3E3A3C3C3C3C3C3C3C3B3B393A3B3B3C39393B393A
38393838393B393838363837373837373738393939383839
3A393B3D40424542
2F31302F30302F2F2F2F3031313031313131313233323432
333434343435343434353537373535353737373637373737
3738373A3A393B383A3B3C3C3A383B3A3D3D3C3D3B3C3B3B
3A3C3C3D3C3B3B3D3B3C3C3B3A3A3C3A3B3A3A3A3939383A
3A393839383A38383738383838383838383838383838393A
39393A3D3C3D403F
2F302F2F30302F2F2F303031303131313031323332333332
33343333323234353635373537353537373637373939383A
3838383939383939393B39393A3A3B383B3B3C3B3B3D3D3C
3C3C3D3E3C3E3E3F3F3D3B3C3B3A3B3A3A393C3C393B3A3A
3A3B3A38393A383938393837373837383737393838383938
38393A3B3B3E3E41
2F30303031302F2F2F2F3030313131323132313233323233
33333332323433353634373636383638353738363838383A
3939383A3A393A3B373B39393A3B393B3C3B3C3A3C3C3F3B
3D3B3E3C3E3F403E3D3C3C3D3B3C3B3C3C3A3D3B3A383A39
3A3B3B3A39393B3938363737373838383A39373737373837
3738383B393B3F41
2F3030303031303030303031303131313232313232323234
33333433343435343636363635363735363636353737383A
3A373837383A39393A3A3A39393A3A3C3C3B3C3B3D3D3E3D
3B3B3C3E3D3D3D3D3C3C3C3C3C3C3B3A3C3B3B3938383A39
3A393B3A3A39393938373838373737383838383637363737
3637393A393B3F44
2E303030303030302F2F2F30303131313131323231333333
34333433343434353436353536363636383736363637383A
393938393A3A393A3B3A3A3A3B3B393A3C3C3C3C3C3C3C3D
3D3C3E3E3C3D3D3E3F3B3D3B3C3A3B3B393B393B3A3B3A3A
393A3B393A39383838373838383939373939373738383837
363738393B3D4246
2F3030302F2F2F302F2F3030303131323031323332333434
343433333334343436363735363637363636373636373738
383938373A3A3A393C3A3A393B3B3B3C3B3A3D3D3B3C3C3B
3D3B3D3F3D3D3E3F3D3B3D3B3A3B3B3B3C3A3B3B3A3B393A
3A393B3939393939393939383838393A3A3B3A3839383836
363838393A3C4345
2F302F30302F302F2E2F2F2F313232313132323333343434
333533333433343436353735363635363535383837363937
3A3939393B3A3B3B3C3C3B3B393C3B3C3C3A3E3D3D3C3E3D
3D3E3F3E3E3D3E3E3F3D3F3B3D3D3C3D3D3B3D393C3A3939
3A3A39393A3A38383A393938393939383A3B393739373737
373837373B3E4347
2E2F302F2F2F2E2F2F302E2F313231313131323233343432
333434343333343436343434353635353535373737373837
3736393A3A3A393A3A3A3A3A3B3A3B3A3C3B3B3B3D3A3C3C
3C3D3F3E3D3F4040403D3D3E3D3C3B3C3B3A3A3A3A393938
393B3938393A3939393A3A3939383A39393A393737373637
38383838393D4248
2F30302F2F2F2F2F2F303030313132313132313032323233
333433333333343435333535383635373736373536373738
3839383939393B3B3A393A3C393A3A3C3B3C3C3C3D3C3C3E
3D3D3F3D3E403F3F3E3D3D3C3C3C3D3C3D3A3B3A3A3B3939
39383A393A3A3938383738393939393A3939393939393839
39393938393B4045
2E302F2F2F302E302F3031302F3030313131313133333333
333433333232333434363636363736373636373737373737
3839393738383A3B3B3B3A3B3B3B3B3A3A3C3B3C3F3C3E3D
403D3E403F3F4040403C3E3D3D3D3D3A3B3A3B3B3B3B3B3A
39393A393A3A393B3937393A383A3A383939393A38373739
39383A39393A3D42
2F302E2F303030302F2E3031303231303132323132313433
343333333334343434363736363737383738383638383737
3837393836393A3C3C3A393B3C3D3C3B3B3C3E3C3D3D4040
413E3D3F413E4140403E3E3D3E3D3D3C3C3C3B3C3C3A3C38
3A3A3A3A3A393A3A3A39393B3A393A383738393A37383638
38393A38393B3B3F
2D2F2F2E2E2E2F2E2F2F2F302F3030313031313130323233
323334333334333535353636363736383837373737373837
383839383839393C3B3B393B3C3B3D3E3D3E3E3F3F3D413F
3F3E3F4040404241403E3E3E3E3D3A3B3B3B3A3B38383A3A
393A373A393A39393938393939393A373838393839373637
39383939393A393C
2F2F2F2F2F2F2F2F2F2E30302F3030303131323031313232
323334343433343534363636373535373737363636373739
39383A3A3B3A3A3A3C3B3B3E3C3C3D3E3C3F3D3F3F403E40
3F424140424341424040403E3D3C3B3B3B3C3B3B3A3A3A3C
3C3C3A3A3A39383939383839393A3A3939393A3839383738
3838393A393A3A3B
2E2F2F2F2F2F2E2E2E2F2F2F2F30303030302F3031323333
323334353334343335333636363637373637373637383637
3839393A383B3B393B3C3B3D3D3D3C3D414240403F414042
424244444444444442423F3E3F3D3C393E3D3C3D3B3A3A3A
3B3C3B383A3937383738393A3B3A3A3B3A39393939393839
3839393A393A3939
2E302F2F2E2F2F2F2F302E3030302F3031302F3130323334
333433353434343536353736373737363638373737383738
39383A3A393C3C393B3D3D3D3F3E3E403E43403F41434243
42464A494A4B4845434241403F3D3C3D3D3C3D3D3B3A3A39
383B3B3A383A38373938393939393A3A393A393A3A383839
383939393A3A3A3A
2E2F2F2F2E2E2D2E2F2E3031302F303030302F3032333333
33343435363334353636363737363637353736373737393A
39393A3A383B3A3B3A3C3C3D3E403D404242424242424246
474D5255554F4D49434442403F3E3D3B3B3B3D3C3B393A3A
393A3A3A3839393837393A3A3B3B3A393A3A3A3A3A393939
39393939393A3839
2E2F2F2F2F2E2E2F2F30313030302F2E3030303131323233
343433343433353636353536373537373638373938393A3A
3A3939393A3A3A3C3C3B3D3E3F3F4041444542464547474C
52595D61625E584D4A454342413E3D3D3B3A3C3B3B3C3A3B
3A3B3A3A3A39393A3A3C393A3B3C3B3C3C3B3D3C3B393A3A
3B3A3A3A3A3A3A39
2E2F2F2F2E2E2E2F30303030303132303030313131313234
333335343333343635353535353635363637383736383939
3A3939383B3A3B3B3C3D3E3F40424345454749484A4A4B54
5A636E797872685B51484442403C3D3F3E3D3C3C3B3B3A39
3C3C3A3A3B373939393B3A3B3D3C3C3D3E3E3D3D3C3A3A39
3A3A393939393A38
2E2F2F2E2E2F2F2F30313130313233323030313131323333
333534343334353534353738383638383736363737373939
39383A39393B3B3B3C3D3F3F41464C4E4C4B4C4D5354585B
67788991939281715E52464540413F3F3C3C3D3B3D3D3B3C
3B3B3A3A393A3A39393A3A3C3D3F3E403F3F3D3D3C3C3B3C
393C3B3B3B393939
2E2F2E2F2F2F2F2F2F303030313130312F2F313032333235
34343535343434343435363738363636353536383939393A
3B38393B3A3D3D3C3D3D3E41434C5153535152575C5B6168
7B8F9BA3A6A19689775C4C454440403E3E3B3B3B3B3B3B3B
3A3A3A393A3B3A39393A3C3D3D403F4040403F3D3E3D3C3B
3B3B3B3B39393838
2E2E2E2F2F2F2E2E2F302F30303132313031313132323232
34343536363432353434363537373736353637383B3B3A3B
3A39393C3A3B3C3B3E404141475155595B5B5B5C61616677
90A2AFADB4B1A99C8D6B534D47423F3C3E3C3B3A3B3A3B3B
393B3A3A3B3A3B3A3B3C3E3F4244464646444340403F3E3D
3C3B3B3A38383736
2E2F302F2F2F2E2F2F2F3030303131313031313231333334
3333343634353533333536353737363536383837393A383A
3A3A39393A3A3D3D3F4043444C585A5D60605F6163676D89
A1B0B8B9BCBAB3AA987C5E554F43413F3C3C3C3A3A3B3A3C
3B3A3B3B393B3A3B3B3C3F42474C4D4F4E4A484542403F3F
3D3B3A3938373738
2E2E2F2E2F2F2F2F2E2F3131313131323131323233343334
353434333533343434343435363737373736363739383A38
3A3A3B3B3B3D3C3F42414348535B5E6061636566676D7598
AEBBBDC3BFBEBBB1A28866575449423D3D3D3D3B3B3A3A3C
3A393B3B3B393C3D3C3E42484F5356595955504C4946423F
3D3D3B3938383737
2D2F2E2F2E2E2F2F2F2F3031313132323231313132323234
34343434343534333433353736353536363638383939393A
373A3D3B3B3C3D3F4140454F5A5E6363656768686A6E81A0
B1BFC0C8C8C5BBB3AB906D5E5448413F3E3D3D3B3B3A3939
39393A3A393B3C3E3C3E454E575A5C5E5E5C58544E494440
3E3D3A3939383636
2E2F2E2F2E2F2F2E2F2F3030313131303030313032323233
34343333333433323234363536363636353737373839393A
383A3B3C3B3B3D3D42444A56606768686C6C6D6C6E7484A2
BBC4C9CBC8C6C3B7AC90715C4E45423E3D3C3C3B3A3A3A39
39393A393B3B3C3D3C4149545C60626565615F5C584F4843
413D3D3B39383836
2E2E2F2F2F2D2F2F2F30303030302F303030313031313132
3333343533333334353636353736353735373837363A3738
383A3B3B3C3D3F42464C5363686F6E6B6B6D6E6D727683A6
BCC5C7CBCAC6BFB7AA966F584944403D3D3D3C3C3B393A39
393B3A3A393A3C3E3F444C575F64696C696B6A6660554D46
44403D3D3B393737
2D2F2F302F2E2E2F2E30302F30302F30302F303031313132
3334353533333233353635373736353738383839363A3A38
3A3B3C3C3D3F42464B586D7F87837E6E6D7172767C7E829D
B8C4C5CAC9C2BDB7A9966D554B43413F3E3D3F3C393A393B
3B3A3B3A3C3C3E3E4147525C6269727270707370675E554E
4845413D3B3A3737
2D2F2F2F2F2E2D2E2D2E2E2F2F2F2F30302F303031323332
3233343533343434333536363837363736373836383A3839
393B3B3C3C3F42485571828F9596917C6F6E77808D8E8E98
ACBFC2C7C6C3BEB3A688645049433F3E3D3D3E3D3B393A3B
3A3B3B393A3C3C3D4048535E666D7376757576746E696158
5048433E3C3A3937
2D2E2E2E2E2E2F2E2D2E2E2F2F2F2F303030303031323332
343333343234323233333535353636363535363739383739
393A3B3B3D3F444C6581919CA3A99F8C77727E93A6A5A59D
A6B8BEC0C0B9B3AB9B785D514B4742403E3E3E3D3C3B3A3A
3A3B3A3A3B3B3C3D4049546068717B7C7B7B7B7877736E64
594F45403C3B3837
2D2E2E2E2E2D2E2E2E2D2E2E2F2F2F2F31302F3030313233
343434333333353434343635353637353536373638393838
393A3A3C3C40455477909DA8AEAFAA96807893A9B6B7B7B2
ABADB6B2B8B5A89D856B59554F4B48423E3D3C3C3C3B3B3A
3A3B393A3B3B3B3E4046535F6A72797F8082807F7B79726B
60564A433D3A3837
2E2E2E2C2D2E2E2E2E2E2E2F2F2F2F30312F302F30323231
33323535333335333335363436353536363638363539383A
3A3A3B3B3C41485B8398A4ADB2B6AD9F827F9DB1BBBDBFB8
B3A1A3A8A89F978570605757524F4A43403E3D3C3D3A3A3B
383A393A3B3B3C3F4147535B697479808485878481807C73
695D4F443E3B3A36
2D2E2F2C2E2E2E2E2D2E2E2F2F2F2F2F3030303031313132
333232333332343333343534363537343534373738383739
393A3B3B3B4148678A99A9B0B5B3AEA38889A7B8BFC4C6BE
B7A996918F877E716357565953504A483F3D3C3D3C3B383B
3A393A39393B3C3E40454F5A66737D82858988868884807A
6F6352463E3C3935
2D2F2D2D2D2E2D2D2E302F2F2E302F2F3030302F32323233
333232333333343434333535353635353536363638393839
393A393B3E414C6B889DADB1B1B8B0A98B8CA9B7C1C7C6C2
BAAB908076766F665B585556514F4E49423E3C3D3B3B3A3A
3A393938383A3B3F40444C586474808283878A8F8E84817C
74695849403B3936
2D2E2D2F2E2E2D2C2D2E2F2F302F2F2F2F2F303031323232
333232323333333334353535353635353436353636373739
38393A3C3D434E70899BABB4BBBAB6A98D8BAABAC4CAC0BD
B8AB917A6F6B65605A55535450504E4A453E3D3D3C3A3A39
3A3A3939393B3C3E4044495261737E8383888F919188837F
766B5C4C403D3A37
2D2E2E2E2F2E2D2E2F2E2F2F2F302F2F302F2F3032313131
33343332333232333436353435363635353736363637383A
393A393A3D414B69889CAAB5BCB6B3A184859FB7BEC2BEB7
B3A98B706963615C5B555552504F4C4B45403D3D3B3B3A39
393A393A3A3B3D3D3F44485263767F83858B9194928B8480
7B6F5F4D413C3938
2D2E2E2E2F2E2E2C2E2E2F2E2F2E302F2F2F2F3031313032
333332323332343434353434343534353436353536383939
3A39393A3D42485F7E97A4AEB0AEA8907D778FAAB3B6B6B4
AB9D806D5F5F5C5B5952524E4F4F4C47443F3D3C3B3A3838
39383B393A3B3C3D3E42465061727D81868D9194928E867F
796E5F4E423B3937
2D2E2E2E2E2E2D2C2E2D2E2E2F2F2E302F30303030323132
333232323432333534343535343535343637363738393A39
3A38373B3E3F44526F8697A2A3A5998475718194A1A9ADA8
9F8B75675E5C5B5A595152504E4F4D49423E3C3B3B3A3A3A
3A3A393A3A3A3B3C3F41464F606E7B83898F93928E8C877F
746C5E4E413C3937
2D2D2E2E2E2D2E2D2D2C2E2E2E2F2F2F30302F3031313031
323232323332333434343535353534353736363637393938
3939393B3C3E414A597387969B9381736C69717B878C9593
877569615D5D59595950504E4D4C4A48423B3D3B3B383738
393A3A39393A3B3D3D41454D5C6E7A81888F91908B88857E
766B5B4B403B3837
2D2E2E2D2E2D2D2C2D2F2F2E2F2F3030312F2F3030313132
323333323232333434353636353434353637363737373839
393A3D3B3D3D41454D596B7A7C746D676464696E76777B75
6C68645F5C5B5B59574F4D4F4C4B4A463F3C3D3B3A383839
39393A393A3A3B3C3D40444B5A6E7B82898E8E8E8B88837D
746B58483F3C3835
2C2D2D2D2D2C2D2C2D2D2E2E30302F2F302F302F32313231
313333333332333435343635343635363636373737373937
39393B3B3C3D3D41454A5460656464605E5D626467696966
64615E5C5A595A58565249494A4B46423D3B3A3B39393837
3A3B3A393A3B3B3C3E3F4349566C7982888C8A8C8884817A
736753453D3A3835
2C2D2D2D2D2E2D2D2E2E2E2F2F30302F2F2F303031313132
333233323432333333343434353536363636383637393939
3839393B3C3D3E4043474A5257595B5A59595E5F5D616260
5D57585957565856524D49454745423D3A3B3A3939383937
383A3A393A3C3C3C3D3E42475469787F85898A88827D7B77
6B604E423C383736
2B2C2D2D2E2D2D2E2E2D2E2F2F302F302F30303132313232
323133323334333434353534343536363736363737383838
38393A3B3C3C3E3E404244494C4E50535357585B5B5E5C5A
5856505253545553504943403E3E3E3C3B3B3B3A3A383938
3B3939383A3A3C3B3C3E41465264737B828686827D74706E
6456473F3B373636
2C2D2D2D2E2F2D2E2E2E2F2F30303030302F313132323232
323334333433343334343535353536353536383739393738
3A39393B393A3E3E3E4042444646474B4C52555857585556
53504A494C51524E4A43413F3C3D3C3B3B3C3B3B3A393939
3A3A39393A3B3B3B3C3D40434D5F6D7A7F81807A7468635F
584D423C3A363635
2D2E2E2E2D2D2E2D2E2F2F2E2F2F2F303030313031323231
32333432323232333434353536353635343637363838373A
39393A3A3A3C3D3E3D3E3F4040434344444D52555453514F
4E4A444345464746433F3E3C3C3B3B3B3B3A3A3939383A39
3939393A3A3A3A3A3B3E3E4048556571787B7A746A5E5651
4B443F3B38373535
2D2E2E2D2E2D2D2D2E2E2E2E2E2F2E2F2F30303131323332
323333333333333334343434353535353435353837373739
3639393A393B3B3D3D3C3F3F4040404142474E5154514D49
48444241424243413F3D3D3D3A3A3A393B393A3939393938
3A393A3A3B3B3B393A3C3E3F454E59666D72706B61544D46
433F3D3A38353535
2C2D2E2D2E2E2D2E2E2E2E2F30302F2F312F303031323232
323233313133343233343534343535343634353636383837
37393939383B3A3C3C3C3D3F3E3F3E414042454A4B484443
42413F3E3F3E3F3E3D3C3C3B3A393A3A3B3939393A3A393A
3B38393A3A3C3C3B3B3D3D3F4248505962686561574D4541
3F3C3A3836353535
2D2E2E2E2D2E2D2E2F2E2F31313130302F2F303032333131
323232323333333434353434353434343634353638373838
3837393A3B3A3B3B3B3D3D3E3E3D3E404040424444424040
403E3D3D3D3D3E3D3B3C3A39393B3A3A39393A393939393A
3A39393A3B3B3C3C3A3D3E3E4143484E545B5B564E48413E
3D3B393737353535
2D2E2E2F2D2D2F2E2E2E2F30312F30302F302F2F32303130
313132323332323334343434343334343636363537383838
3836393939393B3C3B3D3C3D3C3D3E3E3E3E3F3E3F3E3F3D
3E3D3D3D3C3B3D3D3B3A393A38393A3A3A3A3A393838383A
3A39393A3A3A3B3A3B3B3B3D3E404346494B4C4945403D3B
3A3A383737363433
2D2E2D2E2E2E2E2E2F2E2F2F30302F2F2F2E2F3031313132
313232323232323333333535333434353634363636383838
38383B3A393C3B3B3A3B393A3B3C3D3C3B3D3C3D3F3D3C3D
3D3B3C3D3B3D3B3B3A3B39393939393939393B3939393939
3939393A3A3A3A3B3A3A3A3B3C3E3E4142434443413E3C3B
3939363636363633
2D2E2E2D2F2E2D2E2E2E2E2F2F2F302F302F2F3131303131
313233343233323234343433353535353436343636383838
38393A393A3A3B3A3A3A3A3B3C3C3B3B3C3C3C3C3E3D3C3B
3C3C3C3C3C3C3A3B3B3B3939393A3A393939393A3939393A
3A3A3B393A3B393B3A3B3B3A3C3E3F3E3D3F3E3E3D3E3B38
3937363535353434
2D2E2E2E2E2E2D2E2D2E2E2F2F2F2F2F2F2F2F302F2F2F31
323234303433333333353435363535343535363737373639
383839393A3B39393A3A3B3B3B3C3B3B3B3C3B3C3C3C3C3B
3A3A3C3B3B3B3A3A3A3C3B3A38393B393939393A3939393A
393A3A393B3A393B3A3B3B3B3C3C3D3E3D3D3C3C3D3B3A38
3838383536353433
2D2E2E2E2E2D2E2D2E2D2E2F302F302E2F2F2F2F30303031
323331263332323233343534353435343533373536363836
3739383838393838383A3B3B3A3A393A3C3B3A3B3B3A3A3A
3C3B3C3B3B3A39393A393A3A38383A393939393B38393A39
3A393B3A393A3939393A393B3A3B3B3D3B3B3C3B3A393938
3737363535353433
2D2E2E2E2E2D2E2E2E2E2E2F302F2F2E2F2F2F2E2F303032
313131313232323334333435353534333535353534353637
383938383839393938393B3A393A3A393B3B393A3B3B393B
3B3C3C3A3A3A3A3A3A3B3A3B393938393839393A393A3939
393A3A3938373939393837393A3A3B3B3B3A3A3938383838
3636353535353434
2D2E2E2E2F2E2E2D2D2E2E2F2F2F2F2F2F2F2F2F30303031
313133323131323333343334343434343535353536353636
3837373739393938383A3B383938393A393B3A3B3B3B393A
3A3B3A3A3A393A3A3939383A3938393A3939383839393939
38393A3938393838393737373A3938393937393938373738
3737363535353534
2D2E2E2E2E2F2E2E2E2E2E2F3030302F2F302F302F313132
323232323231333233343335353434353435353736353636
3837383839393938373A393838383938383C3B3B3C3A3A3A
3B3A393A3A3A3A3A393A3939393939393938383939383838
393A3938383938383A383837393938383938393737373737
3536363634353433
2C2E2E2D2E2D2D2D2D2E2E2F2F302F2F2F2F2F2F2F303030
323131313131313232343433343434353436353636363736
39373837373839383938393837383A393A3A393A3B3A3A39
3A393B39393A3A3B3B3B3837383837383939383939393736
383A36373739383737383738383837383837373738363635
3635353434343333
2C2E2E2E2E2D2E2D2D2E2D2F2F2F2E2F302F2F2F31302F31
313131313232323232343334343434353335353636363736
37373837373737393A383839393A3A393A39373B3A3A3A39
3A3A3A3B393A3A3A393B3939393839383A393837383A3737
383838383838383837373739393838383837373736353535
3534353434343333
2C2D2E2D2D2D2D2C2C2D2D2D2E2F2F2F2F2F2F2F30303030
313030303130303032313432343335353334343537363535
3736363837383839383A3A39383A393A3A38393A3A3A393A
39393A3A3A3A393A3A3A39393939393A3837373738383838
373838393A3838383837383A383839383836373636363635
3533353434343333
2D2D2E2E2D2C2C2C2D2D2D2D2E2E302F2F2E2F2E30303131
303130303131313133323333303234343334353536363735
363737363838363837383937383A39393B3A393B3A3B3A3A
3A38393A3A3B3B3B3A39383A3938373A3939373739393838
3738373A393937373837383A383939383737363635353535
3434343534343334
2C2D2E2C2D2C2D2C2C2D2D2C2E2E2E2F2E2E2E2E30303030
3030303030303030313232312E2B33353433333636373736
363737373838373738393938393839383939393B3B373A39
3939383A393A3B3A393939393837373A3938383838383837
363838383838383738373738383939383836353535353535
3534343435343332
2C2E2D2D2C2C2D2D2C2D2C2D2D2E2E2E2F2E2E2E2F2F2F30
3031303030303031313132322E2B32343433353637363735
353636373837383738393838383839383839383A39383A3A
393938383838383839383838373837373839383837393736
373737373838373736363638373837363636353535333334
3634343534343332
2C2E2C2D2C2D2D2D2D2C2E2E2D2E2E2E2E2E2E2E2F2E2F30
2F3030303030313130323133303133343434343536373735
373636383838383738383939393838393739393938383A39
393939383837383839383938363737373838393737373738
363535373737363636353637373736363635363434353536
3534353434343333
2C2D2D2D2E2D2D2E2E2D2D2D2E2E2E2F2E2F2E2E2D2F302F
2F2F31313230313131333234323334353534353637353635
373737373839383739383939393839393739393A38393A38
393939393939393939393837373736383939383837373737
373637383739373636373737373736373636353434363636
3535353634333334
2B2C2C2D2D2D2D2C2E2D2D2D2E2E2E2E2F2E2E2F2E2E2F2F
302F31313030303131323233323335343535353636353636
373836363738383739393738383938373939383A39383938
3839393938383A393A393736373637383738383836363836
373536373739383836383838363837373636363334353434
3435363535353333
2B2D2C2D2D2D2D2D2E2E2E2E2E2E2E2E2E2D2E2E2E2E3030
303031313030313131323433333435343534333535353636
37363637383737383838373838393838373A3A3B39383838
3839383A3838393938393737383836383736373735343636
373636373737393737383838373737363536343434343433
3436353434343433
2B2C2C2E2D2D2D2D2E2D2D2E2E2E2E2E2D2D2E2E2F2F3130
303031303030313131333233343433353434343535363537
363736373638373739373738383838393739383A39393838
383738373939393838383838373736373736363636353636
373636373737383737383738393736353636353434343433
3334343433333333
2B2C2D2D2E2D2E2D2D2D2E2D2E2E2E2D2E2F2E2F2E2F2F31
3030302F2F31323232323233343432343433343535363436
3636363637373737373738383837373738393738393A3939
393838383838393838373738363637393638373737363635
373837373737383737373637383836353635343534353434
3435343433333232
2B2C2D2D2D2C2D2D2C2D2D2D2D2D2F2D2D2E2D2E2E2F2F30
2F30302F2F2F313130323233343333333333333435343436
363635373736373737383837373636373738383937383839
373837373738383838383838363636383837373737363736
373637373738373838383737383837363535343434353433
3334343534343333
2A2B2C2D2D2C2D2D2C2D2E2E2D2E2E2E2D2D2E2F2F2E2F30
30302E302F2F303131313232323334333232343435343436
363536363736363737373837373636373838383937383838
373737373837383837393737373736373638373737383736
373637373635363837373738383737363535343534343433
3333343433333333
2A2B2C2C2D2D2E2D2D2E2E2E2E2F2E2E2D2C2E2E2D2E2E2F
2F2F2E2F2F2F303031303232333333323233333333333434
353535353535363736363737363636373737373837383838
373837373737363736383737363637383737383737373635
363637373837373737363638383838373635353434343434
3233333333333334
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0113379 0.97619 0.464853 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.015024 0.0192308 0.015024 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
64 string
64 64 8 [64 0 0 64 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
3C3A3E3D3D3C3E3D3D3E3F3E3E3D3E3E3F3D3F3B3D3D3C3D
3D3B3D393C3A39393A3A39393A3A38383A39393839393938
3A3B393739373737373837373B3E4347
3C3B3B3B3D3A3C3C3C3D3F3E3D3F4040403D3D3E3D3C3B3C
3B3A3A3A3A393938393B3938393A3939393A3A3939383A39
393A39373737363738383838393D4248
3B3C3C3C3D3C3C3E3D3D3F3D3E403F3F3E3D3D3C3C3C3D3C
3D3A3B3A3A3B393939383A393A3A3938383738393939393A
393939393939383939393938393B4045
3A3C3B3C3F3C3E3D403D3E403F3F4040403C3E3D3D3D3D3A
3B3A3B3B3B3B3B3A39393A393A3A393B3937393A383A3A38
3939393A3837373939383A39393A3D42
3B3C3E3C3D3D4040413E3D3F413E4140403E3E3D3E3D3D3C
3C3C3B3C3C3A3C383A3A3A3A3A393A3A3A39393B3A393A38
3738393A3738363838393A38393B3B3F
3D3E3E3F3F3D413F3F3E3F4040404241403E3E3E3E3D3A3B
3B3B3A3B38383A3A393A373A393A39393938393939393A37
383839383937363739383939393A393C
3C3F3D3F3F403E403F424140424341424040403E3D3C3B3B
3B3C3B3B3A3A3A3C3C3C3A3A3A39383939383839393A3A39
39393A38393837383838393A393A3A3B
414240403F414042424244444444444442423F3E3F3D3C39
3E3D3C3D3B3A3A3A3B3C3B383A3937383738393A3B3A3A3B
3A393939393938393839393A393A3939
3E43403F4143424342464A494A4B4845434241403F3D3C3D
3D3C3D3D3B3A3A39383B3B3A383A38373938393939393A3A
393A393A3A383839383939393A3A3A3A
4242424242424246474D5255554F4D49434442403F3E3D3B
3B3B3D3C3B393A3A393A3A3A3839393837393A3A3B3B3A39
3A3A3A3A3A39393939393939393A3839
444542464547474C52595D61625E584D4A454342413E3D3D
3B3A3C3B3B3C3A3B3A3B3A3A3A39393A3A3C393A3B3C3B3C
3C3B3D3C3B393A3A3B3A3A3A3A3A3A39
454749484A4A4B545A636E797872685B51484442403C3D3F
3E3D3C3C3B3B3A393C3C3A3A3B373939393B3A3B3D3C3C3D
3E3E3D3D3C3A3A393A3A393939393A38
4C4B4C4D5354585B67788991939281715E52464540413F3F
3C3C3D3B3D3D3B3C3B3B3A3A393A3A39393A3A3C3D3F3E40
3F3F3D3D3C3C3B3C393C3B3B3B393939
535152575C5B61687B8F9BA3A6A19689775C4C454440403E
3E3B3B3B3B3B3B3B3A3A3A393A3B3A39393A3C3D3D403F40
40403F3D3E3D3C3B3B3B3B3B39393838
5B5B5B5C6161667790A2AFADB4B1A99C8D6B534D47423F3C
3E3C3B3A3B3A3B3B393B3A3A3B3A3B3A3B3C3E3F42444646
46444340403F3E3D3C3B3B3A38383736
60605F6163676D89A1B0B8B9BCBAB3AA987C5E554F43413F
3C3C3C3A3A3B3A3C3B3A3B3B393B3A3B3B3C3F42474C4D4F
4E4A484542403F3F3D3B3A3938373738
61636566676D7598AEBBBDC3BFBEBBB1A28866575449423D
3D3D3D3B3B3A3A3C3A393B3B3B393C3D3C3E42484F535659
5955504C4946423F3D3D3B3938383737
656768686A6E81A0B1BFC0C8C8C5BBB3AB906D5E5448413F
3E3D3D3B3B3A393939393A3A393B3C3E3C3E454E575A5C5E
5E5C58544E4944403E3D3A3939383636
6C6C6D6C6E7484A2BBC4C9CBC8C6C3B7AC90715C4E45423E
3D3C3C3B3A3A3A3939393A393B3B3C3D3C4149545C606265
65615F5C584F4843413D3D3B39383836
6B6D6E6D727683A6BCC5C7CBCAC6BFB7AA966F584944403D
3D3D3C3C3B393A39393B3A3A393A3C3E3F444C575F64696C
696B6A6660554D4644403D3D3B393737
6D7172767C7E829DB8C4C5CAC9C2BDB7A9966D554B43413F
3E3D3F3C393A393B3B3A3B3A3C3C3E3E4147525C62697272
70707370675E554E4845413D3B3A3737
6F6E77808D8E8E98ACBFC2C7C6C3BEB3A688645049433F3E
3D3D3E3D3B393A3B3A3B3B393A3C3C3D4048535E666D7376
757576746E6961585048433E3C3A3937
77727E93A6A5A59DA6B8BEC0C0B9B3AB9B785D514B474240
3E3E3E3D3C3B3A3A3A3B3A3A3B3B3C3D4049546068717B7C
7B7B7B7877736E64594F45403C3B3837
807893A9B6B7B7B2ABADB6B2B8B5A89D856B59554F4B4842
3E3D3C3C3C3B3B3A3A3B393A3B3B3B3E4046535F6A72797F
8082807F7B79726B60564A433D3A3837
827F9DB1BBBDBFB8B3A1A3A8A89F978570605757524F4A43
403E3D3C3D3A3A3B383A393A3B3B3C3F4147535B69747980
8485878481807C73695D4F443E3B3A36
8889A7B8BFC4C6BEB7A996918F877E716357565953504A48
3F3D3C3D3C3B383B3A393A39393B3C3E40454F5A66737D82
858988868884807A6F6352463E3C3935
8B8CA9B7C1C7C6C2BAAB908076766F665B585556514F4E49
423E3C3D3B3B3A3A3A393938383A3B3F40444C5864748082
83878A8F8E84817C74695849403B3936
8D8BAABAC4CAC0BDB8AB917A6F6B65605A55535450504E4A
453E3D3D3C3A3A393A3A3939393B3C3E4044495261737E83
83888F919188837F766B5C4C403D3A37
84859FB7BEC2BEB7B3A98B706963615C5B555552504F4C4B
45403D3D3B3B3A39393A393A3A3B3D3D3F44485263767F83
858B9194928B84807B6F5F4D413C3938
7D778FAAB3B6B6B4AB9D806D5F5F5C5B5952524E4F4F4C47
443F3D3C3B3A383839383B393A3B3C3D3E42465061727D81
868D9194928E867F796E5F4E423B3937
75718194A1A9ADA89F8B75675E5C5B5A595152504E4F4D49
423E3C3B3B3A3A3A3A3A393A3A3A3B3C3F41464F606E7B83
898F93928E8C877F746C5E4E413C3937
6C69717B878C9593877569615D5D59595950504E4D4C4A48
423B3D3B3B383738393A3A39393A3B3D3D41454D5C6E7A81
888F91908B88857E766B5B4B403B3837
6464696E76777B756C68645F5C5B5B59574F4D4F4C4B4A46
3F3C3D3B3A38383939393A393A3A3B3C3D40444B5A6E7B82
898E8E8E8B88837D746B58483F3C3835
5E5D62646769696664615E5C5A595A58565249494A4B4642
3D3B3A3B393938373A3B3A393A3B3B3C3E3F4349566C7982
888C8A8C8884817A736753453D3A3835
59595E5F5D6162605D57585957565856524D49454745423D
3A3B3A3939383937383A3A393A3C3C3C3D3E42475469787F
85898A88827D7B776B604E423C383736
5357585B5B5E5C5A5856505253545553504943403E3E3E3C
3B3B3B3A3A3839383B3939383A3A3C3B3C3E41465264737B
828686827D74706E6456473F3B373636
4C5255585758555653504A494C51524E4A43413F3C3D3C3B
3B3C3B3B3A3939393A3A39393A3B3B3B3C3D40434D5F6D7A
7F81807A7468635F584D423C3A363635
444D52555453514F4E4A444345464746433F3E3C3C3B3B3B
3B3A3A3939383A393939393A3A3A3A3A3B3E3E4048556571
787B7A746A5E56514B443F3B38373535
42474E5154514D4948444241424243413F3D3D3D3A3A3A39
3B393A39393939383A393A3A3B3B3B393A3C3E3F454E5966
6D72706B61544D46433F3D3A38353535
4042454A4B48444342413F3E3F3E3F3E3D3C3C3B3A393A3A
3B3939393A3A393A3B38393A3A3C3C3B3B3D3D3F42485059
62686561574D45413F3C3A3836353535
4040424444424040403E3D3D3D3D3E3D3B3C3A39393B3A3A
39393A393939393A3A39393A3B3B3C3C3A3D3E3E4143484E
545B5B564E48413E3D3B393737353535
3E3E3F3E3F3E3F3D3E3D3D3D3C3B3D3D3B3A393A38393A3A
3A3A3A393838383A3A39393A3A3A3B3A3B3B3B3D3E404346
494B4C4945403D3B3A3A383737363433
3B3D3C3D3F3D3C3D3D3B3C3D3B3D3B3B3A3B393939393939
39393B39393939393939393A3A3A3A3B3A3A3A3B3C3E3E41
42434443413E3C3B3939363636363633
3C3C3C3C3E3D3C3B3C3C3C3C3C3C3A3B3B3B3939393A3A39
3939393A3939393A3A3A3B393A3B393B3A3B3B3A3C3E3F3E
3D3F3E3E3D3E3B383937363535353434
3B3C3B3C3C3C3C3B3A3A3C3B3B3B3A3A3A3C3B3A38393B39
3939393A3939393A393A3A393B3A393B3A3B3B3B3C3C3D3E
3D3D3C3C3D3B3A383838383536353433
3C3B3A3B3B3A3A3A3C3B3C3B3B3A39393A393A3A38383A39
3939393B38393A393A393B3A393A3939393A393B3A3B3B3D
3B3B3C3B3A3939383737363535353433
3B3B393A3B3B393B3B3C3C3A3A3A3A3A3A3B3A3B39393839
3839393A393A3939393A3A3938373939393837393A3A3B3B
3B3A3A39383838383636353535353434
393B3A3B3B3B393A3A3B3A3A3A393A3A3939383A3938393A
393938383939393938393A3938393838393737373A393839
39373939383737383737363535353534
383C3B3B3C3A3A3A3B3A393A3A3A3A3A393A393939393939
3938383939383838393A3938383938383A38383739393838
39383937373737373536363634353433
3A3A393A3B3A3A393A393B39393A3A3B3B3B383738383738
3939383939393736383A3637373938373738373838383738
38373737383636353635353434343333
3A39373B3A3A3A393A3A3A3B393A3A3A393B393939383938
3A393837383A373738383838383838383737373939383838
38373737363535353534353434343333
3A38393A3A3A393A39393A3A3A3A393A3A3A39393939393A
3837373738383838373838393A3838383837383A38383938
38363736363636353533353434343333
3B3A393B3A3B3A3A3A38393A3A3B3B3B3A39383A3938373A
39393737393938383738373A393937373837383A38393938
37373636353535353434343534343334
3939393B3B373A393939383A393A3B3A393939393837373A
393838383838383736383838383838373837373838393938
38363535353535353534343435343332
3839383A39383A3A39393838383838383938383837383737
383938383739373637373737383837373636363837383736
36363535353333343634343534343332
3739393938383A3939393938383738383938393836373737
383839373737373836353537373736363635363737373636
36353634343535363534353434343333
3739393A38393A3839393939393939393939383737373638
393938383737373737363738373937363637373737373637
36363534343636363535353634333334
3939383A393839383839393938383A393A39373637363738
373838383636383637353637373938383638383836383737
36363633343534343435363535353333
373A3A3B393838383839383A383839393839373738383638
373637373534363637363637373739373738383837373736
35363434343434333436353434343433
3739383A3939383838373837393939383838383837373637
373636363635363637363637373738373738373839373635
36363534343434333334343433333333
38393738393A393939383838383839383837373836363739
363837373736363537383737373738373737363738383635
36353435343534343435343433333232
373838393738383937383737373838383838383836363638
383737373736373637363737373837383838373738383736
35353434343534333334343534343333
383838393738383837373737383738383739373737373637
363837373738373637363737363536383737373838373736
35353435343434333333343433333333
373737383738383837383737373736373638373736363738
373738373737363536363737383737373736363838383837
36353534343434343233333333333334
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{322, 153.25},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000520000VA000`40O003h00Oogoo@goo003oOom3
Ool00?mood=oo`00ogoo@goo0008OonB000=OonB0009Ool000Qoo`03001oogoo08ioo`03001oogoo
00]oo`03001oogoo08ioo`03001oogoo00Moo`0027oo00<007ooOol0SWoo00<007ooOol02goo00<0
07ooOol0SWoo00<007ooOol01goo0008Ool00`00Oomoo`2>Ool00`00Oomoo`0;Ool00`00Oomoo`2>
Ool00`00Oomoo`07Ool000Qoo`03001oogoo03XHaP<Li`036<HLiaS600PLi`078@PU:BU:;F/mkdic
DY@00UJe0U:D00A>Ld8@<H`U:@LQ208U:@03:DX]Jc6<008aS003=JdaS3F]00De[@8aS08]J`04:DXU
:BDY8@P47>L00aS67>LHaP027>L36<H67>L28@P29BT3Ool00`00Oomoo`0;Ool00`00Oomoo`1_7>L2
6<H27>L96<H27>L46<H57>L48@P3Ool00`00Oomoo`07Ool000Qoo`03001oogoo03`HaP037>LHaQS6
008Li`<HaPDLi`058@PYBRe[@Q1>L`03E[D3DY@00dHa>LhU:@078@P29BT00bU:;F/aS004<H`5=Jd3
<H`2;F/012U:9BTU:B481AcW0QS600<LiaS66<H011S611cW0R4800<U:BU:Ool00Woo00<007ooOol0
2goo00<007ooOol0KacW0QS60QcW2AS60QcW11S61AcW12480goo00<007ooOol01goo0008Ool00`00
Oomoo`0o6<H00acW6<HLi`036<H47>L01B489BTaS4YBDY@00e[F0UJe00ABU4Ha?NlYBPDQ20049BTY
BRU::DX2;F/6<H`4=Jd2<H`3;F/012U:9BTQ22481acW1aS60acW00<Q22DY9BT00RU:0goo00<007oo
Ool02goo00<007ooOol07QcW1b48BQcW2aS63AcW0R480RDY0goo00<007ooOol01goo0008Ool00`00
Oomoo`146<H57>L01B489BTaS4YBDY@00e[F0UJe00ABU4YB?NlYBP@Q20039BT]Jbe[008]J`<aS003
=JdaS36<00<aS0<e[@04<H`]Jbe[;F/2:DX00bDY8@PLi`047>L:6<H37>L00b489BTU:@02:DX3Ool0
0`00Oomoo`0;Ool00`00Oomoo`0N7>L78@Q:7>L;6<H=7>L28@P29BT3Ool00`00Oomoo`07Ool000Qo
o`03001oogoo04@HaPDLi`068@PU:C6<AS5BU5Je0U[F0UJe00ABU4YB>LhU:@@Q2003:DXaS3F]00Le
[@05<H`e[C6<<H`e[@03<H`3;F/012U:9BTU:B480acW0aS600<LiaS66<H01QS600@Lib488@PQ208U
:@8YBP=oo`03001oogoo00]oo`03001oogoo01`Li`8Q23/Li`8HaR`Li`@Q20=oo`03001oogoo00Mo
o`0027oo00<007ooOol0A1S61QcW00DU:Be[>Li>Le:D009JeP9F]@04DYA6<CF]9BT38@P012DY;F/a
S3F]1CW>0cF]1c6<0Re[0RU:00<U:B487>L00acW0QS600<LiaS66<H01aS600@Lib488@PQ208U:@8Y
BP=oo`03001oogoo00]oo`03001oogoo01`Li`8Q23/Li`8HaR`Li`@Q20=oo`03001oogoo00Moo`00
27oo00<007ooOol0A1S61QcW00DU:Be[>Li>Le:D009JeP9F]@04DYA6<CF]9BT38@P012DY;F/aS3F]
1CW>0cF]1c6<0Re[0RU:00<U:B487>L00acW0QS600<LiaS66<H01aS600@Lib488@PQ208U:@8YBP=o
o`03001oogoo00]oo`03001oogoo01`Li`8Q23/Li`8HaR`Li`@Q20=oo`03001oogoo00Moo`0027oo
00<007ooOol0A1S61QcW00DQ22U:=Je244ic00ABU003BU9242e[00@Q20049BT]JcF]>Lh4?Nl00d8@
?NlicP03=Jd5<H`2;F/012U:9BTU:B480acW3AS600@Lib488@PQ208U:@8YBP=oo`03001oogoo00]o
o`03001oogoo014Li`<Q20@Li`8Q20@Li`LQ23@Li`8HaQPLi`@HaQ8Li`8Q20=oo`03001oogoo00Mo
o`0027oo00<007ooOol0A1S61QcW00DQ22U:;F/icT8@009:DP96<@03@Q0e[BDY00@Q2004:DX]JcF]
>Lh3?Nl2@Q02?Nl013W>=Jde[C6<1Be[0RU:00<U:B487>L00QcW3QS60acW00DQ22DY9BTU:BU:00=o
o`03001oogoo00]oo`03001oogoo014Li`<Q20@Li`8Q20@Li`LQ23@Li`8HaQPLi`@HaQ8Li`8Q20=o
o`03001oogoo00Moo`0027oo00<007ooOol0A1S61QcW00HQ22DY:DXaS3F]?Nl3>Lh00c6<:DXQ2004
8@P012U:<H`icSg_0T8@00<mkd8@@Q0013g_0SF]0be[0bU:00<U:B488@P00QcW0QS600<LiaS66<H0
21S600<LiaS66<H00QcW0R480bDY0goo00<007ooOol02goo00<007ooOol03AcW1b481QcW0R480QcW
1b48@acW0QS61acW0QS60QcW0QS651cW0goo00<007ooOol01goo0008Ool00`00Oomoo`156<H57>L0
12489BTYBRU:0be[0RU:00DU:B488@PQ21cW008Q2004:DXaS3W>?Nl6@Q03?Nl2>Lh0136<:DXYBRU:
0RDY0R480acW41S60acW00@Q22DY9BTU:@=oo`03001oogoo00]oo`03001oogoo00dLi`LQ20HLi`8Q
208Li`LQ24<Li`8HaPLLi`8HaP8Li`8HaQ@Li`=oo`03001oogoo00Moo`0027oo00<007ooOol0B1S6
0acW0R480RDY0RU:0RDY0b480acW00DQ22U:<H`e[Cg_00Q2408mk`04>Lhe[Be[;F/29BT00b487>LL
i`027>LA6<H47>L00b489BTU:@03Ool00`00Oomoo`0;Ool00`00Oomoo`0=7>L28@P97>L=8@PU7>L2
6<HJ7>L26<H;7>L76<HA7>L3Ool00`00Oomoo`07Ool000Qoo`03001oogoo04PHaP<Li`038@PLib48
00<U:@<Q20DLi`058@PU:Be[=JdicP02?Nl5@Q03?Nl2>Lh2;F/00bDY8@PLi`057>LB6<H27>L28@P0
1BDYOomoogoo00003Goo00<007ooOol03AcW0R482AcW3B489AcW0QS66QcW0QS62acW1aS64AcW0goo
00<007ooOol01goo0008Ool00`00Oomoo`146<H97>L68@P67>L012489BTYBS6<0cW>1Sg_13W>0S6<
00<YBR488@P01QcW4AS60acW0R480goo00<007ooOol02goo00<007ooOol02acW0R480QcW0R480acW
5B48C1cW0QS651cW0goo00<007ooOol01goo0008Ool00`00Oomoo`176<HB7>L28@P00bU:<H`e[@03
>Lh013g_>Lhmkcg_0SW>0cF]0S6<00<YBR487>L011cW4aS611cW00DQ27ooOomoo`0000eoo`03001o
ogoo00/Li`8Q208Li`8Q20<LiaDQ24`Li`8HaQ@Li`=oo`03001oogoo00Moo`0027oo00<007ooOol0
B1S64QcW00@Q22DY;F/aS0<e[@<icP03?NlicSF]00<e[@8aS003:DXQ21cW00@Lia@HaP@Li`=oo`03
001oogoo00]oo`03001oogoo00TQ208Lia`Q22`Li`8HaP8Li`8HaS8Li`=oo`03001oogoo00Moo`00
27oo00<007ooOol0AaS611cW00<HaQcW7>L031cW0R4800@YBRe[<H`aS0<e[@8icP05=JdaS36<<H`e
[@02<H`00bU:8@PLi`047>L:6<H00acW6<HHaP076<H47>L3Ool00`00Oomoo`0;Ool00`00Oomoo`09
8@P27>LL8@P/7>L26<H27>L26<Hb7>L3Ool00`00Oomoo`07Ool000Qoo`03001oogoo04DHaQHLi`03
8@PU:BU:008]J`04<H`e[CF]=Jd5<H`01CF]<H`aS2U:8@P01AcW2aS600<LiaS66<H01QS611cW0goo
00<007ooOol02goo00<007ooOol00QcW1B480QcW3B482bDY2R48:QcW0QS6=1cW0goo00<007ooOol0
1goo0008Ool00`00Oomoo`156<H57>L00aS67>LLi`0?7>L00b489BTYBP02:DX012e[<H`aS36<0Re[
0c6<0Re[00<U:B487>L011cW2QS60QcW1AS60QcW00<HaQcW7>L00QcW0goo00<007ooOol02goo00<0
07ooOol00QcW1B480QcW3B482bDY2R48:QcW0QS6=1cW0goo00<007ooOol01goo0008Ool00`00Oomo
o`156<H57>L00aS67>LLi`0?7>L00b489BTYBP02:DX012e[<H`aS36<0Re[0c6<0Re[00<U:B487>L0
11cW2QS60QcW1AS60QcW00<HaQcW7>L00QcW0goo00<007ooOol02goo00<007ooOol00QcW1B480QcW
3B482bDY2R48:QcW0QS6=1cW0goo00<007ooOol01goo0008Ool00`00Oomoo`156<HG7>L48@P012DY
;F/]Jc6<1Re[0RU:00<Q21cW7>L011cW2aS600<LiaS66<H00aS60QcW00<HaQcW7>L00QcW0goo00<0
07ooOol02goo00<007ooOol052480RDY1RU:1bDY2248;1cW0QS6<QcW0goo00<007ooOol01goo0008
Ool00`00Oomoo`0j6<H00acW6<HHaP056<H00acW6<HHaP026<H27>L00aS67>LLi`026<H?7>L38@P2
9BT8:DX29BT00b487>LLi`047>L00aS67>LHaP0B6<H00acW6<HHaP03Ool00`00Oomoo`0;Ool00`00
Oomoo`0D8@P29BT6:DX79BT88@P/7>L26<Hb7>L3Ool00`00Oomoo`07Ool000Qoo`03001oogoo03XH
aP057>LHaQcW6<HLi`026<H011cW6<HHaQS66AcW12481BDY00<YBRDY9BT00b4811cW0QS60QcW11S6
0QcW41S60goo00<007ooOol02goo00<007ooOol03b480RDY0bU:12e[136<1Be[12DY2B48GAcW0goo
00<007ooOol01goo0008Ool01000OomooaBU=aS60QcW00@HaQcW6<HLi`LHaP8Li`036<HLiacW01HL
i`XQ20LLi`036<HLiacW01LHaP=oo`03001oogoo00]oo`03001oogoo00lQ208U:@<YBP@]J`@aS0D]
J`@U:@TQ25dLi`=oo`03001oogoo00Moo`0027oo00<007ooOol0=1S600<LiaS66<H00acW00<HaQcW
6<H00QS600<LiaS67>L00aS60QcW00<HaQcW7>L011cW00<HaQcW7>L04AcW12482AcW71S60goo00<0
07ooOol02goo00<007ooOol012482bDY0RU:0be[0S6<0SF]13g_0SW>0cF]0Re[0RU:0RDY1b488QcW
0aS6>1cW0goo00<007ooOol01goo0008Ool00`00Oomoo`0b6<H011cW6<HHaQS611cW00@HaQcW6<HL
i`THaRTLia/HaP=oo`03001oogoo00]oo`03001oogoo00@Q20/U:@8YBP<]J`8aS08e[@@mk`8icP<e
[@8]J`8YBP8U:@LQ228Li`<HaSPLi`=oo`03001oogoo00Moo`0027oo00<007ooOol021S600<DYAS6
6<H09aS600@LiaS66<HHaP8Li`@HaP037>LHaQS6008HaP047>LHaQcW6<H27>L00aS67>LLi`067>L0
0aS67>LLi`0M7>LK6<H3Ool00`00Oomoo`0;Ool00`00Oomoo`099BT4:DX4;F/3<H`2?Nl2AS46BU83
@Q02>Lh2;F/2:DX98@Pf7>L28@PS7>L3Ool00`00Oomoo`07Ool000Qoo`03001oogoo00PHaP035:DH
aQS602LHaP037>LHaQS600HHaP047>LHaQS67>L26<H011cW6<HHaQS60QcW0QS69acW4QS600<LiaS6
6<H01QS60goo00<007ooOol02goo00<007ooOol02BDY12U:12e[0c6<0Sg_0THa1TYB0d8@0SW>0Re[
0RU:2B48=QcW0R488acW0goo00<007ooOol01goo0008Ool00`00Oomoo`0b6<H01AcW6<HHaQS67>L0
2AS60acW11S62AcW00<HaQcW7>L07QcW00<HaQcW6<H03aS600<LiaS66<H01AS60goo00<007ooOol0
2goo00<007ooOol02BU:12e[0S6<0SF]0cg_0THa0Tic1U:D0dYB0THa0SW>0Re[0RDY2B48<1cW0R48
0QcW1b487QcW0goo00<007ooOol01goo0008Ool00`00Oomoo`0c6<H01AcW6<HHaQS67>L01QS600<L
iaS67>L00acW0aS600<LiaS66<H091cW00<HaQcW7>L06QS60goo00<007ooOol02goo00<007ooOol0
2BU:12e[0S6<0SF]0cg_0THa0Tic1U:D0dYB0THa0SW>0Re[0RDY2B48<1cW0R480QcW1b487QcW0goo
00<007ooOol01goo0008Ool00`00Oomoo`0a6<H00acW6<HHaP036<H01AcW6<HHaQcW6<H0>1cW0QS6
00<LiaS66<H04QS60goo00<007ooOol02goo00<007ooOol02Be[1S6<0SW>0dYB0U:D15Je15[F0eJe
0Tic0THa0SF]0RU:0RDY1B48<1cW4b4851cW11S60goo00<007ooOol01goo0008Ool00`00Oomoo`0e
6<H00acW6<HHaP046<H27>L00aS67>LHaP036<H00acW6<HHaP0[7>LI6<H3Ool00`00Oomoo`0;Ool0
0`00Oomoo`09;F/6<H`2>Lh3BU82DY@4E[D4F]H3E[D2CW<2AS42=Jd2:DX29BT58@P`7>LC8@PD7>L4
6<H3Ool00`00Oomoo`07Ool000Qoo`03001oogoo03DHaP037>LHaQS600@HaP8Li`036<HLiaS600<H
aP037>LHaQS602/LiaTHaP=oo`03001oogoo00]oo`03001oogoo00T]J`HaS08icP=:DP9BU0AF]@AJ
eP=F]@9>L`96<@8e[@8YBP8U:@DQ230Lia<Q21@Li`@HaP=oo`03001oogoo00Moo`0027oo00<007oo
Ool0<AS60QcW2QS61acW00<HaQcW7>L0:acW1aS60QcW1AS60acW1aS600DLigooOomoo`0000eoo`03
001oogoo00@aS0<]J`HaS08e[@96<@=BU09JePQNm`=JeP9F]@9>L`8mk`8]J`8YBP<U:@@Q22/Li`DQ
20dU:@HQ20lLi`DHaP8Li`=oo`03001oogoo00Moo`0027oo00<007ooOol021S60QBU9aS60QcW0aS6
00<LiaS66<H01QS61AcW00<HaQcW7>L0:AcW00<HaQcW6<H01aS600<LiaS66<H02QS60QcW00<HaQcW
Ool00Woo00<007ooOol02goo00<007ooOol0136<0be[1S6<0SF]0THa0e:D0U[F25kg0e[F0UJe0Tic
0Sg_0Re[0RU:0bDY1248:acW1B483BDY1R483acW1AS60QcW0goo00<007ooOol01goo0008Ool00`00
Oomoo`0:6<H00aBU6<HHaP0W6<H37>L46<H47>L01AS67>LLiacW6<H0;acW1QS60acW0QS600@LiaS6
6<HHaPDLi`046<HLiacW7>L3Ool00`00Oomoo`0;Ool00`00Oomoo`0;<H`2=Jd2>Lh2CW<3E[D4G_L2
HaP7G_L2F]H2DY@2AS42<H`5:DX29BT28@PY7>L28@P59BT4:DX4;F/5:DX49BT48@P@7>L46<H3Ool0
0`00Oomoo`07Ool000Qoo`03001oogoo02lHaP037>LHaQS6008HaP8Li`LHaP037>LHaQS600DLi`<H
aRPLi`<HaP037>LHaQS600@HaP057>LHaQS66<HLi`026<H:7>L3Ool00`00Oomoo`0;Ool00`00Oomo
o`0;<H`2=Jd2>Lh2CW<3E[D4G_L2HaP7G_L2F]H2DY@2AS42<H`5:DX29BT28@PY7>L28@P59BT4:DX4
;F/5:DX49BT48@P@7>L46<H3Ool00`00Oomoo`07Ool000Qoo`03001oogoo00PHaP8DYC4HaP037>LH
aQcW00HLi`036<HLiacW02TLi`046<HLiaS66<H37>L26<H27>L36<H00acW6<HHaP066<H37>L01B48
Oomoogoo00003Goo00<007ooOol0136<2CF]0T8@0U:D0e[F0Ukg0V<H16Li0V<H0ekg0U[F0UJe0TYB
0SF]0Re[0bU:0RDY0R48:AcW0R480bDY0RU:3Be[0RU:12DY1B483AcW11S60goo00<007ooOol01goo
0008Ool00`00Oomoo`0l6<H37>L00aS67>LLi`026<HI7>L00aS67>LLi`0:7>L26<H00acW6<HHaP02
7>L00aS67>LHaP026<H47>L<6<H37>L00b489BUoo`02Ool00`00Oomoo`0;Ool00`00Oomoo`04<H`9
=Jd2@Q02DY@3F]H2G_L2HaP4IcT2HaP3G_L2F]H2E[D2BU82=Jd2;F/3:DX29BT28@PY7>L28@P39BT2
:DX=;F/2:DX49BT58@P=7>L46<H3Ool00`00Oomoo`07Ool000Qoo`03001oogoo02THaP037>LHaQS6
00<HaP047>LHaQcW7>L86<H37>L00aS67>LLi`0;7>L00aS67>LLi`0H7>L00aS67>LLi`087>L56<H3
7>L86<H011cW6<HHaQS60QcW00<Q22DY9BT00goo00<007ooOol02goo00<007ooOol02cF]0SW>0T8@
0U:D0ekg0V<H1VLi1F<H0U[F0UJe0TYB0SW>0Re[0bDY12489acW0R480RDY0bU:0Re[2c6<1Re[12DY
1B483AcW0QS60goo00<007ooOol01goo0008Ool00`00Oomoo`0k6<H77>L26<HC7>L00aS67>LLi`09
7>L00aS67>LLi`0;7>LA6<H00acW6<HLi`037>L00b489BTU:@03Ool00`00Oomoo`0;Ool00`00Oomo
o`0;=Jd2>Lh2@Q02DY@3G_L2HaP6IcT5HaP2F]H2E[D2BU82>Lh2;F/39BT48@PW7>L28@P29BT3:DX2
;F/;<H`6;F/49BT58@P=7>L26<H3Ool00`00Oomoo`07Ool000Qoo`04001oogoo5:D46<H65:DT6<H0
11cW6<HHaQcW21S60QcW00<HaQcW7>L0;acW00<HaQcW7>L00aS611cW1AS600@LiaS66<HHaPDLi`8Q
208U:@=oo`03001oogoo00]oo`03001oogoo00Te[@@icP92409BU0=Nm`AS60AW>@9S60=Nm`9JeP9F
]@9:DP8e[@8]J`<U:@@Q22LLi`8Q208U:@<YBP8]J`8aS0/e[@@aS08YBP8U:@LQ20TLi`@HaP=oo`03
001oogoo00Moo`0027oo00<007ooOol021S600<DYAS66<H09AS600<LiaS66<H021S600<LiaS66<H0
11cW00<HaQcW7>L0;QcW11S60acW00<HaQcW6<H011S61QcW0R480RDY0goo00<007ooOol02goo00<0
07ooOol02CF]13W>0T8@0U:D0ekg16<H16Li0V<H0ekg0U[F0UJe0TYB0SF]0Re[0bDY12489acW0R48
0RDY0bU:0Re[0S6<2cF]136<0RU:0RDY1b482AcW11S60goo00<007ooOol01goo0008Ool00`00Oomo
o`086<H00aBU6<HHaP0P6<H37>L>6<H77>L011S67>LDYABU9QcW00<HaQcW7>L00acW0QS61AcW1QS6
1acW0R480RDY0goo00<007ooOol02goo00<007ooOol00SF]1cW>13g_0T8@0Tic0ekg16<H16Li0V<H
0ekg0U[F0UJe0TYB0SF]0RU:0bDY12489AcW12480RU:0be[0S6<0SF]3CW>0S6<0Re[0RU:1BDY1248
1acW11S60goo00<007ooOol01goo0008Ool00`00Oomoo`086<H00aBU6<HHaP0P6<H37>L>6<H77>L0
11S67>LDYABU9QcW00<HaQcW7>L00acW0QS61AcW1QS61acW0R480RDY0goo00<007ooOol02goo00<0
07ooOol00SF]1cW>13g_0T8@0Tic0ekg16<H16Li0V<H0ekg0U[F0UJe0TYB0SF]0RU:0bDY12489AcW
12480RU:0be[0S6<0SF]3CW>0S6<0Re[0RU:1BDY12481acW11S60goo00<007ooOol01goo0008Ool0
1000OomooaBU11S611BU:1S600@LiaS66<HLi`HHaP037>LHaQcW03`Li`036<HLiacW00@HaPHLi`04
8@PU:BDY9BT3Ool00`00Oomoo`0;Ool00`00Oomoo`02=Jd7>Lh4?Nl2@Q02CW<3G_L4HaP4IcT2HaP3
G_L2F]H2E[D2BU82=Jd2:DX39BT48@PU7>L48@P2:DX3;F/2<H`2=Jd=>Lh2<H`2;F/2:DX59BT48@P7
7>L46<H3Ool00`00Oomoo`07Ool000Qoo`04001oogoo5:D66<H35:DV6<H011cW6<HLiacW21S60acW
00<HaQcW7>L0<AcW00<HaQcW7>L01QcW1AS61acW00<Q22DY9BT00goo00<007ooOol02goo00<007oo
Ool013F]0cW>0T8@1THa0Tic0eJe0Ukg26<H0ekg0U[F0U:D0THa0S6<0RU:0bDY0R489acW0R480RDY
0RU:0be[0S6<0SF]3CW>13F]0S6<0be[0RU:0RDY0R482AcW0QS60goo00<007ooOol01goo0008Ool0
0`00Oomoo`076<H00aBU6<HHaP0V6<H011cW6<HHaQcW0aS61acW00<HaQcW7>L0:1cW0aS61QcW0QS6
00<LiaS66<H01QcW11S61acW0R4800DU:GooOomoo`0000eoo`03001oogoo00@e[@<icP9240I6<@9>
L`=F]@9Nm`QS60=Nm`9JeP9BU096<@8aS08YBP<U:@8Q22LLi`8Q208U:@8YBP<]J`8aS08e[@dicP@e
[@8aS0<]J`8YBP8U:@8Q20TLi`8HaP=oo`03001oogoo00Moo`0027oo00<007ooOol01aS600<DYAS6
6<H091S60QcW1QS611cW0QS60QcW00<HaQcW7>L0:AcW0QS61QcW0QS621cW1QS61QcW0R4800DU:Goo
Oomoo`0000eoo`03001oogoo00@icP<mk`9:DPIBU09>L`=BU0ANm`AS609Nm`=JeP9F]@9>L`8mk`8]
J`8YBP<U:@HQ22<Li`8Q208U:@8YBP<aS08e[@8icPdmk`@icP8e[@<aS08]J`8U:@@Q20LLi`8HaP=o
o`03001oogoo00Moo`0027oo00<007ooOol01aS600@DYAS65:DDYB<HaP8Li`046<HLiaS67>L66<H^
7>L01aS67>LLiacW6<HLiaS600@Li`046<HLiaS67>L56<H011cW6<HHaQS61acW0b4800DU:GooOomo
o`0000eoo`03001oogoo00@icP<mk`9:DPIBU09>L`=BU0ANm`AS609Nm`=JeP9F]@9>L`8mk`8]J`8Y
BP<U:@HQ22<Li`8Q208U:@8YBP<aS08e[@8icPdmk`@icP8e[@<aS08]J`8U:@@Q20LLi`8HaP=oo`03
001oogoo00Moo`0027oo00<007ooOol021S60QBU9QS60QcW0QS600<LiaS66<H011S611cW00<HaQcW
7>L09QcW00<HaQcW7>L02QcW0QS60acW11S600<LiaS67>L01AcW0R480bDY0goo00<007ooOol02goo
00<007ooOol00T8@0Sg_0dYB0UJe25[F1EJe15[F0Ukg0U[F0eJe0Tic0T8@0SF]0Re[0RU:1bDY0R48
8acW12480RU:0be[0SF]0SW>13g_1d8@1Sg_0SW>0cF]0S6<0RU:0RDY0R481acW0QS60goo00<007oo
Ool01goo0008Ool00`00Oomoo`076<H00aBU6<HDY@0V6<H01AcW6<HHaQS67>L00aS60QcW00<HaQcW
7>L0:QcW00<HaQcW6<H021cW1aS62acW0b4812DY0goo00<007ooOol02goo00<007ooOol00T8@0Sg_
0dYB0UJe25[F1EJe15[F0Ukg0U[F0eJe0Tic0T8@0SF]0Re[0RU:1bDY0R488acW12480RU:0be[0SF]
0SW>13g_1d8@1Sg_0SW>0cF]0S6<0RU:0RDY0R481acW0QS60goo00<007ooOol01goo0008Ool00`00
Oomoo`096<H00aBU6<HHaP0N6<H00acW6<HHaP046<H00acW6<HLi`026<H00acW6<HLi`037>L00aS6
7>LLi`0d7>L011S67>LHaQcW0QS60acW00<HaQcW7>L01AcW0R481BDY0goo00<007ooOol02goo00<0
07ooOol00T8@0Sg_0dic0U[F25kg0e[F15:D15Je0Tic0dYB0T8@0SW>0S6<1bU:12DY12488AcW1248
0RU:0be[0SF]0SW>0Sg_3d8@0Sg_0cW>0SF]0Re[0RDY0R481acW0QS60goo00<007ooOol01goo0008
Ool00`00Oomoo`086<H25:DV6<H011cW6<HHaQS611cW0QS61acW00<HaQcW7>L091cW00@HaQcW6<HH
aP@Li`8HaP037>LHaQS600@HaP@Li`036<HLiacW00@Li`8Q208U:@038@PU:BDY00=oo`03001oogoo
00]oo`03001oogoo0092408mk`=>L`9JePQNm`=JePABU0AF]@9>L`=:DP92408icP8aS0LYBP@U:@@Q
224Li`@Q208YBP<]J`8e[@8icP8mk`m2408mk`<icP8e[@8]J`8U:@8Q20LLi`8HaP=oo`03001oogoo
00Moo`0027oo00<007ooOol021S60aBU9AS600<LiaS66<H00QS60acW0QS6;QcW00<HaQcW7>L01AcW
0QS600<LiaS66<H011S60QcW00<HaQcW7>L01AcW0b481BDY0goo00<007ooOol02goo00<007ooOol0
14Ha0e:D15kg16<H0Ukg0e[F0UJe14YB0THa0T8@0cg_0SW>0S6<12U:0Re[1BU:12DY8acW12480RDY
0be[0S6<0SW>0Sg_148@1DHa0T8@0THa148@0cg_0SF]0S6<0RU:0R481acW0QS60goo00<007ooOol0
1goo0008Ool01000OomooaBU0aS600LDYAS66<HHaQBU6<HDY@0T6<H00acW6<HLi`067>L26<Hj7>L0
0aS67>LHaP027>L00aS67>LLi`077>L38@P59BT3Ool00`00Oomoo`0;Ool00`00Oomoo`04AS43DY@4
G_L4HaP2G_L3F]H2E[D4BU82AS42@Q03?Nl2>Lh2<H`4:DX2;F/5:DX49BTS7>L48@P29BT3;F/2<H`2
>Lh2?Nl4@Q05AS42@Q02AS44@Q03?Nl2=Jd2<H`2:DX28@P77>L26<H3Ool00`00Oomoo`07Ool000Qo
o`03001oogoo02lHaP037>LHaQcW03hLi`8HaP@Li`036<HLiacW00XLi`<Q20DU:@=oo`03001oogoo
00]oo`03001oogoo00A6<@=F]@9JePQS60=Nm`9F]@9:DP9240@icP<e[@8aS0@]J`LYBPHU:@8Q224L
i`@Q208U:@<]J`8aS08icPU240I6<@A240<mk`8icP8e[@8]J`8U:@8Q20DLi`8HaP=oo`03001oogoo
00Moo`0027oo00<007ooOol0;aS600<LiaS67>L0?QcW0QS611cW00<HaQcW7>L02QcW0b481BDY0goo
00<007ooOol02goo00<007ooOol014Ha0eJe0U[F26<H0ekg0UJe0TYB0T8@13W>0cF]0S6<12e[1bU:
1RDY0R488AcW12480RDY0be[0S6<0SW>2D8@1THa148@0cg_0SW>0SF]0Re[0RDY0R481AcW0QS60goo
00<007ooOol01goo0008Ool00`00Oomoo`0b6<H00acW6<HLi`037>L26<Hh7>L00aS67>LLi`087>L0
0aS67>LLi`037>L38@P59BT3Ool00`00Oomoo`0;Ool00`00Oomoo`04AS43E[D2F]H8HaP3G_L2E[D2
BU82@Q04>Lh3=Jd2<H`4;F/7:DX69BT28@PQ7>L48@P29BT3;F/2<H`2>Lh9@Q06AS44@Q03?Nl2>Lh2
=Jd2;F/29BT28@P57>L26<H3Ool00`00Oomoo`07Ool000Qoo`03001oogoo02dHaP037>LHaQS6008H
aP037>LHaQcW00PLi`036<HLiacW030Li`036<HLiaS600@Li`<HaP@Li`036<HLiacW00<Li`@Q20<U
:@=oo`03001oogoo00]oo`03001oogoo00A6<@=F]@9Nm`9S609W>@9S60ENm`9F]@9:DP8mk`@e[@Da
S08]J`/YBP@U:@8Q224Li`@Q208U:@<YBP8aS08icP8mk`A240E6<@A:DP96<@9240<mk`8icP8e[@8]
J`8U:@8Q20DLi`8HaP=oo`03001oogoo00Moo`0027oo00H007ooOolDYAS65:D46<H00aBU6<HHaP0O
6<H00acW6<HHaP066<H47>L00aS67>LLi`0l7>L00aS67>LLi`057>L00aS67>LLi`047>L48@P39BT3
Ool00`00Oomoo`0;Ool00`00Oomoo`04AS43E[D2G_L2HaP2IcT2HaP5G_L2E[D2BU82?Nl4=Jd5<H`2
;F/;:DX49BT28@PQ7>L48@P29BT3:DX2<H`2>Lh2?Nl4@Q05AS44BU82AS42@Q03?Nl2>Lh2=Jd2;F/2
9BT28@P57>L26<H3Ool00`00Oomoo`07Ool000Qoo`04001oogoo5:D86<H00aBU6<HHaP0V6<H00acW
6<HLi`0D7>L00b487>LLi`0U7>L26<H00acW6<HHaP067>L00aS67>LLi`077>L38@P00bDY8@Qoo`02
Ool00`00Oomoo`0;Ool00`00Oomoo`04@Q03CW<2F]H2G_L2HaP2G_L5F]H2E[D2AS42>Lh2=Jd5<H`4
;F/9:DX69BT48@PQ7>L28@P29BT3:DX2<H`2>Lh2?Nl4@Q03AS46BU82AS45@Q02?Nl2=Jd2;F/29BT2
8@P77>L3Ool00`00Oomoo`07Ool000Qoo`03001oogoo008DY@036<HDYAS6008HaP<DYB/HaSdLi`05
6<HLiaS66<HLi`046<H<7>L48@P3Ool00`00Oomoo`0;Ool00`00Oomoo`04@Q03CW<2F]H2G_L2HaP2
G_L5F]H2E[D2AS42>Lh2=Jd5<H`4;F/9:DX69BT48@PQ7>L28@P29BT3:DX2<H`2>Lh2?Nl4@Q03AS46
BU82AS45@Q02?Nl2=Jd2;F/29BT28@P77>L3Ool00`00Oomoo`07Ool000Qoo`04001oogoo5:D26<H0
11BU6<HHaQS611BU:QS600<LiaS67>L0>AcW00<HaQcW7>L05AcW00<Q21cWOol00Woo00<007ooOol0
2goo00<007ooOol00Sg_0SW>0dHa0UJe25[F0eJe0Tic0T8@0SF]2be[12U:2BDY12488acW12480bU:
0S6<0SW>0Sg_148@0dHa1TYB0THa0T8@1Cg_0SF]0Re[0RDY0R481AcW0QS60goo00<007ooOol01goo
0008Ool01@00OomooaBU6<H00QBU0aS60aBU9QS6A1cW0QS600@LiaS66<HLi`8HaPhLi`058@Qoogoo
Ool0000=Ool00`00Oomoo`02?Nl2>Lh3AS42E[D8F]H3E[D2CW<2@Q02=Jd;;F/4:DX99BT48@PS7>L4
8@P3:DX2<H`2>Lh2?Nl4@Q03AS46BU82AS42@Q05?Nl2=Jd2;F/29BT28@P57>L26<H3Ool00`00Oomo
o`07Ool000Qoo`04001oogoo5:D66<H45:DM6<H00acW6<HLi`036<H00acW6<HLi`0<7>L00aS67>LL
i`0E7>L00b487>LLi`0J7>L46<H67>L46<H00acW6<HHaP077>L01B48Oomoogoo00003Goo00<007oo
Ool013W>0d8@0TYB0U:D1UJe0dic0THa0SW>0S6<2be[1RU:2BDY0R488acW12480bDY0S6<0SF]0Sg_
0T8@1DHa14YB14Ha0T8@0cg_0SW>0SF]0Re[0RDY0R481AcW0QS60goo00<007ooOol01goo0008Ool0
1000OomooaBU<AS60acW00<HaQcW6<H0>QcW00<HaQcW7>L011S611cW1aS61QcW00DQ27ooOomoo`00
00eoo`03001oogoo00@icP=2409:DP9BU0IF]@=>L`96<@8icP8aS0/]J`HYBPTU:@8Q22<Li`@Q20<U
:@8aS08e[@8mk`9240E6<@A:DPA6<@9240<mk`8icP8e[@8]J`8U:@8Q20DLi`8HaP=oo`03001oogoo
00Moo`0027oo00@007ooOolDY@PHaP<DYAlHaP8Li`DHaT0Li`036<HLiacW00@Li`036<HLiacW008H
aP<Li`<HaPDLi`8Q20=oo`03001oogoo00]oo`03001oogoo00@e[@<icP8mk`924096<@A:DP=2408i
cP8e[@8aS0/]J`@YBP/U:@8Q20/Li`8HaQHLi`@Q20<U:@8]J`8e[@8mk`9240E6<@A:DPA6<@9240<m
k`8icP8e[@8]J`8U:@8Q20DLi`8HaP=oo`03001oogoo00Moo`0027oo00@007ooOolDY@<HaP@DY@03
6<HDYABU02PHaP@Li`036<HLiacW04LLi`8HaPHLi`8Q20=oo`03001oogoo00]oo`03001oogoo00@e
[@<icP8mk`924096<@A:DP=2408icP8e[@8aS0/]J`@YBP/U:@8Q20/Li`8HaQHLi`@Q20<U:@8]J`8e
[@8mk`9240E6<@A:DPA6<@9240<mk`8icP8e[@8]J`8U:@8Q20DLi`8HaP=oo`03001oogoo00Moo`00
27oo00@007ooOolDY@<HaP@DY@036<HDYABU02PHaP@Li`036<HLiacW04LLi`8HaPHLi`8Q20=oo`03
001oogoo00]oo`03001oogoo00@e[@<icP8mk`924096<@A:DP=2408icP8e[@8aS0/]J`@YBP/U:@8Q
20/Li`8HaQHLi`@Q20<U:@8]J`8e[@8mk`9240E6<@A:DPA6<@9240<mk`8icP8e[@8]J`8U:@8Q20DL
i`8HaP=oo`03001oogoo00Moo`0027oo00H007ooOolDYAS65:D26<H25:D00aS65:DDY@035:DQ6<H2
7>L26<H00acW6<HLi`187>L00aS67>LHaP036<H011cW6<HHaQS60QcW0R480goo00<007ooOol02goo
00<007ooOol0136<1CF]13W>0Sg_0SW>1CF]0S6<2be[0RU:3BDY0R489AcW12480bDY0Re[0SF]0Sg_
0T8@3DHa0T8@0cg_0SW>0SF]0Re[0RDY1acW0QS60goo00<007ooOol01goo0008Ool00`00Oomoo`02
5:D00aS65:DDY@055:D00aS65:DDY@0U6<H011cW6<HHaQS67acW0b489AcW1AS61acW00<Q22DYOol0
0Woo00<007ooOol02goo00<007ooOol0136<1CF]13W>0Sg_0SW>1CF]0S6<2be[0RU:3BDY0R489AcW
12480bDY0Re[0SF]0Sg_0T8@3DHa0T8@0cg_0SW>0SF]0Re[0RDY1acW0QS60goo00<007ooOol01goo
0008Ool01000OomooaBU0QS61aBU7AS600<LiaS66<H02AS68AcW00<Q21cW7>L06acW00<HaQcW7>L0
51cW0R480goo00<007ooOol02goo00<007ooOol012e[1c6<13F]1c6<3Be[12U:2BDY12483acW0QS6
5QcW0R480bDY0RU:0SF]0Sg_0T8@2dHa148@0cg_0SW>0S6<0RU:0R481acW0QS60goo00<007ooOol0
1goo0008Ool01@00OomooaBU6<H00aBU0QS600<DYAS65:D00aS600<DYAS66<H091S60acW00<HaQcW
7>L051cW00<Q21cW7>L00R480QcW0b486QcW00<HaQcW7>L02QcW0QS62AcW00DQ27ooOomoo`0000eo
o`03001oogoo00@]J`LaS0@e[@LaS0d]J`@YBPTU:@@Q20lLi`8HaQHLi`8Q20<U:@8YBP8e[@8mk`92
40]6<@A240<mk`8icP8aS08YBP8Q20LLi`8HaP=oo`03001oogoo00Moo`0027oo00D007ooOolDYAS6
008DY@DHaP8DYAlHaP037>LHaQS6008Li`036<HLiacW008HaP047>LHaQcW7>L26<HB7>L38@P47>L0
0b487>LQ20028@PR7>L01aS67>LLiacW6<HLiaS600XLi`=oo`03001oogoo00]oo`03001oogoo00/]
J`HaS0<]J`8YBP@]J`@YBP<]J`@YBP@U:@TQ214Li`8HaQHLi`DQ208YBP8e[@@mk`9240M6<@9240@m
k`<icP8e[@8aS08U:@8Q20DLi`@HaP=oo`03001oogoo00Moo`0027oo00<007ooOol031BU00<HaQBU
6<H06aS60acW1AS600<LiaS67>L05acW00<Q21cW7>L00QcW1b484QcW0QS63AcW00<HaQcW7>L00acW
0aS62AcW0goo00<007ooOol02goo00<007ooOol02be[1S6<0be[0RU:12e[12U:0be[12U:12DY2B48
4AcW0QS65QcW1B480RU:0SF]13g_0T8@1dHa0T8@13g_0cW>0SF]0S6<0RDY0R481AcW11S60goo00<0
07ooOol01goo0008Ool00`00Oomoo`0;5:D26<H00aBU6<HHaP0S6<HH7>L012487>LQ21cW2b489QcW
00<HaQcW7>L021cW0goo00<007ooOol02goo00<007ooOol012U:42e[4BU:0RDY1248<1cW1B480RU:
0S6<0SW>0Sg_2D8@0Sg_13W>0cF]0S6<0RU:0R4811cW1aS60goo00<007ooOol01goo0008Ool00`00
Oomoo`0>5:D66<H00aBU6<HHaP0J6<H00acW6<HHaP0A7>L58@P00acW8@PQ200<8@PF7>L00aS67>LH
aP0I7>L3Ool00`00Oomoo`0;Ool00`00Oomoo`04:DX@;F/A:DX29BT48@P`7>L58@P2:DX2<H`2>Lh2
?Nl9@Q02?Nl4>Lh3=Jd2<H`2:DX28@P47>L76<H3Ool00`00Oomoo`07Ool000Qoo`05001oogoo5:DH
aP085:D00aS65:DHaP026<H00aBU6<HHaP026<H00aBU6<HHaP0F6<H01QcW6<HHaQS67>LHaQ4Li`03
8@PLiacW008Q20037>LQ224800@Q20HU:@DQ21DLi`036<HLiacW01PLi`=oo`03001oogoo00]oo`03
001oogoo008U:@DYBP8]J`8YBP8]J`TYBPHU:@DYBP@U:@@Q238Li`DQ208U:@8]J`8e[@@mk`E2408m
k`8icP8e[@8aS0D]J`8U:@8Q20@Li`LHaP=oo`03001oogoo00Moo`0027oo00<007ooOol02aBU0aS6
00<DYAS66<H00aS600<DYAS66<H06aS641cW00<Q21cW8@P02R4800<U:BU::DX00RU:0bDY12485QcW
00<HaQcW7>L05acW0goo00<007ooOol02goo00<007ooOol00RDY1BU:0Re[0RU:0Re[2BU:1RDY1BU:
12DY1248<QcW1B480RDY0Re[0SF]13g_1D8@0Sg_0SW>0SF]0S6<1Be[0RDY0R4811cW1aS60goo00<0
07ooOol01goo0008Ool00`00Oomoo`0:5:D56<H25:DL6<H00acW6<HLi`0C7>L:8@P012DY:DX]Jbe[
0c6<0Re[0RDY1248;acW0goo00<007ooOol02goo00<007ooOol00R480RDY2bU:1bDY3b48>1cW0b48
0RDY0RU:0S6<0SW>1cg_0SW>0SF]0Re[1BU:0RDY0R481QcW1aS60goo00<007ooOol01goo0008Ool0
0`00Oomoo`095:DU6<H00acW6<HHaP0@7>L78@P59BT012U:;F/aS3F]0cg_00DicSF];F/YBRDY00<Q
218Li`036<HLiacW01XLi`=oo`03001oogoo00]oo`03001oogoo008Q208U:@/YBPLU:@lQ23PLi`<Q
208U:@8YBP8aS08icPLmk`8icP8e[@8]J`DYBP8U:@8Q20HLi`LHaP=oo`03001oogoo00Moo`0027oo
00<007ooOol02ABU9AS600<LiaS66<H041cW1b481BDY00@YBRe[<H`e[@<mk`05>Lhe[Be[:DXU:@03
8@PB7>L00aS67>LLi`0J7>L3Ool00`00Oomoo`0;Ool00`00Oomoo`028@P29BT;:DX79BT?8@Ph7>L3
8@P29BT2:DX2<H`2>Lh7?Nl2>Lh2=Jd2;F/5:DX29BT28@P67>L76<H3Ool00`00Oomoo`07Ool000Qo
o`03001oogoo00TDYAdHaP8Li`036<HLiacW00LHaPlLi`8Q20LU:@8YBP8]J`03<H`mkdHa00A:DP04
@Q0icRe[:DX48@PL7>L00b487>LLi`0?7>L3Ool00`00Oomoo`0;Ool00`00Oomoo`048@P39BT6:DX7
9BT?8@Pm7>L28@P29BT2;F/2<H`2=Jd5>Lh2=Jd2<H`2:DX29BT58@P87>L76<H3Ool00`00Oomoo`07
Ool000Qoo`03001oogoo00XDY@LHaP<DYA<HaP037>LHaQS600DHaQ4Li`8Q20039BTYBRU:00DYBP8]
J`05<H`e[Cg_AS5>L`04DY@01DYBAS4icRe[9BT0124861cW00<Q21cW7>L00b483acW0goo00<007oo
Ool02goo00<007ooOol012480bDY1RU:1bDY3b48?AcW0R480RDY0Re[0S6<0SF]1CW>0SF]0S6<0RU:
0RDY1B4821cW1aS60goo00<007ooOol01goo0008Ool00`00Oomoo`0:5:D00aS65:DHaP0R6<H?7>L4
8@P2:DX6;F/3<H`00cW>BU9BU003E[D2F]H01UJeCW=6<CF]:DXU:@8Q21PLi`XQ20XLi`8HaP=oo`03
001oogoo00]oo`03001oogoo00LQ20HU:@TQ24XLi`8Q208U:@8YBP8]J`8aS0<e[@@aS08YBP8U:@DQ
20PLi`THaP=oo`03001oogoo00Moo`0027oo00<007ooOol00QBU00<HaQBU5:D01QBU8QS60QcW00<H
aQcW7>L031cW0b4800@U:Be[;F/]J`<aS008;F/aS36<<H`e[DHaDYAJePENm`07F]IF]Dic?Nl]JbU:
9BT00R485QcW0R481bDY0b4821cW0QS600DLigooOomoo`0000eoo`03001oogoo00LQ20HU:@TQ24XL
i`8Q208U:@8YBP8]J`8aS0<e[@@aS08YBP8U:@DQ20PLi`THaP=oo`03001oogoo00Moo`0027oo00<0
07ooOol02aBU9AS63AcW0b4800@U:BU:;F/]J`LaS004=JdicTicE[D2G_L2HaP3G_L015[FDYA6<C6<
0RU:00<U:B487>L051cW00<Q22DY9BT00bU:0Re[0RU:0RDY0R4821cW0QS60goo00<007ooOol02goo
00<007ooOol05248C1cW124812DY0RU:1Be[0RU:12DY0R482AcW2aS60goo00<007ooOol01goo0008
Ool00`00Oomoo`0;5:DS6<H67>L00aS67>LLi`067>L38@P00bDY;F/]J`05<H`4=Jd01D8@DYAJeUkg
HaP00fLi00YS65kgF]IF]DYB=Jd]JbU:9BTQ21DLi`038@PU:BU:00L]J`03:DXU:BDY008Q20LLi`8H
aP=oo`03001oogoo00]oo`03001oogoo01@Q24`Li`@Q20@U:@8YBPD]J`8YBP@U:@8Q20TLi`/HaP=o
o`03001oogoo00Moo`0027oo00<007ooOol02aBU9AS63AcW0R4800@U:BU:<H`aS0Pe[@05>Li245:D
G_MS6004IcT2HaP01U[FE[E:DSW>;F/U:@8Q21@Li`048@PU:BU:;F/6<H`3;F/29BT28@P77>L01AS6
Oomoogoo00003Goo00<007ooOol0HQcW1R482BDY12482acW2aS60goo00<007ooOol01goo0008Ool0
0`00Oomoo`0:5:D56<H00aBU6<HHaP0L6<H01AcW6<HHaQcW6<H02AcW0R4800<U:BU:<H`02CF]0SW>
00=245:DG_L00V<H0fLi00QS65kgF]IF]DYB=Jd]JbDY0R4851cW00DQ22DY:DX]Jc6<00He[@8aS003
:DXU:B48008Q20DLi`8HaP=oo`03001oogoo00]oo`03001oogoo068Li`HQ20TU:@@Q20/Li`/HaP=o
o`03001oogoo00Moo`0027oo00<007ooOol00aBU00<HaQBU5:D011BU0QS600@DYAS66<HDY@8HaP8D
YALHaPDLi`036<HLiacW00PLi`8Q20049BT]JcF]?Nl2@Q0013g_=Jde[CF]0cW>0Sg_00=244icG_L0
0V<H0fLi00QS65kgF]IF]DYB=JdYBRDY0R484acW0R4800@YBRe[<H`e[@LicP03<H`]JbU:008U:@<Q
20<Li`8HaP=oo`03001oogoo00]oo`03001oogoo06HLi`dQ20/Li`dHaP=oo`03001oogoo00Moo`00
27oo00<007ooOol041BU0QS60QBU4aS600<LiaS66<H011S600<LiaS67>L02QcW00HQ22DY:DXicT8@
AS43BU801Sg_=Jde[CF]>Li240=6<@03CW=F]Ekg00ES6008G_MJeU:DAS4aS2U:9BTQ21@Li`068@PU
:BU:;F/aS3F]1cW>0SF]00@aS2e[:DXU:@8Q20@Li`056<IoogooOol0000=Ool00`00Oomoo`1V7>L=
8@P;7>L=6<H3Ool00`00Oomoo`07Ool000Qoo`03001oogoo010DYB0HaP8Li`036<HLiacW00HLi`0:
8@PU:C6<@Q1:DTicDYAF]DicAS43>Lh00cg_BU9BU002DY@014icDYANmekg0f<H00QNme[FE[E>Lcg_
;F/YBRDY12484AcW00HQ22DY:DXaS3F]>Lh7?Nl2>Lh013F]<H`]JbDY0b480acW00DHaWooOomoo`00
00eoo`03001oogoo07`Li`lHaP=oo`03001oogoo00Moo`0027oo00<007ooOol04ABU0aS600<DYAS6
6<H06AS62QcW0R4800@YBSW>BU9>L`AF]@06BU92448@?Nm:DUJe15[F0UJe0e[F00QNme[FE[E>Ld8@
=Jd]JbU:0bDY0R484AcW0R4800@YBRe[=JdicP<mk`=240<mk`04>Lhe[C6<:DX29BT01B487>LLiacW
6<H00goo00<007ooOol02goo00<007ooOol0O1cW3aS60goo00<007ooOol01goo0008Ool00`00Oomo
o`0A5:D36<H00aBU6<HHaP0I6<H:7>L28@P012U:>Li:DTic15Je00I:DT8@@Q0mkdYBE[D4F]H2E[D3
F]H025kgF]IF]Dic@Q0e[Be[:DX39BT28@PA7>L28@P012U:;F/e[CW>0cg_0d8@0cg_00@icSF]<H`Y
BP8U:@058@PLiacW7>LHaP03Ool00`00Oomoo`0;Ool00`00Oomoo`1l7>L?6<H3Ool00`00Oomoo`07
Ool000Qoo`03001oogoo010DY@8HaP8DY@036<HDYAS601LHaP037>LHaQS600TLi`078@PU:Be[@Q1>
Le:DE[D00U[F00MF]Dic@Q1243g_CW=JeP04G_L00e[FDYABU003E[D01DicBU9243W><H`00bU:0RDY
0b4841cW0R4800@YBRe[=JdicP8mk`M24004?NlicSF];F/29BT01B487>LLiacW6<H00goo00<007oo
Ool02goo00<007ooOol0P1cW2aS60goo00<007ooOol01goo0008Ool00`00Oomoo`0A5:DO6<H27>L0
0aS67>LLi`057>L01R489BTaS4HaCW=F]@=JeP03E[EBU4Ha0096<@03DYANmekg009S6003G_MJeUJe
00=:DP05AS5243g_>LhaS002:DX00be[:DXYBP039BTA7>L28@P012DY;F/aS3W>0Sg_0T8@0THa00M2
44Ha@Q1243g_=JdaS002:DX01B487>LLiacW6<H00goo00<007ooOol02goo00<007ooOol0P1cW2aS6
0goo00<007ooOol01goo0008Ool00`00Oomoo`0:5:D01AS65:DDYABU6<H00QBU11S600<DYAS66<H0
61S62QcW00HQ22DY=Je6<DicE[D2F]H00ekgF]IF]@03AS400eJeF]IS6003HaP00ekgE[E:DP02@Q02
>Lh013F]<H`]Jbe[0bU:12DY00<Q21cW7>L03QcW0R4800@U:Be[<H`icPE240=6<@924003?NlicSF]
008]J`059BTQ21cW7>LHaP03Ool00`00Oomoo`0;Ool00`00Oomoo`1j7>LA6<H3Ool00`00Oomoo`07
Ool000Qoo`03001oogoo00dDY@036<HDYABU00@DYAlHaPLLi`078@PU:CW>AS5>LeJeF]H00Ukg00=J
eUJeAS400THa00EF]EkgHaQW>F<H009Nm`04E[E:DSg_?Nl2=Jd2<H`00be[:DXYBP03:DX39BT00b48
7>LLi`0>7>L28@P012DY:DXaS3W>0Sg_0T8@0THa0TYB00E6<D8@?NlicSF]008]J`059BTQ21cW7>LH
aP03Ool00`00Oomoo`0;Ool00`00Oomoo`1j7>LA6<H3Ool00`00Oomoo`07Ool000Qoo`03001oogoo
00hDY@046<HDYABU6<H35:DM6<H87>L022489BTe[DHaCW=F]E[FG_L2F]H02E:D@Q12448@CW=JeUkg
HaQNm`02F]H01EJeAS4icSW>=Jd00S6<0Re[12U:12DY0R4841cW00DQ22DY:DXaS3W>008mk`924005
AS5:DTYBBU96<@02@Q001Sg_=Jd]Jbe[9BTQ20<Li`=oo`03001oogoo00]oo`03001oogoo050Li`<H
aPPLi`8HaQdLia4HaP=oo`03001oogoo00Moo`0027oo00<007ooOol03aBU00<HaQBU5:D00aBU71S6
2AcW00PQ22DY;F/mkdYBDYAF]E[F0UJe00I:DSg_?NlicTHaE[D4F]H00eJeCW=24002=Jd5;F/2:DX4
9BT38@PA7>L28@P00bU:<H`icP02?Nl2@Q001THaBU9:DTYBAS52408mk`05=Jd]Jbe[9BTQ20027>L0
1AS6Oomoogoo00003Goo00<007ooOol0D1cW0aS621cW0QS67AcW4AS60goo00<007ooOol01goo0008
Ool00`00Oomoo`0@5:D00aS65:DHaP0M6<H67>L00aS67>LLi`027>L01B48:DXe[D8@BU800e:D00=>
Ld8@>Lh00SW>00=244YBDY@00eJe00=>LdHa>Lh00S6<1Be[0bU:1BDY00<Q21cW7>L03acW0R4800<U
:C6<=Jd00Sg_00=244HaAS400TYB0THa00A243g_>Lhe[@8]J`059BTQ21cW7>LHaP03Ool00`00Oomo
o`0;Ool00`00Oomoo`1I7>L76<H:7>L36<H67>L46<H37>LA6<H3Ool00`00Oomoo`07Ool000Qoo`03
001oogoo014DY@<HaP035:DHaQS601XHaPXLi`0:8@PU:Be[>Li244YBCW=:DT8@>Lh3=Jd013W>?Nm2
44Ha0TYB00=243W>=Jd00S6<1Be[0RU:1RDY00<Q21cW7>L00acW00<HaQcW7>L02AcW0R4800<U:Be[
=Jd00Sg_00=244HaAS400TYB0THa00A243g_>Lhe[@8]J`059BTQ21cW7>LHaP03Ool00`00Oomoo`0;
Ool00`00Oomoo`1I7>L76<H:7>L36<H67>L46<H37>LA6<H3Ool00`00Oomoo`07Ool000Qoo`03001o
ogoo00lDY@<HaP<DYAdHaPTLi`8Q20039BT]JcF]008mk`03>Lhe[C6<00<aS08e[@8icP05?NlicSF]
=JdaS006;F/00bU:9BTU:@049BT28@PB7>L28@P00bDY;F/e[@02?Nl00d8@AS56<@04AS40148@?Nli
cSF]0Re[00DU:AcW7>LLiaS600=oo`03001oogoo00]oo`03001oogoo05dLi`<HaPlLia`HaP=oo`03
001oogoo00Moo`0027oo00<007ooOol03ABU0QS60QBU00DHaQBU5:DHaQBU01`HaP037>LHaQcW00LL
i`8Q20039BTYBS6<00@aS0<]J`<aS08e[@<aS0L]J`8YBP@U:@<Q20LLi`036<HLiacW00TLi`048@PU
:BU:=Jd2?Nl00d8@AS56<@03AS42@Q000cg_>LhaS002:DX01B487>LLiacW6<H00goo00<007ooOol0
2goo00<007ooOol0GAcW0aS63acW71S60goo00<007ooOol01goo0008Ool00`00Oomoo`0>5:D26<H4
5:DJ6<H00acW6<HHaP0;7>L38@P00bDY:DXYBP09;F/3<H`00be[:DX]J`02;F/2:DX00be[:DXYBP02
9BT48@P97>L00aS67>LLi`097>L28@P00bU:=Jdmk`02?Nl01D8@AS56<DHa@Q000Sg_00<icSF]<H`0
0RDY00<Q21cW7>L00QS60goo00<007ooOol02goo00<007ooOol0:AcW0QS61AcW0QS63acW11S61AcW
1QS61AcW11S60QcW0QS61acW0QS611cW1aS60QcW61S60goo00<007ooOol01goo0008Ool00`00Oomo
o`0>5:D26<H45:DJ6<H00acW6<HHaP0;7>L38@P00bDY:DXYBP09;F/3<H`00be[:DX]J`02;F/2:DX0
0be[:DXYBP029BT48@P97>L00aS67>LLi`097>L28@P00bU:=Jdmk`02?Nl01D8@AS56<DHa@Q000Sg_
00<icSF]<H`00RDY00<Q21cW7>L00QS60goo00<007ooOol02goo00<007ooOol0:AcW0QS61AcW0QS6
3acW11S61AcW1QS61AcW11S60QcW0QS61acW0QS611cW1aS60QcW61S60goo00<007ooOol01goo0008
Ool00`00Oomoo`0>5:D011S65:DHaQBU7aS631cW0b480bDY1BU:1be[2BU:00<U:B488@P061cW0R48
00DYBS6<>LhicSg_00A24006?NlicSW>=JdaS2U:0R480QcW0aS60goo00<007ooOol02goo00<007oo
Ool0:AcW0QS61AcW0QS63acW11S61AcW1QS61AcW11S60QcW0QS61acW0QS611cW1aS60QcW61S60goo
00<007ooOol01goo0008Ool00`00Oomoo`0=5:D56<H25:DJ6<H01AcW6<HLiacW6<H02acW1R480bDY
0RU:00<]JbU:;F/012U:12DY0RU:0RDY0R486AcW0R4800@U:Be[=Jde[@8mk`924004?NlicSF]<H`2
;F/00bDY8@PQ20027>L36<H3Ool00`00Oomoo`0;Ool00`00Oomoo`047>L36<Hd7>L26<H47>L46<HB
7>L66<H=7>LQ6<H3Ool00`00Oomoo`07Ool000Qoo`03001oogoo010DYB0HaP8Li`036<HLiacW00/L
i`LQ20039BTYBRU:00<YBP<U:@PQ21`Li`038@PU:BU:008aS007>Lhmkcg_?NlicSF];F/00RU:00<U
:B487>L00acW0aS60goo00<007ooOol02goo00<007ooOol011cW0aS6=1cW0QS611cW11S64QcW1QS6
3AcW8AS60goo00<007ooOol01goo0008Ool00`00Oomoo`0B5:DM6<H01QcW6<HHaQS67>LHaP`Li`LQ
20049BTYBRU::DX39BT88@PN7>L01R489BT]Jbe[<H`e[@8icP04=JdaS2U:9BT28@P57>L36<H3Ool0
0`00Oomoo`0;Ool00`00Oomoo`0f7>L76<H87>L36<HA7>L26<H?7>LQ6<H3Ool00`00Oomoo`07Ool0
00Qoo`03001oogoo00dDY@8HaP8DY@036<HDYABU01dHaP8Li`8HaPlLi`DQ20<U:@@Q22DLi`078@PU
:BU::DX]Jc6<=Jd00S6<00@YBRDY8@PQ20DLi`@HaP=oo`03001oogoo00]oo`03001oogoo03HLi`LH
aPPLi`<HaQ4Li`8HaPlLib4HaP=oo`03001oogoo00Moo`0027oo00<007ooOol031BU1AS60aBU71S6
00<LiaS67>L00QcW00<HaQcW7>L031cW2b489QcW0R480bDY00@YBRe[;F/YBP8U:@038@PLiacW00<L
i`DHaP=oo`03001oogoo00]oo`03001oogoo030Li`8HaPHLi`DHaPPLi`<HaP8Li`8HaPLLi`@HaP8L
i`8HaPdLib<HaP=oo`03001oogoo00Moo`0027oo00<007ooOol031BU0QS600@DYAS66<HDY@8HaP8D
YA/HaP@Li`036<HLiacW03hLi`@Q20@U:@8Q20HLi`DHaP=oo`03001oogoo00]oo`03001oogoo030L
i`8HaPHLi`DHaPPLi`<HaP8Li`8HaPLLi`@HaP8Li`8HaPdLib<HaP=oo`03001oogoo00Moo`0027oo
00<007ooOol03ABU0QS61QBU71S6B1cW1R481AcW1aS60goo00<007ooOol02goo00<007ooOol02acW
0QS68AcW11S64AcW1AS63AcW0QS60QcW11S63AcW8AS60goo00<007ooOol01goo0008Ool00`00Oomo
o`0?5:D00aS65:DHaP035:DL6<IB7>L86<H3Ool00`00Oomoo`0;Ool00`00Oomoo`0;7>L26<HQ7>L4
6<HA7>L56<H=7>L26<H27>L46<H=7>LQ6<H3Ool00`00Oomoo`07Ool000Qoo`03001oogoo01DDY@04
6<HDYABU5:DJ6<IC7>L56<H3Ool00`00Oomoo`0;Ool00`00Oomoo`0[7>L36<H27>L46<H97>L26<H2
7>L=6<H57>L:6<H37>L26<H27>LW6<H3Ool00`00Oomoo`07Ool000Qoo`03001oogoo00dDY@036<HD
YAS600HDY@LHaP0348@HaQS6018HaP037>LHaQS604dLi`THaP=oo`03001oogoo00]oo`03001oogoo
02/Li`<HaP8Li`@HaPTLi`8HaP8Li`dHaPDLi`XHaP<Li`8HaP8LibLHaP=oo`03001oogoo00Moo`00
27oo00<007ooOol03ABU00<HaQBU5:D01aBU7AS6>QcW00<HaQcW7>L00QcW00<HaQcW7>L031cW2AS6
0goo00<007ooOol02goo00<007ooOol00QS66QcW0QS63AcW2AS61acW21S60QcWAQS60goo00<007oo
Ool01goo0008Ool00`00Oomoo`0=5:D00aS65:DDY@075:DM6<Hj7>L00aS67>LLi`027>L00aS67>LL
i`0<7>L96<H3Ool00`00Oomoo`0;Ool00`00Oomoo`026<HJ7>L26<H=7>L96<H77>L86<H27>M66<H3
Ool00`00Oomoo`07Ool000Qoo`03001oogoo01HDYAhHaP047>LHaQS66<Hj7>L36<H67>L011S67>LL
iacW0QS600<LiaS66<H01aS60goo00<007ooOol02goo00<007ooOol00QS66QcW0QS63AcW2AS61acW
21S60QcWAQS60goo00<007ooOol01goo0008Ool00`00Oomoo`0=5:D36<H25:D26<H00aBU6<HDY@0M
6<H00acW6<HLi`067>L00aS67>LLi`0d7>L00aS67>LLi`067>L>6<H3Ool00`00Oomoo`0;Ool00`00
Oomoo`026<HW7>L96<H;7>L?6<H27>L26<H37>Lh6<H3Ool00`00Oomoo`07Ool000Qoo`03001oogoo
00hDY@036<HDYABU00HDYAdHaP037>LHaQcW00<HaPLLi`036<HLiacW01HLi`046<HLiacW6<H87>L2
6<H27>L46<H27>L26<H00acW6<HLi`027>L26<H27>L36<H00acW6<HHaP0:6<H3Ool00`00Oomoo`0;
Ool00`00Oomoo`026<HW7>L96<H;7>L?6<H27>L26<H37>Lh6<H3Ool00`00Oomoo`07Ool000Qoo`03
001oogoo014DY@036<HDYABU008DY@8HaP035:DHaQS601/HaP037>LHaQS600<HaP`Li`036<HLiacW
01PLi`036<HLiacW008HaPTLi`<HaPLLia0HaP=oo`03001oogoo00]oo`03001oogoo02LLi`/HaP8L
i`8HaPLLi`@HaP8Li`dHaPLLi`8HaPLLi`8HaP8LibLHaP=oo`03001oogoo00Moo`0027oo00<007oo
Ool05QBU8AS600<LiaS66<H09acW0aS611cW00<HaQcW7>L01acW00<HaQcW7>L01QcW41S60goo00<0
07ooOol02goo00<007ooOol09acW2aS60QcW0QS61acW11S60QcW3AS61acW0QS61acW0QS60QcW9aS6
0goo00<007ooOol01goo0008Ool00`00Oomoo`0?5:D00aS65:DDY@045:DR6<H37>L00aS67>LHaP02
7>L00aS67>LLi`0J7>L00aS67>LLi`027>L26<H47>L011S67>LHaQS60acW0QS600<LiaS67>L01QcW
4AS60goo00<007ooOol02goo00<007ooOol00QS69AcW11S61AcW0QS60QcW7aS60QcW11S61acW:aS6
0goo00<007ooOol01goo0008Ool00`00Oomoo`0F5:DA6<H25:D?6<H37>L26<H>7>L00aS67>LLi`0>
7>L26<H97>L26<H77>L011S67>LHaQS61acW41S60goo00<007ooOol02goo00<007ooOol00QS69AcW
11S61AcW0QS60QcW7aS60QcW11S61acW:aS60goo00<007ooOol01goo0008Ool00`00Oomoo`0I5:D>
6<H25:D?6<H27>L00aS67>LHaP0N7>L00aS67>LHaP026<H47>L00aS67>LHaP066<H27>L56<H00acW
6<HLi`0D6<H3Ool00`00Oomoo`0;Ool00`00Oomoo`026<HB7>L26<H27>L26<HA7>LX6<H27>L46<H2
7>L26<H57>LY6<H3Ool00`00Oomoo`07Ool000Qoo`03001oogoo01TDY@036<HDYAS601/HaPDLi`03
6<HLiacW00HLi`8HaPdLi`036<HLiacW00@Li`DHaP<Li`@HaP037>LHaQS6024HaP=oo`03001oogoo
00]oo`03001oogoo008HaQ8Li`8HaP8Li`8HaQ4LibPHaP8Li`@HaP8Li`8HaPDLibTHaP=oo`03001o
ogoo00Moo`0027oo00<007ooOol061BU00@HaQBU5:DDYA`HaP@Li`036<HLiacW00HLi`8HaQ<Li`@H
aPHLi`PHaP037>LHaQcW01`HaP=oo`03001oogoo00]oo`03001oogoo00@Li`<HaQhLi`@HaP8Li`LH
aP8Li`8HaP8Lia0HaP8Li`THaP8Li`/HaP@LibLHaP=oo`03001oogoo00Moo`0027oo00<007ooOol0
6QBU00<HaQBU6<H061S600<LiaS66<H00QS60QcW00@HaQcW7>LHaP@Li`036<HLiacW018Li`DHaP8L
i`046<HLiacW7>L26<H00acW6<HHaP056<H37>L01QS67>LLiacW6<HLia@HaP=oo`03001oogoo00]o
o`03001oogoo00@Li`<HaQhLi`@HaP8Li`LHaP8Li`8HaP8Lia0HaP8Li`THaP8Li`/HaP@LibLHaP=o
o`03001oogoo00Moo`0027oo00<007ooOol061BU81S60QcW0QS60acW00<HaQcW7>L00acW0QS64QcW
0QS60QcW00<HaQcW7>L03aS600<LiaS66<H00acW5QS60goo00<007ooOol02goo00<007ooOol00QS6
1acW0QS61QcW0aS60QcW1QS63acW1aS611cW6QS60acW0QS61QcW1AS611cW9aS60goo00<007ooOol0
1goo0008Ool00`00Oomoo`0H5:DP6<H27>L26<H37>L00aS67>LLi`037>L26<HB7>L26<H27>L00aS6
7>LLi`0?6<H00acW6<HHaP037>LF6<H3Ool00`00Oomoo`0;Ool00`00Oomoo`026<H77>L26<H67>L3
6<H27>L66<H?7>L76<H47>LJ6<H37>L26<H67>L56<H47>LW6<H3Ool00`00Oomoo`07Ool000Qoo`03
001oogoo01PDYB8HaP047>LHaQS67>L26<H57>L26<H87>L011S67>LHaQS621cW51S600DLiaS66<HL
iaS6008LiaDHaP=oo`03001oogoo00]oo`03001oogoo008HaPLLi`8HaPHLi`<HaP8Li`HHaPlLi`LH
aP@LiaXHaP<Li`8HaPHLi`DHaP@LibLHaP=oo`03001oogoo00Moo`0027oo00<007ooOol06ABU11S6
0QBU81S60acW0aS60acW00<HaQcW7>L03AcW0QS600@LiaS66<HHaP8Li`036<HLiaS600HHaP037>LH
aQS600<HaP037>LHaQS600<HaP8Lia@HaP=oo`03001oogoo00]oo`03001oogoo00TLi`8HaPHLi`TH
aP8Li`8HaPDLi`8HaP8Li`lHaP8Li`LHaP8Lia@HaP8Li`HHaPDLibTHaP=oo`03001oogoo00Moo`00
27oo00<007ooOol06ABU00@HaQBU6<HHaP@DYAdHaP8Li`LHaP<Li`066<HLiacW7>LHaQcW11S61acW
0aS60acW3AS600<LiaS67>L00QcW0QS60QcW51S60goo00<007ooOol02goo00<007ooOol02AcW0QS6
1QcW2AS60QcW0QS61AcW0QS60QcW3aS60QcW1aS60QcW51S60QcW1QS61AcW:AS60goo00<007ooOol0
1goo0008Ool00`00Oomoo`0I5:D36<H00aBU6<HDY@025:DN6<H00acW6<HHaP036<H57>L011S67>LL
iacW1AS600HLiaS67>LLiaS67>L86<H01AcW6<HHaQS67>L02QS600@LiaS66<HHaP8LiaDHaP=oo`03
001oogoo00]oo`03001oogoo00LHaP8Li`8HaPHLi`<HaP8Li`lHaP8Li`/HaP8Li`@HaP<Lia<HaP8L
i`dHaPTLibDHaP=oo`03001oogoo00Moo`0027oo00<007ooOol08ABU:1S600<LiaS67>L00QcW00<H
aQcW6<H01aS600<LiaS66<H00aS60QcW0QS600<LiaS66<H021S600<LiaS66<H011S61AcW4QS60goo
00<007ooOol02goo00<007ooOol01aS60QcW0QS61QcW0aS60QcW3aS60QcW2aS60QcW11S60acW4aS6
0QcW3AS62AcW9AS60goo00<007ooOol01goo0008Ool00`00Oomoo`2>Ool00`00Oomoo`0;Ool00`00
Oomoo`2>Ool00`00Oomoo`07Ool000Qoo`03001oogoo08ioo`03001oogoo00]oo`03001oogoo08io
o`03001oogoo00Moo`0027ooTP003GooTP002Goo003oOom3Ool00?mood=oo`00ogoo@goo0000\
\>"],
  ImageRangeCache->{{{0, 321}, {152.25, 0}} -> {-0.0541967, -0.0238146, 
  0.00656821, 0.00656821}, {{8.25, 153.25}, {148.625, 
  3.625}} -> {-10.2629, -6.00941, 0.919664, 0.919664}, {{167.75, 312.75}, {
  148.625, 3.625}} -> {-78.4748, -3.00471, 0.459833, 0.459833}}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["CONTRAST MODIFICATION", "Section"],

Cell["\<\
In this section we will investigate a few simple contrast modifying \
operations. The operations discussed here are grayscale negation, linear \
contrast stretching, contrast modification using the power law, range \
compression, and  level slicing. On digital image processing hardware, all of \
these operations can be performed without any performance penalty, by \
modifying the output look-up tables (LUTs).\
\>", "Text"],

Cell[CellGroupData[{

Cell["Negative image.", "Subsection"],

Cell["\<\
Negating an image is the simplest image modification operation. This \
operation changes large values to small and vice versa.\
\>", "Text"],

Cell[CellGroupData[{

Cell["Example 1: Negative image", "Example"],

Cell[TextData[{
  "Obtain the \"negative\" of the example image. Formally, this is done by \
calculating the diminished radix complement of ",
  StyleBox["x",
    FontSlant->"Italic"],
  ",  ",
  Cell[BoxData[
      \(TraditionalForm\`x\&_\)]],
  " = ",
  Cell[BoxData[
      \(TraditionalForm\`r\^n\)]],
  "-1-x, with the radix ",
  Cell[BoxData[
      \(TraditionalForm\`r\  = 2\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`n = 8\)]],
  ".\n",
  StyleBox["Solution",
    FontWeight->"Bold"],
  ". In order to obtain the diminished radix complement of x, where x is an \
integer in the range {0,255}, subtract from 255. For example, the original \
and complemented values of a small segment of the image a will be:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(SubMatrix[A, \ {100, 100}, {6, 6}]\  // MatrixForm\)], "Input"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", GridBox[{
            {"56", "58", "58", "60", "59", "60"},
            {"57", "58", "59", "59", "59", "60"},
            {"58", "58", "58", "58", "58", "59"},
            {"58", "59", "59", "59", "57", "58"},
            {"58", "58", "60", "60", "59", "59"},
            {"58", "59", "59", "60", "60", "58"}
            }], ")"}],
      (MatrixForm[ #]&)]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\((255 - SubMatrix[A, \ {100, 100}, {6, 6}])\)\  // MatrixForm\)], 
  "Input"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", GridBox[{
            {"199", "197", "197", "195", "196", "195"},
            {"198", "197", "196", "196", "196", "195"},
            {"197", "197", "197", "197", "197", "196"},
            {"197", "196", "196", "196", "198", "197"},
            {"197", "197", "195", "195", "196", "196"},
            {"197", "196", "196", "195", "195", "197"}
            }], ")"}],
      (MatrixForm[ #]&)]], "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Contrast modification with the power law.", "Subsection"],

Cell[TextData[{
  "A common approach to contrast modification is to use a power law point \
transformation, where each pixel of the original image is raised to a \
specified exponent value. By selecting the exponent values appropriately, \
either high or low luminance values can be boosted. The function ",
  StyleBox["ContrastModifyPower", "Program"],
  " in the ",
  StyleBox["ImageProcessing", "Program"],
  " package returns a scaled version of the image using the power \
transformation. The transfer functions for some typical choices of the \
exponent are shown:"
}], "Text"],

Cell[BoxData[
    \(\(x = Range[0, 255]; \)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[
      \(ListPlot[ContrastModifyScale[#1, \ {0, 255}], 
            PlotJoined \[Rule] True, DisplayFunction \[Rule] Identity]\ &
          \)\ /@{ContrastModifyPower[x, 3], \ ContrastModifyPower[x, 1], \ 
          ContrastModifyPower[x, 1\/2]}, \ 
      DisplayFunction \[Rule] $DisplayFunction]; \)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00372024 0.0147151 0.00230825 [
[.20982 .00222 -6 -9 ]
[.20982 .00222 6 0 ]
[.39583 .00222 -9 -9 ]
[.39583 .00222 9 0 ]
[.58185 .00222 -9 -9 ]
[.58185 .00222 9 0 ]
[.76786 .00222 -9 -9 ]
[.76786 .00222 9 0 ]
[.95387 .00222 -9 -9 ]
[.95387 .00222 9 0 ]
[.01131 .13013 -12 -4.5 ]
[.01131 .13013 0 4.5 ]
[.01131 .24554 -18 -4.5 ]
[.01131 .24554 0 4.5 ]
[.01131 .36095 -18 -4.5 ]
[.01131 .36095 0 4.5 ]
[.01131 .47637 -18 -4.5 ]
[.01131 .47637 0 4.5 ]
[.01131 .59178 -18 -4.5 ]
[.01131 .59178 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.20982 .01472 m
.20982 .02097 L
s
[(50)] .20982 .00222 0 1 Mshowa
.39583 .01472 m
.39583 .02097 L
s
[(100)] .39583 .00222 0 1 Mshowa
.58185 .01472 m
.58185 .02097 L
s
[(150)] .58185 .00222 0 1 Mshowa
.76786 .01472 m
.76786 .02097 L
s
[(200)] .76786 .00222 0 1 Mshowa
.95387 .01472 m
.95387 .02097 L
s
[(250)] .95387 .00222 0 1 Mshowa
.125 Mabswid
.06101 .01472 m
.06101 .01847 L
s
.09821 .01472 m
.09821 .01847 L
s
.13542 .01472 m
.13542 .01847 L
s
.17262 .01472 m
.17262 .01847 L
s
.24702 .01472 m
.24702 .01847 L
s
.28423 .01472 m
.28423 .01847 L
s
.32143 .01472 m
.32143 .01847 L
s
.35863 .01472 m
.35863 .01847 L
s
.43304 .01472 m
.43304 .01847 L
s
.47024 .01472 m
.47024 .01847 L
s
.50744 .01472 m
.50744 .01847 L
s
.54464 .01472 m
.54464 .01847 L
s
.61905 .01472 m
.61905 .01847 L
s
.65625 .01472 m
.65625 .01847 L
s
.69345 .01472 m
.69345 .01847 L
s
.73065 .01472 m
.73065 .01847 L
s
.80506 .01472 m
.80506 .01847 L
s
.84226 .01472 m
.84226 .01847 L
s
.87946 .01472 m
.87946 .01847 L
s
.91667 .01472 m
.91667 .01847 L
s
.99107 .01472 m
.99107 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02381 .13013 m
.03006 .13013 L
s
[(50)] .01131 .13013 1 0 Mshowa
.02381 .24554 m
.03006 .24554 L
s
[(100)] .01131 .24554 1 0 Mshowa
.02381 .36095 m
.03006 .36095 L
s
[(150)] .01131 .36095 1 0 Mshowa
.02381 .47637 m
.03006 .47637 L
s
[(200)] .01131 .47637 1 0 Mshowa
.02381 .59178 m
.03006 .59178 L
s
[(250)] .01131 .59178 1 0 Mshowa
.125 Mabswid
.02381 .0378 m
.02756 .0378 L
s
.02381 .06088 m
.02756 .06088 L
s
.02381 .08396 m
.02756 .08396 L
s
.02381 .10705 m
.02756 .10705 L
s
.02381 .15321 m
.02756 .15321 L
s
.02381 .17629 m
.02756 .17629 L
s
.02381 .19938 m
.02756 .19938 L
s
.02381 .22246 m
.02756 .22246 L
s
.02381 .26862 m
.02756 .26862 L
s
.02381 .29171 m
.02756 .29171 L
s
.02381 .31479 m
.02756 .31479 L
s
.02381 .33787 m
.02756 .33787 L
s
.02381 .38404 m
.02756 .38404 L
s
.02381 .40712 m
.02756 .40712 L
s
.02381 .4302 m
.02756 .4302 L
s
.02381 .45328 m
.02756 .45328 L
s
.02381 .49945 m
.02756 .49945 L
s
.02381 .52253 m
.02756 .52253 L
s
.02381 .54561 m
.02756 .54561 L
s
.02381 .5687 m
.02756 .5687 L
s
.02381 .61486 m
.02756 .61486 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02753 .01472 m
.03125 .01472 L
.03497 .01472 L
.03869 .01472 L
.04241 .01472 L
.04613 .01472 L
.04985 .01472 L
.05357 .01473 L
.05729 .01473 L
.06101 .01474 L
.06473 .01475 L
.06845 .01476 L
.07217 .01478 L
.07589 .01479 L
.07961 .01481 L
.08333 .01483 L
.08705 .01486 L
.09077 .01489 L
.09449 .01492 L
.09821 .01496 L
.10193 .015 L
.10565 .01504 L
.10937 .01509 L
.1131 .01515 L
.11682 .01521 L
.12054 .01527 L
.12426 .01534 L
.12798 .01541 L
.1317 .01549 L
.13542 .01558 L
.13914 .01567 L
.14286 .01577 L
.14658 .01588 L
.1503 .01599 L
.15402 .01611 L
.15774 .01624 L
.16146 .01637 L
.16518 .01651 L
.1689 .01666 L
.17262 .01682 L
.17634 .01699 L
.18006 .01716 L
.18378 .01735 L
.1875 .01754 L
.19122 .01774 L
.19494 .01795 L
.19866 .01817 L
.20238 .0184 L
.2061 .01864 L
.20982 .01889 L
Mistroke
.21354 .01915 L
.21726 .01942 L
.22098 .01971 L
.2247 .02 L
.22842 .0203 L
.23214 .02062 L
.23586 .02095 L
.23958 .02129 L
.2433 .02164 L
.24702 .02201 L
.25074 .02238 L
.25446 .02277 L
.25818 .02318 L
.2619 .02359 L
.26563 .02402 L
.26935 .02446 L
.27307 .02492 L
.27679 .02539 L
.28051 .02588 L
.28423 .02638 L
.28795 .02689 L
.29167 .02742 L
.29539 .02796 L
.29911 .02852 L
.30283 .0291 L
.30655 .02969 L
.31027 .0303 L
.31399 .03092 L
.31771 .03156 L
.32143 .03222 L
.32515 .03289 L
.32887 .03358 L
.33259 .03429 L
.33631 .03501 L
.34003 .03575 L
.34375 .03652 L
.34747 .03729 L
.35119 .03809 L
.35491 .03891 L
.35863 .03974 L
.36235 .04059 L
.36607 .04147 L
.36979 .04236 L
.37351 .04327 L
.37723 .0442 L
.38095 .04515 L
.38467 .04612 L
.38839 .04711 L
.39211 .04813 L
.39583 .04916 L
Mistroke
.39955 .05021 L
.40327 .05129 L
.40699 .05239 L
.41071 .0535 L
.41443 .05465 L
.41815 .05581 L
.42188 .05699 L
.4256 .0582 L
.42932 .05943 L
.43304 .06069 L
.43676 .06196 L
.44048 .06326 L
.4442 .06459 L
.44792 .06593 L
.45164 .06731 L
.45536 .0687 L
.45908 .07012 L
.4628 .07157 L
.46652 .07304 L
.47024 .07453 L
.47396 .07606 L
.47768 .0776 L
.4814 .07917 L
.48512 .08077 L
.48884 .0824 L
.49256 .08405 L
.49628 .08572 L
.5 .08743 L
.50372 .08916 L
.50744 .09092 L
.51116 .0927 L
.51488 .09452 L
.5186 .09636 L
.52232 .09823 L
.52604 .10013 L
.52976 .10205 L
.53348 .10401 L
.5372 .10599 L
.54092 .10801 L
.54464 .11005 L
.54836 .11212 L
.55208 .11422 L
.5558 .11636 L
.55952 .11852 L
.56324 .12071 L
.56696 .12293 L
.57068 .12519 L
.5744 .12747 L
.57813 .12979 L
.58185 .13214 L
Mistroke
.58557 .13452 L
.58929 .13693 L
.59301 .13938 L
.59673 .14185 L
.60045 .14436 L
.60417 .1469 L
.60789 .14948 L
.61161 .15209 L
.61533 .15473 L
.61905 .15741 L
.62277 .16011 L
.62649 .16286 L
.63021 .16564 L
.63393 .16845 L
.63765 .17129 L
.64137 .17418 L
.64509 .17709 L
.64881 .18005 L
.65253 .18303 L
.65625 .18606 L
.65997 .18912 L
.66369 .19221 L
.66741 .19534 L
.67113 .19851 L
.67485 .20172 L
.67857 .20496 L
.68229 .20824 L
.68601 .21156 L
.68973 .21491 L
.69345 .21831 L
.69717 .22174 L
.70089 .22521 L
.70461 .22872 L
.70833 .23226 L
.71205 .23585 L
.71577 .23947 L
.71949 .24314 L
.72321 .24684 L
.72693 .25059 L
.73065 .25437 L
.73438 .2582 L
.7381 .26206 L
.74182 .26597 L
.74554 .26991 L
.74926 .2739 L
.75298 .27793 L
.7567 .282 L
.76042 .28611 L
.76414 .29026 L
.76786 .29446 L
Mistroke
.77158 .2987 L
.7753 .30298 L
.77902 .3073 L
.78274 .31167 L
.78646 .31608 L
.79018 .32053 L
.7939 .32503 L
.79762 .32957 L
.80134 .33416 L
.80506 .33879 L
.80878 .34346 L
.8125 .34818 L
.81622 .35294 L
.81994 .35775 L
.82366 .36261 L
.82738 .36751 L
.8311 .37245 L
.83482 .37744 L
.83854 .38248 L
.84226 .38757 L
.84598 .3927 L
.8497 .39787 L
.85342 .4031 L
.85714 .40837 L
.86086 .41369 L
.86458 .41906 L
.8683 .42447 L
.87202 .42994 L
.87574 .43545 L
.87946 .44101 L
.88318 .44662 L
.8869 .45228 L
.89063 .45798 L
.89435 .46374 L
.89807 .46955 L
.90179 .4754 L
.90551 .48131 L
.90923 .48726 L
.91295 .49327 L
.91667 .49933 L
.92039 .50544 L
.92411 .5116 L
.92783 .51781 L
.93155 .52407 L
.93527 .53039 L
.93899 .53675 L
.94271 .54317 L
.94643 .54964 L
.95015 .55616 L
.95387 .56274 L
Mistroke
.95759 .56937 L
.96131 .57605 L
.96503 .58279 L
.96875 .58958 L
.97247 .59642 L
.97619 .60332 L
Mfstroke
.02753 .01472 m
.03125 .01702 L
.03497 .01933 L
.03869 .02164 L
.04241 .02395 L
.04613 .02626 L
.04985 .02856 L
.05357 .03087 L
.05729 .03318 L
.06101 .03549 L
.06473 .0378 L
.06845 .04011 L
.07217 .04241 L
.07589 .04472 L
.07961 .04703 L
.08333 .04934 L
.08705 .05165 L
.09077 .05396 L
.09449 .05626 L
.09821 .05857 L
.10193 .06088 L
.10565 .06319 L
.10937 .0655 L
.1131 .0678 L
.11682 .07011 L
.12054 .07242 L
.12426 .07473 L
.12798 .07704 L
.1317 .07935 L
.13542 .08165 L
.13914 .08396 L
.14286 .08627 L
.14658 .08858 L
.1503 .09089 L
.15402 .0932 L
.15774 .0955 L
.16146 .09781 L
.16518 .10012 L
.1689 .10243 L
.17262 .10474 L
.17634 .10705 L
.18006 .10935 L
.18378 .11166 L
.1875 .11397 L
.19122 .11628 L
.19494 .11859 L
.19866 .12089 L
.20238 .1232 L
.2061 .12551 L
.20982 .12782 L
Mistroke
.21354 .13013 L
.21726 .13244 L
.22098 .13474 L
.2247 .13705 L
.22842 .13936 L
.23214 .14167 L
.23586 .14398 L
.23958 .14629 L
.2433 .14859 L
.24702 .1509 L
.25074 .15321 L
.25446 .15552 L
.25818 .15783 L
.2619 .16013 L
.26563 .16244 L
.26935 .16475 L
.27307 .16706 L
.27679 .16937 L
.28051 .17168 L
.28423 .17398 L
.28795 .17629 L
.29167 .1786 L
.29539 .18091 L
.29911 .18322 L
.30283 .18553 L
.30655 .18783 L
.31027 .19014 L
.31399 .19245 L
.31771 .19476 L
.32143 .19707 L
.32515 .19938 L
.32887 .20168 L
.33259 .20399 L
.33631 .2063 L
.34003 .20861 L
.34375 .21092 L
.34747 .21322 L
.35119 .21553 L
.35491 .21784 L
.35863 .22015 L
.36235 .22246 L
.36607 .22477 L
.36979 .22707 L
.37351 .22938 L
.37723 .23169 L
.38095 .234 L
.38467 .23631 L
.38839 .23862 L
.39211 .24092 L
.39583 .24323 L
Mistroke
.39955 .24554 L
.40327 .24785 L
.40699 .25016 L
.41071 .25246 L
.41443 .25477 L
.41815 .25708 L
.42188 .25939 L
.4256 .2617 L
.42932 .26401 L
.43304 .26631 L
.43676 .26862 L
.44048 .27093 L
.4442 .27324 L
.44792 .27555 L
.45164 .27786 L
.45536 .28016 L
.45908 .28247 L
.4628 .28478 L
.46652 .28709 L
.47024 .2894 L
.47396 .29171 L
.47768 .29401 L
.4814 .29632 L
.48512 .29863 L
.48884 .30094 L
.49256 .30325 L
.49628 .30555 L
.5 .30786 L
.50372 .31017 L
.50744 .31248 L
.51116 .31479 L
.51488 .3171 L
.5186 .3194 L
.52232 .32171 L
.52604 .32402 L
.52976 .32633 L
.53348 .32864 L
.5372 .33095 L
.54092 .33325 L
.54464 .33556 L
.54836 .33787 L
.55208 .34018 L
.5558 .34249 L
.55952 .34479 L
.56324 .3471 L
.56696 .34941 L
.57068 .35172 L
.5744 .35403 L
.57813 .35634 L
.58185 .35864 L
Mistroke
.58557 .36095 L
.58929 .36326 L
.59301 .36557 L
.59673 .36788 L
.60045 .37019 L
.60417 .37249 L
.60789 .3748 L
.61161 .37711 L
.61533 .37942 L
.61905 .38173 L
.62277 .38404 L
.62649 .38634 L
.63021 .38865 L
.63393 .39096 L
.63765 .39327 L
.64137 .39558 L
.64509 .39788 L
.64881 .40019 L
.65253 .4025 L
.65625 .40481 L
.65997 .40712 L
.66369 .40943 L
.66741 .41173 L
.67113 .41404 L
.67485 .41635 L
.67857 .41866 L
.68229 .42097 L
.68601 .42328 L
.68973 .42558 L
.69345 .42789 L
.69717 .4302 L
.70089 .43251 L
.70461 .43482 L
.70833 .43712 L
.71205 .43943 L
.71577 .44174 L
.71949 .44405 L
.72321 .44636 L
.72693 .44867 L
.73065 .45097 L
.73438 .45328 L
.7381 .45559 L
.74182 .4579 L
.74554 .46021 L
.74926 .46252 L
.75298 .46482 L
.7567 .46713 L
.76042 .46944 L
.76414 .47175 L
.76786 .47406 L
Mistroke
.77158 .47637 L
.7753 .47867 L
.77902 .48098 L
.78274 .48329 L
.78646 .4856 L
.79018 .48791 L
.7939 .49021 L
.79762 .49252 L
.80134 .49483 L
.80506 .49714 L
.80878 .49945 L
.8125 .50176 L
.81622 .50406 L
.81994 .50637 L
.82366 .50868 L
.82738 .51099 L
.8311 .5133 L
.83482 .51561 L
.83854 .51791 L
.84226 .52022 L
.84598 .52253 L
.8497 .52484 L
.85342 .52715 L
.85714 .52945 L
.86086 .53176 L
.86458 .53407 L
.8683 .53638 L
.87202 .53869 L
.87574 .541 L
.87946 .5433 L
.88318 .54561 L
.8869 .54792 L
.89063 .55023 L
.89435 .55254 L
.89807 .55485 L
.90179 .55715 L
.90551 .55946 L
.90923 .56177 L
.91295 .56408 L
.91667 .56639 L
.92039 .5687 L
.92411 .571 L
.92783 .57331 L
.93155 .57562 L
.93527 .57793 L
.93899 .58024 L
.94271 .58254 L
.94643 .58485 L
.95015 .58716 L
.95387 .58947 L
Mistroke
.95759 .59178 L
.96131 .59409 L
.96503 .59639 L
.96875 .5987 L
.97247 .60101 L
.97619 .60332 L
Mfstroke
.02753 .01472 m
.03125 .05157 L
.03497 .06684 L
.03869 .07856 L
.04241 .08843 L
.04613 .09714 L
.04985 .105 L
.05357 .11224 L
.05729 .11897 L
.06101 .12529 L
.06473 .13128 L
.06845 .13697 L
.07217 .1424 L
.07589 .14761 L
.07961 .15263 L
.08333 .15747 L
.08705 .16215 L
.09077 .16669 L
.09449 .1711 L
.09821 .17538 L
.10193 .17956 L
.10565 .18363 L
.10937 .1876 L
.1131 .19149 L
.11682 .19529 L
.12054 .19901 L
.12426 .20266 L
.12798 .20624 L
.1317 .20976 L
.13542 .21321 L
.13914 .2166 L
.14286 .21994 L
.14658 .22323 L
.1503 .22646 L
.15402 .22964 L
.15774 .23278 L
.16146 .23587 L
.16518 .23892 L
.1689 .24193 L
.17262 .2449 L
.17634 .24784 L
.18006 .25073 L
.18378 .25359 L
.1875 .25642 L
.19122 .25922 L
.19494 .26198 L
.19866 .26471 L
.20238 .26741 L
.2061 .27009 L
.20982 .27273 L
Mistroke
.21354 .27535 L
.21726 .27795 L
.22098 .28051 L
.2247 .28306 L
.22842 .28558 L
.23214 .28807 L
.23586 .29055 L
.23958 .293 L
.2433 .29543 L
.24702 .29784 L
.25074 .30023 L
.25446 .3026 L
.25818 .30495 L
.2619 .30728 L
.26563 .30959 L
.26935 .31189 L
.27307 .31417 L
.27679 .31643 L
.28051 .31867 L
.28423 .3209 L
.28795 .32311 L
.29167 .3253 L
.29539 .32748 L
.29911 .32965 L
.30283 .3318 L
.30655 .33393 L
.31027 .33605 L
.31399 .33816 L
.31771 .34025 L
.32143 .34233 L
.32515 .3444 L
.32887 .34645 L
.33259 .34849 L
.33631 .35052 L
.34003 .35254 L
.34375 .35455 L
.34747 .35654 L
.35119 .35852 L
.35491 .36049 L
.35863 .36245 L
.36235 .3644 L
.36607 .36634 L
.36979 .36826 L
.37351 .37018 L
.37723 .37208 L
.38095 .37398 L
.38467 .37587 L
.38839 .37774 L
.39211 .37961 L
.39583 .38147 L
Mistroke
.39955 .38331 L
.40327 .38515 L
.40699 .38698 L
.41071 .3888 L
.41443 .39061 L
.41815 .39242 L
.42188 .39421 L
.4256 .396 L
.42932 .39777 L
.43304 .39954 L
.43676 .4013 L
.44048 .40306 L
.4442 .4048 L
.44792 .40654 L
.45164 .40827 L
.45536 .40999 L
.45908 .41171 L
.4628 .41341 L
.46652 .41512 L
.47024 .41681 L
.47396 .41849 L
.47768 .42017 L
.4814 .42184 L
.48512 .42351 L
.48884 .42517 L
.49256 .42682 L
.49628 .42847 L
.5 .4301 L
.50372 .43174 L
.50744 .43336 L
.51116 .43498 L
.51488 .43659 L
.5186 .4382 L
.52232 .4398 L
.52604 .4414 L
.52976 .44299 L
.53348 .44457 L
.5372 .44615 L
.54092 .44772 L
.54464 .44929 L
.54836 .45085 L
.55208 .4524 L
.5558 .45395 L
.55952 .45549 L
.56324 .45703 L
.56696 .45857 L
.57068 .46009 L
.5744 .46162 L
.57813 .46313 L
.58185 .46465 L
Mistroke
.58557 .46615 L
.58929 .46766 L
.59301 .46915 L
.59673 .47065 L
.60045 .47213 L
.60417 .47362 L
.60789 .47509 L
.61161 .47657 L
.61533 .47804 L
.61905 .4795 L
.62277 .48096 L
.62649 .48241 L
.63021 .48386 L
.63393 .48531 L
.63765 .48675 L
.64137 .48819 L
.64509 .48962 L
.64881 .49105 L
.65253 .49247 L
.65625 .49389 L
.65997 .49531 L
.66369 .49672 L
.66741 .49813 L
.67113 .49953 L
.67485 .50093 L
.67857 .50232 L
.68229 .50372 L
.68601 .5051 L
.68973 .50649 L
.69345 .50787 L
.69717 .50924 L
.70089 .51061 L
.70461 .51198 L
.70833 .51335 L
.71205 .51471 L
.71577 .51606 L
.71949 .51742 L
.72321 .51877 L
.72693 .52011 L
.73065 .52145 L
.73438 .52279 L
.7381 .52413 L
.74182 .52546 L
.74554 .52679 L
.74926 .52811 L
.75298 .52943 L
.7567 .53075 L
.76042 .53207 L
.76414 .53338 L
.76786 .53469 L
Mistroke
.77158 .53599 L
.7753 .53729 L
.77902 .53859 L
.78274 .53989 L
.78646 .54118 L
.79018 .54247 L
.7939 .54375 L
.79762 .54504 L
.80134 .54631 L
.80506 .54759 L
.80878 .54886 L
.8125 .55013 L
.81622 .5514 L
.81994 .55267 L
.82366 .55393 L
.82738 .55519 L
.8311 .55644 L
.83482 .55769 L
.83854 .55894 L
.84226 .56019 L
.84598 .56143 L
.8497 .56268 L
.85342 .56391 L
.85714 .56515 L
.86086 .56638 L
.86458 .56761 L
.8683 .56884 L
.87202 .57006 L
.87574 .57129 L
.87946 .57251 L
.88318 .57372 L
.8869 .57494 L
.89063 .57615 L
.89435 .57736 L
.89807 .57856 L
.90179 .57977 L
.90551 .58097 L
.90923 .58216 L
.91295 .58336 L
.91667 .58455 L
.92039 .58574 L
.92411 .58693 L
.92783 .58812 L
.93155 .5893 L
.93527 .59048 L
.93899 .59166 L
.94271 .59284 L
.94643 .59401 L
.95015 .59518 L
.95387 .59635 L
Mistroke
.95759 .59752 L
.96131 .59868 L
.96503 .59985 L
.96875 .60101 L
.97247 .60216 L
.97619 .60332 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo0015Ool0
0`00Oomoo`02Ool00`00Oomoo`0VOol50002Ool00`00Oomoo`02Ool00`00Oomoo`0SOol50002Ool0
0`00Oomoo`02Ool00`00Oomoo`0UOol30003Ool00`00Oomoo`02Ool00`00Oomoo`0TOol30003Ool0
0`00Oomoo`02Ool00`00Oomoo`07Ool004Aoo`03001oo`00009oo`03001oo`0002Uoo`07001oogoo
Ool007oo00000Woo00<007oo00009Woo00L007ooOomoo`00Ool00002Ool00`00Ool0000VOol00`00
Oomoo`02Ool00`00Ool00002Ool00`00Ool0000UOol00`00Oomoo`02Ool00`00Ool00002Ool00`00
Ool00008Ool004Ioo`06001oogoo001oo`00:Goo00L007ooOomoo`00Ool00002Ool00`00Ool0000V
Ool00`00Oomoo`03Ool01P00Oomoo`00Ool002Moo`07001oogooOol007oo00000Woo00<007oo0000
9Woo00<007ooOol00goo00H007ooOol007oo0008Ool004Aoo`8000=oo`03001oo`0002Uoo`07001o
ogooOol007oo00000Woo00<007oo00009Woo00@007ooOomoo`8000=oo`03001oo`0002Moo`07001o
ogooOol007oo00000Woo00<007oo00009Woo00@007ooOomoo`8000=oo`03001oo`0000Qoo`00A7oo
00<007ooOol00Woo00<007oo0000:Goo00L007ooOomoo`00Ool00002Ool00`00Ool0000VOol01@00
Oomoogoo000017oo00<007oo00009Woo00<007oo00000Woo00<007oo00000Woo00<007oo00009Goo
00<007oo00000Woo00<007ooOol00Woo00<007oo000027oo0014Ool30003Ool00`00Oomoo`0WOol2
0004Ool00`00Oomoo`02Ool00`00Oomoo`0TOol20003Ool30003Ool00`00Oomoo`0VOol00`00Oomo
o`02Ool00`00Oomoo`02Ool00`00Oomoo`0UOol01000Oomoogoo0`000goo00<007ooOol01goo003o
OolQOol001Eoo`03001oogoo0?moo`Uoo`005Goo00<007ooOol0ogoo2Goo000EOol00`00Oomoo`3o
Ool9Ool001Eoo`03001oogoo0?moo`Uoo`003Wooo`004`00000EOol40006Ool00`00Oomoo`07Ool0
0`00Oomoo`07Ool01000Oomoogoo50001goo00<007ooOol01goo00<007ooOol01goo00<007ooOol0
1goo00<007ooOol01goo00<007ooOol01goo00<007ooOol01goo00<007ooOol01goo00<007ooOol0
27oo00<007ooOol01goo00<007ooOol01goo00<007ooOol01goo00<007ooOol01goo00<007ooOol0
1goo00<007ooOol01goo00<007ooOol01goo00<007ooOol027oo00<007ooOol01goo00<007ooOol0
1goo00<007ooOol01goo00<007ooOol01goo00<007ooOol00Goo000EOol20002Ool00`00Oomoo`0/
Ool00`00Oomoo`0;000TOol00`00Oomoo`0`Ool00`00Oomoo`0_Ool00`00Oomoo`0`Ool00`00Oomo
o`0;Ool001Eoo`8000=oo`8003Yoo`P00<9oo`005Goo0P001Goo00<007ooOol0?goo1P00_7oo000E
Ool20006Ool20015Ool6002fOol001Eoo`<000Moo`8004Uoo`@00;9oo`005Goo00<007oo00002Goo
00<007ooOol0BWoo1@00[Goo000EOol00`00Ool0000:Ool2001?Ool4002YOol001Eoo`03001oo`00
00aoo`03001oogoo051oo`<00:Ioo`005Goo00<007oo00003Goo0P00Dgoo1000XWoo000EOol00`00
Ool0000?Ool2001EOol3002OOol001Eoo`03001oo`00015oo`03001oogoo05Eoo`<009aoo`005Goo
0P0000=oo`00Ool047oo0P00F7oo0`00VGoo000EOol01000Oomoo`004goo00<007ooOol0F7oo0`00
UWoo000EOol01000Oomoo`0057oo0P00Fgoo0P00U7oo000EOol01000Oomoo`005Woo0P00Fgoo0`00
TGoo000EOol01@00Oomoogoo00005goo00<007ooOol0Fgoo0P00Sgoo000EOol01@00Oomoogoo0000
67oo0P00GGoo0P00SGoo000EOol20002Ool00`00Oomoo`0HOol00`00Oomoo`1LOol3002:Ool001Eo
o`03001oogoo009oo`03001oogoo01Qoo`8005moo`8008Qoo`005Goo00<007ooOol00Woo00<007oo
Ool06Woo00<007ooOol0GWoo0P00QWoo000EOol00`00Oomoo`03Ool00`00Oomoo`0JOol2001POol3
0023Ool001Eoo`03001oogoo00=oo`03001oogoo01aoo`80065oo`80085oo`005Goo00<007ooOol0
0goo00<007ooOol07Woo00<007ooOol0H7oo0P00Ogoo000EOol20005Ool00`00Oomoo`0NOol2001R
Ool00`00Oomoo`1lOol001Eoo`03001oogoo00Aoo`03001oogoo021oo`03001oogoo061oo`8007ao
o`005Goo00<007ooOol01Goo00<007ooOol087oo0P00HWoo0P00NWoo000EOol00`00Oomoo`05Ool0
0`00Oomoo`0ROol2001ROol2001hOol001Eoo`03001oogoo00Ioo`03001oogoo02=oo`03001oogoo
065oo`03001oogoo07Eoo`002Woo00<007ooOol00Woo00<007ooOol00goo00<007ooOol01goo00<0
07ooOol08goo0`00HGoo0P00MGoo0009Ool00`00Ool00002Ool00`00Ool00004Ool00`00Oomoo`07
Ool00`00Oomoo`0VOol00`00Oomoo`1POol2001cOol000]oo`06001oogoo001oo`0017oo0`0027oo
00<007ooOol09Woo0P00HWoo00<007ooOol0L7oo0009Ool20003Ool00`00Ool00004Ool00`00Oomo
o`09Ool00`00Oomoo`0WOol2001QOol2001`Ool000Uoo`03001oogoo009oo`03001oo`0000Aoo`03
001oogoo00Uoo`03001oogoo02Uoo`03001oogoo061oo`03001oogoo06eoo`002Goo0`000goo00<0
07ooOol00goo00<007ooOol02Woo00<007ooOol0:Goo0P00HGoo0P00KGoo000EOol00`00Oomoo`0;
Ool00`00Oomoo`0ZOol00`00Oomoo`1POol00`00Oomoo`1ZOol001Eoo`03001oogoo00]oo`03001o
ogoo02]oo`80065oo`03001oogoo06Uoo`005Goo0P003Goo00<007ooOol0;7oo0P00H7oo0P00JGoo
000EOol00`00Oomoo`0=Ool00`00Oomoo`0]Ool00`00Oomoo`1OOol00`00Oomoo`1VOol001Eoo`03
001oogoo00ioo`03001oogoo02eoo`80061oo`8006Ioo`005Goo00<007ooOol03Woo00<007ooOol0
;goo00<007ooOol0Ggoo00<007ooOol0Hgoo000EOol00`00Oomoo`0?Ool00`00Oomoo`0_Ool2001P
Ool00`00Oomoo`1ROol001Eoo`03001oogoo011oo`03001oogoo031oo`8005moo`03001oogoo065o
o`005Goo0P004Woo00<007ooOol0<Goo00<007ooOol0GGoo0P00HGoo000EOol00`00Oomoo`0BOol0
0`00Oomoo`0aOol2001OOol00`00Oomoo`1NOol001Eoo`03001oogoo01=oo`03001oogoo039oo`03
001oogoo05eoo`03001oogoo05eoo`005Goo00<007ooOol057oo00<007ooOol0<Woo0P00GWoo00<0
07ooOol0G7oo000EOol00`00Oomoo`0EOol00`00Oomoo`0cOol00`00Oomoo`1LOol2001LOol001Eo
o`03001oogoo01Ioo`03001oogoo03=oo`8005ioo`03001oogoo05Uoo`005Goo0P0067oo00<007oo
Ool0=7oo0P00GGoo00<007ooOol0F7oo000EOol00`00Oomoo`0HOol00`00Oomoo`0eOol00`00Oomo
o`1KOol00`00Oomoo`1GOol001Eoo`03001oogoo01Uoo`03001oogoo03Eoo`8005aoo`03001oogoo
05Ioo`005Goo00<007ooOol06Woo00<007ooOol0=Woo00<007ooOol0FWoo00<007ooOol0EGoo000E
Ool00`00Oomoo`0KOol00`00Oomoo`0fOol2001KOol00`00Oomoo`1DOol001Eoo`03001oogoo01ao
o`03001oogoo03Moo`8005Yoo`03001oogoo05=oo`005Goo00<007ooOol07Goo00<007ooOol0>7oo
00<007ooOol0F7oo0P00Dgoo000EOol2000OOol00`00Oomoo`0hOol2001JOol00`00Oomoo`1@Ool0
01Eoo`03001oogoo01moo`03001oogoo03Uoo`03001oogoo05Qoo`03001oogoo04moo`005Goo00<0
07ooOol087oo0P00>Woo0P00FGoo00<007ooOol0CWoo000EOol00`00Oomoo`0ROol00`00Oomoo`0i
Ool2001HOol00`00Oomoo`1=Ool000=oo`D0009oo`03001oogoo009oo`03001oogoo00=oo`03001o
ogoo02=oo`03001oogoo03Yoo`03001oogoo05Ioo`03001oogoo04aoo`001Goo00L007ooOomoo`00
Ool00002Ool00`00Ool00004Ool00`00Oomoo`0TOol00`00Oomoo`0jOol2001GOol00`00Oomoo`1;
Ool000Eoo`07001oogooOol007oo00000Woo00<007oo000017oo0`009Goo00<007ooOol0>goo00<0
07ooOol0EGoo00<007ooOol0BWoo0005Ool01`00Oomoogoo001oo`00009oo`03001oo`0000Aoo`03
001oogoo02Ioo`8003aoo`8005Ioo`03001oogoo04Uoo`001Goo00L007ooOomoo`00Ool00002Ool0
0`00Ool00004Ool00`00Oomoo`0XOol00`00Oomoo`0kOol2001EOol00`00Oomoo`18Ool000Aoo`80
00Aoo`03001oogoo009oo`03001oogoo00=oo`03001oogoo02Uoo`03001oogoo03aoo`03001oogoo
05=oo`03001oogoo04Moo`005Goo00<007ooOol0:Woo0P00?Goo0P00E7oo00<007ooOol0AWoo000E
Ool00`00Oomoo`0/Ool00`00Oomoo`0lOol00`00Oomoo`1AOol00`00Oomoo`16Ool001Eoo`8002io
o`03001oogoo03aoo`80059oo`03001oogoo04Eoo`005Goo00<007ooOol0;Woo0`00?Goo0P00DGoo
00<007ooOol0A7oo000EOol00`00Oomoo`0aOol00`00Oomoo`0lOol00`00Oomoo`1?Ool00`00Oomo
o`13Ool001Eoo`03001oogoo039oo`8003eoo`80051oo`03001oogoo049oo`005Goo00<007ooOol0
=7oo00<007ooOol0?7oo00<007ooOol0CWoo00<007ooOol0@Goo000EOol00`00Oomoo`0eOol00`00
Oomoo`0lOol2001?Ool00`00Oomoo`10Ool001Eoo`03001oogoo03Ioo`8003ioo`03001oogoo04eo
o`03001oogoo03moo`005Goo0P00>Goo00<007ooOol0?7oo0P00CWoo00<007ooOol0?Woo000EOol0
0`00Oomoo`0iOol2000nOol2001=Ool00`00Oomoo`0mOol001Eoo`03001oogoo03]oo`8003ioo`03
001oogoo04Yoo`03001oogoo03eoo`005Goo00<007ooOol0?Goo00<007ooOol0?7oo0P00Bgoo00<0
07ooOol0?7oo000EOol00`00Oomoo`0nOol2000nOol00`00Oomoo`19Ool00`00Oomoo`0kOol001Eo
o`03001oogoo041oo`03001oogoo03aoo`8004Yoo`03001oogoo03Yoo`005Goo0P00@Woo0P00?Woo
0`00B7oo00<007ooOol0>Goo000EOol00`00Oomoo`13Ool2000oOol00`00Oomoo`16Ool00`00Oomo
o`0hOol001Eoo`03001oogoo04Eoo`03001oogoo03eoo`8004Ioo`03001oogoo03Qoo`005Goo00<0
07ooOol0AWoo0P00?goo00<007ooOol0A7oo00<007ooOol0=goo000EOol00`00Oomoo`18Ool2000n
Ool20015Ool00`00Oomoo`0fOol001Eoo`03001oogoo04Yoo`03001oogoo03eoo`8004Aoo`03001o
ogoo03Eoo`005Goo0P00C7oo0P00?goo00<007ooOol0@Woo00<007ooOol0=7oo000EOol00`00Oomo
o`1=Ool2000nOol20012Ool00`00Oomoo`0dOol001Eoo`03001oogoo04moo`8003ioo`03001oogoo
041oo`03001oogoo03=oo`005Goo00<007ooOol0DGoo00<007ooOol0?7oo0P00@Goo00<007ooOol0
<Woo0003Ool50002Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`1BOol2000nOol20010
Ool00`00Oomoo`0aOol000Eoo`07001oogooOol007oo00000Woo00<007oo000017oo00<007ooOol0
E7oo0P00?Woo00<007ooOol0?Woo0P00<Goo0005Ool00`00Oomoo`03Ool01P00Oomoo`00Ool000Ao
o`<005Ioo`8003eoo`8003moo`03001oogoo02moo`001Goo00@007ooOomoo`8000=oo`03001oo`00
00Aoo`03001oogoo05Qoo`8003eoo`03001oogoo03eoo`03001oogoo02ioo`001Goo00D007ooOomo
o`0000Aoo`03001oo`0000Aoo`03001oogoo05Yoo`8003aoo`8003ioo`03001oogoo02eoo`0017oo
0P000goo0`000goo00<007ooOol00goo00<007ooOol0G7oo0P00?7oo0P00?Goo00<007ooOol0;7oo
000EOol00`00Oomoo`1NOol2000lOol00`00Oomoo`0jOol00`00Oomoo`0/Ool001Eoo`03001oogoo
061oo`8003]oo`8003]oo`03001oogoo02]oo`005Goo00<007ooOol0HWoo0P00>goo00<007ooOol0
>Goo00<007ooOol0:Woo000EOol2001UOol2000jOol2000iOol00`00Oomoo`0ZOol001Eoo`03001o
ogoo06Ioo`8003Yoo`03001oogoo03Moo`03001oogoo02Uoo`005Goo00<007ooOol0J7oo0P00>Goo
0P00>7oo00<007ooOol0:7oo000EOol00`00Oomoo`1ZOol2000iOol2000gOol00`00Oomoo`0WOol0
01Eoo`03001oogoo06aoo`8003Uoo`03001oogoo03Aoo`03001oogoo02Moo`005Goo00<007ooOol0
KWoo0P00>7oo0P00=Goo00<007ooOol09Woo000EOol2001aOol2000hOol00`00Oomoo`0cOol00`00
Oomoo`0UOol001Eoo`03001oogoo079oo`8003Moo`8003=oo`03001oogoo02Eoo`005Goo00<007oo
Ool0M7oo0P00=goo0P00<Woo00<007ooOol097oo000EOol00`00Oomoo`1fOol3000fOol00`00Oomo
o`0`Ool00`00Oomoo`0SOol001Eoo`03001oogoo07Uoo`8003Eoo`80031oo`03001oogoo02=oo`00
5Goo00<007ooOol0Ngoo0P00=Goo00<007ooOol0;Woo00<007ooOol08Woo000EOol2001nOol2000d
Ool2000_Ool00`00Oomoo`0QOol001Eoo`03001oogoo07moo`<003=oo`8002eoo`03001oogoo025o
o`005Goo00<007ooOol0PWoo0`00<Woo00<007ooOol0:goo00<007ooOol087oo000EOol00`00Oomo
o`25Ool2000aOol2000/Ool00`00Oomoo`0OOol001Eoo`03001oogoo08Moo`80035oo`03001oogoo
02Uoo`03001oogoo01moo`005Goo00<007ooOol0RGoo0`00;goo0P00:Woo00<007ooOol07Woo000E
Ool2002=Ool2000_Ool2000YOol00`00Oomoo`0MOol001Eoo`03001oogoo08ioo`<002ioo`03001o
ogoo02Ioo`03001oogoo01eoo`005Goo00<007ooOol0TGoo0P00;Goo0P009goo00<007ooOol077oo
000EOol00`00Oomoo`2COol2000]Ool00`00Oomoo`0UOol00`00Oomoo`0KOol001Eoo`03001oogoo
09Eoo`<002]oo`8002Eoo`03001oogoo01]oo`0017oo0`000goo00<007ooOol00Woo00<007ooOol0
0goo00<007ooOol0V7oo0P00:goo00<007ooOol08goo00<007ooOol06Woo0004Ool00`00Oomoo`02
Ool00`00Ool00002Ool00`00Ool00004Ool00`00Oomoo`2JOol3000YOol2000TOol00`00Oomoo`0I
Ool000Eoo`07001oogooOol007oo00000Woo00<007oo000017oo0`00WGoo0P00:Goo0P008Woo00<0
07ooOol06Goo0005Ool01`00Oomoogoo001oo`00009oo`03001oo`0000Aoo`03001oogoo09moo`<0
02Qoo`03001oogoo021oo`03001oogoo01Qoo`0017oo00<007oo00000Woo00<007oo00000Woo00<0
07oo000017oo00<007ooOol0XWoo0P009goo0P0087oo00<007ooOol067oo0005Ool00`00Oomoo`02
Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`2TOol3000VOol00`00Oomoo`0NOol00`00
Oomoo`0GOol001Eoo`03001oogoo0:Moo`8002Eoo`8001moo`03001oogoo01Ioo`005Goo00<007oo
Ool0ZGoo0`0097oo0P007Goo00<007ooOol05Woo000EOol2002]Ool3000SOol00`00Oomoo`0KOol0
0`00Oomoo`0EOol001Eoo`03001oogoo0:moo`80029oo`8001]oo`03001oogoo01Eoo`005Goo00<0
07ooOol0/Goo0`008Goo0P006Woo00<007ooOol057oo000EOol00`00Oomoo`2dOol3000POol2000I
Ool00`00Oomoo`0COol001Eoo`03001oogoo0;Moo`80021oo`8001Moo`03001oogoo01=oo`005Goo
00<007ooOol0^Goo0`007goo00<007ooOol05Goo00<007ooOol04Woo000EOol2002mOol3000MOol2
000EOol00`00Oomoo`0BOol001Eoo`03001oogoo0;moo`<001aoo`03001oogoo01=oo`03001oogoo
015oo`005Goo00<007ooOol0`Woo0P006goo0P0057oo00<007ooOol047oo000EOol00`00Oomoo`34
Ool3000JOol2000BOol00`00Oomoo`0@Ool001Eoo`03001oogoo0<Moo`<001Uoo`03001oogoo011o
o`03001oogoo00moo`005Goo00<007ooOol0bWoo0`005goo0P0047oo00<007ooOol03goo000EOol0
0`00Oomoo`3=Ool3000FOol00`00Oomoo`0>Ool00`00Oomoo`0>Ool001Eoo`800=5oo`<001Aoo`80
00ioo`03001oogoo00ioo`005Goo00<007ooOol0dgoo0P0057oo0P003Goo00<007ooOol03Goo000E
Ool00`00Oomoo`3EOol4000BOol00`00Oomoo`0;Ool00`00Oomoo`0<Ool001Eoo`03001oogoo0=Uo
o`<0011oo`8000]oo`03001oogoo00aoo`005Goo00<007ooOol0g7oo0`003goo00<007ooOol02Goo
00<007ooOol02goo000EOol00`00Oomoo`3OOol3000=Ool20009Ool00`00Oomoo`0;Ool001Eoo`80
0>=oo`<000aoo`03001oogoo00Moo`03001oogoo00Yoo`005Goo00<007ooOol0iGoo0`002Woo0P00
1goo00<007ooOol02Woo000EOol00`00Oomoo`3XOol30009Ool20006Ool00`00Oomoo`09Ool001Eo
o`03001oogoo0>]oo`<000Qoo`03001oogoo00=oo`03001oogoo00Uoo`0017oo0`000goo00<007oo
Ool00Woo00<007ooOol00goo00<007ooOol0kWoo0`001Woo0P0017oo00<007ooOol027oo0004Ool0
0`00Oomoo`02Ool00`00Ool00002Ool00`00Ool00004Ool00`00Oomoo`3aOol40004Ool01@00Oomo
ogoo00002Woo0005Ool00`00Oomoo`03Ool01P00Oomoo`00Ool000Aoo`<00?Eoo`<0009oo`80009o
o`03001oogoo00Moo`001Goo00@007ooOomoo`8000=oo`03001oo`0000Aoo`03001oogoo0?Qoo`<0
0005Ool00000Ool00008Ool000Aoo`03001oo`00009oo`03001oogoo009oo`03001oo`0000Aoo`03
001oogoo0?]oo`D000Qoo`001Goo00@007ooOomoo`<000=oo`03001oogoo00=oo`03001oogoo0?io
o`<000Moo`005Goo00<007ooOol0ogoo2Goo000EOol00`00Oomoo`3oOol9Ool001Eoo`800?moo`Yo
o`005Goo00<007ooOol0ogoo2Goo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-21.1446, -20.0556, 
  0.987964, 1.59232}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Contrast modification using the logarithmic law.", "Subsection"],

Cell["\<\
The logarithmic function is typically used to compress the range of data with \
large dynamic range. This is especially usefull when displaying image \
transforms. The transfer function has the following shape.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(ListPlot[ContrastModifyLog[x], PlotJoined -> True]; \)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00372024 0.0147151 0.106147 [
[.20982 .00222 -6 -9 ]
[.20982 .00222 6 0 ]
[.39583 .00222 -9 -9 ]
[.39583 .00222 9 0 ]
[.58185 .00222 -9 -9 ]
[.58185 .00222 9 0 ]
[.76786 .00222 -9 -9 ]
[.76786 .00222 9 0 ]
[.95387 .00222 -9 -9 ]
[.95387 .00222 9 0 ]
[.01131 .12086 -6 -4.5 ]
[.01131 .12086 0 4.5 ]
[.01131 .22701 -6 -4.5 ]
[.01131 .22701 0 4.5 ]
[.01131 .33316 -6 -4.5 ]
[.01131 .33316 0 4.5 ]
[.01131 .4393 -6 -4.5 ]
[.01131 .4393 0 4.5 ]
[.01131 .54545 -6 -4.5 ]
[.01131 .54545 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.20982 .01472 m
.20982 .02097 L
s
[(50)] .20982 .00222 0 1 Mshowa
.39583 .01472 m
.39583 .02097 L
s
[(100)] .39583 .00222 0 1 Mshowa
.58185 .01472 m
.58185 .02097 L
s
[(150)] .58185 .00222 0 1 Mshowa
.76786 .01472 m
.76786 .02097 L
s
[(200)] .76786 .00222 0 1 Mshowa
.95387 .01472 m
.95387 .02097 L
s
[(250)] .95387 .00222 0 1 Mshowa
.125 Mabswid
.06101 .01472 m
.06101 .01847 L
s
.09821 .01472 m
.09821 .01847 L
s
.13542 .01472 m
.13542 .01847 L
s
.17262 .01472 m
.17262 .01847 L
s
.24702 .01472 m
.24702 .01847 L
s
.28423 .01472 m
.28423 .01847 L
s
.32143 .01472 m
.32143 .01847 L
s
.35863 .01472 m
.35863 .01847 L
s
.43304 .01472 m
.43304 .01847 L
s
.47024 .01472 m
.47024 .01847 L
s
.50744 .01472 m
.50744 .01847 L
s
.54464 .01472 m
.54464 .01847 L
s
.61905 .01472 m
.61905 .01847 L
s
.65625 .01472 m
.65625 .01847 L
s
.69345 .01472 m
.69345 .01847 L
s
.73065 .01472 m
.73065 .01847 L
s
.80506 .01472 m
.80506 .01847 L
s
.84226 .01472 m
.84226 .01847 L
s
.87946 .01472 m
.87946 .01847 L
s
.91667 .01472 m
.91667 .01847 L
s
.99107 .01472 m
.99107 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02381 .12086 m
.03006 .12086 L
s
[(1)] .01131 .12086 1 0 Mshowa
.02381 .22701 m
.03006 .22701 L
s
[(2)] .01131 .22701 1 0 Mshowa
.02381 .33316 m
.03006 .33316 L
s
[(3)] .01131 .33316 1 0 Mshowa
.02381 .4393 m
.03006 .4393 L
s
[(4)] .01131 .4393 1 0 Mshowa
.02381 .54545 m
.03006 .54545 L
s
[(5)] .01131 .54545 1 0 Mshowa
.125 Mabswid
.02381 .03594 m
.02756 .03594 L
s
.02381 .05717 m
.02756 .05717 L
s
.02381 .0784 m
.02756 .0784 L
s
.02381 .09963 m
.02756 .09963 L
s
.02381 .14209 m
.02756 .14209 L
s
.02381 .16332 m
.02756 .16332 L
s
.02381 .18455 m
.02756 .18455 L
s
.02381 .20578 m
.02756 .20578 L
s
.02381 .24824 m
.02756 .24824 L
s
.02381 .26947 m
.02756 .26947 L
s
.02381 .2907 m
.02756 .2907 L
s
.02381 .31193 m
.02756 .31193 L
s
.02381 .35439 m
.02756 .35439 L
s
.02381 .37561 m
.02756 .37561 L
s
.02381 .39684 m
.02756 .39684 L
s
.02381 .41807 m
.02756 .41807 L
s
.02381 .46053 m
.02756 .46053 L
s
.02381 .48176 m
.02756 .48176 L
s
.02381 .50299 m
.02756 .50299 L
s
.02381 .52422 m
.02756 .52422 L
s
.02381 .56668 m
.02756 .56668 L
s
.02381 .58791 m
.02756 .58791 L
s
.02381 .60914 m
.02756 .60914 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02753 .01472 m
.03125 .08829 L
.03497 .13133 L
.03869 .16187 L
.04241 .18555 L
.04613 .2049 L
.04985 .22127 L
.05357 .23544 L
.05729 .24794 L
.06101 .25913 L
.06473 .26924 L
.06845 .27848 L
.07217 .28698 L
.07589 .29484 L
.07961 .30217 L
.08333 .30902 L
.08705 .31545 L
.09077 .32152 L
.09449 .32726 L
.09821 .3327 L
.10193 .33788 L
.10565 .34282 L
.10937 .34754 L
.1131 .35206 L
.11682 .35639 L
.12054 .36055 L
.12426 .36456 L
.12798 .36842 L
.1317 .37214 L
.13542 .37574 L
.13914 .37922 L
.14286 .38259 L
.14658 .38586 L
.1503 .38903 L
.15402 .3921 L
.15774 .39509 L
.16146 .398 L
.16518 .40083 L
.1689 .40359 L
.17262 .40628 L
.17634 .4089 L
.18006 .41146 L
.18378 .41396 L
.1875 .4164 L
.19122 .41878 L
.19494 .42111 L
.19866 .4234 L
.20238 .42563 L
.2061 .42782 L
.20982 .42996 L
Mistroke
.21354 .43207 L
.21726 .43413 L
.22098 .43615 L
.2247 .43813 L
.22842 .44008 L
.23214 .44199 L
.23586 .44387 L
.23958 .44572 L
.2433 .44753 L
.24702 .44932 L
.25074 .45107 L
.25446 .4528 L
.25818 .4545 L
.2619 .45617 L
.26563 .45781 L
.26935 .45943 L
.27307 .46103 L
.27679 .4626 L
.28051 .46415 L
.28423 .46568 L
.28795 .46719 L
.29167 .46867 L
.29539 .47013 L
.29911 .47158 L
.30283 .473 L
.30655 .47441 L
.31027 .4758 L
.31399 .47717 L
.31771 .47852 L
.32143 .47985 L
.32515 .48117 L
.32887 .48248 L
.33259 .48376 L
.33631 .48503 L
.34003 .48629 L
.34375 .48753 L
.34747 .48876 L
.35119 .48997 L
.35491 .49117 L
.35863 .49236 L
.36235 .49353 L
.36607 .49469 L
.36979 .49584 L
.37351 .49697 L
.37723 .4981 L
.38095 .49921 L
.38467 .50031 L
.38839 .5014 L
.39211 .50247 L
.39583 .50354 L
Mistroke
.39955 .5046 L
.40327 .50564 L
.40699 .50668 L
.41071 .5077 L
.41443 .50872 L
.41815 .50973 L
.42188 .51072 L
.4256 .51171 L
.42932 .51269 L
.43304 .51366 L
.43676 .51462 L
.44048 .51557 L
.4442 .51651 L
.44792 .51745 L
.45164 .51838 L
.45536 .51929 L
.45908 .52021 L
.4628 .52111 L
.46652 .522 L
.47024 .52289 L
.47396 .52377 L
.47768 .52465 L
.4814 .52551 L
.48512 .52637 L
.48884 .52723 L
.49256 .52807 L
.49628 .52891 L
.5 .52974 L
.50372 .53057 L
.50744 .53139 L
.51116 .5322 L
.51488 .53301 L
.5186 .53381 L
.52232 .53461 L
.52604 .5354 L
.52976 .53618 L
.53348 .53696 L
.5372 .53773 L
.54092 .53849 L
.54464 .53926 L
.54836 .54001 L
.55208 .54076 L
.5558 .54151 L
.55952 .54225 L
.56324 .54298 L
.56696 .54371 L
.57068 .54443 L
.5744 .54515 L
.57813 .54587 L
.58185 .54658 L
Mistroke
.58557 .54728 L
.58929 .54798 L
.59301 .54868 L
.59673 .54937 L
.60045 .55006 L
.60417 .55074 L
.60789 .55142 L
.61161 .55209 L
.61533 .55276 L
.61905 .55343 L
.62277 .55409 L
.62649 .55475 L
.63021 .5554 L
.63393 .55605 L
.63765 .5567 L
.64137 .55734 L
.64509 .55797 L
.64881 .55861 L
.65253 .55924 L
.65625 .55986 L
.65997 .56049 L
.66369 .56111 L
.66741 .56172 L
.67113 .56233 L
.67485 .56294 L
.67857 .56355 L
.68229 .56415 L
.68601 .56475 L
.68973 .56534 L
.69345 .56593 L
.69717 .56652 L
.70089 .5671 L
.70461 .56769 L
.70833 .56826 L
.71205 .56884 L
.71577 .56941 L
.71949 .56998 L
.72321 .57055 L
.72693 .57111 L
.73065 .57167 L
.73438 .57223 L
.7381 .57278 L
.74182 .57333 L
.74554 .57388 L
.74926 .57443 L
.75298 .57497 L
.7567 .57551 L
.76042 .57605 L
.76414 .57658 L
.76786 .57712 L
Mistroke
.77158 .57764 L
.7753 .57817 L
.77902 .5787 L
.78274 .57922 L
.78646 .57974 L
.79018 .58025 L
.7939 .58077 L
.79762 .58128 L
.80134 .58179 L
.80506 .58229 L
.80878 .5828 L
.8125 .5833 L
.81622 .5838 L
.81994 .5843 L
.82366 .58479 L
.82738 .58528 L
.8311 .58577 L
.83482 .58626 L
.83854 .58675 L
.84226 .58723 L
.84598 .58771 L
.8497 .58819 L
.85342 .58867 L
.85714 .58914 L
.86086 .58962 L
.86458 .59009 L
.8683 .59056 L
.87202 .59102 L
.87574 .59149 L
.87946 .59195 L
.88318 .59241 L
.8869 .59287 L
.89063 .59333 L
.89435 .59378 L
.89807 .59423 L
.90179 .59468 L
.90551 .59513 L
.90923 .59558 L
.91295 .59603 L
.91667 .59647 L
.92039 .59691 L
.92411 .59735 L
.92783 .59779 L
.93155 .59822 L
.93527 .59866 L
.93899 .59909 L
.94271 .59952 L
.94643 .59995 L
.95015 .60038 L
.95387 .6008 L
Mistroke
.95759 .60123 L
.96131 .60165 L
.96503 .60207 L
.96875 .60249 L
.97247 .6029 L
.97619 .60332 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{216, 133.438},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003H0000QA000`40O003h00Of7oo000`Ool00`00
Oomoo`02Ool00`00Oomoo`0HOol50002Ool00`00Oomoo`02Ool00`00Oomoo`0GOol50002Ool00`00
Oomoo`02Ool00`00Oomoo`0GOol30003Ool00`00Oomoo`02Ool00`00Oomoo`0GOol30003Ool00`00
Oomoo`02Ool00`00Oomoo`09Ool002moo`03001oo`00009oo`03001oo`0001]oo`07001oogooOol0
07oo00000Woo00<007oo00006Woo00L007ooOomoo`00Ool00002Ool00`00Ool0000HOol00`00Oomo
o`02Ool00`00Ool00002Ool00`00Ool0000HOol00`00Oomoo`02Ool00`00Ool00002Ool00`00Ool0
000:Ool0035oo`06001oogoo001oo`006goo00L007ooOomoo`00Ool00002Ool00`00Ool0000JOol0
0`00Oomoo`03Ool01P00Oomoo`00Ool001Uoo`07001oogooOol007oo00000Woo00<007oo00006Goo
00<007ooOol00goo00H007ooOol007oo000:Ool002moo`8000=oo`03001oo`0001]oo`07001oogoo
Ool007oo00000Woo00<007oo00006Woo00@007ooOomoo`8000=oo`03001oo`0001Uoo`07001oogoo
Ool007oo00000Woo00<007oo00006Goo00@007ooOomoo`8000=oo`03001oo`0000Yoo`00;goo00<0
07ooOol00Woo00<007oo00006goo00L007ooOomoo`00Ool00002Ool00`00Ool0000JOol01@00Oomo
ogoo000017oo00<007oo000067oo00<007oo00000Woo00<007oo00000Woo00<007oo000067oo00<0
07oo00000Woo00<007ooOol00Woo00<007oo00002Woo000_Ool30003Ool00`00Oomoo`0IOol20004
Ool00`00Oomoo`02Ool00`00Oomoo`0HOol20003Ool30003Ool00`00Oomoo`0HOol00`00Oomoo`02
Ool00`00Oomoo`02Ool00`00Oomoo`0HOol01000Oomoogoo0`000goo00<007ooOol02Goo003HOol0
0=Qoo`003Goo00<007ooOol0b7oo000=Ool00`00Oomoo`38Ool000eoo`03001oogoo0<Qoo`002Goo
b@001Woo000=Ool2000TOol00`00Oomoo`0ROol00`00Oomoo`0ROol00`00Oomoo`0SOol00`00Oomo
o`0ROol00`00Oomoo`0=Ool000eoo`800<Uoo`003Goo0P00bGoo000=Ool20039Ool000eoo`800<Uo
o`003Goo0P00bGoo000=Ool20039Ool000eoo`<00<Qoo`003Goo00<007oo0000b7oo000=Ool00`00
Ool00038Ool000eoo`03001oo`000<Qoo`003Goo0`00b7oo000=Ool00`00Ool00038Ool000eoo`03
001oo`000<Qoo`003Goo00<007oo0000b7oo000=Ool00`00Ool00038Ool000eoo`<00<Qoo`003Goo
00<007oo0000b7oo0006Ool50002Ool01000Oomoo`00agoo0008Ool00`00Oomoo`02Ool01000Oomo
o`00agoo0008Ool00`00Oomoo`02Ool40037Ool000Qoo`03001oogoo009oo`04001oogoo0037Ool0
00Qoo`03001oogoo009oo`04001oogoo0037Ool000Moo`8000Aoo`04001oogoo0037Ool000eoo`80
0003Ool007oo0<Ioo`003Goo00@007ooOol00<Moo`003Goo00@007ooOol00<Moo`003Goo00@007oo
Ool00<Moo`003Goo0P0000=oo`00Ool0aWoo000=Ool01000Oomoo`00agoo000=Ool01000Oomoo`00
agoo000=Ool01@00Oomoogoo0000aWoo000=Ool01@00Oomoogoo0000aWoo000=Ool20002Ool00`00
Oomoo`34Ool000eoo`05001oogooOol00036Ool000eoo`05001oogooOol00036Ool000eoo`03001o
ogoo009oo`03001oogoo0<=oo`003Goo0P000goo00<007ooOol0`goo000=Ool00`00Oomoo`02Ool0
0`00Oomoo`33Ool000Moo`<000=oo`03001oogoo00=oo`03001oogoo0<9oo`001goo00<007ooOol0
0goo00<007ooOol00goo00<007ooOol0`Woo0008Ool00`00Oomoo`02Ool30003Ool00`00Oomoo`32
Ool000Qoo`03001oogoo009oo`03001oogoo00=oo`03001oogoo0<9oo`001goo00<007oo00000goo
00<007ooOol00goo00<007ooOol0`Woo0008Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomo
o`32Ool000eoo`8000Eoo`03001oogoo0<5oo`003Goo00<007ooOol017oo00<007ooOol0`Goo000=
Ool00`00Oomoo`05Ool00`00Oomoo`30Ool000eoo`03001oogoo00Eoo`03001oogoo0<1oo`003Goo
00<007ooOol01Goo00<007ooOol0`7oo000=Ool20007Ool00`00Oomoo`2oOol000eoo`03001oogoo
00Ioo`03001oogoo0;moo`003Goo00<007ooOol01Woo00<007ooOol0_goo000=Ool00`00Oomoo`07
Ool00`00Oomoo`2nOol000eoo`8000Qoo`03001oogoo0;ioo`003Goo00<007ooOol027oo00<007oo
Ool0_Goo000=Ool00`00Oomoo`09Ool00`00Oomoo`2lOol000eoo`03001oogoo00Uoo`03001oogoo
0;aoo`003Goo0P002Woo00<007ooOol0_7oo000=Ool00`00Oomoo`0:Ool00`00Oomoo`2kOol000Mo
o`8000Aoo`03001oogoo00]oo`03001oogoo0;Yoo`002Goo00D007ooOomoo`0000ioo`03001oogoo
0;Uoo`0027oo00<007ooOol00Woo0`0037oo00<007ooOol0^Goo0009Ool01@00Oomoogoo00003goo
00<007ooOol0^7oo0007Ool00`00Ool00003Ool00`00Oomoo`0>Ool00`00Oomoo`2gOol000Qoo`03
001oogoo009oo`03001oogoo00moo`03001oogoo0;Ioo`003Goo00<007ooOol03goo00<007ooOol0
]Woo000=Ool2000AOol00`00Oomoo`2eOol000eoo`03001oogoo015oo`03001oogoo0;Aoo`003Goo
00<007ooOol04Woo00<007ooOol0/goo000=Ool00`00Oomoo`0COol00`00Oomoo`2bOol000eoo`80
01Eoo`03001oogoo0;5oo`003Goo00<007ooOol05Goo00<007ooOol0/7oo000=Ool00`00Oomoo`0F
Ool00`00Oomoo`2_Ool000eoo`03001oogoo01Moo`800:moo`003Goo0P006Goo0P00[Woo000=Ool0
0`00Oomoo`0JOol00`00Oomoo`2[Ool000eoo`03001oogoo01]oo`03001oogoo0:Yoo`003Goo00<0
07ooOol077oo0P00ZWoo000=Ool2000NOol2002YOol000eoo`03001oogoo01moo`800:Moo`003Goo
00<007ooOol08Goo0P00YGoo0008Ool30002Ool00`00Oomoo`0SOol00`00Oomoo`2ROol000Uoo`05
001oogooOol0000VOol3002QOol000Moo`@0009oo`<002Ioo`800:1oo`001goo00<007oo00000goo
00<007ooOol0:7oo0P00WWoo0008Ool20003Ool00`00Oomoo`0ZOol3002KOol000Uoo`05001oogoo
Ool0000^Ool3002IOol000eoo`80031oo`8009Moo`003Goo00<007ooOol0<Goo0P00UGoo000=Ool0
0`00Oomoo`0cOol3002BOol000eoo`03001oogoo03Ioo`<008moo`003Goo0P00>Goo1000S7oo000=
Ool00`00Oomoo`0kOol40029Ool000eoo`03001oogoo03ioo`@008Ioo`003Goo00<007ooOol0@Goo
1000Pgoo000=Ool20016Ool30020Ool000eoo`03001oogoo04Qoo`@007aoo`003Goo00<007ooOol0
C7oo1000N7oo000=Ool00`00Oomoo`1?Ool4001eOol000eoo`03001oogoo05=oo`D0071oo`003Goo
0P00FGoo1000K7oo000=Ool00`00Oomoo`1LOol5001WOol000Qoo`03001oogoo009oo`03001oogoo
065oo`@006=oo`001goo00<007oo00000goo00<007ooOol0IGoo1P00GGoo0009Ool01000Oomoogoo
0`00JWoo1P00F7oo0007Ool20004Ool00`00Oomoo`1`Ool5001COol000Moo`03001oogoo00=oo`03
001oogoo07Eoo`H004eoo`001goo0`000goo00<007ooOol0Ngoo1P00Agoo000=Ool20022Ool60011
Ool000eoo`03001oogoo08Moo`L003Yoo`003Goo00<007ooOol0SGoo1`00=7oo000=Ool00`00Oomo
o`2DOol8000/Ool000eoo`8009eoo`L002Eoo`003Goo00<007ooOol0Xgoo20007Goo000=Ool00`00
Oomoo`2[Ool9000DOol000eoo`03001oogoo0;=oo`X000]oo`003Goo00<007ooOol0_7oo00<007oo
Ool02Goo000=Ool20039Ool000eoo`03001oogoo0<Qoo`00\
\>"],
  ImageRangeCache->{{{0, 215}, {132.438, 0}} -> {-18.6619, -0.540743, 
  1.34101, 0.0469998}}]
}, Open  ]],

Cell[TextData[{
  "Consider the display of the Fourier coefficients of the small cell image \
directly and transformed using ",
  StyleBox["ContrastModifyLog", "Program"],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[ScriptCapitalB] = DFT[B]\ *\ 64; \n
    SignalRange[Abs[\[ScriptCapitalB]]]\)], "Input"],

Cell[BoxData[
    \({0.`, 4589.68750000000014`}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[
      GraphicsArray[
        \(ListDensityPlot[#1, PlotRange \[Rule] All, 
              DisplayFunction \[Rule] Identity]\ &\)\ /@{
            Abs[\[ScriptCapitalB]], 
            ContrastModifyLog[Abs[\[ScriptCapitalB]]]}]]; \)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .47619 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0113379 0.47619 [
[ 0 0 0 0 ]
[ 1 .47619 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .47619 L
0 .47619 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0113379 0.477324 0.464853 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.015024 0.0192308 0.015024 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
64 string
64 64 8 [64 0 0 64 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF16150E0302030101010100000000000101000000000000
000000000000000000000000000000000000000000000001
010000000000010101010302030E1516
2A1A0C0F0400010000010100000000000000000000000000
000000000000000000000000000000000000000000000000
00000000000000010001030305071208
0E1107080601000000010000000000000000000000000000
000000000000000000000000000000000000000000000000
00000000000000000000020305030802
020506030402000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
00000000000000000000000204030202
020003010100000100000000000000000000000000000000
000000000000000000000000000000000000000000000000
00000000000000000000000103020302
010101010000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
00000000000000000000000001010202
010000010000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
00000000000000000000010000000001
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
00000000000000000000000000000000
010100000000010000000000000000000000000000000000
000000000000000000000000000000000000000000000000
00000000000000000000000000010000
010202010100000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
00000000000000000000000000010101
020203020301000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
00000000000000000001000001010300
020202030402000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
00000000000000000000000204030605
0E0208030503020000000000000000000000000000000000
000000000000000000000000000000000000000000000000
00000000000000010000000106080711
2A0812070503030100010000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000010100000100040F0C1A
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0113379 0.97619 0.464853 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.015024 0.0192308 0.015024 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
64 string
64 64 8 [64 0 0 64 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFB5B5A97E71816C5E6D653C485455535A5B525256524F51
504E4E52504D504E4C4E504D50524E4E50514F525652525B
5A535554483C656D5E6C81717EA9B5B5
C9BBA4AA873F62575765603825424C454A5447424E4B4348
4645464A48494A474747484A484A4A4A474A43434647434E
5350474E4722585E4262807A8D94B097
A9AE94998F6B331A4B5D5436302B3B3037453F3A41443B3C
3D36313D3A343B3E333535373A32393A383B3A2C2E312931
43412C3542272751453E727F897A9978
6F8B8F7B826D304A413D311A3320291E281D221612331E16
1D1B071A1A191C291E251C281B1429252920273229211C20
0A2F36322938444654442B78827F7277
724F7B6B6B54455B51411E312924342C2E15111A1D172619
2125211E22161B210D23231E20202426191A2729351F1425
113424301B1B4743554221657A727E76
635F6162504D49574E47321F393634110D1E061F1B09150F
1C12151C0C0E05201D131C1B0E140F1A2112172024241C24
281E1F2C352E32534D544E4E625F6F76
5F55586455464D4D48493E3B3D2722241C111F2A18181917
0D0C261214192019181E1A131B14131C1A1D1F1712141518
271E1D2427333B4F50415D56584F505E
26483B514A1C4C50383735332F18272E0D211A11171F0921
161628211B0D180817272620161C1F1B10161E1525151A1A
180F283E42343E3D4C384D5447583E37
12353E3D1E1839432133222C1C292C2F1F1E1108181D1A13
1904110C0C17140F121419130D10100A0F0F222623201510
03242A363D1C313E363B37323845493E
51453B442C2B133D3C352D34362C2D302F23120F1107060B
130D0F0412081708111B1C0E05181810160C201F1A211F1C
271324183D303A412417403D40313C41
342B334437191A33382C2E3A2F1C2729271D19051602151C
0C1410131614161109170E0F0D150E12070C130616051C1D
121525292D322A342A1E38412E342422
43353A281610161A22210E2D252419241C1F19181C111413
0C0818111C1C140C090B0D0D19061D1F1106241611172224
161B1717282334373830271E1F24243E
3E2F2C2B2411231D26201D2414180B111B1A0112201A1C09
160E0B1B140312160E15080A060E1B0A191A18180817272B
211E1921302C2F3031272724222C1C32
192F260D251A302B37221723221F1516151B0E0D14241C12
0A04100D17131D151E1B0A03120D1214130A0D0B111B1D1E
0B1C261D1819110F232631262205271A
2E311A1A1524211B1A0A191E2A1A221508110B161E1B140D
1217120F141918181E19150C151E0F150B1C1F2317140B12
10211E131D0F08151011090422120725
332C1B0C1D2717260A09170F211C23150C1510110B141E0F
090E1A16091A130D151609081422150705141C241C19190C
080621181A181C1F2F1814121D182022
381820221F231319101D180B1A171D15150D19170D050B10
211E131B1708110D101406051818190313151F1E180E1513
1417021D20191507131618231622221A
3424172313061A24191B221B0A0F100D14071F0E11160C1F
0F1B1D0111140D14110B18170C05130D111716140D130D1D
11121912170F130E16121E26191D222D
2712110A1B1E181E17121E12121812161618070D09100A0F
03150C12121A11151A190C1119141F1619120B0B13161D07
22111A121C1E081210150D1C191B1919
311516271812170B0B1C1411151E22270F1309070D180F20
0608160E07100B0B251B170F070F0E0A0F0E05111006220C
0E0F0B181414100C1D152222141D090B
30080F1C171D16141219191E1A0D181912120B0D0B170C0A
100E0B04150D17120C150F0919061611021B0E1612171415
151009120910040315072112110B151E
2B1C0615161D221D031112050E0D18110F08100C0F061107
1E0A051708100E170A0911070A031C12120D18191B171208
07170F0B0B12061A1D05131517180205
2C1D0520220F191806061A050A1510160C19101B180E1119
0A0E050F10140F0F0C09121111040F0B1619170E04141216
140F051515030D1C1C110D0B170D0A25
2712161819140A0D07120C041F0E0107150D08060B090620
05120F1E0E0B0E030D0D140E09110E131617090F1113150D
0D1A160D140D1D1A15101807080D0512
21120B1317130F18171A15071111170B170E0C08180D1313
0C10070B08141215180919100F1E160F0D0B040F1B200F18
1517160B1F17191C05170D1C09031416
2F1E131D1C161416131A0F0616111208121209160F0D160F
0F11040804161B150A0D11100F0E0D070E17160615141D1E
0A0D16141111051113111A150A071422
2C190508160D0E0714131E13191A160C0B0E16170C0E1212
030A0C060A180F090A081709051311140D0A14101711140A
04120D0A0C0A15111218141117192221
2206100B171009130F24140E0F160D1A12100E0E070D060E
0C13150E05080C0D07170F12160411130D13160C0C0A1A1A
110E150D0910190B0D180B06161C0D1A
2D1F0C151B1016090E1116120E0C072313121410090E0F0E
170E17140A100C0E1816140418090F0E0D0D100F120B0D0C
04090D0F15160D1008190D0F0C1C1819
1F1415081413110F07101E1B1E121B060E1416170F160B15
0C0E0511060715111E0C03070F030F14130A0D1B1111100C
0B0C051517060507171F1D13050C1E20
201217100B0C120316121410151819060407121A19110B16
2012111B0F08100F09070D0E0B040810140A0F150A120614
16170A071604121013151107090B0F1E
221C121612120E120E1516151E0F15151D0A0A0C0A0B0A13
0E0A110D081311111A0512030109160C04120E0B0B0D1B16
0B0E0F0D150C1011170A0C130D101A1E
410C0E09070B0607100E030B170C07151D1A131304151105
0E101413120F15060006150F121314100E0511150413131A
1D15070C170B030E1007060B07090E0C
221E1A100D130C0A1711100C150D0F0E0B161B0D0B0B0E12
040C1609010312051A111113080D110A0E130A0B0A0C0A0A
1D15150F1E1516150E120E121216121C
201E0F0B090711151310120416070A17161406120A150F0A
141008040B0E0D07090F10080F1B111220160B11191A1207
04061918151014121603120C0B101712
1F201E0C05131D1F170705061715050C0B0C1011111B0D0A
13140F030F07030C1E1115070611050E0C150B160F171614
0E061B121E1B1E10070F111314081514
2D19181C0C0F0D1908100D16150F0D09040C0D0B120F100D
0D0E0F0918041416180E0C100A14170E170E0F0E09101412
1323070C0E1216110E0916101B150C1F
221A0D1C16060B180D0B1910090D150E111A1A0A0C0C1613
0D13110416120F17070D0C08050E15130C0E060D070E0E10
121A0D160F0E14240F130910170B1006
2C212219171114181211150A0C0A0D12040A14111710140A
0D141113050917080A090F180A060C0A0312120E0C17160E
0B0C161A19131E1314070E0D16080519
2F2214070A151A11131105111114160D0A1E1D1415061617
0E070D0E0F10110D0A151B16040804110F0F160D0F160912
1208121116060F1A131614161C1D131E
21161403091C0D17051C19171F0B161715180F201B0F040B
0D0F161E0F10190918151214080B07100C13130D18080C0E
170B17111107151A17180F1317130B12
2712050D08071810151A1D0D140D161A0D0D1513110F0917
16130E11090E140D0D030E0B0E1E0F12052006090B06080D
1507010E1F040C12070D0A1419181612
2C250A0D170B0D111C1C0D031515050F14161214040E1719
160B0F04111112090C0F0F14100F050E0A19110E181B1019
0C1610150A051A060618190F2220051D
2B050218171513051D1A06120B0B0F17070812171B19180D
12121C030A0711090A170E100817050A1E0711060F0C1008
0F11180D0E051211031D221D1615061C
301E150B1112210715030410091209101515141712160E1B
0211160619090F150C12170D15040B0E100A0C170B0D0B12
1219180D1A1E19191214161D171C0F08
310B091D142222151D0C101414180B0F0E0C22061011050E
0F0A0E0F070F171B250B0B10070E160806200F180D070913
0F27221E1511141C0B0B171218271615
2719191B191C0D151012081E1C121A1122071D16130B0B12
19161F1419110C191A15111A12120C15030F0A10090D0718
1616121812121E12171E181E1B0A1112
342D221D19261E12160E130F17121912111D0D130D141617
110D13050C17180B11140D1411011D1B0F1F0C16110E1F07
140D100F0A1B221B19241A0613231724
381A22221623181613071519201D02171413150E181E1F15
1303191818050614100D1108171B131E21100B050D17190D
15151D171A0B181D101913231F222018
332220181D1214182F1F1C181A182106080C19191C241C14
0507152214080916150D131A09161A0E090F1E140B111015
0C15231C210F17090A2617271D0C1B2C
2E250712220409111015080F1D131E2110120B1417231F1C
0B150F1E150C15191E181819140F1217120D141B1E160B11
0815221A2A1E190A1A1B2124151A1A31
191A270522263126230F1119181D261C0B1E1D1B110B0D0A
1314120D12030A1B1E151D13170D10040A121C24140D0E1B
1516151F22231722372B301A250D262F
3E321C2C2224272731302F2C3021191E212B27170818181A
190A1B0E060A08150E161203141B0B0E16091C1A2012011A
1B110B1814241D20261D2311242B2C2F
433E24241F1E2730383734232817171B1624221711162406
111F1D06190D0D0B090C141C1C1118080C1314111C18191F
1C241924252D0E21221A161016283A35
342224342E41381E2A342A322D292515121D1C051606130C
07120E150D0F0E1709111614161310140C1C15021605191D
2729271C2F3A2E2C38331A193744332B
51413C31403D401724413A303D182413271C1F211A1F200C
16101818050E1C1B1108170812040F0D130B0607110F1223
2F302D2C36342D353C3D132B2C443B45
123E49453832373B363E311C3D362A24031015202326220F
0F0A10100D131914120F14170C0C110419131A1D1808111E
1F2F2C291C2C2233214339181E3D3E35
26373E5847544D384C3D3E34423E280F181A1A1525151E16
101B1F1C162026271708180D1B2128161621091F17111A21
0D2E27182F33353738504C1C4A513B48
5F5E504F58565D41504F3B3327241D1E2718151412171F1D
1A1C13141B131A1E181920191412260C0D171918182A1F11
1C2422273D3B3E49484D4D4655645855
63766F5F624E4E544D53322E352C1F1E28241C2424201712
211A0F140E1B1C131D20050E0C1C15121C0F15091B1F061E
0D113436391F32474E57494D5062615F
72767E727A6521425543471B1B3024341125141F3529271A
19262420201E23230D211B16221E2125211926171D1A1115
2E2C342429311E41515B45546B6B7B4F
6F77727F82782B44544644382932362F0A201C2129322720
292529141B281C251E291C191A1A071B1D161E331216221D
281E2920331A313D414A306D827B8F8B
A978997A897F723E4551272742352C41433129312E2C3A3B
383A39323A373535333E3B343A3D31363D3C3B44413A3F45
37303B2B3036545D4B1A336B8F9994AE
C997B0948D7A8062425E5822474E4750534E43474643434A
474A4A4A484A484747474A49484A46454648434B4E424754
4A454C42253860655757623F87AAA4BB
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{216, 102.813},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003H0000IQ000`40O003h00Of7oo003HOol000Eo
of8000Uoof8000Ioo`001Goo00<007ooOol0GWoo00<007ooOol01goo00<007ooOol0GWoo00<007oo
Ool017oo0005Ool00`00Oomoo`1NOol00`00Oomoo`07Ool00`00Oomoo`1NOol00`00Oomoo`04Ool0
00Eoo`03001oogoo00<8@P848E<000041248@PQ22482Ool00`00Oomoo`07Ool00`00Oomoo`03F]H2
E[D013g_>LhicT8@0SF]00D]JcF]=JdaS1cW008U:@@YBP<]J`HYBP049BTYBRU::DX39BT3:DX29BT0
0bU:9BTU:@029BT2:DX012DY:DXYBRU:0bDY0bU:00<U:BU::DX012U:0be[1BU:00DU:AcW<H`aS3F]
008]J`04=Je2448@>Lh2?Nl015JeF]IJeU[F0Woo00<007ooOol017oo0005Ool00`00OolDY@0236<3
125D0002248010@QOomoo`002Goo00<007ooIcT00Ukg00ABU5JeE[E2408Li`04<H`YBRU::DX3<H`0
11cW48@@Q2480RDY00@Q22DY9BTYBP<Q20<U:@038@PU:BDY00@Q20HU:@@Q20TU:@8Q20039BTQ2248
00DQ208U:@<YBP058@PU:BDY8@P@Q003;F/28@P0136<@Q1243g_0THa00A:DU[FF]I:DP9oo`03001o
ogoo00Aoo`001Goo00<007oo5:D00PaS0`@QE0000PQ200@48GooOol000Uoo`03001oofLi009Nm`04
DYAF]EJe@Q027>L0136<:DXYBRU:0c6<00@Lia2448@Q208U:@048@PU:BDY:DX38@P39BT00b489BTU
:@048@P69BT48@P99BT28@P00bDY8@PQ20058@P29BT3:DX01B489BTU:B4848@00be[0R4800@aS48@
@Q0mk`96<@04BU9JeU[FBU82Ool00`00Oomoo`04Ool000Eoo`03001oo`@Q0088@P0300048@@Q05@0
00848@04001oogoo0009Ool00`00OomF]@02E[D014YBCW=>LdHa0SF]00@HaPaS36<U:@8]J`05:DXH
aQS66<HDY@027>L36<H012487>LLiacW0b4811cW0aS60acW0QS60QcW1QS60QcW00<HaQcW7>L01AcW
0aBU0QS600<DYAS66<H00b4800@DYAS66<HQ20<@Q004:DXQ22487>L2>Lh013g_AS56<Cg_0Tic00@m
kgooOol000Ioo`001Goo00<007oo0000G0000Woo00<007ooOol01goo00<007oo=Jd00dHa0Sg_00A2
43F]=JdHaP8U:@058@PLiacW6<H<H`026<H011245:DDY@aS0QBU00<<Ha2448@00`Q200@HaPaS2488
@P<<H`03000<H`aS00@<H`045:D<H`aS48@236<011BU36<<H`Q20QBU00<@Q1BU5:D00Q240QS600@D
YA2448@<H`8@Q003124DYABU00<HaP035:DLib48008Q208YBP048@PDYABU?Nl2@Q0013g_>LhicSW>
0Woo00<007ooOol017oo0005Ool00`00Ool0001L0002Ool00`00Oomoo`07Ool00`00Oole[@03AS42
?Nl0148@=Jde[AS60RDY00DQ21cW7>LHaPaS008HaP0448@DYABU36<25:D00`aS48@@Q003248011S6
36<8@PQ20`aS00<000aS36<010aS00@DY@aS36<@Q08<H`045:D<H`aS24825:D00a245:DDY@0248@2
6<H011BU48@@Q0aS0Q2400<48ABU5:D00aS600<DYAcW8@P00R480RU:00@Q21BU5:Dmk`924004?Nli
cSW>>Lh2Ool00`00Oomoo`04Ool000Eoo`03001oo`0005`0009oo`03001oogoo00Moo`03001oocW>
008U:@04?Nle[CF]=Jd2:DX01248;F/]JbU:0R4800D<HaS65:DDYA24008HaP<DY@<8@P<<H`04248@
Q0aS36<448@236<01A242488@PaS48@00P@Q0a2400<<Ha2448@011240`aS00@@Q1BU5:DHaP8<H`04
248@Q12424826<H00a246<HHaP0236<38@P2:DX0124848@@Q36<0Sg_00@icSg_?NlicP9oo`03001o
ogoo00Aoo`001Goo00<007oo0000G0000Woo00<007ooOol01goo00<007oo<H`00Re[0c6<00@YBRDY
9BTU:@8YBP059BTQ22486<H<H`027>L36<H010Q212448@aS0P000`aS00D48@Q212448@aS00<8@P8<
H`<48@05000@Q0aS36<8@P0336<2124010Q212448@aS0Q240PQ21A2400@<Ha2448@DY@<<H`8DY@05
6<HDYAS66<HYBP029BT012U:9BTU:BDY0S6<00@]JcF]=JdicP9oo`03001oogoo00Aoo`001Goo00<0
07oo0000G0000Woo00<007ooOol01goo00<007oo<H`00Re[0c6<00@YBRDY9BTU:@8YBP059BTQ2248
6<H<H`027>L36<H010Q212448@aS0P000`aS00D48@Q212448@aS00<8@P8<H`<48@05000@Q0aS36<8
@P0336<2124010Q212448@aS0Q240PQ21A2400@<Ha2448@DY@<<H`8DY@056<HDYAS66<HYBP029BT0
12U:9BTU:BDY0S6<00@]JcF]=JdicP9oo`03001oogoo00Aoo`001Goo00<007oo0000G0000Woo00<0
07ooOol01goo00<007oo;F/00RU:00@]Jc6<<H`YBP8Q20HU:@@Li`@@Q08<H`04248<H`aS5:D436<2
2483124011242488@PQ20PaS00<@Q0aS36<010aS00<8@PaS36<00`Q21@aS1PQ20PaS00@@Q0aS36<<
H`<@Q0046<HLiacW9BT2:DX01248;F/]JbU:0Re[00@U:BU::DX]J`9oo`03001oogoo00Aoo`001Goo
00<007oo0000G0000Woo00<007ooOol01goo00<007oo48@00RDY00@LibU::DXU:@8<H`049BTYBRU:
7>L46<H25:D010aS48@@Q1BU0P@Q00<@Q0aS36<00`Q200@<H`@Q48@@Q0<8@P045:D@Q12436<21240
10aS1248@PQ211240PQ210aS0`Q200@<H`Q2248@Q088@P@<H`848@055:DLiacW8@PHaP037>L29BT0
11cW9BTU:BU:0R4800@]JacW7>LHaP9oo`03001oogoo00Aoo`001Goo00<007oo0000G0000Woo00<0
07ooOol01goo00<007oo48@00RDY00@LibU::DXU:@8<H`049BTYBRU:7>L46<H25:D010aS48@@Q1BU
0P@Q00<@Q0aS36<00`Q200@<H`@Q48@@Q0<8@P045:D@Q12436<2124010aS1248@PQ211240PQ210aS
0`Q200@<H`Q2248@Q088@P@<H`848@055:DLiacW8@PHaP037>L29BT011cW9BTU:BU:0R4800@]JacW
7>LHaP9oo`03001oogoo00Aoo`001Goo00<007oo0000G0000Woo00<007ooOol01goo00<007oo2480
0QS60acW0`aS00@Lib488@P@Q08HaP0448@DY@aS36<45:D336<224800`@Q36<<H`0236<2248010aS
000000Q20`@Q0`Q200@48@Q22488@P8<H`0324848@@Q00<8@P@48@H@Q0<8@P04000@Q1245:D26<H0
1AcW36<HaQS67>L00QS600@LiaS66<HHaP8Li`048@PU:BDY7>L2Ool00`00Oomoo`04Ool000Eoo`03
001oo`0005`0009oo`03001oogoo00Moo`03001oobU:008Q20037>LQ224800<DY@04248LiacW7>L2
6<H011BU6<HHaQS60aBU00@HaQBU5:D@Q088@P031248@PQ2008000848@0424848@@Q124200001@Q2
12448@Q212400PQ20`aS00<48@0000000`aS0`Q200<48A2436<00PaS0Q240`aS00@@Q0Q2248@Q08<
H`057>LHaQcW7>LQ200248@010Q28@PQ21cW0R4800@HaQcW7>LQ209oo`03001oogoo00Aoo`001Goo
00<007oo0000G0000Woo00<007ooOol01goo00<007oo:DX00R4800<Lib488@P00aBU00@8@QcW7>LL
i`8HaP045:DHaQS66<H35:D011S65:DDYA240PQ200<48@Q224800P000P@Q00@8@P@Q12448@800005
24848@@Q24848@02248336<00`@Q0000000336<324800`@Q48@<H`0236<248@336<011242488@Q24
0PaS00DLiaS67>LLib48008@Q004248Q22487>L28@P011S67>LLib480Woo00<007ooOol017oo0005
Ool00`00Ool0001L0002Ool00`00Oomoo`07Ool00`00OolHaP025:D011S68@PQ21S60`aS0QS600DL
iaBU5:DDYAcW008DY@0436<@Q1245:D248@336<01@002488@P0024800PaS00<48@Q2248020Q20P@Q
00<8@P@Q12400`@Q00@8@P@Q1248@P8000051248@P000008@P02000336<324801A245:DDYABU6<H0
0QBU00@HaQBU5:D<H`8Li`048@PDYABU6<H348@2Ool00`00Oomoo`04Ool000Eoo`03001oo`0005`0
009oo`03001oogoo00Moo`03001oob48008HaP037>LDYABU00@8@P8<H`<@Q003124DYA24008@Q08<
H`0348@<H`aS00H<H`@8@P<48@0336<8@PQ200<<H`0324848@@Q00D48@8<H`04000<H`aS36<22480
0`0048@8@P04248348@00`Q236<<H`0324800aBU48@HaP026<H27>L00aS648@@Q00336<348@011cW
Oomoo`001Woo0005Ool00`00Ool0001L0002Ool00`00Oomoo`07Ool00`00OolLi`055:D011242488
@Q240PaS0a2400D<Ha242488@PaS00848@04248<H`aS36<200000`Q248@@Q00236<2124010Q21244
8@@Q0PaS00<8@P0000000PQ20P@Q00@8@P@Q12448@800004124<H`aS124636<010@Q2488@Q240QBU
00@@Q0aS36<<H`8@Q0046<HDYABU5:D36<H648@011BU36<<HaS60Woo00<007ooOol017oo0005Ool0
0`00Ool0001L0002Ool00`00Oomoo`07Ool00`00OolLi`055:D011242488@Q240PaS0a2400D<Ha24
2488@PaS00848@04248<H`aS36<200000`Q248@@Q00236<2124010Q212448@@Q0PaS00<8@P000000
0PQ20P@Q00@8@P@Q12448@800004124<H`aS124636<010@Q2488@Q240QBU00@@Q0aS36<<H`8@Q004
6<HDYABU5:D36<H648@011BU36<<HaS60Woo00<007ooOol017oo0005Ool00`00Ool0001L0002Ool0
0`00Oomoo`07Ool00`00Ool<H`025:D0112412448A240PaS00@HaQBU5:DHaP8@Q005248@Q12448@<
H`05248010aS12448@@Q0PQ200D@Q0aS2488@P@Q0080000324848@@Q00<8@P0336<8@PaS008<H`84
8@040008@PQ21245248412400`Q236<<H`0336<010@Q36<<Ha2410aS0PQ200@48A2448@@Q08HaP<@
Q004000@Q12436<2Ool00`00Oomoo`04Ool000Eoo`03001oo`0005`0009oo`03001oogoo00Moo`03
001ooaBU008HaP<<H`04248@Q12448@336<2124236<25:D010aS48@@Q0Q20P@Q00@8@P@Q1248@P<<
H`0324848@@Q00@8@P848@03248<H`aS00D<H`88@P041248@PQ236<212400`Q212448@0236<248@3
248010@Q2488@PQ20Q2400@<H`Q2248<H`<48@@8@P848@04000@Q124248200001124Oomoo`001Woo
0005Ool00`00Ool0001L0002Ool00`00Oomoo`07Ool00`00OolDY@026<H336<010Q248@@Q1240`aS
0P@Q0PaS0QBU00@<Ha2448@8@P848@0424848@@Q248336<00`Q212448@04248212400`Q236<<H`05
36<2248010@Q2488@PaS0P@Q00<8@P@Q12400PaS0Q240`Q200@48@Q22488@P8@Q00436<8@PQ236<3
124424821240100048@@Q0Q20P0000@@Q7ooOol000Ioo`001Goo00<007oo0000G0000Woo00<007oo
Ool01goo00<007oo6<H00QBU00@<H`@Q124<H`8@Q003248@Q12400<48@0524848A2448@<H`0248@0
0`Q212448@04248212400`Q236<48@04124010aS2488@P@Q0PaS00<8@P@Q24800PQ20`@Q0PQ200<@
Q0Q224800`0000@8@PaS48@@Q0@<H`<48@80000348@<H`aS00D<H`8DY@0436<8@PQ2248336<348@2
Ool00`00Oomoo`04Ool000Eoo`03001oo`0005`0009oo`03001oogoo00Moo`03001ooacW008<H`<@
Q00436<@Q124248236<01@Q236<<H`aS12400PaS00<8@PaS36<00`Q200@48@aS36<8@P848@050004
8@Q2248@Q00236<010Q236<<H`Q20P@Q00<8@P@Q24800PQ20`001@aS00@000Q22488@P@<H`848@H8
@P05000<H`aS48@<H`02248010002488@PQ20PaS00<@Q0Q224800a2400@<HgooOol000Ioo`001Goo
00<007oo0000G0000Woo00<007ooOol01goo00<007oo7>L00PaS0a2400@<Ha2448@8@P8<H`05248<
H`aS36<48@0236<00`Q236<<H`03248010@Q36<<H`Q20P@Q00D000@Q2488@Q24008<H`04248<H`aS
248212400`Q21248@P022483000536<010002488@PQ210aS0P@Q1PQ200D000aS36<@Q0aS0088@P04
0008@PQ2248236<00a242488@P0348@010aSOomoo`001Woo0005Ool00`00Ool0001L0002Ool00`00
Oomoo`07Ool00`00OolHaP0248@010Q248@@Q0Q20P0000<<Ha2448@00`aS00<@Q0aS12400P@Q0PQ2
00@48@Q22480008<H`051248@PQ224848@0236<010@Q36<<H`aS0P000`Q200D48@Q22488@P@Q008<
H`0424848@@Q000224800`@Q2488@P04248010@Q2488@P@Q0PaS0`Q200D<H`Q22488@P@Q0088@P04
1248@PQ2248236<0112436<<H`aS0Q2400@DYGooOol000Ioo`001Goo00<007oo0000G0000Woo00<0
07ooOol01goo00<007oo48@00`Q20P@Q1PaS0`Q200D<H`Q22488@PaS00D8@P0336<0000000<48@05
24848@@Q12400002248010@Q2488@PQ20PaS0PQ20`aS0P@Q00@8@PaS36<8@P8<H`04248<H`aS2483
1243248010aS000001240PQ200<<H`Q224800PaS0P@Q10Q20P@Q1`aS0Woo00<007ooOol017oo0005
Ool00`00Ool0001L0002Ool00`00Oomoo`07Ool00`00Ool@Q0032482124636<324801@aS2488@PQ2
36<01@Q200<<H`0000000`@Q00D8@P@Q12448@000088@P041248@PQ2248236<2248336<2124010Q2
36<<H`Q20PaS00@8@PaS36<8@P<48@<8@P0436<0000048@224800`aS2488@P0236<2124424821247
36<2Ool00`00Oomoo`04Ool000Eoo`03001oo`0005`0009oo`03001oogoo00Moo`03001ooaS600<8
@P8@Q00436<8@PQ22483124236<4248010aS48@@Q1240P@Q00@8@P@Q124000848@0536<48A2448@0
0002124010Q212448@000PQ20P@Q0Q2400@<H`Q224848@8000L48@040008@PQ2248200000a241244
8@04124236<4248010@Q36<<H`Q20a240PQ200@<H`@Q12448@9oo`03001oogoo00Aoo`001Goo00<0
07oo0000G0000Woo00<007ooOol01goo00<007oo6<H00`@Q0PaS00<8@PaS36<010Q21PaS00@48@aS
36<<H`<8@PD48@0524848@@Q1248@P03124200000`Q212448@022482124010Q212448@@Q0PaS00@0
00Q22488@P80000336<48@Q200X8@P051248@PQ21248@P03000224800`0048@@Q003248010@Q2488
@PaS0Woo00<007ooOol017oo0005Ool00`00Ool0001L0002Ool00`00Oomoo`07Ool00`00OolHaP03
124236<00`Q236<<H`04248636<010@Q36<<H`aS0`Q21@@Q00D8@P@Q12448@Q200<48@8000032484
8@@Q0088@P848@0424848@@Q124236<010002488@PQ20P0000<<H`@Q24802PQ200D48@Q224848@Q2
00<00088@P03000@Q12400<8@P041248@PQ236<2Ool00`00Oomoo`04Ool000Eoo`03001oo`0005`0
009oo`03001oogoo00Moo`03001ooaBU008<H`040008@PQ2248236<0112436<<H`000`Q200@000@Q
12448@8<H`0424848@@Q1242248312401@002480000036<00P@Q00@000Q224848@88@P031248@P@Q
00848@88@P0400048@@Q000236<324800`@Q36<<H`0236<3248212400`002488@P0412400`Q20000
000336<00`002488@P03248010aS000000000Woo00<007ooOol017oo0005Ool00`00Ool0001L0002
Ool00`00Oomoo`07Ool00`00OolDY@0236<0100048@@Q1240P@Q0`aS0`0000@<H`0012448@@8@P84
8@0336<8@PQ200<<H`041248@PaS36<312400`0012448@03248512452480100012448@@Q0PQ200D<
H`Q212448@0000H8@P848@050008@PQ224800002124336<010Q212448@@Q0PQ20`@Q00@@Q7ooOol0
00Ioo`001Goo00<007oo0000G0000Woo00<007ooOol01goo00<007oo48@00`Q20`aS0PQ20`@Q00D0
00Q224848@00008<H`04124000000002248312401@0012448@@Q00000Q2400@000Q224848@8<H`@4
8@0400048@@Q1242248312400`Q212448@04248312442483124236<01@Q212448@Q212400`aS0`Q2
0PaS00@000@Q12448@800004249oogoo0006Ool000Eoo`03001oo`0005`0009oo`03001oogoo00Mo
o`03001ooa2400<8@P<<H`88@P<48@050008@PQ21240000236<010@Q000000000PQ20`@Q00D000@Q
12448@00008@Q0040008@PQ2124236<41240100012448@@Q0PQ20`@Q00<8@P@Q124010Q20`@Q10Q2
0`@Q0PaS00D8@P@Q1248@P@Q00<<H`<8@P8<H`0400048@@Q1242000010Q2Oomoo`001Woo0005Ool0
0`00Ool0001L0002Ool00`00Oomoo`07Ool00`00Ool@Q00224800`@Q2488@P03248010@Q36<<H`Q2
0PaS00<8@P00248010Q200<48@Q2248010@Q0PaS00D48@Q22488@P@Q0088@P0400048@@Q12442482
36<010@Q36<<H`Q20P@Q00<<H`Q2248010@Q00@000@Q124<H`8@Q003124<H`aS00@8@P848@0336<8
@PaS008<H`80000424848@@Q36<2124010002488@PQ20Woo00<007ooOol017oo0005Ool00`00Ool0
001L0002Ool00`00Oomoo`07Ool00`00OolDY@0236<010Q236<<H`aS1PQ20PaS00<48@00248010Q2
00@48@Q22488@P848@0524848@@Q1248@P0312422480100012448@000PQ200<<H`Q212400P@Q0`Q2
1@@Q00<000@Q12400PQ20P000`Q20`aS0`@Q1@Q20P0010Q20PaS00@8@P@Q12400088@P0448Aoogoo
0006Ool000Eoo`03001oo`0005`0009oo`03001oogoo00Moo`03001ooaBU008<H`04248<H`aS36<6
248236<00`@Q0008@P04248010@Q2488@PQ20P@Q00D8@P@Q12448@Q200<48@88@P0400048@@Q0002
24800`aS24848@021243248512400`0012448@0224820003248336<3124524820004248236<010Q2
12448@000PQ200@@Q7ooOol000Ioo`001Goo00<007oo0000G0000Woo00<007ooOol01goo00<007oo
5:D00PaS00@000@Q1248@P<48@8000<8@P0336<8@PaS008<H`88@P@48@<8@P<48@<8@P0400048@@Q
124200000`@Q36<<H`05124224800`@Q0000000424831247248212400`002488@P05124524800`aS
2488@P03248010aS48@@Q1240Woo00<007ooOol017oo0005Ool00`00Ool0001L0002Ool00`00Oomo
o`07Ool00`00Ool@Q00200000`Q212448@03248010@Q2488@P@Q0Q2400D8@P@Q12448@Q200848@04
36<8@PQ22483124200000`@Q00048@021243248212400`0012448@02124200000`Q212448@032480
10002488@PQ20P@Q0PQ21@@Q0`aS00@8@P@Q1248@P<48@03248<H`aS00<48@0436<48@@Q00022480
10aS12448@aS0Woo00<007ooOol017oo0005Ool00`00Ool0001L0002Ool00`00Oomoo`07Ool00`00
Ool@Q00200000`Q212448@03248010@Q2488@P@Q0Q2400D8@P@Q12448@Q200848@0436<8@PQ22483
124200000`@Q00048@021243248212400`0012448@02124200000`Q212448@03248010002488@PQ2
0P@Q0PQ21@@Q0`aS00@8@P@Q1248@P<48@03248<H`aS00<48@0436<48@@Q0002248010aS12448@aS
0Woo00<007ooOol017oo0005Ool00`00Ool0001L0002Ool00`00Oomoo`07Ool00`00OolDY@0236<0
10@Q2488@PaS0`Q20`@Q10Q20`@Q0P0000<@Q0Q2248010Q21P@Q00<8@P@Q12400`Q200<48@Q22480
0P@Q0PaS0`Q200<000aS36<01`@Q00@8@P@Q1248@PD48@0300048@@Q00<48@88@P848@0424848@@Q
36<5124436<2Ool00`00Oomoo`04Ool000Eoo`03001oo`0005`0009oo`03001oogoo00Moo`03001o
o`aS00<8@P848@@8@P848@030008@PQ200@<H`04248<H`aS000212442482124010Q21248@PQ20`@Q
00<000Q224800`000PQ20PaS00@48@00000000848@0300048@@Q00<8@P848@8<H`@8@PD48@040008
@PQ224840002248336<010Q2000000@Q0PaS00@@Q7ooOol000Ioo`001Goo00<007oo0000G0000Woo
00<007ooOol01goo00<007oo36<00`Q20P@Q10Q20P@Q00<000Q2248010aS00@8@PaS36<000848@@8
@P848@0424848@Q2248312400`002488@P030002248236<010@Q000000000P@Q00<000@Q12400`Q2
0P@Q0PaS10Q21@@Q00@000Q22488@P@00088@P<<H`0424800000124236<01124Oomoo`001Woo0005
Ool00`00Ool0001L0002Ool00`00Oomoo`07Ool00`00Ool@Q005248312400`Q200000007248336<4
0002248336<01@Q21248@PQ248@00`Q20PaS0`@Q00D8@P@Q12448@0000D48@0300048@@Q00<8@P84
8@88@P041248@PQ2000524801@@Q000000Q2000020Q200<000@Q12400`@Q00@<HgooOol000Ioo`00
1Goo00<007oo0000G0000Woo00<007ooOol01goo00<007oo48@00PaS1PQ200@48@Q224848@@8@P8<
H`041248@PQ2248236<812422483124010Q212448@@Q10Q20PaS00<000Q224800`0000@48@Q22484
8@80000324848@@Q00@48@0336<8@PQ200H48@0324848@Q200@8@P<48@0424848@@Q248336<2Ool0
0`00Oomoo`04Ool000Eoo`03001oo`0005`0009oo`03001oogoo00Moo`03001ooa24008<H`H8@P04
1248@PQ21244248236<010@Q2488@PQ20PaS20@Q0PQ20`@Q00@8@P@Q12448@@8@P8<H`030008@PQ2
00<000041248@PQ2124200000`Q212448@0412400`aS2488@P0612400`Q21248@P042483124010Q2
12448@Q20`aS0Woo00<007ooOol017oo0005Ool00`00Ool0001L0002Ool00`00Oomoo`07Ool00`00
OolQ200512400`0012448@0300001@Q212448@0012400PQ200@48@000008@P<<H`<8@P800088@P80
00031248@PQ200@8@P848@032480000000800088@P031248@PQ200@8@P848@050008@PQ224800003
248336<224801@0012448@Q212400P0000<48@Q224800`0000<48@00000010@Q0Woo00<007ooOol0
17oo0005Ool00`00Ool0001L0002Ool00`00Oomoo`07Ool00`00Ool@Q00336<224800`@Q2488@P03
124424800`@Q2488@P0612400`Q236<<H`0512422480100012448@Q20P@Q0`0000@8@P0036<<H`@8
@P<48@88@P<48@0324848@@Q00L48@0436<8@PQ2248212400`aS2488@P02248212400`Q212448@06
248010aSOomoo`001Woo0005Ool00`00Ool0001L0002Ool00`00Oomoo`07Ool00`00Ool@Q00236<4
12420007248010002488@P000P@Q10Q20P0000@8@P@Q1248@P<48@<8@P031240000000@48@040004
8@@Q12422483124010aS2488@PQ20Q2400@8@P@Q2488@P<<H`032480000000<000<<H`L8@P030008
@PQ200<48@@8@P9oo`03001oogoo00Aoo`001Goo00<007oo0000G0000Woo00<007ooOol01goo00<0
07oo48@00PaS10@Q0P001`Q200@000Q2248000848@@8@P80000424848@@Q2483124324800`@Q0000
00041240100012448@@Q0PQ20`@Q00@<H`Q22488@P8@Q00424848@Q2248336<00`Q2000000030003
36<724800`002488@P0312442482Ool00`00Oomoo`04Ool000Eoo`03001oo`0005`0009oo`03001o
ogoo00Moo`03001oo`aS008@Q00436<48@@Q0002248336<00`Q20000000200032482000412452480
10aS12448@@Q0`Q200@48@0000048@<00003124<H`aS00<8@P<000032480000000<48@0524848@Q2
24848@05248010@Q000000aS0PQ210aS00@8@P0000048@D8@P041248@PQ22482Ool00`00Oomoo`04
Ool000Eoo`03001oo`0005`0009oo`03001oogoo00Moo`03001ooaBU00D<H`@48@8<H`041248@PQ2
1243248412420004124224800`@Q24848@0712400`aS00000002248236<312400`Q212448@032480
0`@Q2488@P051246248248@0100012448@@Q10Q20`@Q0`Q20PaS00@8@P@Q124<H`9oo`03001oogoo
00Aoo`001Goo00<007oo0000G0000Woo00<007ooOol01goo00<007oo5:D01@aS10@Q0PaS00@48@Q2
24848@<8@P@48@8000@48@88@P031248@P@Q00L48@0336<000000088@P8<H`<48@0324848@@Q00<8
@P031248@PQ200D48@H8@P8@Q00400048@@Q124424831243248236<010Q212448@aS0Woo00<007oo
Ool017oo0005Ool00`00Ool0001L0002Ool00`00Oomoo`07Ool00`00Ool@Q00236<010@Q36<<H`Q2
0P0000<48@aS36<00`@Q00<<H`Q212400P@Q0PQ200<48@Q224800`aS10@Q0`Q200@48@Q22488@P80
00<8@P041248@P0000041242000010@Q2488@PQ20`@Q00@000@Q124000<48@<8@P8<H`031248@PQ2
00848@88@P0448@48@@Q24821243248010@Q2488@P000Woo00<007ooOol017oo0005Ool00`00Ool0
001L0002Ool00`00Oomoo`07Ool00`00OolDY@0348@236<4248236<42486124010Q2000000@Q1`Q2
0`@Q1@Q200@000@Q1248@PH48@0436<48@@Q00031242000224831243248512401@Q236<<H`aS2480
0PaS0`Q200@000@Q12448@88@P041240000036<2Ool00`00Oomoo`04Ool000Eoo`03001oo`0005`0
009oo`03001oogoo00Moo`03001ooaBU00<@Q08<H`@8@P8<H`@8@PH48@0424800000124724831245
2480100012448@Q21P@Q00@<H`@Q124000<48@800088@P<48@<8@PD48@05248<H`aS36<8@P0236<3
2480100012448@@Q0PQ200@48@00000<H`9oo`03001oogoo00Aoo`001Goo00<007oo0000G0000Woo
00<007ooOol01goo00<007oo5:D00Q2400@8@P0000048@88@P0336<8@PQ200<8@P030008@PQ200@8
@P<48@<<H`<8@P050008@PQ224848@02000412432483124010Q236<<H`Q20P0000@48@000008@P<4
8@0424848@@Q1242248010@Q2488@PQ20P@Q10Q200@000@Q124<H`H8@P<<H`88@P0436=oogoo0006
Ool000Eoo`03001oo`0005`0009oo`03001oogoo00Moo`03001ooa2400<8@P800004124<H`aS1242
24801@0036<<H`aS24800PaS00<48@Q224800`Q200@<H`@Q124@Q08<H`03124000@Q00@48@04248<
H`aS1242248010aS124<H`aS10Q20`@Q0P0000<8@P@Q12400PQ20P@Q00<<H`@Q12400`@Q00<8@P@Q
124010Q200@000Q2248<H`88@P0336<48@@Q00@8@P848@04249oogoo0006Ool000Eoo`03001oo`00
05`0009oo`03001oogoo00Moo`03001ooa2400<8@P800004124<H`aS124224801@0036<<H`aS2480
0PaS00<48@Q224800`Q200@<H`@Q124@Q08<H`03124000@Q00@48@04248<H`aS1242248010aS124<
H`aS10Q20`@Q0P0000<8@P@Q12400PQ20P@Q00<<H`@Q12400`@Q00<8@P@Q124010Q200@000Q2248<
H`88@P0336<48@@Q00@8@P848@04249oogoo0006Ool000Eoo`03001oo`0005`0009oo`03001oogoo
00Moo`03001ooa240088@P0400048@@Q1242000010aS2488@PQ20`aS00@48@Q224848@88@P0436<4
8@@Q12452482124524800`@Q2488@P0312401@Q212448@@Q00001@@Q00@<H`@Q1248@P80000348@0
00@Q00848@8000<48@0424800000000212401@aS00048@@Q24800P000`@Q00@8@PaS36<<H`<8@P9o
o`03001oogoo00Aoo`001Goo00<007oo0000G0000Woo00<007ooOol01goo00<007oo5:D00Q240`@Q
00@8@P@Q12448@88@P<<H`03124000Q20088@P8000031248@PQ200@8@P8000051248@PaS36<8@P03
124200042486124324800`@Q00000003124010aS24848@@Q0`aS00@8@PaS36<48@D8@P04124000aS
36<3000336<010@Q48@@Q1240P0000@<HgooOol000Ioo`001Goo00<007oo0000G0000Woo00<007oo
Ool01goo00<007oo5:D00`000PaS10Q20P000`aS00<000Q2124010@Q00@8@P0000048@<8@P@<H`84
8@<8@P0436<00000124200001@Q212448@@Q24800P@Q00@8@P@Q1248@P800005124<H`aS0008@P02
0003124010Q212448@@Q0PQ200D<H`@Q12448@0000<8@P80000436<@Q12436<32482000010aSOomo
o`001Woo0005Ool00`00Ool0001L0002Ool00`00Oomoo`07Ool00`00OolDY@03000236<424820003
36<00`0024848@04124010Q2000000@Q0`Q210aS0P@Q0`Q200@<H`0000048@80000524848@@Q1248
@P02124010Q212448@Q20P0000D48@aS36<000Q2008000<48@0424848@@Q124224801@aS12448@@Q
00000`Q20P0000@<Ha2448@<H`<8@P80000436=oogoo0006Ool000Eoo`03001oo`0005`0009oo`03
001oogoo00Moo`03001ooaS6008<H`0324848@@Q00<8@P0448@000002483000010Q212448@Q20P@Q
2PQ200@48@aS36<000<8@P80000536<48@@Q1248@P021243248010@Q2488@P000`@Q0PQ20P@Q0PQ2
10@Q0`Q20`aS0P@Q1@aS1@Q200@<H`Q2248<H`<48@9oo`03001oogoo00Aoo`001Goo00<007oo0000
G0000Woo00<007ooOol01goo00<007oo6<H00`@Q0PaS00@8@Q2448@@Q088@P0336<48@@Q00@8@P03
36<48@@Q00@48@8@Q0050008@PQ22480000812401@0012448@Q236<00Q240`@Q00@8@P0000048@88
@P051240000048@48@0236<010@Q000000@Q0PQ200@48A2448@@Q08<H`@8@P0436<48@@Q12432482
36<011242488@PQ20Woo00<007ooOol017oo0005Ool00`00Ool0001L0002Ool00`00Oomoo`07Ool0
0`00OolHaP03124236<010Q248@@Q1240PQ200<<H`@Q124010Q200<<H`@Q124010@Q0Q2400D000Q2
2488@P0000P48@0500048@@Q248<H`0248@3124010Q2000000@Q0PQ200D48@00000@Q0@Q008<H`04
124000001242248010@Q48@@Q1240PaS10Q200@<H`@Q12448@<8@P8<H`0448@8@PQ22482Ool00`00
Oomoo`04Ool000Eoo`03001oo`0005`0009oo`03001oogoo00Moo`03001ooa2400P<H`031248@PQ2
00<8@P05124<H`aS36<8@P0236<010Q248@@Q0000PaS0`Q20P@Q0PQ200@<H`Q2248<H`88@P0436<8
@PQ2124336<3248010aS2488@PQ20P@Q00<8@P0000000P@Q0PQ20`@Q00<000aS36<010Q20PaS0PQ2
0PaS0`Q21PaS00@48@Q22488@P9oo`03001oogoo00Aoo`001Goo00<007oo0000G0000Woo00<007oo
Ool01goo00<007oo6<H00QBU00@@Q0aS36<<H`8@Q00436<8@PQ2248212400`Q21248@P02248236<3
248010aS12448@Q20P@Q1@Q20P@Q00@8@P0000048@88@P0336<48@Q20088@P848@<8@P04000<H`aS
36<212400`aS1248@P022482124010aS000000Q20P@Q00D8@P@Q12448@aS008@Q0<<H`0448@<H`aS
0002248011242488@Q240Woo00<007ooOol017oo0005Ool00`00Ool0001L0002Ool00`00Oomoo`07
Ool00`00OolHaP025:D0112436<<H`aS0Q2400@<H`Q22488@P848@0324848@Q20088@P8<H`<8@P04
36<48@@Q248212452482124010Q2000000@Q0PQ200<<H`@Q24800PQ20P@Q0`Q200@000aS36<<H`84
8@0336<48@Q20088@P848@0436<00000248212401@Q212448@@Q36<00Q240`aS00@@Q0aS36<00088
@P0448@8@PQ248@2Ool00`00Oomoo`04Ool000Eoo`03001oo`0005`0009oo`03001oogoo00Moo`03
001ooacW008<H`<@Q004248@Q12436<3248200001@Q236<@Q12436<00P001PQ200<48@aS36<00PaS
0`Q20P0010aS0`000`Q200@48@Q224848@88@P0436<8@PQ236<248@01@Q21240000012400PQ200<<
H`@Q12400`Q200D<H`Q2248<H`@Q00<<H`88@P0436<8@PQ248@236<348@010aSOomoo`001Woo0005
Ool00`00Ool0001L0002Ool00`00Oomoo`07Ool00`00OolHaP0348@336<3248236<00aBU36<<H`05
36<248@0100012448@@Q1@aS00@@Q0aS2488@P<00004248@Q12424831243248010@Q2488@PaS0P@Q
00<8@PaS36<010@Q00@<H`Q224848@D8@P041248@PQ248@236<011241248@PQ20`@Q00@@Q0Q2248@
Q08<H`04124<H`aS5:D2Ool00`00Oomoo`04Ool000Eoo`03001oo`0005`0009oo`03001oogoo00Mo
o`03001ooaS600<@Q0<<H`<8@P8<H`035:D<H`aS00D<H`8@Q00400048@@Q124536<0112436<8@PQ2
0`0000@8@Q2448@8@P<48@<8@P041248@PQ236<212400`Q236<<H`04124010aS2488@P@Q1@Q200@4
8@Q2248@Q08<H`0448@48@Q22483124011242488@Q240PaS00@48@aS36<DY@9oo`03001oogoo00Ao
o`001Goo00<007oo0000G0000Woo00<007ooOol01goo00<007oo5:D00Q2400@000Q2248@Q0800003
1248@PQ200<8@P848@8<H`04248<H`aS48@32482124324801A2436<<H`aS12400PQ200@48@aS36<8
@P848@03248<H`aS00D<H`88@P031248@PQ200<8@P031248@PaS008<H`88@P041248@PQ212422480
112436<<HaBU0`aS00@48@aS36<<H`<@Q088@P<<H`046<Ioogoo0006Ool000Eoo`03001oo`0005`0
009oo`03001oogoo00Moo`03001oo`aS008<H`0348@0000000<@Q0046<H@Q12448@212400`Q236<<
H`0236<248@00`aS12448@0436<2248412442482124010Q2000000@Q0`aS00<8@PaS36<00`Q200@4
8@Q2248000848@05248<Ha2448@8@P03124236<4248236<248@2248011246<HHaQBU0QS600@<Ha24
48@48@8@Q0045:Eoogoo0006Ool000Eoo`03001oo`0005`0009oo`03001oogoo00Moo`03001oo`aS
008<H`0348@0000000<@Q0046<H@Q12448@212400`Q236<<H`0236<248@00`aS12448@0436<22484
12442482124010Q2000000@Q0`aS00<8@PaS36<00`Q200@48@Q2248000848@05248<Ha2448@8@P03
124236<4248236<248@2248011246<HHaQBU0QS600@<Ha2448@48@8@Q0045:Eoogoo0006Ool000Eo
o`03001oo`0005`0009oo`03001oogoo00Moo`03001ooacW008HaP0336<DYABU00H@Q0<HaP8DY@8H
aP0448@<H`aS36<248@011BU48@@Q0Q20P@Q1@aS0P@Q00@<H`@Q124000<48@0324848@@Q00<8@P04
0008@PQ236<3124224801@@Q36<<H`aS48@00PQ200@000aS36<<H`88@P05124<H`aS248@Q00236<3
48@010aS48@@Q0Q20Q2411BU0Woo00<007ooOol017oo0005Ool00`00Ool0001L0002Ool00`00Oomo
o`07Ool00`00OolQ20027>L348@336<011246<HHaQcW0aS600<@Q1BU5:D00`Q200<<H`Q224800a24
10Q200@@Q0000008@P<<H`80000336<48@@Q00D48@88@P<<H`03248<H`aS00<48@@8@PL<H`8@Q005
36<@Q12448@DY@02124348@00`aS2488@P03248011BU7>LLiaS60Woo00<007ooOol017oo0005Ool0
0`00Ool0001L0002Ool00`00Oomoo`07Ool00`00OolHaP0348@26<H011BU8@PQ21cW0PaS00DDYAS6
6<HDYAS600<DY@8@Q0<8@P<<H`050008@PQ20008@P02124010002488@P@Q0PQ210@Q00<8@P@Q1240
2PQ20P@Q00D<H`Q2000000Q2008000<<H`0448@DYABU48@236<00aBU7>LDY@025:D27>L011S636<<
H`aS0QS600@Q21S66<HDY@9oo`03001oogoo00Aoo`001Goo00<007oo0000G0000Woo00<007ooOol0
1goo00<007oo6<H00a240QS600@DYB488@PLi`8<H`055:DHaQS65:DHaP035:D248@3248336<01@00
2488@P0024800P@Q00@000Q224848@88@P@48@0324848@@Q00X8@P848@0536<8@P000008@P020003
36<011245:DDYA240PaS00<DYAcW5:D00QBU0QcW00@HaPaS36<<H`8HaP048@PHaQS65:D2Ool00`00
Oomoo`04Ool000Eoo`03001oo`0005`0009oo`03001oogoo00Moo`03001oobU:008Q20047>LHaQS6
8@P27>L012482488@Q240R4800DLiaS67>LLi`aS008@Q003248@Q12400<<H`0548@<H`aS36<@Q002
1243248336<00`0012448@0236<2248010@Q2488@P@Q0PQ200@000@Q12448@88@P05124000000008
@P02124010Q248@@Q1BU0QS60aBU0QS60QBU00@HaQcW7>LLi`88@P<DY@048@PLiacW8@P2Ool00`00
Oomoo`04Ool000Eoo`03001oo`0005`0009oo`03001oogoo00Moo`03001oo`Q2008Li`049BTQ2248
7>L36<H27>L01AS67>LLiaS636<00QcW00@HaQBU5:D@Q08000<8@PD@Q0D48@<8@P041248@PQ236<3
248010@Q2488@PQ20`@Q0PQ200@000aS36<8@P@<H`848@04248<H`aS36<55:D01@aS5:D@Q1246<H0
0Q2400<Q21cW7>L00`aS0acW00@HaWooOol000Ioo`001Goo00<007oo0000G0000Woo00<007ooOol0
1goo00<007oo24800QcW00@U:B488@PLi`<HaP8Li`056<HLiacW6<H<H`027>L011S65:DDYA240P00
0`Q21A241@@Q0`Q200@48@Q2248<H`<8@P041248@PQ2248312422480100036<<H`Q210aS0P@Q00@8
@PaS36<<H`DDY@0536<DYA2448@HaP0248@00b487>LLi`0336<37>L011S6Oomoo`001Woo0005Ool0
0`00Ool0001L0002Ool00`00Oomoo`07Ool00`00Ool@Q0026<H011cW;F/]Jb480RU:00@U:AcW7>LU
:@<Li`046<HQ22487>L25:D00`@Q36<<H`0336<01@Q248@@Q0Q236<00`Q21@aS00<8@Q2448@00Q24
0PQ200@48@aS36<48@8<H`0348@DYABU00<8@P0448@48@aS36<3248010aS48@@Q0@Q0QBU00@@Q0aS
36<DY@@HaP8Li`04:DXU:BDY36<29BT012U:7>LLibDY0Woo00<007ooOol017oo0005Ool00`00Ool0
001L0002Ool00`00Oomoo`07Ool00`00Ool]J`02;F/012U:9BTU:Be[0RU:00@]Jb488@PYBP8U:@03
7>LHaQ24008@Q0<<H`8@Q00336<8@PQ200@8@PH<H`<8@P0336<8@PQ200D<H`8@Q00436<8@PQ22482
48@312400`Q236<<H`0236<25:D010aS2488@PaS1A2411cW1RDY00@Q22U::DXaS08]J`04:DYoogoo
0006Ool000Eoo`03001oo`0005`0009oo`03001oogoo00Moo`03001oobe[008]J`04:DXU:BDY;F/2
:DX012e[8@PQ22U:0RDY00<LiaS648@00Q240`aS0Q2400<<H`Q2248010Q21PaS0`Q200<<H`Q22480
1@aS0Q2400@<H`Q22488@P8@Q0<48@03248<H`aS008<H`8DY@0436<8@PQ236<548@47>L69BT01248
:DXYBS6<0Re[00@YBWooOol000Ioo`001Goo00<007oo0000G0000Woo00<007ooOol01goo00<007oo
<H`00SW>00@e[Be[;F/aS0<U:@8YBP059BTYBRU:6<HDY@026<H011BU36<<H`aS0QBU00<@Q0aS36<0
11240`Q200@@Q0aS36<48@88@P05124<H`aS36<8@P0236<00a2400000003124010aS2488@PQ20PaS
00@48@Q212448@<<H`04000<H`aS124224836<H01AcW36<HaQS68@P00RDY00@YBRDY9BTU:@8YBP<a
S004;F]oogoo0006Ool000Eoo`03001oo`0005`0009oo`03001oogoo00Moo`03001oocW>008icP04
?NlicSW>?Nl2<H`011248@PQ22U:0b480`aS00@HaQ2448@HaP88@P0448@8@PQ236<26<H00aBU48@<
H`0236<648@236<248@21240112436<<H`Q20Q2400<<Ha2448@00a2400@<Ha242488@P<<H`<8@P<D
Y@056<H@Q1245:DHaP0236<01248:DXYBRe[0R4800@YBSF]=Jde[@8mk`049BUoogoo0006Ool000Eo
o`03001oo`0005`0009oo`03001oogoo00Moo`03001oocW>008icP04?NlicSW>?Nl2<H`011248@PQ
22U:0b480`aS00@HaQ2448@HaP88@P0448@8@PQ236<26<H00aBU48@<H`0236<648@236<248@21240
112436<<H`Q20Q2400<<Ha2448@00a2400@<Ha242488@P<<H`<8@P<DY@056<H@Q1245:DHaP0236<0
1248:DXYBRe[0R4800@YBSF]=Jde[@8mk`049BUoogoo0006Ool000Eoo`03001oo`0005`0009oo`03
001oogoo00Moo`03001oocF]00<icP8mk`04@Q0mkcg_5:D28@P01BU:8@PQ22487>L00QBU0aS600@D
Y@@Q124@Q08<H`0448@DYABU6<H348@011BU48@@Q1BU0PQ200D<HaBU5:D<Ha24008<H`035:D<H`aS
00@<H`8000<<H`04248<HaS66<H32480112436<<HaBU0PaS00DDYA2448@HaPaS008HaP047>LQ2248
9BT26<H013F]@Q1243g_0dHa0Woo00<007ooOol017oo0005Ool00`00Ool48@0200000`@Q0000001C
000010@Q000000Q20Woo00<007ooOol01goo00<007ooE[D00Sg_00A>Lcg_?Nm6<@8mk`04>LhLiacW
8@P2:DX248@28@P00aS65:DDY@038@P011S65:DDYAS60aBU1acW0QS600<LiaS66<H011S60acW00@H
aQcW7>LLi`<HaP@Li`<Q20<Li`8Q20<HaP037>LDYABU008HaP8YBP04;F/U:BDY36<26<H013F]AS56
<Dic0TYB00AF]GooOol000Ioo`001Goo00<007oo12400P0000<48@000000D`0000@48@000008@P9o
o`03001oogoo00Moo`03001ooeJe008mk`04CW<mkcg_AS42?Nl013W>7>LLib480RU:0Q240R4800<H
aQBU5:D00b4800@HaQBU5:DHaP<DY@LLi`8HaP037>LHaQS600@HaP<Li`046<HLiacW7>L36<H47>L3
8@P37>L28@P36<H00acW5:DDY@026<H2:DX012e[9BTU:@aS0QS600@e[DHaAS5>L`9:DP04E[Eoogoo
0006Ool000Eoo`03001ooaBU00848@032480000005<000<48@0436=oogoo0009Ool00`00OomW>@02
BU8015[FBU9:DTHa0Sg_00A2436<<H`Q20<]J`0448@Q22489BT28@P3:DX00bDY8@PQ20058@P29BT0
0b489BTU:@079BT48@P69BT58@P00bDY8@PU:@029BT38@P2:DX012DY8@PQ22DY0R4800<@Q1cW<H`0
0S6<0bU:0S6<00@Lid8@@Q1F]@9BU004G_Moogoo0006Ool000Eoo`03001oogoo05ioo`03001oogoo
00Moo`03001oogoo05ioo`03001oogoo00Aoo`001GooHP002GooHP001Woo003HOol00=Qoo`00\
\>"],
  ImageRangeCache->{{{0, 215}, {101.813, 0}} -> {-0.055872, -0.0238146, 
  0.00982208, 0.00982208}, {{5.6875, 102.625}, {99.375, 
  2.375}} -> {-5.28173, -3.06591, 0.688412, 0.688412}, {{112.313, 209.313}, {
  99.375, 2.375}} -> {-78.6337, -3.04325, 0.687967, 0.687967}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Linear contrast manipulation", "Subsection"],

Cell["\<\
A simple, but useful technique of contrast manipulation, is to define a \
piecewise linear transformation to selectively stretch and/or compress a \
range of luminance values. The slope of the transformation is chosen greater \
than 1 in the region of stretch and less than 1 in the region of compression.\
\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(ListPlot[
      ContrastModifyLinear[x, {{0, 0}, {75, 25}, {175, 225}, {255, 255}}], 
      PlotJoined -> True]; \)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00372024 0.0147151 0.00230825 [
[.20982 .00222 -6 -9 ]
[.20982 .00222 6 0 ]
[.39583 .00222 -9 -9 ]
[.39583 .00222 9 0 ]
[.58185 .00222 -9 -9 ]
[.58185 .00222 9 0 ]
[.76786 .00222 -9 -9 ]
[.76786 .00222 9 0 ]
[.95387 .00222 -9 -9 ]
[.95387 .00222 9 0 ]
[.01131 .13013 -12 -4.5 ]
[.01131 .13013 0 4.5 ]
[.01131 .24554 -18 -4.5 ]
[.01131 .24554 0 4.5 ]
[.01131 .36095 -18 -4.5 ]
[.01131 .36095 0 4.5 ]
[.01131 .47637 -18 -4.5 ]
[.01131 .47637 0 4.5 ]
[.01131 .59178 -18 -4.5 ]
[.01131 .59178 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.20982 .01472 m
.20982 .02097 L
s
[(50)] .20982 .00222 0 1 Mshowa
.39583 .01472 m
.39583 .02097 L
s
[(100)] .39583 .00222 0 1 Mshowa
.58185 .01472 m
.58185 .02097 L
s
[(150)] .58185 .00222 0 1 Mshowa
.76786 .01472 m
.76786 .02097 L
s
[(200)] .76786 .00222 0 1 Mshowa
.95387 .01472 m
.95387 .02097 L
s
[(250)] .95387 .00222 0 1 Mshowa
.125 Mabswid
.06101 .01472 m
.06101 .01847 L
s
.09821 .01472 m
.09821 .01847 L
s
.13542 .01472 m
.13542 .01847 L
s
.17262 .01472 m
.17262 .01847 L
s
.24702 .01472 m
.24702 .01847 L
s
.28423 .01472 m
.28423 .01847 L
s
.32143 .01472 m
.32143 .01847 L
s
.35863 .01472 m
.35863 .01847 L
s
.43304 .01472 m
.43304 .01847 L
s
.47024 .01472 m
.47024 .01847 L
s
.50744 .01472 m
.50744 .01847 L
s
.54464 .01472 m
.54464 .01847 L
s
.61905 .01472 m
.61905 .01847 L
s
.65625 .01472 m
.65625 .01847 L
s
.69345 .01472 m
.69345 .01847 L
s
.73065 .01472 m
.73065 .01847 L
s
.80506 .01472 m
.80506 .01847 L
s
.84226 .01472 m
.84226 .01847 L
s
.87946 .01472 m
.87946 .01847 L
s
.91667 .01472 m
.91667 .01847 L
s
.99107 .01472 m
.99107 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02381 .13013 m
.03006 .13013 L
s
[(50)] .01131 .13013 1 0 Mshowa
.02381 .24554 m
.03006 .24554 L
s
[(100)] .01131 .24554 1 0 Mshowa
.02381 .36095 m
.03006 .36095 L
s
[(150)] .01131 .36095 1 0 Mshowa
.02381 .47637 m
.03006 .47637 L
s
[(200)] .01131 .47637 1 0 Mshowa
.02381 .59178 m
.03006 .59178 L
s
[(250)] .01131 .59178 1 0 Mshowa
.125 Mabswid
.02381 .0378 m
.02756 .0378 L
s
.02381 .06088 m
.02756 .06088 L
s
.02381 .08396 m
.02756 .08396 L
s
.02381 .10705 m
.02756 .10705 L
s
.02381 .15321 m
.02756 .15321 L
s
.02381 .17629 m
.02756 .17629 L
s
.02381 .19938 m
.02756 .19938 L
s
.02381 .22246 m
.02756 .22246 L
s
.02381 .26862 m
.02756 .26862 L
s
.02381 .29171 m
.02756 .29171 L
s
.02381 .31479 m
.02756 .31479 L
s
.02381 .33787 m
.02756 .33787 L
s
.02381 .38404 m
.02756 .38404 L
s
.02381 .40712 m
.02756 .40712 L
s
.02381 .4302 m
.02756 .4302 L
s
.02381 .45328 m
.02756 .45328 L
s
.02381 .49945 m
.02756 .49945 L
s
.02381 .52253 m
.02756 .52253 L
s
.02381 .54561 m
.02756 .54561 L
s
.02381 .5687 m
.02756 .5687 L
s
.02381 .61486 m
.02756 .61486 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02753 .01472 m
.03125 .01548 L
.03497 .01625 L
.03869 .01702 L
.04241 .01779 L
.04613 .01856 L
.04985 .01933 L
.05357 .0201 L
.05729 .02087 L
.06101 .02164 L
.06473 .02241 L
.06845 .02318 L
.07217 .02395 L
.07589 .02472 L
.07961 .02549 L
.08333 .02626 L
.08705 .02703 L
.09077 .0278 L
.09449 .02856 L
.09821 .02933 L
.10193 .0301 L
.10565 .03087 L
.10937 .03164 L
.1131 .03241 L
.11682 .03318 L
.12054 .03395 L
.12426 .03472 L
.12798 .03549 L
.1317 .03626 L
.13542 .03703 L
.13914 .0378 L
.14286 .03857 L
.14658 .03934 L
.1503 .04011 L
.15402 .04088 L
.15774 .04164 L
.16146 .04241 L
.16518 .04318 L
.1689 .04395 L
.17262 .04472 L
.17634 .04549 L
.18006 .04626 L
.18378 .04703 L
.1875 .0478 L
.19122 .04857 L
.19494 .04934 L
.19866 .05011 L
.20238 .05088 L
.2061 .05165 L
.20982 .05242 L
Mistroke
.21354 .05319 L
.21726 .05396 L
.22098 .05472 L
.2247 .05549 L
.22842 .05626 L
.23214 .05703 L
.23586 .0578 L
.23958 .05857 L
.2433 .05934 L
.24702 .06011 L
.25074 .06088 L
.25446 .06165 L
.25818 .06242 L
.2619 .06319 L
.26563 .06396 L
.26935 .06473 L
.27307 .0655 L
.27679 .06627 L
.28051 .06704 L
.28423 .0678 L
.28795 .06857 L
.29167 .06934 L
.29539 .07011 L
.29911 .07088 L
.30283 .07165 L
.30655 .07242 L
.31027 .07704 L
.31399 .08165 L
.31771 .08627 L
.32143 .09089 L
.32515 .0955 L
.32887 .10012 L
.33259 .10474 L
.33631 .10935 L
.34003 .11397 L
.34375 .11859 L
.34747 .1232 L
.35119 .12782 L
.35491 .13244 L
.35863 .13705 L
.36235 .14167 L
.36607 .14629 L
.36979 .1509 L
.37351 .15552 L
.37723 .16013 L
.38095 .16475 L
.38467 .16937 L
.38839 .17398 L
.39211 .1786 L
.39583 .18322 L
Mistroke
.39955 .18783 L
.40327 .19245 L
.40699 .19707 L
.41071 .20168 L
.41443 .2063 L
.41815 .21092 L
.42188 .21553 L
.4256 .22015 L
.42932 .22477 L
.43304 .22938 L
.43676 .234 L
.44048 .23862 L
.4442 .24323 L
.44792 .24785 L
.45164 .25246 L
.45536 .25708 L
.45908 .2617 L
.4628 .26631 L
.46652 .27093 L
.47024 .27555 L
.47396 .28016 L
.47768 .28478 L
.4814 .2894 L
.48512 .29401 L
.48884 .29863 L
.49256 .30325 L
.49628 .30786 L
.5 .31248 L
.50372 .3171 L
.50744 .32171 L
.51116 .32633 L
.51488 .33095 L
.5186 .33556 L
.52232 .34018 L
.52604 .34479 L
.52976 .34941 L
.53348 .35403 L
.5372 .35864 L
.54092 .36326 L
.54464 .36788 L
.54836 .37249 L
.55208 .37711 L
.5558 .38173 L
.55952 .38634 L
.56324 .39096 L
.56696 .39558 L
.57068 .40019 L
.5744 .40481 L
.57813 .40943 L
.58185 .41404 L
Mistroke
.58557 .41866 L
.58929 .42328 L
.59301 .42789 L
.59673 .43251 L
.60045 .43712 L
.60417 .44174 L
.60789 .44636 L
.61161 .45097 L
.61533 .45559 L
.61905 .46021 L
.62277 .46482 L
.62649 .46944 L
.63021 .47406 L
.63393 .47867 L
.63765 .48329 L
.64137 .48791 L
.64509 .49252 L
.64881 .49714 L
.65253 .50176 L
.65625 .50637 L
.65997 .51099 L
.66369 .51561 L
.66741 .52022 L
.67113 .52484 L
.67485 .52945 L
.67857 .53407 L
.68229 .53494 L
.68601 .5358 L
.68973 .53667 L
.69345 .53753 L
.69717 .5384 L
.70089 .53926 L
.70461 .54013 L
.70833 .541 L
.71205 .54186 L
.71577 .54273 L
.71949 .54359 L
.72321 .54446 L
.72693 .54532 L
.73065 .54619 L
.73438 .54706 L
.7381 .54792 L
.74182 .54879 L
.74554 .54965 L
.74926 .55052 L
.75298 .55138 L
.7567 .55225 L
.76042 .55311 L
.76414 .55398 L
.76786 .55485 L
Mistroke
.77158 .55571 L
.7753 .55658 L
.77902 .55744 L
.78274 .55831 L
.78646 .55917 L
.79018 .56004 L
.7939 .5609 L
.79762 .56177 L
.80134 .56264 L
.80506 .5635 L
.80878 .56437 L
.8125 .56523 L
.81622 .5661 L
.81994 .56696 L
.82366 .56783 L
.82738 .5687 L
.8311 .56956 L
.83482 .57043 L
.83854 .57129 L
.84226 .57216 L
.84598 .57302 L
.8497 .57389 L
.85342 .57475 L
.85714 .57562 L
.86086 .57649 L
.86458 .57735 L
.8683 .57822 L
.87202 .57908 L
.87574 .57995 L
.87946 .58081 L
.88318 .58168 L
.8869 .58254 L
.89063 .58341 L
.89435 .58428 L
.89807 .58514 L
.90179 .58601 L
.90551 .58687 L
.90923 .58774 L
.91295 .5886 L
.91667 .58947 L
.92039 .59033 L
.92411 .5912 L
.92783 .59207 L
.93155 .59293 L
.93527 .5938 L
.93899 .59466 L
.94271 .59553 L
.94643 .59639 L
.95015 .59726 L
.95387 .59813 L
Mistroke
.95759 .59899 L
.96131 .59986 L
.96503 .60072 L
.96875 .60159 L
.97247 .60245 L
.97619 .60332 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{216, 133.438},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003H0000QA000`40O003h00Of7oo000fOol00`00
Oomoo`02Ool00`00Oomoo`0IOol50002Ool00`00Oomoo`02Ool00`00Oomoo`0FOol50002Ool00`00
Oomoo`02Ool00`00Oomoo`0GOol30003Ool00`00Oomoo`02Ool00`00Oomoo`0GOol30003Ool00`00
Oomoo`02Ool00`00Oomoo`03Ool003Eoo`03001oo`00009oo`03001oo`0001aoo`07001oogooOol0
07oo00000Woo00<007oo00006Goo00L007ooOomoo`00Ool00002Ool00`00Ool0000HOol00`00Oomo
o`02Ool00`00Ool00002Ool00`00Ool0000HOol00`00Oomoo`02Ool00`00Ool00002Ool00`00Ool0
0004Ool003Moo`06001oogoo001oo`0077oo00L007ooOomoo`00Ool00002Ool00`00Ool0000IOol0
0`00Oomoo`03Ool01P00Oomoo`00Ool001Uoo`07001oogooOol007oo00000Woo00<007oo00006Goo
00<007ooOol00goo00H007ooOol007oo0004Ool003Eoo`8000=oo`03001oo`0001aoo`07001oogoo
Ool007oo00000Woo00<007oo00006Goo00@007ooOomoo`8000=oo`03001oo`0001Uoo`07001oogoo
Ool007oo00000Woo00<007oo00006Goo00@007ooOomoo`8000=oo`03001oo`0000Aoo`00=Goo00<0
07ooOol00Woo00<007oo000077oo00L007ooOomoo`00Ool00002Ool00`00Ool0000IOol01@00Oomo
ogoo000017oo00<007oo000067oo00<007oo00000Woo00<007oo00000Woo00<007oo000067oo00<0
07oo00000Woo00<007ooOol00Woo00<007oo000017oo000eOol30003Ool00`00Oomoo`0JOol20004
Ool00`00Oomoo`02Ool00`00Oomoo`0GOol20003Ool30003Ool00`00Oomoo`0HOol00`00Oomoo`02
Ool00`00Oomoo`02Ool00`00Oomoo`0HOol01000Oomoogoo0`000goo00<007ooOol00goo003HOol0
0=Qoo`0057oo00<007ooOol0`Goo000DOol00`00Oomoo`31Ool001Aoo`03001oogoo0<5oo`003goo
b@00000DOol01000Oomoogoo1@001Woo00<007ooOol017oo00<007ooOol01Goo00<007ooOol017oo
00<007ooOol017oo00<007ooOol01Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol017oo
00<007ooOol01Goo00<007ooOol017oo00<007ooOol017oo00<007ooOol01Goo00<007ooOol017oo
00<007ooOol01Goo00<007ooOol017oo00<007ooOol017oo00<007ooOol01Goo00<007ooOol017oo
00<007ooOol01Goo00<007ooOol017oo00<007ooOol017oo00<007ooOol01Goo00<007ooOol017oo
00<007ooOol01Goo0@000Goo0Goo000DOol00`00Oomoo`06Ool5002fOol001Aoo`03001oogoo00Yo
o`H00;5oo`0057oo00<007ooOol047oo1000[Goo000DOol2000EOol5002XOol001Aoo`03001oogoo
01Uoo`D00:=oo`0057oo00<007ooOol07Woo1@00WWoo000DOol00`00Oomoo`0SOol5002IOol001Ao
o`8002Qoo`H009Aoo`0057oo00<007ooOol0;7oo1P00Sgoo000DOol00`00Oomoo`0bOol4002;Ool0
01Aoo`03001oogoo03Ioo`03001oogoo08Qoo`0057oo00<007ooOol0=goo00<007ooOol0Qgoo000D
Ool2000iOol00`00Oomoo`26Ool001Aoo`03001oogoo03Qoo`03001oogoo08Ioo`0057oo00<007oo
Ool0>Goo00<007ooOol0QGoo000DOol00`00Oomoo`0jOol00`00Oomoo`24Ool001Aoo`8003aoo`03
001oogoo08=oo`0057oo00<007ooOol0>goo00<007ooOol0Pgoo000DOol00`00Oomoo`0lOol00`00
Oomoo`22Ool000Yoo`03001oogoo009oo`03001oogoo009oo`03001oogoo03eoo`03001oogoo085o
o`002Goo00<007oo00000Woo00<007oo00000goo00<007ooOol0?Goo0P00PWoo000;Ool01P00Oomo
o`00Ool000=oo`80041oo`03001oogoo07moo`002Goo0P000goo00<007oo00000goo00<007ooOol0
@7oo00<007ooOol0OWoo0009Ool00`00Oomoo`02Ool00`00Ool00003Ool00`00Oomoo`10Ool00`00
Oomoo`1nOol000Uoo`<000=oo`03001oogoo009oo`03001oogoo045oo`03001oogoo07eoo`0057oo
00<007ooOol0@Woo00<007ooOol0O7oo000DOol20014Ool00`00Oomoo`1kOol001Aoo`03001oogoo
04=oo`03001oogoo07]oo`0057oo00<007ooOol0A7oo00<007ooOol0NWoo000DOol00`00Oomoo`15
Ool00`00Oomoo`1iOol001Aoo`8004Moo`03001oogoo07Qoo`0057oo00<007ooOol0AWoo0P00NGoo
000DOol00`00Oomoo`18Ool00`00Oomoo`1fOol001Aoo`03001oogoo04Uoo`03001oogoo07Eoo`00
57oo00<007ooOol0BGoo00<007ooOol0MGoo000DOol2001;Ool00`00Oomoo`1dOol001Aoo`03001o
ogoo04]oo`03001oogoo07=oo`0057oo00<007ooOol0C7oo00<007ooOol0LWoo000DOol00`00Oomo
o`1<Ool00`00Oomoo`1bOol001Aoo`8004ioo`03001oogoo075oo`0057oo00<007ooOol0CWoo00<0
07ooOol0L7oo000DOol00`00Oomoo`1?Ool00`00Oomoo`1_Ool000=oo`D0009oo`03001oogoo009o
o`03001oogoo009oo`03001oogoo04moo`03001oogoo06moo`001Goo00L007ooOomoo`00Ool00002
Ool00`00Ool00003Ool00`00Oomoo`1@Ool2001_Ool000Eoo`07001oogooOol007oo00000Woo00<0
07oo00000goo0P00DWoo00<007ooOol0KGoo0005Ool01`00Oomoogoo001oo`00009oo`03001oo`00
00=oo`03001oogoo059oo`03001oogoo06aoo`001Goo00L007ooOomoo`00Ool00002Ool00`00Ool0
0003Ool00`00Oomoo`1COol00`00Oomoo`1[Ool000Aoo`8000Aoo`03001oogoo009oo`03001oogoo
009oo`03001oogoo05Aoo`03001oogoo06Yoo`0057oo00<007ooOol0E7oo00<007ooOol0JWoo000D
Ool2001FOol00`00Oomoo`1YOol001Aoo`03001oogoo05Ioo`03001oogoo06Qoo`0057oo00<007oo
Ool0Egoo00<007ooOol0Igoo000DOol00`00Oomoo`1GOol00`00Oomoo`1WOol001Aoo`8005Uoo`03
001oogoo06Ioo`0057oo00<007ooOol0FGoo0P00IWoo000DOol00`00Oomoo`1JOol00`00Oomoo`1T
Ool001Aoo`03001oogoo05]oo`03001oogoo06=oo`0057oo00<007ooOol0G7oo00<007ooOol0HWoo
000DOol2001NOol00`00Oomoo`1QOol001Aoo`03001oogoo05eoo`03001oogoo065oo`0057oo00<0
07ooOol0GWoo00<007ooOol0H7oo000DOol00`00Oomoo`1OOol00`00Oomoo`1OOol001Aoo`80065o
o`03001oogoo05ioo`0057oo00<007ooOol0H7oo00<007ooOol0GWoo000DOol00`00Oomoo`1QOol0
0`00Oomoo`1MOol000=oo`D0009oo`03001oogoo009oo`03001oogoo009oo`03001oogoo069oo`03
001oogoo05aoo`001Goo00L007ooOomoo`00Ool00002Ool00`00Ool00003Ool00`00Oomoo`1SOol0
0`00Oomoo`1KOol000Eoo`03001oogoo00=oo`06001oogoo001oo`000goo0P00IGoo00<007ooOol0
FWoo0005Ool01000Oomoogoo0P000goo00<007oo00000goo00<007ooOol0IGoo00<007ooOol0FGoo
0005Ool01@00Oomoogoo000017oo00<007oo00000goo00<007ooOol0IWoo00<007ooOol0F7oo0004
Ool20003Ool30003Ool00`00Oomoo`02Ool00`00Oomoo`1VOol00`00Oomoo`1HOol001Aoo`03001o
ogoo06Moo`03001oogoo05Moo`0057oo0P00JGoo00<007ooOol0EWoo000DOol00`00Oomoo`1XOol0
0`00Oomoo`1FOol001Aoo`03001oogoo06Uoo`03001oogoo05Eoo`0057oo00<007ooOol0JWoo00<0
07ooOol0E7oo000DOol2001/Ool00`00Oomoo`1COol001Aoo`03001oogoo06]oo`8005Aoo`0057oo
00<007ooOol0KGoo00<007ooOol0DGoo000DOol00`00Oomoo`1^Ool00`00Oomoo`1@Ool001Aoo`03
001oogoo06ioo`03001oogoo051oo`0057oo0P00L7oo00<007ooOol0Cgoo000DOol00`00Oomoo`1`
Ool00`00Oomoo`1>Ool001Aoo`03001oogoo075oo`03001oogoo04eoo`0057oo00<007ooOol0LGoo
00<007ooOol0CGoo000DOol2001cOol00`00Oomoo`1<Ool001Aoo`03001oogoo07=oo`03001oogoo
04]oo`0057oo00<007ooOol0M7oo00<007ooOol0BWoo0004Ool30003Ool00`00Oomoo`02Ool00`00
Oomoo`02Ool00`00Oomoo`1dOol00`00Oomoo`1:Ool000Aoo`03001oogoo009oo`03001oo`00009o
o`03001oo`0000=oo`03001oogoo07Eoo`8004Yoo`001Goo00L007ooOomoo`00Ool00002Ool00`00
Ool00003Ool2001hOol00`00Oomoo`17Ool000Eoo`07001oogooOol007oo00000Woo00<007oo0000
0goo00<007ooOol0Mgoo00<007ooOol0Agoo0004Ool00`00Ool00002Ool00`00Ool00002Ool00`00
Ool00003Ool00`00Oomoo`1hOol00`00Oomoo`16Ool000Eoo`03001oogoo009oo`03001oogoo009o
o`03001oogoo009oo`03001oogoo07Uoo`03001oogoo04Eoo`0057oo00<007ooOol0NWoo00<007oo
Ool0A7oo000DOol2001kOol00`00Oomoo`14Ool001Aoo`03001oogoo07]oo`03001oogoo04=oo`00
57oo00<007ooOol0O7oo00<007ooOol0@Woo000DOol00`00Oomoo`1lOol00`00Oomoo`12Ool001Ao
o`8007ioo`03001oogoo045oo`0057oo00<007ooOol0OWoo0P00@Goo000DOol00`00Oomoo`1oOol0
0`00Oomoo`0oOol001Aoo`03001oogoo081oo`D003aoo`0057oo00<007ooOol0QGoo1000>7oo000D
Ool2002:Ool4000dOol001Aoo`03001oogoo08eoo`D002moo`0057oo00<007ooOol0TGoo1@00:goo
000DOol00`00Oomoo`2FOol4000WOol001Aoo`8009]oo`D0029oo`0057oo00<007ooOol0Wgoo1000
7Woo000DOol00`00Oomoo`2ROol5000JOol000Aoo`<000=oo`03001oogoo009oo`03001oogoo009o
o`03001oogoo0:Moo`@001Ioo`0017oo00<007ooOol00Woo00<007oo00000Woo00<007oo00000goo
00<007ooOol0Zgoo1@004Goo0005Ool00`00Oomoo`03Ool01P00Oomoo`00Ool000=oo`800;5oo`@0
00eoo`001Goo00@007ooOomoo`8000=oo`03001oo`0000=oo`03001oogoo0;Aoo`@000Uoo`0017oo
00<007oo00000Woo00<007ooOol00Woo00<007oo00000goo00<007ooOol0^7oo10001Goo0005Ool0
1000Oomoogoo0`000goo00<007ooOol00Woo00<007ooOol0`Goo000DOol20032Ool001Aoo`03001o
ogoo0<5oo`00\
\>"],
  ImageRangeCache->{{{0, 215}, {132.438, 0}} -> {-27.6441, -25.7823, 1.34905, 
  2.17428}}]
}, Open  ]],

Cell[TextData[{
  "The function ",
  StyleBox["ContrastModifyLinear", "Program"],
  " accepts a list of vertices of the piecewise linear transformation, with \
the first number of each pair the input (original) pixel value, and the \
second, the output pixel value."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Intensity slicing.", "Subsection"],

Cell[TextData[{
  "Consider the operation of highlighting a pixel based on its luminance \
value. By making pixels satisfying a given brightness criteria either white \
or black, their visibility will be improved. This is is known as level \
slicing. Sometimes the pixels are colored. Intensity slicing may be \
implemented using ",
  StyleBox["ContrastModifyLinear", "Program"],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(ListPlot[
      ContrastModifyLinear[
        x, {{0, 0}, {100, 100}, {101, 255}, \n
          \t\t\t{120, 255}, {121, 121}, {255, 255}}], PlotJoined -> True]; 
    \)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00372024 0.0147151 0.00230825 [
[.20982 .00222 -6 -9 ]
[.20982 .00222 6 0 ]
[.39583 .00222 -9 -9 ]
[.39583 .00222 9 0 ]
[.58185 .00222 -9 -9 ]
[.58185 .00222 9 0 ]
[.76786 .00222 -9 -9 ]
[.76786 .00222 9 0 ]
[.95387 .00222 -9 -9 ]
[.95387 .00222 9 0 ]
[.01131 .13013 -12 -4.5 ]
[.01131 .13013 0 4.5 ]
[.01131 .24554 -18 -4.5 ]
[.01131 .24554 0 4.5 ]
[.01131 .36095 -18 -4.5 ]
[.01131 .36095 0 4.5 ]
[.01131 .47637 -18 -4.5 ]
[.01131 .47637 0 4.5 ]
[.01131 .59178 -18 -4.5 ]
[.01131 .59178 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.20982 .01472 m
.20982 .02097 L
s
[(50)] .20982 .00222 0 1 Mshowa
.39583 .01472 m
.39583 .02097 L
s
[(100)] .39583 .00222 0 1 Mshowa
.58185 .01472 m
.58185 .02097 L
s
[(150)] .58185 .00222 0 1 Mshowa
.76786 .01472 m
.76786 .02097 L
s
[(200)] .76786 .00222 0 1 Mshowa
.95387 .01472 m
.95387 .02097 L
s
[(250)] .95387 .00222 0 1 Mshowa
.125 Mabswid
.06101 .01472 m
.06101 .01847 L
s
.09821 .01472 m
.09821 .01847 L
s
.13542 .01472 m
.13542 .01847 L
s
.17262 .01472 m
.17262 .01847 L
s
.24702 .01472 m
.24702 .01847 L
s
.28423 .01472 m
.28423 .01847 L
s
.32143 .01472 m
.32143 .01847 L
s
.35863 .01472 m
.35863 .01847 L
s
.43304 .01472 m
.43304 .01847 L
s
.47024 .01472 m
.47024 .01847 L
s
.50744 .01472 m
.50744 .01847 L
s
.54464 .01472 m
.54464 .01847 L
s
.61905 .01472 m
.61905 .01847 L
s
.65625 .01472 m
.65625 .01847 L
s
.69345 .01472 m
.69345 .01847 L
s
.73065 .01472 m
.73065 .01847 L
s
.80506 .01472 m
.80506 .01847 L
s
.84226 .01472 m
.84226 .01847 L
s
.87946 .01472 m
.87946 .01847 L
s
.91667 .01472 m
.91667 .01847 L
s
.99107 .01472 m
.99107 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02381 .13013 m
.03006 .13013 L
s
[(50)] .01131 .13013 1 0 Mshowa
.02381 .24554 m
.03006 .24554 L
s
[(100)] .01131 .24554 1 0 Mshowa
.02381 .36095 m
.03006 .36095 L
s
[(150)] .01131 .36095 1 0 Mshowa
.02381 .47637 m
.03006 .47637 L
s
[(200)] .01131 .47637 1 0 Mshowa
.02381 .59178 m
.03006 .59178 L
s
[(250)] .01131 .59178 1 0 Mshowa
.125 Mabswid
.02381 .0378 m
.02756 .0378 L
s
.02381 .06088 m
.02756 .06088 L
s
.02381 .08396 m
.02756 .08396 L
s
.02381 .10705 m
.02756 .10705 L
s
.02381 .15321 m
.02756 .15321 L
s
.02381 .17629 m
.02756 .17629 L
s
.02381 .19938 m
.02756 .19938 L
s
.02381 .22246 m
.02756 .22246 L
s
.02381 .26862 m
.02756 .26862 L
s
.02381 .29171 m
.02756 .29171 L
s
.02381 .31479 m
.02756 .31479 L
s
.02381 .33787 m
.02756 .33787 L
s
.02381 .38404 m
.02756 .38404 L
s
.02381 .40712 m
.02756 .40712 L
s
.02381 .4302 m
.02756 .4302 L
s
.02381 .45328 m
.02756 .45328 L
s
.02381 .49945 m
.02756 .49945 L
s
.02381 .52253 m
.02756 .52253 L
s
.02381 .54561 m
.02756 .54561 L
s
.02381 .5687 m
.02756 .5687 L
s
.02381 .61486 m
.02756 .61486 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02753 .01472 m
.03125 .01702 L
.03497 .01933 L
.03869 .02164 L
.04241 .02395 L
.04613 .02626 L
.04985 .02856 L
.05357 .03087 L
.05729 .03318 L
.06101 .03549 L
.06473 .0378 L
.06845 .04011 L
.07217 .04241 L
.07589 .04472 L
.07961 .04703 L
.08333 .04934 L
.08705 .05165 L
.09077 .05396 L
.09449 .05626 L
.09821 .05857 L
.10193 .06088 L
.10565 .06319 L
.10937 .0655 L
.1131 .0678 L
.11682 .07011 L
.12054 .07242 L
.12426 .07473 L
.12798 .07704 L
.1317 .07935 L
.13542 .08165 L
.13914 .08396 L
.14286 .08627 L
.14658 .08858 L
.1503 .09089 L
.15402 .0932 L
.15774 .0955 L
.16146 .09781 L
.16518 .10012 L
.1689 .10243 L
.17262 .10474 L
.17634 .10705 L
.18006 .10935 L
.18378 .11166 L
.1875 .11397 L
.19122 .11628 L
.19494 .11859 L
.19866 .12089 L
.20238 .1232 L
.2061 .12551 L
.20982 .12782 L
Mistroke
.21354 .13013 L
.21726 .13244 L
.22098 .13474 L
.2247 .13705 L
.22842 .13936 L
.23214 .14167 L
.23586 .14398 L
.23958 .14629 L
.2433 .14859 L
.24702 .1509 L
.25074 .15321 L
.25446 .15552 L
.25818 .15783 L
.2619 .16013 L
.26563 .16244 L
.26935 .16475 L
.27307 .16706 L
.27679 .16937 L
.28051 .17168 L
.28423 .17398 L
.28795 .17629 L
.29167 .1786 L
.29539 .18091 L
.29911 .18322 L
.30283 .18553 L
.30655 .18783 L
.31027 .19014 L
.31399 .19245 L
.31771 .19476 L
.32143 .19707 L
.32515 .19938 L
.32887 .20168 L
.33259 .20399 L
.33631 .2063 L
.34003 .20861 L
.34375 .21092 L
.34747 .21322 L
.35119 .21553 L
.35491 .21784 L
.35863 .22015 L
.36235 .22246 L
.36607 .22477 L
.36979 .22707 L
.37351 .22938 L
.37723 .23169 L
.38095 .234 L
.38467 .23631 L
.38839 .23862 L
.39211 .24092 L
.39583 .24323 L
Mistroke
.39955 .24554 L
.40327 .60332 L
.40699 .60332 L
.41071 .60332 L
.41443 .60332 L
.41815 .60332 L
.42188 .60332 L
.4256 .60332 L
.42932 .60332 L
.43304 .60332 L
.43676 .60332 L
.44048 .60332 L
.4442 .60332 L
.44792 .60332 L
.45164 .60332 L
.45536 .60332 L
.45908 .60332 L
.4628 .60332 L
.46652 .60332 L
.47024 .60332 L
.47396 .60332 L
.47768 .29401 L
.4814 .29632 L
.48512 .29863 L
.48884 .30094 L
.49256 .30325 L
.49628 .30555 L
.5 .30786 L
.50372 .31017 L
.50744 .31248 L
.51116 .31479 L
.51488 .3171 L
.5186 .3194 L
.52232 .32171 L
.52604 .32402 L
.52976 .32633 L
.53348 .32864 L
.5372 .33095 L
.54092 .33325 L
.54464 .33556 L
.54836 .33787 L
.55208 .34018 L
.5558 .34249 L
.55952 .34479 L
.56324 .3471 L
.56696 .34941 L
.57068 .35172 L
.5744 .35403 L
.57813 .35634 L
.58185 .35864 L
Mistroke
.58557 .36095 L
.58929 .36326 L
.59301 .36557 L
.59673 .36788 L
.60045 .37019 L
.60417 .37249 L
.60789 .3748 L
.61161 .37711 L
.61533 .37942 L
.61905 .38173 L
.62277 .38404 L
.62649 .38634 L
.63021 .38865 L
.63393 .39096 L
.63765 .39327 L
.64137 .39558 L
.64509 .39788 L
.64881 .40019 L
.65253 .4025 L
.65625 .40481 L
.65997 .40712 L
.66369 .40943 L
.66741 .41173 L
.67113 .41404 L
.67485 .41635 L
.67857 .41866 L
.68229 .42097 L
.68601 .42328 L
.68973 .42558 L
.69345 .42789 L
.69717 .4302 L
.70089 .43251 L
.70461 .43482 L
.70833 .43712 L
.71205 .43943 L
.71577 .44174 L
.71949 .44405 L
.72321 .44636 L
.72693 .44867 L
.73065 .45097 L
.73438 .45328 L
.7381 .45559 L
.74182 .4579 L
.74554 .46021 L
.74926 .46252 L
.75298 .46482 L
.7567 .46713 L
.76042 .46944 L
.76414 .47175 L
.76786 .47406 L
Mistroke
.77158 .47637 L
.7753 .47867 L
.77902 .48098 L
.78274 .48329 L
.78646 .4856 L
.79018 .48791 L
.7939 .49021 L
.79762 .49252 L
.80134 .49483 L
.80506 .49714 L
.80878 .49945 L
.8125 .50176 L
.81622 .50406 L
.81994 .50637 L
.82366 .50868 L
.82738 .51099 L
.8311 .5133 L
.83482 .51561 L
.83854 .51791 L
.84226 .52022 L
.84598 .52253 L
.8497 .52484 L
.85342 .52715 L
.85714 .52945 L
.86086 .53176 L
.86458 .53407 L
.8683 .53638 L
.87202 .53869 L
.87574 .541 L
.87946 .5433 L
.88318 .54561 L
.8869 .54792 L
.89063 .55023 L
.89435 .55254 L
.89807 .55485 L
.90179 .55715 L
.90551 .55946 L
.90923 .56177 L
.91295 .56408 L
.91667 .56639 L
.92039 .5687 L
.92411 .571 L
.92783 .57331 L
.93155 .57562 L
.93527 .57793 L
.93899 .58024 L
.94271 .58254 L
.94643 .58485 L
.95015 .58716 L
.95387 .58947 L
Mistroke
.95759 .59178 L
.96131 .59409 L
.96503 .59639 L
.96875 .5987 L
.97247 .60101 L
.97619 .60332 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{216, 133.438},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003H0000QA000`40O003h00Of7oo000fOol00`00
Oomoo`02Ool00`00Oomoo`0IOol50002Ool00`00Oomoo`02Ool00`00Oomoo`0FOol50002Ool00`00
Oomoo`02Ool00`00Oomoo`0GOol30003Ool00`00Oomoo`02Ool00`00Oomoo`0GOol30003Ool00`00
Oomoo`02Ool00`00Oomoo`03Ool003Eoo`03001oo`00009oo`03001oo`0001aoo`07001oogooOol0
07oo00000Woo00<007oo00006Goo00L007ooOomoo`00Ool00002Ool00`00Ool0000HOol00`00Oomo
o`02Ool00`00Ool00002Ool00`00Ool0000HOol00`00Oomoo`02Ool00`00Ool00002Ool00`00Ool0
0004Ool003Moo`06001oogoo001oo`0077oo00L007ooOomoo`00Ool00002Ool00`00Ool0000IOol0
0`00Oomoo`03Ool01P00Oomoo`00Ool001Uoo`07001oogooOol007oo00000Woo00<007oo00006Goo
00<007ooOol00goo00H007ooOol007oo0004Ool003Eoo`8000=oo`03001oo`0001aoo`07001oogoo
Ool007oo00000Woo00<007oo00006Goo00@007ooOomoo`8000=oo`03001oo`0001Uoo`07001oogoo
Ool007oo00000Woo00<007oo00006Goo00@007ooOomoo`8000=oo`03001oo`0000Aoo`00=Goo00<0
07ooOol00Woo00<007oo000077oo00L007ooOomoo`00Ool00002Ool00`00Ool0000IOol01@00Oomo
ogoo000017oo00<007oo000067oo00<007oo00000Woo00<007oo00000Woo00<007oo000067oo00<0
07oo00000Woo00<007ooOol00Woo00<007oo000017oo000eOol30003Ool00`00Oomoo`0JOol20004
Ool00`00Oomoo`02Ool00`00Oomoo`0GOol20003Ool30003Ool00`00Oomoo`0HOol00`00Oomoo`02
Ool00`00Oomoo`02Ool00`00Oomoo`0HOol01000Oomoogoo0`000goo00<007ooOol00goo003HOol0
0=Qoo`0057oo00<007ooOol0`Goo000DOol00`00Oomoo`31Ool001Aoo`03001oogoo0<5oo`003goo
b@00000DOol01000Ool000000goo00<007ooOol01Goo00<007ooOol017oo00<007ooOol01Goo00<0
07ooOol017oo00<007ooOol017oo00<007ooOol01Goo00<007ooOol017oo00<007ooOol01Goo00<0
07ooOol017oo00<007ooOol01Goo00<007ooOol017oo00<007ooOol017oo00<007ooOol01Goo00<0
07ooOol017oo00<007ooOol01Goo00<007ooOol017oo00<007ooOol017oo00<007ooOol01Goo00<0
07ooOol017oo00<007ooOol01Goo00<007ooOol017oo00<007ooOol017oo00<007ooOol01Goo00<0
07ooOol017oo00<007ooOol01Goo0@000Goo0Goo000DOol01@00Oomoogoo0000_goo000DOol00`00
Oomoo`02Ool2002mOol001Aoo`03001oogoo00Aoo`03001oogoo0;Yoo`0057oo0P001Woo0`00^Goo
000DOol00`00Oomoo`07Ool2002hOol001Aoo`03001oogoo00Uoo`800;Ioo`0057oo00<007ooOol0
2Woo0P00]Goo000DOol2000=Ool2002cOol001Aoo`03001oogoo00eoo`<00;5oo`0057oo00<007oo
Ool047oo00<007ooOol0[Woo000DOol00`00Oomoo`0AOol2002^Ool001Aoo`03001oogoo019oo`80
0:eoo`0057oo0P005Goo0P00Zgoo000DOol00`00Oomoo`0EOol2002ZOol001Aoo`03001oogoo01Mo
o`800:Qoo`0057oo00<007ooOol06Goo0P00YWoo000DOol2000LOol00`00Oomoo`2SOol001Aoo`03
001oogoo01aoo`800:=oo`0057oo00<007ooOol07Woo00<007ooOol0X7oo000:Ool00`00Oomoo`02
Ool00`00Oomoo`02Ool00`00Oomoo`0OOol2002POol000Uoo`03001oo`00009oo`03001oo`0000=o
o`03001oogoo025oo`8009ioo`002goo00H007ooOol007oo0003Ool2000TOol2002LOol000Uoo`80
00=oo`03001oo`0000=oo`03001oogoo02Aoo`8009]oo`002Goo00<007ooOol00Woo00<007oo0000
0goo00<007ooOol09Woo0P00VGoo0009Ool30003Ool00`00Oomoo`02Ool00`00Oomoo`0WOol2002H
Ool001Aoo`03001oogoo02Uoo`03001oogoo09Eoo`0057oo0P00:goo0`00U7oo000DOol00`00Oomo
o`0/Ool2002COol001Aoo`03001oogoo02ioo`80095oo`0057oo00<007ooOol0;goo0P00T7oo000D
Ool2000bOol2002>Ool001Aoo`03001oogoo039oo`<008aoo`0057oo00<007ooOol0=Goo00<007oo
Ool0RGoo000DOol00`00Oomoo`0fOol20029Ool001Aoo`03001oogoo03Qoo`03001oogoo08Ioo`00
57oo0P00>Woo0P00QWoo000DOol00`00Oomoo`0kOol00`00Oomoo`23Ool001Aoo`03001oogoo03ao
o`8008=oo`0057oo00<007ooOol0?Woo0P00PGoo000DOol20011Ool00`00Oomoo`1nOol001Aoo`03
001oogoo045oo`8007ioo`0057oo00<007ooOol0@goo00<007ooOol0Ngoo0003Ool50002Ool00`00
Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`14Ool2001kOol000Eoo`07001oogooOol007oo0000
0Woo00<007oo00000goo00<007ooOol0AWoo0P00NGoo0005Ool01`00Oomoogoo001oo`00009oo`03
001oo`0000=oo`8004Uoo`03001oogoo07Ioo`001Goo00L007ooOomoo`00Ool00002Ool00`00Ool0
0003Ool00`00Oomoo`18Ool00`00Oomoo`1fOol000Eoo`07001oogooOol007oo00000Woo00<007oo
00000goo00<007ooOol0B7oo00<007ooOol0MWoo0004Ool20004Ool00`00Oomoo`02Ool00`00Oomo
o`02Ool00`00Oomoo`18Ool00`00Oomoo`1fOol001Aoo`03001oogoo04Qoo`03001oogoo07Ioo`00
57oo0P00BGoo00<007ooOol0MWoo000DOol00`00Oomoo`18Ool00`00Oomoo`1fOol001Aoo`03001o
ogoo04Qoo`03001oogoo07Ioo`0057oo00<007ooOol0B7oo00<007ooOol0MWoo000DOol20019Ool0
0`00Oomoo`1fOol001Aoo`03001oogoo04Qoo`03001oogoo00aoo`<006Moo`0057oo00<007ooOol0
B7oo00<007ooOol037oo00@007ooOol006Ioo`0057oo00<007ooOol0B7oo00<007ooOol037oo00@0
07ooOomoo`8006Aoo`0057oo00<007ooOol0B7oo00<007ooOol037oo00<007ooOol00goo00<007oo
Ool0HGoo000DOol20019Ool00`00Oomoo`0<Ool00`00Oomoo`04Ool2001QOol001Aoo`03001oogoo
04Qoo`03001oogoo00aoo`03001oogoo00Ioo`03001oogoo05ioo`0057oo00<007ooOol0B7oo00<0
07ooOol037oo00<007ooOol01goo0`00GGoo000DOol00`00Oomoo`18Ool00`00Oomoo`0<Ool00`00
Oomoo`09Ool2001LOol001Aoo`8004Uoo`03001oogoo00aoo`03001oogoo00]oo`8005Yoo`0057oo
00<007ooOol0B7oo00<007ooOol037oo00<007ooOol037oo0P00FGoo000DOol00`00Oomoo`18Ool0
0`00Oomoo`0<Ool00`00Oomoo`0>Ool00`00Oomoo`1FOol000=oo`D0009oo`03001oogoo009oo`03
001oogoo009oo`03001oogoo04Qoo`03001oogoo00aoo`03001oogoo00moo`8005Ioo`001Goo00L0
07ooOomoo`00Ool00002Ool00`00Ool00003Ool00`00Oomoo`18Ool00`00Oomoo`0<Ool00`00Oomo
o`0AOol2001DOol000Eoo`03001oogoo00=oo`06001oogoo001oo`000goo0P00BGoo00<007ooOol0
37oo00<007ooOol04goo0P00DWoo0005Ool01000Oomoogoo0P000goo00<007oo00000goo00<007oo
Ool0B7oo00<007ooOol037oo00<007ooOol057oo0P00DGoo0005Ool01@00Oomoogoo000017oo00<0
07oo00000goo00<007ooOol0B7oo00<007ooOol037oo00<007ooOol05Woo0P00Cgoo0004Ool20003
Ool30003Ool00`00Oomoo`02Ool00`00Oomoo`18Ool00`00Oomoo`0<Ool00`00Oomoo`0GOol2001>
Ool001Aoo`03001oogoo04Qoo`03001oogoo00aoo`03001oogoo01Uoo`8004aoo`0057oo0P00BGoo
00<007ooOol037oo00<007ooOol06Woo0`00BWoo000DOol00`00Oomoo`18Ool00`00Oomoo`0<Ool0
0`00Oomoo`0MOol00`00Oomoo`17Ool001Aoo`03001oogoo04Qoo`03001oogoo00aoo`03001oogoo
01ioo`8004Moo`0057oo00<007ooOol0B7oo00<007ooOol037oo00<007ooOol087oo00<007ooOol0
A7oo000DOol20019Ool00`00Oomoo`0<Ool00`00Oomoo`0QOol20014Ool001Aoo`03001oogoo04Qo
o`03001oogoo00aoo`03001oogoo029oo`<0049oo`0057oo00<007ooOol0B7oo00<007ooOol037oo
00<007ooOol09Goo00<007ooOol0?goo000DOol00`00Oomoo`18Ool00`00Oomoo`0<Ool00`00Oomo
o`0VOol2000oOol001Aoo`03001oogoo04Uoo`03001oogoo00]oo`03001oogoo02Qoo`03001oogoo
03aoo`0057oo0P00BWoo00<007ooOol02goo00<007ooOol0:Goo0P00?7oo000DOol00`00Oomoo`19
Ool00`00Oomoo`0;Ool00`00Oomoo`0[Ool00`00Oomoo`0iOol001Aoo`03001oogoo04Uoo`03001o
ogoo00]oo`03001oogoo02aoo`<003Qoo`0057oo00<007ooOol0BGoo00<007ooOol02goo00<007oo
Ool0;Woo0P00=goo000DOol2001:Ool00`00Oomoo`0;Ool00`00Oomoo`0`Ool2000eOol001Aoo`03
001oogoo04Uoo`03001oogoo00]oo`03001oogoo035oo`8003Aoo`0057oo00<007ooOol0BGoo00<0
07ooOol02goo00<007ooOol0<goo0P00<Woo0004Ool30003Ool00`00Oomoo`02Ool00`00Oomoo`02
Ool00`00Oomoo`19Ool00`00Oomoo`0;Ool00`00Oomoo`0dOol2000aOol000Aoo`03001oogoo009o
o`03001oo`00009oo`03001oo`0000=oo`03001oogoo04Uoo`03001oogoo00]oo`03001oogoo03Io
o`8002moo`001Goo00L007ooOomoo`00Ool00002Ool00`00Ool00003Ool2001:Ool00`00Oomoo`0;
Ool00`00Oomoo`0hOol2000]Ool000Eoo`07001oogooOol007oo00000Woo00<007oo00000goo00<0
07ooOol0BGoo00<007ooOol02goo00<007ooOol0>Goo0P00;7oo0004Ool00`00Ool00002Ool00`00
Ool00002Ool00`00Ool00003Ool00`00Oomoo`19Ool00`00Oomoo`0;Ool00`00Oomoo`0kOol2000Z
Ool000Eoo`03001oogoo009oo`03001oogoo009oo`03001oogoo009oo`03001oogoo04Uoo`03001o
ogoo00]oo`03001oogoo03aoo`8002Uoo`0057oo00<007ooOol0BGoo00<007ooOol02goo00<007oo
Ool0?Woo0P009goo000DOol2001:Ool00`00Oomoo`0;Ool00`00Oomoo`0oOol3000UOol001Aoo`03
001oogoo04Uoo`03001oogoo00]oo`03001oogoo049oo`03001oogoo029oo`0057oo00<007ooOol0
BGoo00<007ooOol02goo00<007ooOol0@goo0P008Woo000DOol00`00Oomoo`19Ool00`00Oomoo`0;
Ool00`00Oomoo`15Ool00`00Oomoo`0OOol001Aoo`8004Yoo`03001oogoo00]oo`03001oogoo04Io
o`8001moo`0057oo00<007ooOol0BGoo00<007ooOol02goo00<007ooOol0B7oo0P007Goo000DOol0
0`00Oomoo`19Ool00`00Oomoo`0;Ool00`00Oomoo`1:Ool2000KOol001Aoo`03001oogoo04Uoo`03
001oogoo00]oo`03001oogoo04]oo`8001Yoo`0057oo00<007ooOol0BGoo00<007ooOol02goo00<0
07ooOol0CGoo00<007ooOol05goo000DOol2001:Ool00`00Oomoo`0;Ool00`00Oomoo`1>Ool2000G
Ool001Aoo`03001oogoo04Uoo`03001oogoo00]oo`03001oogoo051oo`03001oogoo01Aoo`0057oo
00<007ooOol0BGoo00<007ooOol02goo00<007ooOol0DGoo0`004goo000DOol00`00Oomoo`19Ool0
0`00Oomoo`0;Ool00`00Oomoo`1COol2000BOol001Aoo`8004Yoo`03001oogoo00]oo`03001oogoo
05Eoo`80011oo`0057oo00<007ooOol0BGoo00<007ooOol02goo00<007ooOol0EWoo0P003goo000D
Ool00`00Oomoo`19Ool00`00Oomoo`0;Ool00`00Oomoo`1HOol2000=Ool000Aoo`<000=oo`03001o
ogoo009oo`03001oogoo009oo`03001oogoo04Uoo`03001oogoo00]oo`03001oogoo05Uoo`8000ao
o`0017oo00<007ooOol00Woo00<007oo00000Woo00<007oo00000goo00<007ooOol0BGoo00<007oo
Ool02goo00<007ooOol0Fgoo0P002Woo0005Ool00`00Oomoo`03Ool01P00Oomoo`00Ool000=oo`80
04Yoo`03001oogoo00]oo`03001oogoo05eoo`8000Qoo`001Goo00@007ooOomoo`8000=oo`03001o
o`0000=oo`03001oogoo04Uoo`03001oogoo00]oo`03001oogoo05moo`03001oogoo00Eoo`0017oo
00<007oo00000Woo00<007ooOol00Woo00<007oo00000goo00<007ooOol0BGoo3`00HWoo0P001Goo
0005Ool01000Oomoogoo0`000goo00<007ooOol00Woo00<007ooOol0`Goo000DOol20032Ool001Ao
o`03001oogoo0<5oo`00\
\>"],
  ImageRangeCache->{{{0, 215}, {132.438, 0}} -> {-27.6441, -25.7823, 1.34905, 
  2.17428}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Summary", "Subsection"],

Cell["\<\
Examples of the effect of selected point operations on the cell image are \
displayed below.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[
      GraphicsArray[
        Map[ListDensityPlot[#1, PlotRange \[Rule] {0, 255}, 
              DisplayFunction \[Rule] Identity]&, \n
          \t\t\t{{255 - B, \n\t\t\t\t
              ContrastModifyScale[ContrastModifyPower[B, 3], \ {0, 255}]}, \n
            \t\t\t{ContrastModifyLinear[
                B, {{0, 0}, {40, 10}, {150, 250}, {255, 255}}], \n\t\t\t\t
              ContrastModifyLinear[
                B, {{0, 0}, {100, 100}, {101, 255}, \n
                  \t\t\t{120, 255}, {121, 121}, {255, 255}}]}}, {2}]\n\t]]; 
    \)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0238095 0.47619 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0238095 0.477324 0.477324 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.015024 0.0192308 0.015024 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
64 string
64 64 8 [64 0 0 64 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
35313A3838353A38383A3C3A3A383A3A3C383C3338383538
3833382F35312F2F31312F2F31312D2D312F2F2D2F2F2F2D
31332F2A2F2A2A2A2A2D2A2A333A454D
353333333831353535383C3A383C3E3E3E38383A38353335
33313131312F2F2D2F332F2D2F312F2F2F31312F2F2D312F
2F312F2A2A2A282A2D2D2D2D2F384250
333535353835353A38383C383A3E3C3C3A38383535353835
3831333131332F2F2F2D312F31312F2D2D2A2D2F2F2F2F31
2F2F2F2F2F2F2D2F2F2F2F2D2F333E49
313533353C353A383E383A3E3C3C3E3E3E353A3838383831
33313333333333312F2F312F31312F332F2A2F312D31312D
2F2F2F312D2A2A2F2F2D312F2F313842
33353A3538383E3E403A383C403A403E3E3A3A383A383835
353533353531352D31313131312F3131312F2F33312F312D
2A2D2F312A2D282D2D2F312D2F33333C
383A3A3C3C38403C3C3A3C3E3E3E42403E3A3A3A3A383133
333331332D2D31312F312A312F312F2F2F2D2F2F2F2F312A
2D2D2F2D2F2A282A2F2D2F2F2F312F35
353C383C3C3E3A3E3C42403E424540423E3E3E3A38353333
333533333131313535353131312F2D2F2F2D2D2F2F31312F
2F2F312D2F2D2A2D2D2D2F312F313133
40423E3E3C403E42424247474747474742423C3A3C38352F
3A383538333131313335332D312F2A2D2A2D2F3133313133
312F2F2F2F2F2D2F2D2F2F312F312F2F
3A453E3C40454245424B5452545650494542403E3C383538
383538383331312F2D3333312D312D2A2F2D2F2F2F2F3131
2F312F31312D2D2F2D2F2F2F31313131
424242424242424B4D5B666C6C5F5B524547423E3C3A3833
33333835332F31312F3131312D2F2F2D2A2F31313333312F
31313131312F2F2F2F2F2F2F2F312D2F
4749424B494D4D5866757E868980735B54494542403A3838
333135333335313331333131312F2F3131352F3133353335
35333835332F3131333131313131312F
494D52505454566A778BA3BBB9AC9679635047423E35383C
3A3835353333312F35353131332A2F2F2F33313338353538
3A3A38383531312F31312F2F2F2F312D
5856585B686A737994B9DEF0F4F2CCA980664B493E403C3C
3535383338383335333331312F31312F2F313135383C3A3E
3C3C3838353533352F353333332F2F2F
686366707B798696BFEBFBFBFBFBFADEB77B5849473E3E3A
3A333333333333333131312F3133312F2F313538383E3C3E
3E3E3C383A383533333333332F2F2D2D
7979797B868691B7EDFBFCFCFCFCFBFBE79C685B4D423C35
3A353331333133332F3331313331333133353A3C42474B4B
4B47453E3E3C3A38353333312D2D2A28
848482868B94A1DEFBFCFCFCFCFCFCFBFBC2806C5F45403C
3535353131333135333133332F33313333353C424D585B5F
5D545049423E3C3C3833312F2D2A2A2D
868B8F9194A1B2FBFCFCFCFDFCFCFCFCFBDC91706A524238
3838383333313135312F3333332F3538353A42505F686E75
756C6158524B423C3838332F2D2D2A2A
8F9496969AA3CCFBFCFCFCFDFDFDFCFCFBEDA1806A50403C
3A38383333312F2F2F2F31312F33353A353A495D70777B80
807B736A5D52473E3A38312F2F2D2828
9E9EA19EA3B0D3FBFCFDFDFDFDFDFDFCFCEDA97B5D49423A
383535333131312F2F2F312F333335383540526A7B84898F
8F86827B735F5045403838332F2D2D28
9CA1A3A1ACB4D1FBFCFDFDFDFDFDFCFCFBFAA57352473E38
38383535332F312F2F3331312F31353A3C475870828D989E
989C9A91846C5B4B473E3838332F2A2A
A1A9ACB4C2C6CFFBFCFDFDFDFDFDFCFCFBFAA16C5645403C
3A383C352F312F333331333135353A3A404D667B8998ACAC
A7A7AEA794806C5D5049403833312A2A
A5A3B7CAE7E9E9FBFCFCFDFDFDFDFCFCFBDC8D6152453C3A
38383A38332F31333133332F313535383E50688091A1AEB4
B2B2B4B0A39886736150453A35312F2A
B7ACC6F4FBFBFBFBFBFCFCFCFCFCFCFBFBB97E63564D423E
3A3A3A383533313131333131333335383E526A8496A9BFC2
BFBFBFB9B7AEA38D755F493E35332D2A
CAB9F4FBFCFCFCFCFBFCFCFCFCFCFBFBD59C756C5F565042
3A3835353533333131332F313333333A3E4B68829AACBBC8
CACFCAC8BFBBAC9C846E544538312D2A
CFC8FBFCFCFCFCFCFCFBFBFBFBFBFBD5A7847070665F5445
3E3A3835383131332D312F313333353C404D687998B0BBCA
D3D5DAD3CCCAC2AE987E5F473A333128
DCDEFBFCFCFDFDFCFCFBFAF0EBDAC6A98B706E7568615450
3C38353835332D33312F312F2F33353A3E495F7791AEC4CF
D5DEDCD7DCD3CABDA58B664B3A352F26
E2E5FBFCFDFDFDFDFCFBEDCAB4B4A59179736C6E635F5D52
423A353833333131312F2F2D2D31333C3E4758738DB0CACF
D1DAE0EBE9D3CCC2B09873523E332F28
E7E2FBFCFDFDFCFCFCFBF0BDA59C8F84776C686A61615D54
493A38383531312F31312F2F2F33353A3E47526686AEC6D1
D1DCEBF0F0DCD1C8B49C7B583E38312A
D3D5FBFCFCFDFCFCFCFBE2A7988B867B796C6C66615F5856
493E38383333312F2F312F31313338383C4750668BB4C8D1
D5E2F0F6F2E2D3CABFA5825B40352F2D
C4B7EBFBFCFCFCFCFBFBCAA182827B797566665D5F5F584D
473C383533312D2D2F2D332F313335383A424B6186ACC4CC
D7E7F0F6F2E9D7C8BBA3825D42332F2A
B2A9CCF6FBFBFCFBFBE2B294807B7977756366615D5F5B52
423A35333331313131312F31313133353C404B5F84A3BFD1
DEEBF4F2E9E5DAC8B09E805D40352F2A
9E98A9BFDAE5F8F4DAB298867E7E75757561615D5B585450
42333833332D2A2D2F31312F2F3133383840495B7BA3BDCC
DCEBF0EDE2DCD5C6B49C79563E332D2A
8D8D98A3B4B7BFB29E968D827B797975705F5B5F5856544B
3C353833312D2D2F2F2F312F31313335383E475677A3BFCF
DEE9E9E9E2DCD1C4B09C73503C352D26
807E898D949898918D86807B777577736E66525254564B42
383331332F2F2D2A3133312F313333353A3C45526E9EBBCF
DCE5E0E5DCD3CCBDAE94684938312D26
757580827E8689847E707375706E736E665B52494D494238
3133312F2F2D2F2A2D31312F31353535383A424D6A98B9C8
D5DEE0DCCFC4BFB79C845D42352D2A28
6870737979807B77736E6166686A6C686152453E3A3A3A35
33333331312D2F2D332F2F2D31313533353A404B668DAEBF
CFD7D7CFC4B0A7A38D6E4D3C332A2828
58666C7370736C6E686154525863665D5445403C35383533
33353333312F2F2F31312F2F3133333335383E455B82A1BD
C8CCCABDB0968B82735B423531282826
475B666C6A68635F5D544745494B4D4B453C3A3535333333
3331312F2F2D312F2F2F2F3131313131333A3A3E506C8FA9
B9BFBDB09A806E6356473C332D2A2626
424D5D636A635B5250474240424245403C3838383131312F
332F312F2F2F2F2D312F31313333332F31353A3C495D7591
A1ACA79C866A5B4B453C38312D262626
3E4249545650474542403C3A3C3A3C3A38353533312F3131
332F2F2F31312F31332D2F31313535333338383C42506175
89968F86705B49403C35312D28262626
3E3E424747423E3E3E3A383838383A383335312F2F333131
2F2F312F2F2F2F31312F2F313333353531383A3A4045505D
6A79796E5D50403A38332F2A2A262626
3A3A3C3A3C3A3C383A3838383533383833312F312D2F3131
3131312F2D2D2D31312F2F3131313331333333383A3E454B
52565852493E383331312D2A2A282422
333835383C383538383335383338333331332F2F2F2F2F2F
2F2F332F2F2F2F2F2F2F2F313131313331313133353A3A40
42454745403A35332F2F282828282822
353535353A383533353535353535313333332F2F2F31312F
2F2F2F312F2F2F313131332F31332F3331333331353A3C3A
383C3A3A383A332D2F2A282626262424
33353335353535333131353333333131313533312D2F332F
2F2F2F312F2F2F312F31312F33312F33313333333535383A
383835353833312D2D2D2D2628262422
35333133333131313533353333312F2F312F31312D2D312F
2F2F2F332D2F312F312F33312F312F2F2F312F3331333338
33333533312F2F2D2A2A282626262422
33332F3133332F333335353131313131313331332F2F2D2F
2D2F2F312F312F2F2F31312F2D2A2F2F2F2D2A2F31313333
3331312F2D2D2D2D2828262626262424
2F33313333332F3131333131312F31312F2F2D312F2D2F31
2F2F2D2D2F2F2F2F2D2F312F2D2F2D2D2F2A2A2A312F2D2F
2F2A2F2F2D2A2A2D2A2A282626262624
2D3533333531313133312F31313131312F312F2F2F2F2F2F
2F2D2D2F2F2D2D2D2F312F2D2D2F2D2D312D2D2A2F2F2D2D
2F2D2F2A2A2A2A2A2628282824262422
31312F313331312F312F332F2F31313333332D2A2D2D2A2D
2F2F2D2F2F2F2A282D31282A2A2F2D2A2A2D2A2D2D2D2A2D
2D2A2A2A2D2828262826262424242222
312F2A333131312F313131332F3131312F332F2F2F2D2F2D
312F2D2A2D312A2A2D2D2D2D2D2D2D2D2A2A2A2F2F2D2D2D
2D2A2A2A282626262624262424242222
312D2F3131312F312F2F313131312F3131312F2F2F2F2F31
2D2A2A2A2D2D2D2D2A2D2D2F312D2D2D2D2A2D312D2D2F2D
2D282A28282828262622262424242222
33312F3331333131312D2F3131333333312F2D312F2D2A31
2F2F2A2A2F2F2D2D2A2D2A312F2F2A2A2D2A2D312D2F2F2D
2A2A2828262626262424242624242224
2F2F2F33332A312F2F2F2D312F3133312F2F2F2F2D2A2A31
2F2D2D2D2D2D2D2A282D2D2D2D2D2D2A2D2A2A2D2D2F2F2D
2D28262626262626262424242624221F
2D2F2D312F2D31312F2F2D2D2D2D2D2D2F2D2D2D2A2D2A2A
2D2F2D2D2A2F2A282A2A2A2A2D2D2A2A2828282D2A2D2A28
2828262626222224282424262424221F
2A2F2F2F2D2D312F2F2F2F2D2D2A2D2D2F2D2F2D282A2A2A
2D2D2F2A2A2A2A2D2826262A2A2A28282826282A2A2A2828
28262824242626282624262424242222
2A2F2F312D2F312D2F2F2F2F2F2F2F2F2F2F2D2A2A2A282D
2F2F2D2D2A2A2A2A2A282A2D2A2F2A28282A2A2A2A2A282A
28282624242828282626262824222224
2F2F2D312F2D2F2D2D2F2F2F2D2D312F312F2A282A282A2D
2A2D2D2D28282D282A26282A2A2F2D2D282D2D2D282D2A2A
28282822242624242426282626262222
2A3131332F2D2D2D2D2F2D312D2D2F2F2D2F2A2A2D2D282D
2A282A2A262428282A28282A2A2A2F2A2A2D2D2D2A2A2A28
26282424242424222428262424242422
2A2F2D312F2F2D2D2D2A2D2A2F2F2F2D2D2D2D2D2A2A282A
2A282828282628282A28282A2A2A2D2A2A2D2A2D2F2A2826
28282624242424222224242422222222
2D2F2A2D2F312F2F2F2D2D2D2D2D2F2D2D2A2A2D28282A2F
282D2A2A2A2828262A2D2A2A2A2A2D2A2A2A282A2D2D2826
28262426242624242426242422221F1F
2A2D2D2F2A2D2D2F2A2D2A2A2A2D2D2D2D2D2D2D2828282D
2D2A2A2A2A282A282A282A2A2A2D2A2D2D2D2A2A2D2D2A28
26262424242624222224242624242222
2D2D2D2F2A2D2D2D2A2A2A2A2D2A2D2D2A2F2A2A2A2A282A
282D2A2A2A2D2A282A282A2A2826282D2A2A2A2D2D2A2A28
26262426242424222222242422222222
2A2A2A2D2A2D2D2D2A2D2A2A2A2A282A282D2A2A28282A2D
2A2A2D2A2A2A282628282A2A2D2A2A2A2A28282D2D2D2D2A
28262624242424241F22222222222224
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0238095 0.97619 0.477324 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.015024 0.0192308 0.015024 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
64 string
64 64 8 [64 0 0 64 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
3C3A3E3D3D3C3E3D3D3E3F3E3E3D3E3E3F3D3F3B3D3D3C3D
3D3B3D393C3A39393A3A39393A3A38383A39393839393938
3A3B393739373737373837373B3E4347
3C3B3B3B3D3A3C3C3C3D3F3E3D3F4040403D3D3E3D3C3B3C
3B3A3A3A3A393938393B3938393A3939393A3A3939383A39
393A39373737363738383838393D4248
3B3C3C3C3D3C3C3E3D3D3F3D3E403F3F3E3D3D3C3C3C3D3C
3D3A3B3A3A3B393939383A393A3A3938383738393939393A
393939393939383939393938393B4045
3A3C3B3C3F3C3E3D403D3E403F3F4040403C3E3D3D3D3D3A
3B3A3B3B3B3B3B3A39393A393A3A393B3937393A383A3A38
3939393A3837373939383A39393A3D42
3B3C3E3C3D3D4040413E3D3F413E4140403E3E3D3E3D3D3C
3C3C3B3C3C3A3C383A3A3A3A3A393A3A3A39393B3A393A38
3738393A3738363838393A38393B3B3F
3D3E3E3F3F3D413F3F3E3F4040404241403E3E3E3E3D3A3B
3B3B3A3B38383A3A393A373A393A39393938393939393A37
383839383937363739383939393A393C
3C3F3D3F3F403E403F424140424341424040403E3D3C3B3B
3B3C3B3B3A3A3A3C3C3C3A3A3A39383939383839393A3A39
39393A38393837383838393A393A3A3B
414240403F414042424244444444444442423F3E3F3D3C39
3E3D3C3D3B3A3A3A3B3C3B383A3937383738393A3B3A3A3B
3A393939393938393839393A393A3939
3E43403F4143424342464A494A4B4845434241403F3D3C3D
3D3C3D3D3B3A3A39383B3B3A383A38373938393939393A3A
393A393A3A383839383939393A3A3A3A
4242424242424246474D5255554F4D49434442403F3E3D3B
3B3B3D3C3B393A3A393A3A3A3839393837393A3A3B3B3A39
3A3A3A3A3A39393939393939393A3839
444542464547474C52595D61625E584D4A454342413E3D3D
3B3A3C3B3B3C3A3B3A3B3A3A3A39393A3A3C393A3B3C3B3C
3C3B3D3C3B393A3A3B3A3A3A3A3A3A39
454749484A4A4B545A63FF79FFFFFF5B51484442403C3D3F
3E3D3C3C3B3B3A393C3C3A3A3B373939393B3A3B3D3C3C3D
3E3E3D3D3C3A3A393A3A393939393A38
4C4B4C4D5354585BFFFF8991939281FF5E52464540413F3F
3C3C3D3B3D3D3B3C3B3B3A3A393A3A39393A3A3C3D3F3E40
3F3F3D3D3C3C3B3C393C3B3B3B393939
535152575C5B61FF7B8F9BA3A6A19689FF5C4C454440403E
3E3B3B3B3B3B3B3B3A3A3A393A3B3A39393A3C3D3D403F40
40403F3D3E3D3C3B3B3B3B3B39393838
5B5B5B5C6161FFFF90A2AFADB4B1A99C8DFF534D47423F3C
3E3C3B3A3B3A3B3B393B3A3A3B3A3B3A3B3C3E3F42444646
46444340403F3E3D3C3B3B3A38383736
60605F6163FFFF89A1B0B8B9BCBAB3AA987C5E554F43413F
3C3C3C3A3A3B3A3C3B3A3B3B393B3A3B3B3C3F42474C4D4F
4E4A484542403F3F3D3B3A3938373738
6163FFFFFFFFFF98AEBBBDC3BFBEBBB1A288FF575449423D
3D3D3D3B3B3A3A3C3A393B3B3B393C3D3C3E42484F535659
5955504C4946423F3D3D3B3938383737
FFFFFFFFFFFF81A0B1BFC0C8C8C5BBB3AB90FF5E5448413F
3E3D3D3B3B3A393939393A3A393B3C3E3C3E454E575A5C5E
5E5C58544E4944403E3D3A3939383636
FFFFFFFFFFFF84A2BBC4C9CBC8C6C3B7AC90FF5C4E45423E
3D3C3C3B3A3A3A3939393A393B3B3C3D3C4149545C6062FF
FF615F5C584F4843413D3D3B39383836
FFFFFFFFFFFF83A6BCC5C7CBCAC6BFB7AA96FF584944403D
3D3D3C3C3B393A39393B3A3A393A3C3E3F444C575F64FFFF
FFFFFFFF60554D4644403D3D3B393737
FFFFFFFF7C7E829DB8C4C5CAC9C2BDB7A996FF554B43413F
3E3D3F3C393A393B3B3A3B3A3C3C3E3E4147525C62FFFFFF
FFFFFFFFFF5E554E4845413D3B3A3737
FFFFFF808D8E8E98ACBFC2C7C6C3BEB3A688645049433F3E
3D3D3E3D3B393A3B3A3B3B393A3C3C3D4048535EFFFFFFFF
FFFFFFFFFFFF61585048433E3C3A3937
FFFF7E93A6A5A59DA6B8BEC0C0B9B3AB9BFF5D514B474240
3E3E3E3D3C3B3A3A3A3B3A3A3B3B3C3D40495460FFFF7B7C
7B7B7BFFFFFFFF64594F45403C3B3837
80FF93A9B6B7B7B2ABADB6B2B8B5A89D85FF59554F4B4842
3E3D3C3C3C3B3B3A3A3B393A3B3B3B3E4046535FFFFF797F
8082807F7B79FFFF60564A433D3A3837
827F9DB1BBBDBFB8B3A1A3A8A89F9785FF605757524F4A43
403E3D3C3D3A3A3B383A393A3B3B3C3F4147535BFFFF7980
8485878481807CFFFF5D4F443E3B3A36
8889A7B8BFC4C6BEB7A996918F877EFF6357565953504A48
3F3D3C3D3C3B383B3A393A39393B3C3E40454F5AFFFF7D82
858988868884807AFF6352463E3C3935
8B8CA9B7C1C7C6C2BAAB9080FFFFFFFF5B585556514F4E49
423E3C3D3B3B3A3A3A393938383A3B3F40444C5864FF8082
83878A8F8E84817CFFFF5849403B3936
8D8BAABAC4CAC0BDB8AB917AFFFFFF605A55535450504E4A
453E3D3D3C3A3A393A3A3939393B3C3E4044495261FF7E83
83888F919188837FFFFF5C4C403D3A37
84859FB7BEC2BEB7B3A98BFFFF63615C5B555552504F4C4B
45403D3D3B3B3A39393A393A3A3B3D3D3F44485263FF7F83
858B9194928B84807BFF5F4D413C3938
7DFF8FAAB3B6B6B4AB9D80FF5F5F5C5B5952524E4F4F4C47
443F3D3C3B3A383839383B393A3B3C3D3E42465061FF7D81
868D9194928E867F79FF5F4E423B3937
FFFF8194A1A9ADA89F8BFFFF5E5C5B5A595152504E4F4D49
423E3C3B3B3A3A3A3A3A393A3A3A3B3C3F41464F60FF7B83
898F93928E8C877FFFFF5E4E413C3937
FFFFFF7B878C959387FFFF615D5D59595950504E4D4C4A48
423B3D3B3B383738393A3A39393A3B3D3D41454D5CFF7A81
888F91908B88857EFFFF5B4B403B3837
6464FFFFFFFF7BFFFFFF645F5C5B5B59574F4D4F4C4B4A46
3F3C3D3B3A38383939393A393A3A3B3C3D40444B5AFF7B82
898E8E8E8B88837DFFFF58483F3C3835
5E5D6264FFFFFFFF64615E5C5A595A58565249494A4B4642
3D3B3A3B393938373A3B3A393A3B3B3C3E3F434956FF7982
888C8A8C8884817AFFFF53453D3A3835
59595E5F5D6162605D57585957565856524D49454745423D
3A3B3A3939383937383A3A393A3C3C3C3D3E424754FFFF7F
85898A88827D7BFFFF604E423C383736
5357585B5B5E5C5A5856505253545553504943403E3E3E3C
3B3B3B3A3A3839383B3939383A3A3C3B3C3E41465264FF7B
828686827DFFFFFF6456473F3B373636
4C5255585758555653504A494C51524E4A43413F3C3D3C3B
3B3C3B3B3A3939393A3A39393A3B3B3B3C3D40434D5FFF7A
7F81807AFFFF635F584D423C3A363635
444D52555453514F4E4A444345464746433F3E3C3C3B3B3B
3B3A3A3939383A393939393A3A3A3A3A3B3E3E404855FFFF
FF7B7AFFFF5E56514B443F3B38373535
42474E5154514D4948444241424243413F3D3D3D3A3A3A39
3B393A39393939383A393A3A3B3B3B393A3C3E3F454E59FF
FFFFFFFF61544D46433F3D3A38353535
4042454A4B48444342413F3E3F3E3F3E3D3C3C3B3A393A3A
3B3939393A3A393A3B38393A3A3C3C3B3B3D3D3F42485059
62FFFF61574D45413F3C3A3836353535
4040424444424040403E3D3D3D3D3E3D3B3C3A39393B3A3A
39393A393939393A3A39393A3B3B3C3C3A3D3E3E4143484E
545B5B564E48413E3D3B393737353535
3E3E3F3E3F3E3F3D3E3D3D3D3C3B3D3D3B3A393A38393A3A
3A3A3A393838383A3A39393A3A3A3B3A3B3B3B3D3E404346
494B4C4945403D3B3A3A383737363433
3B3D3C3D3F3D3C3D3D3B3C3D3B3D3B3B3A3B393939393939
39393B39393939393939393A3A3A3A3B3A3A3A3B3C3E3E41
42434443413E3C3B3939363636363633
3C3C3C3C3E3D3C3B3C3C3C3C3C3C3A3B3B3B3939393A3A39
3939393A3939393A3A3A3B393A3B393B3A3B3B3A3C3E3F3E
3D3F3E3E3D3E3B383937363535353434
3B3C3B3C3C3C3C3B3A3A3C3B3B3B3A3A3A3C3B3A38393B39
3939393A3939393A393A3A393B3A393B3A3B3B3B3C3C3D3E
3D3D3C3C3D3B3A383838383536353433
3C3B3A3B3B3A3A3A3C3B3C3B3B3A39393A393A3A38383A39
3939393B38393A393A393B3A393A3939393A393B3A3B3B3D
3B3B3C3B3A3939383737363535353433
3B3B393A3B3B393B3B3C3C3A3A3A3A3A3A3B3A3B39393839
3839393A393A3939393A3A3938373939393837393A3A3B3B
3B3A3A39383838383636353535353434
393B3A3B3B3B393A3A3B3A3A3A393A3A3939383A3938393A
393938383939393938393A3938393838393737373A393839
39373939383737383737363535353534
383C3B3B3C3A3A3A3B3A393A3A3A3A3A393A393939393939
3938383939383838393A3938383938383A38383739393838
39383937373737373536363634353433
3A3A393A3B3A3A393A393B39393A3A3B3B3B383738383738
3939383939393736383A3637373938373738373838383738
38373737383636353635353434343333
3A39373B3A3A3A393A3A3A3B393A3A3A393B393939383938
3A393837383A373738383838383838383737373939383838
38373737363535353534353434343333
3A38393A3A3A393A39393A3A3A3A393A3A3A39393939393A
3837373738383838373838393A3838383837383A38383938
38363736363636353533353434343333
3B3A393B3A3B3A3A3A38393A3A3B3B3B3A39383A3938373A
39393737393938383738373A393937373837383A38393938
37373636353535353434343534343334
3939393B3B373A393939383A393A3B3A393939393837373A
393838383838383736383838383838373837373838393938
38363535353535353534343435343332
3839383A39383A3A39393838383838383938383837383737
383938383739373637373737383837373636363837383736
36363535353333343634343534343332
3739393938383A3939393938383738383938393836373737
383839373737373836353537373736363635363737373636
36353634343535363534353434343333
3739393A38393A3839393939393939393939383737373638
393938383737373737363738373937363637373737373637
36363534343636363535353634333334
3939383A393839383839393938383A393A39373637363738
373838383636383637353637373938383638383836383737
36363633343534343435363535353333
373A3A3B393838383839383A383839393839373738383638
373637373534363637363637373739373738383837373736
35363434343434333436353434343433
3739383A3939383838373837393939383838383837373637
373636363635363637363637373738373738373839373635
36363534343434333334343433333333
38393738393A393939383838383839383837373836363739
363837373736363537383737373738373737363738383635
36353435343534343435343433333232
373838393738383937383737373838383838383836363638
383737373736373637363737373837383838373738383736
35353434343534333334343534343333
383838393738383837373737383738383739373737373637
363837373738373637363737363536383737373838373736
35353435343434333333343433333333
373737383738383837383737373736373638373736363738
373738373737363536363737383737373736363838383837
36353534343434343233333333333334
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.522676 0.477324 0.97619 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.015024 0.0192308 0.015024 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
64 string
64 64 8 [64 0 0 64 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
C3C5C1C2C2C3C1C2C2C1C0C1C1C2C1C1C0C2C0C4C2C2C3C2
C2C4C2C6C3C5C6C6C5C5C6C6C5C5C7C7C5C6C6C7C6C6C6C7
C5C4C6C8C6C8C8C8C8C7C8C8C4C1BCB8
C3C4C4C4C2C5C3C3C3C2C0C1C2C0BFBFBFC2C2C1C2C3C4C3
C4C5C5C5C5C6C6C7C6C4C6C7C6C5C6C6C6C5C5C6C6C7C5C6
C6C5C6C8C8C8C9C8C7C7C7C7C6C2BDB7
C4C3C3C3C2C3C3C1C2C2C0C2C1BFC0C0C1C2C2C3C3C3C2C3
C2C5C4C5C5C4C6C6C6C7C5C6C5C5C6C7C7C8C7C6C6C6C6C5
C6C6C6C6C6C6C7C6C6C6C6C7C6C4BFBA
C5C3C4C3C0C3C1C2BFC2C1BFC0C0BFBFBFC3C1C2C2C2C2C5
C4C5C4C4C4C4C4C5C6C6C5C6C5C5C6C4C6C8C6C5C7C5C5C7
C6C6C6C5C7C8C8C6C6C7C5C6C6C5C2BD
C4C3C1C3C2C2BFBFBEC1C2C0BEC1BEBFBFC1C1C2C1C2C2C3
C3C3C4C3C3C5C3C7C5C5C5C5C5C6C5C5C5C6C6C4C5C6C5C7
C8C7C6C5C8C7C9C7C7C6C5C7C6C4C4C0
C2C1C1C0C0C2BEC0C0C1C0BFBFBFBDBEBFC1C1C1C1C2C5C4
C4C4C5C4C7C7C5C5C6C5C8C5C6C5C6C6C6C7C6C6C6C6C5C8
C7C7C6C7C6C8C9C8C6C7C6C6C6C5C6C3
C3C0C2C0C0BFC1BFC0BDBEBFBDBCBEBDBFBFBFC1C2C3C4C4
C4C3C4C4C5C5C5C3C3C3C5C5C5C6C7C6C6C7C7C6C6C5C5C6
C6C6C5C7C6C7C8C7C7C7C6C5C6C5C5C4
BEBDBFBFC0BEBFBDBDBDBBBBBBBBBBBBBDBDC0C1C0C2C3C6
C1C2C3C2C4C5C5C5C4C3C4C7C5C6C8C7C8C7C6C5C4C5C5C4
C5C6C6C6C6C6C7C6C7C6C6C5C6C5C6C6
C1BCBFC0BEBCBDBCBDB9B5B6B5B4B7BABCBDBEBFC0C2C3C2
C2C3C2C2C4C5C5C6C7C4C4C5C7C5C7C8C6C7C6C6C6C6C5C5
C6C5C6C5C5C7C7C6C7C6C6C6C5C5C5C5
BDBDBDBDBDBDBDB9B8B2ADAAAAB0B2B6BCBBBDBFC0C1C2C4
C4C4C2C3C4C6C5C5C6C5C5C5C7C6C6C7C8C6C5C5C4C4C5C6
C5C5C5C5C5C6C6C6C6C6C6C6C6C5C7C6
BBBABDB9BAB8B8B3ADA6A29E9DA1A7B2B5BABCBDBEC1C2C2
C4C5C3C4C4C3C5C4C5C4C5C5C5C6C6C5C5C3C6C5C4C3C4C3
C3C4C2C3C4C6C5C5C4C5C5C5C5C5C5C6
BAB8B6B7B5B5B4ABA59C9186878D97A4AEB7BBBDBFC3C2C0
C1C2C3C3C4C4C5C6C3C3C5C5C4C8C6C6C6C4C5C4C2C3C3C2
C1C1C2C2C3C5C5C6C5C5C6C6C6C6C5C7
B3B4B3B2ACABA7A49887766E6C6D7E8EA1ADB9BABFBEC0C0
C3C3C2C4C2C2C4C3C4C4C5C5C6C5C5C6C6C5C5C3C2C0C1BF
C0C0C2C2C3C3C4C3C6C3C4C4C4C6C6C6
ACAEADA8A3A49E978470645C595E697688A3B3BABBBFBFC1
C1C4C4C4C4C4C4C4C5C5C5C6C5C4C5C6C6C5C3C2C2BFC0BF
BFBFC0C2C1C2C3C4C4C4C4C4C6C6C7C7
A4A4A4A39E9E99886F5D50524B4E56637294ACB2B8BDC0C3
C1C3C4C5C4C5C4C4C6C4C5C5C4C5C4C5C4C3C1C0BDBBB9B9
B9BBBCBFBFC0C1C2C3C4C4C5C7C7C8C9
9F9FA09E9C9892765E4F474643454C556783A1AAB0BCBEC0
C3C3C3C5C5C4C5C3C4C5C4C4C6C4C5C4C4C3C0BDB8B3B2B0
B1B5B7BABDBFC0C0C2C4C5C6C7C8C8C7
9E9C9A9998928A675144423C4041444E5D7799A8ABB6BDC2
C2C2C2C4C4C5C5C3C5C6C4C4C4C6C3C2C3C1BDB7B0ACA9A6
A6AAAFB3B6B9BDC0C2C2C4C6C7C7C8C8
9A98979795917E5F4E403F37373A444C546F92A1ABB7BEC0
C1C2C2C4C4C5C6C6C6C6C5C5C6C4C3C1C3C1BAB1A8A5A3A1
A1A3A7ABB1B6BBBFC1C2C5C6C6C7C9C9
93939293918B7B5D443B363437393C48536F8EA3B1BABDC1
C2C3C3C4C5C5C5C6C6C6C5C6C4C4C3C2C3BEB6ABA39F9D9A
9A9EA0A3A7B0B7BCBEC2C2C4C6C7C7C9
949291928D897C59433A383435394048556990A7B6BBBFC2
C2C2C3C3C4C6C5C6C6C4C5C5C6C5C3C1C0BBB3A8A09B9693
969495999FAAB2B9BBBFC2C2C4C6C8C8
928E8D8983817D62473B3A35363D4248566992AAB4BCBEC0
C1C2C0C3C6C5C6C4C4C5C4C5C3C3C1C1BEB8ADA39D968D8D
8F8F8C8F98A1AAB1B7BABEC2C4C5C8C8
9091887F7271716753403D38393C414C59779BAFB6BCC0C1
C2C2C1C2C4C6C5C4C5C4C4C6C5C3C3C2BFB7ACA199928C89
8A8A898B91969EA7AFB7BCC1C3C5C6C8
888D816C595A5A625947413F3F464C546487A2AEB4B8BDBF
C1C1C1C2C3C4C5C5C5C4C5C5C4C4C3C2BFB6AB9F978E8483
84848487888C919BA6B0BABFC3C4C7C8
7F876C564948484D5452494D474A57627A94A6AAB0B4B7BD
C1C2C3C3C3C4C4C5C5C4C6C5C4C4C4C1BFB9ACA0958D8680
7F7D7F8084868D949FA9B5BCC2C5C7C8
7D80624E444240474C5E5C575760687A8F9FA8A8ADB0B5BC
BFC1C2C3C2C5C5C4C7C5C6C5C4C4C3C0BEB8ACA4968B867F
7B7A787B7E7F838C96A2B0BBC1C4C5C9
77765847403B39414856696E7078818E9CA8A9A6ACAFB5B7
C0C2C3C2C3C4C7C4C5C6C5C6C6C4C3C1BFBAB0A5998C827D
7A767779777B7F85909CADB9C1C3C6CA
747356483E38393D45546F7F89899099A4A7AAA9AEB0B1B6
BDC1C3C2C4C4C5C5C5C6C6C7C7C5C4C0BFBBB3A79B8B7F7D
7C787570717B7E838B96A7B6BFC4C6C9
727455453B353F4247546E8590949A9FA5AAACABAFAFB1B5
BAC1C2C2C3C5C5C6C5C5C6C6C6C4C3C1BFBBB6AD9E8C817C
7C77706E6E777C808994A3B3BFC2C5C8
7B7A6048413D41484C56748F969C9EA3A4AAAAADAFB0B3B4
BABFC2C2C4C4C5C6C6C5C6C5C5C4C2C2C0BBB7AD9C89807C
7A746E6B6D747B7F8490A0B2BEC3C6C7
828870554C49494B54627F92A0A0A3A4A6ADADB1B0B0B3B8
BBC0C2C3C4C5C7C7C6C7C4C6C5C4C3C2C1BDB9AF9E8D827E
79726E6B6D7179808691A0B1BDC4C6C8
8A8E7E6B5E56525760748A98A1A3A4A5A6AEADAFB1B0B2B6
BDC1C3C4C4C5C5C5C5C5C6C5C5C5C4C3C0BEB9B09F91847C
76706C6D717378808B93A1B1BEC3C6C8
93968E8478736A6C788A969EA2A2A6A6A6AFAFB1B2B3B5B7
BDC4C2C4C4C7C8C7C6C5C5C6C6C5C4C2C2BEBAB2A391857E
77706E6F74777A818994A4B4BFC4C7C8
9B9B96918988848A93979BA0A3A4A4A6A8B0B2B0B3B4B5B9
C0C3C2C4C5C7C7C6C6C6C5C6C5C5C4C3C2BFBBB4A591847D
7671717174777C828B94A7B7C0C3C7CA
A1A29D9B989696999B9EA1A3A5A6A5A7A9ADB6B6B5B4B9BD
C2C4C5C4C6C6C7C8C5C4C5C6C5C4C4C3C1C0BCB6A993867D
77737573777B7E858C98ACBAC2C5C7CA
A6A6A1A0A29E9D9FA2A8A7A6A8A9A7A9ADB2B6BAB8BABDC2
C5C4C5C6C6C7C6C8C7C5C5C6C5C3C3C3C2C1BDB8AB968780
7A7675777D828488949FB1BDC3C7C8C9
ACA8A7A4A4A1A3A5A7A9AFADACABAAACAFB6BCBFC1C1C1C3
C4C4C4C5C5C7C6C7C4C6C6C7C5C5C3C4C3C1BEB9AD9B8C84
7D79797D828B8F919BA9B8C0C4C8C9C9
B3ADAAA7A8A7AAA9ACAFB5B6B3AEADB1B5BCBEC0C3C2C3C4
C4C3C4C4C5C6C6C6C5C5C6C6C5C4C4C4C3C2BFBCB2A09285
807E7F858B979CA0A7B2BDC3C5C9C9CA
BBB2ADAAABACAEB0B1B5BBBCBAB9B8B9BCC0C1C3C3C4C4C4
C4C5C5C6C6C7C5C6C6C6C6C5C5C5C5C5C4C1C1BFB7AA9A8E
8784858B95A1A9AEB4BBC0C4C7C8CACA
BDB8B1AEABAEB2B6B7BBBDBEBDBDBCBEC0C2C2C2C5C5C5C6
C4C6C5C6C6C6C6C7C5C6C5C5C4C4C4C6C5C3C1C0BAB1A699
928D8F949EABB2B9BCC0C2C5C7CACACA
BFBDBAB5B4B7BBBCBDBEC0C1C0C1C0C1C2C3C3C4C5C6C5C5
C4C6C6C6C5C5C6C5C4C7C6C5C5C3C3C4C4C2C2C0BDB7AFA6
9D979A9EA8B2BABEC0C3C5C7C9CACACA
BFBFBDBBBBBDBFBFBFC1C2C2C2C2C1C2C4C3C5C6C6C4C5C5
C6C6C5C6C6C6C6C5C5C6C6C5C4C4C3C3C5C2C1C1BEBCB7B1
ABA4A4A9B1B7BEC1C2C4C6C8C8CACACA
C1C1C0C1C0C1C0C2C1C2C2C2C3C4C2C2C4C5C6C5C7C6C5C5
C5C5C5C6C7C7C7C5C5C6C6C5C5C5C4C5C4C4C4C2C1BFBCB9
B6B4B3B6BABFC2C4C5C5C7C8C8C9CBCC
C4C2C3C2C0C2C3C2C2C4C3C2C4C2C4C4C5C4C6C6C6C6C6C6
C6C6C4C6C6C6C6C6C6C6C6C5C5C5C5C4C5C5C5C4C3C1C1BE
BDBCBBBCBEC1C3C4C6C6C9C9C9C9C9CC
C3C3C3C3C1C2C3C4C3C3C3C3C3C3C5C4C4C4C6C6C6C5C5C6
C6C6C6C5C6C6C6C5C5C5C4C6C5C4C6C4C5C4C4C5C3C1C0C1
C2C0C1C1C2C1C4C7C6C8C9CACACACBCB
C4C3C4C3C3C3C3C4C5C5C3C4C4C4C5C5C5C3C4C5C7C6C4C6
C6C6C6C5C6C6C6C5C6C5C5C6C4C5C6C4C5C4C4C4C3C3C2C1
C2C2C3C3C2C4C5C7C7C7C7CAC9CACBCC
C3C4C5C4C4C5C5C5C3C4C3C4C4C5C6C6C5C6C5C5C7C7C5C6
C6C6C6C4C7C6C5C6C5C6C4C5C6C5C6C6C6C5C6C4C5C4C4C2
C4C4C3C4C5C6C6C7C8C8C9CACACACBCC
C4C4C6C5C4C4C6C4C4C3C3C5C5C5C5C5C5C4C5C4C6C6C7C6
C7C6C6C5C6C5C6C6C6C5C5C6C7C8C6C6C6C7C8C6C5C5C4C4
C4C5C5C6C7C7C7C7C9C9CACACACACBCB
C6C4C5C4C4C4C6C5C5C4C5C5C5C6C5C5C6C6C7C5C6C7C6C5
C6C6C7C7C6C6C6C6C7C6C5C6C7C6C7C7C6C8C8C8C5C6C7C6
C6C8C6C6C7C8C8C7C8C8C9CACACACACB
C7C3C4C4C3C5C5C5C4C5C6C5C5C5C5C5C6C5C6C6C6C6C6C6
C6C7C7C6C6C7C7C7C6C5C6C7C7C6C7C7C5C7C7C8C6C6C7C7
C6C7C6C8C8C8C8C8CAC9C9C9CBCACBCC
C5C5C6C5C4C5C5C6C5C6C4C6C6C5C5C4C4C4C7C8C7C7C8C7
C6C6C7C6C6C6C8C9C7C5C9C8C8C6C7C8C8C7C8C7C7C7C8C7
C7C8C8C8C7C9C9CAC9CACACBCBCBCCCC
C5C6C8C4C5C5C5C6C5C5C5C4C6C5C5C5C6C4C6C6C6C7C6C7
C5C6C7C8C7C5C8C8C7C7C7C7C7C7C7C7C8C8C8C6C6C7C7C7
C7C8C8C8C9CACACACACBCACBCBCBCCCC
C5C7C6C5C5C5C6C5C6C6C5C5C5C5C6C5C5C5C6C6C6C6C6C5
C7C8C8C8C7C7C7C7C8C7C7C6C5C7C7C7C7C8C7C5C7C7C6C7
C7C9C8C9C9C9C9CACACCCACBCBCBCCCC
C4C5C6C4C5C4C5C5C5C7C6C5C5C4C4C4C5C6C7C5C6C7C8C5
C6C6C8C8C6C6C7C7C8C7C8C5C6C6C8C8C7C8C7C5C7C6C6C7
C8C8C9C9CACACACACBCBCBCACBCBCCCB
C6C6C6C4C4C8C5C6C6C6C7C5C6C5C4C5C6C6C6C6C7C8C8C5
C6C7C7C7C7C7C7C8C9C7C7C7C7C7C7C8C7C8C8C7C7C6C6C7
C7C9CACACACACACACACBCBCBCACBCCCD
C7C6C7C5C6C7C5C5C6C6C7C7C7C7C7C7C6C7C7C7C8C7C8C8
C7C6C7C7C8C6C8C9C8C8C8C8C7C7C8C8C9C9C9C7C8C7C8C9
C9C9CACACACCCCCBC9CBCBCACBCBCCCD
C8C6C6C6C7C7C5C6C6C6C6C7C7C8C7C7C6C7C6C7C9C8C8C8
C7C7C6C8C8C8C8C7C9CACAC8C8C8C9C9C9CAC9C8C8C8C9C9
C9CAC9CBCBCACAC9CACBCACBCBCBCCCC
C8C6C6C5C7C6C5C7C6C6C6C6C6C6C6C6C6C6C7C8C8C8C9C7
C6C6C7C7C8C8C8C8C8C9C8C7C8C6C8C9C9C8C8C8C8C8C9C8
C9C9CACBCBC9C9C9CACACAC9CBCCCCCB
C6C6C7C5C6C7C6C7C7C6C6C6C7C7C5C6C5C6C8C9C8C9C8C7
C8C7C7C7C9C9C7C9C8CAC9C8C8C6C7C7C9C7C7C7C9C7C8C8
C9C9C9CCCBCACBCBCBCAC9CACACACCCC
C8C5C5C4C6C7C7C7C7C6C7C5C7C7C6C6C7C6C8C8C7C7C9C7
C8C9C8C8CACBC9C9C8C9C9C8C8C8C6C8C8C7C7C7C8C8C8C9
CAC9CBCBCBCBCBCCCBC9CACBCBCBCBCC
C8C6C7C5C6C6C7C7C7C8C7C8C6C6C6C7C7C7C7C7C8C8C9C8
C8C9C9C9C9CAC9C9C8C9C9C8C8C8C7C8C8C7C8C7C6C8C9CA
C9C9CACBCBCBCBCCCCCBCBCBCCCCCCCC
C7C6C8C7C6C5C6C6C6C7C7C7C7C7C6C7C7C8C8C7C9C9C8C6
C9C7C8C8C8C9C9CAC8C7C8C8C8C8C7C8C8C8C9C8C7C7C9CA
C9CACBCACBCACBCBCBCACBCBCCCCCDCD
C8C7C7C6C8C7C7C6C8C7C8C8C8C7C7C7C7C7C7C7C9C9C9C7
C7C8C8C8C8C9C8C9C8C9C8C8C8C7C8C7C7C7C8C8C7C7C8C9
CACACBCBCBCACBCCCCCBCBCACBCBCCCC
C7C7C7C6C8C7C7C7C8C8C8C8C7C8C7C7C8C6C8C8C8C8C9C8
C9C7C8C8C8C7C8C9C8C9C8C8C9CAC9C7C8C8C8C7C7C8C8C9
CACACBCACBCBCBCCCCCCCBCBCCCCCCCC
C8C8C8C7C8C7C7C7C8C7C8C8C8C8C9C8C9C7C8C8C9C9C8C7
C8C8C7C8C8C8C9CAC9C9C8C8C7C8C8C8C8C9C9C7C7C7C7C8
C9CACACBCBCBCBCBCDCCCCCCCCCCCCCB
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.522676 0.97619 0.97619 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.015024 0.0192308 0.015024 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
64 string
64 64 8 [64 0 0 64 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
020203030302030303030303030303030303030203030203
030203010202010102020101020201010201010101010101
02020101010101010101010102030507
020202020302020202030303030304040403030303020202
020202020201010101020101010201010102020101010201
01020101010100010101010101030407
020202020302020303030303030403030303030202020302
030202020202010101010201020201010101010101010102
01010101010101010101010101020406
020202020302030304030304030304040402030303030302
020202020202020201010201020201020101010201020201
01010102010101010101020101020304
020203020303040404030303040304040403030303030302
020202020202020102020202020102020201010202010201
01010102010100010101020101020203
030303030303040303030304040404040403030303030202
020202020101020201020102010201010101010101010201
01010101010100010101010101020102
020303030304030403040404040504040404040303020202
020202020202020202020202020101010101010101020201
01010201010101010101010201020202
040404040304040404040505050505050404030303030201
030302030202020202020201020101010101010202020202
02010101010101010101010201020101
030504030405040504060808080907060504040403030203
030203030202020101020202010201010101010101010202
01020102020101010101010102020202
0404040404040406070A0D0E0E0B0A080505040403030302
020203020201020201020202010101010101020202020201
02020202020101010101010101020101
05060406060707090D1114181815110A0806050404030303
020202020202020202020202020101020202010202020202
02020302020102020202020202020201
060708070808090E1219243231291E130C07050404020303
030302020202020102020202020101010102020203020203
03030303020202010202010101010201
0909090A0D0E11131D314A595D5B3D28150D060604040303
020203020303020202020202010202010102020203030304
03030303020202020102020202010101
0D0C0D101413181E35556E80887B634A2F14090605040403
030202020202020202020201020202010102020303040304
04040303030302020202020201010101
1313131418181C2F577EA09AAEA58F7051210D0A07040302
030202020202020201020202020202020202030304050606
06050504040303030202020201010100
17171618191D234A7BA3BABDC7C1AB926736150E0B050403
020202020202020202020202010202020202030407090A0B
0A080706040403030302020101010101
18191B1C1D232D679DC4CADFD1CEC4A57E491C100E080403
03030302020202020201020202010203020304070B0D0F11
110E0B09080604030303020101010101
1B1D1E1E20243D79A5D1D4F0F0E6C4AB955723150E070403
030303020202010101010202010202030203060A10121415
1514110E0A0805040303020101010000
22222322242B427EC4E2F4FCF0E9DFB7975728140A060403
030202020202020101010201020202030204080E1417181B
1B181614110B07050403030201010100
21232423292E4088C7E6EDFCF8E9D1B79263261108050403
0303020202010201010202020102020303050910161A1F22
1F21201C170E0A060504030302010101
2328292E36393F72BAE2E6F8F4DBCAB78F63230E09050403
0303030201020102020202020202030304070D14181F2929
27272A271D150E0A0706040302020101
26242F3C5153536797D1DBEDE9DFCEAB88491A0B08050303
0303030302010202020202010202020304070D151C232A2E
2D2D2E2B241F18110B07050302020101
2F29395D8885857288BACED4D4BDAB956E31140C09070404
0303030302020202020202020202020304080E171E283536
353535312F2A241A110B060402020101
3C315D8FB4B7B7A8959AB4A8BAB18D724421110E0B090704
0303020202020202020201020202020304060D162029323A
3C3F3C3A35322921170F080503020101
3F3A72A5C4CAD1BAAB7B808D8D776544271710100D0B0805
0403030203020202010201020202020304070D131F2B323C
424447423D3C362A1F140B0503020200
494A8ABAD1E2E9CEB78F63595547392819100F110D0B0807
0303020302020102020102010102020304060B121C2A373F
444A494549423C3326190D0603020100
4E508FB7D8EDE9DBC195573C2E2E261C13110E0F0C0B0A08
04030203020202020201010101020203040509111A2B3C3F
40474C5553423D362B1F110804020100
514E92C1E2F8D4CABA95593326211B17120E0D0E0B0B0A08
060303030202020102020101010202030405080D182A3940
404955595949403A2E21140904030201
424477B7CEDBCEB7AB8F4E271F191814130E0E0D0B0B0909
060403030202020101020102020203030305070D192E3A40
444E595F5B4E423C3526160A04020101
372F5592ABB4B4AE95723C2316161413110D0D0A0B0B0907
050303020202010101010201020202030304060B1829373D
4551595F5B53453A3224160A04020101
2D283D5F7B8F9A8D774E2D1D15141312110C0D0B0A0B0A08
040302020202020202020102020202020304060B17243540
4A555D5B5350473A2B22150A04020101
221F28354750615D472D1F1814141111110B0B0A0A090807
040203020201010101020201010202030304060A1424333D
495559574E4944392E21130904020101
1A1A1F242E2F352D221E1A1614131311100B0A0B09090806
03020302020101010101020102020202030405091224353F
4A5353534E4940372B21110703020100
1514181A1D1F1F1C1A181514121112110F0D080808090604
03020202010101010202020102020202030305080F22323F
49504C5049423D332A1D0D0603020100
111115161418181714101111100F110F0D0A080607060403
02020201010101010102020102020202030304070E1F313A
444A4C493F37352F21170A0402010100
0D10111313151412110F0B0D0D0E0E0D0B08050403030302
02020202020101010201010102020202020304060D1A2A35
3F45453F372B27241A0F070302010000
090D0E1110110E0F0D0B0808090C0D0A0805040302030202
02020202020101010202010102020202020304050A162333
3A3D3C332B1E1916110A040202000000
050A0D0E0E0D0C0B0A080505060607060503030202020202
0202020101010201010101020202020202030304070E1B28
3135332B20150F0C0905030201010000
04070A0C0E0C0A0807050404040405040303030302020201
0201020101010101020102020202020102020303060A111C
23292721180E0A060503030201000000
040406080907050504040303030303030302020202010202
020101010202010202010102020202020203030304070B11
181E1B18100A06040302020100000000
040404050504040404030303030303030202020101020202
01010201010101020201010202020202020303030405070A
0E13130F0A0704030302010101000000
030303030303030303030303020203030202010201010202
020202010101010202010102020202020202020303040506
08090908060403020202010101000000
020302030303020303020203020302020202010101010101
010102010101010101010102020202020202020202030304
04050505040302020101000000000000
020202020303020202020202020202020202010101020201
010101020101010202020201020201020202020202030303
03030303030302010101000000000000
020202020202020202020202020202020202020201010201
010101020101010201020201020201020202020202020303
03030202030202010101010000000000
020202020202020202020202020201010201020201010201
010101020101020102010202010201010102010202020203
02020202020101010101000000000000
020201020202010202020202020202020202020201010101
010101020102010101020201010101010101010102020202
02020201010101010000000000000000
010202020202010202020202020102020101010201010102
010101010101010101010201010101010101010102010101
01010101010101010101000000000000
010202020202020202020102020202020102010101010101
010101010101010101020101010101010201010101010101
01010101010101010000000000000000
020201020202020102010201010202020202010101010101
010101010101010001020001010101010101010101010101
01010101010000000000000000000000
020101020202020102020202010202020102010101010101
020101010102010101010101010101010101010101010101
01010101000000000000000000000000
020101020202010201010202020201020202010101010102
010101010101010101010101020101010101010201010101
01000100000000000000000000000000
020201020202020202010102020202020201010201010102
010101010101010101010102010101010101010201010101
01010000000000000000000000000000
010101020201020101010102010202020101010101010102
010101010101010100010101010101010101010101010101
01000000000000000000000000000000
010101020101020201010101010101010101010101010101
010101010101010001010101010101010000000101010100
00000000000000000000000000000000
010101010101020101010101010101010101010100010101
010101010101010100000001010100000000000101010000
00000000000000000000000000000000
010101020101020101010101010101010101010101010001
010101010101010101000101010101000001010101010001
00000000000000000000000000000000
010101020101010101010101010102010201010001000101
010101010000010001000001010101010001010100010101
00000000000000000000000000000000
010202020101010101010102010101010101010101010001
010001010000000001000001010101010101010101010100
00000000000000000000000000000000
010101020101010101010101010101010101010101010001
010000000000000001000001010101010101010101010000
00000000000000000000000000000000
010101010102010101010101010101010101010100000101
000101010100000001010101010101010101000101010000
00000000000000000000000000000000
010101010101010101010101010101010101010100000001
010101010100010001000101010101010101010101010100
00000000000000000000000000000000
010101010101010101010101010101010101010101010001
000101010101010001000101000000010101010101010100
00000000000000000000000000000000
010101010101010101010101010100010001010100000101
010101010101000000000101010101010100000101010101
00000000000000000000000000000000
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{216, 216},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003H0000f1000`40O003h00Of7oo003HOol00=Qo
o`00f7oo003HOol00=Qoo`001GooHP002GooHP001Woo0005Ool00`00Oomoo`1NOol00`00Oomoo`07
Ool00`00Oomoo`1NOol00`00Oomoo`04Ool000Eoo`03001oogoo05ioo`03001oogoo00Moo`03001o
ogoo05ioo`03001oogoo00Aoo`001Goo00<007oo6<H00QS611cW0QS64acW00DHaQcW7>LLiaS600<L
i`8HaP037>LDYABU00<HaP8DY@<HaP<DY@<HaP<DY@8HaPXDY@<HaPhDY@8HaP047>LQ22489BT2Ool0
0`00Oomoo`07Ool00`00OolLi`197>L26<H00acW6<HHaP046<H011cW6<HHaQS60acW0b480Woo00<0
07ooOol017oo0005Ool00`00OolHaP056<H00acW6<HHaP046<HB7>L;6<H65:D00aS65:DDY@035:D0
0aS65:DDY@035:D26<H55:D011S65:DDYABU0QS641BU00@Lib488@PYBP9oo`03001oogoo00Moo`03
001ooacW01<Li`DQ234Li`LHaPTLi`8Q20049BUoogoo0006Ool000Eoo`03001ooaS600DHaP037>LH
aQS600@HaQ8Li`/HaPHDY@036<HDYABU00<DY@036<HDYABU00<DY@8HaPDDY@046<HDYABU5:D26<H@
5:D011cW8@PQ22U:0Woo00<007ooOol01goo00<007oo7>L04acW1B48<AcW1aS62AcW0R4800@U:Goo
Ool000Ioo`001Goo00<007oo6<H01AS600@LiaS66<HHaQ8Li`@HaP047>LHaQS67>L86<H55:D26<H0
11BU6<HHaQS63ABU0QS64aBU00@HaQcW7>LU:@9oo`03001oogoo00Moo`03001ooacW018Li`038@PL
iacW02HLi`036<HLiacW01/Li`<Q209oo`03001oogoo00Aoo`001Goo00<007oo6<H01AS600<LiaS6
6<H041cW00<HaQcW7>L01AcW3AS60aBU0QS600@DYAS66<HHaP8DY@036<HDYABU008DY@8HaP045:DH
aQS66<H65:D26<H85:D26<H35:D011S67>LLib480Woo00<007ooOol01goo00<007oo7>L02acW00DQ
21cW7>LLib4800<Li`DQ22<Li`036<HLiacW00hLi`<HaP`Li`048@Qoogoo0006Ool000Eoo`03001o
oaS600DHaP037>LHaQS6010Li`036<HLiacW00DLi`dHaP<DY@8HaP045:DHaQS66<H25:D00aS65:DD
Y@025:D26<H011BU6<HHaQS61QBU0QS621BU0QS60aBU00@HaQcW7>LQ209oo`03001oogoo00Moo`03
001ooacW00/Li`058@PLiacW7>LQ20037>L58@PS7>L00aS67>LLi`0>7>L36<H<7>L01248Oomoo`00
1Woo0005Ool00`00OolHaP026<H00acW6<HHaP067>L00b487>LLi`027>L28@P00acW8@PQ200;7>L<
6<H00aBU6<HHaP066<H00aBU6<HHaP036<H25:D36<H25:D00aS65:DDY@045:D26<H85:D26<H35:D3
6<H011cWOomoo`002Goo00<007oo7>L021cW124811cW0R4800<Lib488@P00b48;AcW00<HaQcW7>L0
0acW00@HaQcW6<HHaPdLi`9oo`03001oogoo00Aoo`001Goo00<007oo7>L021cW00<Q21cW7>L021cW
0b482AcW2AS60aBU0QS60QBU00@HaQBU5:DHaP8DY@036<HDYABU00XDY@036<HDYABU01<DY@046<HD
YABU6<H2Ool00`00Oomoo`07Ool00`00OolLi`087>L00b487>LLi`047>L98@PH7>L26<HA7>L26<H7
7>L46<H<7>L2Ool00`00Oomoo`04Ool000Eoo`03001ooacW00PLi`038@PLiacW00PLi`<Q20TLi`TH
aP<DY@8HaP8DY@046<HDYABU6<H25:D00aS65:DDY@0:5:D00aS65:DDY@0C5:D011S65:DDYAS60Woo
00<007ooOol01goo00<007oo7>L021cW00<Q21cW7>L011cW2B4861cW0QS64AcW0QS61acW11S631cW
0Woo00<007ooOol017oo0005Ool00`00OolHaP0<7>L38@P00acW8@PQ20048@P87>LG6<H;5:D36<H5
5:D00aS65:DDY@0:5:D00aS65:DDY@046<H2Ool00`00Oomoo`07Ool00`00OolLi`067>L28@P011cW
8@PQ21cW3b48<QcW0QS63AcW0Woo00<007ooOol017oo0005Ool00`00OolQ20028@P47>L28@P00acW
8@PQ200>8@P67>L00aS65:DDY@037>L00aS67>LLi`0:6<H00aBU6<HHaP085:D96<H?5:D011S65:DD
YAS60aBU0Woo00<007ooOol01goo00<007oo8@P01B4800<Lib488@P04B487AcW0QS600<LiaS66<H0
8AcW0Woo00<007ooOol017oo0005Ool00`00OolQ20028@P47>L28@P00acW8@PQ200>8@P67>L00aS6
5:DDY@037>L00aS67>LLi`0:6<H00aBU6<HHaP085:D96<H?5:D011S65:DDYAS60aBU0Woo00<007oo
Ool01goo00<007oo8@P01B4800<Lib488@P04B487AcW0QS600<LiaS66<H08AcW0Woo00<007ooOol0
17oo0005Ool00`00OolLi`028@P37>L78@P29BT7:DX00bDY8@PQ20038@P47>L011S67>LLiacW0QS6
0acW11S60aBU11S60QBU00<HaQBU5:D02QBU0aS600@DYAS66<HDY@<HaPXDY@HHaP9oo`03001oogoo
00Moo`03001ooacW00<Q208Li`TQ20LU:@LQ21`Li`036<HLiacW024Li`9oo`03001oogoo00Aoo`00
1Goo00<007oo8@P02B480bDY0Re[00@aS3F]=Jde[@<]J`03:DXQ224800<Q20DLi`DHaP047>LHaQS6
6<H25:D26<H25:D46<H95:D76<H25:D76<H<5:D011S65:DDYABU0Woo00<007ooOol01goo00<007oo
8@P032480RDY12U:12DY1R487AcW0QS68AcW0Woo00<007ooOol017oo0005Ool00`00OolQ20098@P3
9BT2;F/0136<=Jde[CF]0be[00<YBR488@P00b481AcW1AS600@LiaS66<HHaP8DY@8HaP8DY@@HaPTD
Y@LHaP8DY@LHaP`DY@046<HDYABU5:D2Ool00`00Oomoo`07Ool00`00OolQ200<8@P29BT4:DX49BT6
8@PM7>L26<HQ7>L2Ool00`00Oomoo`04Ool000Eoo`03001oob48008U:@038@PU:BDY00@U:@8]J`05
<H`icSW>?Nm24002AS40148@>LhicRe[0RU:00<U:B488@P00b4811cW4aS60aBU11S600<DYAS66<H0
2AS600DLiaS66<HHaQBU00hHaP045:Eoogoo0009Ool00`00OolQ20098@P29BT012U:;F/]Jbe[0c6<
0be[0bDY1R48?QcW0Woo00<007ooOol017oo0005Ool00`00OolU:@029BT7:DX2=Jd013W>AS56<E:D
0ekg00AF]DYBBU8mk`8aS004:DXQ22488@P27>L00aS67>LLi`047>L76<H00aBU6<HHaP066<H65:D4
6<H011cW6<HHaQS621cW11S600@DYAS66<HHaPHDY@8HaP045:Eoogoo0009Ool00`00OolQ20028@P7
9BT2:DX01Be[<H`aS7oo?Nl01Goo00@]JbU::DXU:@DQ21LLi`036<HLiacW02@Li`9oo`03001oogoo
00Aoo`001Goo00<007oo;F/00RU:0be[0cF]00@icSg_?Nm:DP9Nm`03Kg]kgW_N009kgP9W>@04E[E2
448@<H`39BT27>L012487>LLiacW0aS600<LiaS66<H00acW21S60QBU0aS60aBU11S631cW1AS60QBU
1QS611BU0Woo00<007ooOol01goo00<007oo9BT01BDY0bU:0be[0goo00=6<DYBBU800TYB0T8@00Ao
obe[;F/YBPHQ22@Li`8Q21LLi`9oo`03001oogoo00Aoo`001Goo00<007oo;F/00RU:0be[0cF]00@i
cSg_?Nm:DP9Nm`03Kg]kgW_N009kgP9W>@04E[E2448@<H`39BT27>L012487>LLiacW0aS600<LiaS6
6<H00acW21S60QBU0aS60aBU11S631cW1AS60QBU1QS611BU0Woo00<007ooOol01goo00<007oo9BT0
1BDY0bU:0be[0goo00=6<DYBBU800TYB0T8@00Aoobe[;F/YBPHQ22@Li`8Q21LLi`9oo`03001oogoo
00Aoo`001Goo00<007oo=Jd00c6<0SW>0cg_00A244YBBU9Nm`9g_@Moo`04Kg]JeU[F?Nl2;F/00bDY
8@PQ20057>L?6<H00aBU6<HHaP036<H35:D26<H@7>L96<H65:D2Ool00`00Oomoo`07Ool00`00OolY
BP05:DX3;F/0136<Oomoocg_0THa00=>Le:DDY@00U:D0TYB00A6<GooOol]J`8U:@DQ220Li`8Q2003
7>LQ224800<Q21@Li`9oo`03001oogoo00Aoo`001Goo00<007oo?Nl01Cg_0d8@00A:DU[FF]Ig_@Yo
o`9cW004CW<e[CF];F/29BT01B487>LHaQS67>L02QS60QBU3AS60acW0b4812DY0b481acW1QS61QBU
0Woo00<007ooOol01goo00<007oo;F/01Be[0c6<0goo00=:DU:DDY@00UJe0e[F0UJe00A>LdHaAS5o
o`8YBP049BTQ22488@PP7>L=8@P=7>L36<H2Ool00`00Oomoo`04Ool000Eoo`03001oocg_00Dmk`=2
4004BU9JeU[FMkd:Ool2Li`014ic=Jde[Be[0RDY00DQ21cW6<HHaQcW00XHaP8DY@dHaP<Li`<Q20@U
:@<Q20LLi`HHaPHDY@9oo`03001oogoo00Moo`03001oobe[00D]J`<aS0=oo`03BU9BU5:D009F]@=J
eP9F]@04CW=6<DHaOol2:DX012DY8@PQ224881cW3B483AcW0aS60Woo00<007ooOol017oo0005Ool0
0`00Oom24005@Q0014HaBU9:DU:D0Vmk3Goo00AS648@@Q0e[@8]J`8Q208Lia4HaP8DY@LHaP047>LQ
22489BT6;F/3:DX29BT00b487>LLi`047>L36<H75:D2Ool00`00Oomoo`07Ool00`00OolaS002<H`0
12e[<H`aS36<0goo0THa00=BU5[FF]H01Ekg0U[F00AF]DicCW<mk`8]J`03:DXU:BDY008Q21dLi`<Q
20TU:@@Q20/Li`<HaP047>Moogoo0006Ool000Eoo`03001ood8@00=6<@=:DP9BU003F]Ioogoo00eo
o`04Kg]:DTYB>Lh2=Jd00bU:8@PLi`057>L96<H00aBU6<HHaP036<H011BU6<HHaQcW0QS600DLib48
:DXYBRe[00<e[@<icP8e[@05<H`]Jbe[:DXU:@028@P47>L26<H75:D2Ool00`00Oomoo`07Ool00`00
OolaS002<H`7Ool2CW<01EJeG_MNmekgHaP01Ekg00AJeU:DDYA6<@9oo`<YBP039BTQ21cW01/Li`04
8@PU:BDY9BT3:DX3;F/3:DX39BT38@P:7>L36<H2Ool00`00Oomoo`04Ool000Eoo`03001ood8@00=6
<@=:DP9BU003F]Ioogoo00eoo`04Kg]:DTYB>Lh2=Jd00bU:8@PLi`057>L96<H00aBU6<HHaP036<H0
11BU6<HHaQcW0QS600DLib48:DXYBRe[00<e[@<icP8e[@05<H`]Jbe[:DXU:@028@P47>L26<H75:D2
Ool00`00Oomoo`07Ool00`00OolaS002<H`7Ool2CW<01EJeG_MNmekgHaP01Ekg00AJeU:DDYA6<@9o
o`<YBP039BTQ21cW01/Li`048@PU:BDY9BT3:DX3;F/3:DX39BT38@P:7>L36<H2Ool00`00Oomoo`04
Ool000Eoo`03001oodHa00E:DP04CW=BU5:DIcT?Ool017NmDYABU48@0SF]00<YBR487>L01AcW1AS6
1ABU0aS60QBU0aS600DLiaS66<HLibDY008]J`<icP04?Nm2448@@Q02?Nl01CW>=Jde[Be[:DX00R48
11cW0QS61aBU0Woo00<007ooOol01goo00<007ooOol027oo00A245:DDYAJeP9Nm`05HaQW>FLiIcUS
6002G_L015[FE[EF]DYB0Woo00D]JbU::DXU:B4801`Li`048@PU:BDY:DX9;F/2:DX29BT38@P97>L3
6<H2Ool00`00Oomoo`04Ool000Eoo`03001oodic009>L`04DYA>LdicDY@2F]H00f]JOomoo`0=Ool0
17NmE[EF]Cg_0Re[00<U:B487>L00QcW2AS611BU0QS600<DYAS66<H00aS600DLiaS66<HQ22U:008e
[@03?Nm2448@00A6<@=2408mk`04>Lh]JbU::DX38@P37>L00aS65:DDY@045:D2Ool00`00Oomoo`07
Ool00`00Oomoo`08Ool0148@DYABU5kg0V<H16Li0f<H00AJeUJeE[E:DP9oo`03;F/U:BDY008Q21/L
i`058@PU:BU::DX]J`03<H`3Ool2<H`4;F/39BT38@P97>L011S6Oomoo`001Woo0005Ool00`00Oom>
L`02CW<015:DCW=>Le:D0U[F00=[FWooOol03Goo00Ag_EJeE[Dmk`8]J`039BTQ21cW008Li`THaP@D
Y@8HaP035:DHaQS600<HaP057>LHaQS68@PYBP02=Jd00cg_@Q124004AS43@Q02?Nl013W>;F/YBRU:
0b480acW00<HaQBU5:D011BU0Woo00<007ooOol01goo00<007ooOol027oo00A245:DDYANm`9S60AW
>@=S6004F]IF]EJeBU82Ool00be[9BTU:@028@PK7>L01B489BTYBRU:;F/00c6<0goo0S6<12e[0bDY
0b482AcW00@HaWooOol000Ioo`001Goo00<007ooCW<01E:D00AF]E[FF]I[FQ1oo`9BU004>LhYBRU:
8@P67>L46<H25:D011S65:DDYABU11S60QBU0aS60acW00DQ22e[>LhicT8@0096<@M>L`9:DP05@Q0e
[Be[;F/U:@028@P47>L26<H45:D2Ool00`00Oomoo`07Ool00`00Oomoo`08Ool0148@DYABU5kg0f<H
0fLi00AS65kgG_MJeP9F]@04BU9oogoo;F/29BT28@PK7>L01B489BTYBRU:;F/00S6<2Goo00@aS2U:
9BTU:@@Q20HLi`<HaP9oo`03001oogoo00Aoo`001Goo00<007ooDY@00eJe0U[F0f<H00=W>GooOol0
3Woo0U:D00<e[BU::DX00R481QcW0QS600@DYAS66<HDY@XHaP<Li`8Q20059BTaS3g_?Nm6<@02CW<3
E[D3DY@01EJeDYABU4YB@Q000SF]00@]JbU::DXU:@8Q20047>LHaQS66<H35:D2Ool00`00Oomoo`07
Ool00`00Oomoo`05Ool3?Nl0148@CW=>Lekg0f<H0fLi00AS65kgG_MJeP9F]@04BU9oogoo:DX29BT2
8@PI7>L38@P012U:;F/]Jc6<37oo00<]JbU::DX00bDY0b4811cW0aS60Woo00<007ooOol017oo0005
Ool00`00OomBU003E[D2F]H3HaP00fLiOomoo`0>Ool2DY@00cF]:DXYBP028@P67>L26<H011BU6<HH
aQBU2QS60acW0R4800DU:C6<?NlmkdHa009>L`=F]@=BU005E[EBU5:DBU924002=Jd012e[:DXYBRDY
0R4800@LiaS66<HHaP<DY@9oo`03001oogoo00Moo`03001oogoo00Eoo`<mk`04@Q1>LdicG_L3HaP3
IcT016<HG_MNme[F0UJe00A:DWooOolYBP8U:@8Q21TLi`<Q2004:DX]Jbe[<H`<Ool00be[:DXYBP03
9BT38@P47>L36<H2Ool00`00Oomoo`04Ool000Eoo`03001ooe:D009BU004F]IW>FLiLi`3Mkd?Ool0
16mkAS56<C6<0RU:00<Q21cW7>L01acW00<HaQBU5:D01aS600<DYAS66<H00aS60acW00DYBSF]@Q12
44YB009BU003E[EJeU[F00IJeP05DYA>Ld8@@Q0icP02<H`012U:8@PQ21cW0aS60aBU0Woo00<007oo
Ool01goo00<007ooOol00goo0T8@14Ha0Tic00=F]EkgG_L01F<H0Ukg00AJeU:DDYA6<@8aS004:DXU
:BDY8@PJ7>L28@P012DY:DX]Jbe[3Woo0S6<00@]JbU::DXU:@8Q20HLi`046<Ioogoo0006Ool000Eo
o`03001ooe[F009F]@03HaQkgW_N01=oo`04G_Lmkcg_<H`2:DX00bDY8@PLi`077>L@6<H37>L01BU:
=Je2448@BU800UJe00=Nmf<HHaP01Ukg00EJeUJeDYABU4Ha008icP04;F/U:BDY7>L36<H35:D2Ool0
0`00Oomoo`07Ool00`00Oomoo`02Ool00cg_BU9:DP04DY@2CW<015:DG_MNmekg0f<H00ANme[FF]IF
]@9>L`04Ool]Jbe[:DX29BT48@PG7>L28@P012DY:DXaS36<0goo1cg_1Woo00@aS2e[;F/U:@<Q20DL
i`046<Ioogoo0006Ool000Eoo`03001oofLi009Nm`03Nmioogoo015oo`9[FP04CW<icSW>=Jd2;F/2
:DX28@P37>L;6<H25:D66<H37>L01BDY=Je2448@CW<00UJe00=NmfLiIcT01VLi0Ukg0UJe00A>Ld8@
@Q0e[@8YBP048@PLiacW6<H35:D2Ool00`00Oomoo`07Ool00`00Oom24002Ool00dYBE[EF]@06F]H3
E[D2F]H2G_L015[FE[EF]Dic0T8@00Aoobe[;F/YBP@U:@8Q21LLi`<Q2003:DX]Jbe[00=oo`<mk`A2
40@mk`=oo`8aS004:DXU:BDY8@P57>L011S6Oomoo`001Woo0005Ool00`00OomW>@02G_L00g_NOomo
o`0AOol2JeX014ic>LhicSF]0Re[0RU:0R480acW2aS60QBU1QS60acW00DU:CF]@Q1244ic009F]@03
G_MW>FLi00IW>@9Nm`9F]@04CW=2448@=Jd2:DX012487>LLiaS60aBU0Woo00<007ooOol01goo00<0
07oo@Q000Woo00=:DUJeE[D01U[F0eJe0U[F0Ukg00AJeUJeE[E>L`924004Ool]Jbe[:DX49BT28@PG
7>L38@P00bU:;F/]J`03Ool3?Nl4@Q04?Nl3Ool2<H`012U:9BTU:B481AcW00@HaWooOol000Ioo`00
1Goo00<007ooIcT00VLi4goo00A[FU:DDYA240<icP8aS004;F/YBR488@P47>L26<H00acW6<HHaP02
6<H25:D00aS65:DDY@066<H01AcW8@PQ22DY=Jd00Sg_00A>Le[FF]INm`9W>@=[FP03Kg][FV]J009W
>@9S6004E[E>Ldic?Nl2;F/00b487>LLi`036<H011BUOomoo`002Goo00<007oo@Q000Sg_00=>Le[F
F]H01Ukg00AJeU:DDYABU0=F]@04CW=:DTYB@Q02Ool00c6<:DXYBP03:DX29BT38@PF7>L38@P00bU:
;F/]J`03Ool00cg_@Q124008@Q02?Nl3Ool012e[9BTU:B481AcW00@HaWooOol000Ioo`001Goo00<0
07ooKg/00Vmk3Goo00AkgWNmMke_N`9S6004E[E6<DHa>Lh2=Jd013W>=Jde[C6<0bU:0acW00<HaQcW
7>L00aS600DDYAS66<HHaQBU008HaP<DY@<HaP<Li`059BT]JcW>>Li:DP02E[D016<HIcUW>F]J0fmk
0V]J00E_Nf]JIcUW>Ekg009BU004AS4aS36<9BT27>L011S65:DDYA240Woo00<007ooOol01goo00<0
07ooAS400THa00ABU5kgG_MNm`=S609Nm`03F]IF]EJe009:DP96<@04@Q0mkcg_Ool2<H`3:DX012e[
:DXYBRU:0bDY5acW0b4800<U:Be[;F/00goo00@mkd8@@Q1240=6<@924005AS52448@@Q0mk`02Ool0
136<:DXYBR481AcW00@HaWooOol000Ioo`001Goo00<007ooKg/00Vmk3Goo00AkgWNmMke_N`9S6004
E[E6<DHa>Lh2=Jd013W>=Jde[C6<0bU:0acW00<HaQcW7>L00aS600DDYAS66<HHaQBU008HaP<DY@<H
aP<Li`059BT]JcW>>Li:DP02E[D016<HIcUW>F]J0fmk0V]J00E_Nf]JIcUW>Ekg009BU004AS4aS36<
9BT27>L011S65:DDYA240Woo00<007ooOol01goo00<007ooAS400THa00ABU5kgG_MNm`=S609Nm`03
F]IF]EJe009:DP96<@04@Q0mkcg_Ool2<H`3:DX012e[:DXYBRU:0bDY5acW0b4800<U:Be[;F/00goo
00@mkd8@@Q1240=6<@924005AS52448@@Q0mk`02Ool0136<:DXYBR481AcW00@HaWooOol000Ioo`00
1Goo00<007ooLi`00W>L37oo00=g_FLiF]H00U[F0U:D00A:DSg_?NlicP<e[@8aS08]J`8YBP048@PL
iacW6<H27>L76<H65:D36<H37>L01B48;F/icSW>AS400U[F0fLi00A[FVmkKg]cW0=g_@04JeYW>FLi
HaP2F]H014ic>LhicRU:0QcW00@HaQBU5:DDY@9oo`03001oogoo00Moo`03001oodHa0096<@03E[EJ
eU[F00IS6005G_MF]EJeBU924006Ool3;F/5:DX49BT00b487>LLi`0D7>L38@P012DY;F/]Jc6<0Woo
1T8@14Ha0d8@00@mkgooOomoo`8]J`039BTQ224800<Li`046<Ioogoo0006Ool000Eoo`03001oog>L
009cW0aoo`05NmiNme:DDYA>L`02AS400d8@>LhicP04=Jd3<H`012e[:DXYBRDY1AcW11S600@DYAS6
6<HHaPDDY@<HaP<Li`058@PYBS6<<Ha24002E[D016<HJeY[FV]J0Vmk00Eg_G_NNmikgVmk009[FP04
IcUJeU[FCW<2?Nl012e[7>LLiacW0QS600@DYGooOol000Uoo`03001oodHa0096<@04E[ENmekgHaP2
IcT016<HG_MNmekg0UJe00=:DSg_Ool017oo00<aS2e[;F/01bU:0bDY00<Q21cW7>L051cW0b4800@U
:BU::DXaS09oo`04?Nm2448@@Q03AS43BU8014Ha@Q1243g_0goo0Re[00<U:B488@P00acW00@HaWoo
Ool000Ioo`001Goo00<007ooLi`00W>L37oo00EkgUkgDYABU4ic0096<@03@Q0icSW>00@e[@<aS004
;F/YBRU:9BT57>L46<H011BU6<HHaQS61ABU0aS60acW00DQ22U:<H`aS48@009F]@04HaQ[FV]JJeX2
Kg/01GNmNmikgW_NKg/00V]J00AW>E[FF]I>L`8mk`04;F/LiacW7>L26<H011BUOomoo`002Goo00<0
07ooAS400THa00AF]EkgG_MS609W>@04HaQNmekgG_L2E[D00dYB?Nmoo`04Ool00c6<;F/]J`07:DX3
9BT00b487>LLi`0D7>L38@P012DY:DXYBS6<0Woo00@mkd8@@Q1240=6<@=:DP04AS52448@?Nl3Ool2
;F/00bDY8@PQ20037>L011S6Oomoo`001Woo0005Ool00`00Oom[FP02JeX<Ool01G>LDYA>LdicAS40
0T8@0cg_0cF]0c6<0Re[0RU:00<U:AcW7>L00acW11S60aBU00<HaQBU5:D011S61AcW00DQ22U:<H`a
S4Ha009JeP04IcU[FV]JJeX2Li`4Nmh017>LJeY[FVLi0Ukg00ABU48@@Q0]J`8Q20046<HDYABU5:D2
Ool00`00Oomoo`07Ool00`00Oom24002@Q0014icF]IJeUkg0V<H00ANme[FF]IJeP9F]@04AS5oogoo
Ool3<H`3;F/6:DX49BT38@PF7>L01B489BTYBRU:<H`00Woo00@mkd8@@Q124096<@A:DP04AS52448@
@Q02?Nl017oo;F/]JbDY0R4811cW0Woo00<007ooOol017oo0005Ool00`00OomS6002F]H00gNmOomo
o`09Ool00fLiDYA24002@Q03?Nl2>Lh3<H`5;F/29BT012487>LLiacW1AS61ABU0QS600<DYAS66<H0
0aS60acW00DQ22DY<H`aS48@009F]@04HaQW>FLiJeX2Li`4Nmh017NmJeY[FVLi0Ukg00ABU48@@Q0]
J`8Q20046<HDYABU5:D2Ool00`00Oomoo`07Ool00`00Oolmk`02Ool00dHaE[EF]@06F]H01EJeCW=>
Ld8@Ool022e[0bU:1BDY0b4861cW0R480RU:00@aS7ooOolmk`=24096<@A:DP03AS52448@00<mk`04
Ool]Jbe[9BT28@P37>L011S6Oomoo`001Woo0005Ool00`00OomS6002F]H00gNmOomoo`09Ool00fLi
DYA24002@Q03?Nl2>Lh3<H`5;F/29BT012487>LLiacW1AS61ABU0QS600<DYAS66<H00aS60acW00DQ
22DY<H`aS48@009F]@04HaQW>FLiJeX2Li`4Nmh017NmJeY[FVLi0Ukg00ABU48@@Q0]J`8Q20046<HD
YABU5:D2Ool00`00Oomoo`07Ool00`00Oolmk`02Ool00dHaE[EF]@06F]H01EJeCW=>Ld8@Ool022e[
0bU:1BDY0b4861cW0R480RU:00@aS7ooOolmk`=24096<@A:DP03AS52448@00<mk`04Ool]Jbe[9BT2
8@P37>L011S6Oomoo`001Woo0005Ool00`00OomJeP02E[D00fLiNmikgP07Ool2Li`015[FBU92448@
0cg_0cW>136<12e[0RU:00<Q21cW7>L02aS60QBU1aS60QcW00DQ22DY;F/]Jd8@009BU004G_M[FV]J
Kg/2Mkd3Nmh01GNmLia_NfmkIcT00U[F00A>Ld8@@Q0]J`8Q20046<HDYABU5:D2Ool00`00Oomoo`07
Ool00`00Oomoo`02Ool0148@BU9:DU:D1EJe00=>LdHaAS400Woo22e[12U:1RDY00<Q21cW7>L05QcW
0R480RDY00@aS7ooOolmk`9240=6<@=:DP96<@924004?NmoogooOol2;F/00bDY8@PQ20037>L011S6
Oomoo`001Woo0005Ool00`00Oom>L`02CW<015JeG_MNmfmk0W>L00Aoog_NNmi_N`9JeP03CW=243g_
008mk`DicP<aS0@]J`<YBP048@PHaQS67>L36<H65:D36<H35:D36<H37>L01B489BT]Jbe[?Nl00U:D
00ANmfLiIcU_N`9g_@05Nmig_GNmLia_N`02JeX016<HF]IJeTic0Sg_00@YBQcW7>LHaP<DY@9oo`03
001oogoo00Moo`03001oogoo00=oo`8mk`03@Q16<DHa00=:DP05@Q1oogooOolaS008;F/3:DX79BT0
0b487>LLi`067>L00aS67>LLi`0=7>L28@P29BT012e[Oomoocg_0T8@0dHa0dYB0THa0T8@00@mkgoo
Oomoo`8]J`039BTQ224800<Li`046<Ioogoo0006Ool000Eoo`03001oodic009>L`04E[ENmekgKg/2
Li`017ooNmikgVmk0U[F00=>Ld8@?Nl00Sg_1CW>0c6<12e[0bU:00@Q21S66<HLi`<HaPHDY@<HaP<D
Y@<HaP<Li`058@PU:Be[;F/mk`02DY@015kgIcUW>Fmk0WNm00EkgWNmMkecW6mk009[FP04HaQJeU[F
CW<2?Nl012U:7>LLiaS60aBU0Woo00<007ooOol01goo00<007ooOol00goo0Sg_00=244HaAS400dYB
00E247ooOomooc6<00P]J`<YBPLU:@038@PLiacW00HLi`036<HLiacW00dLi`8Q208U:@04;F]oogoo
?Nl2@Q03AS43BU82AS42@Q0013g_Oomoogoo0Re[00<U:B488@P00acW00@HaWooOol000Ioo`001Goo
00<007ooAS400THa00=>Le:DDY@00e[F00ANme[FF]I>L`9:DP03AS5243g_00@mk`<icPH]J`8YBP8U
:@047>LHaQS67>L36<H75:D26<H00aBU6<HHaP046<H37>L01248:DXYBSW>0U:D00ANmfLiIcU_N`Eg
_@05Lia_Nf]JJeYS6002F]H014ic>LhicRU:0QcW00@HaQBU5:D@Q09oo`03001oogoo00Moo`03001o
oc6<008aS0Ioo`03?Nmoogoo00=oo`03<H`]Jbe[00D]J`8YBPPU:@8Q21TLi`8Q208U:@04;F]oogoo
?Nl2@Q08AS42@Q0013g_Oomoogoo0Re[00<U:AcW7>L00acW00@HaWooOol000Ioo`001Goo00<007oo
@Q000Sg_0dHa00A:DTicCW=>L`9:DP05AS52448@@Q0mk`06>Lh2=Jd00c6<:DXYBP04:DX012DY8@PQ
21cW1AS61ABU1AS600<DYAS66<H011S60acW00@Q22U::DXe[@9>L`04G_MW>FLiKg/5Li`01FmkJeYW
>FLiG_L00UJe00A:DSF]=JdU:@8Li`046<HDYABU48@2Ool00`00Oomoo`07Ool00`00Ool]J`02;F/3
<H`6Ool3<H`8;F/3:DX69BT38@P:7>L00aS67>LLi`0=7>L012489BTU:BU:0Woo00<mkd8@@Q001dHa
0d8@00@mkgooOomoo`8YBP038@PLiacW00<Li`046<Ioogoo0006Ool000Eoo`03001oocW>008icP=2
4004?Nm2448@AS42@Q000cg_>LhicP04>Lh013F]>LhicSF]0S6<00<]JbU::DX012DY00<Q21cW7>L0
11S62ABU0aS600<DYAS66<H011S60acW00@Q22DY9BTe[@9>L`04G_MW>FLiJeX2Kg/01G>LKg]_NfLi
HaP00Ukg00AJeTicCW=2408]J`038@PHaQS600@DY@9oo`03001oogoo00Moo`03001oobe[00H]J`Da
S003;F/YBRU:008]J`<YBP8]J`<YBP<U:@DQ20`Li`036<HLiacW00dLi`<Q2004:DYoogooOol2?Nl0
0d8@AS56<@03AS40148@?Nlmkcg_0goo00@aS2DY9BTQ20<Li`<HaP9oo`03001oogoo00Aoo`001Goo
00<007oo>Lh00SW>0d8@00@mkd8@@Q16<@924003?NlicSW>00@icP04=JdicSW>=Jd2<H`00be[:DXY
BP049BT00b487>LLi`046<H95:D36<H00aBU6<HHaP046<H37>L012489BTU:CF]0Tic00ANmfLiIcU[
FP9_N`05Lia_NfmkIcUS6002G_L015[FCW=>Ld8@0Re[00<Q21S66<H011BU0Woo00<007ooOol01goo
00<007oo;F/01Re[1C6<00<]JbU::DX00Re[0bU:0Re[0bU:0bDY1B4831cW00<HaQcW7>L03AcW0b48
00@YBWooOomoo`8mk`03@Q16<DHa00=6<@04@Q0mkcg_?Nl3Ool0136<9BTU:B480acW0aS60Woo00<0
07ooOol017oo0005Ool00`00Oole[@03>Lh3?Nl2@Q0013g_>LhicSW>0SF]0S6<1SF]0S6<00<YBR48
8@P01AcW2AS611BU0QS611BU21S600DLib489BTU:C6<0096<@04E[ENmekgIcT3JeX2IcT00f<HF]IB
U002DY@2AS4013F]9BTU:AcW0QS611BU0Woo00<007ooOol01goo00<007oo:DX00RU:2Re[32U:00@U
:B488@PQ220Li`<Q2004:DXaS36<Ool2?Nl6@Q000cg_Oomoo`02Ool2<H`00bU:8@PQ20037>L46<H2
Ool00`00Oomoo`04Ool000Eoo`03001oobe[008aS003=JdicSW>00<icP@e[@8aS08YBP8]J`<aS003
;F/YBRU:00<Q20047>LHaQS67>L:6<H45:D36<H35:D86<H27>L28@P012e[@Q1245:D0Ukg16Li0Ukg
00EJeTYBAS56<D8@008icP03;F/Q224800<HaP<DY@0448Aoogoo0009Ool00`00OolU:@03:DX2;F/0
0bU:;F/]J`06:DX49BT3:DX39BT38@PQ7>L38@P012DY;F/]Jgoo0cg_0d8@0Sg_0Woo0S6<0be[00<U
:B488@P00acW11S60Woo00<007ooOol017oo0005Ool00`00Ool]J`02<H`00cF]>LhicP03>Lh4=Jd2
<H`2:DX2;F/3<H`00be[:DXYBP038@P011cW6<HHaQcW2QS611BU0aS60aBU21S60QcW0R4800@]Jd8@
@Q1BU09Nm`AW>@9Nm`05F]I:DTHaAS524002>Lh00be[8@PQ20036<H35:D01124Oomoo`002Goo00<0
07oo9BT00bU:0Re[00<YBRe[;F/01RU:12DY0bU:0bDY0b488AcW0b4800@U:Be[;F]oo`<mk`=2408m
k`9oo`8aS0<]J`039BTQ224800<Li`@HaP9oo`03001oogoo00Aoo`001Goo00<007oo8@P00Re[00<a
S3F]=Jd00cF]00@aS2e[;F/]J`8YBP8Q20HU:@8Q20<Li`/HaPDDY@036<HDYABU00@DY@THaP@Li`04
:DXe[CF]AS42E[D4G_L2F]H01Dic@Q0e[CF]<H`00RU:00@Q21cW7>LHaP<DY@<@Q09oo`03001oogoo
00Moo`03001oob48008U:@LYBPDU:@XQ22DLi`8Q20039BTYBRU:00Aoo`<mk`=oo`04;F/YBRU::DX2
9BT00b487>LLi`037>L46<H2Ool00`00Oomoo`04Ool000Eoo`03001oob48008U:@04;F/aS36<=Jd2
<H`012e[:DXYBRU:2R481QcW11S60QBU00@HaQBU5:DHaPLDY@8HaP035:DHaQS600HHaP045:DHaQS6
6<H37>L012DY;F/]JcW>0TYB00ABU5JeE[EBU09>L`05@Q0e[Be[;F/U:@028@P37>L00aS65:DDY@04
48@2Ool00`00Oomoo`07Ool00`00OolQ20028@P00bDY:DXYBP03:DX49BT:8@PY7>L012489BTU:Be[
27oo00@aS2U:9BTU:@<Q20HLi`@HaP9oo`03001oogoo00Aoo`001Goo00<007oo8@P00RDY00@]Jc6<
<H`e[@8aS004;F/YBRU::DX:8@P67>L46<H25:D011S65:DDYAS61aBU0QS600<DYAS66<H01QS600@D
YAS66<HHaP<Li`049BT]Jbe[>Lh2BU8015:DE[EF]E:D0Tic00E243F];F/]JbDY008Q20<Li`036<HD
YABU00@@Q09oo`03001oogoo00Moo`03001oob48008Q20039BTYBRU:00<YBP@U:@XQ22TLi`048@PU
:BDY;F/8Ool0136<:DXU:BDY0b481QcW11S60Woo00<007ooOol017oo0005Ool00`00OolLi`028@P0
0bDY:DXYBP03:DX68@P:7>L66<H00aBU6<HHaP026<H55:D36<H011BU6<HHaQS60aBU2AS611cW00@Q
22U::DXaS08icP04AS5:DTYBAS42@Q001CW>;F/U:BDY8@P00QcW0aS60aBU11240Woo00<007ooOol0
1goo00<007oo8@P00b481BDY1R48<AcW00@Q22DY9BTYBP8]J`04<HaoogooOol2<H`00bU:9BTQ2002
8@P67>L66<H2Ool00`00Oomoo`04Ool000Eoo`03001ooacW008Li`HQ20hLi`DHaP<DY@@HaP<DY@03
6<HDYABU00@DY@<HaP<DY@THaP@Li`<Q2004:DX]Jbe[=Jd3?Nl2=Jd012e[:DXQ22480acW00<HaQBU
5:D00aBU11240Woo00<007ooOol01goo00<007oo8@P03248<acW0b480bDY00@YBRe[;F/]J`8YBP8U
:@8Q20HLi`LHaP9oo`03001oogoo00Aoo`001Goo00<007oo7>L00QcW1R483QcW1AS60aBU11S60aBU
00<HaQBU5:D011BU0aS60aBU2AS611cW0b4800@YBRe[;F/e[@<mk`8e[@04;F/YBR488@P37>L00aS6
5:DDY@035:D448@2Ool00`00Oomoo`07Ool00`00OolQ200<8@Pc7>L38@P39BT012U:;F/]Jbe[0RU:
0RDY0R481QcW1aS60Woo00<007ooOol017oo0005Ool00`00OolLi`0@7>L36<H37>L36<H25:D011S6
5:DDYABU1aS61QBU0aS60aBU2aS61AcW00<Q22DY9BT00bU:00@]JbU::DXU:@<Li`@HaPHDY@<@Q09o
o`03001oogoo00Moo`03001ooacW040Li`DQ20HU:@8Q20PLi`LHaP9oo`03001oogoo00Aoo`001Goo
00<007oo6<H00QcW00<HaQcW7>L00acW00@HaQcW7>LLi`<HaP047>LHaQS67>L66<H<5:D00aS65:DD
Y@0:5:D>6<H37>L98@P011cW6<HHaQS62aBU00@@Q7ooOol000Uoo`03001ooacW04<Li`TQ20LLi`TH
aP9oo`03001oogoo00Aoo`001Goo00<007oo6<H01AS60acW4AS61ABU0QS61QBU0QS611BU1QS600@D
YAS66<HHaP8DY@PHaPdLi`8HaPHDY@L@Q09oo`03001oogoo00Moo`03001ooacW058Li`XHaP9oo`03
001oogoo00Aoo`001Goo00<007oo6<H01AS60acW4AS61ABU0QS61QBU0QS611BU1QS600@DYAS66<HH
aP8DY@PHaPdLi`8HaPHDY@L@Q09oo`03001oogoo00Moo`03001ooacW058Li`XHaP9oo`03001oogoo
00Aoo`001Goo00<007oo6<H071S60aBU00<HaQBU5:D011BU0QS611BU00<HaQBU5:D00aS600@DYAS6
6<HHaP8DY@XHaPHLi`<HaP047>LHaQS66<H65:D00a245:DDY@0448@2Ool00`00Oomoo`07Ool00`00
OolLi`1E7>L76<H2Ool00`00Oomoo`04Ool000Eoo`03001ooaS601<HaP<DY@8HaP045:DHaQS66<H3
5:D00aS65:DDY@045:D26<H35:D01AS65:DHaQS65:D00aS60QBU00<HaQBU5:D00aBU00<HaQBU6<H0
1AS60QcW1aS62ABU1a240Woo00<007ooOol01goo00<007oo7>L0D1cW31S60Woo00<007ooOol017oo
0005Ool00`00OolHaP0C6<H35:D26<H011BU6<HHaQS60aBU00<HaQBU5:D011BU0QS60aBU00DHaQBU
6<HHaQBU00<HaP8DY@036<HDYABU00<DY@036<HDYAS600DHaP8Li`LHaPTDY@L@Q09oo`03001oogoo
00Moo`03001ooacW050Li``HaP9oo`03001oogoo00Aoo`001Goo00<007oo6<H00QS600<DYAS66<H0
0aS600<DYAS66<H04AS62QBU0QS600<DYAS66<H011BU0aS63ABU2QS62QBU2A240Woo00<007ooOol0
1goo00<007oo7>L0=AcW00<HaQcW7>L011cW00<HaQcW7>L04AcW31S60Woo00<007ooOol017oo0005
Ool00`00OolDY@086<H00aBU6<HHaP076<H011BU6<HHaQS61ABU00<HaQBU5:D00QBU0QS63QBU0QS6
3ABU00<HaQBU5:D04aBU1a240Woo00<007ooOol01goo00<007oo7>L0>acW11S61acW0QS611cW0aS6
00<LiaS66<H02QS60Woo00<007ooOol017oo0005Ool00`00OolDY@086<H00aBU6<HHaP076<H011BU
6<HHaQS61ABU00<HaQBU5:D00QBU0QS63QBU0QS63ABU00<HaQBU5:D04aBU1a240Woo00<007ooOol0
1goo00<007oo7>L0>acW11S61acW0QS611cW0aS600<LiaS66<H02QS60Woo00<007ooOol017oo0005
Ool00`00OolDY@0>6<H00aBU6<HHaP056<H25:D00aS65:DDY@0D5:D00aS65:DDY@075:D26<HE5:D2
48@45:D648@2Ool00`00Oomoo`07Ool00`00OolLi`0m7>L26<H:7>LC6<H2Ool00`00Oomoo`04Ool0
00Eoo`03001ooaS6008HaP035:DHaQS600@HaP8DY@046<HDYABU6<H35:D76<HF5:D00aS65:DDY@0M
5:D00a245:DDY@0:48@2Ool00`00Oomoo`07Ool00`00OolLi`0K7>L01AS67>LLiacW6<H02acW0QS6
0acW1AS60acW0aS600<LiaS67>L011cW00@HaQcW7>LLi`DHaP037>LHaQS600hHaP9oo`03001oogoo
00Aoo`001Goo00<007oo6<H00QS600<DYAS66<H011S60QBU00@HaQBU5:DHaP<DY@LHaQHDY@036<HD
YABU01dDY@0348@DYABU00X@Q09oo`03001oogoo00Moo`03001ooacW01/Li`056<HLiacW7>LHaP0;
7>L26<H37>L56<H37>L36<H00acW6<HLi`047>L011S67>LLiacW1AS600<LiaS66<H03QS60Woo00<0
07ooOol017oo0005Ool00`00OolHaP035:D66<H25:D56<H25:D46<H25:D00aS65:DDY@075:D00aS6
5:DDY@045:D26<HQ5:D@48@2Ool00`00Oomoo`07Ool00`00OolLi`027>L00aS67>LLi`0Q7>L26<H3
7>L26<H<7>L46<H97>LF6<H2Ool00`00Oomoo`04Ool000Eoo`03001ooaS600<DY@DHaP035:DHaQS6
00<DY@DHaP8DY@@HaPLDY@8HaQ4DY@8HaPPDY@8HaQ0DY@d@Q09oo`03001oogoo00Moo`03001ooacW
02<Li`DHaPDLi`8HaP`Li`036<HLiacW00PLiaHHaP9oo`03001oogoo00Aoo`001Goo00<007oo6<H0
0aBU1AS600<DYAS66<H00aBU1AS60QBU11S61aBU0QS64ABU0QS621BU0QS641BU3A240Woo00<007oo
Ool01goo00<007oo7>L08acW1AS61AcW0QS631cW00<HaQcW7>L021cW5QS60Woo00<007ooOol017oo
0005Ool00`00OolHaP026<H00aBU6<HHaP076<H35:D96<H35:D00aS65:DDY@025:D26<H@5:D00aS6
5:DDY@085:D26<H<5:DA48@2Ool00`00Oomoo`07Ool00`00OolLi`0O7>L00aS67>LLi`037>L36<H5
7>L26<H00acW6<HHaP047>L36<H27>L00aS67>LLi`077>LG6<H2Ool00`00Oomoo`04Ool000Eoo`03
001ooaBU00<DY@<HaP8DY@036<HDYABU00@DY@036<HDYABU00@HaPXDY@8HaRHDYA<@Q00436=oogoo
0009Ool00`00OolLi`067>L26<HF7>L26<H<7>L36<H97>L00aS67>LLi`026<H97>LF6<H2Ool00`00
Oomoo`04Ool000Eoo`03001ooaBU00<DY@8HaP<DY@<HaSdDY@P@Q08DY@T@Q00436=oogoo0009Ool0
0`00OolLi`0L7>L26<H011cW6<HHaQS61QcW00<HaQcW7>L021S60acW1aS60QcW00<HaQcW7>L06QS6
0Woo00<007ooOol017oo0005Ool00`00OolDY@035:D26<H35:D36<Hm5:D848@25:D948@010aSOomo
o`002Goo00<007oo7>L071cW0QS600@LiaS66<HHaPHLi`036<HLiacW00PHaP<Li`LHaP8Li`036<HL
iacW01XHaP9oo`03001oogoo00Aoo`001Goo00<007oo5:D021BU00<HaQBU5:D091BU0a242ABU00<@
Q1BU5:D021BU0Q2400<DYA2448@0112400<DYA2448@02Q240Woo00<007ooOol01goo00<007oo6<H0
4QcW00<HaQcW7>L01acW1QS611cW1QS600<LiaS66<H0;AS60Woo00<007ooOol017oo0005Ool00`00
OolDY@035:D26<H35:D00aS65:DDY@0m5:D448@45:D548@00aBU48@@Q00448@2Ool00`00Oomoo`07
Ool00`00OolHaP0K7>L56<H87>L:6<H011cW6<HHaQcW9QS60Woo00<007ooOol017oo0005Ool00`00
OolDY@035:D26<H35:D00aS65:DDY@0m5:D448@45:D548@00aBU48@@Q00448@2Ool00`00Oomoo`07
Ool00`00OolHaP0K7>L56<H87>L:6<H011cW6<HHaQcW9QS60Woo00<007ooOol017oo0005Ool00`00
OolDY@035:D26<H>5:D26<H00aBU6<HHaP0G5:D00a245:DDY@0G5:D:48@25:D748@2Ool00`00Oomo
o`07Ool00`00OolLi`0I7>L76<H27>L00aS67>LLi`037>L36<H00acW6<HHaP076<H47>L26<H47>L0
0aS67>LLi`0J6<H2Ool00`00Oomoo`04Ool000Eoo`03001ooaBU00DHaPXDY@036<HDYABU01HDY@<@
Q1XDY@0348@DYABU00X@Q0035:D@Q12400L@Q09oo`03001oogoo00Moo`03001ooaS601TLi`<HaP<L
i`036<HLiacW01@HaP8Li`<HaP@LiadHaP9oo`03001oogoo00Aoo`001Goo00<007oo5:D01AS62QBU
00<HaQBU5:D05QBU0a246QBU00<@Q1BU5:D02Q2400<DYA2448@01a240Woo00<007ooOol01goo00<0
07oo6<H06AcW0aS60acW00<HaQcW7>L051S60QcW0aS611cW7AS60Woo00<007ooOol017oo0005Ool0
0`00OolDY@035:D26<HT5:D248@H5:D248@35:DD48@2Ool00`00Oomoo`07Ool00`00OolHaP0<7>L2
6<H00acW6<HLi`0;7>LJ6<H27>L36<H00acW6<HLi`027>LL6<H2Ool00`00Oomoo`04Ool000Eoo`03
001ooaBU00HDY@8HaR@DY@0348@DYABU01@DY@8@Q0035:D@Q124014@Q0<<H`9oo`03001oogoo00Mo
o`03001ooacW008Li`036<HLiacW01<Li`<HaP037>LHaQS6008HaP8Li`036<HLiacW00XHaP037>LH
aQS600@HaP8Li`LHaP<LiaXHaP9oo`03001oogoo00Aoo`001Goo00<007oo5:D01QBU0QS691BU00<@
Q1BU5:D051BU0Q2400<DYA2448@04A240`aS0Woo00<007ooOol01goo00<007oo7>L00QcW00<HaQcW
7>L04acW0aS600<LiaS66<H00QS60QcW00<HaQcW7>L02QS600<LiaS66<H011S60QcW1aS60acW6QS6
0Woo00<007ooOol017oo0005Ool00`00OolDY@155:DG48@2Ool00`00Oomoo`07Ool00`00OolHaP05
7>L00aS67>LLi`037>L00aS67>LLi`046<H:7>L46<H37>LB6<H00acW6<HHaP047>L36<H37>LJ6<H2
Ool00`00Oomoo`04Ool000Eoo`03001ooaBU03DDY@0348@DYABU00dDYAL@Q09oo`03001oogoo00Mo
o`03001ooacW00DLi`036<HLiacW00<Li`DHaP8Li`046<HLiacW7>L26<H00acW6<HHaP086<H27>L4
6<H27>L=6<H00acW6<HHaP026<H37>LL6<H2Ool00`00Oomoo`04Ool000Eoo`03001ooaBU03DDY@03
48@DYABU00dDYAL@Q09oo`03001oogoo00Moo`03001ooacW00DLi`036<HLiacW00<Li`DHaP8Li`04
6<HLiacW7>L26<H00acW6<HHaP086<H27>L46<H27>L=6<H00acW6<HHaP026<H37>LL6<H2Ool00`00
Oomoo`04Ool000Eoo`03001ooaBU02`DY@0348@DYABU01LDY@X@Q08<H`X@Q09oo`03001oogoo00Mo
o`03001ooaS600<HaP8Li`036<HLiacW00<Li`036<HLiacW00XHaP037>LHaQS600DHaP8Li`<HaP03
7>LHaQS600/HaP8Li`PHaPHLiaTHaP9oo`03001oogoo00Aoo`001Goo00<007ooOol0GWoo00<007oo
Ool01goo00<007ooOol0GWoo00<007ooOol017oo0005OomR0009OomR0006Ool00=Qoo`00f7oo003H
Ool00=Qoo`00f7oo003HOol00=Qoo`00f7oo003HOol000Eoof8000Uoof8000Ioo`001Goo00<007oo
Ool0GWoo00<007ooOol01goo00<007ooOol0GWoo00<007ooOol017oo0005Ool00`00Oomoo`1NOol0
0`00Oomoo`07Ool00`00Oomoo`1NOol00`00Oomoo`04Ool000Eoo`03001oof<H04US609W>@03HaQW
>FLi00AW>@04HaQW>FLiIcT3HaP3G_L2Ool00`00Oomoo`07Ool00`00Ool0001L0002Ool00`00Oomo
o`04Ool000Eoo`03001oof<H01=S60ENmc5S60MW>@US609Nm`04F]Ioogoo0009Ool00`00Ool0001L
0002Ool00`00Oomoo`04Ool000Eoo`03001oof<H01=S60ENmc5S60MW>@US609Nm`04F]Ioogoo0009
Ool00`00Ool0001L0002Ool00`00Oomoo`04Ool000Eoo`03001oof<H019S6003G_MS66<H02IS6003
IcUS66<H01]S60=Nm`9oo`03001oogoo00Moo`03001oo`0005`0009oo`03001oogoo00Aoo`001Goo
00<007ooHaP02f<H00ENmf<HHaQS65kg00=S60ENmb=S6003IcUS66<H00iS60=W>@aS6004G_Moogoo
0009Ool00`00Ool0001L0002Ool00`00Oomoo`04Ool000Eoo`03001oof<H00]S6005G_MS66<HHaQN
m`03HaP5G_LSHaP00fLiHaQS600>HaP3IcT<HaP015kgOomoo`002Goo00<007oo0000G0000Woo00<0
07ooOol017oo0005Ool00`00OomS6008HaP4G_L4HaP2G_L00f<HG_MNm`03G_L]HaP00fLiHaQS6003
HaP016LiHaQW>FLi3F<H0Woo00<007ooOol01goo00<007oo0000G0000Woo00<007ooOol017oo0005
Ool00`00OomS6008HaP00ekgHaQS6004HaP9G_LHHaP2IcTAHaP2IcT7HaP4IcT<HaP2Ool00`00Oomo
o`07Ool00`00Ool0001L0002Ool00`00Oomoo`04Ool000Eoo`03001oof<H00QS6003G_MS66<H00AS
60UNmaQS609W>A5S609W>@MS60AW>@aS609oo`03001oogoo00Moo`03001oo`0005`0009oo`03001o
ogoo00Aoo`001Goo00<007ooHaP01V<H0Ukg00AS65kgG_MS60mNmc9S609W>@eS609oo`03001oogoo
00Moo`03001oo`0005`0009oo`03001oogoo00Aoo`001Goo00<007ooG_L01Ekg00=S65kgG_L04Ekg
7F<H0VLi00=S66LiIcT08F<H0Woo00<007ooOol01goo00<007oo0000G0000Woo00<007ooOol017oo
0005Ool00`00OomNm`05G_L00f<HG_MNm`0AG_LMHaP2IcT00f<HIcUW>@0QHaP2Ool00`00Oomoo`07
Ool00`00Ool0001L0002Ool00`00Oomoo`04Ool000Eoo`03001oof<H00=Nm`9S60UNm`MJePMNmaaS
6003IcUS66<H025S609oo`03001oogoo00Moo`03001oo`0000h000D48DT0009oo`03001oogoo00Ao
o`001Goo00<007ooG_L035kg0U[F15Je15[F1Ukg7F<H0VLi8F<H0Woo00<007ooOol01goo00<007oo
000030002P@QAP000Woo00<007ooOol017oo0005Ool00`00OomNm`0<G_L2F]H4E[D4F]H6G_LMHaP2
IcTQHaP2Ool00`00Oomoo`07Ool00`00Ool0000<000:12560002Ool00`00Oomoo`04Ool000Eoo`03
001ooekg00UNm`9JeP04E[EBU5:DDY@3CW<3DY@3F]H6G_LnHaP2Ool00`00Oomoo`07Ool00`00Ool0
000900031243248336<3248312540002Ool00`00Oomoo`04Ool000Eoo`03001ooekg009Nm`MJeP9F
]@04DYA>LdicBU83@Q0014HaBU9:DU:D0UJe00=JeUkgG_L00ekg5f<H00=W>F<HHaP096<H0Woo00<0
07ooOol01goo00<007oo00000P0000<48@0000001P@Q00@8@PaS36<@Q0<HaP045:D<H`aS24821254
0002Ool00`00Oomoo`04Ool000Eoo`03001ooe[F00EJeP=F]@=BU004CW=2448@>Lh4=Jd2?Nl014Ha
DYABU5Je1Ukg96<H0Ukg5f<H0Woo00<007ooOol01goo00<007oo124020@Q0`Q200@<HaS66<HU:@@]
J`8Li`045:D8@PQ212530002Ool00`00Oomoo`04Ool000Eoo`03001ooe[F00EJeP=F]@=BU004CW=2
448@>Lh4=Jd2?Nl014HaDYABU5Je1Ukg96<H0Ukg5f<H0Woo00<007ooOol01goo00<007oo124020@Q
0`Q200@<HaS66<HU:@@]J`8Li`045:D8@PQ212530002Ool00`00Oomoo`04Ool000Eoo`03001ooeJe
00EF]@=BU004CW=:DTYB@Q02>Lh00c6<;F/]J`02;F/2=Jd013W>AS56<E:D0U[F1Ekg86<H0Ukg00=S
65kgG_L00ekg56<H0Woo00<007ooOol01goo00<007oo12400`@Q1@Q20`aS00DHaRU::DXe[D8@0096
<@04?NlaS36<9BT25:D00`Q212448@110002Ool00`00Oomoo`04Ool000Eoo`03001ooe:D00EBU0A>
L`96<@03=Jd]Jbe[008YBP<U:@8YBP04<H`icSW>BU82E[D015[FG_MNmekg86<H3Ekg3F<H0fLi0Woo
00<007ooOol01goo00<007oo24801@Q210aS0QBU00DYBSg_?NmBU4ic009F]@04DYA6<DHa>Lh2:DX0
112412448@@Q@0000Woo00<007ooOol017oo0005Ool00`00OomBU005DY@4CW<2AS400cF];F/]J`02
:DX39BT2:DX0136<>LhicTYB0UJe00AJeUkgG_MNmb1S60eNm`eS60=W>@9oo`03001oogoo00Moo`03
001oo`Q200D8@P@<H`8DY@05:DXmkcg_DYA>L`02E[D015:DAS56<CW>0RU:00@@Q0@Q12448D00009o
o`03001oogoo00Aoo`001Goo00<007ooCW<00Tic00=BU4icCW<00dic00A:DSW>>Lh]J`8U:@DQ208U
:@04:DXaS36<@Q02DY@00eJeF]IJeP02G_LMHaP3G_L9F]H4G_L;HaP3IcT016<HOomoo`002Goo00<0
07oo24800`Q21@aS00@@Q2DY9BTmk`9BU09Nm`=S609F]@04BU8aS36<6<H22483124R0008124D0002
Ool00`00Oomoo`04Ool000Eoo`03001oodic00I>L`9:DP04AS4aS36<:DX38@P00acW8@PQ20038@P0
12DY;F/]JcW>0Tic0eJe00=JeUkgHaP06f<H00ANme[FF]IJeP=F]@=BU0=F]@=JeP=Nm`YS60=W>@9o
o`03001oogoo00Moo`03001oo`aS00H<H`8@Q0045:DaS36<CW<2HaP01FLiKg][FV]JIcT00V<H00AB
U3g_?NlU:@8<H`0424848@@Q124P000412432486124@0002Ool00`00Oomoo`04Ool000Eoo`03001o
odic00I>L`9:DP04AS4aS36<:DX38@P00acW8@PQ20038@P012DY;F/]JcW>0Tic0eJe00=JeUkgHaP0
6f<H00ANme[FF]IJeP=F]@=BU0=F]@=JeP=Nm`YS60=W>@9oo`03001oogoo00Moo`03001oo`aS00H<
H`8@Q0045:DaS36<CW<2HaP01FLiKg][FV]JIcT00V<H00ABU3g_?NlU:@8<H`0424848@@Q124P0004
12432486124@0002Ool00`00Oomoo`04Ool000Eoo`03001oodic009>L`I:DP04?Nl]Jbe[9BT28@P0
1AcW6<HHaQS67>L00R4800@U:BU::DXe[@9:DP05DYAF]EJeF]INm`0LHaP015kgF]IJeUJe2E:D0UJe
0U[F0ekg2F<H0fLi0Woo00<007ooOol01goo00<007oo36<01@aS0a2400@Licg_?NmBU0=[FP=kgP04
LiaS66<HE[D2BU8012U:48@@Q0Q20P@Q7`000P@Q2PQ210@Q3`000Woo00<007ooOol017oo0005Ool0
0`00Oom:DP06BU82AS4013g_;F/]Jb480QcW11S60acW00@U:BU::DXe[@96<@03DYAJeU[F009Nma]S
6005G_MJeUJeE[EBU008CW<4DY@3F]H3G_L9HaP016LiOomoo`002Goo00<007oo48@01Q240QBU00@Q
23g_?NmS609cW005Nmioog_NNmig_@02Kg/015[FBU9:DRU:0QBU00<8@P@Q12407P000`@Q0`Q21PaS
10Q200<48@0000003@000Woo00<007ooOol017oo0005Ool00`00Oom:DP06BU82AS4013g_;F/]Jb48
0QcW11S60acW00@U:BU::DXe[@96<@03DYAJeU[F009Nma]S6005G_MJeUJeE[EBU008CW<4DY@3F]H3
G_L9HaP016LiOomoo`002Goo00<007oo48@01Q240QBU00@Q23g_?NmS609cW005Nmioog_NNmig_@02
Kg/015[FBU9:DRU:0QBU00<8@P@Q12407P000`@Q0`Q21PaS10Q200<48@0000003@000Woo00<007oo
Ool017oo0005Ool00`00Oom:DP05BU83AS4013g_;F/]Jb480acW0aS600@Lib488@PU:@8YBP04=Je:
DTYBDY@2F]H2G_LKHaP01EkgF]IF]EJeDY@00Tic1dYB0dic00=F]E[FF]H015kg1V<H0fLi0Woo00<0
07ooOol01goo00<007oo48@01A240aBU00@Q24HaAS5S609cW005MkeoogooOomg_@02JeX015[FBU9:
DS6<0Q2400<8@P@Q12407P0000@48@Q22488@P<<H`8@Q00436<@Q12448@236<010Q212448@@Q3@00
0Woo00<007ooOol017oo0005Ool00`00Oom:DP05AS43@Q0013g_<H`aS2480acW0aS600@Lib488@PU
:@8YBP04=Je:DTYBE[D2F]H2G_LIHaP3G_L015JeDYABU4ic0TYB2DHa00A>Le:DE[EF]@=JeP=Nm`AS
60=W>@9oo`03001oogoo00Moo`03001ooa2400DDY@046<HLiacW7>L2>Lh01EkgLiacW7>LOol00W_N
00A_NfLiIcUJeP96<@03<H`@Q12400<48Ah000031248@PQ200<<H`<DY@<@Q0055:D@Q12436<8@P03
124<0002Ool00`00Oomoo`04Ool000Eoo`03001oodYB00E6<@=24004?NlaS36<8@P37>L36<H011cW
8@PQ22DY0RU:00@e[DYBBU9F]@9JeP9NmaUS60=Nm`04E[EBU5:DCW<2BU89AS4014icDYAF]EJe0e[F
0ekg16<H0fLi0Woo00<007ooOol01goo00<007oo48@01ABU00@HaQcW7>LLi`8icP05G_McW7>LLiao
o`02Nmh016mkIcUW>E[F0THa00<aS12448@00`@Q7P0000<48@Q224800`aS0aBU0a2400DDYA2448@<
H`Q200<48@`0009oo`03001oogoo00Aoo`001Goo00<007ooBU800TYB00=6<Cg_?Nl013W>0S6<00<Y
BR488@P01AcW0R4800@U:Be[;F/icP9>L`04E[EJeU[FG_LJHaP2G_L01E[FE[EBU5:DCW<00TYB2DHa
0TYB0Tic00ABU5JeE[EJeP9Nm`IS6004IcUoogoo0009Ool00`00Ool@Q00248@00aBU7>LLi`04:DX2
<H`014YBJeY[FVmk0gNm00A_NfLiIcUF]@96<@039BT<H`aS00<48Ah000041248@PQ236<248@95:D0
1A2436<<H`aS24800P@Q2P000Woo00<007ooOol017oo0005Ool00`00Oom6<@02AS400d8@=Jde[@04
;F/2<H`012e[8@PQ22480acW00@Q22DY9BTYBP8aS004@Q1BU5:DE[D2F]H4G_LGHaP2G_L01E[FE[E>
LdicBU800THa2D8@0THa0TYB00A>Le:DDYAJeP=Nm`ES6004IcUoogoo0009Ool00`00OolDY@025:D0
11cW;F/]JdHa0d8@0SW>00A6<EkgG_MW>@=[FP04G_MF]EJeBU82=Jd00aS62488@P03124M00021242
24800`aS5:DDY@096<H25:D248@010aS2488@P@Q2@000Woo00<007ooOol017oo0005Ool00`00Oolm
k`02@Q000cF]:DXYBP069BT3:DX29BT28@P012DY:DXYBS6<0Sg_00A:DU:DDYAF]@AJeP9NmaMS60=N
m`04E[EBU5:DBU82AS43@Q04?Nl4@Q02AS4014YBCW=>LeJe0U[F00=Nmf<HHaP00f<H00AW>GooOol0
00Uoo`03001ooacW008HaP03;F]6<DHa00AJeP9F]@05BU9>LdicF]IF]@02G_L015[FAS56<CW>0R48
00<@Q0Q2248010@Q7@0000@48@Q2248@Q08DY@036<HLiacW00HLi`8HaP8DY@0348@8@PQ200<48@L0
009oo`03001oogoo00Aoo`001Goo00<007oo?Nl00T8@00<e[BU::DX01RDY0bU:0RDY0R4800@U:BU:
:DXaS08mk`04BU9BU5:DE[D4F]H2G_LGHaP3G_L015JeDYABU4YB0THa0d8@13g_148@0THa00A:DTic
CW=F]@9JeP03G_MS66<H00=S6004IcUoogoo0009Ool00`00OolLi`026<H00be[AS56<@04F]H2E[D0
1DYBCW=>Le[FE[D00Ukg00AJeTHaAS4icP8Q200348@8@PQ200@48Ad000041248@PQ248@25:D00aS6
7>LLi`067>L26<H25:D00a242488@P0312470002Ool00`00Oomoo`04Ool000Eoo`03001oocg_0092
4003<H`U:BDY00HQ20049BT]Jbe[;F/3:DX0136<=Jde[Cg_0THa00=>LeJeE[D00eJe0U[F0ekg5V<H
0ekg00AF]E:DDYA:DP96<@03@Q0mkcg_00Pmk`924004AS5:DTYBDY@2F]H00ekgHaQS6003HaP016Li
Oomoo`002Goo00<007oo7>L00QcW00@icU:DDYAS609W>@04JeYNmekgE[D2?Nl01D8@AS56<DHa>Lh0
0S6<00<Q212448@010Q210@Q700000@48@Q2248<H`8DY@036<HLiacW00HQ208Li`8HaP045:D<H`aS
248212470002Ool00`00Oomoo`04Ool000Eoo`03001oocW>008icP04;F/Q22488@P37>L28@P00bDY
:DXYBP02=Jd2>Lh013g_@Q1244Ha0Tic0eJe00ABU5JeE[EF]@=JeQMS60=Nm`04F]IBU5:DCW<2AS40
148@?Nlmkcg_0cW>0Sg_00DicSg_?Nlmkd8@009:DP04CW=F]EJeG_L5HaP016LiOomoo`002Goo00<0
07oo9BT00RDY00A6<EkgG_M[FP9cW004MkeW>FLiF]H2AS401C6<;F/YBRU:8@P00QcW00@DY@aS36<8
@P848@0324848@@Q00848A`000041248@PQ236<25:D011S67>LLib480bDY0R4800DU:B487>LLiaS6
008@Q00336<48@@Q00L0009oo`03001oogoo00Aoo`001Goo00<007oo>Lh00SW>00@]Jb488@PQ20<L
i`8Q20039BTYBRU:008e[@8icP04?Nm2448@AS42CW<3E[D015:DE[EF]EJe0e[F5f<H0ekg00AJeU:D
DYA>L`96<@04@Q0mkcg_?Nl3>Lh2?Nl01CW>?Nlmkcg_@Q000TYB00A>LeJeE[ENm`ES6004IcUoogoo
0009Ool00`00OolU:@029BT014HaG_MNmf]J0W>L00Ag_FLiIcUJeP96<@05<H`]JbU::DXQ20027>L0
11BU36<<H`Q20P@Q00<8@P@Q12400P@Q700000@48@Q2248<H`8DY@046<HLiacW8@P39BT28@P01BDY
8@PLiacW6<H00Q2400<<H`@Q12401`000Woo00<007ooOol017oo0005Ool00`00OolicP02>Lh00bU:
9BTU:@067>L01B48:DXYBSF]?Nl00dHa0TYB00A>Le:DDYABU0EF]@AJeP03G_MS66<H01AS60=Nm`04
F]IBU5:DCW<2AS46?Nl4>Lh3?Nl0148@AS56<DYB0U:D00=JeUkgG_L00f<H00AW>GooOol000Uoo`03
001oobDY008YBP04AS5JeU[FKg/3Mkd2Kg/01F<HBU9:DRU:7>L00aBU0Q2400@<H`Q22488@PT48AX0
00041248@PQ236<25:D37>L38@P01BDY:DXYBRU:8@P00QcW00@HaQBU5:D<H`88@P031240000000@0
009oo`03001oogoo00Aoo`001Goo00<007oo>Lh00SW>00@YBR488@PLi`8HaP047>LQ22488@P2:DX0
0cF]@Q1:DP02BU83CW<2DY@7E[D3F]H00ekgHaQS600DHaP3G_L015[FE[EF]Dic0THa00A243g_?Nlm
k`<icP<e[@04>Lhmkcg_@Q02AS4014YBDYABU5[F0Ukg0f<H00AW>GooOol000Uoo`03001oobU:008U
:@04BU9S66<HLi`2Ool016]JIcUW>Ekg0TYB00<]JaS648@00Q240PaS0`Q22P@Q6P000`@Q00@<HaBU
5:DLi`<Q208U:@05:DX]Jbe[;F/U:@028@P011cW5:DDYA240PQ200<48@00000010000Woo00<007oo
Ool017oo0005Ool00`00OolicP02>Lh012U:8@PQ21cW0QS600@Lib488@PQ208YBP03=Je244YB009:
DP=>L`9BU0MF]@=JeP03G_MS66<H01AS60=Nm`04F]IF]EJeCW<2AS40148@?Nlmkcg_0cW>0cF]00@i
cSg_?Nm24096<@04BU9BU5:DF]H2G_L3HaP016LiOomoo`002Goo00<007oo:DX00RDY00A:DV<HHaQc
W09oo`04JeYW>FLiG_L2BU800be[6<H@Q00248@236<3248:124J0003124010aS5:DDYAcW0b480RDY
00DYBRe[;F/]JbDY008Q20047>LDYABU48@224800`@Q000000040002Ool00`00Oomoo`04Ool000Eo
o`03001oocg_008mk`04<H`U:BDY8@P27>L012489BTU:BDY0RU:00@icTHaBU9:DP=>L`=BU0IF]@AJ
eP=NmaIS6005G_MJeUJeE[E>L`02AS40148@?Nlmkcg_0SW>13F]00@icSg_?Nlmk`924004BU9BU5:D
F]H2G_L4HaP2Ool00`00Oomoo`07Ool00`00OolQ20028@P013W>F]IJeVLi0Vmk00AW>E[FF]IF]@96
<@039BT@Q0aS00@<H`<8@PX48A/000848@0436<DYABU7>L38@P29BT4;F/012DY8@PQ21cW0QS600@@
Q0Q224848@H0009oo`03001oogoo00Aoo`001Goo00<007oo@Q000THa00<icRU::DX01RDY00DYBS6<
<H`mkdYB00QBU0=F]@EJeP=NmaQS609Nm`9F]@04CW=6<DHa@Q03?Nl2>Lh4=Jd00cW>?Nlmk`03@Q00
14YBDYABU5[F0Ukg0f<H00AW>GooOol000Uoo`03001ooaS6008DY@04:DY:DTYBE[D3F]H2E[D01DYB
>LhicQcW48@020Q220@Q7@000P@Q00@<HaBU5:DHaP8Li`038@PYBRU:00@]J`04:DXQ22487>L26<H0
11242488@P@Q1P000Woo00<007ooOol017oo0005Ool00`00Oom24002AS400cW>:DXYBP069BT01BU:
<H`aS3g_BU8025:D0eJe1E[F0ekg66<H0Ukg0UJe00A>LdHaAS5240<mk`8icP@e[@03>Lhmkcg_00=2
4004BU9BU5:DF]H2G_L3HaP016LiOomoo`002Goo00<007oo6<H00QBU00@YBTYBBU9F]@=JeP9F]@05
BU8icSW>7>L@Q0082488124M0002124010aS5:DDYAS60QcW00<Q22U::DX012e[00@YBR488@PLi`8H
aP0448@8@PQ212460002Ool00`00Oomoo`04Ool000Eoo`03001oodHa0096<@04?Nle[CF];F/5:DX0
1C6<>LhicTHaCW<025:D15Je1U[F00=Nmf<HHaP05V<H0Ukg0U[F00A>LdYBBU92408mk`<icP<e[@8i
cP8mk`04@Q16<DHaBU82DY@00e[FG_MNm`03HaP016LiOomoo`002Goo00<007oo5:D00QBU00@Libe[
;F/mk`96<@04CW=6<DHa>Lh29BT00aBU36<8@P07248:124K0002124010Q248@@Q1S60R4800<U:BU:
:DX00be[0RU:0R4800@LiaBU5:D@Q088@P031240000000@0009oo`03001oogoo00Aoo`001Goo00<0
07ooBU800TYB00A6<D8@@Q0mk`8icP<e[@05?Nm6<DHaBU9>L`08DY@3E[D7F]H00ekgHaQS6006HaP0
0fLiHaQS600=HaP2G_L2F]H015:DBU9:DT8@0Sg_0cW>0cF]0SW>0Sg_00A244HaAS5:DP9BU003F]IN
mekg00=S6004IcUoogoo0009Ool00`00Ool@Q00236<011BU6<HHaR480RU:00@aS2e[;F/Q208DY@8<
H`P8@PP48Ad000848@04248@Q1246<H27>L012DY:DXYBRe[0RU:0RDY0R4800@LiaBU5:D@Q088@P03
1240000000@0009oo`03001oogoo00Aoo`001Goo00<007ooBU800TYB00A6<D8@@Q0mk`8icP<e[@05
?Nm6<DHaBU9>L`08DY@3E[D7F]H00ekgHaQS6006HaP00fLiHaQS600=HaP2G_L2F]H015:DBU9:DT8@
0Sg_0cW>0cF]0SW>0Sg_00A244HaAS5:DP9BU003F]INmekg00=S6004IcUoogoo0009Ool00`00Ool@
Q00236<011BU6<HHaR480RU:00@aS2e[;F/Q208DY@8<H`P8@PP48Ad000848@04248@Q1246<H27>L0
12DY:DXYBRe[0RU:0RDY0R4800@LiaBU5:D@Q088@P031240000000@0009oo`03001oogoo00Aoo`00
1Goo00<007ooCW<00Tic0dYB0dHa00=244HaAS400dYB00=>Le:DDY@01E:D0UJe25[F0Ukg6F<H0Ukg
0U[F00ABU4YBBU92408mk`PicP8mk`04@Q16<DHaBU82DY@00e[FHaQS6003HaP016LiOomoo`002Goo
00<007oo36<00`aS0Q240aBU00@HaQBU5:D@Q0<<H`T8@PP48Ad000848@04248@Q1246<H27>L00bDY
:DXYBP03:DX29BT28@P011S65:DDYA240PQ21`000Woo00<007ooOol017oo0005Ool00`00OomBU002
DY@4CW<3BU85CW<8DY@3E[D6F]H3G_L:HaP00fLiHaQS600=HaP015kgF]IJeUJe0TYB00=243g_?Nl0
1cW>0cg_00A244HaAS5>L`9F]@03G_MS66<H00=S6004IcUoogoo0009Ool00`00Ool8@P02248<36<8
2489124N0003124248@011S67>LLibDY0RU:00DU:BU::DXU:B48008Li`046<HDYABU36<212470002
Ool00`00Oomoo`04Ool000Eoo`03001ooe:D00IBU0E>L`03DYAF]EJe009BU0=F]@9BU0=F]@=JePEN
m`aS6003IcUS66<H00eS60=Nm`03E[E:DTYB00=24003?NlicSW>00<icP05?Nm2448@@Q16<@02BU80
14icF]IJeUkg0f<H0fLi0Woo00<007ooOol01goo00<007oo24801PQ20`aS2@Q200<48@Q224801P@Q
900000@48@aS36<HaP8Li`038@PU:BDY00<U:@057>LHaQS66<HDY@0248@00`Q212448@070002Ool0
0`00Oomoo`04Ool000Eoo`03001ooe:D00IBU0E>L`03DYAF]EJe009BU0=F]@9BU0=F]@=JePENm`aS
6003IcUS66<H00eS60=Nm`03E[E:DTYB00=24003?NlicSW>00<icP05?Nm2448@@Q16<@02BU8014ic
F]IJeUkg0f<H0fLi0Woo00<007ooOol01goo00<007oo24801PQ20`aS2@Q200<48@Q224801P@Q9000
00@48@aS36<HaP8Li`038@PU:BDY00<U:@057>LHaQS66<HDY@0248@00`Q212448@070002Ool00`00
Oomoo`04Ool000Eoo`03001ooeJe009F]@YBU0aF]@04F]INmekgG_LPHaP3G_L015JeCW=>LdHa0T8@
1Sg_00E244HaAS56<DYB009>L`03E[ENmekg00=S60AW>@9oo`03001oogoo00Moo`03001oo`@Q00`8
@Pd48BH00004124<H`aS5:D26<H011cW8@PQ22480QcW00<HaQBU48@00Q240PaS00<48@0000001`00
0Woo00<007ooOol017oo0005Ool00`00OomJeP03E[D2DY@00eJeDYABU006E[D4F]H3E[D3F]H3G_LQ
HaP3G_L015[FDYABU4YB0d8@0cg_0T8@00A6<DYBCW=>L`=BU003F]INmekg00=S60AW>@9oo`03001o
ogoo00Moo`03001oo`@Q00<48@D8@Q048BL000041248@PQ248@26<H47>L26<H011BU36<<H`aS0`Q2
00<48@0000001`000Woo00<007ooOol017oo0005Ool00`00OomJeP03E[D2DY@00eJeDYABU006E[D4
F]H3E[D3F]H3G_LQHaP3G_L015[FDYABU4YB0d8@0cg_0T8@00A6<DYBCW=>L`=BU003F]INmekg00=S
60AW>@9oo`03001oogoo00Moo`03001oo`@Q00<48@D8@Q048BL000041248@PQ248@26<H47>L26<H0
11BU36<<H`aS0`Q200<48@0000001`000Woo00<007ooOol017oo0005Ool00`00OomNm`02F]H7E[D5
F]H:G_LUHaP2G_L015[FE[EF]Dic0THa148@0THa00=:DU:DE[D00UJe0U[F00=Nmf<HHaP00f<H16Li
0Woo00<007ooOol01goo00<007oo00003P@Q<P000P@Q00<<HaBU5:D011S60QBU00<@Q0Q2124010@Q
2P000Woo00<007ooOol017oo0005Ool00`00OomNm`02G_L00e[FE[EF]@03E[D4F]H:G_LYHaP015kg
F]IJeU:D0Tic00A:DTHaAS56<@9:DP04CW=F]E[FF]H3G_L6HaP4IcT2Ool00`00Oomoo`07Ool00`00
Ool000020009124e0002124010Q236<<Ha240QBU0a2400@<H`@Q12448@d0009oo`03001oogoo00Ao
o`001Goo00<007ooG_L00Ukg00=JeUJeE[D00eJe15[F2Ukg:F<H00ANme[FF]IBU09>L`04BU96<DHa
AS42BU8014icE[EJeU[F0ekg1V<H16Li0Woo00<007ooOol01goo00<007oo00000P002@@Q=@000P@Q
00@8@PaS36<@Q08DY@<@Q00436<48@@Q124=0002Ool00`00Oomoo`04Ool000Eoo`03001ooekg00=N
m`EJePINmc5S6004G_MJeU[FE[D2DY@00dicBU9:DP03CW<00eJeF]INm`02G_L6HaP6IcT2Ool00`00
Oomoo`07Ool00`00Ool000030003124l00000`@Q2488@P0636<00`Q21240000>0002Ool00`00Oomo
o`04Ool000Eoo`03001ooekg00aNmc=S60=Nm`=JeP04E[EBU5:DDY@2E[D2F]H2G_L6HaP7IcT2Ool0
0`00Oomoo`07Ool00`00Ool00013000312432483124@0002Ool00`00Oomoo`04Ool000Eoo`03001o
oekg00aNmc=S60=Nm`=JeP04E[EBU5:DDY@2E[D2F]H2G_L6HaP7IcT2Ool00`00Oomoo`07Ool00`00
Ool00013000312432483124@0002Ool00`00Oomoo`04Ool000Eoo`03001oof<H041S60ENm`IJeP9N
m`QS60MW>@9oo`03001oogoo00Moo`03001oo`0004D000H48A40009oo`03001oogoo00Aoo`001Goo
00<007ooHaP0@f<H2Ekg1f<H2FLi0Woo00<007ooOol01goo00<007oo0000G0000Woo00<007ooOol0
17oo0005Ool00`00OomS601BHaP:IcT2Ool00`00Oomoo`07Ool00`00Ool0001L0002Ool00`00Oomo
o`04Ool000Eoo`03001oof<H059S60YW>@9oo`03001oogoo00Moo`03001oo`0005`0009oo`03001o
ogoo00Aoo`001Goo00<007ooHaP0EF<H1fLi0Woo00<007ooOol01goo00<007oo0000G0000Woo00<0
07ooOol017oo0005Ool00`00OomS601@HaP<IcT2Ool00`00Oomoo`07Ool00`00Ool0001L0002Ool0
0`00Oomoo`04Ool000Eoo`03001oof<H051S60aW>@9oo`03001oogoo00Moo`03001oo`0005`0009o
o`03001oogoo00Aoo`001Goo00<007ooHaP0=F<H00=W>F<HHaP016<H00=W>F<HHaP04F<H36Li0Woo
00<007ooOol01goo00<007oo0000G0000Woo00<007ooOol017oo0005Ool00`00OomS600kHaP4IcT7
HaP2IcT4HaP3IcT00f<HIcUW>@0:IcT2Ool00`00Oomoo`07Ool00`00Ool0001L0002Ool00`00Oomo
o`04Ool000Eoo`03001oof<H03]S60AW>@MS609W>@AS60=W>@03HaQW>FLi00YW>@9oo`03001oogoo
00Moo`03001oo`0005`0009oo`03001oogoo00Aoo`001Goo00<007ooHaP0?F<H0VLi2V<H4fLi0Woo
00<007ooOol01goo00<007oo0000G0000Woo00<007ooOol017oo0005Ool00`00OomS600KHaP01FLi
HaQS66<HIcT02f<H0VLi0f<H1FLi0f<H0fLi00=S66LiHaP016<H00AW>F<HHaQS60EW>@03HaQW>FLi
00iW>@9oo`03001oogoo00Moo`03001oo`0005`0009oo`03001oogoo00Aoo`001Goo00<007ooHaP0
6f<H00EW>F<HHaQS66Li00]S609W>@=S60EW>@=S60=W>@03HaQW>F<H00AS6004IcUS66<HHaP5IcT0
0f<HIcUW>@0>IcT2Ool00`00Oomoo`07Ool00`00Ool0001L0002Ool00`00Oomoo`04Ool000Eoo`03
001oof<H009S6003IcUS66<H025S609W>@=S609W>@aS60AW>@US61IW>@9oo`03001oogoo00Moo`03
001oo`0005`0009oo`03001oogoo00Aoo`001Goo00<007ooHaP08f<H1FLi1F<H0VLi36<H00=W>F<H
HaP026<H5VLi0Woo00<007ooOol01goo00<007oo0000G0000Woo00<007ooOol017oo0005Ool00`00
OomS600SHaP5IcT5HaP2IcT<HaP00fLiHaQS6008HaPFIcT2Ool00`00Oomoo`07Ool00`00Ool0001L
0002Ool00`00Oomoo`04Ool000Eoo`03001oof<H01mS6003IcUS66<H00=S60=W>@ES609W>@03HaQW
>FLi00AS60=W>@9S6003IcUS66<H00MS61MW>@9oo`03001oogoo00Moo`03001oo`0005`0009oo`03
001oogoo00Aoo`001Goo00<007ooHaP01V<H0VLi5V<H0VLi36<H0fLi2F<H00=W>F<HHaP00VLi2F<H
5VLi0Woo00<007ooOol01goo00<007oo0000G0000Woo00<007ooOol017oo0005Ool00`00OomS600L
HaP2IcT016<HIcUW>FLi1V<H00=W>F<HHaP026Li0f<H1fLi0V<H00=W>F<HHaP06VLi0Woo00<007oo
Ool01goo00<007oo0000G0000Woo00<007ooOol017oo0005Ool00`00OomS600LHaP2IcT016<HIcUW
>FLi1V<H00=W>F<HHaP026Li0f<H1fLi0V<H00=W>F<HHaP06VLi0Woo00<007ooOol01goo00<007oo
0000G0000Woo00<007ooOol017oo0005Ool00`00OomW>@0BHaP00fLiHaQS6007HaP6IcT4HaP6IcT0
0f<HIcUW>@0]IcT2Ool00`00Oomoo`07Ool00`00Ool0001L0002Ool00`00Oomoo`04Ool000Eoo`03
001oofLi01]S60EW>@QS60YW>@04HaQW>FLiHaPVIcT2Ool00`00Oomoo`07Ool00`00Ool0001L0002
Ool00`00Oomoo`04Ool000Eoo`03001oofLi01]S60EW>@QS60YW>@04HaQW>FLiHaPVIcT2Ool00`00
Oomoo`07Ool00`00Ool0001L0002Ool00`00Oomoo`04Ool000Eoo`03001oof<H01US60MW>@9S6003
IcUS66<H00=S60=W>@03HaQW>FLi00MW>@AS609W>@AS6003IcUS66<H01YW>@9oo`03001oogoo00Mo
o`03001oo`0005`0009oo`03001oogoo00Aoo`001Goo00<007ooIcT06F<H0fLi0f<H00=W>F<HHaP0
56Li0V<H0fLi16<H7FLi0Woo00<007ooOol01goo00<007oo0000G0000Woo00<007ooOol017oo0005
Ool00`00OomW>@0IHaP3IcT3HaP00fLiHaQS600DIcT2HaP3IcT4HaPMIcT2Ool00`00Oomoo`07Ool0
0`00Ool0001L0002Ool00`00Oomoo`04Ool000Eoo`03001oofLi00aS609W>@03HaQW>F<H00]S61YW
>@9S60=W>@03HaQW>F<H009S61aW>@9oo`03001oogoo00Moo`03001oo`0005`0009oo`03001oogoo
00Aoo`001Goo00<007ooHaP00V<H00=W>F<HHaP04f<H0fLi00=S66LiIcT00VLi0V<H00=W>F<HHaP0
2VLi00=S66LiIcT016Li0V<H1fLi0f<H6VLi0Woo00<007ooOol01goo00<007oo0000G0000Woo00<0
07ooOol017oo0005Ool00`00OomS6002HaP00fLiHaQS600CHaP3IcT00f<HIcUW>@02IcT2HaP00fLi
HaQS600:IcT00f<HIcUW>@04IcT2HaP7IcT3HaPJIcT2Ool00`00Oomoo`07Ool00`00Ool0001L0002
Ool00`00Oomoo`04Ool000Eoo`03001oofLi00ES6003IcUS66<H00=S6003IcUS66<H00AW>@YS60AW
>@=S619W>@03HaQW>FLi00AS60=W>@=S61YW>@9oo`03001oogoo00Moo`03001oo`0005`0009oo`03
001oogoo00Aoo`001Goo00<007ooHaP01F<H00=W>F<HHaP00f<H1FLi0V<H00AW>F<HHaQS609W>@03
HaQW>FLi00QW>@9S60AW>@9S60eW>@03HaQW>FLi009W>@=S61aW>@9oo`03001oogoo00Moo`03001o
o`0005`0009oo`03001oogoo00Aoo`001Goo00<007ooHaP01F<H00=W>F<HHaP00f<H1FLi0V<H00AW
>F<HHaQS609W>@03HaQW>FLi00QW>@9S60AW>@9S60eW>@03HaQW>FLi009W>@=S61aW>@9oo`03001o
ogoo00Moo`03001oo`0005`0009oo`03001oogoo00Aoo`001Goo00<007ooIcT00fLi0V<H00=W>F<H
HaP00f<H00=W>F<HHaP02VLi00=S66LiIcT01FLi0V<H0fLi00=S66LiIcT02fLi0V<H26Li1V<H6FLi
0Woo00<007ooOol01goo00<007oo0000G0000Woo00<007ooOol017oo0005Ool00`00Oomoo`1NOol0
0`00Oomoo`07Ool00`00Oomoo`1NOol00`00Oomoo`04Ool000Eoof8000Uoof8000Ioo`00f7oo003H
Ool00=Qoo`00f7oo003HOol00001\
\>"],
  ImageRangeCache->{{{0, 215}, {215, 0}} -> {-0.0500105, -0.0500105, 
  0.00976755, 0.00976755}, {{5.0625, 102.625}, {209.875, 
  112.375}} -> {-4.82854, -4.84991, 0.683991, 0.683991}, {{112.375, 
  209.875}, {209.875, 112.375}} -> {-78.2787, -4.8736, 0.68443, 0.68443}, {{
  5.0625, 102.625}, {102.625, 5.0625}} -> {-4.82854, -78.2293, 0.683991, 
  0.683991}, {{112.375, 209.875}, {102.625, 5.0625}} -> {-78.2787, -78.3001, 
  0.68443, 0.68443}}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["HISTOGRAM MODIFICATION", "Section"],

Cell[TextData[{
  "An important concept common to many image enhancement operations is that \
of a ",
  StyleBox["histogram",
    FontSlant->"Italic"],
  ", which is a count of the luminance values occuring in the image.  The \
histogram of an image is simply a count (or relative frequency, if \
normalized) of the various gray levels in the image.  Image enhancement by \
histogram modeling is a useful and powerful technique.  Histogram modeling \
techniques modify an image histogram so that it has some desired shape.  ",
  StyleBox["Histogram equalization",
    FontSlant->"Italic"],
  ", also known as ",
  StyleBox["linearization",
    FontSlant->"Italic"],
  ", is the most widely used method of enhancing low contrast images.  Image \
histograms are also important in other applications of image processing, most \
notably compression and thresholding."
}], "Text"],

Cell["Here we calculate  the histogram of a low-contrast image.", "Caption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(ListPlot[h = Histogram[B], PlotJoined \[Rule] True, 
      PlotRange \[Rule] All]; \)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0200747 0.00373483 0.0147151 0.00115187 [
[.20682 .00222 -6 -9 ]
[.20682 .00222 6 0 ]
[.39356 .00222 -9 -9 ]
[.39356 .00222 9 0 ]
[.5803 .00222 -9 -9 ]
[.5803 .00222 9 0 ]
[.76704 .00222 -9 -9 ]
[.76704 .00222 9 0 ]
[.95378 .00222 -9 -9 ]
[.95378 .00222 9 0 ]
[.00757 .1299 -18 -4.5 ]
[.00757 .1299 0 4.5 ]
[.00757 .24509 -18 -4.5 ]
[.00757 .24509 0 4.5 ]
[.00757 .36028 -18 -4.5 ]
[.00757 .36028 0 4.5 ]
[.00757 .47546 -18 -4.5 ]
[.00757 .47546 0 4.5 ]
[.00757 .59065 -18 -4.5 ]
[.00757 .59065 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.20682 .01472 m
.20682 .02097 L
s
[(50)] .20682 .00222 0 1 Mshowa
.39356 .01472 m
.39356 .02097 L
s
[(100)] .39356 .00222 0 1 Mshowa
.5803 .01472 m
.5803 .02097 L
s
[(150)] .5803 .00222 0 1 Mshowa
.76704 .01472 m
.76704 .02097 L
s
[(200)] .76704 .00222 0 1 Mshowa
.95378 .01472 m
.95378 .02097 L
s
[(250)] .95378 .00222 0 1 Mshowa
.125 Mabswid
.05742 .01472 m
.05742 .01847 L
s
.09477 .01472 m
.09477 .01847 L
s
.13212 .01472 m
.13212 .01847 L
s
.16947 .01472 m
.16947 .01847 L
s
.24416 .01472 m
.24416 .01847 L
s
.28151 .01472 m
.28151 .01847 L
s
.31886 .01472 m
.31886 .01847 L
s
.35621 .01472 m
.35621 .01847 L
s
.43091 .01472 m
.43091 .01847 L
s
.46825 .01472 m
.46825 .01847 L
s
.5056 .01472 m
.5056 .01847 L
s
.54295 .01472 m
.54295 .01847 L
s
.61765 .01472 m
.61765 .01847 L
s
.655 .01472 m
.655 .01847 L
s
.69234 .01472 m
.69234 .01847 L
s
.72969 .01472 m
.72969 .01847 L
s
.80439 .01472 m
.80439 .01847 L
s
.84174 .01472 m
.84174 .01847 L
s
.87908 .01472 m
.87908 .01847 L
s
.91643 .01472 m
.91643 .01847 L
s
.99113 .01472 m
.99113 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02007 .1299 m
.02632 .1299 L
s
[(100)] .00757 .1299 1 0 Mshowa
.02007 .24509 m
.02632 .24509 L
s
[(200)] .00757 .24509 1 0 Mshowa
.02007 .36028 m
.02632 .36028 L
s
[(300)] .00757 .36028 1 0 Mshowa
.02007 .47546 m
.02632 .47546 L
s
[(400)] .00757 .47546 1 0 Mshowa
.02007 .59065 m
.02632 .59065 L
s
[(500)] .00757 .59065 1 0 Mshowa
.125 Mabswid
.02007 .03775 m
.02382 .03775 L
s
.02007 .06079 m
.02382 .06079 L
s
.02007 .08383 m
.02382 .08383 L
s
.02007 .10686 m
.02382 .10686 L
s
.02007 .15294 m
.02382 .15294 L
s
.02007 .17598 m
.02382 .17598 L
s
.02007 .19901 m
.02382 .19901 L
s
.02007 .22205 m
.02382 .22205 L
s
.02007 .26813 m
.02382 .26813 L
s
.02007 .29116 m
.02382 .29116 L
s
.02007 .3142 m
.02382 .3142 L
s
.02007 .33724 m
.02382 .33724 L
s
.02007 .38331 m
.02382 .38331 L
s
.02007 .40635 m
.02382 .40635 L
s
.02007 .42939 m
.02382 .42939 L
s
.02007 .45242 m
.02382 .45242 L
s
.02007 .4985 m
.02382 .4985 L
s
.02007 .52154 m
.02382 .52154 L
s
.02007 .54457 m
.02382 .54457 L
s
.02007 .56761 m
.02382 .56761 L
s
.02007 .61369 m
.02382 .61369 L
s
.25 Mabswid
.02007 0 m
.02007 .61803 L
s
.5 Mabswid
.02381 .01472 m
.02754 .01472 L
.03128 .01472 L
.03501 .01472 L
.03875 .01472 L
.04248 .01472 L
.04622 .01472 L
.04995 .01472 L
.05369 .01472 L
.05742 .01472 L
.06116 .01472 L
.06489 .01472 L
.06863 .01472 L
.07236 .01472 L
.0761 .01472 L
.07983 .01472 L
.08357 .01472 L
.0873 .01472 L
.09104 .01472 L
.09477 .01472 L
.09851 .01472 L
.10224 .01472 L
.10598 .01472 L
.10971 .01472 L
.11345 .01472 L
.11718 .01472 L
.12092 .01472 L
.12465 .01472 L
.12838 .01472 L
.13212 .01472 L
.13585 .01472 L
.13959 .01472 L
.14332 .01472 L
.14706 .01472 L
.15079 .01472 L
.15453 .01472 L
.15826 .01472 L
.162 .01472 L
.16573 .01472 L
.16947 .01472 L
.1732 .01472 L
.17694 .01472 L
.18067 .01472 L
.18441 .01472 L
.18814 .01472 L
.19188 .01472 L
.19561 .01472 L
.19935 .01472 L
.20308 .01472 L
.20682 .01472 L
Mistroke
.21055 .02047 L
.21429 .07346 L
.21802 .12299 L
.22176 .13221 L
.22549 .17598 L
.22923 .34415 L
.23296 .44091 L
.23669 .60332 L
.24043 .53421 L
.24416 .36028 L
.2479 .2232 L
.25163 .20592 L
.25537 .13796 L
.2591 .10226 L
.26284 .09535 L
.26657 .05503 L
.27031 .07922 L
.27404 .04812 L
.27778 .04927 L
.28151 .04351 L
.28525 .03775 L
.28898 .03314 L
.29272 .04006 L
.29645 .04121 L
.30019 .0343 L
.30392 .03084 L
.30766 .03314 L
.31139 .0366 L
.31513 .0366 L
.31886 .0366 L
.3226 .03199 L
.32633 .02623 L
.33007 .03775 L
.3338 .03199 L
.33754 .03084 L
.34127 .0343 L
.345 .02969 L
.34874 .02969 L
.35247 .03545 L
.35621 .03545 L
.35994 .02508 L
.36368 .03545 L
.36741 .0343 L
.37115 .02393 L
.37488 .03199 L
.37862 .02854 L
.38235 .02739 L
.38609 .03314 L
.38982 .02163 L
.39356 .02393 L
Mistroke
.39729 .02739 L
.40103 .02278 L
.40476 .02508 L
.4085 .02393 L
.41223 .02393 L
.41597 .03084 L
.4197 .01932 L
.42344 .02739 L
.42717 .02393 L
.43091 .02854 L
.43464 .02969 L
.43838 .02163 L
.44211 .02278 L
.44585 .02393 L
.44958 .02623 L
.45331 .02393 L
.45705 .02623 L
.46078 .02278 L
.46452 .02623 L
.46825 .02393 L
.47199 .02278 L
.47572 .02163 L
.47946 .02278 L
.48319 .03084 L
.48693 .02047 L
.49066 .02163 L
.4944 .02047 L
.49813 .02508 L
.50187 .02854 L
.5056 .02508 L
.50934 .02623 L
.51307 .02393 L
.51681 .02393 L
.52054 .02393 L
.52428 .02047 L
.52801 .02163 L
.53175 .02969 L
.53548 .02393 L
.53922 .01817 L
.54295 .02393 L
.54669 .02047 L
.55042 .01932 L
.55415 .02393 L
.55789 .02278 L
.56162 .02047 L
.56536 .02393 L
.56909 .01932 L
.57283 .02047 L
.57656 .01817 L
.5803 .01587 L
Mistroke
.58403 .01932 L
.58777 .01587 L
.5915 .01817 L
.59524 .01472 L
.59897 .01472 L
.60271 .01702 L
.60644 .01587 L
.61018 .02047 L
.61391 .01472 L
.61765 .01817 L
.62138 .01587 L
.62512 .01932 L
.62885 .01817 L
.63259 .01702 L
.63632 .01472 L
.64006 .01702 L
.64379 .02047 L
.64753 .01587 L
.65126 .01932 L
.655 .02278 L
.65873 .01932 L
.66246 .02163 L
.6662 .01702 L
.66993 .01817 L
.67367 .01587 L
.6774 .01587 L
.68114 .01587 L
.68487 .01932 L
.68861 .01702 L
.69234 .02278 L
.69608 .01702 L
.69981 .01587 L
.70355 .01932 L
.70728 .02508 L
.71102 .02278 L
.71475 .01702 L
.71849 .01817 L
.72222 .02047 L
.72596 .01702 L
.72969 .01932 L
.73343 .02163 L
.73716 .02163 L
.7409 .01932 L
.74463 .01587 L
.74837 .01932 L
.7521 .01817 L
.75584 .01932 L
.75957 .01817 L
.76331 .02047 L
.76704 .01817 L
Mistroke
.77077 .01817 L
.77451 .01702 L
.77824 .01817 L
.78198 .01702 L
.78571 .01472 L
.78945 .01472 L
.79318 .01472 L
.79692 .01472 L
.80065 .01472 L
.80439 .01472 L
.80812 .01472 L
.81186 .01472 L
.81559 .01472 L
.81933 .01472 L
.82306 .01472 L
.8268 .01472 L
.83053 .01472 L
.83427 .01472 L
.838 .01472 L
.84174 .01472 L
.84547 .01472 L
.84921 .01472 L
.85294 .01472 L
.85668 .01472 L
.86041 .01472 L
.86415 .01472 L
.86788 .01472 L
.87162 .01472 L
.87535 .01472 L
.87908 .01472 L
.88282 .01472 L
.88655 .01472 L
.89029 .01472 L
.89402 .01472 L
.89776 .01472 L
.90149 .01472 L
.90523 .01472 L
.90896 .01472 L
.9127 .01472 L
.91643 .01472 L
.92017 .01472 L
.9239 .01472 L
.92764 .01472 L
.93137 .01472 L
.93511 .01472 L
.93884 .01472 L
.94258 .01472 L
.94631 .01472 L
.95005 .01472 L
.95378 .01472 L
Mistroke
.95752 .01472 L
.96125 .01472 L
.96499 .01472 L
.96872 .01472 L
.97246 .01472 L
.97619 .01472 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{216, 133.438},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003H0000QA000`40O003h00Of7oo003HOol003Io
o`03001oogoo009oo`03001oogoo01Uoo`D0009oo`03001oogoo009oo`03001oogoo01Ioo`D0009o
o`03001oogoo009oo`03001oogoo01Moo`<000=oo`03001oogoo009oo`03001oogoo01Moo`<000=o
o`03001oogoo009oo`03001oogoo00=oo`00=Goo00<007oo00000Woo00<007oo000077oo00L007oo
Oomoo`00Ool00002Ool00`00Ool0000IOol01`00Oomoogoo001oo`00009oo`03001oo`0001Qoo`03
001oogoo009oo`03001oo`00009oo`03001oo`0001Qoo`03001oogoo009oo`03001oo`00009oo`03
001oo`0000Aoo`00=goo00H007ooOol007oo000LOol01`00Oomoogoo001oo`00009oo`03001oo`00
01Uoo`03001oogoo00=oo`06001oogoo001oo`006Goo00L007ooOomoo`00Ool00002Ool00`00Ool0
000IOol00`00Oomoo`03Ool01P00Oomoo`00Ool000Aoo`00=Goo0P000goo00<007oo000077oo00L0
07ooOomoo`00Ool00002Ool00`00Ool0000IOol01000Oomoogoo0P000goo00<007oo00006Goo00L0
07ooOomoo`00Ool00002Ool00`00Ool0000IOol01000Oomoogoo0P000goo00<007oo000017oo000e
Ool00`00Oomoo`02Ool00`00Ool0000LOol01`00Oomoogoo001oo`00009oo`03001oo`0001Uoo`05
001oogooOol00004Ool00`00Ool0000HOol00`00Ool00002Ool00`00Ool00002Ool00`00Ool0000H
Ool00`00Ool00002Ool00`00Oomoo`02Ool00`00Ool00004Ool003Eoo`<000=oo`03001oogoo01Yo
o`8000Aoo`03001oogoo009oo`03001oogoo01Moo`8000=oo`<000=oo`03001oogoo01Qoo`03001o
ogoo009oo`03001oogoo009oo`03001oogoo01Qoo`04001oogooOol30003Ool00`00Oomoo`03Ool0
0=Qoo`0057oo00<007ooOol0`Goo000DOol00`00Oomoo`31Ool001Aoo`03001oogoo0<5oo`0047oo
b000000DOol00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00
Oomoo`04Ool20005Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`04
Ool00`00Oomoo`02Ool01000Oomoo`001Woo00@007ooOomoo`800003Ool007oo009oo`03001oogoo
00<00003Ool007oo00D0009oo`800003Ool0000000T0009oo`<00003Ool007oo00@00003Ool007oo
00L000Aoo`03001oogoo00Aoo`03001oogoo00Aoo`03001oogoo00Eoo`03001oogoo00Aoo`03001o
ogoo00Eoo`40005oo`5oo`0057oo00<007ooOol08goo00<007ooOol057oo00<007ooOol00goo00@0
07ooOol0009oo`800003Ool0000000800003Ool007oo00/00003Ool0000000<00006Ool00000Ool0
07oo0`004Goo0P001Goo00<007ooOol00P0017oo00<007ooOol0<goo000DOol00`00Oomoo`0SOol0
0`00Oomoo`0?Ool01000Oomoogoo0P0000Moo`00000007oo001oo`0500000goo001oo`02Ool20000
0goo001oo`08Ool01@00Oomoogoo00001Goo00<007ooOol0Fgoo000DOol00`00Oomoo`0SOol00`00
Oomoo`0<Ool00`00Oomoo`0500001Goo001oo`00Ool01@000Woo00<007ooOol0N7oo000DOol2000T
Ool00`00Oomoo`0<Ool30006Ool00`00Oomoo`23Ool001Aoo`03001oogoo02=oo`03001oogoo00]o
o`03001oogoo08eoo`0057oo00<007ooOol097oo00<007ooOol027oo0P00T7oo000DOol00`00Oomo
o`0TOol00`00Oomoo`07Ool2002AOol001Aoo`8002Eoo`03001oogoo00Moo`80095oo`0057oo00<0
07ooOol097oo00<007ooOol01goo0P00TGoo000DOol00`00Oomoo`0TOol00`00Oomoo`07Ool2002A
Ool001Aoo`03001oogoo02Aoo`03001oogoo00Ioo`03001oo`00095oo`0057oo00<007ooOol097oo
00<007ooOol01Woo00<007oo0000TGoo000DOol2000UOol00`00Oomoo`06Ool00`00Oomoo`2AOol0
01Aoo`03001oogoo02Aoo`03001oogoo00Ioo`03001oogoo095oo`0057oo00<007ooOol097oo00<0
07ooOol01Woo00<007ooOol0TGoo000DOol00`00Oomoo`0TOol00`00Oomoo`05Ool00`00Oomoo`2B
Ool001Aoo`8002Eoo`03001oogoo00Eoo`03001oogoo099oo`0057oo00<007ooOol097oo00<007oo
Ool01Goo00<007ooOol0TWoo000DOol00`00Oomoo`0TOol00`00Oomoo`05Ool00`00Oomoo`2BOol0
00=oo`D0009oo`03001oogoo009oo`03001oogoo009oo`03001oogoo02Aoo`03001oogoo00Eoo`03
001oogoo099oo`001Goo00L007ooOomoo`00Ool00002Ool00`00Ool00003Ool00`00Oomoo`0TOol0
0`00Oomoo`05Ool00`00Oomoo`2BOol000Eoo`07001oogooOol007oo00000Woo00<007oo00000goo
0P009Woo00<007ooOol017oo00<007ooOol0TWoo0005Ool01`00Oomoogoo001oo`00009oo`03001o
o`0000=oo`03001oogoo02Eoo`03001oogoo00Aoo`03001oogoo099oo`001Goo00L007ooOomoo`00
Ool00002Ool00`00Ool00003Ool00`00Oomoo`0UOol00`00Oomoo`04Ool00`00Oomoo`2BOol000Ao
o`8000Aoo`03001oogoo009oo`03001oogoo009oo`03001oogoo02Eoo`03001oogoo00Aoo`03001o
ogoo099oo`0057oo00<007ooOol09Goo00<007ooOol017oo00<007ooOol0TWoo000DOol2000WOol0
0`00Oomoo`03Ool00`00Oomoo`2BOol001Aoo`03001oogoo02Ioo`03001oogoo00=oo`03001oogoo
099oo`0057oo00<007ooOol09Woo00<007ooOol00goo00<007ooOol0TWoo000DOol00`00Oomoo`0V
Ool00`00Oomoo`03Ool00`00Oomoo`2BOol001Aoo`8002Moo`03001oogoo009oo`03001oogoo09=o
o`0057oo00<007ooOol09Woo00<007ooOol00Woo00<007ooOol0Tgoo000DOol00`00Oomoo`0VOol0
0`00Oomoo`02Ool00`00Oomoo`2COol001Aoo`03001oogoo02Ioo`03001oogoo009oo`03001oogoo
09=oo`0057oo00<007ooOol09Woo00<007ooOol00Woo00<007ooOol0Tgoo000DOol2000WOol00`00
Oomoo`02Ool00`00Oomoo`2COol001Aoo`03001oogoo02Ioo`03001oogoo009oo`03001oogoo09=o
o`0057oo00<007ooOol09Woo00<007ooOol00Woo00<007ooOol0Tgoo000DOol00`00Oomoo`0VOol0
1@00Oomoogoo0000UWoo000DOol2000WOol01@00Oomoogoo0000UWoo000DOol00`00Oomoo`0VOol0
1@00Oomoogoo0000UWoo000DOol00`00Oomoo`0VOol01@00Oomoogoo0000UWoo0004Ool30003Ool0
0`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`0VOol01@00Oomoogoo0000UWoo0004Ool00`00
Oomoo`02Ool00`00Ool00002Ool00`00Ool00003Ool00`00Oomoo`0VOol01@00Oomoogoo0000UWoo
0005Ool01`00Oomoogoo001oo`00009oo`03001oo`0000=oo`8002Moo`05001oogooOol0002FOol0
00Eoo`07001oogooOol007oo00000Woo00<007oo00000goo00<007ooOol09Woo00D007ooOomoo`00
09Ioo`0017oo00<007oo00000Woo00<007oo00000Woo00<007oo00000goo00<007ooOol09Woo00D0
07ooOomoo`0009Ioo`001Goo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol00Woo00<007oo
Ool09Woo00D007ooOomoo`0009Ioo`0057oo0P00:7oo00@007ooOol009Ioo`0057oo00<007ooOol0
9goo00@007ooOol009Ioo`0057oo00<007ooOol09goo00@007ooOol009Ioo`0057oo00<007ooOol0
9goo00@007ooOol009Ioo`0057oo00<007ooOol09goo00@007ooOol009Ioo`0057oo0P00:7oo00@0
07ooOol009Ioo`0057oo00<007ooOol09goo00<007oo0000Ugoo000DOol00`00Oomoo`0WOol00`00
Ool0002GOol001Aoo`03001oogoo02Moo`03001oo`0009Moo`0057oo00<007ooOol09goo00<007oo
0000Ugoo000DOol2000XOol00`00Ool0002GOol001Aoo`03001oogoo02Moo`03001oo`0009Moo`00
57oo00<007ooOol09goo00<007oo0000Ugoo000DOol00`00Oomoo`0WOol00`00Ool0002GOol001Ao
o`8002Qoo`03001oo`0009Moo`0057oo00<007ooOol09goo00<007oo0000Ugoo000DOol00`00Oomo
o`0WOol00`00Ool0002GOol000Aoo`8000Aoo`03001oogoo009oo`03001oogoo009oo`03001oogoo
02Moo`03001oo`0009Moo`001Woo00H007ooOol007oo0002Ool00`00Ool00003Ool00`00Oomoo`0W
Ool00`00Ool0002GOol000Eoo`07001oogooOol007oo00000Woo00<007oo00000goo0P00:7oo00<0
07oo0000Ugoo0006Ool01P00Oomoo`00Ool0009oo`03001oo`0000=oo`03001oogoo02Moo`03001o
o`0009Moo`0017oo00<007oo00000Woo00<007oo00000Woo00<007oo00000goo00<007ooOol09goo
00<007oo0000Ugoo0005Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomo
o`0WOol00`00Ool0002GOol001Aoo`8002Qoo`03001oo`0009Moo`0057oo00<007ooOol09goo00<0
07oo0000Ugoo000DOol00`00Oomoo`0WOol00`00Ool0002GOol001Aoo`03001oogoo02Moo`03001o
o`0009Moo`0057oo00<007ooOol09goo00<007oo0000Ugoo000DOol2000XOol00`00Ool0002GOol0
01Aoo`03001oogoo02Moo`03001oo`0009Moo`0057oo00<007ooOol09goo00<007oo0000Ugoo000D
Ool00`00Oomoo`0WOol00`00Ool0002GOol001Aoo`8002Qoo`03001oo`0009Moo`0057oo00<007oo
Ool09goo00<007oo0000Ugoo000DOol00`00Oomoo`0WOol00`00Ool0002GOol001Aoo`03001oogoo
02Moo`03001oo`0009Moo`0057oo00<007ooOol09goo00<007oo0000Ugoo000DOol2000XOol00`00
Ool0002GOol001Aoo`03001oogoo02Moo`03001oo`0009Moo`0057oo00<007ooOol09goo00<007oo
0000Ugoo0005Ool30002Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`0WOol00`00Ool0
002GOol000Ioo`06001oogoo001oo`000Woo00<007oo00000goo00<007ooOol09goo00<007oo0000
Ugoo0004Ool4000017oo001oo`000Woo00<007oo00000goo0P00:7oo00<007oo0000Ugoo0004Ool0
0`00Ool00002Ool00`00Ool00002Ool00`00Ool00003Ool00`00Oomoo`0WOol00`00Ool0002GOol0
00Eoo`80009oo`03001oo`00009oo`03001oo`0000=oo`03001oogoo02Moo`03001oo`0009Moo`00
1Woo00D007ooOomoo`0000Aoo`03001oogoo009oo`03001oogoo02Moo`03001oo`0009Moo`0057oo
0P00:7oo00<007oo0000Ugoo000DOol00`00Oomoo`0WOol00`00Ool0002GOol001Aoo`03001oogoo
02Moo`03001oo`0009Moo`0057oo00<007ooOol09goo00<007oo0000Ugoo000DOol00`00Oomoo`0W
Ool00`00Ool0002GOol001Aoo`8002Qoo`03001oo`0009Moo`0057oo00<007ooOol0:7oo0P00Ugoo
000DOol00`00Oomoo`0XOol2002GOol001Aoo`03001oogoo02Qoo`8009Moo`0057oo0P00:Goo0P00
Ugoo000DOol00`00Oomoo`0XOol2002GOol001Aoo`03001oogoo02Qoo`8009Moo`0057oo00<007oo
Ool0:7oo0P00Ugoo000DOol00`00Oomoo`0XOol2002GOol001Aoo`8002Uoo`03001oogoo09Ioo`00
57oo00<007ooOol0:7oo00<007ooOol0UWoo0005Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00
Oomoo`02Ool00`00Oomoo`0XOol00`00Oomoo`2FOol000Aoo`03001oo`00009oo`03001oo`00009o
o`03001oo`0000=oo`03001oogoo02Qoo`03001oogoo09Ioo`001Woo00H007ooOol007oo0002Ool0
0`00Ool00003Ool2000YOol00`00Oomoo`2FOol000Aoo`8000=oo`03001oo`00009oo`03001oo`00
00=oo`03001oogoo02Qoo`03001oogoo09Ioo`0017oo00<007ooOol00Woo00<007oo00000Woo00<0
07oo00000goo00<007ooOol0:7oo00<007ooOol0UWoo0004Ool30003Ool00`00Oomoo`02Ool00`00
Oomoo`02Ool00`00Oomoo`0XOol00`00Oomoo`2FOol001Aoo`03001oogoo0<5oo`0057oo0P00`Woo
000DOol00`00Oomoo`31Ool00001\
\>"],
  ImageRangeCache->{{{0, 215}, {132.438, 0}} -> {-27.629, -52.8312, 1.34886, 
  4.37355}}]
}, Open  ]]
}, Open  ]],

Cell["\<\
It is sometimes desirable to modify image contrast by \"equalizing\" the \
probability density of the pixels.  The resulting image histogram is \
approximately uniform.  This has the effect of enhancing the dark areas in an \
image.  The operation is also very effective when a need exists to quantitate \
(compare) images of a scene taken under different lighting conditions.  \
Histogram equalization is typicaly implemented as a point transformation for \
which the input/output mapping is defined by the cumulative histogram \
function of the original image.\
\>", "Text"],

Cell["\<\
Here we calculate the cumulative histogram of the example image.\
\>", "Caption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(ListPlot[CumulativeHistogram[h], PlotJoined \[Rule] True]; \)\)], 
  "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00372024 0.0147151 0.588604 [
[.20982 .00222 -6 -9 ]
[.20982 .00222 6 0 ]
[.39583 .00222 -9 -9 ]
[.39583 .00222 9 0 ]
[.58185 .00222 -9 -9 ]
[.58185 .00222 9 0 ]
[.76786 .00222 -9 -9 ]
[.76786 .00222 9 0 ]
[.95387 .00222 -9 -9 ]
[.95387 .00222 9 0 ]
[.01131 .13244 -18 -4.5 ]
[.01131 .13244 0 4.5 ]
[.01131 .25016 -18 -4.5 ]
[.01131 .25016 0 4.5 ]
[.01131 .36788 -18 -4.5 ]
[.01131 .36788 0 4.5 ]
[.01131 .4856 -18 -4.5 ]
[.01131 .4856 0 4.5 ]
[.01131 .60332 -6 -4.5 ]
[.01131 .60332 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.20982 .01472 m
.20982 .02097 L
s
[(50)] .20982 .00222 0 1 Mshowa
.39583 .01472 m
.39583 .02097 L
s
[(100)] .39583 .00222 0 1 Mshowa
.58185 .01472 m
.58185 .02097 L
s
[(150)] .58185 .00222 0 1 Mshowa
.76786 .01472 m
.76786 .02097 L
s
[(200)] .76786 .00222 0 1 Mshowa
.95387 .01472 m
.95387 .02097 L
s
[(250)] .95387 .00222 0 1 Mshowa
.125 Mabswid
.06101 .01472 m
.06101 .01847 L
s
.09821 .01472 m
.09821 .01847 L
s
.13542 .01472 m
.13542 .01847 L
s
.17262 .01472 m
.17262 .01847 L
s
.24702 .01472 m
.24702 .01847 L
s
.28423 .01472 m
.28423 .01847 L
s
.32143 .01472 m
.32143 .01847 L
s
.35863 .01472 m
.35863 .01847 L
s
.43304 .01472 m
.43304 .01847 L
s
.47024 .01472 m
.47024 .01847 L
s
.50744 .01472 m
.50744 .01847 L
s
.54464 .01472 m
.54464 .01847 L
s
.61905 .01472 m
.61905 .01847 L
s
.65625 .01472 m
.65625 .01847 L
s
.69345 .01472 m
.69345 .01847 L
s
.73065 .01472 m
.73065 .01847 L
s
.80506 .01472 m
.80506 .01847 L
s
.84226 .01472 m
.84226 .01847 L
s
.87946 .01472 m
.87946 .01847 L
s
.91667 .01472 m
.91667 .01847 L
s
.99107 .01472 m
.99107 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02381 .13244 m
.03006 .13244 L
s
[(0.2)] .01131 .13244 1 0 Mshowa
.02381 .25016 m
.03006 .25016 L
s
[(0.4)] .01131 .25016 1 0 Mshowa
.02381 .36788 m
.03006 .36788 L
s
[(0.6)] .01131 .36788 1 0 Mshowa
.02381 .4856 m
.03006 .4856 L
s
[(0.8)] .01131 .4856 1 0 Mshowa
.02381 .60332 m
.03006 .60332 L
s
[(1)] .01131 .60332 1 0 Mshowa
.125 Mabswid
.02381 .04415 m
.02756 .04415 L
s
.02381 .07358 m
.02756 .07358 L
s
.02381 .10301 m
.02756 .10301 L
s
.02381 .16187 m
.02756 .16187 L
s
.02381 .1913 m
.02756 .1913 L
s
.02381 .22073 m
.02756 .22073 L
s
.02381 .27959 m
.02756 .27959 L
s
.02381 .30902 m
.02756 .30902 L
s
.02381 .33845 m
.02756 .33845 L
s
.02381 .39731 m
.02756 .39731 L
s
.02381 .42674 m
.02756 .42674 L
s
.02381 .45617 m
.02756 .45617 L
s
.02381 .51503 m
.02756 .51503 L
s
.02381 .54446 m
.02756 .54446 L
s
.02381 .57389 m
.02756 .57389 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02753 .01472 m
.03125 .01472 L
.03497 .01472 L
.03869 .01472 L
.04241 .01472 L
.04613 .01472 L
.04985 .01472 L
.05357 .01472 L
.05729 .01472 L
.06101 .01472 L
.06473 .01472 L
.06845 .01472 L
.07217 .01472 L
.07589 .01472 L
.07961 .01472 L
.08333 .01472 L
.08705 .01472 L
.09077 .01472 L
.09449 .01472 L
.09821 .01472 L
.10193 .01472 L
.10565 .01472 L
.10937 .01472 L
.1131 .01472 L
.11682 .01472 L
.12054 .01472 L
.12426 .01472 L
.12798 .01472 L
.1317 .01472 L
.13542 .01472 L
.13914 .01472 L
.14286 .01472 L
.14658 .01472 L
.1503 .01472 L
.15402 .01472 L
.15774 .01472 L
.16146 .01472 L
.16518 .01472 L
.1689 .01472 L
.17262 .01472 L
.17634 .01472 L
.18006 .01472 L
.18378 .01472 L
.1875 .01472 L
.19122 .01472 L
.19494 .01472 L
.19866 .01472 L
.20238 .01472 L
.2061 .01472 L
.20982 .01472 L
Mistroke
.21354 .01543 L
.21726 .02276 L
.22098 .03627 L
.2247 .05093 L
.22842 .07105 L
.23214 .11215 L
.23586 .16531 L
.23958 .23875 L
.2433 .30356 L
.24702 .34667 L
.25074 .37268 L
.25446 .39653 L
.25818 .41191 L
.2619 .42283 L
.26563 .43289 L
.26935 .43792 L
.27307 .44597 L
.27679 .45013 L
.28051 .45444 L
.28423 .45804 L
.28795 .46091 L
.29167 .46321 L
.29539 .46637 L
.29911 .46968 L
.30283 .47212 L
.30655 .47413 L
.31027 .47643 L
.31399 .47916 L
.31771 .48189 L
.32143 .48462 L
.32515 .48678 L
.32887 .48821 L
.33259 .49109 L
.33631 .49324 L
.34003 .49525 L
.34375 .4977 L
.34747 .49957 L
.35119 .50143 L
.35491 .50402 L
.35863 .50661 L
.36235 .5079 L
.36607 .51049 L
.36979 .51293 L
.37351 .51408 L
.37723 .51624 L
.38095 .51796 L
.38467 .51954 L
.38839 .52184 L
.39211 .5227 L
.39583 .52385 L
Mistroke
.39955 .52543 L
.40327 .52644 L
.40699 .52773 L
.41071 .52888 L
.41443 .53003 L
.41815 .53204 L
.42188 .53262 L
.4256 .5342 L
.42932 .53535 L
.43304 .53707 L
.43676 .53894 L
.44048 .5398 L
.4442 .54081 L
.44792 .54196 L
.45164 .5434 L
.45536 .54454 L
.45908 .54598 L
.4628 .54699 L
.46652 .54842 L
.47024 .54957 L
.47396 .55058 L
.47768 .55144 L
.4814 .55245 L
.48512 .55446 L
.48884 .55518 L
.49256 .55604 L
.49628 .55676 L
.5 .55805 L
.50372 .55978 L
.50744 .56107 L
.51116 .56251 L
.51488 .56366 L
.5186 .56481 L
.52232 .56596 L
.52604 .56667 L
.52976 .56754 L
.53348 .56941 L
.5372 .57055 L
.54092 .57099 L
.54464 .57214 L
.54836 .57285 L
.55208 .57343 L
.5558 .57458 L
.55952 .57558 L
.56324 .5763 L
.56696 .57745 L
.57068 .57803 L
.5744 .57875 L
.57813 .57918 L
.58185 .57932 L
Mistroke
.58557 .5799 L
.58929 .58004 L
.59301 .58047 L
.59673 .58047 L
.60045 .58047 L
.60417 .58076 L
.60789 .5809 L
.61161 .58162 L
.61533 .58162 L
.61905 .58205 L
.62277 .58219 L
.62649 .58277 L
.63021 .5832 L
.63393 .58349 L
.63765 .58349 L
.64137 .58378 L
.64509 .58449 L
.64881 .58464 L
.65253 .58521 L
.65625 .58622 L
.65997 .58679 L
.66369 .58766 L
.66741 .58794 L
.67113 .58837 L
.67485 .58852 L
.67857 .58866 L
.68229 .5888 L
.68601 .58938 L
.68973 .58967 L
.69345 .59067 L
.69717 .59096 L
.70089 .5911 L
.70461 .59168 L
.70833 .59297 L
.71205 .59398 L
.71577 .59427 L
.71949 .5947 L
.72321 .59542 L
.72693 .5957 L
.73065 .59628 L
.73438 .59714 L
.7381 .598 L
.74182 .59858 L
.74554 .59872 L
.74926 .5993 L
.75298 .59973 L
.7567 .6003 L
.76042 .60073 L
.76414 .60145 L
.76786 .60188 L
Mistroke
.77158 .60231 L
.7753 .6026 L
.77902 .60303 L
.78274 .60332 L
.78646 .60332 L
.79018 .60332 L
.7939 .60332 L
.79762 .60332 L
.80134 .60332 L
.80506 .60332 L
.80878 .60332 L
.8125 .60332 L
.81622 .60332 L
.81994 .60332 L
.82366 .60332 L
.82738 .60332 L
.8311 .60332 L
.83482 .60332 L
.83854 .60332 L
.84226 .60332 L
.84598 .60332 L
.8497 .60332 L
.85342 .60332 L
.85714 .60332 L
.86086 .60332 L
.86458 .60332 L
.8683 .60332 L
.87202 .60332 L
.87574 .60332 L
.87946 .60332 L
.88318 .60332 L
.8869 .60332 L
.89063 .60332 L
.89435 .60332 L
.89807 .60332 L
.90179 .60332 L
.90551 .60332 L
.90923 .60332 L
.91295 .60332 L
.91667 .60332 L
.92039 .60332 L
.92411 .60332 L
.92783 .60332 L
.93155 .60332 L
.93527 .60332 L
.93899 .60332 L
.94271 .60332 L
.94643 .60332 L
.95015 .60332 L
.95387 .60332 L
Mistroke
.95759 .60332 L
.96131 .60332 L
.96503 .60332 L
.96875 .60332 L
.97247 .60332 L
.97619 .60332 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{216, 133.438},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003H0000QA000`40O003h00Of7oo000fOol00`00
Oomoo`02Ool00`00Oomoo`0IOol50002Ool00`00Oomoo`02Ool00`00Oomoo`0FOol50002Ool00`00
Oomoo`02Ool00`00Oomoo`0FOol30003Ool00`00Oomoo`02Ool00`00Oomoo`0GOol30003Ool00`00
Oomoo`02Ool00`00Oomoo`04Ool003Eoo`03001oo`00009oo`03001oo`0001aoo`07001oogooOol0
07oo00000Woo00<007oo00006Goo00L007ooOomoo`00Ool00002Ool00`00Ool0000GOol00`00Oomo
o`02Ool00`00Ool00002Ool00`00Ool0000HOol00`00Oomoo`02Ool00`00Ool00002Ool00`00Ool0
0005Ool003Moo`06001oogoo001oo`0077oo00L007ooOomoo`00Ool00002Ool00`00Ool0000IOol0
0`00Oomoo`03Ool01P00Oomoo`00Ool001Qoo`07001oogooOol007oo00000Woo00<007oo00006Goo
00<007ooOol00goo00H007ooOol007oo0005Ool003Eoo`8000=oo`03001oo`0001aoo`07001oogoo
Ool007oo00000Woo00<007oo00006Goo00@007ooOomoo`8000=oo`03001oo`0001Qoo`07001oogoo
Ool007oo00000Woo00<007oo00006Goo00@007ooOomoo`8000=oo`03001oo`0000Eoo`00=Goo00<0
07ooOol00Woo00<007oo000077oo00L007ooOomoo`00Ool00002Ool00`00Ool0000IOol01@00Oomo
ogoo000017oo00<007oo00005goo00<007oo00000Woo00<007oo00000Woo00<007oo000067oo00<0
07oo00000Woo00<007ooOol00Woo00<007oo00001Goo000eOol30003Ool00`00Oomoo`0JOol20004
Ool00`00Oomoo`02Ool00`00Oomoo`0GOol20003Ool30003Ool00`00Oomoo`0GOol00`00Oomoo`02
Ool00`00Oomoo`02Ool00`00Oomoo`0HOol01000Oomoogoo0`000goo00<007ooOol017oo003HOol0
0=Qoo`005Goo00<007ooOol0`7oo000EOol00`00Oomoo`30Ool001Eoo`03001oogoo0<1oo`0047oo
a`000Goo000EOol00`00Oomoo`0QOol00`00Ool0000ROol00`00Oomoo`0ROol00`00Oomoo`0ROol0
0`00Oomoo`0ROol00`00Oomoo`08Ool001Eoo`03001oogoo02=oo`03001oogoo09Yoo`005Goo00<0
07ooOol097oo00<007ooOol0VGoo000EOol00`00Oomoo`0TOol00`00Oomoo`2IOol001Eoo`03001o
ogoo02Aoo`03001oogoo09Uoo`005Goo00<007ooOol097oo00<007ooOol0VGoo000EOol00`00Oomo
o`0TOol00`00Oomoo`2IOol001Eoo`03001oogoo02Aoo`03001oogoo09Uoo`005Goo00<007ooOol0
97oo00<007ooOol0VGoo000EOol00`00Oomoo`0UOol00`00Oomoo`2HOol001Eoo`03001oogoo02Eo
o`03001oogoo09Qoo`005Goo00<007ooOol09Goo00<007ooOol0V7oo000EOol00`00Oomoo`0UOol0
0`00Oomoo`2HOol001Eoo`03001oogoo02Eoo`03001oogoo09Qoo`005Goo00<007ooOol09Goo00<0
07ooOol0V7oo000EOol00`00Oomoo`0VOol00`00Oomoo`2GOol001Eoo`03001oogoo02Ioo`03001o
ogoo09Moo`005Goo00<007ooOol09Woo00<007ooOol0Ugoo000EOol00`00Oomoo`0VOol00`00Oomo
o`2GOol001Eoo`03001oogoo02Ioo`03001oogoo09Moo`001Goo00<007ooOol00Woo00@007ooOomo
o`<000Aoo`03001oogoo02Ioo`03001oogoo09Moo`0017oo00<007oo00001goo00<007ooOol017oo
00<007ooOol09Woo00<007ooOol0Ugoo0004Ool00`00Ool00008Ool00`00Oomoo`03Ool2000WOol0
0`00Oomoo`2GOol000Aoo`03001oo`0000Qoo`03001oogoo00=oo`03001oogoo02Ioo`03001oogoo
09Moo`0017oo00<007oo00001goo00<007oo000017oo00<007ooOol09goo00<007ooOol0UWoo0005
Ool00`00Oomoo`07Ool00`00Oomoo`03Ool00`00Oomoo`0WOol00`00Oomoo`2FOol001Eoo`03001o
ogoo02Moo`03001oogoo09Ioo`005Goo00<007ooOol09goo00<007ooOol0UWoo000EOol00`00Oomo
o`0WOol00`00Oomoo`2FOol001Eoo`03001oogoo02Moo`03001oogoo09Ioo`005Goo00<007ooOol0
9goo00<007ooOol0UWoo000EOol00`00Oomoo`0WOol00`00Oomoo`2FOol001Eoo`03001oogoo02Mo
o`03001oogoo09Ioo`005Goo00<007ooOol09goo00<007ooOol0UWoo000EOol00`00Oomoo`0WOol0
0`00Oomoo`2FOol001Eoo`03001oogoo02Moo`03001oogoo09Ioo`005Goo00<007ooOol09goo00<0
07ooOol0UWoo000EOol00`00Oomoo`0WOol00`00Oomoo`2FOol001Eoo`03001oogoo02Moo`03001o
ogoo09Ioo`005Goo00<007ooOol09goo00<007ooOol0UWoo000EOol00`00Oomoo`0WOol00`00Oomo
o`2FOol001Eoo`03001oogoo02Moo`03001oogoo09Ioo`005Goo00<007ooOol09goo00<007ooOol0
UWoo0005Ool00`00Oomoo`02Ool00`00Oomoo`02Ool30003Ool00`00Oomoo`0WOol00`00Oomoo`2F
Ool000Aoo`03001oo`0000Uoo`03001oogoo009oo`03001oogoo02Moo`03001oogoo09Ioo`0017oo
00<007oo00001goo10000goo0P00:7oo00<007ooOol0UWoo0004Ool00`00Ool00007Ool00`00Ool0
0004Ool00`00Oomoo`0WOol00`00Oomoo`2FOol000Aoo`03001oo`0000Qoo`8000Aoo`03001oogoo
02Moo`03001oogoo09Ioo`001Goo00<007ooOol027oo00<007ooOol00Woo00<007ooOol09goo00<0
07ooOol0UWoo000EOol00`00Oomoo`0WOol00`00Oomoo`2FOol001Eoo`03001oogoo02Qoo`03001o
ogoo09Eoo`005Goo00<007ooOol0:7oo00<007ooOol0UGoo000EOol00`00Oomoo`0XOol00`00Oomo
o`2EOol001Eoo`03001oogoo02Qoo`03001oogoo09Eoo`005Goo00<007ooOol0:7oo00<007ooOol0
UGoo000EOol00`00Oomoo`0XOol00`00Oomoo`2EOol001Eoo`03001oogoo02Qoo`03001oogoo09Eo
o`005Goo00<007ooOol0:7oo00<007ooOol0UGoo000EOol00`00Oomoo`0XOol00`00Oomoo`2EOol0
01Eoo`03001oogoo02Qoo`03001oogoo09Eoo`005Goo00<007ooOol0:7oo00<007ooOol0UGoo000E
Ool00`00Oomoo`0YOol00`00Oomoo`2DOol001Eoo`03001oogoo02Uoo`03001oogoo09Aoo`005Goo
00<007ooOol0:Goo00<007ooOol0U7oo000EOol00`00Oomoo`0YOol00`00Oomoo`2DOol001Eoo`03
001oogoo02Uoo`03001oogoo09Aoo`001Goo00<007ooOol00Woo00@007ooOomoo`8000Eoo`03001o
ogoo02Uoo`03001oogoo09Aoo`0017oo00<007oo00001goo00<007oo000017oo00<007ooOol0:Woo
00<007ooOol0Tgoo0004Ool00`00Ool00007Ool00`00Ool00004Ool2000[Ool00`00Oomoo`2COol0
00Aoo`03001oo`0000Moo`8000Eoo`03001oogoo02Yoo`03001oogoo09=oo`0017oo00<007oo0000
1goo00<007ooOol017oo00<007ooOol0:Woo00<007ooOol0Tgoo0005Ool00`00Oomoo`07Ool20004
Ool00`00Oomoo`0ZOol00`00Oomoo`2COol001Eoo`03001oogoo02Yoo`03001oogoo09=oo`005Goo
00<007ooOol0:Woo00<007ooOol0Tgoo000EOol00`00Oomoo`0ZOol00`00Oomoo`2COol001Eoo`03
001oogoo02Yoo`03001oogoo09=oo`005Goo00<007ooOol0:goo00<007ooOol0TWoo000EOol00`00
Oomoo`0[Ool00`00Oomoo`2BOol001Eoo`03001oogoo02]oo`03001oogoo099oo`005Goo00<007oo
Ool0;7oo00<007ooOol0TGoo000EOol00`00Oomoo`0/Ool00`00Oomoo`2AOol001Eoo`03001oogoo
02eoo`03001oogoo091oo`005Goo00<007ooOol0;Goo00<007ooOol0T7oo000EOol00`00Oomoo`0]
Ool00`00Oomoo`2@Ool001Eoo`03001oogoo02ioo`03001oogoo08moo`005Goo00<007ooOol0;goo
00<007ooOol0SWoo000EOol00`00Oomoo`0_Ool2002?Ool001Eoo`03001oogoo035oo`8008eoo`00
5Goo00<007ooOol0<Woo00<007ooOol0Rgoo000EOol00`00Oomoo`0cOol3002:Ool000Eoo`03001o
ogoo009oo`03001oogoo009oo`03001oogoo00=oo`03001oogoo03Eoo`8008Uoo`0017oo00<007oo
00001goo00<007oo000017oo00<007ooOol0=goo00<007ooOol0QWoo0004Ool00`00Ool00007Ool0
0`00Ool00004Ool2000iOol20026Ool000Aoo`03001oo`0000Qoo`03001oogoo00=oo`03001oogoo
03Yoo`03001oogoo08=oo`0017oo00<007oo00001goo00<007oo000017oo00<007ooOol0>goo0`00
PWoo0005Ool00`00Oomoo`07Ool00`00Oomoo`03Ool00`00Oomoo`0mOol20021Ool001Eoo`03001o
ogoo03moo`8007moo`005Goo00<007ooOol0@7oo0`00OGoo000EOol00`00Oomoo`13Ool2001kOol0
01Eoo`03001oogoo04Eoo`8007Uoo`005Goo00<007ooOol0Agoo1000MGoo000EOol00`00Oomoo`1;
Ool2001cOol001Eoo`03001oogoo04eoo`<0071oo`005Goo00<007ooOol0D7oo0`00KGoo000EOol0
0`00Oomoo`1COol3001ZOol001Eoo`03001oogoo05Ioo`@006Ioo`005Goo00<007ooOol0FGoo1000
Hgoo000EOol00`00Oomoo`1LOol4001POol001Eoo`03001oogoo05moo`@005eoo`005Goo00<007oo
Ool0HWoo1@00FGoo000EOol00`00Oomoo`1WOol9001@Ool001Eoo`03001oogoo06moo`/004Ioo`00
5Goo00<007ooOol0NWoo2000?Woo000=Ool50003Ool00`00Oomoo`22Ool7000gOol000moo`03001o
ogoo00=oo`03001oogoo08Uoo`H0035oo`003goo00<007ooOol00goo0P00T7oo:`001Woo000?Ool0
0`00Oomoo`03Ool00`00Oomoo`30Ool000moo`03001oogoo00=oo`03001oogoo0<1oo`003Woo0P00
1Goo00<007ooOol0`7oo003HOol00001\
\>"],
  ImageRangeCache->{{{0, 215}, {132.438, 0}} -> {-28.7459, -0.0985107, 
  1.35851, 0.00858636}}]
}, Open  ]],

Cell["Here we equalize the example image.", "Caption"],

Cell[BoxData[
    \(\(B\&^ = HistogramEqualize[B]\  // Round; \)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[
      GraphicsArray[
        \(ListDensityPlot[#1, PlotRange \[Rule] {0, 255}, 
              DisplayFunction \[Rule] Identity]\ &\)\ /@\ {B, \ \(B\&^\)}]]; 
    \)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .47619 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0113379 0.47619 [
[ 0 0 0 0 ]
[ 1 .47619 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .47619 L
0 .47619 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0113379 0.477324 0.464853 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.015024 0.0192308 0.015024 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
64 string
64 64 8 [64 0 0 64 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
3C3A3E3D3D3C3E3D3D3E3F3E3E3D3E3E3F3D3F3B3D3D3C3D
3D3B3D393C3A39393A3A39393A3A38383A39393839393938
3A3B393739373737373837373B3E4347
3C3B3B3B3D3A3C3C3C3D3F3E3D3F4040403D3D3E3D3C3B3C
3B3A3A3A3A393938393B3938393A3939393A3A3939383A39
393A39373737363738383838393D4248
3B3C3C3C3D3C3C3E3D3D3F3D3E403F3F3E3D3D3C3C3C3D3C
3D3A3B3A3A3B393939383A393A3A3938383738393939393A
393939393939383939393938393B4045
3A3C3B3C3F3C3E3D403D3E403F3F4040403C3E3D3D3D3D3A
3B3A3B3B3B3B3B3A39393A393A3A393B3937393A383A3A38
3939393A3837373939383A39393A3D42
3B3C3E3C3D3D4040413E3D3F413E4140403E3E3D3E3D3D3C
3C3C3B3C3C3A3C383A3A3A3A3A393A3A3A39393B3A393A38
3738393A3738363838393A38393B3B3F
3D3E3E3F3F3D413F3F3E3F4040404241403E3E3E3E3D3A3B
3B3B3A3B38383A3A393A373A393A39393938393939393A37
383839383937363739383939393A393C
3C3F3D3F3F403E403F424140424341424040403E3D3C3B3B
3B3C3B3B3A3A3A3C3C3C3A3A3A39383939383839393A3A39
39393A38393837383838393A393A3A3B
414240403F414042424244444444444442423F3E3F3D3C39
3E3D3C3D3B3A3A3A3B3C3B383A3937383738393A3B3A3A3B
3A393939393938393839393A393A3939
3E43403F4143424342464A494A4B4845434241403F3D3C3D
3D3C3D3D3B3A3A39383B3B3A383A38373938393939393A3A
393A393A3A383839383939393A3A3A3A
4242424242424246474D5255554F4D49434442403F3E3D3B
3B3B3D3C3B393A3A393A3A3A3839393837393A3A3B3B3A39
3A3A3A3A3A39393939393939393A3839
444542464547474C52595D61625E584D4A454342413E3D3D
3B3A3C3B3B3C3A3B3A3B3A3A3A39393A3A3C393A3B3C3B3C
3C3B3D3C3B393A3A3B3A3A3A3A3A3A39
454749484A4A4B545A636E797872685B51484442403C3D3F
3E3D3C3C3B3B3A393C3C3A3A3B373939393B3A3B3D3C3C3D
3E3E3D3D3C3A3A393A3A393939393A38
4C4B4C4D5354585B67788991939281715E52464540413F3F
3C3C3D3B3D3D3B3C3B3B3A3A393A3A39393A3A3C3D3F3E40
3F3F3D3D3C3C3B3C393C3B3B3B393939
535152575C5B61687B8F9BA3A6A19689775C4C454440403E
3E3B3B3B3B3B3B3B3A3A3A393A3B3A39393A3C3D3D403F40
40403F3D3E3D3C3B3B3B3B3B39393838
5B5B5B5C6161667790A2AFADB4B1A99C8D6B534D47423F3C
3E3C3B3A3B3A3B3B393B3A3A3B3A3B3A3B3C3E3F42444646
46444340403F3E3D3C3B3B3A38383736
60605F6163676D89A1B0B8B9BCBAB3AA987C5E554F43413F
3C3C3C3A3A3B3A3C3B3A3B3B393B3A3B3B3C3F42474C4D4F
4E4A484542403F3F3D3B3A3938373738
61636566676D7598AEBBBDC3BFBEBBB1A28866575449423D
3D3D3D3B3B3A3A3C3A393B3B3B393C3D3C3E42484F535659
5955504C4946423F3D3D3B3938383737
656768686A6E81A0B1BFC0C8C8C5BBB3AB906D5E5448413F
3E3D3D3B3B3A393939393A3A393B3C3E3C3E454E575A5C5E
5E5C58544E4944403E3D3A3939383636
6C6C6D6C6E7484A2BBC4C9CBC8C6C3B7AC90715C4E45423E
3D3C3C3B3A3A3A3939393A393B3B3C3D3C4149545C606265
65615F5C584F4843413D3D3B39383836
6B6D6E6D727683A6BCC5C7CBCAC6BFB7AA966F584944403D
3D3D3C3C3B393A39393B3A3A393A3C3E3F444C575F64696C
696B6A6660554D4644403D3D3B393737
6D7172767C7E829DB8C4C5CAC9C2BDB7A9966D554B43413F
3E3D3F3C393A393B3B3A3B3A3C3C3E3E4147525C62697272
70707370675E554E4845413D3B3A3737
6F6E77808D8E8E98ACBFC2C7C6C3BEB3A688645049433F3E
3D3D3E3D3B393A3B3A3B3B393A3C3C3D4048535E666D7376
757576746E6961585048433E3C3A3937
77727E93A6A5A59DA6B8BEC0C0B9B3AB9B785D514B474240
3E3E3E3D3C3B3A3A3A3B3A3A3B3B3C3D4049546068717B7C
7B7B7B7877736E64594F45403C3B3837
807893A9B6B7B7B2ABADB6B2B8B5A89D856B59554F4B4842
3E3D3C3C3C3B3B3A3A3B393A3B3B3B3E4046535F6A72797F
8082807F7B79726B60564A433D3A3837
827F9DB1BBBDBFB8B3A1A3A8A89F978570605757524F4A43
403E3D3C3D3A3A3B383A393A3B3B3C3F4147535B69747980
8485878481807C73695D4F443E3B3A36
8889A7B8BFC4C6BEB7A996918F877E716357565953504A48
3F3D3C3D3C3B383B3A393A39393B3C3E40454F5A66737D82
858988868884807A6F6352463E3C3935
8B8CA9B7C1C7C6C2BAAB908076766F665B585556514F4E49
423E3C3D3B3B3A3A3A393938383A3B3F40444C5864748082
83878A8F8E84817C74695849403B3936
8D8BAABAC4CAC0BDB8AB917A6F6B65605A55535450504E4A
453E3D3D3C3A3A393A3A3939393B3C3E4044495261737E83
83888F919188837F766B5C4C403D3A37
84859FB7BEC2BEB7B3A98B706963615C5B555552504F4C4B
45403D3D3B3B3A39393A393A3A3B3D3D3F44485263767F83
858B9194928B84807B6F5F4D413C3938
7D778FAAB3B6B6B4AB9D806D5F5F5C5B5952524E4F4F4C47
443F3D3C3B3A383839383B393A3B3C3D3E42465061727D81
868D9194928E867F796E5F4E423B3937
75718194A1A9ADA89F8B75675E5C5B5A595152504E4F4D49
423E3C3B3B3A3A3A3A3A393A3A3A3B3C3F41464F606E7B83
898F93928E8C877F746C5E4E413C3937
6C69717B878C9593877569615D5D59595950504E4D4C4A48
423B3D3B3B383738393A3A39393A3B3D3D41454D5C6E7A81
888F91908B88857E766B5B4B403B3837
6464696E76777B756C68645F5C5B5B59574F4D4F4C4B4A46
3F3C3D3B3A38383939393A393A3A3B3C3D40444B5A6E7B82
898E8E8E8B88837D746B58483F3C3835
5E5D62646769696664615E5C5A595A58565249494A4B4642
3D3B3A3B393938373A3B3A393A3B3B3C3E3F4349566C7982
888C8A8C8884817A736753453D3A3835
59595E5F5D6162605D57585957565856524D49454745423D
3A3B3A3939383937383A3A393A3C3C3C3D3E42475469787F
85898A88827D7B776B604E423C383736
5357585B5B5E5C5A5856505253545553504943403E3E3E3C
3B3B3B3A3A3839383B3939383A3A3C3B3C3E41465264737B
828686827D74706E6456473F3B373636
4C5255585758555653504A494C51524E4A43413F3C3D3C3B
3B3C3B3B3A3939393A3A39393A3B3B3B3C3D40434D5F6D7A
7F81807A7468635F584D423C3A363635
444D52555453514F4E4A444345464746433F3E3C3C3B3B3B
3B3A3A3939383A393939393A3A3A3A3A3B3E3E4048556571
787B7A746A5E56514B443F3B38373535
42474E5154514D4948444241424243413F3D3D3D3A3A3A39
3B393A39393939383A393A3A3B3B3B393A3C3E3F454E5966
6D72706B61544D46433F3D3A38353535
4042454A4B48444342413F3E3F3E3F3E3D3C3C3B3A393A3A
3B3939393A3A393A3B38393A3A3C3C3B3B3D3D3F42485059
62686561574D45413F3C3A3836353535
4040424444424040403E3D3D3D3D3E3D3B3C3A39393B3A3A
39393A393939393A3A39393A3B3B3C3C3A3D3E3E4143484E
545B5B564E48413E3D3B393737353535
3E3E3F3E3F3E3F3D3E3D3D3D3C3B3D3D3B3A393A38393A3A
3A3A3A393838383A3A39393A3A3A3B3A3B3B3B3D3E404346
494B4C4945403D3B3A3A383737363433
3B3D3C3D3F3D3C3D3D3B3C3D3B3D3B3B3A3B393939393939
39393B39393939393939393A3A3A3A3B3A3A3A3B3C3E3E41
42434443413E3C3B3939363636363633
3C3C3C3C3E3D3C3B3C3C3C3C3C3C3A3B3B3B3939393A3A39
3939393A3939393A3A3A3B393A3B393B3A3B3B3A3C3E3F3E
3D3F3E3E3D3E3B383937363535353434
3B3C3B3C3C3C3C3B3A3A3C3B3B3B3A3A3A3C3B3A38393B39
3939393A3939393A393A3A393B3A393B3A3B3B3B3C3C3D3E
3D3D3C3C3D3B3A383838383536353433
3C3B3A3B3B3A3A3A3C3B3C3B3B3A39393A393A3A38383A39
3939393B38393A393A393B3A393A3939393A393B3A3B3B3D
3B3B3C3B3A3939383737363535353433
3B3B393A3B3B393B3B3C3C3A3A3A3A3A3A3B3A3B39393839
3839393A393A3939393A3A3938373939393837393A3A3B3B
3B3A3A39383838383636353535353434
393B3A3B3B3B393A3A3B3A3A3A393A3A3939383A3938393A
393938383939393938393A3938393838393737373A393839
39373939383737383737363535353534
383C3B3B3C3A3A3A3B3A393A3A3A3A3A393A393939393939
3938383939383838393A3938383938383A38383739393838
39383937373737373536363634353433
3A3A393A3B3A3A393A393B39393A3A3B3B3B383738383738
3939383939393736383A3637373938373738373838383738
38373737383636353635353434343333
3A39373B3A3A3A393A3A3A3B393A3A3A393B393939383938
3A393837383A373738383838383838383737373939383838
38373737363535353534353434343333
3A38393A3A3A393A39393A3A3A3A393A3A3A39393939393A
3837373738383838373838393A3838383837383A38383938
38363736363636353533353434343333
3B3A393B3A3B3A3A3A38393A3A3B3B3B3A39383A3938373A
39393737393938383738373A393937373837383A38393938
37373636353535353434343534343334
3939393B3B373A393939383A393A3B3A393939393837373A
393838383838383736383838383838373837373838393938
38363535353535353534343435343332
3839383A39383A3A39393838383838383938383837383737
383938383739373637373737383837373636363837383736
36363535353333343634343534343332
3739393938383A3939393938383738383938393836373737
383839373737373836353537373736363635363737373636
36353634343535363534353434343333
3739393A38393A3839393939393939393939383737373638
393938383737373737363738373937363637373737373637
36363534343636363535353634333334
3939383A393839383839393938383A393A39373637363738
373838383636383637353637373938383638383836383737
36363633343534343435363535353333
373A3A3B393838383839383A383839393839373738383638
373637373534363637363637373739373738383837373736
35363434343434333436353434343433
3739383A3939383838373837393939383838383837373637
373636363635363637363637373738373738373839373635
36363534343434333334343433333333
38393738393A393939383838383839383837373836363739
363837373736363537383737373738373737363738383635
36353435343534343435343433333232
373838393738383937383737373838383838383836363638
383737373736373637363737373837383838373738383736
35353434343534333334343534343333
383838393738383837373737383738383739373737373637
363837373738373637363737363536383737373838373736
35353435343434333333343433333333
373737383738383837383737373736373638373736363738
373738373737363536363737383737373736363838383837
36353534343434343233333333333334
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0113379 0.97619 0.464853 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.015024 0.0192308 0.015024 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
64 string
64 64 8 [64 0 0 64 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
9B7DACA5A59BACA5A5ACB0ACACA5ACACB0A5B08FA5A59BA5
A58FA5619B7D61617D7D61617D7D41417D61614161616141
7D8F612A612A2A2A2A412A2A8FACBCC2
9B8F8F8FA57D9B9B9BA5B0ACA5B0B5B5B5A5A5ACA59B8F9B
8F7D7D7D7D616141618F6141617D6161617D7D6161417D61
617D612A2A2A182A4141414161A5BAC3
8F9B9B9BA59B9BACA5A5B0A5ACB5B0B0ACA5A59B9B9BA59B
A57D8F7D7D8F616161417D617D7D6141412A41616161617D
616161616161416161616141618FB5C0
7D9B8F9BB09BACA5B5A5ACB5B0B0B5B5B59BACA5A5A5A57D
8F7D8F8F8F8F8F7D61617D617D7D618F612A617D417D7D41
6161617D412A2A6161417D61617DA5BA
8F9BAC9BA5A5B5B5B7ACA5B0B7ACB7B5B5ACACA5ACA5A59B
9B9B8F9B9B7D9B417D7D7D7D7D617D7D7D61618F7D617D41
2A41617D2A41184141617D41618F8FB0
A5ACACB0B0A5B7B0B0ACB0B5B5B5BAB7B5ACACACACA57D8F
8F8F7D8F41417D7D617D2A7D617D61616141616161617D2A
41416141612A182A61416161617D619B
9BB0A5B0B0B5ACB5B0BAB7B5BABCB7BAB5B5B5ACA59B8F8F
8F9B8F8F7D7D7D9B9B9B7D7D7D61416161414161617D7D61
61617D4161412A414141617D617D7D8F
B7BAB5B5B0B7B5BABABABEBEBEBEBEBEBABAB0ACB0A59B61
ACA59BA58F7D7D7D8F9B8F417D612A412A41617D8F7D7D8F
7D616161616141614161617D617D6161
ACBCB5B0B7BCBABCBAC1C6C5C6C7C3C0BCBAB7B5B0A59BA5
A59BA5A58F7D7D61418F8F7D417D412A6141616161617D7D
617D617D7D414161416161617D7D7D7D
BABABABABABABAC1C2C9CED1D1CBC9C5BCBEBAB5B0ACA58F
8F8FA59B8F617D7D617D7D7D416161412A617D7D8F8F7D61
7D7D7D7D7D61616161616161617D4161
BEC0BAC1C0C2C2C8CED5D8DBDCD9D3C9C6C0BCBAB7ACA5A5
8F7D9B8F8F9B7D8F7D8F7D7D7D61617D7D9B617D8F9B8F9B
9B8FA59B8F617D7D8F7D7D7D7D7D7D61
C0C2C5C3C6C6C7D0D5DCE3E8E8E5DFD6CDC3BEBAB59BA5B0
ACA59B9B8F8F7D619B9B7D7D8F2A6161618F7D8FA59B9BA5
ACACA5A59B7D7D617D7D616161617D41
C8C7C8C9CFD0D3D6DEE8F0F3F4F4ECE4D9CEC1C0B5B7B0B0
9B9BA58FA5A58F9B8F8F7D7D617D7D61617D7D9BA5B0ACB5
B0B0A5A59B9B8F9B619B8F8F8F616161
CFCDCED2D7D6DBDFE9F2F5F6F6F6F4F0E7D7C8C0BEB5B5AC
AC8F8F8F8F8F8F8F7D7D7D617D8F7D61617D9BA5A5B5B0B5
B5B5B0A5ACA59B8F8F8F8F8F61614141
D6D6D6D7DBDBDEE7F3F6F8F8F9F8F7F5F2E1CFC9C2BAB09B
AC9B8F7D8F7D8F8F618F7D7D8F7D8F7D8F9BACB0BABEC1C1
C1BEBCB5B5B0ACA59B8F8F7D41412A18
DADADADBDCDEE2F0F6F8FAFBFBFBF9F7F5EAD9D1CBBCB7B0
9B9B9B7D7D8F7D9B8F7D8F8F618F7D8F8F9BB0BAC2C8C9CB
CAC6C3C0BAB5B0B0A58F7D61412A2A41
DBDCDDDEDEE2E6F5F8FBFBFDFCFCFBF8F6F0DED2D0C5BAA5
A5A5A58F8F7D7D9B7D618F8F8F619BA59BACBAC3CBCFD2D5
D5D1CCC8C5C1BAB0A5A58F6141412A2A
DDDEDFDFE0E3ECF5F8FCFCFEFEFDFBF9F8F3E2D9D0C3B7B0
ACA5A58F8F7D616161617D7D618F9BAC9BACC0CAD2D5D7D9
D9D7D3D0CAC5BEB5ACA57D6161411818
E1E1E2E1E3E6EEF6FBFDFEFFFEFEFDFAF8F3E4D7CAC0BAAC
A59B9B8F7D7D7D6161617D618F8F9BA59BB7C5D0D7DADCDD
DDDBDAD7D3CBC3BCB7A5A58F61414118
E1E2E3E2E5E7EDF6FBFDFEFFFEFEFCFAF7F4E3D3C5BEB5A5
A5A59B9B8F617D61618F7D7D617D9BACB0BEC8D2DADDE0E1
E0E1E0DEDAD1C9C1BEB5A5A58F612A2A
E2E4E5E7EAEAEDF5FAFDFDFEFEFDFBFAF7F4E2D1C7BCB7B0
ACA5B09B617D618F8F7D8F7D9B9BACACB7C2CED7DCE0E5E5
E3E3E5E3DED9D1CAC3C0B7A58F7D2A2A
E3E3E7ECF2F2F2F5F8FCFDFEFEFDFCF9F6F0DDCCC5BCB0AC
A5A5ACA58F617D8F7D8F8F617D9B9BA5B5C3CFD9DEE2E5E7
E6E6E7E6E3E0DBD3CCC3BCAC9B7D612A
E7E5EAF4F6F6F6F5F6FAFCFCFCFBF9F8F5E8D8CDC7C2BAB5
ACACACA59B8F7D7D7D8F7D7D8F8F9BA5B5C5D0DADFE4E9EA
E9E9E9E8E7E5E3DDD5CBC0B59B8F412A
ECE8F4F7F9FAFAF9F8F8F9F9FAF9F7F5EEE1D5D1CBC7C3BA
ACA59B9B9B8F8F7D7D8F617D8F8F8FACB5C1CFDAE0E5E8EB
ECEDECEBE9E8E5E1DAD2C6BCA57D412A
EDEBF5F8FBFBFCFAF9F6F6F7F7F5F4EEE3DAD2D2CECBC6BC
B5ACA59BA57D7D8F417D617D8F8F9BB0B7C2CFD6E0E6E8EC
EEEEEFEEECECEAE5E0D8CBBEAC8F7D18
F0F0F6FAFCFDFEFCFAF7F4F3F2EFEAE4DCD2D2D5CFCCC6C3
B0A59BA59B8F418F7D617D61618F9BACB5C0CBD5DEE5EAED
EEF0F0EFF0EEECE8E3DCCEC1AC9B610F
F1F1F7FAFDFEFEFDFBF8F3ECE7E7E3DED6D3D1D2CDCBCAC5
BAAC9BA58F8F7D7D7D616141417D8FB0B5BEC8D3DDE6ECED
EDEFF0F2F2EEECEAE6E0D3C5B58F6118
F2F1F7FBFDFEFCFBFAF8F3E8E3E1DDDAD5D1CFD0CCCCCAC6
C0ACA5A59B7D7D617D7D6161618F9BACB5BEC5CEDBE5EAED
EDF0F2F3F3F0EDEBE7E1D7C8B5A57D2A
EEEEF5FAFCFDFCFAF9F7F1E3E0DCDBD7D6D1D1CECCCBC8C7
C0B5A5A58F8F7D61617D617D7D8FA5A5B0BEC3CEDCE7EBED
EEF1F3F4F4F1EEECE9E3DAC9B79B6141
EAE7F2F7F9F9F9F9F8F5ECE2DADAD7D6D5CECECACBCBC8C2
BEB0A59B8F7D414161418F617D8F9BA5ACBAC1CCDBE5EAEC
EFF2F3F4F4F2EFEBE8E3DACABA8F612A
E6E4ECF4F6F7F8F7F5F1E6DED9D7D6D5D5CDCECCCACBC9C5
BAAC9B8F8F7D7D7D7D7D617D7D7D8F9BB0B7C1CBDAE3E9ED
F0F2F4F4F2F1EFEBE6E1D9CAB79B612A
E1E0E4E9EFF1F4F4EFE6E0DBD8D8D5D5D5CCCCCAC9C8C6C3
BA8FA58F8F412A41617D7D61617D8FA5A5B7C0C9D7E3E8EC
F0F2F3F3F1F0EEEAE7E1D6C7B58F412A
DDDDE0E3E7E7E9E6E1DFDDDAD7D6D6D5D2CBC9CBC8C7C6C1
B09BA58F7D41416161617D617D7D8F9BA5B5BEC7D5E3E9ED
F0F2F2F2F1F0EDEAE6E1D3C3B09B410F
D9D8DCDDDEE0E0DEDDDBD9D7D5D5D5D3D2CEC5C5C6C7C1BA
A58F7D8F6161412A7D8F7D617D8F8F9BACB0BCC5D2E1E8ED
F0F1F0F1F0EEECE8E5DECFC0A57D410F
D5D5D9DAD8DBDCDAD8D2D3D5D2D2D3D2CEC9C5C0C2C0BAA5
7D8F7D616141612A417D7D617D9B9B9BA5ACBAC2D0E0E8EB
EEF0F0F0EDEAE9E7E1DACABA9B412A18
CFD2D3D6D6D9D7D5D3D2CCCECFD0D1CFCCC5BCB5ACACAC9B
8F8F8F7D7D4161418F6161417D7D9B8F9BACB7C1CEDDE5E9
EDEFEFEDEAE6E3E3DDD2C2B08F2A1818
C8CED1D3D2D3D1D2CFCCC6C5C8CDCECAC6BCB7B09BA59B8F
8F9B8F8F7D6161617D7D61617D8F8F8F9BA5B5BCC9DAE2E8
EBECECE8E6DFDCDAD3C9BA9B7D18180F
BEC9CED1D0CFCDCBCAC6BEBCC0C1C2C1BCB0AC9B9B8F8F8F
8F7D7D6161417D616161617D7D7D7D7D8FACACB5C3D1DDE4
E8E9E8E6E0D9D2CDC7BEB08F412A0F0F
BAC2CACDD0CDC9C5C3BEBAB7BABABCB7B0A5A5A57D7D7D61
8F617D61616161417D617D7D8F8F8F617D9BACB0C0CAD5DE
E2E5E3E1DBD0C9C1BCB0A57D410F0F0F
B5BAC0C6C7C3BEBCBAB7B0ACB0ACB0ACA59B9B8F7D617D7D
8F6161617D7D617D8F41617D7D9B9B8F8FA5A5B0BAC3CCD5
DCDFDDDBD2C9C0B7B09B7D41180F0F0F
B5B5BABEBEBAB5B5B5ACA5A5A5A5ACA58F9B7D61618F7D7D
61617D616161617D7D61617D8F8F9B9B7DA5ACACB7BCC3CA
D0D6D6D2CAC3B7ACA58F612A2A0F0F0F
ACACB0ACB0ACB0A5ACA5A5A59B8FA5A58F7D617D41617D7D
7D7D7D614141417D7D61617D7D7D8F7D8F8F8FA5ACB5BCC1
C5C7C8C5C0B5A58F7D7D412A2A180903
8FA59BA5B0A59BA5A58F9BA58FA58F8F7D8F616161616161
61618F61616161616161617D7D7D7D8F7D7D7D8F9BACACB7
BABCBEBCB7AC9B8F6161181818181803
9B9B9B9BACA59B8F9B9B9B9B9B9B7D8F8F8F6161617D7D61
6161617D6161617D7D7D8F617D8F618F7D8F8F7D9BACB0AC
A5B0ACACA5AC8F41612A180F0F0F0909
8F9B8F9B9B9B9B8F7D7D9B8F8F8F7D7D7D9B8F7D41618F61
6161617D6161617D617D7D618F7D618F7D8F8F8F9B9BA5AC
A5A59B9BA58F7D414141410F180F0903
9B8F7D8F8F7D7D7D9B8F9B8F8F7D61617D617D7D41417D61
6161618F41617D617D618F7D617D6161617D618F7D8F8FA5
8F8F9B8F7D6161412A2A180F0F0F0903
8F8F617D8F8F618F8F9B9B7D7D7D7D7D7D8F7D8F61614161
4161617D617D6161617D7D61412A616161412A617D7D8F8F
8F7D7D614141414118180F0F0F0F0909
618F7D8F8F8F617D7D8F7D7D7D617D7D6161417D6141617D
616141416161616141617D6141614141612A2A2A7D614161
612A6161412A2A412A2A180F0F0F0F09
419B8F8F9B7D7D7D8F7D617D7D7D7D7D617D616161616161
6141416161414141617D6141416141417D41412A61614141
6141612A2A2A2A2A0F181818090F0903
7D7D617D8F7D7D617D618F61617D7D8F8F8F412A41412A41
6161416161612A18417D182A2A61412A2A412A4141412A41
412A2A2A4118180F180F0F0909090303
7D612A8F7D7D7D617D7D7D8F617D7D7D618F616161416141
7D61412A417D2A2A41414141414141412A2A2A6161414141
412A2A2A180F0F0F0F090F0909090303
7D41617D7D7D617D61617D7D7D7D617D7D7D61616161617D
412A2A2A414141412A4141617D414141412A417D41416141
41182A181818180F0F030F0909090303
8F7D618F7D8F7D7D7D41617D7D8F8F8F7D61417D61412A7D
61612A2A616141412A412A7D61612A2A412A417D41616141
2A2A18180F0F0F0F0909090F09090309
6161618F8F2A7D616161417D617D8F7D61616161412A2A7D
614141414141412A184141414141412A412A2A4141616141
41180F0F0F0F0F0F0F0909090F090300
4161417D61417D7D6161414141414141614141412A412A2A
416141412A612A182A2A2A2A41412A2A181818412A412A18
18180F0F0F0303091809090F09090300
2A61616141417D6161616141412A414161416141182A2A2A
4141612A2A2A2A41180F0F2A2A2A1818180F182A2A2A1818
180F1809090F0F180F090F0909090303
2A61617D41617D4161616161616161616161412A2A2A1841
616141412A2A2A2A2A182A412A612A18182A2A2A2A2A182A
18180F09091818180F0F0F1809030309
6161417D614161414161616141417D617D612A182A182A41
2A414141181841182A0F182A2A6141411841414118412A2A
18181803090F0909090F180F0F0F0303
2A7D7D8F614141414161417D4141616141612A2A41411841
2A182A2A0F0918182A18182A2A2A612A2A4141412A2A2A18
0F1809090909090309180F0909090903
2A61417D61614141412A412A61616141414141412A2A182A
2A181818180F18182A18182A2A2A412A2A412A41612A180F
18180F09090909030309090903030303
41612A41617D61616141414141416141412A2A4118182A61
18412A2A2A18180F2A412A2A2A2A412A2A2A182A4141180F
180F090F090F0909090F090903030000
2A4141612A4141612A412A2A2A4141414141414118181841
412A2A2A2A182A182A182A2A2A412A4141412A2A41412A18
0F0F0909090F09030309090F09090303
414141612A4141412A2A2A2A412A41412A612A2A2A2A182A
18412A2A2A412A182A182A2A180F18412A2A2A41412A2A18
0F0F090F090909030303090903030303
2A2A2A412A4141412A412A2A2A2A182A18412A2A18182A41
2A2A412A2A2A180F18182A2A412A2A2A2A1818414141412A
180F0F09090909090003030303030309
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{302, 143.688},
  ImageMargins->{{43, 0}, {0, 1}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004^0000Sa000`40O003h00Oogoo;goo003oOol_
Ool00?moobmoo`001gooR@003GooR@0027oo0007Ool00`00Oomoo`25Ool00`00Oomoo`0;Ool00`00
Oomoo`25Ool00`00Oomoo`06Ool000Moo`03001oogoo08Eoo`03001oogoo00]oo`03001oogoo08Eo
o`03001oogoo00Ioo`001goo00<007ooOol0QGoo00<007ooOol02goo00<007ooOol0QGoo00<007oo
Ool01Woo0007Ool00`00Oomoo`1X7>L26<H27>L96<H27>L46<H47>L48@P2Ool00`00Oomoo`0;Ool0
1000Oom>Ldic0Sg_0UJe15:D0Tic0UJe15:D0UJe0e[F15Je0U:D15Je0U[F0U:D0U[F0THa15:D0Tic
15:D0THa0U:D0S6<0Tic0Sg_136<1Cg_136<13g_12480Sg_136<0R481S6<0R480Sg_0THa0S6<0QBU
0S6<2ABU0R4811BU0THa0UJe0Ukg0V<H0goo00<007ooOol01Woo0007Ool00`00Oomoo`1X7>L26<H2
7>L96<H27>L46<H47>L48@P2Ool00`00Oomoo`0;Ool01000Oom>Ldic0Sg_0UJe15:D0Tic0UJe15:D
0UJe0e[F15Je0U:D15Je0U[F0U:D0U[F0THa15:D0Tic15:D0THa0U:D0S6<0Tic0Sg_136<1Cg_136<
13g_12480Sg_136<0R481S6<0R480Sg_0THa0S6<0QBU0S6<2ABU0R4811BU0THa0UJe0Ukg0V<H0goo
00<007ooOol01Woo0007Ool00`00Oomoo`0M7>L68@Q57>L;6<H<7>L28@P29BT2Ool00`00Oomoo`0;
Ool01000Oom>Ldic1THa0U:D0Sg_1Tic0U:D0e[F0UJe0U:D25[F15:D0UJe0U:D0Tic0THa0Tic0THa
23g_136<0R480c6<0THa0S6<0R480S6<0Sg_1S6<13g_136<0R480Sg_136<0Sg_0S6<1aBU0PaS0QBU
22480S6<0U:D0Ukg0V<H0goo00<007ooOol01Woo0007Ool00`00Oomoo`0M7>L68@Q57>L;6<H<7>L2
8@P29BT2Ool00`00Oomoo`0;Ool01000Oom>Ldic1THa0U:D0Sg_1Tic0U:D0e[F0UJe0U:D25[F15:D
0UJe0U:D0Tic0THa0Tic0THa23g_136<0R480c6<0THa0S6<0R480S6<0Sg_1S6<13g_136<0R480Sg_
136<0Sg_0S6<1aBU0PaS0QBU22480S6<0U:D0Ukg0V<H0goo00<007ooOol01Woo0007Ool00`00Oomo
o`0K7>L28@Pg7>L26<HY7>L48@P2Ool00`00Oomoo`0;Ool01000Oom6<DHa1Tic0U:D14ic0UJe15:D
0e[F0U:D0UJe1U[F0UJe15:D1Tic0U:D0Tic0U:D0Sg_0THa13g_0THa1c6<0R480Sg_0S6<13g_0S6<
12480QBU0R48236<0Sg_3C6<0R48236<0R480S6<0THa0U[F0V<H0goo00<007ooOol01Woo0007Ool0
0`00Oomoo`0K7>L28@Pg7>L26<HY7>L48@P2Ool00`00Oomoo`0;Ool01000Oom6<DHa1Tic0U:D14ic
0UJe15:D0e[F0U:D0UJe1U[F0UJe15:D1Tic0U:D0Tic0U:D0Sg_0THa13g_0THa1c6<0R480Sg_0S6<
13g_0S6<12480QBU0R48236<0Sg_3C6<0R48236<0R480S6<0THa0U[F0V<H0goo00<007ooOol01Woo
0007Ool00`00Oomoo`0@7>L28@P57>L28@P47>L68@Pa7>L26<HF7>L56<H@7>L28@P2Ool00`00Oomo
o`0;Ool01000Oolmkcg_0Tic0THa0Tic0U[F0Tic0UJe0U:D0U[F0U:D0eJe35[F0Tic0UJe25:D0Sg_
0THa0Sg_2THa0Sg_1C6<0Sg_0S6<13g_0S6<0THa0S6<0QBU0S6<0Sg_0R4813g_0R481S6<0Sg_0R48
1ABU136<0R480Sg_136<0Sg_0U:D0Ukg0goo00<007ooOol01Woo0007Ool00`00Oomoo`0@7>L28@P5
7>L28@P47>L68@Pa7>L26<HF7>L56<H@7>L28@P2Ool00`00Oomoo`0;Ool01000Oolmkcg_0Tic0THa
0Tic0U[F0Tic0UJe0U:D0U[F0U:D0eJe35[F0Tic0UJe25:D0Sg_0THa0Sg_2THa0Sg_1C6<0Sg_0S6<
13g_0S6<0THa0S6<0QBU0S6<0Sg_0R4813g_0R481S6<0Sg_0R481ABU136<0R480Sg_136<0Sg_0U:D
0Ukg0goo00<007ooOol01Woo0007Ool00`00Oomoo`0<7>L68@P77>L28@P27>L68@Po7>L26<H67>L2
6<H37>L26<HB7>L2Ool00`00Oomoo`0;Ool01000Oom6<DHa0Tic0UJe0Tic15:D1U[F0UJe0e:D15[F
0UJe1U[F15Je0U:D0UJe15:D1Tic0THa14ic0Sg_0Tic0R482cg_0S6<1Sg_136<0THa0Sg_0S6<0Sg_
0R480QBU0R480S6<0Sg_0QBU0b480PaS12480S6<0Sg_0R480S6<14Ha0U[F0goo00<007ooOol01Woo
0007Ool00`00Oomoo`0<7>L68@P77>L28@P27>L68@Po7>L26<H67>L26<H37>L26<HB7>L2Ool00`00
Oomoo`0;Ool01000Oom6<DHa0Tic0UJe0Tic15:D1U[F0UJe0e:D15[F0UJe1U[F15Je0U:D0UJe15:D
1Tic0THa14ic0Sg_0Tic0R482cg_0S6<1Sg_136<0THa0Sg_0S6<0Sg_0R480QBU0R480S6<0Sg_0QBU
0b480PaS12480S6<0Sg_0R480S6<14Ha0U[F0goo00<007ooOol01Woo0007Ool00`00Oomoo`0<7>L2
8@P97>L<8@PS7>L26<HH7>L26<H:7>L76<H@7>L2Ool00`00Oomoo`0;Ool01000OomBU5:D15Je15[F
0U:D1U[F0UJe2E[F0Ukg15[F25Je0U:D0Sg_1THa0Sg_0THa124813g_0c6<0Sg_0QBU0Sg_0S6<0Sg_
1S6<0R48236<0Sg_0QBU12480S6<0R480S6<0aBU0PaS0QBU0S6<0R481S6<0Sg_0S6<0Tic0goo00<0
07ooOol01Woo0007Ool00`00Oomoo`0<7>L28@P97>L<8@PS7>L26<HH7>L26<H:7>L76<H@7>L2Ool0
0`00Oomoo`0;Ool01000OomBU5:D15Je15[F0U:D1U[F0UJe2E[F0Ukg15[F25Je0U:D0Sg_1THa0Sg_
0THa124813g_0c6<0Sg_0QBU0Sg_0S6<0Sg_1S6<0R48236<0Sg_0QBU12480S6<0R480S6<0aBU0PaS
0QBU0S6<0R481S6<0Sg_0S6<0Tic0goo00<007ooOol01Woo0007Ool00`00Oomoo`0:7>L28@P27>L2
8@P27>LE8@Q87>L26<HB7>L2Ool00`00Oomoo`0;Ool01000Oom>Ldic0U[F0U:D1U[F0UJe15[F0Ukg
1E[F15kg0U[F0Ukg1U[F0UJe0U:D0Tic1THa0Tic14Ha1Sg_1dic1Sg_0S6<0R48136<1248136<13g_
1S6<0Sg_0R480S6<0b480QBU1R480S6<0Sg_0S6<13g_0THa0goo00<007ooOol01Woo0007Ool00`00
Oomoo`0:7>L28@P27>L28@P27>LE8@Q87>L26<HB7>L2Ool00`00Oomoo`0;Ool01000Oom>Ldic0U[F
0U:D1U[F0UJe15[F0Ukg1E[F15kg0U[F0Ukg1U[F0UJe0U:D0Tic1THa0Tic14Ha1Sg_1dic1Sg_0S6<
0R48136<1248136<13g_1S6<0Sg_0R480S6<0b480QBU1R480S6<0Sg_0S6<13g_0THa0goo00<007oo
Ool01Woo0007Ool00`00Oomoo`088@P27>LK8@PY7>L26<H27>L26<H_7>L2Ool00`00Oomoo`0;Ool0
1000OomJeU[F0Ukg2U[F5ekg0U[F0UJe0U[F0U:D0Tic0S6<0UJe0U:D0Tic0U:D0THa1Sg_0dHa0Tic
0THa0R480Sg_0S6<0QBU0R480QBU0R480S6<0Sg_0THa13g_0THa0Sg_2c6<0R480S6<0R48136<0Sg_
0S6<0Sg_136<0goo00<007ooOol01Woo0007Ool00`00Oomoo`088@P27>LK8@PY7>L26<H27>L26<H_
7>L2Ool00`00Oomoo`0;Ool01000OomJeU[F0Ukg2U[F5ekg0U[F0UJe0U[F0U:D0Tic0S6<0UJe0U:D
0Tic0U:D0THa1Sg_0dHa0Tic0THa0R480Sg_0S6<0QBU0R480QBU0R480S6<0Sg_0THa13g_0THa0Sg_
2c6<0R480S6<0R48136<0Sg_0S6<0Sg_136<0goo00<007ooOol01Woo0007Ool00`00Oomoo`027>L4
8@P27>L<8@P;9BT:8@PW7>L26<Ha7>L2Ool00`00Oomoo`0;Ool01000OomF]EJe0Ukg1U[F25kg3f<H
15kg1U[F0U:D0Tic15:D0Tic15:D0THa13g_0S6<0b4814Ha0Sg_0R480Sg_0R480QBU0S6<0R48236<
13g_0S6<0Sg_0S6<13g_1B480S6<0R481S6<23g_0goo00<007ooOol01Woo0007Ool00`00Oomoo`02
7>L48@P27>L<8@P;9BT:8@PW7>L26<Ha7>L2Ool00`00Oomoo`0;Ool01000OomF]EJe0Ukg1U[F25kg
3f<H15kg1U[F0U:D0Tic15:D0Tic15:D0THa13g_0S6<0b4814Ha0Sg_0R480Sg_0R480QBU0S6<0R48
236<13g_0S6<0Sg_0S6<13g_1B480S6<0R481S6<23g_0goo00<007ooOol01Woo0007Ool00`00Oomo
o`0B8@P29BT7:DX69BT88@PY7>L26<H_7>L2Ool00`00Oomoo`0;Ool00`00OomNm`0=G_L4HaP5IcT4
JeX4IcT2HaP6G_L4F]H2E[D2DY@6AS42DY@2CW<2AS42<H`4?Nl3<H`6?Nl28@P4<H`28@P25:D2<H`4
?Nl4AS42?Nl2<H`:?NlA<H`2?Nl28@P2<H`3Ool00`00Oomoo`06Ool000Moo`03001oogoo018Q208U
:@LYBPHU:@PQ22TLi`8HaRlLi`9oo`03001oogoo00]oo`03001ooekg00eNm`AS60EW>@A[FPAW>@9S
60INm`AJeP9F]@9BU0I6<@9BU09>L`96<@8aS0@mk`<aS0Hmk`8Q20@aS08Q208DY@8aS0@mk`A6<@8m
k`8aS0Xmka4aS08mk`8Q208aS0=oo`03001oogoo00Ioo`001goo00<007ooOol03R480RDY0RU:1Be[
136<12e[12DY2248F1cW0Woo00<007ooOol02goo00@007ooG_MNm`9S609Nm`QS60AW>@9[FPU_N`9[
FP9W>@AS60ANm`9JeP9F]@ABU096<@8mk`9>L`A6<@9>L`8mk`96<@<mk`96<@Hmk`@aS0@mk`9>L`8a
S08mk`96<@9>L`96<@A>L`96<@9BU09>L`96<@<aS0@mk`96<@`mk`8aS0=oo`03001oogoo00Ioo`00
1goo00<007ooOol03R480RDY0RU:1Be[136<12e[12DY2248F1cW0Woo00<007ooOol02goo00@007oo
G_MNm`9S609Nm`QS60AW>@9[FPU_N`9[FP9W>@AS60ANm`9JeP9F]@ABU096<@8mk`9>L`A6<@9>L`8m
k`96<@<mk`96<@Hmk`@aS0@mk`9>L`8aS08mk`96<@9>L`96<@A>L`96<@9BU09>L`96<@<aS0@mk`96
<@`mk`8aS0=oo`03001oogoo00Ioo`001goo00<007ooOol012482RDY0RU:0Re[0S6<0cF]13g_0SW>
0SF]0Re[0RU:0RDY1R488AcW0QS6=AcW0Woo00<007ooOol02goo00<007ooHaP03F<H16]J0Vmk0g>L
17Nm0W>L0Vmk0V]J0VLi0V<H15kg0U[F0Tic0U:D0U[F0UJe0U:D14ic14Ha0Sg_0S6<1Dic13g_0THa
0QBU1S6<0THa0Sg_0THa0U:D14ic0U:D15Je15:D0Tic1Cg_0S6<13g_236<0Sg_0R480goo00<007oo
Ool01Woo0007Ool00`00Oomoo`048@P:9BT2:DX2;F/2<H`3=Jd4?Nl2>Lh2=Jd2;F/2:DX29BT68@PQ
7>L26<He7>L2Ool00`00Oomoo`0;Ool00`00OomS600=HaP4JeX2Kg/3Li`4Mkd2Li`2Kg/2JeX2IcT2
HaP4G_L2F]H2CW<2DY@2F]H2E[D2DY@4CW<4AS42?Nl2<H`5CW<4?Nl2AS425:D6<H`2AS42?Nl2AS42
DY@4CW<2DY@4E[D4DY@2CW<5?Nl2<H`4?Nl8<H`2?Nl28@P3Ool00`00Oomoo`06Ool000Moo`03001o
ogoo00PU:@@YBP@]J`8aS08mk`=6<@I:DP92408icP8]J`8YBPPQ23<Li`8Q224Li`9oo`03001oogoo
00]oo`04001oofLiIcT2HaP6IcT6JeX2Kg/2Mkd9Nmh2Mkd2Li`2Kg/2IcT4HaP8F]H4CW<2DY@2AS44
DY@2AS42CW<5AS44?Nl2<H`4?Nl4<H`4?Nl2CW<2DY@2F]H2E[D6F]H4DY@5CW<2AS42CW<2<H`2CW<6
AS46<H`3Ool00`00Oomoo`06Ool000Moo`03001oogoo00PU:@@YBP@]J`8aS08mk`=6<@I:DP92408i
cP8]J`8YBPPQ23<Li`8Q224Li`9oo`03001oogoo00]oo`04001oofLiIcT2HaP6IcT6JeX2Kg/2Mkd9
Nmh2Mkd2Li`2Kg/2IcT4HaP8F]H4CW<2DY@2AS44DY@2AS42CW<5AS44?Nl2<H`4?Nl4<H`4?Nl2CW<2
DY@2F]H2E[D6F]H4DY@5CW<2AS42CW<2<H`2CW<6AS46<H`3Ool00`00Oomoo`06Ool000Moo`03001o
ogoo00PYBP@]J`8aS08e[@8mk`96<@=>L`IBU09:DP96<@8icP8]J`8U:@PQ22dLi`8Q208Li`HQ21dL
i`9oo`03001oogoo00]oo`03001oofLi00EW>@I[FPA_N`9g_@mkgP9cW09[FP9W>@9S609Nm`AJePAF
]@i6<@Lmk`8aS08mk`96<@8mk`@aS08mk`9>L`ABU0aJeP9BU09F]@=BU09>L`Y6<@@aS0@Q20=oo`03
001oogoo00Ioo`001goo00<007ooOol022U:12e[0S6<0SF]0Sg_0THa0dic1U:D0TYB0THa0SW>0Re[
0RDY2248;AcW0R480QcW1R487AcW0Woo00<007ooOol02goo00<007ooIcT01FLi1V]J16mk0WNm3g_N
0W>L0V]J0VLi0V<H0Ukg15[F15Je3THa1cg_0S6<0Sg_0THa0Sg_136<0Sg_0Tic15:D35[F0U:D0UJe
0e:D0Tic2THa136<12480goo00<007ooOol01Woo0007Ool00`00Oomoo`08;F/6<H`2>Lh2BU82DY@5
E[D4F]H2E[D2CW<2AS42=Jd2:DX29BT48@P]7>LB8@PC7>L46<H2Ool00`00Oomoo`0;Ool00`00Oom[
FP07JeX6Kg/2Li`4Nmh9Ool6Nmh2Li`4IcT2HaP2G_L2F]H2CW<2E[D2CW<2AS42?Nl2AS42?Nl4AS43
<H`2AS44?Nl2AS42?Nl2AS42?Nl2AS42CW<2E[D2F]H4G_L6HaP4G_L7F]H2E[D2DY@2CW<4AS42?Nl4
8@P25:D236<3Ool00`00Oomoo`06Ool000Moo`03001oogoo00P]J`HaS08icP9:DP9BU0EF]@AJeP9F
]@9>L`96<@8e[@8YBP8U:@@Q22dLia8Q21<Li`@HaP9oo`03001oogoo00]oo`03001oof]J00M[FPI_
N`9cW0AkgPUoo`IkgP9cW0AW>@9S609Nm`9JeP9>L`9F]@9>L`96<@8mk`96<@8mk`A6<@<aS096<@@m
k`96<@8mk`96<@8mk`96<@9>L`9F]@9JePANm`IS60ANm`MJeP9F]@9BU09>L`A6<@8mk`@Q208DY@8<
H`=oo`03001oogoo00Ioo`001goo00<007ooOol0136<0Re[1S6<0SF]0THa0U:D0U[F2Ekg0U[F0UJe
0Tic0Sg_0Re[0RU:0RDY1248:AcW124832DY1b483QcW11S60QcW0Woo00<007ooOol02goo00<007oo
Kg/02fmk0W>L17_N3Goo17_N0WNm0Vmk0V]J0VLi0Ukg15[F1Tic13g_0THa0Sg_0Tic0dHa0Sg_14Ha
0S6<0THa0Sg_14Ha0Tic0U[F0Ukg0V<H26Li1V<H0Ukg1e[F0U:D0THa0Sg_0S6<0R4811BU0R480goo
00<007ooOol01Woo0007Ool00`00Oomoo`04<H`2;F/6<H`2=Jd2AS42DY@2F]H9G_L2F]H2E[D2CW<2
?Nl2;F/2:DX29BT48@PY7>L48@P<9BT78@P>7>L46<H27>L2Ool00`00Oomoo`0;Ool00`00Oom_N`0;
Kg/2Li`4Nmh=Ool4Nmh2Mkd2Kg/2JeX2IcT2G_L4F]H6CW<4?Nl2AS42?Nl2CW<3AS42?Nl4AS42<H`2
AS42?Nl4AS42CW<2F]H2G_L2HaP8IcT6HaP2G_L7F]H2DY@2AS42?Nl2<H`28@P45:D28@P3Ool00`00
Oomoo`06Ool000Moo`03001oogoo00@aS08]J`HaS08e[@96<@9BU09JePUNm`9JeP9F]@9>L`8mk`8]
J`8YBP8U:@@Q22TLi`@Q20`U:@LQ20hLi`@HaP8Li`9oo`03001oogoo00]oo`03001oofmk00]_N`9c
W0AkgPeoo`AkgP9g_@9_N`9[FP9W>@9Nm`AJePI>L`@mk`96<@8mk`9>L`=6<@8mk`A6<@8aS096<@8m
k`A6<@9>L`9JeP9Nm`9S60QW>@IS609Nm`MJeP9BU096<@8mk`8aS08Q20@DY@8Q20=oo`03001oogoo
00Ioo`001goo00<007ooOol02S6<0SF]0SW>0Tic0UJe1Ekg0V<H1Ukg0U[F0U:D0THa0S6<12U:0RDY
0R489acW0R4812DY12U:12e[12U:12DY1B483QcW11S60Woo00<007ooOol02goo00<007ooKg/02Fmk
17>L0W_N4Goo17_N0Vmk16]J0V<H0Ukg25:D14Ha13g_0Tic0cg_0S6<1THa0S6<0Tic0U:D0Tic0UJe
0Ukg0V<H16Li26]J16Li1F<H0Ukg0U[F15:D0THa0S6<124811BU0goo00<007ooOol01Woo0007Ool0
0`00Oomoo`0:<H`2=Jd2>Lh2CW<2E[D5G_L2HaP6G_L2F]H2DY@2AS42<H`4:DX29BT28@PW7>L28@P4
9BT4:DX4;F/4:DX49BT58@P>7>L46<H2Ool00`00Oomoo`0;Ool00`00Oom_N`09Kg/4Li`2NmhAOol4
Nmh2Kg/4JeX2HaP2G_L8DY@4AS44?Nl2CW<3?Nl2<H`6AS42<H`2CW<2DY@2CW<2E[D2G_L2HaP4IcT8
JeX4IcT5HaP2G_L2F]H4DY@2AS42<H`48@P45:D3Ool00`00Oomoo`06Ool000Moo`03001oogoo00@a
S0Pe[@92409BU09JeP9Nm`=S60AW>@9S609Nm`9JeP9F]@9:DP8e[@8]J`8YBP8U:@8Q22LLi`8Q208U
:@8YBP`]J`8YBPDU:@@Q20`Li`@HaP9oo`03001oogoo00]oo`03001oofmk00M_N`AcW09g_@9kgQ=o
o`9kgP9cW09_N`9[FP9S60AJeP9F]@ABU0A6<@8mk`TaS0@mk`8aS096<@9>L`9F]@9>L`9F]@9S609W
>@I[FPA_N`I[FP9W>@=S609Nm`9JeP9F]@9BU08mk`@aS08Q20@<H`=oo`03001oogoo00Ioo`001goo
00<007ooOol0136<23F]0T8@0U:D0U[F0Ukg0f<H16Li0V<H0Ukg0U[F0UJe0TYB0SF]0Re[0RU:0RDY
0R489acW0R480RDY0RU:32e[0RU:1BDY124831cW11S60Woo00<007ooOol02goo00<007ooKg/01fmk
17>L0WNm0W_N4goo0W_N0W>L0Vmk0V]J0V<H15[F0UJe15:D14Ha0Sg_2C6<13g_0S6<0THa0Tic0UJe
0Tic0UJe0V<H0VLi1V]J16mk1V]J0VLi0f<H0Ukg0U[F0UJe0U:D0Sg_136<0R4810aS0goo00<007oo
Ool01Woo0007Ool00`00Oomoo`0:=Jd2>Lh2@Q02DY@2G_L2HaP7IcT4HaP2F]H2E[D2BU82>Lh2;F/2
9BT48@PU7>L28@P29BT2:DX2;F/:<H`6;F/59BT48@P<7>L26<H2Ool00`00Oomoo`0;Ool00`00Oomc
W00;Li`2Mkd2NmhCOol2Nmh2Li`2JeX2IcT2HaP2G_L2E[D2DY@4CW<2AS46?Nl7<H`2?Nl2<H`4AS42
CW<2DY@2CW<2F]H2HaP4JeX<Kg/4JeX3IcT2HaP2G_L2F]H4DY@2AS42<H`48@P236<3Ool00`00Oomo
o`06Ool000Moo`03001oogoo00Xe[@8icP92409BU09Nm`9S60MW>@AS609JeP9F]@9:DP8icP8]J`8U
:@@Q22DLi`8Q208U:@8YBP8]J`XaS0H]J`DU:@@Q20`Li`8HaP9oo`03001oogoo00]oo`03001oog>L
00]cW09g_@9kgQ=oo`9kgP9cW09[FP9W>@9S609Nm`9F]@9BU0A>L`96<@Hmk`LaS08mk`8aS0A6<@9>
L`9BU09>L`9JeP9S60A[FPa_N`A[FP=W>@9S609Nm`9JePABU096<@8aS0@Q208<H`=oo`03001oogoo
00Ioo`001goo00<007ooOol023F]13W>0T8@0U:D0Ukg1F<H16Li0V<H0Ukg0U[F0UJe0TYB0SF]0Re[
0RDY12489AcW0R480RDY0RU:0Re[0S6<2SF]136<0bU:0RDY1R4821cW11S60Woo00<007ooOol02goo
00<007ooLi`02g>L0WNm0W_N4Goo17_N0W>L0V]J0V<H0Ukg0U[F1U:D14ic0THa0S6<0Sg_1C6<0THa
13g_0S6<0Sg_0Tic0UJe0U[F0Ukg0VLi0V]J16mk2W>L16mk0f]J0VLi0V<H0Ukg0U[F15:D0THa0S6<
11BU0goo00<007ooOol01Woo0007Ool00`00Oomoo`08=Jd4>Lh2@Q02DY@2G_L5HaP4IcT2HaP2G_L2
F]H2E[D2BU82=Jd2;F/29BT48@PU7>L28@P29BT2:DX2;F/2<H`:=Jd4<H`3:DX29BT68@P87>L46<H2
Ool00`00Oomoo`0;Ool00`00OomcW00;Li`2Mkd2NmhAOol4Nmh2Li`2JeX2HaP2G_L2F]H6DY@4CW<2
AS42<H`2?Nl5<H`2AS44?Nl2<H`2?Nl2CW<2E[D2F]H2G_L2IcT2JeX4Kg/:Li`4Kg/3JeX2IcT2HaP2
G_L2F]H4DY@2AS42<H`45:D3Ool00`00Oomoo`06Ool000Moo`03001oogoo008e[@HicP@mk`92409>
L`9Nm`ES60AW>@9S609Nm`9JeP9F]@9:DP8e[@8YBP8U:@@Q22<Li`@Q208YBP8]J`8aS08e[@`icP8a
S0<]J`8YBP@U:@@Q20HLi`@HaP9oo`03001oogoo00]oo`03001oog>L00McW0Ig_@9kgQ5oo`AkgP9c
W09[FP9S609Nm`AJeP9F]@9BU09JeP9>L`8aS08mk`8aS0E6<@8mk`96<@8mk`A>L`AF]@9JeP9S609W
>@9[FP9_N`icW0E_N`9[FP9W>@AS609JeP9BU096<@8mk`@DY@=oo`03001oogoo00Ioo`001goo00<0
07ooOol00SF]1SW>13g_0T8@0Tic0Ukg1F<H16Li0V<H0Ukg0U[F0UJe0TYB0SF]0RU:0RDY12488acW
12480RU:0Re[0S6<0SF]33W>0S6<0be[0RU:12DY12481QcW11S60Woo00<007ooOol02goo00<007oo
Li`01g>L1WNm0W_N4Goo17_N0W>L0V]J0V<H0Ukg15[F0UJe0U:D0U[F0Tic0S6<0Sg_0S6<1DHa0Sg_
0THa0Sg_14ic15Je0U[F0V<H0VLi0V]J0Vmk3W>L1Fmk0V]J0VLi16<H0U[F0U:D0THa0Sg_11BU0goo
00<007ooOol01Woo0007Ool00`00Oomoo`04=Jd2>Lh2@Q06AS42CW<2E[D2G_L9HaP2G_L2F]H2DY@2
AS42<H`2:DX29BT28@PU7>L28@P29BT2:DX2;F/2<H`2=Jd<>Lh5=Jd2<H`2;F/2:DX29BT28@P87>L2
6<H2Ool00`00Oomoo`0;Ool00`00OomcW005Li`2Mkd8NmhAOol4Nmh2Kg/2IcT2HaP2G_L2F]H2E[D4
DY@2E[D2DY@2AS42<H`2?Nl2AS43?Nl4AS42<H`2?Nl4CW<2DY@2F]H2HaP2IcT4Kg/CLi`2Kg/2JeX2
IcT2HaP2G_L2E[D2CW<2?Nl2<H`25:D3Ool00`00Oomoo`06Ool000Moo`03001oogoo00@e[@8icP92
40I6<@9>L`9F]@9Nm`US609Nm`9JeP9BU096<@8aS08YBP8U:@8Q22DLi`8Q208U:@8YBP8]J`8aS08e
[@`icPDe[@8aS08]J`8YBP8U:@8Q20PLi`8HaP9oo`03001oogoo00]oo`03001oog>L00EcW09g_@Qk
gQ5oo`AkgP9_N`9W>@9S609Nm`9JeP9F]@ABU09F]@9BU096<@8aS08mk`96<@<mk`A6<@8aS08mk`A>
L`9BU09JeP9S609W>@A_Na=cW09_N`9[FP9W>@9S609Nm`9F]@9>L`8mk`8aS08DY@=oo`03001oogoo
00Ioo`001goo00<007ooOol013W>0Sg_0TYB1U:D0Tic0U:D1Ekg16<H0Ukg0U[F0UJe0Tic0Sg_0Re[
0RU:0RDY1R488AcW0R480RDY0RU:0S6<0SF]0SW>33g_1CW>0SF]0S6<0Re[0RDY12481QcW0QS60Woo
00<007ooOol02goo00<007ooLi`00g>L0WNm37_N3goo0W_N0WNm0Vmk0VLi16<H0Ukg0U[F1UJe0U:D
0Tic0THa1cg_0THa13g_14Ha0Tic0U:D0U[F0V<H0V]J16mk0W>L37Nm1g>L0Vmk0V]J0VLi0V<H0U[F
0Tic0THa0R480QBU0goo00<007ooOol01Woo0007Ool00`00Oomoo`04>Lh2?Nl2BU86DY@2CW<2DY@5
G_L4HaP2G_L2F]H2E[D2CW<2?Nl2;F/2:DX29BT68@PQ7>L28@P29BT2:DX2<H`2=Jd2>Lh<?Nl5>Lh2
=Jd2<H`2;F/29BT48@P67>L26<H2Ool00`00Oomoo`0;Ool00`00OomcW003Li`2Mkd<Nmh?Ool2Nmh2
Mkd2Kg/2IcT4HaP2G_L2F]H6E[D2DY@2CW<2AS47?Nl2AS44?Nl4AS42CW<2DY@2F]H2HaP2JeX4Kg/2
Li`<Mkd7Li`2Kg/2JeX2IcT2HaP2F]H2CW<2AS428@P25:D3Ool00`00Oomoo`06Ool000Moo`03001o
ogoo0092408mk`9:DP9F]@QJePAF]@EJeP9Nm`9JeP9F]@9>L`92408e[@8]J`8YBPHU:@8Q224Li`@Q
208YBP8]J`8e[@8icP@mk`I240Lmk`8icP8e[@8aS08YBP8U:@8Q20HLi`8HaP9oo`03001oogoo00]o
o`03001oogNm00=g_@AkgQEoo`AkgP9g_@9cW0A[FP9W>@AS609Nm`9F]@9BU0I>L`A6<@Dmk`96<@8a
S08mk`I6<@9F]@9JeP9S609W>@9_N`AcW15g_@AcW09_N`9[FP9S609Nm`9BU08mk`8Q208DY@=oo`03
001oogoo00Ioo`001goo00<007ooOol00T8@0Sg_0TYB0UJe25[F15Je1E[F0Ukg0U[F0UJe0Tic0T8@
0SF]0Re[0RU:1RDY0R488AcW12480RU:0Re[0SF]0SW>13g_1T8@1cg_0SW>0SF]0S6<0RU:0RDY0R48
1QcW0QS60Woo00<007ooOol02goo00<007ooMkd00gNm17_N5Goo17_N0WNm0W>L16]J0VLi16<H0Ukg
0UJe0U:D1Tic14Ha1Cg_0THa0S6<0Sg_1THa0UJe0U[F0V<H0VLi0Vmk17>L4GNm17>L0Vmk0V]J0V<H
0Ukg0U:D0Sg_0R480QBU0goo00<007ooOol01Woo0007Ool00`00Oomoo`02@Q02?Nl2CW<2F]H8G_L2
F]H5DY@4E[D2CW<2BU82@Q02>Lh2<H`6:DX49BT48@PO7>L48@P2:DX2;F/2=Jd2>Lh2?Nl?@Q02?Nl2
>Lh2=Jd2;F/29BT28@P67>L26<H2Ool00`00Oomoo`0;Ool00`00Oomg_@03Mkd2Nmh<Ool=Nmh2Mkd2
Li`2Kg/4JeX4IcT2HaP2G_L2F]H2E[D2DY@2CW<2DY@4?Nl2AS438@P2?Nl2<H`2?Nl4AS42CW<4F]H2
HaP2IcT2JeX4Li`CMkd4Li`2Kg/2IcT2G_L2E[D2AS42?Nl236<3Ool00`00Oomoo`06Ool000Moo`03
001oogoo0092408mk`9>L`9JePQNm`9JePEBU0AF]@9>L`9:DP92408icP8aS0HYBP@U:@@Q21lLi`@Q
208YBP8]J`8e[@8icP8mk`m2408mk`8icP8e[@8]J`8U:@8Q20HLi`8HaP9oo`03001oogoo00]oo`03
001oogNm00=g_@9kgPaoo`ekgP9g_@9cW09_N`A[FPAW>@9S609Nm`9JeP9F]@9BU09>L`9BU0@mk`96
<@<Q208mk`8aS08mk`A6<@9>L`AJeP9S609W>@9[FPAcW1=g_@AcW09_N`9W>@9Nm`9F]@96<@8mk`8<
H`=oo`03001oogoo00Ioo`001goo00<007ooOol014Ha0U:D15kg16<H0Ukg0U[F0UJe1DYB0THa0T8@
0Sg_0SW>0S6<12U:0Re[12U:12DY8AcW12480RDY0Re[0S6<0SW>0Sg_148@14Ha0T8@0THa1D8@0Sg_
0SF]0S6<0RU:0R481QcW0QS60Woo00<007ooOol02goo00<007ooNmh01G_N37oo2G_N17Nm0W>L0Vmk
1V]J16Li16<H0U[F0U:D0Tic0U:D0Tic0THa0R480THa0cg_0S6<0Sg_136<0THa0Tic0UJe0U[F0V<H
0VLi0V]J0Vmk0W>L1WNm17_N0WNm0W_N1gNm0W>L0Vmk0VLi0V<H0UJe0Tic0S6<0P@Q0goo00<007oo
Ool01Woo0007Ool00`00Oomoo`04AS42DY@4G_L4HaP2G_L2F]H2E[D5BU82AS42@Q02?Nl2>Lh2<H`4
:DX2;F/4:DX49BTQ7>L48@P29BT2;F/2<H`2>Lh2?Nl4@Q04AS42@Q02AS45@Q02?Nl2=Jd2<H`2:DX2
8@P67>L26<H2Ool00`00Oomoo`0;Ool00`00OomkgP05Nmh<Ool9Nmh4Mkd2Li`2Kg/6JeX4IcT4HaP2
F]H2DY@2CW<2DY@2CW<2AS428@P2AS43?Nl2<H`2?Nl4<H`2AS42CW<2E[D2F]H2HaP2IcT2JeX2Kg/2
Li`6Mkd4Nmh2Mkd2Nmh7Mkd2Li`2Kg/2IcT2HaP2E[D2CW<2<H`21243Ool00`00Oomoo`06Ool000Mo
o`03001oogoo00A6<@9F]@9JePQS609Nm`9F]@=:DP9240@icP8e[@8aS0@]J`HYBPHU:@8Q21lLi`@Q
208U:@8]J`8aS08icPQ240I6<@E2408mk`8icP8e[@8]J`8U:@8Q20@Li`8HaP9oo`03001oogoo00]o
o`03001oog_N00EkgPioo`=kgP9g_@IcW09_N`Q[FPIW>@9S609Nm`9F]@9>L`9BU0A6<@Lmk`@aS0@Q
208mk`96<@AJeP9Nm`9W>@9[FP9_N`9cW0Qg_@IkgPMg_@AcW09[FP9S609JeP96<@8aS08<H`=oo`03
001oogoo00Ioo`001goo00<007ooOol014Ha0UJe0U[F26<H0Ukg0UJe0dYB0T8@13W>0SF]0S6<12e[
1RU:1RDY0R487acW12480RDY0Re[0S6<0SW>248@1THa1D8@0Sg_0SW>0SF]0Re[0RDY0R4811cW0QS6
0Woo00<007ooOol02goo00<007ooNmh01G_N3Woo0g_N0WNm1W>L0Vmk26]J1VLi0V<H0Ukg0UJe0Tic
0U:D14Ha1cg_136<12480Sg_0THa15[F0Ukg0VLi0V]J0Vmk0W>L27Nm1W_N1gNm17>L0V]J0V<H0U[F
0THa0S6<0PaS0goo00<007ooOol01Woo0007Ool00`00Oomoo`04AS42E[D2G_L2HaP2IcT2HaP4G_L2
E[D3BU82?Nl4=Jd4<H`2;F/::DX49BT28@PO7>L48@P29BT2:DX2<H`2>Lh2?Nl4@Q04AS44BU83AS42
@Q02?Nl2>Lh2=Jd2;F/29BT28@P47>L26<H2Ool00`00Oomoo`0;Ool00`00OomkgP05Nmh>Ool3Nmh2
Mkd4Li`4Kg/4JeX2IcT2JeX6IcT4HaP2E[D4DY@2CW<4?Nl2<H`5?Nl6<H`2AS42CW<2E[D2F]H2G_L2
HaP2IcT2Kg/2Li`6Mkd;Nmh4Mkd4Li`2JeX2IcT2F]H2DY@2?Nl25:D3Ool00`00Oomoo`06Ool000Mo
o`03001oogoo00A6<@9F]@9Nm`9S609W>@9S60ANm`9F]@=:DP8mk`@e[@@aS08]J`XYBP@U:@8Q21lL
i`@Q208U:@8YBP8aS08icP8mk`A240A6<@A:DP=6<@92408mk`8icP8e[@8]J`8U:@8Q20@Li`8HaP9o
o`03001oogoo00]oo`03001oog_N00EkgPioo`=kgP9g_@AcW0A_N`A[FP9W>@9[FPIW>@AS609F]@AB
U09>L`@mk`8aS0Dmk`HaS096<@9>L`9F]@9JeP9Nm`9S609W>@9_N`9cW0Ig_@]kgPAg_@AcW09[FP9W
>@9JeP9BU08mk`8DY@=oo`03001oogoo00Ioo`001goo00<007ooOol0148@0Tic0U[F0Ukg0V<H0Ukg
15[F0UJe0dHa0SW>0SF]136<12e[22U:1RDY12487acW0R480RDY0RU:0S6<0SW>0Sg_148@0THa1TYB
0dHa148@0Sg_0SF]0Re[0RDY0R481QcW0Woo00<007ooOol02goo00<007ooMkd00gNm0W_N37oo1G_N
17>L16mk26]J26Li16<H0U[F15:D14Ha0Sg_1C6<0Sg_0S6<13g_0THa15:D0U[F0Ukg0V<H0VLi0Vmk
0W>L1WNm2g_N1WNm0W>L0Vmk0VLi0U[F0Tic0S6<0R480goo00<007ooOol01Woo0007Ool00`00Oomo
o`04@Q02CW<2F]H2G_L2HaP2G_L4F]H2E[D3AS42>Lh2=Jd4<H`4;F/8:DX69BT48@PO7>L28@P29BT2
:DX2<H`2>Lh2?Nl4@Q02AS46BU83AS44@Q02?Nl2=Jd2;F/29BT28@P67>L2Ool00`00Oomoo`0;Ool0
0`00Oomg_@03Mkd2Nmh<Ool5Nmh4Li`4Kg/8JeX8IcT4HaP2F]H4DY@4AS42?Nl5<H`2?Nl2<H`4?Nl2
AS44DY@2F]H2G_L2HaP2IcT2Kg/2Li`6Mkd;Nmh6Mkd2Li`2Kg/2IcT2F]H2CW<2<H`28@P3Ool00`00
Oomoo`06Ool000Moo`03001oogoo008mk`8icP96<@9F]@QJeP9F]@9>L`=2408e[@X]J`@YBPPU:@@Q
224Li`@Q208YBP8aS08icP8mk`A24096<@I:DP=6<@9240@mk`8e[@8]J`8U:@8Q20@Li`8HaP9oo`03
001oogoo00]oo`04001oogNmMkd2Li`4Nmh:Ool2Nmh3Mkd2Li`4Kg/6JeX<IcT2HaP2G_L2F]H2DY@2
CW<2AS42?Nl48@P3<H`28@P2AS42<H`2?Nl2AS42CW<2DY@2E[D2G_L2HaP2IcT2Kg/2Li`6Mkd;Nmh6
Mkd2Li`2Kg/2IcT2G_L2AS42<H`25:D3Ool00`00Oomoo`06Ool000Moo`03001oogoo008mk`8icP96
<@9F]@QJeP9F]@9>L`=2408e[@X]J`@YBPPU:@@Q224Li`@Q208YBP8aS08icP8mk`A24096<@I:DP=6
<@9240@mk`8e[@8]J`8U:@8Q20@Li`8HaP9oo`03001oogoo00]oo`04001oogNmMkd2Li`4Nmh:Ool2
Nmh3Mkd2Li`4Kg/6JeX<IcT2HaP2G_L2F]H2DY@2CW<2AS42?Nl48@P3<H`28@P2AS42<H`2?Nl2AS42
CW<2DY@2E[D2G_L2HaP2IcT2Kg/2Li`6Mkd;Nmh6Mkd2Li`2Kg/2IcT2G_L2AS42<H`25:D3Ool00`00
Oomoo`06Ool000Moo`03001oogoo00@icP92409:DP9BU0IF]@9>L`96<@<icP8aS0X]J`HYBPPU:@8Q
224Li`@Q208U:@8aS08e[@8mk`9240A6<@A:DPE6<@92408mk`8icP8e[@8]J`8U:@8Q20@Li`8HaP9o
o`03001oogoo00]oo`03001oog>L00=cW09g_@IkgP9oo`IkgP=cW0A_N`Q[FPaW>@9S609Nm`9F]@9>
L`A6<@/mk`8aS0Hmk`96<@9>L`AJeP9S609W>@9_N`9cW0Ag_@ekgPAg_@AcW09_N`9W>@9JeP9>L`8a
S08DY@=oo`03001oogoo00Ioo`001goo00<007ooOol013W>0T8@0TYB0U:D1UJe0Tic0THa0cW>0S6<
2Re[1RU:22DY0R488AcW12480RDY0S6<0SF]0Sg_0T8@14Ha14YB1DHa0T8@0Sg_0SW>0SF]0Re[0RDY
0R4811cW0QS60Woo00<007ooOol02goo00<007ooLi`00g>L0WNm1W_N0Woo1W_N0g>L16mk26]J36Li
0V<H0Ukg0UJe0Tic14Ha2cg_0S6<1Sg_0THa0Tic15[F0V<H0VLi0Vmk0W>L17Nm3G_N17Nm17>L0Vmk
0VLi0U[F0Tic0S6<0QBU0goo00<007ooOol01Woo0007Ool00`00Oomoo`04=Jd2>Lh2?Nl2@Q02AS44
BU82@Q02>Lh3=Jd2<H`:;F/4:DX:9BT28@P:7>L26<HE7>L48@P29BT2;F/2=Jd2?Nl2@Q04AS44BU85
AS42@Q02?Nl2>Lh2=Jd2;F/29BT28@P47>L26<H2Ool00`00Oomoo`0;Ool00`00OomcW005Li`4Mkd6
Nmh2Mkd5Li`6Kg/6JeX:IcT4HaP2G_L2AS42DY@4AS428@P25:D28@P3<H`4?Nl4<H`2?Nl2AS44DY@2
F]H2HaP2IcT2JeX2Li`4Mkd=Nmh4Mkd4Li`2JeX2HaP2F]H2AS428@P25:D3Ool00`00Oomoo`06Ool0
00Moo`03001oogoo00@e[@8icP8mk`924096<@A:DP92408icP<e[@8aS0X]J`@YBPXU:@8Q20XLi`8H
aQDLi`@Q208U:@8]J`8e[@8mk`9240A6<@A:DPE6<@92408mk`8icP8e[@8]J`8U:@8Q20@Li`8HaP9o
o`03001oogoo00]oo`03001oog>L00EcW0Ag_@IkgP9g_@EcW0I_N`I[FPYW>@AS609Nm`96<@9BU0A6
<@8Q208DY@8Q20<aS0@mk`@aS08mk`96<@ABU09JeP9S609W>@9[FP9cW0Ag_@ekgPAg_@AcW09[FP9S
609JeP96<@8Q208DY@=oo`03001oogoo00Ioo`001goo00<007ooOol0136<13F]13W>0Sg_0SW>13F]
0c6<2Re[0RU:32DY0R488acW12480RDY0Re[0SF]0Sg_0T8@3DHa0T8@0Sg_0SW>0SF]0Re[0RDY1QcW
0QS60Woo00<007ooOol02goo00<007ooKg/00fmk27>L0WNm17>L1fmk2V]J26Li1V<H0U[F0Tic0U:D
0THa0Sg_12481c6<0Sg_0S6<13g_0THa0Tic0U:D0U[F0Ukg0V<H0V]J0W>L17Nm3G_N17Nm17>L0V]J
0V<H0U[F0Tic0R480P@Q0goo00<007ooOol01Woo0007Ool00`00Oomoo`04<H`4=Jd4>Lh2?Nl2>Lh4
=Jd3<H`:;F/2:DX<9BT28@PS7>L48@P29BT2;F/2=Jd2?Nl2@Q0=AS42@Q02?Nl2>Lh2=Jd2;F/29BT6
7>L26<H2Ool00`00Oomoo`0;Ool00`00Oom_N`03Kg/8Li`2Mkd4Li`7Kg/:JeX8IcT6HaP2F]H2CW<2
DY@2AS42?Nl48@P7<H`2?Nl2<H`4?Nl2AS42CW<2DY@2F]H2G_L2HaP2JeX2Li`4Mkd=Nmh4Mkd4Li`2
JeX2HaP2F]H2CW<28@P21243Ool00`00Oomoo`06Ool000Moo`03001oogoo00@]J`HaS0@e[@HaS0d]
J`@YBPPU:@@Q20hLi`8HaQDLi`8Q208U:@8YBP8e[@8mk`9240Y6<@E2408mk`8icP8aS08YBP8Q20HL
i`8HaP9oo`03001oogoo00]oo`03001oofmk00U_N`AcW0U_N`a[FP9W>@YS609Nm`9BU096<@8mk`96
<@@aS08Q208DY@<mk`96<@8mk`8aS08mk`A6<@9>L`9F]@9JeP9Nm`9S609[FP9cW0Ag_@YkgPMg_@9c
W09_N`9W>@9S609BU08mk`8Q20848@=oo`03001oogoo00Ioo`001goo00<007ooOol012e[1S6<13F]
1S6<3Be[12U:22DY12483QcW0QS65AcW0R480RDY0RU:0SF]0Sg_0T8@2THa1D8@0Sg_0SW>0S6<0RU:
0R481QcW0QS60Woo00<007ooOol02goo00<007ooKg/02Fmk17>L2Fmk36]J0VLi2V<H0Ukg0U:D0THa
0Sg_0THa136<0R480QBU0cg_0THa0Sg_0S6<0Sg_14Ha0Tic0UJe0U[F0Ukg0V<H0V]J0W>L17Nm2W_N
1gNm0W>L0Vmk0VLi0V<H0U:D0Sg_0R480P@Q0goo00<007ooOol01Woo0007Ool00`00Oomoo`0:;F/6
<H`2;F/2:DX5;F/4:DX2;F/4:DX49BT88@P@7>L26<HE7>L48@P2:DX2=Jd4?Nl2@Q06AS42@Q05?Nl2
>Lh2=Jd2<H`29BT28@P47>L46<H2Ool00`00Oomoo`0;Ool00`00Oom[FP03JeX>Kg/?JeX4IcT8HaP2
G_L2DY@2?Nl2AS42?Nl4<H`28@P2<H`25:D38@P4?Nl2<H`2?Nl6CW<2DY@2E[D2G_L2HaP2JeX2Li`6
Mkd6Nmh7Mkd4Li`2Kg/2IcT2G_L2CW<28@P25:D236<3Ool00`00Oomoo`06Ool000Moo`03001oogoo
00X]J`HaS08]J`8YBPD]J`@YBP8]J`@YBP@U:@PQ210Li`8HaQDLi`@Q208YBP8e[@@mk`9240I6<@92
40Dmk`8icP8e[@8aS08U:@8Q20@Li`@HaP9oo`03001oogoo00]oo`03001oof]J00=[FPi_N`m[FPAW
>@QS609Nm`9BU08mk`96<@8mk`@aS08Q208aS08DY@<Q20@mk`8aS08mk`I>L`9BU09F]@9Nm`9S609[
FP9cW0Ig_@IkgPMg_@AcW09_N`9W>@9Nm`9>L`8Q208DY@8<H`=oo`03001oogoo00Ioo`001goo00<0
07ooOol012U:3Re[4BU:0RDY1248;AcW12480RU:0S6<0SW>0Sg_248@0Sg_1CW>0SF]0S6<0RU:0R48
11cW1QS60Woo00<007ooOol02goo00@007ooIcUW>@Q[FP9_N`Q[FPMW>@A[FPAW>@9S609Nm`9JePIF
]@9>L`I6<@@mk`8Q208aS08Q20=6<@@aS08Q20@mk`9>L`96<@9>L`9F]@9JeP9S609W>@9_N`9cW0ag
_@McW09_N`9[FP9S609JeP96<@8DY@@<H`=oo`03001oogoo00Ioo`001goo00<007ooOol012U:3Re[
4BU:0RDY1248;AcW12480RU:0S6<0SW>0Sg_248@0Sg_1CW>0SF]0S6<0RU:0R4811cW1QS60Woo00<0
07ooOol02goo00@007ooIcUW>@Q[FP9_N`Q[FPMW>@A[FPAW>@9S609Nm`9JePIF]@9>L`I6<@@mk`8Q
208aS08Q20=6<@@aS08Q20@mk`9>L`96<@9>L`9F]@9JeP9S609W>@9_N`9cW0ag_@McW09_N`9[FP9S
609JeP96<@8DY@@<H`=oo`03001oogoo00Ioo`001goo00<007ooOol00RDY12U:0Re[0RU:0Re[22U:
1bDY12U:12DY1248;acW12480RDY0Re[0SF]13g_148@0Sg_0SW>0cF]0S6<12e[0RDY0R4811cW1QS6
0Woo00<007ooOol02goo00<007ooIcT00fLi36]J16Li1F<H26Li0V<H0Ukg15[F0Tic0U:D0Tic14Ha
0Tic14Ha0Sg_1S6<1Cg_136<0Sg_1THa0Tic0U:D0U[F0Ukg0VLi0Vmk0W>L2WNm0W>L1fmk0V]J0VLi
0Ukg0Tic0Sg_10aS0P@Q0goo00<007ooOol01Woo0007Ool00`00Oomoo`029BT4:DX2;F/2:DX2;F/8
:DX79BT4:DX49BT48@P_7>L48@P29BT2;F/2=Jd4?Nl4@Q02?Nl2>Lh3=Jd2<H`4;F/29BT28@P47>L6
6<H2Ool00`00Oomoo`0;Ool00`00OomW>@03IcT<JeX4IcT5HaP8IcT2HaP2G_L4F]H2CW<2DY@2CW<4
AS42CW<4AS42?Nl6<H`5?Nl4<H`2?Nl6AS42CW<2DY@2F]H2G_L2IcT2Kg/2Li`:Mkd2Li`7Kg/2JeX2
IcT2G_L2CW<2?Nl436<21243Ool00`00Oomoo`06Ool000Moo`03001oogoo008Q208U:@XYBPHU:@lQ
23DLi`8Q208U:@8YBP8aS08icPHmk`8icP8e[@<]J`@YBP8U:@8Q20HLi`HHaP9oo`03001oogoo00]o
o`04001ooekgG_L4IcT4JeX8IcT2HaP5G_L8HaP2G_L2F]H2E[D4CW<8AS44?Nl4<H`28@P2?Nl9<H`:
?Nl2AS44E[D2F]H2HaP2JeX2Kg/2Li`6Mkd4Li`3Kg/2JeX2IcT2HaP2G_L2F]H2AS428@P25:D41243
Ool00`00Oomoo`06Ool000Moo`03001oogoo008Q208U:@XYBPHU:@lQ23DLi`8Q208U:@8YBP8aS08i
cPHmk`8icP8e[@<]J`@YBP8U:@8Q20HLi`HHaP9oo`03001oogoo00]oo`04001ooekgG_L4IcT4JeX8
IcT2HaP5G_L8HaP2G_L2F]H2E[D4CW<8AS44?Nl4<H`28@P2?Nl9<H`:?Nl2AS44E[D2F]H2HaP2JeX2
Kg/2Li`6Mkd4Li`3Kg/2JeX2IcT2HaP2G_L2F]H2AS428@P25:D41243Ool00`00Oomoo`06Ool000Mo
o`03001oogoo00@Q208U:@HYBPHU:@lQ23TLi`8Q208U:@8]J`8aS08e[@@icP8e[@8aS0<YBP8U:@@Q
20PLi`HHaP9oo`03001oogoo00]oo`04001ooekgG_L2HaP4IcT2JeX4IcT4HaP5G_L2F]H6G_L4F]H6
DY@6?Nl2<H`2AS42<H`2?Nl8<H`28@P3?Nl2<H`4?Nl6AS42<H`2?Nl2CW<2E[D2F]H2HaP2IcT2JeX2
Kg/8Li`2Kg/3JeX2IcT2HaP2G_L2F]H2DY@2?Nl28@P61243Ool00`00Oomoo`06Ool000Moo`03001o
ogoo00@Q208U:@HYBPHU:@lQ23TLi`8Q208U:@8]J`8aS08e[@@icP8e[@8aS0<YBP8U:@@Q20PLi`HH
aP9oo`03001oogoo00]oo`04001ooekgG_L2HaP4IcT2JeX4IcT4HaP5G_L2F]H6G_L4F]H6DY@6?Nl2
<H`2AS42<H`2?Nl8<H`28@P3?Nl2<H`4?Nl6AS42<H`2?Nl2CW<2E[D2F]H2HaP2IcT2JeX2Kg/8Li`2
Kg/3JeX2IcT2HaP2G_L2F]H2DY@2?Nl28@P61243Ool00`00Oomoo`06Ool000Moo`03001oogoo00HQ
20HU:@PQ24HLi`8Q208U:@8YBP8]J`8aS08e[@@aS08YBP<U:@@Q20PLi`PHaP9oo`03001oogoo00]o
o`04001ooe[FF]H2G_L8HaP6G_L5F]H2E[D2F]H2E[D2F]H2E[D2DY@4CW<2AS42?Nl2<H`4?Nl2AS46
<H`4?Nl2<H`2?Nl3AS428@P2<H`4?Nl4CW<4AS44DY@2F]H2G_L2HaP2IcT2JeX8Kg/2JeX3IcT2HaP4
F]H2CW<2?Nl28@P236<61243Ool00`00Oomoo`06Ool000Moo`03001oogoo00HQ20HU:@PQ24HLi`8Q
208U:@8YBP8]J`8aS08e[@@aS08YBP<U:@@Q20PLi`PHaP9oo`03001oogoo00]oo`04001ooe[FF]H2
G_L8HaP6G_L5F]H2E[D2F]H2E[D2F]H2E[D2DY@4CW<2AS42?Nl2<H`4?Nl2AS46<H`4?Nl2<H`2?Nl3
AS428@P2<H`4?Nl4CW<4AS44DY@2F]H2G_L2HaP2IcT2JeX8Kg/2JeX3IcT2HaP4F]H2CW<2?Nl28@P2
36<61243Ool00`00Oomoo`06Ool000Moo`03001oogoo018Q24PLi`@Q20@U:@8YBP@]J`8YBPDU:@8Q
20PLi`XHaP9oo`03001oogoo00]oo`03001ooe[F00=JePQNm`IJeP9F]@UBU09F]@9BU096<@9>L`8m
k`@aS096<@@mk`@aS08mk`PaS0Dmk`@aS08mk`A6<@A>L`8mk`9BU0AF]@9JeP9Nm`9S609W>@Q[FP9W
>@=S609JeP9F]@9BU096<@8aS0@DY@H48@=oo`03001oogoo00Ioo`001goo00<007ooOol04R48B1cW
124812DY0RU:12e[0RU:1BDY0R4821cW2QS60Woo00<007ooOol02goo00<007ooF]H00e[F25kg1U[F
0UJe2E:D0UJe0U:D0THa0Tic0Sg_136<0THa13g_136<0Sg_236<1Cg_136<0Sg_14Ha14ic0Sg_0U:D
15Je0U[F0Ukg0V<H0VLi26]J0VLi0f<H0U[F0UJe0U:D0THa0S6<11BU1P@Q0goo00<007ooOol01Woo
0007Ool00`00Oomoo`1L7>L68@P89BT58@P:7>L:6<H2Ool00`00Oomoo`0;Ool00`00OomF]@03E[D2
F]H2E[D2F]H2E[D2F]H2DY@2E[D7DY@2CW<2AS44DY@2AS42?Nl2<H`2?Nl28@P2<H`:?Nl2<H`68@P5
?Nl4<H`6?Nl2AS42?Nl6AS42DY@2E[D2F]H2G_L6HaP2IcT4HaP3F]H2DY@2AS44?Nl28@P45:D236<2
12420003Ool00`00Oomoo`06Ool000Moo`03001oogoo05`Li`HQ20PU:@DQ20XLi`XHaP9oo`03001o
ogoo00]oo`03001ooeJe00=F]@9JeP9F]@9JeP9F]@9JeP9BU09F]@MBU09>L`96<@ABU096<@8mk`8a
S08mk`8Q208aS0Xmk`8aS0HQ20Dmk`@aS0Hmk`96<@8mk`I6<@9BU09F]@9JeP9Nm`IS609W>@AS60=J
eP9BU096<@@mk`8Q20@DY@8<H`848@8000=oo`03001oogoo00Ioo`001goo00<007ooOol0H1cW3248
2acW31S60Woo00<007ooOol02goo00@007ooAS56<@9BU09>L`9BU09JeP9BU09>L`ABU096<@=>L`9B
U096<@9BU0A6<@8mk`96<A0aS096<A4aS0Pmk`96<@Hmk`96<@9>L`AF]@9JePQNm`9JeP=F]@9>L`96
<@@aS0X<H`8000=oo`03001oogoo00Ioo`001goo00<007ooOol0H1cW32482acW31S60Woo00<007oo
Ool02goo00@007ooAS56<@9BU09>L`9BU09JeP9BU09>L`ABU096<@=>L`9BU096<@9BU0A6<@8mk`96
<A0aS096<A4aS0Pmk`96<@Hmk`96<@9>L`AF]@9JePQNm`9JeP=F]@9>L`96<@@aS0X<H`8000=oo`03
001oogoo00Ioo`001goo00<007ooOol0MAcW3QS60Woo00<007ooOol02goo00<007ooCW<01dic0UJe
0U:D0Tic0THa3Dic0Sg_1THa1S6<13g_236<0Sg_1S6<1cg_0THa0S6<0Sg_0THa0S6<0THa0Sg_14Ha
0Sg_0Tic0UJe0U[F0UJe0U:D0U[F15Je0U:D0eJe0THa0R480S6<0QBU0PaS2P@Q0goo00<007ooOol0
1Woo0007Ool00`00Oomoo`1e7>L>6<H2Ool00`00Oomoo`0;Ool00`00Oom>L`07CW<2E[D2DY@2CW<2
AS4=CW<2?Nl6AS46<H`4?Nl8<H`2?Nl6<H`7?Nl2AS42<H`2?Nl2AS42<H`2AS42?Nl4AS42?Nl2CW<2
E[D2F]H2E[D2DY@2F]H4E[D2DY@3E[D2AS428@P2<H`25:D236<:1243Ool00`00Oomoo`06Ool000Mo
o`03001oogoo07TLi`XHaP9oo`03001oogoo00]oo`04001oodHaAS42CW<2AS48CW<2AS44?Nl3CW<6
AS46?Nl2CW<2AS42?Nl28@P2<H`2AS48<H`2?Nl6<H`2?Nl3<H`4?Nl2<H`2AS42?Nl2<H`2AS42?Nl6
AS44CW<2DY@2E[D4DY@4CW<2DY@3AS42?Nl88@P2124236<412420003Ool00`00Oomoo`06Ool000Mo
o`03001oogoo07TLi`XHaP9oo`03001oogoo00]oo`04001oodHaAS42CW<2AS48CW<2AS44?Nl3CW<6
AS46?Nl2CW<2AS42?Nl28@P2<H`2AS48<H`2?Nl6<H`2?Nl3<H`4?Nl2<H`2AS42?Nl2<H`2AS42?Nl6
AS44CW<2DY@2E[D4DY@4CW<2DY@3AS42?Nl88@P2124236<412420003Ool00`00Oomoo`06Ool000Mo
o`03001oogoo07<Lia0HaP9oo`03001oogoo00]oo`04001oodicCW<2AS42?Nl4AS46?Nl2CW<2AS43
CW<4AS42?Nl4<H`2?Nl2<H`4?Nl48@P2?Nl8<H`2AS428@P2<H`2?Nl2<H`3?Nl2<H`2AS42?Nl2<H`2
?Nl6<H`2?Nl2<H`2AS42?Nl4AS42DY@4AS42CW<2AS42?Nl5<H`28@P45:D236<812420003Ool00`00
Oomoo`06Ool000Moo`03001oogoo07<Lia0HaP9oo`03001oogoo00]oo`04001oodicCW<2AS42?Nl4
AS46?Nl2CW<2AS43CW<4AS42?Nl4<H`2?Nl2<H`4?Nl48@P2?Nl8<H`2AS428@P2<H`2?Nl2<H`3?Nl2
<H`2AS42?Nl2<H`2?Nl6<H`2?Nl2<H`2AS42?Nl4AS42DY@4AS42CW<2AS42?Nl5<H`28@P45:D236<8
12420003Ool00`00Oomoo`06Ool000Moo`03001oogoo04`Li`8HaPPLi`8HaQ/Lia0HaP9oo`03001o
ogoo00]oo`03001oodHa00=6<@8aS08mk`A6<@8aS0A6<@E>L``mk`96<@8mk`96<@@aS08Q208aS08Q
20@aS08mk`8aS08mk`LaS0@mk`8aS08Q208DY@HaS08Q208DY@8aS0@mk`I6<@@mk`8aS0TQ20@<H``4
8@=oo`03001oogoo00Ioo`001goo00<007ooOol0C1cW0QS621cW0QS66acW41S60Woo00<007ooOol0
2goo00<007ooAS400dHa0S6<0Sg_14Ha0S6<14Ha1Dic33g_0THa0Sg_0THa136<0R480S6<0R48136<
0Sg_0S6<0Sg_1c6<13g_0S6<0R480QBU1S6<0R480QBU0S6<13g_1THa13g_0S6<2B4810aS30@Q0goo
00<007ooOol01Woo0007Ool00`00Oomoo`1D7>L66<H:7>L26<H67>L56<H27>L@6<H2Ool00`00Oomo
o`0;Ool01000OolaS36<0THa0Sg_1THa0S6<13g_0THa1cg_0S6<13g_136<0R480Sg_0S6<0R480S6<
0Sg_136<1248236<0b480S6<0Sg_0S6<0R480S6<12480S6<1QBU0Sg_0S6<0R48136<0QBU136<0R48
1ABU0R4811BU0PaS2P@Q0goo00<007ooOol01Woo0007Ool00`00Oomoo`1D7>L66<H:7>L26<H67>L5
6<H27>L@6<H2Ool00`00Oomoo`0;Ool01000OolaS36<0THa0Sg_1THa0S6<13g_0THa1cg_0S6<13g_
136<0R480Sg_0S6<0R480S6<0Sg_136<1248236<0b480S6<0Sg_0S6<0R480S6<12480S6<1QBU0Sg_
0S6<0R48136<0QBU136<0R481ABU0R4811BU0PaS2P@Q0goo00<007ooOol01Woo0007Ool00`00Oomo
o`1D7>L66<H:7>L26<H67>L56<H27>L@6<H2Ool00`00Oomoo`0;Ool01000OolaS36<0THa0Sg_1THa
0S6<13g_0THa1cg_0S6<13g_136<0R480Sg_0S6<0R480S6<0Sg_136<1248236<0b480S6<0Sg_0S6<
0R480S6<12480S6<1QBU0Sg_0S6<0R48136<0QBU136<0R481ABU0R4811BU0PaS2P@Q0goo00<007oo
Ool01Woo0007Ool00`00Oomoo`1H7>L26<H>7>LK6<H2Ool00`00Oomoo`0;Ool01000OolQ22480Tic
14Ha0Tic1Sg_0THa0Sg_0c6<2Sg_0S6<0Sg_3S6<1248136<1R480c6<0Sg_0S6<12480S6<12480Sg_
12480QBU136<12480S6<0R480S6<2aBU0P@Q1PaS1P@Q0P000goo00<007ooOol01Woo0007Ool00`00
Oomoo`1H7>L26<H>7>LK6<H2Ool00`00Oomoo`0;Ool01000OolQ22480Tic14Ha0Tic1Sg_0THa0Sg_
0c6<2Sg_0S6<0Sg_3S6<1248136<1R480c6<0Sg_0S6<12480S6<12480Sg_12480QBU136<12480S6<
0R480S6<2aBU0P@Q1PaS1P@Q0P000goo00<007ooOol01Woo0007Ool00`00Oomoo`0W7>L26<H47>L2
6<H>7>L46<H57>L66<H47>L46<H27>L26<H67>L26<H47>L66<H27>LG6<H2Ool00`00Oomoo`0;Ool0
0`00Oolmk`03?Nl2<H`2?Nl2AS44?Nl2<H`2?Nl2<H`3AS44<H`4?Nl6AS428@P25:D48@P25:D28@P4
<H`28@P6<H`25:D236<38@P2?Nl236<45:D2<H`28@P45:D28@P25:D68@P25:D48@P65:D28@P536<2
124236<:12440003Ool00`00Oomoo`06Ool000Moo`03001oogoo02LLi`8HaP@Li`8HaPhLi`@HaPDL
i`HHaP@Li`@HaP8Li`8HaPHLi`8HaP@Li`HHaP8LiaLHaP9oo`03001oogoo00]oo`03001oocg_00<m
k`8aS08mk`96<@@mk`8aS08mk`8aS0=6<@@aS0@mk`I6<@8Q208DY@@Q208DY@8Q20@aS08Q20HaS08D
Y@8<H`<Q208mk`8<H`@DY@8aS08Q20@DY@8Q208DY@HQ208DY@@Q20HDY@8Q20D<H`848@8<H`X48@@0
00=oo`03001oogoo00Ioo`001goo00<007ooOol011cW0QS6<AcW0QS611cW11S64AcW1QS631cW7aS6
0Woo00<007ooOol02goo00@007oo?Nlmk`8aS08DY@96<@Hmk`8aS0Lmk`96<@8aS0Hmk`8aS096<@Ha
S08Q208aS08Q208mk`8aS08Q208DY@8Q208mk`@DYA4Q20HDY@@aS0PQ20HDY@8<Ha<48@@000=oo`03
001oogoo00Ioo`001goo00<007ooOol011cW0QS6<AcW0QS611cW11S64AcW1QS631cW7aS60Woo00<0
07ooOol02goo00@007oo?Nlmk`8aS08DY@96<@Hmk`8aS0Lmk`96<@8aS0Hmk`8aS096<@HaS08Q208a
S08Q208mk`8aS08Q208DY@8Q208mk`@DYA4Q20HDY@@aS0PQ20HDY@8<Ha<48@@000=oo`03001oogoo
00Ioo`001goo00<007ooOol0<acW1QS621cW0aS641cW0QS63QcW7aS60Woo00<007ooOol02goo00@0
07oo?Nlmk`8Q208aS0Hmk`8aS08mk`@aS0Tmk`8aS0Hmk`XaS08mk`8Q20HDY@PQ20<DY@@Q208aS08m
k`PQ208DY@8Q208mk`@Q208aS0@Q208<H`8DY@T<H`@48@8000P48@@000=oo`03001oogoo00Ioo`00
1goo00<007ooOol0<acW1QS621cW0aS641cW0QS63QcW7aS60Woo00<007ooOol02goo00@007oo?Nlm
k`8Q208aS0Hmk`8aS08mk`@aS0Tmk`8aS0Hmk`XaS08mk`8Q20HDY@PQ20<DY@@Q208aS08mk`PQ208D
Y@8Q208mk`@Q208aS0@Q208<H`8DY@T<H`@48@8000P48@@000=oo`03001oogoo00Ioo`001goo00<0
07ooOol0;AcW0QS61QcW11S621cW0aS60QcW0QS61QcW11S60QcW0QS631cW8AS60Woo00<007ooOol0
2goo00@007ooAS56<@8mk`8aS096<@8mk`96<@Hmk`8Q20<aS0@mk`I6<@8mk`8aS08Q208mk`8aS08Q
208DY@8mk`@aS0@DY@@aS0@Q20<DY@8Q208DY@8mk`@aS0@DY@8Q208DY@8Q208mk`8Q20@aS08Q20@D
Y@@<HaD48@8000848@=oo`03001oogoo00Ioo`001goo00<007ooOol0;AcW0QS61QcW11S621cW0aS6
0QcW0QS61QcW11S60QcW0QS631cW8AS60Woo00<007ooOol02goo00@007ooAS56<@8mk`8aS096<@8m
k`96<@Hmk`8Q20<aS0@mk`I6<@8mk`8aS08Q208mk`8aS08Q208DY@8mk`@aS0@DY@@aS0@Q20<DY@8Q
208DY@8mk`@aS0@DY@8Q208DY@8Q208mk`8Q20@aS08Q20@DY@@<HaD48@8000848@=oo`03001oogoo
00Ioo`001goo00<007ooOol02QcW0QS67acW11S641cW1AS631cW0QS60QcW11S631cW7aS60Woo00<0
07ooOol02goo00<007oo<H`01C6<14Ha0QBU0Sg_1S6<0b480Sg_0S6<0Sg_0THa0Sg_236<0R4811BU
0Sg_0S6<32480QBU0`aS32480QBU0R4811BU1248136<12480PaS6@@Q10000goo00<007ooOol01Woo
0007Ool00`00Oomoo`0:7>L26<HO7>L46<H@7>L56<H<7>L26<H27>L46<H<7>LO6<H2Ool00`00Oomo
o`0;Ool00`00OolaS005<H`4AS425:D2?Nl6<H`38@P2?Nl2<H`2?Nl2AS42?Nl8<H`28@P45:D2?Nl2
<H`<8@P25:D336<<8@P25:D28@P45:D48@P4<H`48@P236<I12440003Ool00`00Oomoo`06Ool000Mo
o`03001oogoo02TLi`8HaP8Li`@HaPPLi`8HaP8Li`dHaP@Li`XHaP8Li`8HaP8LibDHaP9oo`03001o
ogoo00]oo`04001oob488@P2<H`28@P2?Nl2<H`28@P4?Nl4<H`=8@P2<H`68@P25:D28@P45:D28@P2
<H`48@P25:D2<H`25:D236<95:D48@P45:D636<28@P25:D28@P25:D636<612450002124236<:1244
0003Ool00`00Oomoo`06Ool000Moo`03001oogoo02TLi`8HaP8Li`@HaPPLi`8HaP8Li`dHaP@Li`XH
aP8Li`8HaP8LibDHaP9oo`03001oogoo00]oo`04001oob488@P2<H`28@P2?Nl2<H`28@P4?Nl4<H`=
8@P2<H`68@P25:D28@P45:D28@P2<H`48@P25:D2<H`25:D236<95:D48@P45:D636<28@P25:D28@P2
5:D636<612450002124236<:12440003Ool00`00Oomoo`06Ool000Moo`03001oogoo008HaQTLi`8H
aP`Li`PHaPHLi`PHaP8Lid8HaP9oo`03001oogoo00]oo`04001ooaBU5:D6<H`48@P2?Nl9<H`48@P2
5:D48@P2<H`28@P2<H`28@P236<65:D48@P2<H`85:D28@P336<412465:D636<2124236<65:D636<2
124236<9124236<<12440003Ool00`00Oomoo`06Ool000Moo`03001oogoo008HaQTLi`8HaP`Li`PH
aPHLi`PHaP8Lid8HaP9oo`03001oogoo00]oo`04001ooaBU5:D6<H`48@P2?Nl9<H`48@P25:D48@P2
<H`28@P2<H`28@P236<65:D48@P2<H`85:D28@P336<412465:D636<2124236<65:D636<2124236<9
124236<<12440003Ool00`00Oomoo`06Ool000Moo`03001oogoo008HaRDLi`PHaPXLi`lHaP8Li`8H
aP8LicDHaP9oo`03001oogoo00]oo`04001ooaBU5:D4<H`2?Nl28@P2<H`2?Nl28@PE<H`28@P65:D2
36<28@P4<H`48@P;5:D236<25:D28@P25:D2<H`25:D436<:5:D236<25:D436<6124736<6124236<2
124400021243Ool00`00Oomoo`06Ool000Moo`03001oogoo008HaRDLi`PHaPXLi`lHaP8Li`8HaP8L
icDHaP9oo`03001oogoo00]oo`04001ooaBU5:D4<H`2?Nl28@P2<H`2?Nl28@PE<H`28@P65:D236<2
8@P4<H`48@P;5:D236<25:D28@P25:D2<H`25:D436<:5:D236<25:D436<6124736<6124236<21244
00021243Ool00`00Oomoo`06Ool000Moo`03001oogoo02DLi`XHaP8Li`8HaPHLi`@HaP8Li`dHaPHL
i`8HaPHLi`8HaP8LibDHaP9oo`03001oogoo00]oo`03001ooc6<00<aS08Q208mk`8aS08Q208aS0@Q
20LaS0@Q208mk`8aS08mk`8aS08DY@8<H`8DY@8<H`8DY@8Q208DY@HQ20@<H`8Q208<H`<DY@848@8<
H`@DY@8aS0@Q208<H`HQ208<H`8Q20@DY@H<H`8000d48@8<H`H48@@000=oo`03001oogoo00Ioo`00
1goo00<007ooOol09AcW2QS60QcW0QS61QcW11S60QcW3AS61QcW0QS61QcW0QS60QcW9AS60Woo00<0
07ooOol02goo00<007oo<H`00c6<0R480Sg_0S6<0R480S6<12481c6<12480Sg_0S6<0Sg_0S6<0QBU
0PaS0QBU0PaS0QBU0R480QBU1R4810aS0R480PaS0aBU0P@Q0PaS11BU0S6<12480PaS1R480PaS0R48
11BU1PaS0P003@@Q0PaS1P@Q10000goo00<007ooOol01Woo0007Ool00`00Oomoo`026<HS7>L46<H4
7>L26<H27>LM6<H27>L46<H67>LY6<H2Ool00`00Oomoo`0;Ool01000OolDYABU13g_0THa0S6<2248
0S6<0b480Sg_1248136<0R480S6<11BU12480PaS0R480QBU0PaS11BU10@Q10aS0aBU10aS1QBU0S6<
11BU1R481QBU0PaS0P@Q0PaS2`@Q0P000P@Q0PaS2P@Q0P000goo00<007ooOol01Woo0007Ool00`00
Oomoo`026<HS7>L46<H47>L26<H27>LM6<H27>L46<H67>LY6<H2Ool00`00Oomoo`0;Ool01000OolD
YABU13g_0THa0S6<22480S6<0b480Sg_1248136<0R480S6<11BU12480PaS0R480QBU0PaS11BU10@Q
10aS0aBU10aS1QBU0S6<11BU1R481QBU0PaS0P@Q0PaS2`@Q0P000P@Q0PaS2P@Q0P000goo00<007oo
Ool01Woo0007Ool00`00Oomoo`026<H@7>L26<H37>L26<H@7>LU6<H27>L46<H27>L26<H47>LW6<H2
Ool00`00Oomoo`0;Ool01000OolDYABU0S6<0R480Sg_136<1R480QBU0b480QBU1S6<2R4811BU0PaS
11BU20aS0P@Q10aS0aBU10aS1QBU0R4811BU0R480QBU0R480S6<0QBU0PaS0P@Q10aS2`@Q10001P@Q
20000goo00<007ooOol01Woo0007Ool00`00Oomoo`026<H@7>L26<H37>L26<H@7>LU6<H27>L46<H2
7>L26<H47>LW6<H2Ool00`00Oomoo`0;Ool01000OolDYABU0S6<0R480Sg_136<1R480QBU0b480QBU
1S6<2R4811BU0PaS11BU20aS0P@Q10aS0aBU10aS1QBU0R4811BU0R480QBU0R480S6<0QBU0PaS0P@Q
10aS2`@Q10001P@Q20000goo00<007ooOol01Woo0007Ool00`00Oomoo`047>L26<HM7>L46<H27>L6
6<H27>L26<H27>L?6<H27>L86<H27>L:6<H47>LU6<H2Ool00`00Oomoo`0;Ool01000OolQ22480S6<
0QBU0R480S6<0Sg_1S6<2b480S6<124811BU0R4810aS0QBU0S6<0PaS0R481QBU10aS0P@Q0aBU0R48
21BU0R481QBU0PaS0QBU12480PaS0P@Q0PaS5`@Q20000goo00<007ooOol01Woo0007Ool00`00Oomo
o`047>L26<HM7>L46<H27>L66<H27>L26<H27>L?6<H27>L86<H27>L:6<H47>LU6<H2Ool00`00Oomo
o`0;Ool01000OolQ22480S6<0QBU0R480S6<0Sg_1S6<2b480S6<124811BU0R4810aS0QBU0S6<0PaS
0R481QBU10aS0P@Q0aBU0R4821BU0R481QBU0PaS0QBU12480PaS0P@Q0PaS5`@Q20000goo00<007oo
Ool01Woo0007Ool00`00Oomoo`026<H67>L26<H67>L26<H27>L76<H>7>L66<H47>LI6<H27>L26<H6
7>L46<H47>LU6<H2Ool00`00Oomoo`0;Ool01000OolDYABU12480S6<0QBU12480S6<0QBU0R481aBU
3R481PaS124821BU0PaS0QBU0PaS0aBU0PaS1QBU0R480QBU1R4811BU12480QBU0PaS3`@Q10002P@Q
10000goo00<007ooOol01Woo0007Ool00`00Oomoo`026<H67>L26<H67>L26<H27>L76<H>7>L66<H4
7>LI6<H27>L26<H67>L46<H47>LU6<H2Ool00`00Oomoo`0;Ool01000OolDYABU12480S6<0QBU1248
0S6<0QBU0R481aBU3R481PaS124821BU0PaS0QBU0PaS0aBU0PaS1QBU0R480QBU1R4811BU12480QBU
0PaS3`@Q10002P@Q10000goo00<007ooOol01Woo0007Ool00`00Oomoo`087>L26<H67>L96<H27>L2
6<H47>L26<H27>L>6<H27>L66<H27>LC6<H27>L66<H47>LW6<H2Ool00`00Oomoo`0;Ool00`00OolQ
20058@P2<H`25:D68@P95:D28@P25:D48@P25:D2<H`85:D236<25:D236<28@P65:D28@P25:D236<3
5:D236<45:D236<2124236<28@P65:D48@P45:D236<?1246000412480003Ool00`00Oomoo`06Ool0
00Moo`03001oogoo00PLi`8HaPHLi`THaP8Li`8HaP@Li`8HaP8Li`hHaP8Li`HHaP8Lia<HaP8Li`HH
aP@LibLHaP9oo`03001oogoo00]oo`03001oob4800DQ208aS08DY@HQ20TDY@8Q208DY@@Q208DY@8a
S0PDY@8<H`8DY@8<H`8Q20HDY@8Q208DY@8<H`<DY@8<H`@DY@8<H`848@8<H`8Q20HDY@@Q20@DY@8<
H`l48@H000@48@P000=oo`03001oogoo00Ioo`001goo00<007ooOol01QS60QcW0QS61QcW0QS60QcW
3aS60QcW2QS60QcW11S60QcW4aS60QcW31S621cW8aS60Woo00<007ooOol02goo00<007oo5:D01ABU
0R480QBU1R480QBU0R482ABU0PaS0QBU0PaS0R4811BU10aS0QBU0R4811BU0R481QBU0PaS0P@Q1@aS
11BU0R4821BU10aS22480QBU0PaS3`@Q3P000P@Q0goo00<007ooOol01Woo0007Ool00`00Oomoo`06
6<H27>L26<H67>L26<H27>L?6<H27>L:6<H27>L46<H27>LC6<H27>L<6<H87>LS6<H2Ool00`00Oomo
o`0;Ool00`00OolDY@055:D28@P25:D68@P25:D28@P95:D236<25:D236<28@P45:D436<25:D28@P4
5:D28@P65:D236<2124536<45:D28@P85:D436<88@P25:D236<?124>00021243Ool00`00Oomoo`06
Ool000Moo`03001oogoo08Eoo`03001oogoo00]oo`03001oogoo08Eoo`03001oogoo00Ioo`001goo
00<007ooOol0QGoo00<007ooOol02goo00<007ooOol0QGoo00<007ooOol01Woo0007Oon9000=Oon9
0008Ool00?moobmoo`00ogoo;goo003oOol_Ool00001\
\>"],
  ImageRangeCache->{{{0, 301}, {142.688, 0}} -> {-0.054762, -0.0238146, 
  0.00700839, 0.00700839}, {{7.8125, 143.688}, {139.25, 
  3.375}} -> {-5.17583, -3.02871, 0.490771, 0.490771}, {{157.25, 293.188}, {
  139.25, 3.375}} -> {-78.4799, -3.01258, 0.490545, 0.490545}}]
}, Open  ]],

Cell["\<\
The histogram of the equalized image is strikingly different. Particularly, \
note that the histogram is stretched, rather than equalized. The latter is \
not possible, in the strict sense, given the discrete density and \
distribution functions of digital images.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(ListPlot[Histogram[B\&^], PlotJoined \[Rule] True, 
      PlotRange \[Rule] All]; \)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0200747 0.00373483 0.0147151 0.00115187 [
[.20682 .00222 -6 -9 ]
[.20682 .00222 6 0 ]
[.39356 .00222 -9 -9 ]
[.39356 .00222 9 0 ]
[.5803 .00222 -9 -9 ]
[.5803 .00222 9 0 ]
[.76704 .00222 -9 -9 ]
[.76704 .00222 9 0 ]
[.95378 .00222 -9 -9 ]
[.95378 .00222 9 0 ]
[.00757 .1299 -18 -4.5 ]
[.00757 .1299 0 4.5 ]
[.00757 .24509 -18 -4.5 ]
[.00757 .24509 0 4.5 ]
[.00757 .36028 -18 -4.5 ]
[.00757 .36028 0 4.5 ]
[.00757 .47546 -18 -4.5 ]
[.00757 .47546 0 4.5 ]
[.00757 .59065 -18 -4.5 ]
[.00757 .59065 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.20682 .01472 m
.20682 .02097 L
s
[(50)] .20682 .00222 0 1 Mshowa
.39356 .01472 m
.39356 .02097 L
s
[(100)] .39356 .00222 0 1 Mshowa
.5803 .01472 m
.5803 .02097 L
s
[(150)] .5803 .00222 0 1 Mshowa
.76704 .01472 m
.76704 .02097 L
s
[(200)] .76704 .00222 0 1 Mshowa
.95378 .01472 m
.95378 .02097 L
s
[(250)] .95378 .00222 0 1 Mshowa
.125 Mabswid
.05742 .01472 m
.05742 .01847 L
s
.09477 .01472 m
.09477 .01847 L
s
.13212 .01472 m
.13212 .01847 L
s
.16947 .01472 m
.16947 .01847 L
s
.24416 .01472 m
.24416 .01847 L
s
.28151 .01472 m
.28151 .01847 L
s
.31886 .01472 m
.31886 .01847 L
s
.35621 .01472 m
.35621 .01847 L
s
.43091 .01472 m
.43091 .01847 L
s
.46825 .01472 m
.46825 .01847 L
s
.5056 .01472 m
.5056 .01847 L
s
.54295 .01472 m
.54295 .01847 L
s
.61765 .01472 m
.61765 .01847 L
s
.655 .01472 m
.655 .01847 L
s
.69234 .01472 m
.69234 .01847 L
s
.72969 .01472 m
.72969 .01847 L
s
.80439 .01472 m
.80439 .01847 L
s
.84174 .01472 m
.84174 .01847 L
s
.87908 .01472 m
.87908 .01847 L
s
.91643 .01472 m
.91643 .01847 L
s
.99113 .01472 m
.99113 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02007 .1299 m
.02632 .1299 L
s
[(100)] .00757 .1299 1 0 Mshowa
.02007 .24509 m
.02632 .24509 L
s
[(200)] .00757 .24509 1 0 Mshowa
.02007 .36028 m
.02632 .36028 L
s
[(300)] .00757 .36028 1 0 Mshowa
.02007 .47546 m
.02632 .47546 L
s
[(400)] .00757 .47546 1 0 Mshowa
.02007 .59065 m
.02632 .59065 L
s
[(500)] .00757 .59065 1 0 Mshowa
.125 Mabswid
.02007 .03775 m
.02382 .03775 L
s
.02007 .06079 m
.02382 .06079 L
s
.02007 .08383 m
.02382 .08383 L
s
.02007 .10686 m
.02382 .10686 L
s
.02007 .15294 m
.02382 .15294 L
s
.02007 .17598 m
.02382 .17598 L
s
.02007 .19901 m
.02382 .19901 L
s
.02007 .22205 m
.02382 .22205 L
s
.02007 .26813 m
.02382 .26813 L
s
.02007 .29116 m
.02382 .29116 L
s
.02007 .3142 m
.02382 .3142 L
s
.02007 .33724 m
.02382 .33724 L
s
.02007 .38331 m
.02382 .38331 L
s
.02007 .40635 m
.02382 .40635 L
s
.02007 .42939 m
.02382 .42939 L
s
.02007 .45242 m
.02382 .45242 L
s
.02007 .4985 m
.02382 .4985 L
s
.02007 .52154 m
.02382 .52154 L
s
.02007 .54457 m
.02382 .54457 L
s
.02007 .56761 m
.02382 .56761 L
s
.02007 .61369 m
.02382 .61369 L
s
.25 Mabswid
.02007 0 m
.02007 .61803 L
s
.5 Mabswid
.02381 .02047 m
.02754 .01472 L
.03128 .01472 L
.03501 .07346 L
.03875 .01472 L
.04248 .01472 L
.04622 .01472 L
.04995 .01472 L
.05369 .01472 L
.05742 .12299 L
.06116 .01472 L
.06489 .01472 L
.06863 .01472 L
.07236 .01472 L
.0761 .01472 L
.07983 .13221 L
.08357 .01472 L
.0873 .01472 L
.09104 .01472 L
.09477 .01472 L
.09851 .01472 L
.10224 .01472 L
.10598 .01472 L
.10971 .01472 L
.11345 .17598 L
.11718 .01472 L
.12092 .01472 L
.12465 .01472 L
.12838 .01472 L
.13212 .01472 L
.13585 .01472 L
.13959 .01472 L
.14332 .01472 L
.14706 .01472 L
.15079 .01472 L
.15453 .01472 L
.15826 .01472 L
.162 .01472 L
.16573 .01472 L
.16947 .01472 L
.1732 .01472 L
.17694 .01472 L
.18067 .34415 L
.18441 .01472 L
.18814 .01472 L
.19188 .01472 L
.19561 .01472 L
.19935 .01472 L
.20308 .01472 L
.20682 .01472 L
Mistroke
.21055 .01472 L
.21429 .01472 L
.21802 .01472 L
.22176 .01472 L
.22549 .01472 L
.22923 .01472 L
.23296 .01472 L
.23669 .01472 L
.24043 .01472 L
.24416 .01472 L
.2479 .01472 L
.25163 .01472 L
.25537 .01472 L
.2591 .01472 L
.26284 .01472 L
.26657 .44091 L
.27031 .01472 L
.27404 .01472 L
.27778 .01472 L
.28151 .01472 L
.28525 .01472 L
.28898 .01472 L
.29272 .01472 L
.29645 .01472 L
.30019 .01472 L
.30392 .01472 L
.30766 .01472 L
.31139 .01472 L
.31513 .01472 L
.31886 .01472 L
.3226 .01472 L
.32633 .01472 L
.33007 .01472 L
.3338 .01472 L
.33754 .01472 L
.34127 .01472 L
.345 .01472 L
.34874 .01472 L
.35247 .01472 L
.35621 .01472 L
.35994 .01472 L
.36368 .01472 L
.36741 .01472 L
.37115 .01472 L
.37488 .01472 L
.37862 .01472 L
.38235 .01472 L
.38609 .60332 L
.38982 .01472 L
.39356 .01472 L
Mistroke
.39729 .01472 L
.40103 .01472 L
.40476 .01472 L
.4085 .01472 L
.41223 .01472 L
.41597 .01472 L
.4197 .01472 L
.42344 .01472 L
.42717 .01472 L
.43091 .01472 L
.43464 .01472 L
.43838 .01472 L
.44211 .01472 L
.44585 .01472 L
.44958 .01472 L
.45331 .01472 L
.45705 .01472 L
.46078 .01472 L
.46452 .01472 L
.46825 .01472 L
.47199 .01472 L
.47572 .01472 L
.47946 .01472 L
.48319 .01472 L
.48693 .01472 L
.49066 .53421 L
.4944 .01472 L
.49813 .01472 L
.50187 .01472 L
.5056 .01472 L
.50934 .01472 L
.51307 .01472 L
.51681 .01472 L
.52054 .01472 L
.52428 .01472 L
.52801 .01472 L
.53175 .01472 L
.53548 .01472 L
.53922 .01472 L
.54295 .01472 L
.54669 .01472 L
.55042 .01472 L
.55415 .01472 L
.55789 .36028 L
.56162 .01472 L
.56536 .01472 L
.56909 .01472 L
.57283 .01472 L
.57656 .01472 L
.5803 .01472 L
Mistroke
.58403 .01472 L
.58777 .01472 L
.5915 .01472 L
.59524 .01472 L
.59897 .01472 L
.60271 .2232 L
.60644 .01472 L
.61018 .01472 L
.61391 .01472 L
.61765 .01472 L
.62138 .01472 L
.62512 .01472 L
.62885 .01472 L
.63259 .01472 L
.63632 .01472 L
.64006 .20592 L
.64379 .01472 L
.64753 .01472 L
.65126 .01472 L
.655 .01472 L
.65873 .01472 L
.66246 .01472 L
.6662 .13796 L
.66993 .01472 L
.67367 .01472 L
.6774 .01472 L
.68114 .10226 L
.68487 .01472 L
.68861 .01472 L
.69234 .01472 L
.69608 .01472 L
.69981 .09535 L
.70355 .01472 L
.70728 .05503 L
.71102 .01472 L
.71475 .01472 L
.71849 .07922 L
.72222 .01472 L
.72596 .04812 L
.72969 .01472 L
.73343 .04927 L
.73716 .01472 L
.7409 .04351 L
.74463 .03775 L
.74837 .03314 L
.7521 .04006 L
.75584 .01472 L
.75957 .04121 L
.76331 .0343 L
.76704 .03084 L
Mistroke
.77077 .03314 L
.77451 .0366 L
.77824 .0366 L
.78198 .0366 L
.78571 .03199 L
.78945 .02623 L
.79318 .03775 L
.79692 .03199 L
.80065 .03084 L
.80439 .0343 L
.80812 .04466 L
.81186 .03545 L
.81559 .01472 L
.81933 .04582 L
.82306 .03545 L
.8268 .0343 L
.83053 .02393 L
.83427 .03199 L
.838 .04121 L
.84174 .03314 L
.84547 .03084 L
.84921 .03545 L
.85294 .0343 L
.85668 .02393 L
.86041 .03545 L
.86415 .0366 L
.86788 .02854 L
.87162 .04466 L
.87535 .02393 L
.87908 .03545 L
.88282 .0343 L
.88655 .03545 L
.89029 .03775 L
.89402 .03084 L
.89776 .03314 L
.90149 .02508 L
.90523 .0389 L
.90896 .03545 L
.9127 .03314 L
.91643 .02739 L
.92017 .04236 L
.9239 .02969 L
.92764 .0366 L
.93137 .02969 L
.93511 .03545 L
.93884 .03199 L
.94258 .0343 L
.94631 .03199 L
.95005 .03545 L
.95378 .03314 L
Mistroke
.95752 .03314 L
.96125 .03314 L
.96499 .03314 L
.96872 .03199 L
.97246 .03314 L
.97619 .01702 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{216, 133.438},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003H0000QA000`40O003h00Of7oo003HOol003Io
o`03001oogoo009oo`03001oogoo01Uoo`D0009oo`03001oogoo009oo`03001oogoo01Ioo`D0009o
o`03001oogoo009oo`03001oogoo01Moo`<000=oo`03001oogoo009oo`03001oogoo01Moo`<000=o
o`03001oogoo009oo`03001oogoo00=oo`00=Goo00<007oo00000Woo00<007oo000077oo00L007oo
Oomoo`00Ool00002Ool00`00Ool0000IOol01`00Oomoogoo001oo`00009oo`03001oo`0001Qoo`03
001oogoo009oo`03001oo`00009oo`03001oo`0001Qoo`03001oogoo009oo`03001oo`00009oo`03
001oo`0000Aoo`00=goo00H007ooOol007oo000LOol01`00Oomoogoo001oo`00009oo`03001oo`00
01Uoo`03001oogoo00=oo`06001oogoo001oo`006Goo00L007ooOomoo`00Ool00002Ool00`00Ool0
000IOol00`00Oomoo`03Ool01P00Oomoo`00Ool000Aoo`00=Goo0P000goo00<007oo000077oo00L0
07ooOomoo`00Ool00002Ool00`00Ool0000IOol01000Oomoogoo0P000goo00<007oo00006Goo00L0
07ooOomoo`00Ool00002Ool00`00Ool0000IOol01000Oomoogoo0P000goo00<007oo000017oo000e
Ool00`00Oomoo`02Ool00`00Ool0000LOol01`00Oomoogoo001oo`00009oo`03001oo`0001Uoo`05
001oogooOol00004Ool00`00Ool0000HOol00`00Ool00002Ool00`00Ool00002Ool00`00Ool0000H
Ool00`00Ool00002Ool00`00Oomoo`02Ool00`00Ool00004Ool003Eoo`<000=oo`03001oogoo01Yo
o`8000Aoo`03001oogoo009oo`03001oogoo01Moo`8000=oo`<000=oo`03001oogoo01Qoo`03001o
ogoo009oo`03001oogoo009oo`03001oogoo01Qoo`04001oogooOol30003Ool00`00Oomoo`03Ool0
0=Qoo`0057oo00<007ooOol0`Goo000DOol00`00Oomoo`31Ool001Aoo`03001oogoo0<5oo`0047oo
b000000DOol3000017oo001oogoo0P000Woo00D007oo001oo`00009oo`80009oo`03001oogoo00Eo
o`800003Ool007oo009oo`03001oogoo00Aoo`09001oogooOol007oo001oo`0000Ioo`03001oogoo
00Eoo`03001oogoo009oo`<000Moo`03001oogoo00Aoo`04001oogooOol200000goo001oo`06Ool0
1000Ool000000goo00@007ooOomoo`80009oo`07001oogoo001oo`00Ool00P0000Aoo`00001oo`<0
0003Ool0000000800003Ool0000000=oo`03001oo`0000Moo`03001oo`0000Aoo`03001oogoo00Ao
o`03001oogoo00Eoo`03001oogoo00Aoo`03001oogoo009oo`04001oogoo0002Ool001Aoo`05001o
o`00Ool00002Ool20002Ool00`00Ool00004Ool2000;Ool00`00Ool0000>Ool00`00Ool0000EOol2
000COol2000;Ool20007Ool20005Ool00`00Ool00002Ool02@00Ool00000Ool007oo001oo`040000
0goo00000003Ool00`00Oomoo`04Ool01000Oomoogoo0P000Woo00<007ooOol00Woo00D007ooOomo
o`0000Aoo`03001oogoo00aoo`03001oogoo00=oo`0057oo00D007oo001oo`00009oo`80009oo`03
001oo`0000Aoo`8000]oo`03001oo`0000ioo`03001oo`0001Eoo`8001=oo`8000]oo`8000Moo`80
00Eoo`03001oo`00009oo`09001oo`00001oo`00Ool007oo00@00003Ool00000009oo`04001oo`00
0003Ool200000goo001oo`0200000goo00000002Ool3000017oo001oo`000Woo0`000Woo0P0000=o
o`00Ool01Woo00<007ooOol017oo000DOol01@00Ool007oo00000Woo0P000Woo00<007oo000017oo
0P002goo00<007oo00003Woo00<007oo00005Goo0P004goo0P002goo0P001goo0P001Goo00<007oo
00000Woo00/007oo000007oo001oo`00Ool007oo00<00006Ool00000Ool007oo200000Aoo`00001o
o`800006Ool00000Ool007oo200000=oo`0000000`0000=oo`0000001P001Woo000DOol3000017oo
001oogoo0P000Woo00<007oo000017oo0P002goo00<007oo00003Woo00<007oo00005Goo0P004goo
0P002goo0P001goo0P001Goo00<007oo00000Woo00/007oo000007oo001oo`00Ool007oo00<00003
Ool0000000800003Ool007oo00Aoo`04001oogoo0002Ool01000Oomoo`001Woo00D007ooOomoo`00
009oo`04001oogoo000@Ool001Aoo`04001oo`000003Ool20002Ool00`00Ool00004Ool2000;Ool0
0`00Ool0000>Ool00`00Ool0000EOol2000COol2000;Ool20007Ool20005Ool00`00Ool00002Ool0
2`00Ool00000Ool007oo001oo`00Ool00`0000=oo`00000037oo00@007ooOol000Uoo`03001oogoo
00Moo`03001oogoo00ioo`0057oo00@007ooOol000=oo`80009oo`03001oo`0000Aoo`8000]oo`03
001oo`0000ioo`03001oo`0001Eoo`8001=oo`8000]oo`8000Moo`8000Eoo`03001oo`00009oo`0:
001oo`00001oo`00Ool007oo0002Ool200000goo001oo`0dOol001Aoo`04001oogoo0003Ool20002
Ool00`00Ool00004Ool2000;Ool00`00Ool0000>Ool00`00Ool0000EOol2000COol2000;Ool20007
Ool20005Ool00`00Ool00002Ool01`00Ool00000Ool007oo00<0009oo`03001oogoo03Ioo`0057oo
0P0000=oo`00Ool00Woo0P000Woo00<007oo000017oo0P002goo00<007oo00003Woo00<007oo0000
5Goo0P004goo0P002goo0P001goo0P001Goo00<007oo00000Woo00<007oo00000P000goo00D007oo
Oomoo`0003Qoo`0057oo00@007ooOol000=oo`80009oo`03001oo`0000Aoo`8000]oo`03001oo`00
00ioo`03001oo`0001Eoo`8001=oo`8000]oo`8000Moo`8000Eoo`03001oo`00009oo`05001oo`00
Ool00003Ool01@00Oomoogoo0000>7oo000DOol01000Oomoo`000goo00L007ooOomoo`00Ool00004
Ool2000;Ool00`00Ool0000>Ool00`00Ool0000EOol2000COol2000;Ool20007Ool20005Ool00`00
Ool00002Ool01@00Ool007oo00000goo00D007ooOomoo`0003Qoo`0057oo00@007ooOol000=oo`03
001oogoo009oo`03001oogoo00=oo`8000]oo`03001oo`0000ioo`03001oo`0001Eoo`8001=oo`80
00]oo`8000Moo`8000Eoo`03001oo`00009oo`05001oo`00Ool00003Ool01@00Oomoogoo0000>7oo
000DOol00`00Oomoo`04Ool00`00Oomoo`02Ool00`00Oomoo`03Ool2000;Ool00`00Ool0000>Ool0
0`00Ool0000EOol2000COol2000;Ool20007Ool20005Ool00`00Ool00003Ool01000Oomoo`000goo
00D007ooOomoo`0003Qoo`0057oo0P001Goo00<007ooOol00Woo00<007ooOol00goo0P002goo00<0
07oo00003Woo00<007oo00005Goo0P004goo0P002goo0P001goo0P001Goo00<007oo00000goo00@0
07ooOol000=oo`03001oogoo03Yoo`0057oo00<007ooOol017oo00<007ooOol00Woo00<007ooOol0
0goo0P002goo00<007oo00003Woo00<007oo00005Goo0P004goo0P002goo0P001goo0P001Goo00<0
07oo00000goo00@007ooOol000=oo`03001oogoo03Yoo`0057oo00<007ooOol017oo00<007ooOol0
0Woo00<007ooOol00goo0P002goo00<007oo00003Woo00<007oo00005Goo0P004goo0P002goo0P00
1goo0P001Goo00<007oo00000goo00@007ooOol000=oo`03001oogoo03Yoo`0057oo00<007ooOol0
17oo00<007ooOol00Woo00<007ooOol017oo00<007ooOol02Goo00<007oo00003Woo00<007oo0000
5Goo0P004goo0P002goo0P001goo0P001Goo00<007oo00000goo00@007ooOol0041oo`0057oo0P00
1Goo00<007ooOol00Woo00<007ooOol017oo00<007ooOol02Goo00<007oo00003Woo00<007oo0000
5Goo0P004goo0P002goo0P001goo0P001Goo00<007oo00000goo00@007ooOol0041oo`0057oo00<0
07ooOol017oo00<007ooOol00Woo00<007ooOol017oo00<007ooOol02Goo00<007oo00003Woo00<0
07oo00005Goo0P004goo0P002goo0P001goo0P001Goo0P0017oo00<007ooOol0@Goo000DOol00`00
Oomoo`04Ool00`00Oomoo`02Ool00`00Oomoo`04Ool00`00Oomoo`09Ool00`00Ool0000>Ool00`00
Ool0000EOol2000COol2000;Ool20007Ool20006Ool00`00Oomoo`02Ool00`00Oomoo`11Ool000=o
o`D0009oo`03001oogoo009oo`03001oogoo009oo`03001oogoo00Aoo`03001oogoo009oo`03001o
ogoo00Aoo`03001oogoo00Uoo`03001oo`0000ioo`03001oo`0001Eoo`8001=oo`8000]oo`8000Mo
o`8000Ioo`03001oogoo009oo`03001oogoo045oo`001Goo00L007ooOomoo`00Ool00002Ool00`00
Ool00003Ool00`00Oomoo`04Ool00`00Oomoo`02Ool00`00Oomoo`04Ool00`00Oomoo`09Ool00`00
Ool0000>Ool00`00Ool0000EOol2000COol2000;Ool20008Ool00`00Oomoo`04Ool00`00Oomoo`02
Ool00`00Oomoo`11Ool000Eoo`07001oogooOol007oo00000Woo00<007oo00000goo0P002Woo00<0
07ooOol017oo00<007ooOol02Goo00<007oo00003Woo00<007oo00005Goo0P004goo0P002goo0P00
27oo00<007ooOol017oo00<007ooOol00Woo00<007ooOol0@Goo0005Ool01`00Oomoogoo001oo`00
009oo`03001oo`0000=oo`03001oogoo011oo`03001oogoo00Uoo`03001oo`0000ioo`03001oo`00
01Eoo`8001=oo`8000]oo`8000Qoo`03001oogoo00Aoo`03001oogoo009oo`03001oogoo045oo`00
1Goo00L007ooOomoo`00Ool00002Ool00`00Ool00003Ool00`00Oomoo`0@Ool00`00Oomoo`09Ool0
0`00Ool0000>Ool00`00Ool0000EOol2000COol2000;Ool20008Ool00`00Oomoo`04Ool00`00Oomo
o`02Ool00`00Oomoo`11Ool000Aoo`8000Aoo`03001oogoo009oo`03001oogoo009oo`03001oogoo
011oo`03001oogoo00Uoo`03001oo`0000ioo`03001oo`0001Eoo`8001=oo`8000]oo`8000Qoo`03
001oogoo00Aoo`03001oogoo04Ioo`0057oo00<007ooOol047oo00<007ooOol02Goo00<007oo0000
3Woo00<007oo00005Goo0P004goo0P002goo0P0027oo00<007ooOol017oo00<007ooOol0AWoo000D
Ool2000AOol00`00Oomoo`09Ool00`00Ool0000>Ool00`00Ool0000EOol2000COol2000;Ool20008
Ool00`00Oomoo`04Ool00`00Oomoo`16Ool001Aoo`03001oogoo011oo`03001oogoo00Uoo`03001o
o`0000ioo`03001oo`0001Eoo`8001=oo`8000]oo`8000Qoo`03001oogoo00Aoo`03001oogoo04Io
o`0057oo00<007ooOol047oo00<007ooOol02Goo00<007oo00003Woo00<007oo00005Goo0P004goo
0P002goo0P0027oo00<007ooOol017oo00<007ooOol0AWoo000DOol00`00Oomoo`0@Ool00`00Oomo
o`09Ool00`00Ool0000>Ool00`00Ool0000EOol2000COol2000;Ool20008Ool00`00Oomoo`04Ool0
0`00Oomoo`16Ool001Aoo`80015oo`03001oogoo00Uoo`03001oo`0000ioo`03001oo`0001Eoo`80
01=oo`8000]oo`8000Qoo`03001oogoo00Aoo`03001oogoo04Ioo`0057oo00<007ooOol077oo0P00
3goo00<007oo00005Goo0P004goo0P002goo0P0027oo00<007ooOol017oo00<007ooOol0AWoo000D
Ool00`00Oomoo`0MOol00`00Oomoo`0=Ool00`00Ool0000EOol2000COol2000;Ool20008Ool00`00
Oomoo`04Ool00`00Oomoo`16Ool001Aoo`03001oogoo01eoo`03001oogoo00eoo`03001oo`0001Eo
o`8001=oo`8000aoo`03001oogoo00Ioo`03001oogoo00Aoo`03001oogoo04Ioo`0057oo00<007oo
Ool07Goo00<007ooOol03Goo00<007oo00005Goo0P004goo0P0037oo00<007ooOol01Woo00<007oo
Ool017oo00<007ooOol0AWoo000DOol2000NOol00`00Oomoo`0=Ool00`00Ool0000EOol2000COol2
000<Ool00`00Oomoo`06Ool00`00Oomoo`04Ool00`00Oomoo`16Ool001Aoo`03001oogoo01eoo`03
001oogoo00eoo`03001oo`0001Eoo`8001=oo`8000aoo`03001oogoo00Ioo`03001oogoo00Aoo`03
001oogoo04Ioo`0057oo00<007ooOol07Goo00<007ooOol03Goo00<007oo00005Goo0P004goo0P00
37oo00<007ooOol01Woo00<007ooOol0CGoo000DOol00`00Oomoo`0MOol00`00Oomoo`0=Ool00`00
Ool0000EOol2000COol2000<Ool00`00Oomoo`06Ool00`00Oomoo`1=Ool001Aoo`8001ioo`03001o
ogoo00eoo`03001oo`0001Eoo`8001=oo`8000aoo`03001oogoo00Ioo`03001oogoo04eoo`0057oo
00<007ooOol07Goo00<007ooOol03Goo00<007oo00005Goo0P004goo0P0037oo00<007ooOol01Woo
00<007ooOol0CGoo000DOol00`00Oomoo`0MOol00`00Oomoo`0>Ool00`00Oomoo`0DOol2000COol2
000<Ool00`00Oomoo`1FOol000Aoo`<000=oo`03001oogoo009oo`03001oogoo009oo`03001oogoo
01eoo`03001oogoo00ioo`03001oogoo01Aoo`8001=oo`8000aoo`03001oogoo05Ioo`0017oo00<0
07ooOol00Woo00<007oo00000Woo00<007oo00000goo00<007ooOol07Goo00<007ooOol03Woo00<0
07ooOol057oo0P004goo0P0037oo00<007ooOol0EWoo0005Ool01`00Oomoogoo001oo`00009oo`03
001oo`0000=oo`8001ioo`03001oogoo00ioo`03001oogoo01Aoo`8001=oo`8000aoo`03001oogoo
05Ioo`001Goo00L007ooOomoo`00Ool00002Ool00`00Ool00003Ool00`00Oomoo`0MOol00`00Oomo
o`0>Ool00`00Oomoo`0DOol2000COol2000<Ool00`00Oomoo`1FOol000Aoo`03001oo`00009oo`03
001oo`00009oo`03001oo`0000=oo`03001oogoo01eoo`03001oogoo00ioo`03001oogoo01Aoo`80
01=oo`8000aoo`03001oogoo05Ioo`001Goo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol0
0Woo00<007ooOol07Goo00<007ooOol03Woo00<007ooOol057oo0P004goo0P0037oo00<007ooOol0
EWoo000DOol2000NOol00`00Oomoo`0>Ool00`00Oomoo`0DOol2000COol2000<Ool00`00Oomoo`1F
Ool001Aoo`03001oogoo01eoo`03001oogoo00ioo`03001oogoo01Aoo`8001=oo`8000aoo`03001o
ogoo05Ioo`0057oo00<007ooOol07Goo00<007ooOol03Woo00<007ooOol057oo0P004goo00<007oo
Ool02goo00<007ooOol0EWoo000DOol00`00Oomoo`0MOol00`00Oomoo`0>Ool00`00Oomoo`0DOol2
000COol00`00Oomoo`0;Ool00`00Oomoo`1FOol001Aoo`03001oogoo01eoo`03001oogoo00ioo`03
001oogoo01Aoo`8001=oo`03001oogoo00]oo`03001oogoo05Ioo`0057oo0P007Woo00<007ooOol0
3Woo00<007ooOol057oo0P004goo00<007ooOol02goo00<007ooOol0EWoo000DOol00`00Oomoo`0M
Ool00`00Oomoo`0>Ool00`00Oomoo`0DOol2000COol00`00Oomoo`0;Ool00`00Oomoo`1FOol001Ao
o`03001oogoo01eoo`03001oogoo00ioo`03001oogoo01Aoo`8001=oo`03001oogoo00]oo`03001o
ogoo05Ioo`0057oo00<007ooOol07Goo00<007ooOol03Woo00<007ooOol057oo0P004goo00<007oo
Ool02goo00<007ooOol0EWoo000DOol00`00Oomoo`0MOol00`00Oomoo`0>Ool00`00Oomoo`0EOol0
0`00Oomoo`0AOol00`00Oomoo`0;Ool00`00Oomoo`1FOol001Aoo`8001ioo`03001oogoo00ioo`03
001oogoo01Eoo`03001oogoo015oo`03001oogoo00]oo`03001oogoo05Ioo`0057oo00<007ooOol0
7Goo00<007ooOol03Woo00<007ooOol05Goo00<007ooOol04Goo00<007ooOol02goo00<007ooOol0
EWoo000DOol00`00Oomoo`0MOol00`00Oomoo`0>Ool00`00Oomoo`0EOol00`00Oomoo`0AOol00`00
Oomoo`0;Ool00`00Oomoo`1FOol001Aoo`03001oogoo01eoo`03001oogoo00ioo`03001oogoo01Eo
o`03001oogoo015oo`03001oogoo00]oo`03001oogoo05Ioo`0057oo0P007Woo00<007ooOol03Woo
00<007ooOol05Goo00<007ooOol04Goo00<007ooOol02goo00<007ooOol0EWoo000DOol00`00Oomo
o`0MOol00`00Oomoo`0>Ool00`00Oomoo`0EOol00`00Oomoo`0AOol00`00Oomoo`0;Ool00`00Oomo
o`1FOol001Aoo`03001oogoo01eoo`03001oogoo00ioo`03001oogoo01Eoo`03001oogoo015oo`03
001oogoo00]oo`03001oogoo05Ioo`0017oo0P0017oo00<007ooOol00Woo00<007ooOol00Woo00<0
07ooOol0;Woo00<007ooOol05Goo00<007ooOol04Goo00<007ooOol02goo00<007ooOol0EWoo0006
Ool01P00Oomoo`00Ool0009oo`03001oo`0000=oo`03001oogoo02ioo`03001oogoo01Eoo`03001o
ogoo015oo`03001oogoo00]oo`03001oogoo05Ioo`001Goo00L007ooOomoo`00Ool00002Ool00`00
Ool00003Ool2000_Ool00`00Oomoo`0EOol00`00Oomoo`0AOol00`00Oomoo`0;Ool00`00Oomoo`1F
Ool000Ioo`06001oogoo001oo`000Woo00<007oo00000goo00<007ooOol0;Woo00<007ooOol05Goo
00<007ooOol04Goo00<007ooOol0I7oo0004Ool00`00Ool00002Ool00`00Ool00002Ool00`00Ool0
0003Ool00`00Oomoo`0^Ool00`00Oomoo`0EOol00`00Oomoo`0AOol00`00Oomoo`1TOol000Eoo`03
001oogoo009oo`03001oogoo009oo`03001oogoo009oo`03001oogoo02ioo`03001oogoo01Eoo`03
001oogoo015oo`03001oogoo06Aoo`0057oo0P00;goo00<007ooOol05Goo00<007ooOol04Goo00<0
07ooOol0I7oo000DOol00`00Oomoo`0^Ool00`00Oomoo`0EOol00`00Oomoo`0AOol00`00Oomoo`1T
Ool001Aoo`03001oogoo02ioo`03001oogoo01Eoo`03001oogoo015oo`03001oogoo06Aoo`0057oo
00<007ooOol0;Woo00<007ooOol05Goo00<007ooOol04Goo00<007ooOol0I7oo000DOol00`00Oomo
o`0^Ool00`00Oomoo`0EOol00`00Oomoo`0AOol00`00Oomoo`1TOol001Aoo`8002moo`03001oogoo
01Eoo`03001oogoo015oo`03001oogoo06Aoo`0057oo00<007ooOol0;Woo00<007ooOol05Goo00<0
07ooOol04Goo00<007ooOol0I7oo000DOol00`00Oomoo`0^Ool00`00Oomoo`0EOol00`00Oomoo`0A
Ool00`00Oomoo`1TOol001Aoo`03001oogoo02ioo`03001oogoo01Eoo`03001oogoo015oo`03001o
ogoo06Aoo`0057oo0P00;goo00<007ooOol05Goo00<007ooOol04Goo00<007ooOol0I7oo000DOol0
0`00Oomoo`0^Ool00`00Oomoo`0EOol00`00Oomoo`0AOol00`00Oomoo`1TOol001Aoo`03001oogoo
02ioo`03001oogoo01Eoo`03001oogoo015oo`03001oogoo06Aoo`0057oo00<007ooOol0;Woo00<0
07ooOol05Goo00<007ooOol04Goo00<007ooOol0I7oo000DOol00`00Oomoo`16Ool00`00Oomoo`0A
Ool00`00Oomoo`1TOol001Aoo`8004Moo`03001oogoo015oo`03001oogoo06Aoo`0057oo00<007oo
Ool0AWoo00<007ooOol04Goo00<007ooOol0I7oo000DOol00`00Oomoo`16Ool00`00Oomoo`0AOol0
0`00Oomoo`1TOol000Eoo`<0009oo`03001oogoo009oo`03001oogoo009oo`03001oogoo04Ioo`03
001oogoo015oo`03001oogoo06Aoo`001Woo00H007ooOol007oo0002Ool00`00Ool00003Ool00`00
Oomoo`16Ool00`00Oomoo`0AOol00`00Oomoo`1TOol000Aoo`@00004Ool007oo0002Ool00`00Ool0
0003Ool20017Ool00`00Oomoo`0AOol00`00Oomoo`1TOol000Aoo`03001oo`00009oo`03001oo`00
009oo`03001oo`0000=oo`03001oogoo04Ioo`03001oogoo015oo`03001oogoo06Aoo`001Goo0P00
0Woo00<007oo00000Woo00<007oo00000goo00<007ooOol0AWoo00<007ooOol04Goo00<007ooOol0
I7oo0006Ool01@00Oomoogoo000017oo00<007ooOol00Woo00<007ooOol0AWoo00<007ooOol04Goo
00<007ooOol0I7oo000DOol20017Ool00`00Oomoo`0AOol00`00Oomoo`1TOol001Aoo`03001oogoo
04Ioo`03001oogoo015oo`03001oogoo06Aoo`0057oo00<007ooOol0AWoo00<007ooOol04Goo00<0
07ooOol0I7oo000DOol00`00Oomoo`16Ool00`00Oomoo`0AOol00`00Oomoo`1TOol001Aoo`03001o
ogoo04Ioo`03001oogoo015oo`03001oogoo06Aoo`0057oo0P00Agoo00<007ooOol04Goo00<007oo
Ool0I7oo000DOol00`00Oomoo`16Ool00`00Oomoo`0AOol00`00Oomoo`1TOol001Aoo`03001oogoo
04Ioo`03001oogoo015oo`03001oogoo06Aoo`0057oo00<007ooOol0AWoo00<007ooOol0N7oo000D
Ool20017Ool00`00Oomoo`1hOol001Aoo`03001oogoo04Ioo`03001oogoo07Qoo`0057oo00<007oo
Ool0AWoo00<007ooOol0N7oo000DOol00`00Oomoo`16Ool00`00Oomoo`1hOol001Aoo`03001oogoo
04Ioo`03001oogoo07Qoo`0057oo0P00Agoo00<007ooOol0N7oo000DOol00`00Oomoo`16Ool00`00
Oomoo`1hOol000Eoo`03001oogoo009oo`03001oogoo009oo`03001oogoo009oo`03001oogoo04Io
o`03001oogoo07Qoo`0017oo00<007oo00000Woo00<007oo00000Woo00<007oo00000goo00<007oo
Ool0AWoo00<007ooOol0N7oo0006Ool01P00Oomoo`00Ool0009oo`03001oo`0000=oo`8004Moo`03
001oogoo07Qoo`0017oo0P000goo00<007oo00000Woo00<007oo00000goo00<007ooOol0AWoo00<0
07ooOol0N7oo0004Ool00`00Oomoo`02Ool00`00Ool00002Ool00`00Ool00003Ool00`00Oomoo`16
Ool00`00Oomoo`1hOol000Aoo`<000=oo`03001oogoo009oo`03001oogoo009oo`03001oogoo04Io
o`03001oogoo07Qoo`0057oo00<007ooOol0`Goo000DOol20032Ool001Aoo`03001oogoo0<5oo`00
\
\>"],
  ImageRangeCache->{{{0, 215}, {132.438, 0}} -> {-27.629, -52.8312, 1.34886, 
  4.37355}}]
}, Open  ]],

Cell["IMAGE SHARPENING", "Section"],

Cell[TextData[{
  "Human perception is very sensitive to edges in a picture. It has also been \
observed that pictures with accentuated edges are typically perceived as \
subjectively \"better\" looking. A number of schemes are available to ",
  StyleBox["sharpen",
    FontSlant->"Italic"],
  " an image. One method, borrowed directly from photographic printing \
practice is called ",
  StyleBox["unsharp masking.",
    FontSlant->"Italic"],
  " The enhanced image is obtained from a difference of the original and its \
scaled, lowpass copy. A second heuristic method used to sharpen edges is \
called statistical differencing, where an image pixel value is scaled by the \
local standard deviation. A generalization of this method is the so-called \
Wallis operator. "
}], "Text"],

Cell["\<\
R.H. Wallis, \"An approach for the space variant restoration and enhancement \
of images,\" Proc. Symposium on Current Mathematical Problems in Image \
Science, Monterey, CA, Nov. 1976\
\>", "Text"],

Cell["NOISE SMOOTHING", "Section"]
},
FrontEndVersion->"Microsoft Windows 3.0",
ScreenRectangle->{{0, 1280}, {0, 968}},
WindowToolbars->"EditBar",
CellGrouping->Manual,
WindowSize->{635, 590},
WindowMargins->{{88, Automatic}, {Automatic, 55}},
PrintingCopies->1,
PrintingPageRange->{Automatic, Automatic},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, -1}},
ShowCellLabel->True,
ShowCellTags->False,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False},
StyleDefinitions -> "ArticleClassic.nb"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1709, 49, 34, 0, 72, "Title"],
Cell[1746, 51, 143, 5, 72, "Address"],
Cell[1892, 58, 71, 0, 24, "Caption"],
Cell[1966, 60, 52, 1, 31, "Input"],
Cell[2021, 63, 118, 2, 31, "Input"],

Cell[CellGroupData[{
Cell[2164, 69, 31, 0, 56, "Section"],
Cell[2198, 71, 1060, 15, 163, "Text"],

Cell[CellGroupData[{
Cell[3283, 90, 32, 0, 43, "Subsection"],
Cell[3318, 92, 161, 3, 44, "Text"],
Cell[3482, 97, 174, 3, 51, "Input"],
Cell[3659, 102, 89, 2, 27, "Text"],

Cell[CellGroupData[{
Cell[3773, 108, 191, 5, 71, "Input"],
Cell[3967, 115, 80302, 1564, 162, 44009, 1112, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[84330, 1686, 40, 0, 56, "Section"],
Cell[84373, 1688, 436, 7, 78, "Text"],

Cell[CellGroupData[{
Cell[84834, 1699, 37, 0, 43, "Subsection"],
Cell[84874, 1701, 150, 3, 44, "Text"],

Cell[CellGroupData[{
Cell[85049, 1708, 44, 0, 25, "Example"],
Cell[85096, 1710, 740, 23, 78, "Text"],

Cell[CellGroupData[{
Cell[85861, 1737, 83, 1, 31, "Input"],
Cell[85947, 1740, 413, 10, 105, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[86397, 1755, 98, 2, 31, "Input"],
Cell[86498, 1759, 449, 10, 105, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[87008, 1776, 63, 0, 43, "Subsection"],
Cell[87074, 1778, 583, 11, 95, "Text"],
Cell[87660, 1791, 56, 1, 31, "Input"],

Cell[CellGroupData[{
Cell[87741, 1796, 341, 6, 128, "Input"],
Cell[88085, 1804, 28064, 1180, 186, 15562, 1021, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[116198, 2990, 70, 0, 43, "Subsection"],
Cell[116271, 2992, 234, 4, 44, "Text"],

Cell[CellGroupData[{
Cell[116530, 3000, 89, 1, 31, "Input"],
Cell[116622, 3003, 13060, 577, 142, 7424, 503, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],
Cell[129697, 3583, 189, 5, 44, "Text"],

Cell[CellGroupData[{
Cell[129911, 3592, 110, 2, 51, "Input"],
Cell[130024, 3596, 61, 1, 30, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[130122, 3602, 271, 6, 71, "Input"],
Cell[130396, 3610, 46397, 880, 111, 18848, 536, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[176842, 4496, 50, 0, 43, "Subsection"],
Cell[176895, 4498, 331, 6, 61, "Text"],

Cell[CellGroupData[{
Cell[177251, 4508, 150, 3, 51, "Input"],
Cell[177404, 4513, 14757, 593, 142, 7378, 497, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],
Cell[192176, 5109, 278, 6, 44, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[192491, 5120, 40, 0, 43, "Subsection"],
Cell[192534, 5122, 397, 8, 61, "Text"],

Cell[CellGroupData[{
Cell[192956, 5134, 202, 5, 51, "Input"],
Cell[193161, 5141, 16306, 612, 142, 7380, 497, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[209516, 5759, 29, 0, 43, "Subsection"],
Cell[209548, 5761, 116, 3, 27, "Text"],

Cell[CellGroupData[{
Cell[209689, 5768, 582, 12, 171, "Input"],
Cell[210274, 5782, 83136, 1610, 224, 37076, 1036, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[293471, 7399, 41, 0, 56, "Section"],
Cell[293515, 7401, 875, 18, 112, "Text"],
Cell[294393, 7421, 76, 0, 24, "Caption"],

Cell[CellGroupData[{
Cell[294494, 7425, 120, 2, 31, "Input"],
Cell[294617, 7429, 15998, 608, 142, 7389, 497, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],
Cell[310642, 8041, 586, 9, 95, "Text"],
Cell[311231, 8052, 91, 2, 24, "Caption"],

Cell[CellGroupData[{
Cell[311347, 8058, 99, 2, 31, "Input"],
Cell[311449, 8062, 14097, 569, 142, 7179, 479, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],
Cell[325561, 8634, 54, 0, 24, "Caption"],
Cell[325618, 8636, 77, 1, 31, "Input"],

Cell[CellGroupData[{
Cell[325720, 8641, 205, 5, 73, "Input"],
Cell[325928, 8648, 57947, 1023, 153, 18848, 536, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],
Cell[383890, 9674, 288, 5, 44, "Text"],

Cell[CellGroupData[{
Cell[384203, 9683, 119, 2, 32, "Input"],
Cell[384325, 9687, 22606, 690, 142, 7383, 497, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],
Cell[406946, 10380, 35, 0, 56, "Section"],
Cell[406984, 10382, 784, 15, 112, "Text"],
Cell[407771, 10399, 208, 4, 44, "Text"],
Cell[407982, 10405, 34, 0, 56, "Section"]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

