(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    270284,       7265]*)
(*NotebookOutlinePosition[    271418,       7302]*)
(*  CellTagsIndexPosition[    271374,       7298]*)
(*WindowFrame->Normal*)



Notebook[{
Cell["GRADIENT EDGE OPERATORS", "Title"],

Cell["Mariusz Jankowski", "Author"],

Cell["\<\
Department of Electrical Engineering
University of Southern Maine
mjkcc@usm.maine.edu\
\>", "Address"],

Cell[BoxData[
    \(<< ImageProcessing`\)], "Input"],

Cell[BoxData[
    \(<< LinearAlgebra`MatrixManipulation`\)], "Input"],

Cell[CellGroupData[{

Cell["INTRODUCTION", "Section"],

Cell["\<\
Edge detection is a problem of fundamental importance in image analysis. In \
typical images, edges characterize object boundaries (under what \
circumstances would this not be true?) and are therefore useful for \
segmentation, registration, and identification of objects in a scene. In this \
document the construction, characteristics and performance of a number of \
well-known edge gradient edge operators will be discussed: Roberts, Prewitt, \
Sobel or Frei-Chen.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["GRADIENT EDGE DETECTORS", "Section"],

Cell["\<\
For a continuous image f(x,y), its first derivative assumes a local maximum \
in the direction of the edge. Therefore, one edge detection technique is to \
measure the gradient of f with respect to the two orthogonal directions x and \
y.\
\>", "Text"],

Cell[CellGroupData[{

Cell["A Simple Edge Model", "Subsection"],

Cell["\<\
We begin by modeling a circularly symmetric bright block on a dark background \
with the following function f(x,y).\
\>", "Text"],

Cell[BoxData[
    \(\(f = \((Tanh[3 - x] + Tanh[3 + x])\)\ \((Tanh[3 - y] + Tanh[3 + y])\); 
    \)\)], "Input"],

Cell["The gradient is defined by the following well known formula:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[Del]f = 
      \@\(\((\[PartialD]\_x f)\)\^2 + \((\[PartialD]\_y f)\)\^2\)\)], "Input"],

Cell[BoxData[
    \(\[Sqrt]\((
        \((\(-Sech[3 - y]\^2\) + Sech[3 + y]\^2)\)\^2\ 
            \((Tanh[3 - x] + Tanh[3 + x])\)\^2 + 
          \((\(-Sech[3 - x]\^2\) + Sech[3 + x]\^2)\)\^2\ 
            \((Tanh[3 - y] + Tanh[3 + y])\)\^2)\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[
      GraphicsArray[
        \(DensityPlot[#1, {x, \(-6\), 6}, {y, \(-6\), 6}, Mesh \[Rule] False, 
              DisplayFunction \[Rule] Identity]\ &\)\ /@\ {f, \[Del]f}]]; 
    \)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .47619 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0113379 0.47619 [
[ 0 0 0 0 ]
[ 1 .47619 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .47619 L
0 .47619 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0113379 0.477324 0.464853 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0801282 0.5 0.0801282 [
[.01923 -0.0125 -6 -9 ]
[.01923 -0.0125 6 0 ]
[.17949 -0.0125 -6 -9 ]
[.17949 -0.0125 6 0 ]
[.33974 -0.0125 -6 -9 ]
[.33974 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.66026 -0.0125 -3 -9 ]
[.66026 -0.0125 3 0 ]
[.82051 -0.0125 -3 -9 ]
[.82051 -0.0125 3 0 ]
[.98077 -0.0125 -3 -9 ]
[.98077 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01923 -12 -4.5 ]
[-0.0125 .01923 0 4.5 ]
[-0.0125 .17949 -12 -4.5 ]
[-0.0125 .17949 0 4.5 ]
[-0.0125 .33974 -12 -4.5 ]
[-0.0125 .33974 0 4.5 ]
[-0.0125 .5 -6 -4.5 ]
[-0.0125 .5 0 4.5 ]
[-0.0125 .66026 -6 -4.5 ]
[-0.0125 .66026 0 4.5 ]
[-0.0125 .82051 -6 -4.5 ]
[-0.0125 .82051 0 4.5 ]
[-0.0125 .98077 -6 -4.5 ]
[-0.0125 .98077 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.01923 0 m
.01923 .00625 L
s
[(-6)] .01923 -0.0125 0 1 Mshowa
.17949 0 m
.17949 .00625 L
s
[(-4)] .17949 -0.0125 0 1 Mshowa
.33974 0 m
.33974 .00625 L
s
[(-2)] .33974 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.66026 0 m
.66026 .00625 L
s
[(2)] .66026 -0.0125 0 1 Mshowa
.82051 0 m
.82051 .00625 L
s
[(4)] .82051 -0.0125 0 1 Mshowa
.98077 0 m
.98077 .00625 L
s
[(6)] .98077 -0.0125 0 1 Mshowa
.125 Mabswid
.05929 0 m
.05929 .00375 L
s
.09936 0 m
.09936 .00375 L
s
.13942 0 m
.13942 .00375 L
s
.21955 0 m
.21955 .00375 L
s
.25962 0 m
.25962 .00375 L
s
.29968 0 m
.29968 .00375 L
s
.37981 0 m
.37981 .00375 L
s
.41987 0 m
.41987 .00375 L
s
.45994 0 m
.45994 .00375 L
s
.54006 0 m
.54006 .00375 L
s
.58013 0 m
.58013 .00375 L
s
.62019 0 m
.62019 .00375 L
s
.70032 0 m
.70032 .00375 L
s
.74038 0 m
.74038 .00375 L
s
.78045 0 m
.78045 .00375 L
s
.86058 0 m
.86058 .00375 L
s
.90064 0 m
.90064 .00375 L
s
.94071 0 m
.94071 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01923 m
.00625 .01923 L
s
[(-6)] -0.0125 .01923 1 0 Mshowa
0 .17949 m
.00625 .17949 L
s
[(-4)] -0.0125 .17949 1 0 Mshowa
0 .33974 m
.00625 .33974 L
s
[(-2)] -0.0125 .33974 1 0 Mshowa
0 .5 m
.00625 .5 L
s
[(0)] -0.0125 .5 1 0 Mshowa
0 .66026 m
.00625 .66026 L
s
[(2)] -0.0125 .66026 1 0 Mshowa
0 .82051 m
.00625 .82051 L
s
[(4)] -0.0125 .82051 1 0 Mshowa
0 .98077 m
.00625 .98077 L
s
[(6)] -0.0125 .98077 1 0 Mshowa
.125 Mabswid
0 .05929 m
.00375 .05929 L
s
0 .09936 m
.00375 .09936 L
s
0 .13942 m
.00375 .13942 L
s
0 .21955 m
.00375 .21955 L
s
0 .25962 m
.00375 .25962 L
s
0 .29968 m
.00375 .29968 L
s
0 .37981 m
.00375 .37981 L
s
0 .41987 m
.00375 .41987 L
s
0 .45994 m
.00375 .45994 L
s
0 .54006 m
.00375 .54006 L
s
0 .58013 m
.00375 .58013 L
s
0 .62019 m
.00375 .62019 L
s
0 .70032 m
.00375 .70032 L
s
0 .74038 m
.00375 .74038 L
s
0 .78045 m
.00375 .78045 L
s
0 .86058 m
.00375 .86058 L
s
0 .90064 m
.00375 .90064 L
s
0 .94071 m
.00375 .94071 L
s
.25 Mabswid
0 0 m
0 1 L
s
.01923 .99375 m
.01923 1 L
s
.17949 .99375 m
.17949 1 L
s
.33974 .99375 m
.33974 1 L
s
.5 .99375 m
.5 1 L
s
.66026 .99375 m
.66026 1 L
s
.82051 .99375 m
.82051 1 L
s
.98077 .99375 m
.98077 1 L
s
.125 Mabswid
.05929 .99625 m
.05929 1 L
s
.09936 .99625 m
.09936 1 L
s
.13942 .99625 m
.13942 1 L
s
.21955 .99625 m
.21955 1 L
s
.25962 .99625 m
.25962 1 L
s
.29968 .99625 m
.29968 1 L
s
.37981 .99625 m
.37981 1 L
s
.41987 .99625 m
.41987 1 L
s
.45994 .99625 m
.45994 1 L
s
.54006 .99625 m
.54006 1 L
s
.58013 .99625 m
.58013 1 L
s
.62019 .99625 m
.62019 1 L
s
.70032 .99625 m
.70032 1 L
s
.74038 .99625 m
.74038 1 L
s
.78045 .99625 m
.78045 1 L
s
.86058 .99625 m
.86058 1 L
s
.90064 .99625 m
.90064 1 L
s
.94071 .99625 m
.94071 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .01923 m
1 .01923 L
s
.99375 .17949 m
1 .17949 L
s
.99375 .33974 m
1 .33974 L
s
.99375 .5 m
1 .5 L
s
.99375 .66026 m
1 .66026 L
s
.99375 .82051 m
1 .82051 L
s
.99375 .98077 m
1 .98077 L
s
.125 Mabswid
.99625 .05929 m
1 .05929 L
s
.99625 .09936 m
1 .09936 L
s
.99625 .13942 m
1 .13942 L
s
.99625 .21955 m
1 .21955 L
s
.99625 .25962 m
1 .25962 L
s
.99625 .29968 m
1 .29968 L
s
.99625 .37981 m
1 .37981 L
s
.99625 .41987 m
1 .41987 L
s
.99625 .45994 m
1 .45994 L
s
.99625 .54006 m
1 .54006 L
s
.99625 .58013 m
1 .58013 L
s
.99625 .62019 m
1 .62019 L
s
.99625 .70032 m
1 .70032 L
s
.99625 .74038 m
1 .74038 L
s
.99625 .78045 m
1 .78045 L
s
.99625 .86058 m
1 .86058 L
s
.99625 .90064 m
1 .90064 L
s
.99625 .94071 m
1 .94071 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
15 string
15 15 8 [15 0 0 15 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
000000000000000000000000000000
000000010203030303030201000000
000001050C11121212110C05010000
0001051636474B4C4B473616050100
00020C367FA8B2B4B2A87F360C0200
00031147A8DFECEEECDFA847110300
0003124BB2ECFBFDFBECB24B120300
0003124CB4EEFDFFFDEEB44C120300
0003124BB2ECFBFDFBECB24B120300
00031147A8DFECEEECDFA847110300
00020C367FA8B2B4B2A87F360C0200
0001051636474B4C4B473616050100
000001050C11121212110C05010000
000000010203030303030201000000
000000000000000000000000000000
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0113379 0.97619 0.464853 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0801282 0.5 0.0801282 [
[.01923 -0.0125 -6 -9 ]
[.01923 -0.0125 6 0 ]
[.17949 -0.0125 -6 -9 ]
[.17949 -0.0125 6 0 ]
[.33974 -0.0125 -6 -9 ]
[.33974 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.66026 -0.0125 -3 -9 ]
[.66026 -0.0125 3 0 ]
[.82051 -0.0125 -3 -9 ]
[.82051 -0.0125 3 0 ]
[.98077 -0.0125 -3 -9 ]
[.98077 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01923 -12 -4.5 ]
[-0.0125 .01923 0 4.5 ]
[-0.0125 .17949 -12 -4.5 ]
[-0.0125 .17949 0 4.5 ]
[-0.0125 .33974 -12 -4.5 ]
[-0.0125 .33974 0 4.5 ]
[-0.0125 .5 -6 -4.5 ]
[-0.0125 .5 0 4.5 ]
[-0.0125 .66026 -6 -4.5 ]
[-0.0125 .66026 0 4.5 ]
[-0.0125 .82051 -6 -4.5 ]
[-0.0125 .82051 0 4.5 ]
[-0.0125 .98077 -6 -4.5 ]
[-0.0125 .98077 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.01923 0 m
.01923 .00625 L
s
[(-6)] .01923 -0.0125 0 1 Mshowa
.17949 0 m
.17949 .00625 L
s
[(-4)] .17949 -0.0125 0 1 Mshowa
.33974 0 m
.33974 .00625 L
s
[(-2)] .33974 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.66026 0 m
.66026 .00625 L
s
[(2)] .66026 -0.0125 0 1 Mshowa
.82051 0 m
.82051 .00625 L
s
[(4)] .82051 -0.0125 0 1 Mshowa
.98077 0 m
.98077 .00625 L
s
[(6)] .98077 -0.0125 0 1 Mshowa
.125 Mabswid
.05929 0 m
.05929 .00375 L
s
.09936 0 m
.09936 .00375 L
s
.13942 0 m
.13942 .00375 L
s
.21955 0 m
.21955 .00375 L
s
.25962 0 m
.25962 .00375 L
s
.29968 0 m
.29968 .00375 L
s
.37981 0 m
.37981 .00375 L
s
.41987 0 m
.41987 .00375 L
s
.45994 0 m
.45994 .00375 L
s
.54006 0 m
.54006 .00375 L
s
.58013 0 m
.58013 .00375 L
s
.62019 0 m
.62019 .00375 L
s
.70032 0 m
.70032 .00375 L
s
.74038 0 m
.74038 .00375 L
s
.78045 0 m
.78045 .00375 L
s
.86058 0 m
.86058 .00375 L
s
.90064 0 m
.90064 .00375 L
s
.94071 0 m
.94071 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01923 m
.00625 .01923 L
s
[(-6)] -0.0125 .01923 1 0 Mshowa
0 .17949 m
.00625 .17949 L
s
[(-4)] -0.0125 .17949 1 0 Mshowa
0 .33974 m
.00625 .33974 L
s
[(-2)] -0.0125 .33974 1 0 Mshowa
0 .5 m
.00625 .5 L
s
[(0)] -0.0125 .5 1 0 Mshowa
0 .66026 m
.00625 .66026 L
s
[(2)] -0.0125 .66026 1 0 Mshowa
0 .82051 m
.00625 .82051 L
s
[(4)] -0.0125 .82051 1 0 Mshowa
0 .98077 m
.00625 .98077 L
s
[(6)] -0.0125 .98077 1 0 Mshowa
.125 Mabswid
0 .05929 m
.00375 .05929 L
s
0 .09936 m
.00375 .09936 L
s
0 .13942 m
.00375 .13942 L
s
0 .21955 m
.00375 .21955 L
s
0 .25962 m
.00375 .25962 L
s
0 .29968 m
.00375 .29968 L
s
0 .37981 m
.00375 .37981 L
s
0 .41987 m
.00375 .41987 L
s
0 .45994 m
.00375 .45994 L
s
0 .54006 m
.00375 .54006 L
s
0 .58013 m
.00375 .58013 L
s
0 .62019 m
.00375 .62019 L
s
0 .70032 m
.00375 .70032 L
s
0 .74038 m
.00375 .74038 L
s
0 .78045 m
.00375 .78045 L
s
0 .86058 m
.00375 .86058 L
s
0 .90064 m
.00375 .90064 L
s
0 .94071 m
.00375 .94071 L
s
.25 Mabswid
0 0 m
0 1 L
s
.01923 .99375 m
.01923 1 L
s
.17949 .99375 m
.17949 1 L
s
.33974 .99375 m
.33974 1 L
s
.5 .99375 m
.5 1 L
s
.66026 .99375 m
.66026 1 L
s
.82051 .99375 m
.82051 1 L
s
.98077 .99375 m
.98077 1 L
s
.125 Mabswid
.05929 .99625 m
.05929 1 L
s
.09936 .99625 m
.09936 1 L
s
.13942 .99625 m
.13942 1 L
s
.21955 .99625 m
.21955 1 L
s
.25962 .99625 m
.25962 1 L
s
.29968 .99625 m
.29968 1 L
s
.37981 .99625 m
.37981 1 L
s
.41987 .99625 m
.41987 1 L
s
.45994 .99625 m
.45994 1 L
s
.54006 .99625 m
.54006 1 L
s
.58013 .99625 m
.58013 1 L
s
.62019 .99625 m
.62019 1 L
s
.70032 .99625 m
.70032 1 L
s
.74038 .99625 m
.74038 1 L
s
.78045 .99625 m
.78045 1 L
s
.86058 .99625 m
.86058 1 L
s
.90064 .99625 m
.90064 1 L
s
.94071 .99625 m
.94071 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .01923 m
1 .01923 L
s
.99375 .17949 m
1 .17949 L
s
.99375 .33974 m
1 .33974 L
s
.99375 .5 m
1 .5 L
s
.99375 .66026 m
1 .66026 L
s
.99375 .82051 m
1 .82051 L
s
.99375 .98077 m
1 .98077 L
s
.125 Mabswid
.99625 .05929 m
1 .05929 L
s
.99625 .09936 m
1 .09936 L
s
.99625 .13942 m
1 .13942 L
s
.99625 .21955 m
1 .21955 L
s
.99625 .25962 m
1 .25962 L
s
.99625 .29968 m
1 .29968 L
s
.99625 .37981 m
1 .37981 L
s
.99625 .41987 m
1 .41987 L
s
.99625 .45994 m
1 .45994 L
s
.99625 .54006 m
1 .54006 L
s
.99625 .58013 m
1 .58013 L
s
.99625 .62019 m
1 .62019 L
s
.99625 .70032 m
1 .70032 L
s
.99625 .74038 m
1 .74038 L
s
.99625 .78045 m
1 .78045 L
s
.99625 .86058 m
1 .86058 L
s
.99625 .90064 m
1 .90064 L
s
.99625 .94071 m
1 .94071 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
15 string
15 15 8 [15 0 0 15 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
000000010202020302020201000000
000001060C0F1010100F0C06010000
0001081E3B4B4F504F4B3B1E080100
01061E6CC4F0FDFFFDF0C46C1E0601
020C3BC4FFF5FDFFFDF5FFC43B0C02
020F4BF0F56A5150516AF5F04B0F02
02104FFDFD51160F1651FDFD4F1002
031050FFFF500F000F50FFFF501003
02104FFDFD51160F1651FDFD4F1002
020F4BF0F56A5150516AF5F04B0F02
020C3BC4FFF5FDFFFDF5FFC43B0C02
01061E6CC4F0FDFFFDF0C46C1E0601
0001081E3B4B4F504F4B3B1E080100
000001060C0F1010100F0C06010000
000000010202020302020201000000
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{216, 102.813},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003H0000IQ000`40O003h00Of7oo003HOol00=Qo
o`00f7oo000EOol2000<Ool30009Ool30009Ool00`00Oomoo`09Ool3000;Ool3000:Ool2000KOol2
000=Ool30009Ool30009Ool00`00Oomoo`09Ool3000;Ool30009Ool2000:Ool001Eoo`03001oo`00
00aoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oo`0000Yoo`03001oogoo00aoo`03001oogoo
00Uoo`03001oo`0001Yoo`03001oo`0000eoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oo`00
00Yoo`03001oogoo00aoo`03001oogoo00Qoo`03001oo`0000Uoo`0047oo0`000Woo00<007oo0000
1Goo0`000Woo100017oo0`000goo00<007ooOol01goo00<007oo00002goo00<007ooOol02Goo1000
2Woo00<007oo00005Goo0`000Woo00<007oo00001Woo0`000Woo100017oo0`000goo00<007ooOol0
1goo00<007oo00002goo00<007ooOol02Goo10002Goo00<007oo00002Goo000EOol2000;Ool00`00
Ool0000;Ool00`00Oomoo`07Ool00`00Ool0000;Ool00`00Oomoo`09Ool00`00Ool0000;Ool2000K
Ool2000<Ool00`00Ool0000;Ool00`00Oomoo`07Ool00`00Ool0000;Ool00`00Oomoo`09Ool00`00
Ool0000:Ool2000:Ool001Eoo`03001oogoo00]oo`8000Yoo`03001oo`0000Qoo`03001oo`0000Yo
o`03001oo`0000]oo`8000]oo`03001oogoo01Yoo`03001oogoo00aoo`8000Yoo`03001oo`0000Qo
o`03001oo`0000Yoo`03001oo`0000]oo`8000Yoo`03001oogoo00Uoo`005Woo0P0037oo00<007oo
Ool02Goo00<007ooOol027oo00<007ooOol02Woo00<007ooOol02goo00<007ooOol02Woo0P006goo
0P003Goo00<007ooOol02Goo00<007ooOol027oo00<007ooOol02Woo00<007ooOol02goo00<007oo
Ool02Goo0P002Goo003HOol00=Qoo`00N7oo0P00GWoo000=Ool20003OomD000BOol00`00Ool00002
OomC0008Ool000eoo`03001oo`00009oo`03001oogoo051oo`03001oogoo00]oo`<0009oo`03001o
o`00009oo`03001oogoo04moo`03001oogoo00Ioo`0027oo0`000Woo00<007oo00000WooD@0000=o
o`0000004Woo0P000gooD@0000=oo`00Ool01goo000=Ool20003Ool00`00Ool0001>0002Ool00`00
Oomoo`0@Ool00`00Oomoo`02OomA00000goo001oo`07Ool000eoo`03001oogoo009oo`03001oo`00
04h0009oo`03001oogoo015oo`80009ooe400003Ool007oo00Moo`003Woo0P000WooD@0000=oo`00
00005gooD@0000=oo`00Ool01goo000BOol00`00Ool0001>0002Ool00`00Oomoo`0EOomA00000goo
001oo`07Ool0019oo`03001oo`0004h0009oo`03001oogoo01EooaH000/48A08@P/48AD00003Ool0
07oo00Moo`004WooD@0000=oo`0000005goo5P002`@Q40Q22`@Q5@0000=oo`00Ool01goo000BOol0
0`00Ool0001>0002Ool00`00Oomoo`0EOolF000;124@248;124E00000goo001oo`07Ool0019oo`03
001oo`0004h0009oo`03001oogoo01EooaH000/48A08@P/48AD00003Ool007oo00Moo`004WooD@00
00=oo`0000005goo5P002`@Q40Q22`@Q5@0000=oo`00Ool01goo000BOol00`00Ool0001>0002Ool0
0`00Oomoo`0EOolF000;124@248;124E00000goo001oo`07Ool000ioo`<00003Ool007oo01D000D4
8A/8@PD48AD0009oo`03001oogoo015oo`<00003Ool0000000X000D48@D<H`HLi`XU:@HYBPXU:@HL
i`D<H`D48@/00003Ool007oo00Moo`003goo00D007ooOol007oo01D000D48A/8@PD48AD0009oo`03
001oogoo019oo`03001oogoo00`000D48@D<H`HLi`XU:@HYBPXU:@HLi`D<H`D48@/00003Ool007oo
00Moo`0027oo0`000Woo100000=oo`0000005@001@@Q6`Q21@@Q5@0000=oo`0000003Goo0`000Woo
100000=oo`0000002P001@@Q1@aS1QcW2RDY1RU:2RDY1QcW1@aS1@@Q2`0000=oo`00Ool01goo000=
Ool00`00Ool00002Ool00`00Ool0000D0005124K2485124E0002Ool00`00Oomoo`0@Ool00`00Ool0
0002Ool<0005124536<67>L:9BT6:DX:9BT67>L536<5124;00000goo001oo`07Ool000ioo`80009o
o`03001oo`0001@000D48A/8@PD48AD0009oo`03001oogoo015oo`80009oo``000D48@D<H`HLi`XU
:@HYBPXU:@HLi`D<H`D48@/00003Ool007oo00Moo`003goo00<007ooOol04P001@Q21AS61R483bDY
1R481AS61@Q2400000=oo`00000057oo00<007ooOol030001@aS1CF]1V<H1G_N47oo1G_N1V<H1CF]
1@aS2`0000=oo`00Ool01goo000BOol00`00Ool0000?000524856<H68@P?9BT68@P56<H5248@0002
Ool00`00Oomoo`0EOol<000536<5=Jd6HaP5Nmh@Ool5Nmh6HaP5=Jd536<;00000goo001oo`07Ool0
019oo`03001oo`0000l000D8@PDHaPHQ20lU:@HQ20DHaPD8@Q00009oo`03001oogoo01Eoo``000D<
H`De[@IS60EkgQ1oo`EkgPIS60De[@D<H`/00003Ool007oo00Moo`004Woo4P001@Q21AS61R483bDY
1R481AS61@Q2400000=oo`0000005goo30001@aS1CF]1V<H1G_N47oo1G_N1V<H1CF]1@aS2`0000=o
o`00Ool01goo000BOol00`00Ool0000?000524856<H68@P?9BT68@P56<H5248@0002Ool00`00Oomo
o`0EOol<000536<5=Jd6HaP5Nmh@Ool5Nmh6HaP5=Jd536<;00000goo001oo`07Ool0019oo`03001o
o`0000X000D48@DHaPDmk`IF]@mJePIF]@Dmk`DHaPH48@X0009oo`03001oogoo01Eoo`H000H48@DL
i`ES60Ioo`EkgQ1oo`EkgPIoo`ES60DLi`H48@D00003Ool007oo00Moo`004Woo00<007oo00002P00
1@@Q1AS61Cg_1UJe3e[F1UJe1Cg_1AS61P@Q2P000Woo00<007ooOol05Goo1P001P@Q1AcW1F<H1Woo
1G_N47oo1G_N1Woo1F<H1AcW1P@Q1@0000=oo`00Ool01goo000BOol=000512456<H5?Nl6E[D?F]H6
E[D5?Nl56<H6124:00000goo0000000GOol6000612457>L5HaP6Ool5Nmh@Ool5Nmh6Ool5HaP57>L6
124500000goo001oo`07Ool000eoo`<0009oo`03001oo`0000X000D48@DHaPDmk`IF]@mJePIF]@Dm
k`DHaPH48@X0009oo`03001oogoo011oo`<0009oo`H000H48@DLi`ES60Ioo`EkgQ1oo`EkgPIoo`ES
60DLi`H48@D00003Ool007oo00Moo`003Goo00<007ooOol00Woo00<007oo00002P001@@Q1AS61Cg_
1UJe3e[F1UJe1Cg_1AS61P@Q2P000Woo00<007ooOol047oo00<007ooOol00Woo1P001P@Q1AcW1F<H
1Woo1G_N47oo1G_N1Woo1F<H1AcW1P@Q1@0000=oo`00Ool01goo0008Ool30003Ool01000Oomoogoo
3@001@@Q1AS61Cg_1UJe3e[F1UJe1Cg_1AS61P@Q2P0000=oo`0000003Goo0`000goo00@007ooOomo
o`H000H48@DLi`ES60Ioo`EkgQ1oo`EkgPIoo`ES60DLi`H48@D00003Ool007oo00Moo`003Woo00H0
07ooOomoo`00Ool;000524858@P5E[D6Kg/?Mkd6Kg/5E[D58@P6248:0002Ool00`00Oomoo`0AOol0
1000Oomoogoo1P001P@Q1BDY2g_N1CF]42U:1CF]2g_N1BDY1P@Q1@0000=oo`00Ool01goo000=Ool0
0`00Ool00002Ool00`00Ool0000:000524858@P5E[D6Kg/?Mkd6Kg/5E[D58@P6248:0002Ool00`00
Oomoo`0@Ool00`00Ool00002Ool6000612459BT;Nmh5=Jd@:DX5=Jd;Nmh59BT6124500000goo001o
o`07Ool000ioo`04001oogooOol=000524858@P5E[D6Kg/?Mkd6Kg/5E[D58@P6248:00000goo0000
000COol01000Oomoogoo1P001P@Q1BDY2g_N1CF]42U:1CF]2g_N1BDY1P@Q1@0000=oo`00Ool01goo
000BOol00`00Ool0000:000524858@P5E[D6Kg/?Mkd6Kg/5E[D58@P6248:0002Ool00`00Oomoo`0E
Ool6000612459BT;Nmh5=Jd@:DX5=Jd;Nmh59BT6124500000goo001oo`07Ool0019oo`03001oo`00
00X000D8@PDQ20EF]@I_N`mg_@I_N`EF]@DQ20H8@PX0009oo`03001oogoo01Eoo`H000H48@DU:@]k
gPDe[A0YBPDe[@]kgPDU:@H48@D00003Ool007oo00Moo`004Woo00<007oo00002P001@Q21BDY1E[F
1WNm3goo1WNm1E[F1BDY1PQ22P000Woo00<007ooOol05Goo1P001PQ21BDY2goo1BU:1@Q21P@Q1@Q2
1BU:2goo1BDY1PQ21@0000=oo`00Ool01goo000BOol=000524859BT5F]H6Mkd?Ool6Mkd5F]H59BT6
248:00000goo0000000GOol6000624859BT;Ool5:DX5248612452485:DX;Ool59BT6248500000goo
001oo`07Ool0019oo`03001oo`0000X000D8@PDU:@EJePIg_@moo`Ig_@EJePDU:@H8@PX0009oo`03
001oogoo01Eoo`H000H8@PDU:@]oo`DYBPD8@PH48@D8@PDYBP]oo`DU:@H8@PD00003Ool007oo00Mo
o`004Woo00<007oo00002P001@Q21BDY1E[F1WNm3goo1WNm1E[F1BDY1PQ22P000Woo00<007ooOol0
5Goo1P001PQ21BDY2goo1BU:1@Q21P@Q1@Q21BU:2goo1BDY1PQ21@0000=oo`00Ool01goo000BOol=
000524859BT5F]H6Mkd?Ool6Mkd5F]H59BT6248:00000goo0000000GOol6000624859BT;Ool5:DX5
248612452485:DX;Ool59BT6248500000goo001oo`07Ool000ioo`06001oogooOol007oo2`001@Q2
1BDY1E[F1WNm3goo1WNm1E[F1BDY1PQ22P000Woo00<007ooOol04Goo00@007ooOomoo`H000H8@PDY
BP]oo`DYBPD48@H000D48@DYBP]oo`DYBPH8@PD00003Ool007oo00Moo`003Goo00<007oo00000Woo
00<007oo00002P001@Q21BDY1E[F1WNm3goo1WNm1E[F1BDY1PQ22P000Woo00<007ooOol047oo00<0
07oo00000Woo1P001PQ21BU:2goo1BU:1@@Q1P001@@Q1BU:2goo1BU:1PQ21@0000=oo`00Ool01goo
000=Ool00`00Ool00002Ool=000524859BT5F]H6Mkd?Ool6Mkd5F]H59BT6248:00000goo0000000B
Ool00`00Ool00002Ool600062485:DX;Ool5:DX5124600051245:DX;Ool5:DX6248500000goo001o
o`07Ool000eoo`03001oo`00009oo`03001oo`0000X000D8@PDU:@EJePIg_@moo`Ig_@EJePDU:@H8
@PX0009oo`03001oogoo011oo`03001oo`00009oo`H000H8@PDYBP]oo`DYBPD48@H000D48@DYBP]o
o`DYBPH8@PD00003Ool007oo00Moo`003Goo00<007oo00000Woo00<007oo00002P001@Q21BDY1E[F
1WNm3goo1WNm1E[F1BDY1PQ22P000Woo00<007ooOol047oo00<007oo00000Woo1P001PQ21BU:2goo
1BU:1@@Q1P001@@Q1BU:2goo1BU:1PQ21@0000=oo`00Ool01goo000>Ool01000Oomoogoo3@001@Q2
1BDY1E[F1WNm3goo1WNm1E[F1BDY1PQ22P0000=oo`0000004goo00@007ooOomoo`H000H8@PDYBP]o
o`DYBPD48@H000D48@DYBP]oo`DYBPH8@PD00003Ool007oo00Moo`004Woo00<007oo00002P001@Q2
1BDY1E[F1WNm3goo1WNm1E[F1BDY1PQ22P000Woo00<007ooOol05Goo1P001PQ21BDY2goo1BU:1@Q2
1P@Q1@Q21BU:2goo1BDY1PQ21@0000=oo`00Ool01goo000BOol00`00Ool0000:000524859BT5F]H6
Mkd?Ool6Mkd5F]H59BT6248:0002Ool00`00Oomoo`0EOol6000624859BT;Ool5:DX5248612452485
:DX;Ool59BT6248500000goo001oo`07Ool0019oo`03001oo`0000X000D8@PDU:@EJePIg_@moo`Ig
_@EJePDU:@H8@PX0009oo`03001oogoo01Eoo`H000H8@PDU:@]oo`DYBPD8@PH48@D8@PDYBP]oo`DU
:@H8@PD00003Ool007oo00Moo`004Woo3@001@Q21BDY1E[F1WNm3goo1WNm1E[F1BDY1PQ22P0000=o
o`0000005goo1P001PQ21BDY2goo1BU:1@Q21P@Q1@Q21BU:2goo1BDY1PQ21@0000=oo`00Ool01goo
000BOol00`00Ool0000:000524859BT5F]H6Mkd?Ool6Mkd5F]H59BT6248:0002Ool00`00Oomoo`0E
Ool6000624859BT;Ool5:DX5248612452485:DX;Ool59BT6248500000goo001oo`07Ool0019oo`03
001oo`0000X000D8@PDQ20EF]@I_N`mg_@I_N`EF]@DQ20H8@PX0009oo`03001oogoo01Eoo`H000H4
8@DU:@]kgPDe[A0YBPDe[@]kgPDU:@H48@D00003Ool007oo00Moo`004Woo3@001@Q21B481EJe1Vmk
3gNm1Vmk1EJe1B481PQ22P0000=oo`0000005goo1P001P@Q1BDY2g_N1CF]42U:1CF]2g_N1BDY1P@Q
1@0000=oo`00Ool01goo000=Ool30002Ool00`00Ool0000:000524858@P5E[D6Kg/?Mkd6Kg/5E[D5
8@P6248:0002Ool00`00Oomoo`0@Ool30002Ool6000612459BT;Nmh5=Jd@:DX5=Jd;Nmh59BT61245
00000goo001oo`07Ool000eoo`03001oogoo009oo`03001oo`0000X000D8@PDQ20EF]@I_N`mg_@I_
N`EF]@DQ20H8@PX0009oo`03001oogoo011oo`03001oogoo009oo`H000H48@DU:@]kgPDe[A0YBPDe
[@]kgPDU:@H48@D00003Ool007oo00Moo`003Woo00@007ooOomoo`d000D8@PDQ20EF]@I_N`mg_@I_
N`EF]@DQ20H8@PX00003Ool0000001=oo`04001oogooOol6000612459BT;Nmh5=Jd@:DX5=Jd;Nmh5
9BT6124500000goo001oo`07Ool000ioo`06001oogooOol007oo2`001@@Q1AS61Cg_1UJe3e[F1UJe
1Cg_1AS61P@Q2P000Woo00<007ooOol04Goo00@007ooOomoo`H000H48@DLi`ES60Ioo`EkgQ1oo`Ek
gPIoo`ES60DLi`H48@D00003Ool007oo00Moo`003Goo00<007oo00000Woo00<007oo00002P001@@Q
1AS61Cg_1UJe3e[F1UJe1Cg_1AS61P@Q2P000Woo00<007ooOol047oo00<007oo00000Woo1P001P@Q
1AcW1F<H1Woo1G_N47oo1G_N1Woo1F<H1AcW1P@Q1@0000=oo`00Ool01goo000>Ool01P00Oomoogoo
001oo`/000D48@DHaPDmk`IF]@mJePIF]@Dmk`DHaPH48@X0009oo`03001oogoo015oo`04001oogoo
Ool6000612457>L5HaP6Ool5Nmh@Ool5Nmh6Ool5HaP57>L6124500000goo001oo`07Ool0019oo`d0
00D48@DHaPDmk`IF]@mJePIF]@Dmk`DHaPH48@X00003Ool0000001Moo`H000H48@DLi`ES60Ioo`Ek
gQ1oo`EkgPIoo`ES60DLi`H48@D00003Ool007oo00Moo`004Woo00<007oo00002P001@@Q1AS61Cg_
1UJe3e[F1UJe1Cg_1AS61P@Q2P000Woo00<007ooOol05Goo1P001P@Q1AcW1F<H1Woo1G_N47oo1G_N
1Woo1F<H1AcW1P@Q1@0000=oo`00Ool01goo000BOol00`00Ool0000:000512456<H5?Nl6E[D?F]H6
E[D5?Nl56<H6124:0002Ool00`00Oomoo`0EOol6000612457>L5HaP6Ool5Nmh@Ool5Nmh6Ool5HaP5
7>L6124500000goo001oo`07Ool0019ooa8000D8@PDHaPHQ20lU:@HQ20DHaPD8@Q000003Ool00000
01Moo``000D<H`De[@IS60EkgQ1oo`EkgPIS60De[@D<H`/00003Ool007oo00Moo`004Woo00<007oo
00003`001@Q21AS61R483bDY1R481AS61@Q240000Woo00<007ooOol05Goo30001@aS1CF]1V<H1G_N
47oo1G_N1V<H1CF]1@aS2`0000=oo`00Ool01goo000BOol00`00Ool0000?000524856<H68@P?9BT6
8@P56<H5248@0002Ool00`00Oomoo`0EOol<000536<5=Jd6HaP5Nmh@Ool5Nmh6HaP5=Jd536<;0000
0goo001oo`07Ool0019ooa8000D8@PDHaPHQ20lU:@HQ20DHaPD8@Q000003Ool0000001Moo``000D<
H`De[@IS60EkgQ1oo`EkgPIS60De[@D<H`/00003Ool007oo00Moo`004Woo00<007oo00003`001@Q2
1AS61R483bDY1R481AS61@Q240000Woo00<007ooOol05Goo30001@aS1CF]1V<H1G_N47oo1G_N1V<H
1CF]1@aS2`0000=oo`00Ool01goo000>Ool300000goo001oo`0E0005124K2485124E0002Ool00`00
Oomoo`0AOol300000goo0000000:0005124536<67>L:9BT6:DX:9BT67>L536<5124;00000goo001o
o`07Ool000moo`05001oogoo001oo`0E0005124K2485124E0002Ool00`00Oomoo`0BOol00`00Oomo
o`0<0005124536<67>L:9BT6:DX:9BT67>L536<5124;00000goo001oo`07Ool000eoo`@00003Ool0
000001D000D48A/8@PD48AD00003Ool00000019oo`@00003Ool0000000X000D48@D<H`HLi`XU:@HY
BPXU:@HLi`D<H`D48@/00003Ool007oo00Moo`003Goo00<007oo00000Woo00<007oo000050001@@Q
6`Q21@@Q5@000Woo00<007ooOol047oo00<007oo00000Woo30001@@Q1@aS1QcW2RDY1RU:2RDY1QcW
1@aS1@@Q2`0000=oo`00Ool01goo000>Ool20002Ool00`00Ool0000D0005124K2485124E0002Ool0
0`00Oomoo`0AOol20002Ool<0005124536<67>L:9BT6:DX:9BT67>L536<5124;00000goo001oo`07
Ool000moo`03001oogoo05400003Ool0000001Aoo`03001oogoo01H000/48A08@P/48AD00003Ool0
07oo00Moo`004Woo00<007oo0000CP000Woo00<007ooOol05Goo5P002`@Q40Q22`@Q5@0000=oo`00
Ool01goo000BOol00`00Ool0001>0002Ool00`00Oomoo`0EOolF000;124@248;124E00000goo001o
o`07Ool0019ooe400003Ool0000001MooaH000/48A08@P/48AD00003Ool007oo00Moo`004Woo00<0
07oo0000CP000Woo00<007ooOol05Goo5P002`@Q40Q22`@Q5@0000=oo`00Ool01goo000BOol00`00
Ool0001>0002Ool00`00Oomoo`0EOolF000;124@248;124E00000goo001oo`07Ool0019oo`03001o
o`0004h0009oo`03001oogoo01Eooe400003Ool007oo00Moo`004WooD@0000=oo`0000005gooD@00
00=oo`00Ool01goo000=Ool20003Ool00`00Ool0001>0002Ool00`00Oomoo`0@Ool20003OomA0000
0goo001oo`07Ool000eoo`03001oo`00009oo`03001oo`0004h0009oo`03001oogoo011oo`03001o
o`00009ooe400003Ool007oo00Moo`003Goo00<007oo00000WooD@0000=oo`0000004Woo00<007oo
00000WooD@0000=oo`00Ool01goo000=Ool20003OomD000BOol20003OomC0008Ool000eoo`03001o
ogoo06Qoo`03001oogoo05eoo`003Woo0P00JGoo0P00GGoo003HOol00=Qoo`00f7oo003HOol00001
\
\>"],
  ImageRangeCache->{{{0, 215}, {101.813, 0}} -> {-0.055872, -0.0238146, 
  0.00982208, 0.00982208}, {{5.6875, 102.625}, {99.375, 
  2.375}} -> {-9.07196, -8.24461, 0.151288, 0.151288}, {{112.313, 209.313}, {
  99.375, 2.375}} -> {-25.1887, -8.23848, 0.151172, 0.151172}}]
}, Open  ]],

Cell["The large gradient values localize the position of the edge.", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Digital Gradient", "Subsection"],

Cell[TextData[{
  "In practice, finite difference approximations of the orthogonal gradient \
are used. They are represented by a pair of masks, call them ",
  Cell[BoxData[
      \(TraditionalForm\`h\_x\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`h\_y\)]],
  ", which approximate the directional derivatives of the image. The \
convolution of the image array, with  ",
  Cell[BoxData[
      \(TraditionalForm\`h\_x\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`h\_y\)]],
  " gives two images, say ",
  Cell[BoxData[
      \(TraditionalForm\`g\_x\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`g\_y\)]],
  ", respectively. The gradient image is traditionally, ",
  Cell[BoxData[
      \(TraditionalForm\`\(\ \[Del]\( = \@\(g\_x\^2\  + \ g\_y\^2\)\)\)\)]],
  ", or alternatively, ",
  Cell[BoxData[
      \(TraditionalForm
      \`\[Del]\ \( = \ \( | g\_x | \ \(+\ \( | g\_y | \)\)\)\)\)]],
  ". A pixel location is declared an edge location, if value of \[Del] (at \
point x, y) exceeds some threshold. The location of all edge points \
constitutes an edge map. The selection of a threshold value is an important \
design decision, that depends on a number of factors, such as image \
brigthness, contrast, level of noise, even edge direction. Typically, the \
threshold is selected following an analysis of the gradient image histogram. \
It is sometimes of interest to calculate edge direction information. This is \
given by ",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[Phi]", "=", 
          RowBox[{"ArcTan", "[", 
            FormBox[\(g\_y\/g\_x\),
              "TraditionalForm"], "]"}]}], TraditionalForm]]],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Common Digital Gradient Operators", "Subsection"],

Cell["Here are the two common gradient edge operators.", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \({r\_x, r\_y} = RobertsKernel\)], "Input"],

Cell[BoxData[
    \({{{0, 1}, {\(-1\), 0}}, {{1, 0}, {0, \(-1\)}}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \({s\_x, s\_y} = SobelKernel\)], "Input",
  CellLabel->"In[25]:="],

Cell[BoxData[
    \({{{\(-\(1\/4\)\), 0, 1\/4}, {\(-\(1\/2\)\), 0, 1\/2}, {\(-\(1\/4\)\), 
          0, 1\/4}}, {{\(-\(1\/4\)\), \(-\(1\/2\)\), \(-\(1\/4\)\)}, {0, 0, 
          0}, {1\/4, 1\/2, 1\/4}}}\)], "Output",
  CellLabel->"Out[25]="]
}, Open  ]],

Cell["\<\
It is of interest to verify that the standard edge operators do indeed \
approximate a derivative operation. From continuos-time Fourier theory we \
have the following relationship [Oppenheim, 1996]\
\>", "Text"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm
    \`\[PartialD]\_t\ \(x(t)\)\  = \ 
      \(1\/\(2  \[Pi]\)\) 
        \(\[Integral]\_\(-\[Infinity]\)\%\[Infinity] j\ \[Omega]\ 
            \(X(\[Omega])\)\ \(\[ExponentialE]\^\(\ j\ \[Omega]\ t\)\) 
            \[DifferentialD]\[Omega]\)\)]]], "NumberedEquation"],

Cell["and thus", "Text"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm
    \`\(x(t)\)\ \(\(\[LongLeftRightArrow]\&CTFT\)\ j\)\ \[Omega]\ 
        \(X(\[Omega])\)\  = \ \(H(\[Omega])\)\ \(X(\[Omega])\)\)]]], 
  "NumberedEquation"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`X(\[Omega])\)]],
  " is the CTFT of ",
  Cell[BoxData[
      \(TraditionalForm\`x(t)\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`H(\[Omega])\  = \ j\ \[Omega]\)]],
  " is the ",
  StyleBox["ideal differentiator",
    FontSlant->"Italic"],
  ". Note that the ideal differentiator is characterized by a frequency \
response that is linear with frequency. We now proceed with an analysis of \
the DTFT of the Sobel edge masks. The 2D DTFTs of ",
  Cell[BoxData[
      \(TraditionalForm\`s\_x\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`s\_y\)]],
  " are: "
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \({S\_x = 
        \[Sum]\+\(i = \(-1\)\)\%1
            \(\[Sum]\+\(j = \(-1\)\)\%1 s\_x[\([i + 2, j + 2]\)]\ 
              Exp[\(-I\)\ \((u\ i + v\ j)\)]\), \ \ 
      S\_y = \[Sum]\+\(i = \(-1\)\)\%1
            \(\[Sum]\+\(j = \(-1\)\)\%1 s\_y[\([i + 2, j + 2]\)]\ 
              Exp[\(-I\)\ \((u\ i + v\ j)\)]\)}\)], "Input",
  CellLabel->"In[26]:="],

Cell[BoxData[
    \({\(-\(1\/4\)\)\ E\^\(\(-I\)\ \((\(-u\) - v)\)\) - 
        1\/4\ E\^\(\(-I\)\ \((u - v)\)\) + E\^\(\(-I\)\ v\)\/2 - 
        E\^\(I\ v\)\/2 + 1\/4\ E\^\(\(-I\)\ \((\(-u\) + v)\)\) + 
        1\/4\ E\^\(\(-I\)\ \((u + v)\)\), 
      E\^\(\(-I\)\ u\)\/2 - E\^\(I\ u\)\/2 - 
        1\/4\ E\^\(\(-I\)\ \((\(-u\) - v)\)\) + 
        1\/4\ E\^\(\(-I\)\ \((u - v)\)\) - 
        1\/4\ E\^\(\(-I\)\ \((\(-u\) + v)\)\) + 
        1\/4\ E\^\(\(-I\)\ \((u + v)\)\)}\)], "Output",
  CellLabel->"Out[26]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[
      GraphicsArray[
        \(Plot3D[Abs[#], \ {u, \ 0, \ \[Pi]}, \ {v, \ 0, \ \[Pi]}, \ 
              AxesLabel -> {"\<u\>", "\<v\>", "\< \>"}, 
              DisplayFunction -> Identity]\ &\)\ /@\ {S\_x, S\_y}]]; \)\)], 
  "Input",
  CellLabel->"In[29]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .38626 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.00919655 0.47619 [
[ 0 0 0 0 ]
[ 1 .38626 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .38626 L
0 .38626 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.00919655 0.477324 0.377059 MathSubStart
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
5.55112e-017 1.04977 -0.0679587 1.04977 [
[.02757 .24618 -6 -8.70276 ]
[.02757 .24618 0 .29724 ]
[.2187 .17096 -5.81399 -9 ]
[.2187 .17096 .18601 0 ]
[.42503 .08982 -5.4158 -9 ]
[.42503 .08982 .5842 0 ]
[.64842 .00203 -5.01761 -9 ]
[.64842 .00203 .98239 0 ]
[.29165 .07573 -9.31117 -12.875 ]
[.29165 .07573 .68883 0 ]
[.70096 -0.00478 0 -6.26206 ]
[.70096 -0.00478 6 2.73794 ]
[.80399 .15298 0 -6.10779 ]
[.80399 .15298 6 2.89221 ]
[.89336 .28984 0 -5.97836 ]
[.89336 .28984 6 3.02164 ]
[.97161 .40968 0 -5.86822 ]
[.97161 .40968 6 3.13178 ]
[.91861 .21225 0 -8.62807 ]
[.91861 .21225 10.0625 4.24693 ]
[.02411 .26511 -6 -2.74232 ]
[.02411 .26511 0 6.25768 ]
[.01568 .31795 -18 -2.78699 ]
[.01568 .31795 0 6.21301 ]
[.00696 .37264 -6 -2.83339 ]
[.00696 .37264 0 6.16661 ]
[-0.00208 .42927 -18 -2.88161 ]
[-0.00208 .42927 0 6.11839 ]
[-0.01144 .48795 -6 -2.93176 ]
[-0.01144 .48795 0 6.06824 ]
[-0.05457 .39542 -10 -4.05332 ]
[-0.05457 .39542 0 8.82168 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
[(0)] .02757 .24618 1 .93395 Mshowa
.22768 .18054 m
.23217 .18532 L
s
[(1)] .2187 .17096 .938 1 Mshowa
.43326 .10004 m
.43737 .10515 L
s
[(2)] .42503 .08982 .80527 1 Mshowa
.65575 .01292 m
.65941 .01836 L
s
[(3)] .64842 .00203 .67254 1 Mshowa
.125 Mabswid
.07414 .24066 m
.07698 .24338 L
s
.11167 .22596 m
.11448 .22872 L
s
.14976 .21105 m
.15253 .21384 L
s
.18843 .19591 m
.19116 .19874 L
s
.26753 .16493 m
.27019 .16784 L
s
.30801 .14908 m
.31061 .15203 L
s
.34911 .13299 m
.35167 .13598 L
s
.39085 .11664 m
.39337 .11967 L
s
.47634 .08317 m
.47875 .08628 L
s
.52011 .06603 m
.52247 .06918 L
s
.56459 .04861 m
.5669 .0518 L
s
.60979 .03091 m
.61205 .03414 L
s
gsave
.29165 .07573 -70.3112 -16.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.875 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.875000 moveto
 460.000000 16.875000 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.875000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(u) show
69.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.68874 0 m
.68263 .00239 L
s
[(0)] .70096 -0.00478 -1 .39157 Mshowa
.79163 .1574 m
.78546 .15961 L
s
[(1)] .80399 .15298 -1 .35729 Mshowa
.88089 .29393 m
.87466 .29598 L
s
[(2)] .89336 .28984 -1 .32852 Mshowa
.95906 .4135 m
.95278 .41541 L
s
[(3)] .97161 .40968 -1 .30405 Mshowa
.125 Mabswid
.71056 .03337 m
.70688 .03479 L
s
.73173 .06576 m
.72804 .06715 L
s
.75228 .0972 m
.74859 .09856 L
s
.77224 .12773 m
.76854 .12908 L
s
.81049 .18623 m
.80677 .18754 L
s
.82882 .21427 m
.8251 .21556 L
s
.84665 .24155 m
.84292 .24282 L
s
.864 .26809 m
.86027 .26934 L
s
.89734 .3191 m
.8936 .32031 L
s
.91337 .34361 m
.90962 .34481 L
s
.92899 .3675 m
.92523 .36868 L
s
.94421 .39079 m
.94045 .39195 L
s
gsave
.91861 .21225 -61 -12.6281 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.875 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.875000 moveto
 460.000000 16.875000 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.875000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(v) show
69.062500 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03634 .26033 m
.04245 .25795 L
s
[(0)] .02411 .26511 1 -0.3906 Mshowa
.02795 .31328 m
.03408 .31095 L
s
[(0.5)] .01568 .31795 1 -0.38067 Mshowa
.01926 .36808 m
.02541 .3658 L
s
[(1)] .00696 .37264 1 -0.37036 Mshowa
.01027 .42483 m
.01644 .42261 L
s
[(1.5)] -0.00208 .42927 1 -0.35964 Mshowa
.00095 .48363 m
.00715 .48147 L
s
[(2)] -0.01144 .48795 1 -0.3485 Mshowa
.125 Mabswid
.03468 .27078 m
.03835 .26935 L
s
.03301 .2813 m
.03669 .27988 L
s
.03134 .29189 m
.03501 .29047 L
s
.02965 .30255 m
.03332 .30114 L
s
.02623 .32409 m
.02991 .3227 L
s
.02451 .33497 m
.02819 .33359 L
s
.02277 .34593 m
.02646 .34455 L
s
.02102 .35697 m
.02471 .35559 L
s
.01749 .37927 m
.02118 .37791 L
s
.0157 .39054 m
.0194 .38919 L
s
.0139 .40189 m
.0176 .40054 L
s
.01209 .41332 m
.01579 .41198 L
s
.00843 .43642 m
.01214 .4351 L
s
.00658 .4481 m
.01029 .44678 L
s
.00472 .45986 m
.00843 .45855 L
s
.00284 .4717 m
.00656 .4704 L
s
gsave
-0.05457 .39542 -71 -8.05332 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.875 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.875000 moveto
 460.000000 16.875000 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.875000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
69.000000 13.000000 moveto
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.5 Mabswid
.233 0 0 r
.38132 .62652 .40512 .60371 .44189 .59268 .41889 .61481 Metetra
.199 0 0 r
.41889 .61481 .44189 .59268 .47916 .5815 .45699 .60187 Metetra
.145 0 0 r
.45699 .60187 .47916 .5815 .51695 .57017 .4956 .58775 Metetra
.061 0 0 r
.4956 .58775 .51695 .57017 .55526 .55867 .53471 .57259 Metetra
.53471 .57259 .55526 .55867 .59412 .54701 .57428 .55654 Metetra
.57428 .55654 .59412 .54701 .63352 .53519 .61432 .53983 Metetra
.408 .856 .791 r
.61432 .53983 .63352 .53519 .67349 .5232 .65481 .52267 Metetra
.559 .929 .924 r
.65481 .52267 .67349 .5232 .71403 .51104 .69578 .5053 Metetra
.645 .926 .974 r
.69578 .5053 .71403 .51104 .75515 .4987 .73724 .48799 Metetra
.681 .884 .973 r
.73724 .48799 .75515 .4987 .79688 .48619 .77924 .47095 Metetra
.689 .837 .954 r
.77924 .47095 .79688 .48619 .83921 .47349 .82182 .4544 Metetra
.685 .797 .934 r
.82182 .4544 .83921 .47349 .88217 .4606 .86503 .4385 Metetra
.677 .767 .919 r
.86503 .4385 .88217 .4606 .92578 .44752 .90894 .42341 Metetra
.668 .748 .91 r
.90894 .42341 .92578 .44752 .97003 .43424 .95362 .4092 Metetra
.182 0 0 r
.35639 .64825 .38132 .62652 .41889 .61481 .39476 .63585 Metetra
.117 0 0 r
.39476 .63585 .41889 .61481 .45699 .60187 .43372 .62112 Metetra
.027 0 0 r
.43372 .62112 .45699 .60187 .4956 .58775 .47321 .60419 Metetra
.47321 .60419 .4956 .58775 .53471 .57259 .51316 .58533 Metetra
.51316 .58533 .53471 .57259 .57428 .55654 .55351 .56488 Metetra
.427 .856 .726 r
.55351 .56488 .57428 .55654 .61432 .53983 .59424 .54327 Metetra
.579 .944 .863 r
.59424 .54327 .61432 .53983 .65481 .52267 .63534 .52097 Metetra
.677 .963 .937 r
.63534 .52097 .65481 .52267 .69578 .5053 .6768 .49847 Metetra
.721 .934 .958 r
.6768 .49847 .69578 .5053 .73724 .48799 .71866 .47625 Metetra
.73 .888 .952 r
.71866 .47625 .73724 .48799 .77924 .47095 .76099 .45478 Metetra
.723 .841 .937 r
.76099 .45478 .77924 .47095 .82182 .4544 .80386 .43447 Metetra
.708 .802 .923 r
.80386 .43447 .82182 .4544 .86503 .4385 .84737 .41565 Metetra
.691 .771 .913 r
.84737 .41565 .86503 .4385 .90894 .42341 .89162 .39859 Metetra
.673 .75 .909 r
.89162 .39859 .90894 .42341 .95362 .4092 .93675 .38345 Metetra
.076 0 0 r
.3304 .66655 .35639 .64825 .39476 .63585 .36957 .65348 Metetra
.36957 .65348 .39476 .63585 .43372 .62112 .4094 .63701 Metetra
.4094 .63701 .43372 .62112 .47321 .60419 .44977 .61738 Metetra
.44977 .61738 .47321 .60419 .51316 .58533 .49059 .59498 Metetra
.491 .889 .74 r
.49059 .59498 .51316 .58533 .55351 .56488 .53177 .57034 Metetra
.627 .961 .845 r
.53177 .57034 .55351 .56488 .59424 .54327 .57325 .5441 Metetra
.716 .981 .908 r
.57325 .5441 .59424 .54327 .63534 .52097 .615 .51695 Metetra
.761 .961 .933 r
.615 .51695 .63534 .52097 .6768 .49847 .65702 .48963 Metetra
.773 .923 .936 r
.65702 .48963 .6768 .49847 .71866 .47625 .69936 .46284 Metetra
.766 .879 .929 r
.69936 .46284 .71866 .47625 .76099 .45478 .74208 .43724 Metetra
.749 .838 .919 r
.74208 .43724 .76099 .45478 .80386 .43447 .7853 .41343 Metetra
.727 .803 .911 r
.7853 .41343 .80386 .43447 .84737 .41565 .82916 .39189 Metetra
.703 .773 .907 r
.82916 .39189 .84737 .41565 .89162 .39859 .8738 .37299 Metetra
.677 .751 .907 r
.8738 .37299 .89162 .39859 .93675 .38345 .91939 .35695 Metetra
.30351 .67906 .3304 .66655 .36957 .65348 .34344 .66533 Metetra
.34344 .66533 .36957 .65348 .4094 .63701 .38411 .64728 Metetra
.44 .864 .737 r
.38411 .64728 .4094 .63701 .44977 .61738 .42535 .62521 Metetra
.584 .943 .82 r
.42535 .62521 .44977 .61738 .49059 .59498 .46705 .59964 Metetra
.692 .981 .875 r
.46705 .59964 .49059 .59498 .53177 .57034 .50906 .57126 Metetra
.761 .985 .904 r
.50906 .57126 .53177 .57034 .57325 .5441 .55132 .5409 Metetra
.796 .965 .915 r
.55132 .5409 .57325 .5441 .615 .51695 .59377 .50947 Metetra
.807 .934 .915 r
.59377 .50947 .615 .51695 .65702 .48963 .63641 .4779 Metetra
.802 .898 .91 r
.63641 .4779 .65702 .48963 .69936 .46284 .67928 .4471 Metetra
.788 .863 .905 r
.67928 .4471 .69936 .46284 .74208 .43724 .72247 .4179 Metetra
.766 .83 .901 r
.72247 .4179 .74208 .43724 .7853 .41343 .76611 .39104 Metetra
.741 .8 .9 r
.76611 .39104 .7853 .41343 .82916 .39189 .81037 .3671 Metetra
.712 .774 .901 r
.81037 .3671 .82916 .39189 .8738 .37299 .85544 .34655 Metetra
.68 .752 .905 r
.85544 .34655 .8738 .37299 .91939 .35695 .90152 .32967 Metetra
.402 .857 .844 r
.27593 .68351 .30351 .67906 .34344 .66533 .31656 .66919 Metetra
.553 .931 .894 r
.31656 .66919 .34344 .66533 .38411 .64728 .358 .6498 Metetra
.668 .968 .918 r
.358 .6498 .38411 .64728 .42535 .62521 .40007 .6257 Metetra
.746 .976 .922 r
.40007 .6257 .42535 .62521 .46705 .59964 .4426 .59751 Metetra
.793 .965 .916 r
.4426 .59751 .46705 .59964 .50906 .57126 .48544 .56608 Metetra
.818 .944 .907 r
.48544 .56608 .50906 .57126 .55132 .5409 .52848 .53239 Metetra
.827 .919 .898 r
.52848 .53239 .55132 .5409 .59377 .50947 .57165 .4975 Metetra
.825 .892 .89 r
.57165 .4975 .59377 .50947 .63641 .4779 .61495 .46252 Metetra
.815 .866 .886 r
.61495 .46252 .63641 .4779 .67928 .4471 .6584 .42849 Metetra
.798 .841 .884 r
.6584 .42849 .67928 .4471 .72247 .4179 .70212 .39639 Metetra
.776 .817 .885 r
.70212 .39639 .72247 .4179 .76611 .39104 .74625 .36705 Metetra
.749 .794 .889 r
.74625 .36705 .76611 .39104 .81037 .3671 .79098 .34116 Metetra
.718 .772 .896 r
.79098 .34116 .81037 .3671 .85544 .34655 .83652 .31923 Metetra
.683 .752 .904 r
.83652 .31923 .85544 .34655 .90152 .32967 .88312 .30158 Metetra
.608 .905 .985 r
.24794 .67802 .27593 .68351 .31656 .66919 .28917 .66317 Metetra
.698 .921 .968 r
.28917 .66317 .31656 .66919 .358 .6498 .33129 .64275 Metetra
.757 .92 .944 r
.33129 .64275 .358 .6498 .40007 .6257 .37409 .61718 Metetra
.794 .909 .92 r
.37409 .61718 .40007 .6257 .4426 .59751 .41738 .58713 Metetra
.815 .894 .899 r
.41738 .58713 .4426 .59751 .48544 .56608 .46099 .55354 Metetra
.826 .879 .883 r
.46099 .55354 .48544 .56608 .52848 .53239 .50478 .51749 Metetra
.828 .863 .872 r
.50478 .51749 .52848 .53239 .57165 .4975 .54867 .48019 Metetra
.824 .848 .865 r
.54867 .48019 .57165 .4975 .61495 .46252 .59264 .44281 Metetra
.815 .833 .864 r
.59264 .44281 .61495 .46252 .6584 .42849 .63672 .40653 Metetra
.799 .818 .866 r
.63672 .40653 .6584 .42849 .70212 .39639 .68103 .37238 Metetra
.779 .803 .872 r
.68103 .37238 .70212 .39639 .74625 .36705 .7257 .34128 Metetra
.753 .787 .881 r
.7257 .34128 .74625 .36705 .79098 .34116 .77096 .31396 Metetra
.721 .77 .891 r
.77096 .31396 .79098 .34116 .83652 .31923 .81702 .29096 Metetra
.684 .751 .902 r
.81702 .29096 .83652 .31923 .88312 .30158 .86416 .27265 Metetra
.67 .818 .954 r
.21984 .6612 .24794 .67802 .28917 .66317 .26154 .64592 Metetra
.724 .825 .927 r
.26154 .64592 .28917 .66317 .33129 .64275 .30421 .62486 Metetra
.761 .825 .902 r
.30421 .62486 .33129 .64275 .37409 .61718 .34762 .59844 Metetra
.786 .822 .881 r
.34762 .59844 .37409 .61718 .41738 .58713 .39156 .5674 Metetra
.802 .818 .864 r
.39156 .5674 .41738 .58713 .46099 .55354 .43584 .53269 Metetra
.811 .814 .853 r
.43584 .53269 .46099 .55354 .50478 .51749 .48032 .49546 Metetra
.815 .81 .846 r
.48032 .49546 .50478 .51749 .54867 .48019 .52489 .45693 Metetra
.813 .805 .844 r
.52489 .45693 .54867 .48019 .59264 .44281 .56952 .41834 Metetra
.806 .8 .846 r
.56952 .41834 .59264 .44281 .63672 .40653 .61425 .38089 Metetra
.794 .794 .852 r
.61425 .38089 .63672 .40653 .68103 .37238 .65918 .34566 Metetra
.777 .787 .862 r
.65918 .34566 .68103 .37238 .7257 .34128 .70445 .31358 Metetra
.753 .778 .874 r
.70445 .31358 .7257 .34128 .77096 .31396 .75028 .28541 Metetra
.722 .766 .888 r
.75028 .28541 .77096 .31396 .81702 .29096 .79692 .26171 Metetra
.684 .751 .902 r
.79692 .26171 .81702 .29096 .86416 .27265 .84462 .24283 Metetra
.672 .724 .889 r
.1919 .63238 .21984 .6612 .26154 .64592 .23395 .61675 Metetra
.71 .734 .87 r
.23395 .61675 .26154 .64592 .30421 .62486 .27702 .59546 Metetra
.739 .742 .853 r
.27702 .59546 .30421 .62486 .34762 .59844 .32088 .56891 Metetra
.761 .748 .841 r
.32088 .56891 .34762 .59844 .39156 .5674 .36532 .5378 Metetra
.777 .753 .831 r
.36532 .5378 .39156 .5674 .43584 .53269 .41015 .5031 Metetra
.787 .758 .826 r
.41015 .5031 .43584 .53269 .48032 .49546 .4552 .4659 Metetra
.794 .762 .824 r
.4552 .4659 .48032 .49546 .52489 .45693 .50038 .42741 Metetra
.795 .766 .826 r
.50038 .42741 .52489 .45693 .56952 .41834 .54564 .38886 Metetra
.792 .769 .832 r
.54564 .38886 .56952 .41834 .61425 .38089 .59101 .3514 Metetra
.784 .771 .842 r
.59101 .3514 .61425 .38089 .65918 .34566 .63657 .3161 Metetra
.77 .771 .854 r
.63657 .3161 .65918 .34566 .70445 .31358 .68248 .28387 Metetra
.748 .768 .869 r
.68248 .28387 .70445 .31358 .75028 .28541 .72894 .25546 Metetra
.72 .761 .885 r
.72894 .25546 .75028 .28541 .79692 .26171 .77618 .23141 Metetra
.684 .749 .901 r
.77618 .23141 .79692 .26171 .84462 .24283 .82447 .21208 Metetra
.659 .654 .834 r
.1644 .59164 .1919 .63238 .23395 .61675 .20666 .57578 Metetra
.689 .666 .822 r
.20666 .57578 .23395 .61675 .27702 .59546 .24995 .55465 Metetra
.713 .677 .814 r
.24995 .55465 .27702 .59546 .32088 .56891 .29408 .52864 Metetra
.733 .688 .808 r
.29408 .52864 .32088 .56891 .36532 .5378 .33885 .4984 Metetra
.749 .699 .804 r
.33885 .4984 .36532 .5378 .41015 .5031 .38406 .46479 Metetra
.761 .71 .804 r
.38406 .46479 .41015 .5031 .4552 .4659 .42956 .42884 Metetra
.77 .721 .807 r
.42956 .42884 .4552 .4659 .50038 .42741 .47524 .39166 Metetra
.774 .731 .813 r
.47524 .39166 .50038 .42741 .54564 .38886 .52106 .35436 Metetra
.774 .741 .822 r
.52106 .35436 .54564 .38886 .59101 .3514 .56703 .31804 Metetra
.769 .749 .835 r
.56703 .31804 .59101 .3514 .63657 .3161 .61323 .28367 Metetra
.758 .755 .85 r
.61323 .28367 .63657 .3161 .68248 .28387 .65979 .25212 Metetra
.741 .758 .867 r
.65979 .25212 .68248 .28387 .72894 .25546 .7069 .22407 Metetra
.715 .756 .885 r
.7069 .22407 .72894 .25546 .77618 .23141 .75478 .20004 Metetra
.682 .748 .901 r
.75478 .20004 .77618 .23141 .82447 .21208 .80369 .18035 Metetra
.645 .605 .794 r
.13752 .53987 .1644 .59164 .20666 .57578 .17984 .52384 Metetra
.669 .617 .788 r
.17984 .52384 .20666 .57578 .24995 .55465 .2232 .50324 Metetra
.689 .629 .784 r
.2232 .50324 .24995 .55465 .29408 .52864 .26742 .4784 Metetra
.706 .642 .783 r
.26742 .4784 .29408 .52864 .33885 .4984 .31232 .44985 Metetra
.722 .656 .784 r
.31232 .44985 .33885 .4984 .38406 .46479 .35773 .41835 Metetra
.734 .67 .788 r
.35773 .41835 .38406 .46479 .42956 .42884 .40352 .38475 Metetra
.744 .685 .794 r
.40352 .38475 .42956 .42884 .47524 .39166 .44957 .35001 Metetra
.751 .7 .804 r
.44957 .35001 .47524 .39166 .52106 .35436 .49585 .3151 Metetra
.753 .715 .816 r
.49585 .3151 .52106 .35436 .56703 .31804 .54236 .28097 Metetra
.751 .728 .831 r
.54236 .28097 .56703 .31804 .61323 .28367 .58916 .24847 Metetra
.744 .74 .848 r
.58916 .24847 .61323 .28367 .65979 .25212 .63637 .21835 Metetra
.73 .748 .867 r
.63637 .21835 .65979 .25212 .7069 .22407 .68414 .19123 Metetra
.708 .75 .885 r
.68414 .19123 .7069 .22407 .75478 .20004 .73269 .16755 Metetra
.68 .746 .901 r
.73269 .16755 .75478 .20004 .80369 .18035 .78223 .14761 Metetra
.634 .571 .766 r
.11134 .47863 .13752 .53987 .17984 .52384 .1536 .4625 Metetra
.651 .581 .763 r
.1536 .4625 .17984 .52384 .2232 .50324 .19687 .44273 Metetra
.667 .593 .763 r
.19687 .44273 .2232 .50324 .26742 .4784 .241 .41954 Metetra
.682 .606 .764 r
.241 .41954 .26742 .4784 .31232 .44985 .28584 .39337 Metetra
.695 .621 .769 r
.28584 .39337 .31232 .44985 .35773 .41835 .33127 .36477 Metetra
.707 .637 .776 r
.33127 .36477 .35773 .41835 .40352 .38475 .37716 .33444 Metetra
.717 .654 .786 r
.37716 .33444 .40352 .38475 .44957 .35001 .42344 .30311 Metetra
.725 .672 .798 r
.42344 .30311 .44957 .35001 .49585 .3151 .47006 .27155 Metetra
.73 .691 .813 r
.47006 .27155 .49585 .3151 .54236 .28097 .51702 .24051 Metetra
.73 .709 .83 r
.51702 .24051 .54236 .28097 .58916 .24847 .56438 .21067 Metetra
.726 .725 .849 r
.56438 .21067 .58916 .24847 .63637 .21835 .61221 .18265 Metetra
.716 .737 .868 r
.61221 .18265 .63637 .21835 .68414 .19123 .66066 .15694 Metetra
.699 .744 .886 r
.66066 .15694 .68414 .19123 .73269 .16755 .70989 .13391 Metetra
.676 .744 .901 r
.70989 .13391 .73269 .16755 .78223 .14761 .76008 .1138 Metetra
.624 .547 .748 r
.08586 .41 .11134 .47863 .1536 .4625 .12796 .39383 Metetra
.636 .555 .747 r
.12796 .39383 .1536 .4625 .19687 .44273 .171 .37507 Metetra
.647 .565 .748 r
.171 .37507 .19687 .44273 .241 .41954 .21487 .35388 Metetra
.659 .577 .752 r
.21487 .35388 .241 .41954 .28584 .39337 .25948 .33056 Metetra
.67 .592 .759 r
.25948 .33056 .28584 .39337 .33127 .36477 .30474 .30547 Metetra
.68 .609 .769 r
.30474 .30547 .33127 .36477 .37716 .33444 .35057 .27907 Metetra
.69 .627 .781 r
.35057 .27907 .37716 .33444 .42344 .30311 .39692 .25186 Metetra
.698 .647 .796 r
.39692 .25186 .42344 .30311 .47006 .27155 .44375 .22436 Metetra
.704 .669 .813 r
.44375 .22436 .47006 .27155 .51702 .24051 .49106 .1971 Metetra
.706 .69 .832 r
.49106 .1971 .51702 .24051 .56438 .21067 .5389 .17056 Metetra
.705 .71 .852 r
.5389 .17056 .56438 .21067 .61221 .18265 .58732 .14515 Metetra
.699 .726 .871 r
.58732 .14515 .61221 .18265 .66066 .15694 .63642 .12124 Metetra
.688 .738 .889 r
.63642 .12124 .66066 .15694 .70989 .13391 .68633 .09909 Metetra
.672 .741 .902 r
.68633 .09909 .70989 .13391 .76008 .1138 .73719 .07886 Metetra
.617 .532 .736 r
.06094 .3364 .08586 .41 .12796 .39383 .10281 .32019 Metetra
.623 .537 .736 r
.10281 .32019 .12796 .39383 .171 .37507 .1455 .30255 Metetra
.63 .545 .74 r
.1455 .30255 .171 .37507 .21487 .35388 .18898 .28355 Metetra
.637 .555 .746 r
.18898 .28355 .21487 .35388 .25948 .33056 .23321 .26333 Metetra
.645 .569 .754 r
.23321 .26333 .25948 .33056 .30474 .30547 .27815 .24207 Metetra
.653 .585 .766 r
.27815 .24207 .30474 .30547 .35057 .27907 .32376 .21998 Metetra
.661 .604 .78 r
.32376 .21998 .35057 .27907 .39692 .25186 .37002 .19731 Metetra
.669 .625 .797 r
.37002 .19731 .39692 .25186 .44375 .22436 .41693 .17434 Metetra
.675 .649 .816 r
.41693 .17434 .44375 .22436 .49106 .1971 .46448 .1513 Metetra
.68 .673 .836 r
.46448 .1513 .49106 .1971 .5389 .17056 .51272 .12846 Metetra
.682 .696 .857 r
.51272 .12846 .5389 .17056 .58732 .14515 .56167 .10602 Metetra
.68 .716 .876 r
.56167 .10602 .58732 .14515 .63642 .12124 .61141 .08418 Metetra
.675 .731 .892 r
.61141 .08418 .63642 .12124 .68633 .09909 .662 .06305 Metetra
.668 .739 .903 r
.662 .06305 .68633 .09909 .73719 .07886 .71353 .04274 Metetra
.612 .524 .731 r
.03634 .26033 .06094 .3364 .10281 .32019 .07793 .24409 Metetra
.612 .526 .732 r
.07793 .24409 .10281 .32019 .1455 .30255 .12022 .22757 Metetra
.614 .53 .736 r
.12022 .22757 .1455 .30255 .18898 .28355 .16322 .21077 Metetra
.617 .539 .744 r
.16322 .21077 .18898 .28355 .23321 .26333 .20695 .19369 Metetra
.621 .55 .754 r
.20695 .19369 .23321 .26333 .27815 .24207 .25144 .17632 Metetra
.625 .565 .767 r
.25144 .17632 .27815 .24207 .32376 .21998 .29669 .15864 Metetra
.631 .584 .783 r
.29669 .15864 .32376 .21998 .37002 .19731 .34274 .14065 Metetra
.637 .606 .801 r
.34274 .14065 .37002 .19731 .41693 .17434 .3896 .12235 Metetra
.644 .63 .822 r
.3896 .12235 .41693 .17434 .46448 .1513 .43729 .10372 Metetra
.65 .656 .843 r
.43729 .10372 .46448 .1513 .51272 .12846 .48583 .08476 Metetra
.655 .682 .864 r
.48583 .08476 .51272 .12846 .56167 .10602 .53526 .06546 Metetra
.659 .706 .882 r
.53526 .06546 .56167 .10602 .61141 .08418 .58558 .0458 Metetra
.662 .725 .896 r
.58558 .0458 .61141 .08418 .662 .06305 .63684 .02578 Metetra
.663 .737 .905 r
.63684 .02578 .662 .06305 .71353 .04274 .68905 .00539 Metetra
0 g
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
[(0)] .02757 .24618 1 .93395 Mshowa
.22768 .18054 m
.23217 .18532 L
s
[(1)] .2187 .17096 .938 1 Mshowa
.43326 .10004 m
.43737 .10515 L
s
[(2)] .42503 .08982 .80527 1 Mshowa
.65575 .01292 m
.65941 .01836 L
s
[(3)] .64842 .00203 .67254 1 Mshowa
.125 Mabswid
.07414 .24066 m
.07698 .24338 L
s
.11167 .22596 m
.11448 .22872 L
s
.14976 .21105 m
.15253 .21384 L
s
.18843 .19591 m
.19116 .19874 L
s
.26753 .16493 m
.27019 .16784 L
s
.30801 .14908 m
.31061 .15203 L
s
.34911 .13299 m
.35167 .13598 L
s
.39085 .11664 m
.39337 .11967 L
s
.47634 .08317 m
.47875 .08628 L
s
.52011 .06603 m
.52247 .06918 L
s
.56459 .04861 m
.5669 .0518 L
s
.60979 .03091 m
.61205 .03414 L
s
gsave
.29165 .07573 -70.3112 -16.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.875 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.875000 moveto
 460.000000 16.875000 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.875000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(u) show
69.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.00919655 0.97619 0.377059 MathSubStart
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
5.55112e-017 1.04977 -0.0679587 1.04977 [
[.02757 .24618 -6 -8.70276 ]
[.02757 .24618 0 .29724 ]
[.2187 .17096 -5.81399 -9 ]
[.2187 .17096 .18601 0 ]
[.42503 .08982 -5.4158 -9 ]
[.42503 .08982 .5842 0 ]
[.64842 .00203 -5.01761 -9 ]
[.64842 .00203 .98239 0 ]
[.29165 .07573 -9.31117 -12.875 ]
[.29165 .07573 .68883 0 ]
[.70096 -0.00478 0 -6.26206 ]
[.70096 -0.00478 6 2.73794 ]
[.80399 .15298 0 -6.10779 ]
[.80399 .15298 6 2.89221 ]
[.89336 .28984 0 -5.97836 ]
[.89336 .28984 6 3.02164 ]
[.97161 .40968 0 -5.86822 ]
[.97161 .40968 6 3.13178 ]
[.91861 .21225 0 -8.62807 ]
[.91861 .21225 10.0625 4.24693 ]
[.02411 .26511 -6 -2.74232 ]
[.02411 .26511 0 6.25768 ]
[.01568 .31795 -18 -2.78699 ]
[.01568 .31795 0 6.21301 ]
[.00696 .37264 -6 -2.83339 ]
[.00696 .37264 0 6.16661 ]
[-0.00208 .42927 -18 -2.88161 ]
[-0.00208 .42927 0 6.11839 ]
[-0.01144 .48795 -6 -2.93176 ]
[-0.01144 .48795 0 6.06824 ]
[-0.05457 .39542 -10 -4.05332 ]
[-0.05457 .39542 0 8.82168 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
[(0)] .02757 .24618 1 .93395 Mshowa
.22768 .18054 m
.23217 .18532 L
s
[(1)] .2187 .17096 .938 1 Mshowa
.43326 .10004 m
.43737 .10515 L
s
[(2)] .42503 .08982 .80527 1 Mshowa
.65575 .01292 m
.65941 .01836 L
s
[(3)] .64842 .00203 .67254 1 Mshowa
.125 Mabswid
.07414 .24066 m
.07698 .24338 L
s
.11167 .22596 m
.11448 .22872 L
s
.14976 .21105 m
.15253 .21384 L
s
.18843 .19591 m
.19116 .19874 L
s
.26753 .16493 m
.27019 .16784 L
s
.30801 .14908 m
.31061 .15203 L
s
.34911 .13299 m
.35167 .13598 L
s
.39085 .11664 m
.39337 .11967 L
s
.47634 .08317 m
.47875 .08628 L
s
.52011 .06603 m
.52247 .06918 L
s
.56459 .04861 m
.5669 .0518 L
s
.60979 .03091 m
.61205 .03414 L
s
gsave
.29165 .07573 -70.3112 -16.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.875 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.875000 moveto
 460.000000 16.875000 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.875000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(u) show
69.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.68874 0 m
.68263 .00239 L
s
[(0)] .70096 -0.00478 -1 .39157 Mshowa
.79163 .1574 m
.78546 .15961 L
s
[(1)] .80399 .15298 -1 .35729 Mshowa
.88089 .29393 m
.87466 .29598 L
s
[(2)] .89336 .28984 -1 .32852 Mshowa
.95906 .4135 m
.95278 .41541 L
s
[(3)] .97161 .40968 -1 .30405 Mshowa
.125 Mabswid
.71056 .03337 m
.70688 .03479 L
s
.73173 .06576 m
.72804 .06715 L
s
.75228 .0972 m
.74859 .09856 L
s
.77224 .12773 m
.76854 .12908 L
s
.81049 .18623 m
.80677 .18754 L
s
.82882 .21427 m
.8251 .21556 L
s
.84665 .24155 m
.84292 .24282 L
s
.864 .26809 m
.86027 .26934 L
s
.89734 .3191 m
.8936 .32031 L
s
.91337 .34361 m
.90962 .34481 L
s
.92899 .3675 m
.92523 .36868 L
s
.94421 .39079 m
.94045 .39195 L
s
gsave
.91861 .21225 -61 -12.6281 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.875 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.875000 moveto
 460.000000 16.875000 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.875000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(v) show
69.062500 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03634 .26033 m
.04245 .25795 L
s
[(0)] .02411 .26511 1 -0.3906 Mshowa
.02795 .31328 m
.03408 .31095 L
s
[(0.5)] .01568 .31795 1 -0.38067 Mshowa
.01926 .36808 m
.02541 .3658 L
s
[(1)] .00696 .37264 1 -0.37036 Mshowa
.01027 .42483 m
.01644 .42261 L
s
[(1.5)] -0.00208 .42927 1 -0.35964 Mshowa
.00095 .48363 m
.00715 .48147 L
s
[(2)] -0.01144 .48795 1 -0.3485 Mshowa
.125 Mabswid
.03468 .27078 m
.03835 .26935 L
s
.03301 .2813 m
.03669 .27988 L
s
.03134 .29189 m
.03501 .29047 L
s
.02965 .30255 m
.03332 .30114 L
s
.02623 .32409 m
.02991 .3227 L
s
.02451 .33497 m
.02819 .33359 L
s
.02277 .34593 m
.02646 .34455 L
s
.02102 .35697 m
.02471 .35559 L
s
.01749 .37927 m
.02118 .37791 L
s
.0157 .39054 m
.0194 .38919 L
s
.0139 .40189 m
.0176 .40054 L
s
.01209 .41332 m
.01579 .41198 L
s
.00843 .43642 m
.01214 .4351 L
s
.00658 .4481 m
.01029 .44678 L
s
.00472 .45986 m
.00843 .45855 L
s
.00284 .4717 m
.00656 .4704 L
s
gsave
-0.05457 .39542 -71 -8.05332 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.875 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.875000 moveto
 460.000000 16.875000 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.875000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
69.000000 13.000000 moveto
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.5 Mabswid
.658 .74 .91 r
.38313 .58323 .40512 .60371 .44189 .59268 .42019 .57246 Metetra
.658 .745 .914 r
.42019 .57246 .44189 .59268 .47916 .5815 .45779 .5615 Metetra
.658 .75 .918 r
.45779 .5615 .47916 .5815 .51695 .57017 .49592 .55034 Metetra
.659 .755 .921 r
.49592 .55034 .51695 .57017 .55526 .55867 .53461 .53893 Metetra
.659 .759 .923 r
.53461 .53893 .55526 .55867 .59412 .54701 .57385 .52727 Metetra
.66 .762 .925 r
.57385 .52727 .59412 .54701 .63352 .53519 .61367 .51532 Metetra
.661 .764 .926 r
.61367 .51532 .63352 .53519 .67349 .5232 .65405 .50308 Metetra
.663 .765 .926 r
.65405 .50308 .67349 .5232 .71403 .51104 .69502 .49054 Metetra
.664 .765 .925 r
.69502 .49054 .71403 .51104 .75515 .4987 .73658 .47769 Metetra
.665 .763 .923 r
.73658 .47769 .75515 .4987 .79688 .48619 .77874 .46454 Metetra
.666 .761 .921 r
.77874 .46454 .79688 .48619 .83921 .47349 .82152 .4511 Metetra
.667 .757 .918 r
.82152 .4511 .83921 .47349 .88217 .4606 .86491 .43739 Metetra
.668 .753 .914 r
.86491 .43739 .88217 .4606 .92578 .44752 .90894 .42341 Metetra
.668 .748 .91 r
.90894 .42341 .92578 .44752 .97003 .43424 .95362 .4092 Metetra
.641 .736 .917 r
.36056 .56222 .38313 .58323 .42019 .57246 .39789 .55276 Metetra
.64 .751 .929 r
.39789 .55276 .42019 .57246 .45779 .5615 .43579 .54304 Metetra
.64 .766 .939 r
.43579 .54304 .45779 .5615 .49592 .55034 .47428 .53295 Metetra
.641 .78 .948 r
.47428 .53295 .49592 .55034 .53461 .53893 .51337 .52241 Metetra
.642 .793 .955 r
.51337 .52241 .53461 .53893 .57385 .52727 .55306 .51132 Metetra
.645 .804 .959 r
.55306 .51132 .57385 .52727 .61367 .51532 .59335 .49962 Metetra
.65 .811 .961 r
.59335 .49962 .61367 .51532 .65405 .50308 .63422 .48726 Metetra
.655 .815 .96 r
.63422 .48726 .65405 .50308 .69502 .49054 .67569 .47421 Metetra
.661 .814 .957 r
.67569 .47421 .69502 .49054 .73658 .47769 .71774 .46049 Metetra
.668 .81 .951 r
.71774 .46049 .73658 .47769 .77874 .46454 .76037 .44612 Metetra
.674 .803 .944 r
.76037 .44612 .77874 .46454 .82152 .4511 .80357 .43115 Metetra
.678 .792 .935 r
.80357 .43115 .82152 .4511 .86491 .43739 .84737 .41565 Metetra
.681 .779 .924 r
.84737 .41565 .86491 .43739 .90894 .42341 .89175 .39972 Metetra
.682 .764 .913 r
.89175 .39972 .90894 .42341 .95362 .4092 .93675 .38345 Metetra
.611 .727 .928 r
.33741 .54067 .36056 .56222 .39789 .55276 .37493 .53351 Metetra
.607 .751 .946 r
.37493 .53351 .39789 .55276 .43579 .54304 .41311 .52598 Metetra
.605 .776 .963 r
.41311 .52598 .43579 .54304 .47428 .53295 .45195 .51785 Metetra
.604 .801 .975 r
.45195 .51785 .47428 .53295 .51337 .52241 .49146 .50891 Metetra
.606 .822 .983 r
.49146 .50891 .51337 .52241 .55306 .51132 .53163 .49895 Metetra
.612 .84 .986 r
.53163 .49895 .55306 .51132 .59335 .49962 .57244 .48784 Metetra
.623 .853 .986 r
.57244 .48784 .59335 .49962 .63422 .48726 .61388 .47548 Metetra
.637 .861 .984 r
.61388 .47548 .63422 .48726 .67569 .47421 .65591 .46181 Metetra
.655 .863 .978 r
.65591 .46181 .67569 .47421 .71774 .46049 .69851 .44686 Metetra
.672 .857 .97 r
.69851 .44686 .71774 .46049 .76037 .44612 .74164 .4307 Metetra
.687 .846 .959 r
.74164 .4307 .76037 .44612 .80357 .43115 .7853 .41343 Metetra
.697 .828 .945 r
.7853 .41343 .80357 .43115 .84737 .41565 .82947 .39525 Metetra
.703 .806 .929 r
.82947 .39525 .84737 .41565 .89175 .39972 .87416 .37634 Metetra
.705 .782 .911 r
.87416 .37634 .89175 .39972 .93675 .38345 .91939 .35695 Metetra
.563 .711 .941 r
.31365 .51855 .33741 .54067 .37493 .53351 .35129 .51457 Metetra
.553 .742 .965 r
.35129 .51457 .37493 .53351 .41311 .52598 .38967 .5101 Metetra
.545 .775 .984 r
.38967 .5101 .41311 .52598 .45195 .51785 .42883 .50472 Metetra
.54 .807 .995 r
.42883 .50472 .45195 .51785 .49146 .50891 .46876 .49805 Metetra
.543 .836 .999 r
.46876 .49805 .49146 .50891 .53163 .49895 .50944 .48975 Metetra
.555 .86 .997 r
.50944 .48975 .53163 .49895 .57244 .48784 .55084 .47956 Metetra
.577 .88 .993 r
.55084 .47956 .57244 .48784 .61388 .47548 .5929 .4673 Metetra
.608 .894 .988 r
.5929 .4673 .61388 .47548 .65591 .46181 .63556 .45291 Metetra
.643 .901 .983 r
.63556 .45291 .65591 .46181 .69851 .44686 .67877 .4364 Metetra
.678 .898 .976 r
.67877 .4364 .69851 .44686 .74164 .4307 .72247 .4179 Metetra
.706 .885 .963 r
.72247 .4179 .74164 .4307 .7853 .41343 .76661 .39765 Metetra
.724 .862 .947 r
.76661 .39765 .7853 .41343 .82947 .39525 .81116 .37594 Metetra
.733 .832 .926 r
.81116 .37594 .82947 .39525 .87416 .37634 .85612 .35314 Metetra
.734 .8 .905 r
.85612 .35314 .87416 .37634 .91939 .35695 .90152 .32967 Metetra
.494 .685 .952 r
.28926 .49583 .31365 .51855 .35129 .51457 .32691 .49578 Metetra
.472 .719 .978 r
.32691 .49578 .35129 .51457 .38967 .5101 .36544 .49509 Metetra
.454 .755 .994 r
.36544 .49509 .38967 .5101 .42883 .50472 .40487 .49314 Metetra
.445 .79 .998 r
.40487 .49314 .42883 .50472 .46876 .49805 .4452 .48932 Metetra
.45 .823 .992 r
.4452 .48932 .46876 .49805 .50944 .48975 .4864 .48312 Metetra
.475 .854 .983 r
.4864 .48312 .50944 .48975 .55084 .47956 .52842 .47413 Metetra
.517 .884 .976 r
.52842 .47413 .55084 .47956 .5929 .4673 .57115 .46208 Metetra
.573 .91 .974 r
.57115 .46208 .5929 .4673 .63556 .45291 .61452 .44685 Metetra
.633 .927 .973 r
.61452 .44685 .63556 .45291 .67877 .4364 .6584 .42849 Metetra
.688 .929 .968 r
.6584 .42849 .67877 .4364 .72247 .4179 .70272 .4072 Metetra
.73 .916 .957 r
.70272 .4072 .72247 .4179 .76661 .39765 .74738 .38334 Metetra
.756 .89 .939 r
.74738 .38334 .76661 .39765 .81116 .37594 .79234 .35739 Metetra
.766 .854 .916 r
.79234 .35739 .81116 .37594 .85612 .35314 .83758 .32992 Metetra
.765 .815 .893 r
.83758 .32992 .85612 .35314 .90152 .32967 .88312 .30158 Metetra
.397 .642 .955 r
.2642 .4725 .28926 .49583 .32691 .49578 .30177 .47691 Metetra
.358 .672 .976 r
.30177 .47691 .32691 .49578 .36544 .49509 .34035 .48055 Metetra
.329 .706 .982 r
.34035 .48055 .36544 .49509 .40487 .49314 .37999 .48254 Metetra
.32 .742 .975 r
.37999 .48254 .40487 .49314 .4452 .48932 .42069 .48203 Metetra
.338 .781 .961 r
.42069 .48203 .4452 .48932 .4864 .48312 .46241 .47829 Metetra
.386 .825 .95 r
.46241 .47829 .4864 .48312 .52842 .47413 .50506 .47073 Metetra
.458 .871 .948 r
.50506 .47073 .52842 .47413 .57115 .46208 .54852 .45897 Metetra
.545 .913 .952 r
.54852 .45897 .57115 .46208 .61452 .44685 .59264 .44281 Metetra
.632 .942 .957 r
.59264 .44281 .61452 .44685 .6584 .42849 .63727 .42235 Metetra
.707 .95 .954 r
.63727 .42235 .6584 .42849 .70272 .4072 .68227 .39788 Metetra
.759 .937 .943 r
.68227 .39788 .70272 .4072 .74738 .38334 .72752 .36992 Metetra
.789 .908 .923 r
.72752 .36992 .74738 .38334 .79234 .35739 .77294 .33917 Metetra
.799 .869 .9 r
.77294 .33917 .79234 .35739 .83758 .32992 .81847 .30645 Metetra
.795 .827 .876 r
.81847 .30645 .83758 .32992 .88312 .30158 .86416 .27265 Metetra
.27 .577 .941 r
.23846 .44853 .2642 .4725 .30177 .47691 .27583 .45772 Metetra
.213 .597 .948 r
.27583 .45772 .30177 .47691 .34035 .48055 .31437 .46602 Metetra
.179 .625 .941 r
.31437 .46602 .34035 .48055 .37999 .48254 .35415 .47228 Metetra
.181 .666 .926 r
.35415 .47228 .37999 .48254 .42069 .48203 .39518 .47538 Metetra
.225 .72 .916 r
.39518 .47538 .42069 .48203 .46241 .47829 .43739 .47434 Metetra
.306 .786 .916 r
.43739 .47434 .46241 .47829 .50506 .47073 .48068 .46837 Metetra
.416 .855 .926 r
.48068 .46837 .50506 .47073 .54852 .45897 .52489 .45693 Metetra
.536 .915 .938 r
.52489 .45693 .54852 .45897 .59264 .44281 .56982 .43979 Metetra
.647 .953 .945 r
.56982 .43979 .59264 .44281 .63727 .42235 .61526 .41705 Metetra
.733 .963 .94 r
.61526 .41705 .63727 .42235 .68227 .39788 .66102 .38913 Metetra
.79 .948 .925 r
.66102 .38913 .68227 .39788 .72752 .36992 .70692 .35673 Metetra
.82 .917 .903 r
.70692 .35673 .72752 .36992 .77294 .33917 .75285 .3208 Metetra
.828 .876 .879 r
.75285 .3208 .77294 .33917 .81847 .30645 .79874 .28244 Metetra
.822 .834 .857 r
.79874 .28244 .81847 .30645 .86416 .27265 .84462 .24283 Metetra
.117 .488 .901 r
.212 .42389 .23846 .44853 .27583 .45772 .24908 .43792 Metetra
.051 .495 .889 r
.24908 .43792 .27583 .45772 .31437 .46602 .28749 .45097 Metetra
.025 .523 .874 r
.28749 .45097 .31437 .46602 .35415 .47228 .32733 .46162 Metetra
.05 .577 .866 r
.32733 .46162 .35415 .47228 .39518 .47538 .36861 .46846 Metetra
.128 .656 .873 r
.36861 .46846 .39518 .47538 .43739 .47434 .41128 .47022 Metetra
.25 .751 .895 r
.41128 .47022 .43739 .47434 .48068 .46837 .4552 .4659 Metetra
.399 .846 .921 r
.4552 .4659 .48068 .46837 .52489 .45693 .50017 .4548 Metetra
.549 .92 .939 r
.50017 .4548 .52489 .45693 .56982 .43979 .54595 .43662 Metetra
.675 .96 .941 r
.54595 .43662 .56982 .43979 .61526 .41705 .59226 .41151 Metetra
.765 .967 .928 r
.59226 .41151 .61526 .41705 .66102 .38913 .63885 .37999 Metetra
.819 .948 .906 r
.63885 .37999 .66102 .38913 .70692 .35673 .68548 .343 Metetra
.846 .916 .881 r
.68548 .343 .70692 .35673 .75285 .3208 .732 .30174 Metetra
.852 .877 .857 r
.732 .30174 .75285 .3208 .79874 .28244 .77833 .2576 Metetra
.845 .836 .837 r
.77833 .2576 .79874 .28244 .84462 .24283 .82447 .21208 Metetra
0 .382 .834 r
.18479 .39856 .212 .42389 .24908 .43792 .2215 .41723 Metetra
0 .383 .809 r
.2215 .41723 .24908 .43792 .28749 .45097 .2597 .43488 Metetra
0 .418 .797 r
.2597 .43488 .28749 .45097 .32733 .46162 .29951 .4498 Metetra
0 .492 .81 r
.29951 .4498 .32733 .46162 .36861 .46846 .34099 .46028 Metetra
.059 .601 .847 r
.34099 .46028 .36861 .46846 .41128 .47022 .38406 .46479 Metetra
.223 .729 .897 r
.38406 .46479 .41128 .47022 .4552 .4659 .42859 .46208 Metetra
.409 .847 .938 r
.42859 .46208 .4552 .4659 .50017 .4548 .47432 .45129 Metetra
.581 .927 .953 r
.47432 .45129 .50017 .4548 .54595 .43662 .52097 .43207 Metetra
.711 .962 .943 r
.52097 .43207 .54595 .43662 .59226 .41151 .56819 .40457 Metetra
.796 .961 .917 r
.56819 .40457 .59226 .41151 .63885 .37999 .61567 .36947 Metetra
.843 .939 .887 r
.61567 .36947 .63885 .37999 .68548 .343 .66311 .32793 Metetra
.865 .907 .859 r
.66311 .32793 .68548 .343 .732 .30174 .71032 .28141 Metetra
.87 .871 .836 r
.71032 .28141 .732 .30174 .77833 .2576 .75718 .23162 Metetra
.863 .835 .818 r
.75718 .23162 .77833 .2576 .82447 .21208 .80369 .18035 Metetra
0 .275 .751 r
.1568 .3725 .18479 .39856 .2215 .41723 .19308 .39536 Metetra
0 .278 .725 r
.19308 .39536 .2215 .41723 .2597 .43488 .231 .4172 Metetra
0 .327 .73 r
.231 .4172 .2597 .43488 .29951 .4498 .27072 .43602 Metetra
0 .425 .772 r
.27072 .43602 .29951 .4498 .34099 .46028 .31232 .44985 Metetra
.022 .563 .843 r
.31232 .44985 .34099 .46028 .38406 .46479 .35574 .45689 Metetra
.225 .719 .918 r
.35574 .45689 .38406 .46479 .42859 .46208 .40083 .45564 Metetra
.441 .851 .966 r
.40083 .45564 .42859 .46208 .47432 .45129 .44731 .44509 Metetra
.622 .928 .97 r
.44731 .44509 .47432 .45129 .52097 .43207 .49483 .42482 Metetra
.746 .953 .943 r
.49483 .42482 .52097 .43207 .56819 .40457 .543 .39503 Metetra
.82 .945 .905 r
.543 .39503 .56819 .40457 .61567 .36947 .59142 .35653 Metetra
.86 .922 .869 r
.59142 .35653 .61567 .36947 .66311 .32793 .63975 .31068 Metetra
.878 .893 .839 r
.63975 .31068 .66311 .32793 .71032 .28141 .68774 .25924 Metetra
.881 .862 .817 r
.68774 .25924 .71032 .28141 .75718 .23162 .73524 .20419 Metetra
.875 .832 .801 r
.73524 .20419 .75718 .23162 .80369 .18035 .78223 .14761 Metetra
0 .181 .669 r
.128 .34568 .1568 .3725 .19308 .39536 .16383 .37206 Metetra
0 .195 .654 r
.16383 .37206 .19308 .39536 .231 .4172 .20142 .39742 Metetra
0 .26 .684 r
.20142 .39742 .231 .4172 .27072 .43602 .241 .41954 Metetra
0 .378 .756 r
.241 .41954 .27072 .43602 .31232 .44985 .28266 .4362 Metetra
.017 .542 .857 r
.28266 .4362 .31232 .44985 .35574 .45689 .32638 .44535 Metetra
.252 .715 .948 r
.32638 .44535 .35574 .45689 .40083 .45564 .37198 .4453 Metetra
.483 .848 .99 r
.37198 .4453 .40083 .45564 .44731 .44509 .41917 .43489 Metetra
.659 .915 .978 r
.41917 .43489 .44731 .44509 .49483 .42482 .46754 .41362 Metetra
.771 .93 .937 r
.46754 .41362 .49483 .42482 .543 .39503 .51666 .38173 Metetra
.834 .92 .892 r
.51666 .38173 .543 .39503 .59142 .35653 .56606 .34017 Metetra
.868 .899 .852 r
.56606 .34017 .59142 .35653 .63975 .31068 .61534 .29048 Metetra
.884 .875 .822 r
.61534 .29048 .63975 .31068 .68774 .25924 .6642 .23468 Metetra
.888 .85 .801 r
.6642 .23468 .68774 .25924 .73524 .20419 .71246 .17501 Metetra
.883 .827 .787 r
.71246 .17501 .73524 .20419 .78223 .14761 .76008 .1138 Metetra
0 .112 .602 r
.09834 .31807 .128 .34568 .16383 .37206 .13373 .34707 Metetra
0 .138 .607 r
.13373 .34707 .16383 .37206 .20142 .39742 .171 .37507 Metetra
0 .218 .662 r
.171 .37507 .20142 .39742 .241 .41954 .2104 .39966 Metetra
0 .355 .761 r
.2104 .39966 .241 .41954 .28266 .4362 .25208 .41844 Metetra
.04 .533 .882 r
.25208 .41844 .28266 .4362 .32638 .44535 .29604 .42915 Metetra
.295 .709 .974 r
.29604 .42915 .32638 .44535 .37198 .4453 .34209 .42993 Metetra
.524 .831 1 r
.34209 .42993 .37198 .4453 .41917 .43489 .38994 .4195 Metetra
.685 .885 .972 r
.38994 .4195 .41917 .43489 .46754 .41362 .43914 .3973 Metetra
.783 .896 .924 r
.43914 .3973 .46754 .41362 .51666 .38173 .4892 .36361 Metetra
.839 .888 .876 r
.4892 .36361 .51666 .38173 .56606 .34017 .53959 .31947 Metetra
.869 .872 .837 r
.53959 .31947 .56606 .34017 .61534 .29048 .58987 .26661 Metetra
.884 .855 .808 r
.58987 .26661 .61534 .29048 .6642 .23468 .63968 .20724 Metetra
.89 .838 .788 r
.63968 .20724 .6642 .23468 .71246 .17501 .6888 .14382 Metetra
.888 .821 .776 r
.6888 .14382 .71246 .17501 .76008 .1138 .73719 .07886 Metetra
0 .07 .56 r
.0678 .28963 .09834 .31807 .13373 .34707 .10281 .32019 Metetra
0 .109 .586 r
.10281 .32019 .13373 .34707 .171 .37507 .13977 .34977 Metetra
0 .202 .664 r
.13977 .34977 .171 .37507 .2104 .39966 .179 .37584 Metetra
0 .351 .782 r
.179 .37584 .2104 .39966 .25208 .41844 .22069 .39585 Metetra
.087 .532 .906 r
.22069 .39585 .25208 .41844 .29604 .42915 .26484 .40742 Metetra
.344 .696 .982 r
.26484 .40742 .29604 .42915 .34209 .42993 .31129 .40856 Metetra
.555 .799 .99 r
.31129 .40856 .34209 .42993 .38994 .4195 .35974 .39791 Metetra
.698 .844 .953 r
.35974 .39791 .38994 .4195 .43914 .3973 .4097 .37488 Metetra
.784 .856 .904 r
.4097 .37488 .43914 .3973 .4892 .36361 .46066 .33977 Metetra
.835 .853 .86 r
.46066 .33977 .4892 .36361 .53959 .31947 .51204 .29369 Metetra
.864 .845 .824 r
.51204 .29369 .53959 .31947 .58987 .26661 .56334 .23849 Metetra
.88 .834 .797 r
.56334 .23849 .58987 .26661 .63968 .20724 .61416 .17651 Metetra
.888 .824 .779 r
.61416 .17651 .63968 .20724 .6888 .14382 .66425 .11038 Metetra
.889 .814 .769 r
.66425 .11038 .6888 .14382 .73719 .07886 .71353 .04274 Metetra
0 .057 .546 r
.03634 .26033 .0678 .28963 .10281 .32019 .07105 .29127 Metetra
0 .106 .592 r
.07105 .29127 .10281 .32019 .13977 .34977 .10779 .32124 Metetra
0 .21 .687 r
.10779 .32124 .13977 .34977 .179 .37584 .1469 .34765 Metetra
0 .364 .812 r
.1469 .34765 .179 .37584 .22069 .39585 .18859 .3679 Metetra
.149 .535 .922 r
.18859 .3679 .22069 .39585 .26484 .40742 .23291 .37953 Metetra
.39 .675 .973 r
.23291 .37953 .26484 .40742 .31129 .40856 .27971 .38051 Metetra
.576 .76 .965 r
.27971 .38051 .31129 .40856 .35974 .39791 .32868 .36942 Metetra
.699 .8 .927 r
.32868 .36942 .35974 .39791 .4097 .37488 .37934 .34567 Metetra
.776 .815 .883 r
.37934 .34567 .4097 .37488 .46066 .33977 .43112 .30957 Metetra
.824 .818 .844 r
.43112 .30957 .46066 .33977 .51204 .29369 .48345 .26226 Metetra
.854 .817 .812 r
.48345 .26226 .51204 .29369 .56334 .23849 .53576 .20567 Metetra
.872 .814 .789 r
.53576 .20567 .56334 .23849 .61416 .17651 .58762 .1422 Metetra
.883 .811 .773 r
.58762 .1422 .61416 .17651 .66425 .11038 .63876 .07454 Metetra
.887 .808 .765 r
.63876 .07454 .66425 .11038 .71353 .04274 .68905 .00539 Metetra
0 g
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
[(0)] .02757 .24618 1 .93395 Mshowa
.22768 .18054 m
.23217 .18532 L
s
[(1)] .2187 .17096 .938 1 Mshowa
.43326 .10004 m
.43737 .10515 L
s
[(2)] .42503 .08982 .80527 1 Mshowa
.65575 .01292 m
.65941 .01836 L
s
[(3)] .64842 .00203 .67254 1 Mshowa
.125 Mabswid
.07414 .24066 m
.07698 .24338 L
s
.11167 .22596 m
.11448 .22872 L
s
.14976 .21105 m
.15253 .21384 L
s
.18843 .19591 m
.19116 .19874 L
s
.26753 .16493 m
.27019 .16784 L
s
.30801 .14908 m
.31061 .15203 L
s
.34911 .13299 m
.35167 .13598 L
s
.39085 .11664 m
.39337 .11967 L
s
.47634 .08317 m
.47875 .08628 L
s
.52011 .06603 m
.52247 .06918 L
s
.56459 .04861 m
.5669 .0518 L
s
.60979 .03091 m
.61205 .03414 L
s
gsave
.29165 .07573 -70.3112 -16.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.875 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.875000 moveto
 460.000000 16.875000 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.875000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(u) show
69.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[29]:=",
  ImageSize->{288, 111.188},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000Ka000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol005aoo`8008eo
o`8003=oo`00GWoo00<007ooOol0S7oo00<007ooOol0<7oo001MOol00`00Oomoo`2<Ool00`00Oomo
o`0aOol005ioo`03001oogoo00Ioo`03001oogoo08=oo`03001oogoo00Ioo`03001oogoo02Moo`00
G7oo00<007oo00001goo00<007oo0000PWoo00<007oo00001goo00<007oo0000:7oo001MOol00`00
Oomoo`06Ool00`00Ool00023Ool00`00Oomoo`06Ool00`00Ool0000XOol006Ioo`03001oo`0008ao
o`03001oo`0002Qoo`00IWoo00<007oo0000S7oo00<007oo0000:7oo000dOol3000/Ool20002Ool0
0`00Oomoo`1HOol3000/Ool20003Ool00`00Oomoo`0WOol003=oo`04001oogoo000YOol6001KOol0
1000Oomoo`00:Woo1@00;7oo000cOol01000Oomoo`003Goo0`005goo10000UKl0P00Fgoo00@007oo
Ool000eoo`<001Moo`@00004Ool00000000/Ool0039oo`800003Ool0000000eoo`03001oogoo01Ao
o`D000AFo003001Fo00005Uoo`800003Ool0000000eoo`03001oogoo01Eoo`8000Aoo`05001c>000
LcP0000[Ool004Eoo`03001oogoo015oo`@0009Fo003001Fo5Kl009Fo004001Fo000001[Ool00`00
Oomoo`0AOol40004Ool01@00LcQc>000LcP00P00:Woo0015Ool00`00Oomoo`0>Ool50004E_`00`00
E_aFo002E_`01000E_`00000Jgoo00<007ooOol03goo0P0027oo00@007<hLcP0009c>003001oogoo
02Qoo`00A7oo00<007oo00003Goo10000UKL00<005KlE_`00eKl00<005KlE_`00`000UKl00<007oo
Ool0Igoo00<007oo00003Goo100027oo00T007<hLcQc>000LcP007=H0000:Goo0015Ool00`00Oomo
o`09Ool40005E]`00`00E_aFo003E_`300000eKl001Fo002E_`2001YOol00`00Oomoo`0:Ool2000<
Ool00`00LcQc>002LcP200000g=H0000000XOol004moo`<0009B^`03001Fg5KL00AFg003001Fo5Kl
0080009Fo003001Fo00000AFo003001oogoo075oo`<000eoo`03001c>7<h00=c>005001cF7=HLeP0
000XOol004aoo`@000AB^`03001Fg5KL00AFg0<000AFo003001Fo000009Fo0800003E_`007oo06mo
o`8000moo`03001c>00000=c>080009cF003001cF00002Moo`00;7oo1@006Goo0`000U:J00<005:k
D[/00e:k00<005KLE]`00`0000=Fg000E_`01EKl10000eKl0P00CWoo1@006Goo0`0047oo00@007<h
LcP0009c>003001cF000009cF004001cF000000VOol002ioo`03001oogoo01Ioo`@000ABVP03001B
^e:k00AB^`8000EFg003001Fo5Kl00=Fo08000IFo003001oogoo04ioo`03001oogoo01Moo`80019o
o`03001c>7<h009c>007001c>000LeP007=H00000g=H00<007ooOol097oo000^Ool00`00Oomoo`0D
Ool30002DYX00`00DYYBVP03DYX01000D[]B^e:k0P0000=Ff`00E]`015KL00<005KlE_`00`0000=J
o00000001EKl0P000goo1@00Agoo00<007ooOol057oo0`0057oo00<007<hLcP00g<h00<007=HLeP0
0P001G=H00<007ooOol00Woo1@0077oo000^Ool00`00Oomoo`0AOol40004DYX00`00DYYBVP03DYX0
1000D[/000000eKK00<005KLE]`015KL0P0015[l0P000UKl0`0000=Fo000Ool017oo00<007ooOol0
Agoo00<007ooOol04Woo0P005Woo00<007<hLcP00g<h00D007=H001cF00000EcF0<000Eoo`03001o
ogoo01aoo`00;Woo00<007ooOol03Woo100000=BN@00DYX01E:J00<005:JDYX00U:J0P001UKK00@0
05KLE]aFg0800003F_/005[l00AJo0<000EFo003001oogoo009oo`03001oogoo04Moo`03001oogoo
00ioo`@001Moo`03001c>7<h00=c>006001cF7=H001cF0001G=H00<007=I00001Goo00<007ooOol0
77oo000]Ool2000>Ool30005DWT00`00DYYBVP03DYX00`00DYYBVP020002E[X00`00E]]Ff`03E]/0
1000E]`000000e[k00<005[lF_`00U[l0P0000=Jo000E_`015Kl0P000goo00<007ooOol0AWoo0P00
3goo0`0067oo00<007<hLcP00g<h00<007=HLeP00W=H0P0017=H00<007=ILeT00P0017oo00<007oo
Ool077oo000kOol200000e9I001BN@05DWT00`00DYYBVP04DYX20004E[X00`00E]]Ff`03E]/20006
F_/02000F_`00000F_`005[l0005E_`20003Ool00`00Oomoo`1DOol3000JOol00`00KeT00004LcP0
1`00LeQcF7=H001cF@0000=cF003001cFG=I009cF@8000=oo`03001oogoo01aoo`00>7oo0`00159I
00<0059iDWT00e9i00<005:JDYX00U:J0`001UJj00<005KKE]/00P000U[K00<005[kF_/015[k00D0
05[lF_aJo000009Jo003001Fo5Kl0080009Fo004001oo`00001DOol2000MOol00`00KeT00003LcP0
0`00LeQcF002LeP00`00LeT00002LeP00`00LeUcF@02LeT00`00KeT00002Ool2000NOol003Ioo`@0
00EBF@03001BNE9i00ABN@04001BVP000003EYX00`00E[YF^P04E[X20004F]/00`00F_]Jn`02F_/3
0003F_`01000F_aJo5[l0P0015Kl0P00Dgoo0`007Woo00L006mIKeU_F@00LcP00004LeP00`00LeUc
F@0200000g=H001cF@02LeT01@00KeU_FFmI00008Goo000IOol00`00Oomoo`0FOol50003CUP00`00
DUUBF@03DUT00`00DWUBN@02DWT30005EYX00`00E[YF^P02E[X30006F]/01000F_/000000e[k00D0
05[lF_`005[l00<000IFo003001oogoo00ioo`8002Eoo`03001oogoo01Eoo`04001oo`00000POol0
0`00KeU_F@03KeT00`00LeQcF002LeP01`00LeUcFG=I001cF@0000=cF@03001_FFmI00=_F@03001o
ogoo00eoo`8000moo`0067oo00<007oo00005Woo0`0000=>>000CUP00diH00<0059IDUT00e9I00<0
059iDWT00P000UIi00<005JJEYX015JJ00@005Jj000000=JfP03001Jfe[K00AJf`03001Jne[k00=J
n`03001Jo5[l008000=Jo004001Fo5KlE_`200000eKl001oo`0>Ool2000TOol00`00Ool0000EOol3
000QOol00`00KeU_F@03KeT00`00LeT00002LeP00`00LeUcF@03LeT00`00LgT00002LeT00`00KeU_
F@02KeT2000?Ool2000?Ool001Qoo`03001oo`0001=oo`@000A>>003001>F4iH009>F003001BFE9I
00=BF@8000AFN@03001FVUJJ00AFVP8000EJfP03001Jfe[K009Jf`<000IJn`<000AJo004001Fo000
0003E_`2000=Ool01000Oomoo`008goo00<007oo00004Woo0`0097oo00<006mIKeT00fmI00H007=I
LeT007=H0004LeT2000017=i001cF@0016mI00@006mJKeX000eoo`04001oogoo000>Ool001Qoo`03
001oo`00011oo`@00003CSL004hh00A>>003001>F4iH009>F004001BFE9IDUT30006EWT01000EYYF
VUJJ0P0000=J^P00F]X01E[J00@005[K000000=Nn`04001Jne[kF_/200000ekk00000004F_`20006
E_`00`00Oomoo`0:Ool20002Ool00`00Oomoo`0QOol00`00Ool0000@Ool3000UOol00`00KeU_F@03
KeT00`00LeUcF@02LeT00`00LeUcF@02LeT00`00LgT00002LgT00`00KeU_F@02KeT01000KeY_FVmJ
0P002goo0P000Woo00<007ooOol037oo000HOol00`00Ool0000>Ool40004CSL00`00CSQ>>002CSP0
0`00CUQ>F003CUP30003EWP00`00EWUFN@03EWT01000EYX000000eZj00<005[JF]X015[J0P001Ekk
00@005[k000000ANn`03001Jo5[l0080009K7003001Fo5Kl00=Fo08003=oo`03001oo`0000ioo`80
02Moo`03001_F@0000=_F@03001cFG=I009cF@03001cN@0000=cF@07001cN@00LgT007=j00000fmI
00<006mJKeX00VmJ00<007ooOol077oo000IOol00`00Oomoo`09Ool500000dhG001>=`04CSL00`00
CSQ>>002CSP00`00CUQ>F002CUP20005EWP00`00EWUFN@04EWT00`00F[YJ^P04F[X01000F]YJfU[J
0P0000=NfP00G_/01Ekk00<005kkG_/015kk0`0015/L00<005KlE_`00`000UKl00<007ooOol0<Goo
00<007ooOol02Goo1000:7oo00@006mIKeT0009_F@03001cFG=I00=cF@06001cNG=i001cF@000W=i
0P000g=j00<006mI000016mJ00<006mJ00007Goo000TOol40004CQL00`00CSM>=`03CSL00`00CSQ>
>002CSP01P00CUP00000DUP000IFN004001FNEIiEWT200000eZI001J^P04F[X01000F]X000000ekJ
00<005kkG_/00Ukk0P0000=Nn`00G_/00ekk0`001U/L0P001EKl00<007ooOol0?7oo0P00:Woo00<0
06mIKeT00VmI00<006mI000017=I00<007=iLgT00W=i00D007=iLgUcN@0000EcNP03001_FVmJ009_
FP03001_FVmJ008001aoo`008Goo100000=>5`00CQL014hG00<004hgCSL00dhg00<004hhCSP00Thh
0P00159H00<005IhEWP00eIh00@005Ii000000=JV@03001J^UZj00AJ^P03001NfUkJ00ANfP04001N
n`000004G_/00`00G_/0000300000elK001K7002Fa`200000elL001Fo004E_`2000jOol3000[Ool0
0`00KeU_F@04KeT00`00LeUcF@02LeT00`00LgUcN@02LgT01000LgX007=i0P0017=j00<006mj0000
0VmJ00<006mJKeX00VmJ0P006goo000OOol200000dhG001>5`03CQL00`00CQM>5`02CQL00`00CSM>
=`04CSL00`00CSP000020005DUP00`00EWQFN004EWP00`00FYUJV@04FYT01000F[YJ^UZj0P0000=N
fP00G]X01EkJ00<005kkG_/01Ekk0`000UlK0P0000=K7000000015lL00<005KlE_`00P000ULL00<0
07ooOol00Woo0`00<7oo0P00;Goo00<006mIKeT016mI00<006mj00000W=I00<007=iLgT00W=i00<0
07=j00000`0000EcNP00LgYcNP00009_NP03001_FP0000A_FP03001[F`0000Aoo`<001Aoo`007Goo
0P000dhG00<004hGCQL00ThG00<004hGCQL00dhG00<004hgCSL00dhg0P000e9H00<0059HDUP00e9H
00@005IhEWQFN0<000IJV@04001J^P000003G]X00`00G]YNfP02G]X200000f;j001Nn`02G_/40004
Ga/00`00Ga/00007Ga`20004Ea`00`00Oomoo`02Ool00`00Oomoo`0^Ool2000^Ool00`00KeU_F@04
KeT01`00KgY_NVmj001cF@0000=cN@<0009cNP06001cNW=j001cNP0016mj00@006mJKeY_FP80009[
F`8000=oo`03001oogoo01Aoo`006Goo00D007ooOomoo`0000E>5`05001>5dhGCQL00005CQL01000
CSM>=dhg0`00159H00<0059HDUP00e9H00@005Ih000000=JV003001JVEZI00AJV@03001NfUkJ00AN
fP04001NfP000003H_X00`00G_/000030002Ha/01000Ga]O6elK0P0000=O6`00Ga`00elL0P0000=O
7000Ea`00eLL0P0017oo00<007ooOol0:7oo00@007ooOomoo`<002eoo`03001[F`0000A_F@03001_
NVmj00=_NP03001cNG=i008000AcNP06001cVP00001cNP0016mj00D006nK001_FP0000E[F`8000=o
o`03001oogoo01=oo`0067oo00<007oo00000Woo0P0014hG00<004hGCQL00ThG00<004hGCQL00dhG
0`000U8g00<0059HDUP00e9H00<0059HDUP00e9H00<005ZHFYP00eZH00<005ZIFYT00eZI00<005ji
00001UkJ00<006;jH_X00V;j0`0000=Nn`00Ha/00f<K00@005lK0000009O6`04001O6`00Ga`20003
Ga`00`00EaaG700200000eLL00000003Ool00`00Oomoo`0WOol00`00Ool00002Ool200000goo001o
o`0ZOol01000Je][F`000fmI00<006mjKgX00fmj1@0017=j00<007>JLiX00W>J00<006mj00000Vmj
00D006nKKi]_V`0000E[F`<000=oo`03001oogoo01=oo`0067oo00<007oo00000Woo0P0014hG00<0
04hGCQL00ThG00<004hGCQL00ThG0P001E8g00<0059HDUP00U9H00@0059HDUQBF0<000IJV003001J
VEZI0080009N^@03001NfUkJ00=NfP03001RfP0000<000=RnP03001S6f<K00AS6`03001O6elK00=O
6`03001O6`0000IO708000AG7006001oogoo001oo`00:7oo00<007oo00000Woo0P000Woo00<007oo
Ool09Woo0P0016]K00<006mI000016mj0`000Vmj00<007=jLgX00W=j00<007>JLiX00W>J00@006nk
001_NP8000=_V`03001[W000009[F`80009WG0800004Ool007oo000DOol001Qoo`04001oo`00Ool3
0004CQL00`00CQM>5`03CQL01P00CQL00000DSL000EB=`03001BF59H00=BF0<000=FN003001JV5ZH
00=JV003001JV@0000EN^@03001NfUkJ00D000ARnP800003H_X006<K009S6`800003Ha/005lK00=O
6`800003Ha/005lL009O70800003Ga`005LL00=G7080009oo`03001oogoo02Moo`03001oo`00009o
o`03001oogoo009oo`03001oogoo02Aoo`03001[Ff]K00E[F`03001_NVmj00@000=_NP03001_V`00
00=cNP05001cVW>JLiX00002Kk/00`00KgX00003Ki/01P00Jia[W000Je/000AWG0<00003Ool007oo
01Aoo`0067oo00@007oo001oo`800003Ool004hG00=>5`04001>5dhGCQL30004DSL00`00DSMB=`02
DSL00`00DUQBF003DUP00`00EWQFN003EWP00`00FYQJV004FYP00`00G[UN^@04G[T00`00G]X00002
0003H]X01000H_X000000f;j00@006<K000000AS6`09001O6`00001S6`00Ha/005lL008000=O7004
001G75LLEa`4000[Ool00`00Ool00002Ool00`00Oomoo`03Ool00`00Oomoo`0ROol00`00Je][F`05
Je/400000fmj001_NP03KgX01`00Ki]_VfnK001cNP00009cVP8000A_^`05001_V`00Ki/00004Ji`0
0`00IeaWG004Ie`2000GOol001Uoo`03001oogoo00800003Ool004hG00=>5`06001>5`00001>=`00
1E8g00<0058gDSL00U8g00@0059HDUQBF0<000IFN004001JV5ZHFYP200000eZI001N^@04G[T20007
H]X00`00H_YRnP04H_X00`00Ha]S6`05Ha/00`00Ha]S6`02Ha/00`00Ha/00006Ga`30003Ea`00`00
Oomoo`0ZOol01@00Oomoogoo00001Woo0P008Goo00<006=L00001F]K0P000f]k00<006mjKgX00Vmj
00<006nKKi/00fnK00@007>JLiX000E_^`05001__000Ki/00004Ji`00`00Ig`00003Ie`200000f=L
0000000FOol000ioo`03001oogoo009oo`03001oogoo009oo`04001oogooOol20002Ool00`00CQM>
5`030004CSL00`00DSMB=`03DSL00`00DSMB=`02DSL30003EUP00`00EWQFN003EWP01000FYP00000
0eZI00<005jiG[T0100000=Rf@00H]X016;J0P001F;j00<006LJ000016<K0P0000=S>`00Ha/00V<K
0P0000=S?000Ga`00UlL0P0000=K7000Ea`00eLL0P0087oo00<007ooOol00Woo00<007ooOol00Woo
00<007ooOol00Woo00<007ooOol01Goo0P007Woo0P000f=L00<006]K00000P0016]k00<006^L0000
0fmj00<006nKKi/00VnK00@006nk000000A_^`8000=__080009[W080009WO004001WG0000003He`0
0`00Ool0000EOol000eoo`03001oo`0000Moo`03001oo`00009oo`04001oogooOol300000dhg001>
=`04CSL00`00DSMB=`03DSL00`00DSMB=`02DSL00`00EUQFF003EUP00`00EWQFN004EWP00`00FYUJ
V@03FYT300000eji00000002H]T01000H]YRfV;J0P000V;j00<006;jH_X00P000fLJ00@006<K0000
00=S>`09001S6`00001S?000Hc`005lL008000=K7004001G75LLEa`3000OOol00`00Ool00007Ool0
0`00Ool00002Ool20008Ool2000LOol00`00HeaSG002He`300000f]K001[N`03Jg/01`00Jia[W6^L
001_NP0000=_V`80009_^`06001[g000001_^`0016nl00<006^l00000P001FMl00<006=LHe`00f=L
0`005Goo000=Ool00`00Ool00009Ool01000Oomoo`000goo00<004hgCSL00Thg00<004hgCSL00dhg
00<0058gDSL00e8g00<0058g00000P001UIH00@005IhEWQFN0<0009JV@<00004FYT005ji0005H]T0
0`00H]X00004H_X00`00H_X00006IaX00`00Hc]S>`04Hc/00`00HcaS?002Hc`00`00Hc`00006Fa`3
0003Ea`00`00Oomoo`0LOol00`00Ool00009Ool00`00Oomoo`020009Ool3000IOol00`00HeaSG003
0003He`00`00Jg][N`02Jg/00`00Jia[W003Ji`20002Ki/01@00Kk]_^fnk000016_L00@006nlKka_
_08000=[_08000=WO0800004Hgd006=LHe`20002Gc`2000DOol000eoo`03001oo`0000Moo`80009o
o`8000Aoo`05001>=dhgCSL00005CSL00`00DSMB=`02DSL30003EUP00`00EUQFF003EUP01000EWP0
00000UZH0`001EZI00<006;IH]T01F;I00<006;jH_X016;j00<006LJIaX016LJ00<006Lk00000f<k
0P0000=S>`00Hc`00V<l0P0000=O?000Fa`00U/L0P0000=K7000Ea`00eLL0P007Goo00<007oo0000
1goo0P000goo00<007ooOol02Woo0P005Woo1@0016=L0P0000EWO000001[N`0000E[W003001[_6^l
008000=_^`03001[g6_L009[g005001[g000Kk`00003Jk`200000fNm000000020004Hgd20004Gc`0
0`00Ool0000COol000eoo`03001oo`0000Moo`04001oogooOol20004Ool01@00CSM>=dhg00001Thg
00H0058g0000059G0004EUP00`00EUQFF004EUP00`00FYQJV00200000eZH001JV@04FYT00`00G[T0
0005H]T20005H_X00`00IaX00003IaX20002Ic/01000Hc/000000f<k00@006<l0000009O?0800003
Fa`0000000=K7004001G75LLEa`3000MOol00`00Ool00007Ool00`00Oomoo`02Ool00`00Oomoo`0;
Ool3000BOol40002Fcd00`00HeaSG0020005Ig`00`00Jia[W002Ji`20003Jk`01@00Jm`006nk0000
0f_L0P000f_L00<006^lJk`00P0016Nm00<006=mHgd00V=m0P0000=OG@00Gc`00ell0`004goo000>
Ool00`00Oomoo`04Ool500000goo001oo`04Ool00`00CSM>=`02CSL00`00CSM>=`03CSL20004DUL0
0`00EUQFF002EUP01000EUQFF5IH1@0015ZH00<005ZIFYT00P000Uji00@006;IH]URf@80009RnP03
001RnV;j008000=W6P03001W6P0000EW>`03001S>f<k00AS>`03001O?5ll009O?0<000EK70@000=G
7@03001oogoo00=oo`8001Ioo`03001oogoo00Aoo`D0009oo`03001oogoo00aoo`H000Yoo`H000EK
?@8000EWO0800005Iid00000Ji`00004Jk`01000Jma[g6_L0P000V_L00@006_LJma[g0800004Imd0
00000003Ikd200000f>N001SO@020003Ged00`00GcaO?0020002Fcd20004Ool2000<Ool001Moo`04
001oogooOol20005Ool01@00CSM>=dhg00000dhg0`001E9G00<005IHEUP00UIH00<005IH00000`00
00=JN000FYP015ZH00<005ZI00001Eji00<006;I000016;j00<006;j00001VLJ00<006LkIc/00fLk
00<006MK00000f<k0P0000ASG000GcaO?0<00004Gc`005/LFa`20002Fad00`00EaeG7@02Ead20006
Ool00`00Oomoo`0LOol00`00Oomoo`02Ool00`00Oomoo`0=Ool400000a8m0000000<0005Fcd20000
0e]n001WO003Ig`00`00IieWW@03Iid01000Jka[_6^l0P000f_L00<006OMImd00P000V_L0P000fOM
00<006>nHkh00`0016>N00<005mMGed00emM0`0015/m0`001Goo00<007ooOol02Goo000GOol01@00
Oomoogoo00001Woo00<004hgCSL00Thg0`000e8g00<0059GDUL00U9G00<005IHEUP00UIH0`0015Yh
00<005ZHFYP015ZH00<005jiG[T01Eji00<006;jH_X016;j00<006LJIaX016LJ00<006Lk00000VLk
0P000VMK00@006<k000000ASG08000=O?004001O?0000004Fad00`00EaeG7@0200000eKm00000004
Ool00`00Oomoo`0MOol01000Oomoogoo0P0047oo1@000Q8m00@003:o<[lb_`<000A;7P800003Fcd0
000000AKOP04001WO0000004Iid2000016>m001[_0000f_L0P000VOM0P0000ASg@000000009Wg@80
009S_P800004Gkh006>NHih40002Ged20002Fcd00`00FceK?@020002Ead00`00Oomoo`02Ool00`00
Oomoo`0:Ool001Moo`05001oogooOol00007Ool00`00CSM>=`020005DSL00`00DUMBE`02DUL00`00
EUP000040006FWP01000FYQJV5ZH0P0000=N^@00G[T015ji00<006;i000016;j00<006LJ00000fLJ
0P000VLk00<006Lk00001FMK00<006=LHe`00f=L00<006=L00000ell0P0000=O?@00Fad00e/M0`00
15Km00<007ooOol00goo00<007ooOol077oo00@007ooOomoo`80015oo`H000044Sd000000002<[l0
0`00Bai;7P02Bah30006Fgh20005Iid00`00HkeS_@02Hkd20002Jm`00`00ImeWg@020002Hmd20002
Gmh20002Hkh20003Gkh30003Ggh30004Fcd30004Ead20004Ool00`00Oomoo`09Ool001Moo`03001o
ogoo008000Moo`<00003CSL0058g00AB=`04001BEe9GDUL50003EWP00`00FWQJN003FWP01000FYP0
00000eji00@005jiG[UN^@80009Rn@05001RnV;jH_X00003IaX00`00IaX00005Ic/00`00Ie]WF`03
Ie/01@00Ie`00000He`00P000V=L00P005ll000005lm001O?@000U/M0P000U/M00<005KmE_d00UKm
0P000Woo00<007oo00007Woo00D007ooOomoo`0001=ooa0000=7?`80009KOP80009GW`800003Iid0
000000=S_@80009OgPD0009Sg@8000=OgP800003Fmh0000000=O_P80009KWP03001OOUmn00@0009K
?@80009G7@03001G7ELM009G7@<00004Ool007oo000;Ool001Ioo`80009oo`8000Moo`03001>=dhg
009>=`03001B=e8g00=B=`<0009BE`03001FN5Ih00=FN003001JN5Yh00AJN003001N^Eji00AN^@03
001N^@0000ERn@03001RnP0000EW6P03001W>fLk00=W>`05001[F`00001WF`020004Ie`00`00HeaS
G003He`00`00GceO?@02Gcd40004Fad00`00E_eFo@0200000eKm001oo`02Ool00`00Oomoo`0LOol2
0003Ool00`00Oomoo`0BOol90003;]l20004Acl40005Eil30002Hkd20003Gmh2000015_N000005ON
0`000UoN0P0000=KgP0000000U^n0`0015^N0`000e]N0`0015LM00<005LMEad00P000UKm00@007oo
Ool000aoo`006Woo0P001goo00<004hgCSL00Thg00@0058gDSMB=`<000=BE`8000IFN003001JN5Yh
009JN003001NV@0000IN^@03001RnF;i00ERn@03001W6VLJ00=W6P03001[>`00009W>`8000A[F`03
001WG6ML009WG0800004Ig`006=LHe`2000015mM001O?Elm0`0000=K?@00Fad00U/M100015Km00<0
07ooOol097oo00<007ooOol03goo0`0000=oo`0000003`000d=O0P000UNO0P000eNo0`000UoN0P00
00AKgP00001GgP8000=CgPD0009K_P80009GW`03001KWU^N0080009GOP03001KGU]N00800003Ecd0
05LM009G7@@000AFo@8000ioo`002Woo1@000Woo00<007ooOol00Woo00@007ooOomoo`8000Qoo`03
001>=dhg009>=`<000=B=`<0009FF003001FN5Ih00=FN003001JN5Yh0080009NV@03001N^Eji00=N
^@03001Rf@0000ERn@03001W6P00009W6P80009[>`03001W>`0000E[F`04001[O000Ie`20004Ig`2
0004Ged20002Fcd00`00Fcd000030003Ead01000E_eFoEKm0P005Goo1@000Woo00<007ooOol00Woo
00<007ooOol00Woo00<007ooOol037oo0`001Goo2`000bKO0P000d=O10000eNo0P000dno20000e?N
10000U>o0`000eNO10000eMn10000ULm00<005Lm00000P000eLM00@005KmE_eFo@<000ioo`0037oo
00<007ooOol01Woo00<007oo00000Woo00<007ooOol01goo00<004hg00000`00158g0P0015IH00<0
05IhEWP015Ih0P001EjI00<005jiG[T00P000V;I00@006;iH_URn@80009W6P03001W6P0000E[>`03
001[Ff]K009[F`8000=[O003001WO6Ml009WO0800004Hid005mMGed2000015mM001K?E/m0P000ULm
00<005LMEad00ULM100000=oo`00Ool05Woo00<007ooOol01Woo00<007oo00000Woo0P002goo0`00
2Goo4P000cmo10000dno0P0000=;_P0000000P000dNn1@000U>o0P000U>O10000eMo10000eLn00<0
05LmEcd00P0000=G7@00Ead00eLM10000Woo00<007ooOol037oo000<Ool00`00Oomoo`08Ool01000
Oomoo`0027oo0`0014hg00H0058g0000059H0005EUP00`00EWQFN003EWP00`00GYUNV@04GYT00`00
G[T00005H]T00`00H_T00005IaX00`00Jc][>`03Jc/01P00Jg/00000Je/000A[O004001WW@00Ig`2
0003Hid30004Ged20002Ecd00`00Ecd00002Ead20005Ool00`00Oomoo`0EOol00`00Oomoo`08Ool0
1@00Oomoogoo000027oo0`003Goo00<0029N00004@000c]n2@000dNn10000T^o0`000e>O0P0000AC
O`00EgmGO`80009G?P04001G?ULnEch4000015LM001G7@000ULM0P001Woo00<007ooOol037oo000<
Ool00`00Oomoo`06Ool20002Ool20006Ool200000goo001>=`03CSL30004DUP00`00EUQFF002EUP0
1000EWQFN5Ih0P0000=JV@00GYT01EjI00<006;IH]T01F;I00<006LJIaX00fLJ00<006/k00000f/k
00<006]kJg/00V]k00@006]lJga[O08000=WW@04001SWF>MHid20002Gih00`00GeeOG@0200000e]N
001G?@02Ecd40008Ool00`00Oomoo`0DOol00`00Oomoo`06Ool20003Ool20006Ool2000AOol01000
8UhRGR9N5@000S=m0P0000<gO@00000020000TnO10000e=o0`0015Ln10000ULM00@005LMEaeG7@@0
00Qoo`03001oogoo00aoo`0037oo00<007ooOol01Woo00@007ooOomoo`8000=oo`<000Aoo`06001>
=`00001BF0001E9H00<005IHEUP00eIH0`000eZI00<005jIGYT00ejI00<005kI00001F;I0P0016LJ
00L006/kJc][>`00Jc/00004Jg/01@00Ji`006]l00000fNM0P0000AS_@00000000AOWP<000AKGP@0
00]oo`03001oogoo01Aoo`03001oogoo00Ioo`03001oogoo009oo`03001oogoo009oo`<001Aoo`80
00038Uh001Yn008JOQT00003@il00000009;W`@000=CO`@0009GGP03001G?ULn0080009G7@03001G
7ELM009G7@<00003Ool007oo00Yoo`03001oogoo00]oo`002goo0P0027oo0`0000=oo`0000000`00
1goo0P00159H00<0059HDUP00e9H00<005IHEUP00UIH00<005ZIFYT015ZI00<005jIGYT00P000UkI
00@006;IH]URf@80009W6P04001W6VLJ0005Jc/01000Jg][Nf]k0P000f^L00<006NMIid00P000f>m
00<005nn00000UnN0P000UNO00<005]NFeh00P0017oo00<007ooOol027oo00<007ooOol04goo0P00
27oo0`000Woo00<007oo00000P0067oo6P000cmo0`000d^O0P0000A?O`00DgmCO`80009CGP04001G
GUMNEeh30004Ead00`00EaeG7@020004Ool00`00Oomoo`09Ool00`00Oomoo`0;Ool001Aoo`<0009o
o`8000Yoo`03001BF59H00=BF003001BF59H00=BF003001FF5IH00800003FYT005ZI00AJV@03001N
V@0000ENf@03001Rf@0000AW6P03001W6P0000E[>`05001[N`00Jg/00004Ji`00`00Ikd000020002
Hkd20003Gkh20003Eil40007Ool00`00Oomoo`07Ool00`00Oomoo`0LOol30003Ool2000LOol00`00
<YhbWP020003;[l=0002>el50002Agl40003Cgl30003Deh50002Ead01000EaeG7ELM10001goo00<0
07ooOol027oo00<007ooOol02goo000DOol00`00Oomoo`03Ool00`00Oomoo`09Ool00`00DUQBF003
DUP00`00DUQBF003DUP20003FYT00`00FYUJV@04FYT00`00G]UNf@05G]T00`00IaYW6P04IaX00`00
Jc][>`02Jc/20003Jg/20002Ji`20002Ikd00`00HmeSg@020003Gkh200000e>o00000002000<Ool0
0`00Oomoo`06Ool00`00Oomoo`0LOol00`00Oomoo`04Ool00`00Oomoo`0KOol70002?_l20002>al2
0003>cl40003Ael40003Cel40002Dch40003Ead01000EaeG7ELM100037oo00<007ooOol01goo00<0
07ooOol02goo000EOol00`00Oomoo`03Ool20009Ool00`00DUQBF003DUP01000DUQBF59H0`001EZI
00@005ZIFYUJV@800003G]T005kI00ANf@03001S6P0000AW6P06001WF`00001[>`0016]k00<006^l
Jk`00P000VNm0P0000ASg@00001Gg@L0011oo`03001oogoo00Ioo`03001oogoo01eoo`03001oogoo
00Aoo`8001aoo`80008n_P8000<no`P000=7?`@0009?G`D0009C?P03001C?U<n00800003Ead005LM
00AG7@<0015oo`03001oogoo00Ioo`03001oogoo00]oo`005Goo00<007ooOol01Goo00<007ooOol0
1goo00<0059HDUP00e9H0`000eIi00<005ZIFYT00UZI00@005ZI000000=Nf@04001NfEkIG]T20002
HaX01@00IaYW6VLJ000016MK00<006]kJg/00V]k00<006^lJk`00P0000=Wg@0000001P0000=7_@00
00005Goo00<007ooOol01Woo00<007ooOol077oo00<007ooOol01Woo00<007ooOol06goo1`000TKn
00@004LOAam77`D0009??`@000=C?P04001C?U<nDch30004Ead00`00EaeG7@02000DOol00`00Oomo
o`06Ool00`00Oomoo`0;Ool001Aoo`03001oo`0000Moo`03001oogoo00Ioo`04001BF59HDUP30005
EWT00`00FYUJV@03FYT00`00G]UNf@04G]T00`00G]T00005HaX00`00IaX00004Ie/01`00Ji`00000
Jg/006^l0080009Wg@800005Fod00000000gN@03000HOol00`00Oomoo`05Ool00`00Oomoo`0KOol0
0`00Ool00008Ool00`00Oomoo`0KOol01@00B]i:gT[N00000dKn10000dlN00<004loCcl00P0000=C
7P0000000e<n10000ULM00@005LMEaeG7@@001Moo`03001oogoo00Eoo`03001oogoo00]oo`005Goo
00<007ooOol01goo00<007ooOol01Woo0`000e9i00<005IiEWT00UIi00@005ZIFYUJV@800003F[X0
05kI00ENf@03001S6V<J00ES6P04001WFfMKIe/20004Ji`30002Imd200000e_m00000004000KOol0
0`00Oomoo`05Ool00`00Oomoo`0LOol00`00Oomoo`08Ool00`00Oomoo`0KOol70002Cah20003Cah3
0003Dah50002Ead01000EaeG7ELM100077oo00<007ooOol017oo00<007ooOol02goo000POol00`00
Oomoo`05Ool00`00DWUBN@03DWT00`00EWUFN@03EWT30003F[X00`00G]UNf@02G]T200000f;j001S
6P03HaX2000016MK001WF`0016^L0P0000=[g@00Ho`01`0087oo00<007ooOol017oo00<007ooOol0
:7oo00<007ooOol06goo00@004kmC_e>o@8000=?7P@0009C7P@000=G7@04001G7ELMEad4000POol0
0`00Oomoo`05Ool00`00Oomoo`0:Ool0025oo`8000Ioo`03001BNE9i00=BN@03001FNEIi009FN@03
001J^UZj00AJ^P04001Nf@000004H_X01000HaX0000016MK0P000V^L0P0000=[g@0000000V?l1000
97oo00<007ooOol00goo00<007ooOol0:Goo0P0077oo00@004kmC_e>o@@0009C7@03001C7U<N0080
0003E_d005LM00AG7@<002Eoo`03001oogoo00Aoo`03001oogoo00Yoo`008goo00<007ooOol00goo
00<0059iDWT00e9i00<005IiEWT00P0000=J^P00F[X01EZj00<006;jH_X01F;j00<006MKIe/00fMK
00<006^LJi`00P000V_M00<006?lHo`00`00:7oo00<007ooOol00Woo00<007ooOol0:goo00<007oo
Ool06Woo0`000U;m00@005<MDaeC7@<000AFo@03001G7ELM008002Uoo`03001oogoo00=oo`03001o
ogoo00Yoo`0097oo00<007ooOol00goo00<0059iDWT00U9i0`000eZj00<005ZjF[X00UZj0P0000=N
n`00H_X016;j00D006ML000006MK008000=[W003001Wg@0000D002Yoo`03001oogoo00=oo`03001o
ogoo02]oo`03001oogoo01Yoo`04001BoE;mD_d40002E_d20003E_d3000/Ool00`00Oomoo`02Ool0
0`00Oomoo`0:Ool002Eoo`03001oogoo009oo`03001BNE9i0080009FVP03001J^UZj009J^P04001J
^P000003G_/01000H_YRnV;j0P0016ML00@006^LJia[W080009Wg@@002eoo`03001oogoo009oo`03
001oogoo02aoo`03001oogoo01Yoo`<0009Fo@04001FoEKmE_d5000_Ool00`00Oomoo`02Ool00`00
Oomoo`0:Ool002Ioo`8000=oo`8000AFVP03001J^UZj00=J^P03001Nnekk00ANn`03001RnP0000EW
G005001W_@00Ji`00002Imd4000`Ool01@00Oomoogoo0000;goo0P006goo0P000UKm1000=Goo00D0
07ooOomoo`0000aoo`00:7oo00D007ooOomoo`0000EFVP07001J^UZjF[X005[k00001Ukk00<006ML
Ie`00VML0P000fNm1P00<goo00@007ooOol0035oo`03001oogoo01Yoo`8003Yoo`04001oogoo000<
Ool002Uoo`04001oogoo0005EYX01000F[X000000U[k00<005kkG_/00Ukk0P0000ESG000001WG000
00AW_@03001Oo@00008003Eoo`04001oogoo000bOol00`00Oomoo`0IOol00`00Oomoo`0iOol01000
Oomoo`0037oo000ZOol01000Oomoo`000eJJ0`001E[k00@005kk000000ASG0<0009W_@D003Qoo`03
001oo`0003=oo`03001oogoo01Qoo`03001oogoo03Yoo`04001oogoo000;Ool002]oo`800004Ool0
00000003E_`00`00F_]Jn`03F_/20003He`20003Hkh6000jOol00`00Ool0000cOol2000HOol00`00
Oomoo`0kOol00`00Ool0000;Ool002eoo`03001oo`0000EFo003001Jne[k0080009OG@<000=S_P80
0004Emd00000000mOol2000eOol00`00Oomoo`0EOol00`00Oomoo`0lOol2000;Ool002ioo`03001o
o`0000=Fo0@000AOG@03001K_U^n00L003moo`8003Ioo`03001oogoo01Aoo`03001oogoo03aoo`80
00]oo`00;goo00<007oo00000P000eMN0P0000=OG@0000000U^n0P0000=7_00000000Woo00<007oo
Ool0?Goo0P00=goo00<007ooOol04goo00<007ooOol0?7oo0P002goo000`Ool01000Ool000000eMN
2P0017oo00<007ooOol0>Goo1000>Woo00<007ooOol04Woo00<007ooOol0>7oo10003Goo000aOol2
000017oo000000000TnO100027oo00<007ooOol0=Goo1000?goo0P004Woo00<007ooOol0=7oo1000
4Goo000cOol00`00Oomoo`03000<Ool00`00Oomoo`0aOol40015Ool00`00Oomoo`0?Ool00`00Oomo
o`0`Ool4000EOol003Aoo`03001oogoo00ioo`03001oogoo02eoo`@004Yoo`03001oogoo00ioo`03
001oogoo02aoo`@001Uoo`00=Goo00<007ooOol03Goo00<007ooOol0:Goo1000Cgoo00<007ooOol0
3Goo00<007ooOol0:7oo10007Goo000fOol2000<Ool00`00Oomoo`0VOol4001DOol2000<Ool00`00
Oomoo`0VOol3000QOol003Qoo`03001oogoo00Uoo`03001oogoo029oo`@005Yoo`03001oogoo00Uo
o`03001oogoo029oo`@002Aoo`00>Goo00<007ooOol027oo00<007ooOol07goo0`00Ggoo00<007oo
Ool027oo00<007ooOol07Woo1000:7oo000jOol00`00Oomoo`07Ool00`00Oomoo`0KOol4001SOol0
0`00Oomoo`07Ool00`00Oomoo`0JOol4000/Ool003]oo`8000Moo`03001oogoo01Moo`@006Qoo`80
00Moo`03001oogoo01Ioo`@0031oo`00?Goo00<007ooOol017oo00<007ooOol04goo1000KWoo00<0
07ooOol017oo00<007ooOol04goo0`00=7oo000nOol00`00Oomoo`03Ool00`00Oomoo`0?Ool4001c
Ool00`00Oomoo`03Ool00`00Oomoo`0?Ool4000gOol003moo`03001oogoo009oo`03001oogoo00]o
o`@007Qoo`03001oogoo009oo`03001oogoo00]oo`@003]oo`00@7oo00D007ooOomoo`0000Uoo`@0
07eoo`05001oogooOol00009Ool4000oOol0045oo`800003Ool007oo00Aoo`@0089oo`800003Ool0
07oo00Aoo`@004=oo`00@goo0P0000=oo`0000000P00R7oo0P0000=oo`0000000P00Agoo0014Ool2
002=Ool2001;Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol0
0001\
\>"],
  ImageRangeCache->{{{0, 287}, {110.188, 0}} -> {-0.0563868, -0.0193168, 
  0.00736159, 0.00736159}, {{7.625, 137}, {107.563, 
  2.625}} -> {-0.227543, -0.0725132, 0.00880224, 0.00880224}, {{149.938, 
  279.313}, {107.563, 2.625}} -> {-1.48021, -0.0725132, 0.00880224, 
  0.00880224}}]
}, Open  ]],

Cell[TextData[{
  "It is clear from these magnitude response plots that the Sobel masks \
approximate a differentiator only in the low frequency region ",
  Cell[BoxData[
      \(TraditionalForm\`\( | \[Omega] | \( < \ \[Pi]\/2\)\)\)]],
  ". Also, note that each mask is a combination of a digital differentiator \
in one of the spatial directions and a smoothing filter in the other. "
}], "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["COMPARISON OF GRADIENT OPERATORS", "Section"],

Cell["\<\
In this section, the edge response characteristics of the edge detectors will \
be compared.\
\>", "Text"],

Cell[CellGroupData[{

Cell["Discrete Edge Model", "Subsection"],

Cell["\<\
To facilitate the comparison, a simple edge model will be assumed. The edges \
are of height h and have three orientations: vertical, horizontal and \
diagonal (45 degrees).\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\((data = 
          ZeroPad[Table[If[i > j, h, 0], {i, 6}, {j, 6}], {{1, 2}, {2, 1}}])
        \)\  // MatrixForm\)], "Input"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", GridBox[{
            {"0", "0", "0", "0", "0", "0", "0", "0", "0"},
            {"0", "0", "0", "0", "0", "0", "0", "0", "0"},
            {"0", "0", "h", "0", "0", "0", "0", "0", "0"},
            {"0", "0", "h", "h", "0", "0", "0", "0", "0"},
            {"0", "0", "h", "h", "h", "0", "0", "0", "0"},
            {"0", "0", "h", "h", "h", "h", "0", "0", "0"},
            {"0", "0", "h", "h", "h", "h", "h", "0", "0"},
            {"0", "0", "0", "0", "0", "0", "0", "0", "0"},
            {"0", "0", "0", "0", "0", "0", "0", "0", "0"}
            }], ")"}],
      (MatrixForm[ #]&)]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Discrete Gradient Calculation", "Subsection"],

Cell["\<\
Calculate the gradients using Roberts, Prewitt and Sobel operators.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\((\[Del]r = GradientEdge[data, RobertsKernel]\  /. \ \@h\^2 -> \ h)
        \) // MatrixForm\)], "Input"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", GridBox[{
            {"0", "0", "0", "0", "0", "0", "0", "0", "0"},
            {"0", "0", "0", "0", "0", "0", "0", "0", "0"},
            {"0", "0", "h", "h", "0", "0", "0", "0", "0"},
            {"0", "0", \(\@2\ h\), "h", "h", "0", "0", "0", "0"},
            {"0", "0", \(\@2\ h\), "0", "h", "h", "0", "0", "0"},
            {"0", "0", \(\@2\ h\), "0", "0", "h", "h", "0", "0"},
            {"0", "0", \(\@2\ h\), "0", "0", "0", "h", "h", "0"},
            {"0", "0", "h", \(\@2\ h\), \(\@2\ h\), \(\@2\ h\), \(\@2\ h\), 
              "h", "0"},
            {"0", "0", "0", "0", "0", "0", "0", "0", "0"}
            }], ")"}],
      (MatrixForm[ #]&)]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[Del]p = GradientEdge[data, PrewittKernel]\  /. \ \@h\^2 -> \ h; \ \n\t
    MatrixForm[N[\[Del]p, 2]]\)], "Input"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", GridBox[{
            {"0", "0", "0", "0", "0", "0", "0", "0", "0"},
            {"0", 
              RowBox[{
                StyleBox["0.4714045207910317`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->2], " ", "h"}], 
              RowBox[{
                StyleBox["0.333333333333333303`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->2], " ", "h"}], 
              RowBox[{
                StyleBox["0.4714045207910317`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->2], " ", "h"}], "0", "0", "0", "0", "0"},
            {"0", 
              RowBox[{
                StyleBox["0.745355992499929875`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->2], " ", "h"}], 
              RowBox[{
                StyleBox["0.745355992499929875`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->2], " ", "h"}], 
              RowBox[{
                StyleBox["0.9428090415820634`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->2], " ", "h"}], 
              RowBox[{
                StyleBox["0.4714045207910317`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->2], " ", "h"}], "0", "0", "0", "0"},
            {"0", "h", 
              RowBox[{
                StyleBox["0.745355992499929875`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->2], " ", "h"}], 
              RowBox[{
                StyleBox["0.9428090415820634`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->2], " ", "h"}], 
              RowBox[{
                StyleBox["0.9428090415820634`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->2], " ", "h"}], 
              RowBox[{
                StyleBox["0.4714045207910317`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->2], " ", "h"}], "0", "0", "0"},
            {"0", "h", "h", 
              RowBox[{
                StyleBox["0.4714045207910317`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->2], " ", "h"}], 
              RowBox[{
                StyleBox["0.9428090415820634`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->2], " ", "h"}], 
              RowBox[{
                StyleBox["0.9428090415820634`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->2], " ", "h"}], 
              RowBox[{
                StyleBox["0.4714045207910317`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->2], " ", "h"}], "0", "0"},
            {"0", "h", "h", "0", 
              RowBox[{
                StyleBox["0.4714045207910317`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->2], " ", "h"}], 
              RowBox[{
                StyleBox["0.9428090415820634`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->2], " ", "h"}], 
              RowBox[{
                StyleBox["0.9428090415820634`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->2], " ", "h"}], 
              RowBox[{
                StyleBox["0.4714045207910317`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->2], " ", "h"}], "0"},
            {"0", 
              RowBox[{
                StyleBox["0.745355992499929875`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->2], " ", "h"}], 
              RowBox[{
                StyleBox["0.9428090415820634`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->2], " ", "h"}], "h", "h", 
              RowBox[{
                StyleBox["0.745355992499929875`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->2], " ", "h"}], 
              RowBox[{
                StyleBox["0.745355992499929875`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->2], " ", "h"}], 
              RowBox[{
                StyleBox["0.333333333333333303`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->2], " ", "h"}], "0"},
            {"0", 
              RowBox[{
                StyleBox["0.4714045207910317`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->2], " ", "h"}], 
              RowBox[{
                StyleBox["0.745355992499929875`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->2], " ", "h"}], "h", "h", "h", 
              RowBox[{
                StyleBox["0.745355992499929875`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->2], " ", "h"}], 
              RowBox[{
                StyleBox["0.4714045207910317`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->2], " ", "h"}], "0"},
            {"0", "0", "0", "0", "0", "0", "0", "0", "0"}
            }], ")"}],
      (MatrixForm[ #]&)]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[Del]s = GradientEdge[data, SobelKernel]\  /. \@h\^2 -> \ h; \n
    MatrixForm[N[\[Del]s, 2]]\)], "Input"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", GridBox[{
            {"0", "0", "0", "0", "0", "0", "0", "0", "0"},
            {"0", 
              RowBox[{
                StyleBox["0.35355339059327373`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->2], " ", "h"}], 
              RowBox[{
                StyleBox["0.5`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->2], " ", "h"}], 
              RowBox[{
                StyleBox["0.35355339059327373`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->2], " ", "h"}], "0", "0", "0", "0", "0"},
            {"0", 
              RowBox[{
                StyleBox["0.790569415042094725`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->2], " ", "h"}], 
              RowBox[{
                StyleBox["0.790569415042094725`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->2], " ", "h"}], 
              RowBox[{
                StyleBox["1.06066017177982119`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->2], " ", "h"}], 
              RowBox[{
                StyleBox["0.35355339059327373`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->2], " ", "h"}], "0", "0", "0", "0"},
            {"0", "h", 
              RowBox[{
                StyleBox["0.790569415042094725`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->2], " ", "h"}], 
              RowBox[{
                StyleBox["1.06066017177982119`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->2], " ", "h"}], 
              RowBox[{
                StyleBox["1.06066017177982119`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->2], " ", "h"}], 
              RowBox[{
                StyleBox["0.35355339059327373`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->2], " ", "h"}], "0", "0", "0"},
            {"0", "h", "h", 
              RowBox[{
                StyleBox["0.35355339059327373`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->2], " ", "h"}], 
              RowBox[{
                StyleBox["1.06066017177982119`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->2], " ", "h"}], 
              RowBox[{
                StyleBox["1.06066017177982119`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->2], " ", "h"}], 
              RowBox[{
                StyleBox["0.35355339059327373`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->2], " ", "h"}], "0", "0"},
            {"0", "h", "h", "0", 
              RowBox[{
                StyleBox["0.35355339059327373`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->2], " ", "h"}], 
              RowBox[{
                StyleBox["1.06066017177982119`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->2], " ", "h"}], 
              RowBox[{
                StyleBox["1.06066017177982119`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->2], " ", "h"}], 
              RowBox[{
                StyleBox["0.35355339059327373`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->2], " ", "h"}], "0"},
            {"0", 
              RowBox[{
                StyleBox["0.790569415042094725`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->2], " ", "h"}], 
              RowBox[{
                StyleBox["1.06066017177982119`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->2], " ", "h"}], "h", "h", 
              RowBox[{
                StyleBox["0.790569415042094725`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->2], " ", "h"}], 
              RowBox[{
                StyleBox["0.790569415042094725`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->2], " ", "h"}], 
              RowBox[{
                StyleBox["0.5`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->2], " ", "h"}], "0"},
            {"0", 
              RowBox[{
                StyleBox["0.35355339059327373`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->2], " ", "h"}], 
              RowBox[{
                StyleBox["0.790569415042094725`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->2], " ", "h"}], "h", "h", "h", 
              RowBox[{
                StyleBox["0.790569415042094725`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->2], " ", "h"}], 
              RowBox[{
                StyleBox["0.35355339059327373`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->2], " ", "h"}], "0"},
            {"0", "0", "0", "0", "0", "0", "0", "0", "0"}
            }], ")"}],
      (MatrixForm[ #]&)]], "Output"]
}, Open  ]],

Cell["\<\
Observe that the edges exhibit 
(a) blurr in the cases of the Prewitt and Sobel operators (why?), 
(b) the response of a vertical/horizontal edge is different from that of a \
diagonal, and 
(c) the responses due to the different gradients are different. 
Additionally, the Sobel operator has a stronger response to diagonal edges \
than horizontal/vertical, while Roberts and Prewitt are the reverse. Finally, \
note the performance of the edge detectors at a corner. It is desirable to \
have a strong response, since it has been suggested that corner detection is \
important to human and generally mammalian vision. Prewitt and Sobel \
operators have this property.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Real Image Example", "Subsection"],

Cell["Read one of the example images.", "Text"],

Cell[BoxData[
    \(dat = Partition[ReadImage["\<coke128.bin\>", "\<Raw\>"], 128]; \n
    A = TakeMatrix[dat, {32, 40}, {71, 79}]; \)], "Input"],

Cell[TextData[
"The gradient magnitude \[ScriptCapitalM] and edge direction \
\[ScriptCapitalO]  using the Sobel mask, will be computed."], "Text"],

Cell[BoxData[
    \(\({\[ScriptCapitalM], \[ScriptCapitalO]} = 
      GradientEdge[A, SobelKernel, Orientation -> True]; \)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[
      GraphicsArray[
        Map[ListDensityPlot[#, Mesh \[Rule] False, FrameTicks \[Rule] None, 
              PlotRange \[Rule] All, DisplayFunction \[Rule] Identity]\ &, \n
          \t\t\t{A, \[ScriptCapitalM], \[ScriptCapitalO]}]]]; \)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .3125 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.31746 0.00744048 0.31746 [
[ 0 0 0 0 ]
[ 1 .3125 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .3125 L
0 .3125 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.00744048 0.321429 0.30506 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0240385 0.0192308 0.0240385 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
40 string
40 40 8 [40 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
AFB3A49D8A75625B6A5BD4C55FABAF95876D838E8ADBDF57
57575F50545F574C5454504141A8C950
3654505F66807C83833AC5BE83503A5783C9C5CCD4E2575B
57575757625457544954453A366ADB5F
D4CCC9C5BEBEB3B6A44CC5AFBA712F4949DFD0E2D4755054
5B545B625B545B574C49452F3A41C96D
D7D0CCC9C5BEBAABA050BAC1B3A462C1CCCCD7DFD7495757
57575B66AFD7D7D4D0573A2F243ACC75
D4D0D0C9C5BEAFAFA450C1BAC1BA9DC1C1C5DBD76D4C5757
545FBADFE6FFDFDFD7D4452B2436D07C
C9D0C9D0C5B6BABAA841B6C5C5BABAAFABCCD0D04554575B
75E2DFDFDFE2E6DFCCD79920242FA087
D4D0C9C9C1BABEAFAB45B6A8C1BEBEBEBEABC59541494971
D0EDE2DFE2E2DBD4DFC9BA1D28367195
D4CCC9C5BAC1B3AFA854ABC1A4B6C1C1C1C5C15B334957DB
DBE2DFF5DFDFD4D4C5AFB324243E8E99
D7D0C9CCBEBEBEABA84CAFBEBEA8AFB6C1C1C53A415499DB
D7E2E2DFE6EAD4D0C9BAB62B206D8E95
DBD4C5D4C9C5BEAFB357ABC1C1AFBA95BAC1BE2B3A4CE2DF
DBDFDBDBD7DBE6C16A3E332420A880A0
D0D7D0C9C1C5BAB6AF5BB3B6BEC9BABAA8B3C92B2F3EDBDB
FCE2DBD7D7D7753E2B2B202024998EAB
D4D7CCC9C5C5BAB6AF50B3B6A4C1B6B6BEC1B3242F45D7D0
DBDBF5DBD054453A2B281D2428B38AAF
D7D0D0CCC5BAB6AFAF50ABB6BA92B3BABEC1B628283AD4D0
D7DBD7E25F49413628242424206A99AF
C9C5D4C9BAC1B6ABAB49ABB3BABE95A8B3C1C91D282BDBD7
DBCCDB8A504541362F2B24202036B3B3
D4C5CCCCBEB6B6B3A454B3B6B3BAB6B39DC5C5362F3383E6
E2D4CC54504C412F2B2B41331920AFAB
CCD0CCC5BEB3BAABA457AFABAFB3BEBABACCC941242F45B6
D7EA834C5045416A99ABB6AB3A247CAF
D0CCD0CCBABAB3AFA84CABAFA499B6B6B6C1C56228333654
99CC5449495FB6BEB3AF99B36619A0A8
D4D7CCC1B6BAB3B6AB57AFBAB3B38ABAC5CCC5752B335499
C9DF414562D7C1BABEB6B683540EA0A8
D4D4D0C9BEBEB6AFA450B3BEB6AFB68EABC5C17C78ABBAD4
C9C1414CBECCABB3B3AFAFA420207C95
DBD0CCC9C1BABAABA457B6A0B3B6B3AFA8B69D492F36A0C9
D7C94557D4C1BEAB95AFA033202492A0
DFC9CCC9BEBAB3AFA457ABAB92ABAFABB3623E2F242B33BE
C1C1454CCCC9B6B6A07524192041A0B3
E6D4D0C9C5B6B3A8A45FB3B3A8A095AF5B33332F28283692
BEC149415BAB99662B2819242092AFAF
DFC9C9C1BAA8B3AFAB57AFAFA8A8A4831919332F28282F80
C1BA4541453A362F282020192BB3AFAF
E2DFC9BEB6AFAFA8A85FB6A8A4B6AB6D0E2033575B2B338E
C1C15B3E45362F242020201D7C92AFA8
DBD4C9C1C1B6B6AF9D62B6AB95A4AB2F1554A8B3AF8728AF
B6B39D3E45362B1D1D202041B37C8E9D
DBCCCCBAB6BAAFAF955FB3A0A487A4193ABAB3A0995B2892
BEA8C1623A33191D202B3EA89524AB8E
DFD4C9C1B3BAAFA8A45BB6ABA4A0831983AFA8712B1D2878
C5BABEC18A2F281D2F7C8E2F1528A087
E6D7CCC5B6B6AFA4A06DB3A8A8A4A415412F28242420246A
B3B6BAB3C1AF95713E2019151D24A087
DFDBD4C5BABEB3ABA06DBE9D83A86D1215202820201D286A
54BAAFAB8A4928191515191915249280
DBDFD4C1C1B6AB9D9D80ABA85719191215242F1D1D283A5B
4141573A282F241915201D1D1919956A
E6D7D7C9BAAFAFA0A487B3A85019191515202841718EA45B
3E2B3E282424241D1D1D191D19209557
E2D7D4C5BEAFABA0A092ABA4500E1519245F95A4997C3A54
4136332B2028242012151D335B839245
E2DFD0C9BABAA0A09D99A8925407205B8792925420202049
412F3324282428191D191D75AB87A03A
DBE2D7D0C1BAB39D999DABA45057927C361D2B20191D1949
49333A28283354191D12151933A48A4C
D7DFD7CCC5B3AFA899A4B3A099785F780019151915192045
4C3E547592A03A121915151515197C66
D7D4CCD0C1AFB3A495AB9DA49254123A121519202B507866
95A4A8A09949201D12190E0E19205B80
D7D7D4CCC5BAAFA49DA4AF95951D15360E154C6250509295
A4A475A0751D243A2F120E1215195F95
D4D4C5D0CCBEB3ABA0A8AF99832B157C627528152019248E
A8925F241D192B9575710E0E0A2050A4
DFD0D0D7C5B3B3A89DAF9D9987716A92870E151919151D2F
ABA8661D1D2062A4958A752F1219579D
D0D4D0D0CCBEBEAFA0A8A0998E8E788A410A15151919152B
A0A46A1D1D24A0A0998E8066501254A8
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.35119 0.00744048 0.64881 0.30506 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0240385 0.0192308 0.0240385 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
40 string
40 40 8 [40 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
B7B0A4967F63503C4A736C6D3A444F265ECCEFEFFFD7B134
4551343E5133406561554F4037AC5E3D
462A2D37475B6B6968599B566A548179727574692A84C03F
0203030D07070510050E231953D32075
B1AF9D8E755C4B3A8237912269A55A83A376151479C45007
0101102F669AA9AB8D4627192CCF304C
770C0C0E0E1213197E258E0B338C88B37C411333C7920703
023379ADCDCBBCB2CACA641E19D64C11
6D08070B13160E188421960718493B361F231584CE410F0E
52B1C1955F1D1D1342C6D14611D26114
5F050609190F0A1691189A1404181607122B2CB6A1161551
BEB85112121517130C63F28B15A57C3D
500A080F14080C178B0F9013190B0916121145C76F1A56B8
A93A080E070A16131E33DBB61E7C7965
480F080F0C0615147E088E0B0718160A07107BBE2740B3B4
3C0C07010A1014112823C2BF32896F66
48150611160C1A16790791111D0316231E07AEB31786CF5E
07090C140E0A1D407C97BF9D64983C65
43130806100A1913770D89170F1B19022416BBB52BC4C32A
180C0A0C12388BD2DEC8A35194881A6A
3A090E0C0A0C150E7A03801113011A171213BEBC23E0C518
0A0E111042B3E3BD6F331B04A9861162
33070F0D0910130E8009830314281605140AC6B822DFC01A
20130149B9C96E36190F06079D8E1B5A
2A0D06121110140F81088809140C1F1E1403CFBE1FE4C907
071333ABCC571A1F150C06026EAF5649
20090719130A130F7F03880E09230D142219CECA10CCE221
0F0864C87118191B0E0F1A1727BE962F
22060317170A0C167A0F7F080F051E1C1E27C2CF0B86F484
032BABA02413144581A8B8A34BA9B73C
2A05061519070918770E780C161F0F0F1B1CAAD31E3CBBD8
776DCF5C023489B7B7A18FB1AB71B851
32070A1A14070A127C077D0B10102916140E89D33F236398
797AC31853AEAB6E3715116CB855BE4B
3F08121B0E080B0E7E0986121D1C072E260C71B56D9EBFB7
699CB744B98D190A09102583B168BC51
48091018110A0F167910800E0814200935267A8C0B627F5A
15B5A494B618241921194EB98C7AA862
3C110A12120B12197313701C201310151270B7A07ABAD16B
0CB597B3991C1D1F2460C2BE3496A367
2C190711141012166D106B16081E1A287FAE8C4E1545C9AF
29A89C97B242447096BCAC4441BB8A56
271B0A121B160C116A0D6F1514031573C5742113081194BC
389EA24CB0B6B8BEA56F2E078FC54748
2E1E13181F11050C690C6D1006152BAD9C28202B34127DBB
479AA5033C7786602C0C0730B8990E42
3E1E1E1317110810661365190F0C65CD4A6E9EABA97D73BE
3676AD32091C1C1B0E030E84A941334E
4D1C1D120C0E0C1B65205D21132591BE49D8AE6F68934DBE
1C339F7A1725231106145CBD2A404F55
541618180A0A101D67215D1A180B9F77C0A90A66A8A55FC7
25166AB477401D053B727547996F724D
611D191D090716145F1E5E15161EAC43A591B9BD9E576CCA
4D032079C1BE9B6C3B3C4C9C8694824F
6C1C1B1F100A1813511E50251818BC698CACA06C2D0367A6
7E35111E535F3E3E38727A410DAD7F5B
7D121E1E0E0E1A16441F3F4B6AA7CA6E2916060C04115C57
89A28FA6C3BE9D753D0E05050BA67863
950D1F1E12171D14301C356B9D997329141C0C316993791C
4291A5A5814423120908030503A36564
AB1119201B1516102016297ABE4C03082F6089A99F61273E
3113212D0E070E100309092859A72E68
C014181F1B18170E14101679BF49285F96A9761754958439
2B0E0E1803030A120706398AA98B3966
CD131C1E191D200E09110573A75E9B77235287B5A5773E2A
21130E13071D25220701498057286460
C008191C1C19201A05190F668C7665398DA48D6022093838
1B1A35628A7A543207083384C19F4969
9C0F16172319142004190535583F6B86741A0F00204E665D
6188989B795A77300306061653A14E80
750A0C122418122003130C196FA86447432643565477817D
7D6B471F63A94F1F1E0E0A0A0F658099
570B0A0A1F1E191C0814122390A524496F602B081D616D41
24396795B66F37768B6A2E08135D9CA4
451003071E1E1619040F162D7E92868C7A3947544F62A9AD
365681896F089B8D95AB963D0A5CAAAA
3F0E07072419131E010619224D7670288D8A330804074AC4
7C58AC5F0168BC50335D9A8F4E47B3AD
66323A49565B656056401D421D30422F90778F96B4E8CF70
8964895C4A7B78535C4B484659A29479
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.678571 0.00744048 0.97619 0.30506 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0240385 0.0192308 0.0240385 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
40 string
40 40 8 [40 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
2200FAFAF2ECEBFCE24A8067951AF2D21BFEF6FCEDFA4050
2FF29C27F5B225F8FEF4DCD87CAE0AD6
B4ED04FCF90206FE4A84747565B4F61D6BBCF5F5F9BCBBC6
803FC0EA1AAC5A62DADDA8BF5264C46A
D5010101FE030A15669E805C4E540DCDAC96DAE29CABB965
BFC0A5C5EAFAFF081D4993BA3F6F6031
84604B535D7A9393808281404849FAD5D8A16CC2A3A01AC0
80C0D8DEDFF6050525435A9A3A7B86C0
7DBF8065809172567D6B7CE52E43F18929605AA6A8B79AD3
CBCDD9E0C8E14E4E464E576657776962
87A5BFA08B7932657F637739FF5111E5474C029D9A1A76B9
C1CCDBB847FFBA9A9063686E76715B6C
8C76AFBF9D749FA27EAE7E2A171A00110574C1A5A955A5B8
B9B12F002CCDC6CEBFA17E7B90827F87
82797479806F808E808B82E59A2E2D3200ED8F9ABCACABAF
B46053C05A6D8EBFABAC817D9D9A9B88
8A684037402965657AD380AF4E40111B442C898D5D9FA6AB
805F1004FF7672B0CFECB8969AA3A681
856C406F6D5A745C7607827351203AFF4F39838650808FC9
EF34BFEF10D3D1D3DAEDDDBC8792D089
816C72A9B2908072811A7F2F2AC05022C0758485647B7A51
4D5D2862C4CCD3D3D0CDCAFF8488D789
859A866A80A5A3A283137AE5041104DAE2F683846E7D7B2F
211ABFA6BAC4C5A3979A6F9A776F6A87
68EA9085A8A59DB685F47A934DA929364D1A7B8056797ED3
6523E4B4B0B49A86765640FF5C5D738D
6D132C8B9AA58086839A83802040153F44747979A5746E6B
36AFB0ABA988838A72060E404A6D7A86
8B103F8C8CBF908480AE832F2E5A1A18A89379761A625A50
1A94A1A4B08032F6F6F6FF233A756C65
7D25408083809388805D79EFFB2E4940B591797565595243
30B7A2ADFFDDE4E9EFF6FD37528B7A77
871A768E8E80765F7A9A831A5A12324C9D8D777261968075
709694D1BECFE0EDEF25AF8D8185868A
7E407A837250658080A086FA31402C46556F7A6C20E4D7C9
BA7E86ABB6C5F4F6A05A6A8F96687368
80938063504D799A85807D0DD0393B5F4F17A0981A98ADBC
D3837F9CA1D6A0E0FAFCAFA29F7B7D7A
9196B285859A90837E8A79E3182A6D25FAE3C9C6012E454E
E0807E82846E6C80CFE1CCC1BA92969C
986853747B92A0917F9284650B2407D4C3D1D4BED3435959
2485836252FECACEDDDACCCAA8A4A495
7D83A5A0A0B3A9747C9582534065F6BEBFD6E28A7474726D
5E828343350CE7DADDD5B99A99A3B882
7D7693B4A9B7DA807E907FA56F17809DAA2092FB22107E7E
817C7AE52602E9D2BFA980B199907278
796F76755D372F92849385931A5693958BBDD8F3162F9E8A
897166539391ACBFDDE5DDAEAA7C2766
6BA78D856F535683876D7B8EDC259B92C0C2DDF838648A7E
63665A5A739DACBF90CDC4B2B6FF4C6C
7B7B8090CDA59D8D807A7D7163E5927AAAB132D1D3BD5073
721F47443D6A8DDAC0D9CE5FD9246F78
8761686C6C9A918E78A4866846447C806B1FE8D6D5D96573
6F1A333633281510C273F1E5E567797B
80675F695A4D6F757BA486A9F7AE86A62B00F1DCC31A7C68
4835E9B67E71768EDE05EACC4A7C7777
766F6F765D728E9A7E96819FDFEEBDB0322D909FFFAF8A59
2B24F8EDE2DCE0DFDBD32525657A726A
7A78797690A79E9D73AC878AA9DBD7B58480D6EFE7EAE32C
F819FAE6E5D49F6FDFD01A40C080766D
7B8B837C8A97846D67B38983848BE5F4BACBE6EAEAF54786
890AEBADD3FF806DE520A0D8E6AEA46E
7B7B8886757794AC7B9D608B8489AEDADAD5E627EEE6EDE5
8480AC9065C076859A6FACC8E2D35172
8065636560616D8D9396C080741BD9E2B82AF5DBE8EA2561
80757275E5D2295C533F6F6B698C7980
838B6C676E746765409FF96248FBD486D101F5D4D0207A81
5F25F4FCF3004B80D3BF3D2A2B2FB68A
85E5AD8C88978476008BDA65579E02C2A22A1A80DADDD5CD
F8FCEFF0FD5F919FE590EF3339423C8A
89B29F857A6F7A839A80A99F9AABF9D790ADD6F3E7C8DEE5
E300EFE3A9B5B02E2872BF5A79787D8B
899AA5765F5B6867F49D5F8D8F8E98E91AEBD33F0D415086
ACACDFF1C6B6B0ED172D495055788289
85929A2C7C897B7400869A8F7352D1DD2967D7FDFB15384C
5480A1D6DA3FAAD6192C372DC07C7E82
7E72E55380745C6FC03F9F82532DDCC69EB6DE0BFF1A4E61
6B737A81C0A4A5C13D3D3D3126907F81
46F2F5EFDBE5EEEBFD2EC9546CFBFE516D30F3FCF3F609AF
55CF8852F4A5750AEFE0AA6D1ADBB96C
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{362, 113.125},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005Z0000LA000`40O003h00OogooJgoo003oOom[
Ool00?moof]oo`002GooK0002WooJ`002WooK0002Woo0009Ool00`00Oomoo`1XOol00`00Oomoo`08
Ool00`00Oomoo`1WOol00`00Oomoo`08Ool00`00Oomoo`1XOol00`00Oomoo`08Ool000Uoo`03001o
ogoo06Qoo`03001oogoo00Qoo`03001oogoo06Moo`03001oogoo00Qoo`03001oogoo06Qoo`03001o
ogoo00Qoo`002Goo00<007ooE[D00UJe0U[F0e:D0Tic0dHa0SW>0c6<0be[0SF]0be[0V]J0f<H0Re[
1UJe0TYB0d8@0SF]0d8@1DHa1Fmk22U:0be[1BU:0Re[0bU:0RDY22U:1B480eJe0VLi0bU:0Woo00<0
07ooOol027oo00<007ooF]H015[F0e:D0TYB0cg_0S6<0bU:0QcW0bDY0cW>1CF]0QcW0b480RDY0a24
0Re[0fLi1GNm0goo0V]J0e[F0QS60b480RU:0aS60QcW0bU:0aS60R481C6<0bU:0RDY0b480QS60eJe
0Re[0acW0Woo00<007ooOol027oo00<007oo48@00Q240P001Goo0g_N1GNm0goo0W>L0bDY0T8@0c6<
0TYB0`aS0g_N0V]J0`aS0Woo0g_N0goo0WNm0goo0R480bU:0QBU0g_N0dic0Q240g_N0U[F0a241Goo
0g_N1Fmk0Sg_0eJe0P@Q0f]J0Woo00<007ooOol027oo0009Ool00`00OomF]@02E[D2F]H3DY@2CW<3
AS42>Lh3<H`3;F/2=Jd3;F/2JeX3HaP2;F/6E[D2BU83@Q02=Jd3@Q05AS45Kg/8:DX3;F/5:DX2;F/3
:DX29BT8:DX58@P3E[D2IcT3:DX2Ool00`00Oomoo`08Ool00`00OomJeP04F]H3DY@2BU83?Nl2<H`3
:DX27>L39BT3>Lh5=Jd27>L38@P29BT348@2;F/3IcT5Mkd3Ool2JeX3F]H26<H38@P2:DX36<H27>L3
:DX36<H28@P5<H`3:DX29BT38@P26<H3E[D2;F/37>L2Ool00`00Oomoo`08Ool00`00Ool@Q00248@2
0005Ool3Nmh5Mkd3Ool2Li`39BT2@Q03<H`2BU8336<3Nmh2JeX336<2Ool3Nmh3Ool2Mkd3Ool28@P3
:DX25:D3Nmh3CW<248@3Nmh2F]H348@5Ool3Nmh5Kg/2?Nl3E[D21243JeX2Ool00`00Oomoo`08Ool0
00Uoo`03001ooeJe009F]@9JeP=BU09>L`=6<@8icP<aS0<]J`8e[@<]J`9[FP=S608]J`IF]@9:DP=2
408e[@=240E6<@E_N`PYBP<]J`DYBP8]J`<YBP8U:@PYBPDQ20=F]@9W>@<YBP9oo`03001oogoo00Qo
o`03001ooe[F00AJeP=BU09:DP<mk`8aS0<YBP8Li`<U:@<icPDe[@8Li`<Q208U:@<@Q08]J`=W>@Eg
_@=oo`9[FP=JeP8HaP<Q208YBP<HaP8Li`<YBP<HaP8Q20DaS0<YBP8U:@<Q208HaP=F]@8]J`<Li`9o
o`03001oogoo00Qoo`03001ooa24008@Q08000Eoo`=kgPEg_@=oo`9cW0<U:@9240<aS09:DP<<H`=k
gP9[FP<<H`9oo`=kgP=oo`9g_@=oo`8Q20<YBP8DY@=kgP=>L`8@Q0=kgP9JeP<@Q0Eoo`=kgPE_N`8m
k`=F]@848@=[FP9oo`03001oogoo00Qoo`002Goo00<007oo6<H00QS61BU:0Re[0c6<0T8@0cg_1D8@
0acW0V<H0ekg0T8@0bU:0acW0RU:0d8@0VLi0f<H0fLi0V]J0g>L0RU:0be[2RU:0c6<1bU:0bDY0bU:
0R480acW0QS60cF]0Vmk0be[0Woo00<007ooOol027oo00<007oo8@P00R481ABU0QS60b480Re[23F]
0be[0Tic0bU:0SF]0bU:0T8@0cg_1cW>0cF]0aBU0T8@0f<H0QcW20000P@Q20000`Q20P000`@Q0Q24
0`aS0RU:0f]J0Q240cW>0Woo00<007ooOol027oo00<007ooF]H00U[F0WNm0`001Goo1@000goo0RDY
0d8@1CW>0S6<0e[F0g_N0PaS0cF]0Ukg1W_N0Woo1Ekg0f<H0T8@0acW0f<H0WNm0`aS0UJe0be[0S6<
1Vmk0UJe0ekg0RU:0c6<0V<H0cF]0Woo00<007ooOol027oo0009Ool00`00OolHaP026<H5:DX2;F/3
<H`2@Q03?Nl5@Q037>L2HaP3G_L2@Q03:DX37>L2:DX3@Q02IcT3HaP3IcT2JeX3Li`2:DX3;F/::DX3
<H`7:DX39BT3:DX28@P37>L26<H3=Jd2Kg/3;F/2Ool00`00Oomoo`08Ool00`00OolQ20028@P55:D2
6<H38@P2;F/8=Jd3;F/2CW<3:DX2=Jd3:DX2@Q03?Nl7>Lh3=Jd35:D2@Q03HaP27>L8000212480003
24820003124248@336<2:DX3JeX248@3>Lh2Ool00`00Oomoo`08Ool00`00OomJeP02F]H2Mkd30005
Ool50003Ool29BT3@Q05>Lh2<H`3F]H3Nmh236<3=Jd2G_L6Nmh2Ool5G_L3HaP2@Q037>L3HaP2Mkd3
36<2E[D3;F/2<H`6Kg/2E[D3G_L2:DX3<H`2HaP3=Jd2Ool00`00Oomoo`08Ool000Uoo`03001oof]J
009[FPEW>@9S60ENm`IJeP9BU0<U:@9S60=F]@9Nm`<icP<DY@DU:@9_N`=[FP=cW09[FP<icPDYBP8]
J`<YBP<]J`8aS0<]J`8YBP<]J`8YBPHU:@8Q20<DY@8Li`<Q209W>@<e[@9oo`03001oogoo00Qoo`03
001ooe[F009JeP9F]@=>L`96<@<icP8]J`<U:@8Li`=240<HaP9:DP<@Q08e[@=BU08]J`=2409BU0<i
cPD8@P<mk`9S60<YBPL000<8@P8DY@<aS0=>L`EF]@96<@<Q208@Q0<<H`8DY@=W>@8HaP<U:@9oo`03
001oogoo00Qoo`03001oof]J009[FPL000=oo`8000<48@<8@P8aS0=>L`9240<]J`8U:@<YBP<48@9W
>@=F]@9:DP=_N`=cW09>L`=F]@9Nm`<aS09Nm`=S60=BU09S60=g_@Eoo`848@<<H`<U:@9:DP=Nm`8L
i`<e[@8aS0<HaP9oo`03001oogoo00Qoo`002Goo00<007ooJeX00V]J1FLi0V<H1Ekg1U[F0U:D0bDY
0V<H0eJe0Ukg0cW>0aBU1BDY0Vmk0f]J0g>L0V]J0cW>1BU:0Re[0bU:0be[0S6<0be[0RU:0be[0RU:
1RDY0R480aBU0QcW0b480VLi0cF]0Woo00<007ooOol027oo00<007ooF]H00U[F0UJe0dic0THa0cW>
0Re[0bDY0QcW0d8@0aS60TYB0a240SF]0e:D0Re[0d8@0U:D0cW>1@Q20cg_0V<H0bU:1`000`Q20QBU
0c6<0dic1EJe0THa0b480Q240`aS0QBU0fLi0QS60bDY0Woo00<007ooOol027oo00<007ooJeX00V]J
1`000goo0P000`@Q0`Q20S6<0dic0T8@0be[0RDY0bU:0`@Q0VLi0eJe0TYB0fmk0g>L0Tic0eJe0Ukg
0c6<0Ukg0f<H0e:D0V<H0gNm1Goo0P@Q0`aS0bDY0TYB0ekg0QcW0cF]0S6<0aS60Woo00<007ooOol0
27oo0009Ool00`00Oom[FP02JeX5IcT2HaP5G_L6F]H2DY@39BT2HaP3E[D2G_L3>Lh35:D59BT2Kg/3
JeX3Li`2JeX3>Lh5:DX2;F/3:DX3;F/2<H`3;F/2:DX3;F/2:DX69BT28@P35:D27>L38@P2IcT3=Jd2
Ool00`00Oomoo`08Ool00`00OomJeP02F]H2E[D3CW<2AS43>Lh2;F/39BT27>L3@Q036<H2BU8348@2
=Jd3DY@2;F/3@Q02DY@3>Lh52483?Nl2HaP3:DX7000324825:D3<H`3CW<5E[D2AS438@P248@336<2
5:D3IcT26<H39BT2Ool00`00Oomoo`08Ool00`00Oom[FP02JeX70003Ool2000312432482<H`3CW<2
@Q03;F/29BT3:DX31242IcT3E[D2BU83Kg/3Li`2CW<3E[D2G_L3<H`2G_L3HaP3DY@2HaP3Mkd5Ool2
124336<39BT2BU83G_L27>L3=Jd2<H`36<H2Ool00`00Oomoo`08Ool000Uoo`03001oof]J00A[FPEW
>@=S60ENm`=F]@9BU0<YBP9Nm`=S609JeP=BU0<aS09S60EW>@=[FP=_N`9[FP<U:@XYBP<]J`8aS0=F
]@Y[FP<YBP8Li`<DY@8@Q0<Li`9W>@<icP9oo`03001oogoo00Qoo`03001oocW>008icPX48@D8@P8<
H`<mk`<@Q096<@<48@8HaPE6<@=JeP8mk`<Q2088@P<HaP=S609:DPP0008HaP<mk`9F]@IW>@9Nm`=J
ePEW>@8aS0D<H`=[FP8U:@<8@P9oo`03001oogoo00Qoo`03001ood8@0092408aS0<U:@8YBP<]J`8m
k`I:DPM240<Q20DU:@=oo`9[FP=_N`9BU0<e[@=S60EBU08<H`=S609240=S60Q_N`9kgPD000<@Q0<Q
208]J`=>L`8Li`<mk`9240=S609oo`03001oogoo00Qoo`002Goo00<007ooJeX016]J1FLi0f<H1Ekg
0eJe0U:D0bU:0Ukg0f<H0U[F0e:D0c6<0V<H1FLi0f]J0fmk0V]J0bDY2RU:0be[0S6<0eJe2V]J0bU:
0QcW0aBU0Q240acW0VLi0cW>0Woo00<007ooOol027oo00<007oo>Lh00SW>2P@Q1@Q20PaS0cg_0a24
0THa0`@Q0QS61DHa0e[F0Sg_0b480PQ20aS60f<H0TYB20000QS60cg_0UJe1VLi0Ukg0e[F1FLi0S6<
1@aS0f]J0RDY0`Q20Woo00<007ooOol027oo00<007oo@Q000T8@0S6<0bDY0RU:0be[0Sg_1TYB1d8@
0b481BDY0goo0V]J0fmk0U:D0cF]0f<H1E:D0PaS0f<H0T8@0f<H26mk0W_N1@000a240b480Re[0dic
0QcW0cg_0T8@0f<H0Woo00<007ooOol027oo0009Ool00`00Oom[FP07JeX2IcT3HaP2G_L6E[D2DY@3
:DX2HaP3G_L2HaP3G_L3CW<7HaP3Kg/3JeX2=Jd39BT7:DX3;F/3G_L2Kg/3Li`2Ool5Kg/6JeX28@P3
5:D248@36<H2JeX3?Nl2Ool00`00Oomoo`08Ool00`00Oole[@02=Jd21243000212452483124236<3
@Q0348@2BU83000236<39BT27>L36<H236<348@22483@Q03IcT28@P51243:DX2F]H3HaP2BU83;F/5
36<324828@P3HaP2JeX38@P22483JeX2<H`32482Ool00`00Oomoo`08Ool00`00Oolmk`02?Nl2G_L3
@Q02<H`3@Q02BU83>Lh3:DX2?Nl3=Jd2?Nl3Li`25:D38@P3Nmh2AS435:D2<H`3;F/3DY@2E[D3F]H2
CW<3JeX5IcT3Kg/2Li`3IcT2Li`59BT38@P39BT2:DX3<H`2:DX3>Lh2=Jd3<H`2Ool00`00Oomoo`08
Ool000Uoo`03001oof]J00M[FP9W>@=S609Nm`IF]@9BU0<YBP9S60=Nm`9S60=Nm`=>L`MS60=_N`=[
FP8e[@<U:@LYBP<]J`=Nm`9_N`=cW09oo`E_N`I[FP8Q20<DY@8@Q0<HaP9[FP<mk`9oo`03001oogoo
00Qoo`03001oocF]008e[@848@<000848@D8@P<48@8<H`=240<@Q09:DP<0008<H`<U:@8Li`<HaP8<
H`<@Q088@P=240=W>@8Q20D48@<YBP9JeP=S609:DP<]J`D<H`<8@P8Q20=S609[FP<Q2088@P=[FP8a
S0<8@P9oo`03001oogoo00Qoo`03001oocg_008mk`9Nm`=2408aS0=2409:DP<icP<YBP8mk`<e[@8m
k`=cW08DY@<Q20=kgP96<@<DY@8aS0<]J`=BU09F]@=JeP9>L`=[FPEW>@=_N`9cW0=W>@9cW0DU:@<Q
20<U:@8YBP<aS08YBP<icP8e[@<aS09oo`03001oogoo00Qoo`002Goo00<007ooJeX01f]J0VLi0f<H
0Ukg1UJe0U:D0bU:0V<H0ekg0V<H0ekg0dic1f<H0fmk0f]J0SF]0bDY1bU:0be[0ekg0Vmk0g>L0Woo
1Fmk1V]J0R480aBU0Q240aS60V]J0cg_0Woo00<007ooOol027oo00<007oo=Jd00SF]0P@Q0`000P@Q
1@Q20`@Q0PaS0d8@0a240TYB0`000PaS0bDY0QcW0aS60PaS0a240PQ20d8@0fLi0R481@@Q0bU:0U[F
0f<H0TYB0be[1@aS0`Q20R480f<H0V]J0b480PQ20f]J0S6<0`Q20Woo00<007ooOol027oo00<007oo
?Nl00Sg_0Ukg0d8@0S6<0d8@0TYB0cW>0bU:0Sg_0cF]0Sg_0g>L0QBU0b480g_N0THa0aBU0S6<0be[
0e:D0UJe0e[F0Tic0f]J1FLi0fmk0W>L0fLi0W>L1BDY0b480bDY0RU:0c6<0RU:0cW>0SF]0c6<0Woo
00<007ooOol027oo0009Ool00`00OomW>@02IcT2JeX3IcT2JeX3HaP2F]H6G_L2E[D38@P2F]H5HaP6
G_L5E[D2IcT6JeX28@P5:DX3;F/2>Lh3Li`8Kg/5Li`2Kg/3IcT3JeX2CW<548@35:D2DY@3@Q02Ool0
0`00Oomoo`08Ool00`00Ool]J`02;F/50002124336<512422483BU8336<2CW<32482000336<22483
000224855:D3F]H3DY@52482:DX5G_L3:DX=24821243<H`2Nmh3AS422483DY@2?Nl37>L2Ool00`00
Oomoo`08Ool00`00Oom24002@Q02DY@3G_L2DY@3AS42?Nl36<H3<H`2?Nl3<H`2>Lh37>L2Ool3:DX3
2482Li`38@P29BT30005CW<336<2>Lh3G_L2HaP3IcT3Kg/2G_L38@P2Ool3G_L2CW<3BU83<H`5=Jd5
>Lh2;F/3=Jd2Ool00`00Oomoo`08Ool000Uoo`03001oofLi009W>@9[FP=W>@9[FP=S609JePINm`9F
]@<Q209JePES60INm`EF]@9W>@I[FP8Q20DYBP<]J`8icP=cW0Q_N`EcW09_N`=W>@=[FP9>L`D@Q0<D
Y@9BU0=2409oo`03001oogoo00Qoo`03001oobe[008]J`D000848@<<H`D48@88@P=:DP<<H`9>L`<8
@P8000<<H`88@P<00088@PDDY@=JeP=BU0D8@P8YBPENm`<YBPd8@P848@<aS09kgP=6<@88@P=BU08m
k`<Li`9oo`03001oogoo00Qoo`03001ood8@0092409BU0=Nm`9BU0=6<@8mk`<HaP<aS08mk`<aS08i
cP<Li`9oo`<YBP<8@P9cW0<Q208U:@<000E>L`<<H`8icP=Nm`9S60=W>@=_N`9Nm`<Q209oo`=Nm`9>
L`=:DP<aS0De[@DicP8]J`<e[@9oo`03001oogoo00Qoo`002Goo00<007ooJeX016]J1FLi0f<H1Ekg
1EJe0b480U[F0eJe0V<H2ekg0UJe0f<H0dYB0R481BDY0cW>0V]J0gNm0g>L0Vmk1G>L0fmk0V]J0fmk
0fLi0Ukg0`aS0QBU0aS60SW>0dYB0Woo00<007ooOol027oo00<007oo:DX00RU:1`@Q0`Q21@@Q0PQ2
0dHa0`@Q0TYB0`Q20PaS1@@Q20Q20R480f<H0cF]0PaS0bU:0Ukg0eJe0QcW1@@Q0`000`@Q1@Q20PaS
0aS60Vmk0e[F0PaS1Cg_0c6<0Woo00<007ooOol027oo00<007ooAS400THa0SW>0eJe0Ukg0dic0SW>
0dic0e:D0Sg_0eJe0Sg_0aBU0PQ20`aS0`000PQ20`000SW>0f<H0e:D0UJe0bU:0U:D1Ekg0e[F0aBU
0P000aBU0VLi0f<H0VLi0ekg0e:D1Cg_0TYB0d8@0Sg_0d8@0Woo00<007ooOol027oo0009Ool00`00
Oom[FP04JeX5IcT3HaP5G_L5E[D38@P2F]H3E[D2HaP;G_L2E[D3HaP3BU828@P59BT3>Lh2JeX3Mkd3
Li`2Kg/5Li`3Kg/2JeX3Kg/3IcT2G_L336<25:D36<H2>Lh3BU82Ool00`00Oomoo`08Ool00`00OolY
BP02:DX71243248512422483AS431242BU83248236<5124824828@P3HaP3=Jd236<3:DX2G_L3E[D2
7>L5124300031245248236<36<H2Kg/3F]H236<5?Nl3<H`2Ool00`00Oomoo`08Ool00`00Oom6<@02
AS42>Lh3E[D2G_L3CW<2>Lh3CW<3DY@2?Nl3E[D2?Nl35:D2248336<3000224830002>Lh3HaP3DY@2
E[D3:DX2DY@5G_L3F]H35:D200035:D2IcT3HaP2IcT3G_L3DY@5?Nl2BU83@Q02?Nl3@Q02Ool00`00
Oomoo`08Ool000Uoo`03001oof]J00A[FPEW>@=S60ENm`EF]@<Q209JeP=F]@9S60]Nm`9F]@=S60=:
DP8Q20DU:@<icP9[FP=g_@=cW09_N`EcW0=_N`9[FP=_N`=W>@9Nm`<<H`8DY@<HaP8icP=:DP9oo`03
001oogoo00Qoo`03001oobU:008YBPL48@<8@PD48@88@P=6<@<48@9:DP<8@P8<H`D48@P8@P8Q20=S
60<e[@8<H`<YBP9Nm`=F]@8Li`D48@<000<48@D8@P8<H`<HaP9_N`=JeP8<H`Dmk`<aS09oo`03001o
ogoo00Qoo`03001oodHa0096<@8icP=F]@9Nm`=>L`8icP=>L`=BU08mk`=F]@8mk`<DY@88@P<<H`<0
0088@P<0008icP=S60=BU09F]@<YBP9BU0ENm`=JeP<DY@8000<DY@9W>@=S609W>@=Nm`=BU0Dmk`9:
DP=2408mk`=2409oo`03001oogoo00Qoo`002Goo00<007ooJeX00V]J1FLi0V<H0ekg0V<H0e[F1EJe
0bU:0UJe0f<H0U:D0e[F3F<H0be[0QS60bDY0RU:1Fmk0g>L0fmk0W_N1Fmk1F]J0f<H0eJe0U[F1A24
0acW0THa0dic0Woo00<007ooOol027oo00<007oo9BT00RDY2P@Q0P001@Q20cg_0`@Q0THa0`@Q0P00
0`aS0PQ20`@Q0P000`Q20Sg_0ekg0a240R481E[F0acW0P@Q1@000`@Q20Q20QBU0a240V<H0ekg0QS6
0dHa0SF]0c6<0Woo00<007ooOol027oo00<007oo@Q000T8@0Sg_0cW>0Sg_0d8@0SF]0d8@0dHa0T8@
0dHa0T8@0g>L0Tic1QBU0QS60`000WNm0dHa0dic0Ukg25Je0U[F0c6<0bU:0V<H0be[0SF]0dHa0Ukg
1UJe0T8@0cg_1dic0dHa0Woo00<007ooOol027oo0009Ool00`00Oom[FP02JeX5IcT2HaP3G_L2HaP3
F]H5E[D3:DX2E[D3HaP2DY@3F]H=HaP3;F/26<H39BT2:DX5Kg/3Li`3Kg/2Nmh5Kg/5JeX3HaP3E[D2
F]H548@37>L2AS43CW<2Ool00`00Oomoo`08Ool00`00OolU:@029BT:124200052483?Nl31242AS43
1242000336<22483124200032482?Nl3G_L348@28@P5F]H37>L212450003124824825:D348@2HaP3
G_L26<H3AS42=Jd3<H`2Ool00`00Oomoo`08Ool00`00Oom24002@Q02?Nl3>Lh2?Nl3@Q02=Jd3@Q03
AS42@Q03AS42@Q03Li`2CW<65:D26<H30002Mkd3AS43CW<2G_L8E[D2F]H3<H`3:DX2HaP3;F/2=Jd3
AS42G_L6E[D2@Q03?Nl7CW<3AS42Ool00`00Oomoo`08Ool000Uoo`03001oof]J009[FPEW>@9S60=N
m`9S60=JePEF]@<YBP9F]@=S609BU0=JePeS60<]J`8HaP<U:@8YBPE_N`=cW0=_N`9kgPE_N`E[FP=S
60=F]@9JePD@Q0<Li`96<@=>L`9oo`03001oogoo00Qoo`03001oobDY008U:@X48@8000D8@P<mk`<4
8@96<@<48@8000<<H`88@P<48@8000<8@P8mk`=Nm`<@Q08Q20EJeP<Li`848@D000<48@P8@P8DY@<@
Q09S60=Nm`8HaP=6<@8e[@<aS09oo`03001oogoo00Qoo`03001ood8@0092408mk`<icP8mk`=2408e
[@=240=6<@9240=6<@9240=cW09>L`HDY@8HaP<0009g_@=6<@=>L`9Nm`QF]@9JeP<aS0<YBP9S60<]
J`8e[@=6<@9Nm`IF]@9240<mk`M>L`=6<@9oo`03001oogoo00Qoo`002Goo00<007ooJeX016]J1FLi
25kg1EJe0bDY0UJe1Ekg1UJe0U[F26<H0acW0R480bU:0Tic0fmk0V]J1W>L0Vmk0g>L0WNm1F]J0fLi
0ekg0U[F0aBU0Q240cF]0THa0dYB0Woo00<007ooOol027oo00<007oo9BT00RDY0PQ20`001@Q20P@Q
0`aS0PQ20cg_0`000TYB0`Q20PaS0`000PQ20a240PaS0`000UJe0e[F0`Q20T8@0fLi0Re[0`001@@Q
0PQ21P@Q0PaS0b480Sg_0dYB0Ukg0dic0S6<0dic0QcW0c6<0Woo00<007ooOol027oo00<007ooAS40
0THa0SF]0b480QS60b480QBU1S6<0Sg_0f]J0T8@0eJe0RDY0b480`Q20PaS0b480QBU1THa0Re[0dic
0U:D0eJe0T8@0be[0`Q20P000goo1CW>0U[F0fLi0gNm0Ukg0dYB0Tic1E:D0d8@0Woo00<007ooOol0
27oo0009Ool00`00Oom[FP04JeX5IcT8G_L5E[D39BT2E[D5G_L6E[D2F]H8HaP37>L28@P3:DX2CW<3
Kg/2JeX6Li`2Kg/3Li`2Mkd5JeX3IcT3G_L2F]H35:D248@3=Jd2AS43BU82Ool00`00Oomoo`08Ool0
0`00OolU:@029BT2248300052482124336<22483?Nl30002BU83248236<30002248348@236<30002
E[D3F]H32482@Q03IcT2;F/3000512422486124236<38@P2?Nl3BU82G_L3CW<2<H`3CW<27>L3<H`2
Ool00`00Oomoo`08Ool00`00Oom6<@02AS42=Jd38@P26<H38@P25:D6<H`2?Nl3JeX2@Q03E[D29BT3
8@P3248236<38@P25:D6AS42;F/3CW<2DY@3E[D2@Q03;F/324820003Ool5>Lh2F]H3IcT3Mkd2G_L3
BU82CW<5DY@3@Q02Ool00`00Oomoo`08Ool000Uoo`03001oofmk009_N`9[FP=S609[FP=W>@9S60=N
m`=F]@9JeP<YBP9F]@ES60=F]@=Nm`9:DP=Nm`9S60=Nm`<DY@8Li`<U:@9cW0e_N`=[FP9_N`=cW09S
60<e[@<Li`8HaPD@Q0=F]@9240=BU09oo`03001oogoo00Qoo`03001oob48008Q2088@P<48@8000<8
@P848@<<H`88@P<icP<48@96<@<8@P848@D<H`<0008@Q0<8@P9Nm`=JeP<DY@ES608DY@<<H`L48@<8
@P<Li`96<@=[FP9_N`=W>@9BU0<YBP9:DP=6<@8<H`<e[@9oo`03001oogoo00Qoo`03001ood8@0092
408e[@<Q20De[@8]J`<icP<]J`8icP<0009240<icP8YBP<@Q0<Li`9oo`<U:@8Li`I2408YBP=24096
<@=W>@9g_@<HaP=Nm`9g_@<8@PM[FP=_N`=g_@9_N`=Nm`9240=:DP9[FP=6<@9oo`03001oogoo00Qo
o`002Goo00<007ooKg/00Vmk0V]J0f<H0V]J0fLi0V<H0ekg0eJe0U[F0bU:0UJe1F<H0eJe0ekg0TYB
0ekg0V<H0ekg0aBU0QcW0bDY0W>L3Fmk0f]J0Vmk0g>L0V<H0cF]0acW0QS61A240eJe0T8@0e:D0Woo
00<007ooOol027oo00<007oo8@P00R480PQ20`@Q0P000`Q20P@Q0`aS0PQ20cW>0`@Q0THa0`Q20P@Q
1@aS0`000Q240`Q20Ukg0e[F0aBU1F<H0QBU0`aS1`@Q0`Q20acW0THa0f]J0Vmk0fLi0U:D0bU:0TYB
0dHa0PaS0cF]0Woo00<007ooOol027oo00<007oo@Q000T8@0SF]0b481CF]0Re[0cW>0be[0SW>0`00
0T8@0cW>0RU:0a240acW0Woo0bDY0QcW1T8@0RU:0d8@0THa0fLi0WNm0aS60ekg0WNm0`Q21f]J0fmk
0gNm0Vmk0ekg0T8@0dYB0V]J0dHa0Woo00<007ooOol027oo0009Ool00`00Oom_N`02Kg/2JeX3HaP2
JeX3IcT2HaP3G_L3E[D2F]H3:DX2E[D5HaP3E[D3G_L2BU83G_L2HaP3G_L35:D27>L39BT2Li`=Kg/3
JeX2Kg/3Li`2HaP3=Jd37>L26<H548@3E[D2@Q03DY@2Ool00`00Oomoo`08Ool00`00OolQ20028@P2
2483124200032482124336<22483>Lh31242AS432482124536<3000248@32482G_L3F]H35:D5HaP2
5:D336<7124324837>L2AS43JeX2Kg/3IcT2DY@3:DX2BU83AS4236<3=Jd2Ool00`00Oomoo`08Ool0
0`00Oom24002@Q02=Jd38@P5=Jd2;F/3>Lh3;F/2>Lh30002@Q03>Lh2:DX348@37>L2Ool39BT27>L6
@Q02:DX3@Q02AS43IcT2Mkd36<H3G_L2Mkd32487JeX3Kg/3Mkd2Kg/3G_L2@Q03BU82JeX3AS42Ool0
0`00Oomoo`08Ool000Uoo`03001oof]J00M[FP9W>@ES60=Nm`=JeP9F]@<]J`EJeP9Nm`=W>@ENm`=F
]@9JeP=W>@DDY@<Li`E_N`9oo`=cW0=_N`M[FP<icP8Li`HDY@L@Q0=>L`96<@=F]@9oo`03001oogoo
00Qoo`03001ooacW008Li``48@<8@P848@<mk`<0009240D8@P<0008<H`P8@PENm`<@Q09cW0=S608<
H`D48@D8@P<Q20=JeP9cW0=Nm`8e[@<HaP8<H`<0009F]@=24088@P<aS09oo`03001oogoo00Qoo`03
001ood8@0092408e[@<icP9F]@=JeP9:DP=240<icP9240<<H`8mk`DDY@=S60<YBP8@Q0=S608icPI2
408aS0Dmk`<YBP8U:@<]J`<DY@8aS0=S609W>@Q[FPEW>@=oo`9240=6<@9[FP=6<@9oo`03001oogoo
00Qoo`002Goo00<007ooJeX01f]J0VLi1F<H0ekg0e[F0UJe0be[1E[F0Ukg0fLi1Ekg0eJe0U[F0fLi
1ABU0acW1Fmk0Woo0g>L0fmk1f]J0cW>0QcW1QBU1a240dic0THa0eJe0Woo00<007ooOol027oo00<0
07oo7>L00QcW30@Q0`Q20P@Q0cg_0`000T8@1@Q20`000PaS20Q21Ekg0a240W>L0f<H0PaS1@@Q1@Q2
0b480e[F0W>L0ekg0SF]0aS60PaS0`000UJe0d8@0PQ20c6<0Woo00<007ooOol027oo00<007oo@Q00
0T8@0SF]0cW>0UJe0e[F0TYB0d8@0cW>0T8@0`aS0Sg_1ABU0f<H0bU:0Q240f<H0SW>1T8@0S6<1Cg_
0bU:0RDY0be[0aBU0S6<0f<H0VLi26]J1FLi0goo0T8@0dHa0V]J0dHa0Woo00<007ooOol027oo0009
Ool00`00Oom[FP04JeX5IcT5HaP3G_L3F]H2E[D3:DX5F]H2DY@3HaP5F]H3G_L2HaP3F]H348@25:D3
8@P5JeX5Kg/3Nmh2Kg/3JeX2:DX38@P27>L65:D236<348@25:D3F]H2AS43E[D2Ool00`00Oomoo`08
Ool00`00OolHaP026<H20008124524821243@Q031242@Q03000224835:D22483000224831242HaP3
G_L348@2Kg/3HaP236<348@2248300029BT3G_L3IcT2=Jd36<H236<312450002CW<3AS4236<3;F/2
Ool00`00Oomoo`08Ool00`00Oom24002@Q02CW<3@Q02=Jd3@Q08DY@2@Q032482?Nl3Li`200032483
0002Kg/3Li`2Nmh6@Q02=Jd5?Nl35:D248@336<3G_L2DY@3G_L5HaP2DY@3BU83CW<2=Jd3CW<2>Lh5
=Jd3@Q02Ool00`00Oomoo`08Ool000Uoo`03001oof]J00A[FPEW>@ES60=Nm`=JeP9F]@<YBPEJeP9B
U0=S60EJeP=Nm`9S60=JeP<@Q08DY@<Q20E[FPE_N`=kgP9_N`=[FP8YBP<Q208Li`HDY@8<H`<@Q08D
Y@=JeP96<@=F]@9oo`03001oogoo00Qoo`03001ooaS6008HaP8000P48@D8@P848@=240<48@9240<0
0088@P<DY@88@P<00088@P<48@9S60=Nm`<@Q09_N`=S608<H`<@Q088@P<0008U:@=Nm`=W>@8e[@<H
aP8<H`<48@D0009>L`=6<@8<H`<]J`9oo`03001oogoo00Qoo`03001ood8@0092409>L`=2408e[@=2
40QBU09240<8@P8mk`=cW08000<8@P<0009_N`=cW09kgPI2408e[@Dmk`<DY@8@Q0<<H`=Nm`9BU0=N
m`ES609BU0=:DP=>L`8e[@=>L`8icPDe[@=2409oo`03001oogoo00Qoo`002Goo00<007ooJeX016]J
1FLi1F<H0ekg0e[F0UJe0bU:1E[F0U:D0f<H1E[F0ekg0V<H0e[F0a240QBU0b481F]J1Fmk0g_N0Vmk
0f]J0RU:0b480QcW1QBU0PaS0a240QBU0e[F0THa0eJe0Woo00<007ooOol027oo00<007oo6<H00QS6
0P0020@Q1@Q20P@Q0d8@0`@Q0T8@0`000PQ20aBU0PQ20`000PQ20`@Q0V<H0ekg0a240Vmk0f<H0PaS
0a240PQ20`000RDY0ekg0fLi0SF]0aS60PaS0`@Q1@000Tic0dHa0PaS0be[0Woo00<007ooOol027oo
00<007oo@Q000T8@0Tic0d8@0SF]0d8@25:D0T8@0`Q20Sg_0g>L0P000`Q20`000Vmk0g>L0W_N1T8@
0SF]1Cg_0aBU0Q240`aS0ekg0U:D0ekg1F<H0U:D0dYB0dic0SF]0dic0SW>1CF]0d8@0Woo00<007oo
Ool027oo0009Ool00`00Oom[FP07JeX2IcT3HaP2G_L3F]H5E[D3:DX2E[D3F]H2G_L3BU83F]H5G_L2
HaP3F]H55:D37>L7JeX3Kg/3JeX2Li`3;F/29BT38@P26<H35:D:48@3=Jd2CW<3E[D2Ool00`00Oomo
o`08Ool00`00OolDY@025:D21243000:24821243@Q031242AS4312422483124536<224830002IcT3
G_L336<2Li`3IcT5000224836<H2E[D3IcT3:DX536<2248312450002=Jd3E[D2:DX39BT2Ool00`00
Oomoo`08Ool00`00Oole[@02=Jd2Mkd3BU82@Q03E[D2DY@3CW<3F]H2@Q03Nmh2?Nl3BU829BT3E[D3
5:D26<H39BT236<3?Nl3@Q02:DX5?Nl3JeX2<H`348@3Li`7F]H3CW<2@Q03>Lh3:DX28@P3Ool5;F/2
>Lh3AS42Ool00`00Oomoo`08Ool000Uoo`03001oof]J00M[FP9W>@=S609Nm`=JePEF]@<YBP9F]@=J
eP9Nm`=:DP=JePENm`9S60=JePDDY@<Li`M[FP=_N`=[FP9cW0<]J`8U:@<Q208HaP<DY@X@Q0<e[@9>
L`=F]@9oo`03001oogoo00Qoo`03001ooaBU008DY@848@<000X8@P848@=240<48@96<@<48@88@P<4
8@D<H`88@P<0009W>@=Nm`<<H`9cW0=W>@D00088@P<HaP9F]@=W>@<YBPD<H`88@P<48@D0008e[@=F
]@8YBP<U:@9oo`03001oogoo00Qoo`03001oocF]008e[@9g_@=:DP9240=F]@9BU0=>L`=JeP9240=k
gP8mk`=:DP8U:@=F]@<DY@8HaP<U:@8<H`<mk`=2408YBPDmk`=[FP8aS0<@Q0=cW0MJeP=>L`9240<i
cP<YBP8Q20=oo`D]J`8icP=6<@9oo`03001oogoo00Qoo`002Goo00<007ooIcT00VLi0V<H0f]J0VLi
0ekg0V<H0e[F1EJe0bDY0UJe0e[F1Ekg0dYB0UJe0e[F0V<H0fLi0`aS1ABU0Vmk0f]J0Vmk0fLi0fmk
0THa0bU:1B480QS61QBU1a240aS61E[F0Woo00<007ooOol027oo00<007oo48@00Q240P@Q0`000PaS
0`Q20P@Q0`Q20P@Q0cg_0`000THa1@@Q0a240P@Q0`Q20Q240`aS1FLi0`Q20VLi0g>L0Q241@@Q0c6<
0VLi0cW>20aS1@@Q0PaS0`Q20Q240ekg0TYB0aBU0Woo00<007ooOol027oo00<007oo=Jd00SF]0PQ2
0aBU0THa0dic0U:D248@0dic1D8@0Q240b480`Q20QcW0b480SW>1Sg_0U:D0cW>1CF]0QS60eJe0e[F
1EJe0THa0d8@0THa0cW>0`000P@Q0b480RDY0cF]0Sg_0d8@0Woo00<007ooOol027oo0009Ool00`00
OomW>@02IcT2HaP3JeX2IcT3G_L2HaP3F]H5E[D39BT2E[D3F]H5G_L3BU82E[D3F]H2HaP3IcT336<5
5:D2Kg/3JeX2Kg/3IcT3Kg/2AS43:DX58@P26<H65:D748@36<H5F]H2Ool00`00Oomoo`08Ool00`00
Ool@Q00248@21243000236<32482124324821243?Nl30002AS45124348@21243248248@336<5IcT3
2482IcT3Li`248@51243<H`2IcT3>Lh836<5124236<3248248@3G_L2BU835:D2Ool00`00Oomoo`08
Ool00`00Oole[@02=Jd224835:D2AS43CW<2DY@8@Q03CW<5@Q0248@38@P324827>L38@P2>Lh6?Nl2
DY@3>Lh5=Jd26<H3E[D3F]H5E[D2AS43@Q02AS43>Lh3000212438@P29BT3=Jd2?Nl3@Q02Ool00`00
Oomoo`08Ool000Uoo`03001oofLi009W>@9S60=[FP9W>@=Nm`9S60=JePEF]@<U:@9F]@=JePENm`=:
DP9F]@=JeP9S60=W>@<<H`DDY@9_N`=[FP9_N`=W>@=_N`96<@<YBPDQ208HaPHDY@L@Q0<HaPEJeP9o
o`03001oogoo00Qoo`03001ooa24008@Q0848@<0008<H`<8@P848@<8@P848@<mk`<00096<@D48@<@
Q0848@<8@P8@Q0<<H`EW>@<8@P9W>@=cW08@Q0D48@<aS09W>@<icPP<H`D48@8<H`<8@P8@Q0=Nm`9:
DP<DY@9oo`03001oogoo00Qoo`03001oocF]008e[@88@P<DY@96<@=>L`9BU0Q240=>L`E2408@Q0<Q
20<8@P8Li`<Q208icPHmk`9BU0<icPDe[@8HaP=F]@=JePEF]@96<@=24096<@<icP<000848@<Q208U
:@<e[@8mk`=2409oo`03001oogoo00Qoo`002Goo00<007ooJeX00V]J0V<H1FLi0ekg25[F0U:D0bU:
1e[F0ekg1E[F0dic1F<H0aS60QBU0aS60T8@1G>L0f]J0fLi1BU:0RDY0b4821BU0R480aS60PaS0a24
1EJe0Woo00<007ooOol027oo00<007oo48@00Q241@001@Q21@@Q0PQ20cg_0`@Q0Sg_1@@Q0`001`aS
0a240V<H0fLi0`@Q0T8@0g_N0T8@0`000QBU0eJe0U:D0a241@Q20b480T8@0eJe0Ukg0e:D0RDY0eJe
0U[F0acW0Woo00<007ooOol027oo00<007ooAS400THa0PQ20acW1DHa0Ukg0dYB1D8@0eJe0T8@1ABU
0be[1@aS0eJe0TYB0cg_0cW>0PaS0c6<0Re[0bU:0PaS0dYB1E:D0e[F0T8@0aS627_N0Woo0a240QcW
0cW>0SF]0c6<0Woo00<007ooOol027oo0009Ool00`00Oom[FP02JeX2HaP5IcT3G_L8F]H2DY@3:DX7
F]H3G_L5F]H3CW<5HaP36<H25:D36<H2@Q05Li`3JeX3IcT5:DX29BT38@P85:D28@P36<H236<348@5
E[D2Ool00`00Oomoo`08Ool00`00Ool@Q00248@50005248512422483?Nl31242?Nl51243000736<3
48@2HaP3IcT31242@Q03Nmh2@Q0300025:D3E[D2DY@348@524838@P2@Q03E[D2G_L3DY@29BT3E[D2
F]H37>L2Ool00`00Oomoo`08Ool00`00Oom6<@02AS4224837>L5AS42G_L3BU85@Q03E[D2@Q055:D3
;F/536<3E[D2BU83?Nl3>Lh236<3<H`2;F/3:DX236<3BU85DY@3F]H2@Q036<H8Nmh2Ool348@27>L3
>Lh2=Jd3<H`2Ool00`00Oomoo`08Ool000Uoo`03001oof]J009[FP9S60EW>@=Nm`QJeP9BU0<YBPMJ
eP=Nm`EJeP=>L`ES60<HaP8DY@<HaP9240EcW0=[FP=W>@DYBP8U:@<Q20PDY@8Q20<HaP8<H`<@Q0EF
]@9oo`03001oogoo00Qoo`03001ooa24008@Q0D000D8@PD48@88@P<mk`<48@8mk`D48@<000L<H`<@
Q09S60=W>@<48@9240=kgP9240<0008DY@=F]@9BU0<@Q0D8@P<Q209240=F]@9Nm`=BU08U:@=F]@9J
eP<Li`9oo`03001oogoo00Qoo`03001oodHa0096<@88@P<Li`E6<@9Nm`=:DPE240=F]@9240DDY@<]
J`D<H`=F]@9:DP<mk`<icP8<H`<aS08]J`<YBP8<H`=:DPEBU0=JeP9240<HaPQkgP9oo`<@Q08Li`<i
cP8e[@<aS09oo`03001oogoo00Qoo`002Goo00<007ooIcT00VLi0V]J0fLi0V<H0ekg0U[F0ekg0eJe
0U:D0bU:1eJe0e[F25kg1FLi0b480Q240aBU0R480e[F0V]J0gNm0d8@0RDY0bU:1B480SF]0dic0eJe
0U[F0eJe0QcW0a240Sg_0eJe0Woo00<007ooOol027oo00<007oo5:D00QBU1@000PQ20`aS0P000`@Q
0PaS0cW>0`@Q0Sg_0`@Q0PQ20`aS1@@Q1@aS0UJe0f]J0`aS0QcW0ekg0Vmk0cW>0SF]0fLi0Re[0`00
0aS60THa1E[F0e:D0THa0e[F0UJe0cW>0Ukg0bU:0Woo00<007ooOol027oo00<007oo?Nl00Sg_0Q24
0b481d8@0dYB0dHa0T8@0be[0Sg_0gNm0Woo0aBU0bDY0R480e[F0TYB0cg_0cW>0S6<0be[0RU:0b48
0QS60e[F0e:D0UJe0goo0Vmk0g>L1GNm0g_N0Woo0aS60RU:0dHa0Sg_0cW>0Woo00<007ooOol027oo
0009Ool00`00OomW>@02IcT2JeX3IcT2HaP3G_L2F]H3G_L3E[D2DY@3:DX7E[D3F]H8G_L5IcT38@P2
48@35:D28@P3F]H2JeX3Mkd3@Q029BT3:DX58@P2=Jd3CW<3E[D2F]H3E[D27>L348@2?Nl3E[D2Ool0
0`00Oomoo`08Ool00`00OolDY@025:D50002248336<20003124236<3>Lh31242?Nl31242248336<5
124536<2E[D3JeX336<27>L3G_L2Kg/3>Lh2=Jd3IcT2;F/300036<H2AS45F]H3DY@2AS43F]H2E[D3
>Lh2G_L3:DX2Ool00`00Oomoo`08Ool00`00Oolmk`02?Nl248@38@P7@Q03BU83AS42@Q03;F/2?Nl3
Mkd2Ool35:D39BT28@P3F]H2BU83?Nl3>Lh2<H`3;F/2:DX38@P26<H3F]H3DY@2E[D3Ool2Kg/3Li`5
Mkd3Nmh2Ool36<H2:DX3AS42?Nl3>Lh2Ool00`00Oomoo`08Ool000Uoo`03001oof]J009[FP9W>@=[
FP9W>@ENm`=JePEF]@<U:@EF]@9BU0=>L`QJePES60<aS08DY@DHaP<YBP9>L`=W>@<YBPDU:@8]J`=J
eP9Nm`=JeP=F]@9>L`=JeP8aS0<<H`9BU0=F]@9oo`03001oogoo00Qoo`03001ooaS6008HaP8000<4
8@8<H`<8@P8000<48@88@P<mk`<0008mk`<48@D8@P8DY@D8@P<48@96<@=[FP<Li`8@Q0<aS09>L`Dm
k`=S608<H`<YBPEF]@<e[@8HaPD8@P<e[@9Nm`<YBP9Nm`<U:@9oo`03001oogoo00Qoo`03001ood8@
0092408<H`<icPE6<@9240<icP<]J`8mk`=>L`9240<<H`8]J`<8@P<HaP8U:@=>L`96<@HicP8aS0=:
DP9240DicPI:DP9[FP=Nm`9W>@=cW0Eg_@<@Q09F]@=6<@M240=6<@9oo`03001oogoo00Qoo`002Goo
00<007ooJeX00V]J0VLi0f]J0VLi1Ekg0e[F1EJe0bDY1EJe0U:D0dic25[F1F<H0c6<0QBU1AS60bU:
0Tic0fLi0bU:1BDY0Re[0e[F0Ukg0e[F0eJe0Tic0e[F0S6<0`aS0U:D0eJe0Woo00<007ooOol027oo
00<007oo6<H00QS60P000`@Q0PaS0`Q20P000`@Q0PQ20cg_0`000Sg_0`@Q1@Q20QBU1@Q20`@Q0THa
0f]J0acW0Q240c6<0Tic1Cg_0f<H0PaS0bU:1EJe0cF]0QS61@Q20cF]0Ukg0bU:0Ukg0bDY0Woo00<0
07ooOol027oo00<007oo@Q000T8@0PaS0cW>1DHa0T8@0cW>0be[0Sg_0dic0T8@0`aS0Re[0`Q20aS6
0RDY0dic0THa1SW>0S6<0dYB0T8@1CW>1TYB0V]J0ekg0VLi0g>L1GNm0a240UJe0dHa1d8@0dHa0Woo
00<007ooOol027oo0009Ool00`00Oom[FP02JeX2IcT3JeX2IcT5G_L3F]H5E[D39BT5E[D2DY@3CW<8
F]H5HaP3<H`25:D56<H3:DX2CW<3IcT3:DX59BT2;F/3F]H2G_L3F]H3E[D2CW<3F]H2<H`336<2DY@3
E[D2Ool00`00Oomoo`08Ool00`00OolHaP026<H20003124236<32482000312422483?Nl30002?Nl3
124524825:D524831242AS43JeX37>L248@3<H`2CW<5?Nl3HaP236<3:DX5E[D3=Jd26<H52483=Jd2
G_L3:DX2G_L39BT2Ool00`00Oomoo`08Ool00`00Oom24002@Q0236<3>Lh5AS42@Q03>Lh3;F/2?Nl3
CW<2@Q0336<2;F/324836<H29BT3CW<2AS46>Lh2<H`3BU82@Q05>Lh6BU82JeX3G_L2IcT3Li`5Mkd3
48@2E[D3AS47@Q03AS42Ool00`00Oomoo`08Ool000Uoo`03001oof]J00A[FP=W>@9S60=JeP9Nm`IJ
eP9F]@<YBP9F]@=Nm`EJeP=6<@9Nm`=S609W>@=S60<icP8DY@<HaP8YBP=>L`9W>@=_N`DQ20<aS09[
FP=S60ENm`EJeP=2408YBP<48@9BU0=F]@9oo`03001oogoo00Qoo`03001ooacW008Li`848@<8@P8<
H`X48@<mk`<48@9240<8@PD<H`8000<DY@8@Q0<48@8icP=JeP<e[@9>L`=Nm`9JeP<e[@9>L`=JeP8Q
20=Nm`=6<@8<H`D48@<8@P8@Q0=2409JeP<e[@9Nm`<YBP9oo`03001oogoo00Qoo`03001oocg_008m
k`8Q20<mk`9240<icP8YBP<aS0E240=BU09240=oo`8HaP<Q20<DY@8Q20<YBP8e[@<mk`<e[@8@Q0=c
W09[FP=W>@9Nm`<mk`=2409F]@=JeP9S60EkgP=BU0<]J`8e[@=6<@9:DP<e[@8icP<e[@9oo`03001o
ogoo00Qoo`002Goo00<007ooJeX016]J0fLi0V<H0e[F0Ukg1U[F0UJe0bU:0UJe0ekg1E[F0dHa0Ukg
0f<H0VLi0f<H0cW>0QBU0aS60RU:0dic0VLi0fmk1B480c6<0V]J0f<H1Ekg1E[F0d8@0RU:0`@Q0U:D
0eJe0Woo00<007ooOol027oo00<007oo7>L00QcW0P@Q0`Q20PaS2P@Q0cg_0`@Q0T8@0`Q21@aS0P00
0aBU0Q240`@Q0SW>0e[F0cF]0Tic0ekg0U[F0cF]0Tic0e[F0R480ekg0dHa0PaS1@@Q0`Q20Q240d8@
0U[F0cF]0Ukg0bU:0Woo00<007ooOol027oo00<007oo?Nl00Sg_0R480cg_0T8@0cW>0RU:0c6<1D8@
0e:D0T8@0goo0QS60b480aBU0R480bU:0SF]0cg_0cF]0Q240g>L0V]J0fLi0Ukg0cg_0d8@0UJe0e[F
0V<H1G_N0e:D0be[0SF]0dHa0TYB0cF]0SW>0cF]0Woo00<007ooOol027oo0009Ool00`00Oom[FP07
JeX2IcT5G_L3F]H3E[D2DY@3:DX2F]H3G_L2F]H3E[D3F]H2AS43E[D5HaP5?Nl3E[D2G_L3JeX2IcT3
HaP38@P29BT3G_L2IcT3E[D5F]H5E[D3DY@548@2?Nl3BU82Ool00`00Oomoo`08Ool00`00OolU:@02
9BT21243248236<3248512422483?Nl32482@Q051243248248@312426<H348@2?Nl3AS431242<H`3
?Nl2;F/32482F]H3DY@2BU83F]H336<248@336<248@336<29BT3G_L2AS43?Nl2E[D3<H`2Ool00`00
Oomoo`08Ool00`00Oom24002@Q02BU83@Q02<H`3:DX29BT3?Nl3CW<5@Q02?Nl31242JeX67>L2;F/3
9BT22483DY@3CW<236<3CW<2E[D3G_L2JeX3@Q03?Nl2CW<3DY@2JeX3DY@2Li`6Ool2E[D3DY@2CW<8
?Nl2Ool00`00Oomoo`08Ool000Uoo`03001oof]J00M[FP9W>@ENm`=JeP=F]@9BU0<YBP9JeP=Nm`9J
eP=F]@=JeP96<@=F]@ES60Dmk`=F]@9Nm`=[FP9W>@=S60<Q208U:@=Nm`9W>@=F]@EJePEF]@=BU0D@
Q08mk`=:DP9oo`03001oogoo00Qoo`03001oobDY008U:@848@<8@P8<H`<8@PD48@88@P<mk`<8@P92
40D48@<8@P8@Q0<48@8HaP<@Q08mk`=6<@<48@8aS0<mk`8]J`<8@P9JeP=BU09:DP=JeP<<H`8@Q0<<
H`8@Q0<<H`8U:@=Nm`96<@<mk`9F]@<aS09oo`03001oogoo00Qoo`03001ood8@0092409:DP=2408a
S0<YBP8U:@<mk`=>L`E2408mk`<48@9[FPHLi`8]J`<U:@88@P=BU0=>L`8<H`=>L`9F]@=Nm`9[FP=2
40<mk`9>L`=BU09[FP=BU09cW0Ioo`9F]@=BU09>L`Pmk`9oo`03001oogoo00Qoo`002Goo00<007oo
JeX01f]J0VLi1Ekg0e[F0eJe0U:D0bU:0U[F0ekg0U[F0eJe0e[F0THa0eJe1F<H1Cg_0eJe0Ukg0f]J
0VLi0f<H0b480RDY0ekg0VLi0eJe1E[F1EJe0e:D1A240Sg_0dYB0Woo00<007ooOol027oo00<007oo
9BT00RDY0P@Q0`Q20PaS0`Q21@@Q0PQ20cg_0`Q20T8@1@@Q0`Q20Q240`@Q0QS60a240Sg_0dHa0`@Q
0S6<0cg_0Re[0`Q20U[F0e:D0TYB0e[F0`aS0Q240`aS0Q240`aS0RDY0ekg0THa0cg_0UJe0c6<0Woo
00<007ooOol027oo00<007oo@Q000T8@0TYB0d8@0S6<0bU:0RDY0cg_0dic1D8@0Sg_0`@Q0V]J1QcW
0Re[0bDY0PQ20e:D0dic0PaS0dic0UJe0ekg0V]J0d8@0cg_0Tic0e:D0V]J0e:D0W>L1Woo0UJe0e:D
0Tic23g_0Woo00<007ooOol027oo0009Ool00`00Oom_N`02Kg/2JeX5IcT3HaP5G_L3E[D2DY@3:DX2
F]H3DY@8F]H5E[D2F]H3CW<39BT25:D36<H2DY@3IcT2JeX3IcT38@P2:DX3JeX2HaP3G_L2E[D3BU83
E[D2DY@36<H548@2BU83DY@2Ool00`00Oomoo`08Ool00`00OolLi`027>L224831245248212432482
36<3>Lh32482>Lh336<248@:2483>Lh2F]H3DY@3?Nl2G_L3JeX2=Jd31242F]H3BU82F]H3CW<836<2
48@3<H`2HaP3G_L26<H3BU82DY@3<H`2Ool00`00Oomoo`08Ool00`00Oom:DP04BU83F]H5@Q02CW<3
BU83@Q02?Nl3AS42?Nl3Li`236<35:D3=Jd248@3Ool2Li`3IcT3HaP200035:D28@P39BT2Li`3@Q03
?Nl5@Q05=Jd2@Q03IcT3Li`2IcT3HaP2G_L5BU83CW<2Ool00`00Oomoo`08Ool000Uoo`03001oofmk
009_N`9[FPEW>@=S60ENm`=F]@9BU0<YBP9JeP=BU0QJePEF]@9JeP=>L`<U:@8DY@<HaP9BU0=W>@9[
FP=W>@<Q208YBP=[FP9S60=Nm`9F]@=:DP=F]@9BU0<HaPD@Q09:DP=BU09oo`03001oogoo00Qoo`03
001ooacW008Li`88@P<48@D8@P848@<8@P8<H`<icP<8@P8icP<<H`8@Q0X8@P<icP9JeP=BU0<mk`9N
m`=[FP8e[@<48@9JeP=:DP9JeP=>L`P<H`8@Q0<aS09S60=Nm`8HaP=:DP9BU0<aS09oo`03001oogoo
00Qoo`03001oodYB00A:DP=JePE2409>L`=:DP=2408mk`=6<@8mk`=cW08<H`<DY@<e[@8@Q0=oo`9c
W0=W>@=S608000<DY@8Q20<U:@9cW0=240<mk`E240De[@9240=W>@=cW09W>@=S609Nm`E:DP=>L`9o
o`03001oogoo00Qoo`002Goo00<007ooKg/00Vmk0V]J1FLi0f<H1Ekg0eJe0U:D0bU:0U[F0e:D25[F
1EJe0U[F0dic0bDY0QBU0aS60U:D0fLi0V]J0fLi0b480RU:0f]J0V<H0ekg0UJe0dYB0eJe0U:D0aS6
1A240TYB0e:D0Woo00<007ooOol027oo00<007oo7>L00QcW0PQ20`@Q1@Q20P@Q0`Q20PaS0cW>0`Q2
0SW>0`aS0Q242PQ20cW>0U[F0e:D0cg_0Ukg0f]J0SF]0`@Q0U[F0dYB0U[F0dic20aS0Q240c6<0V<H
0ekg0QS60dYB0U:D0c6<0Woo00<007ooOol027oo00<007ooBU8014YB0e[F1D8@0Tic0dYB0d8@0Sg_
0dHa0Sg_0g>L0PaS0aBU0cF]0Q240goo0W>L0fLi0f<H0P000aBU0R480bDY0W>L0d8@0cg_1D8@1CF]
0T8@0fLi0g>L0VLi0f<H0Ukg1DYB0dic0Woo00<007ooOol027oo0009Ool00`00Oom_N`02Kg/7IcT5
G_L3F]H3E[D2DY@3:DX5E[D2BU88E[D3F]H2<H`37>L35:D248@35:D26<H3G_L5HaP38@P29BT5IcT5
F]H3DY@3>Lh248@336<248@38@P2DY@3F]H2Ool00`00Oomoo`08Ool00`00OolDY@025:D236<3000<
2483=Jd32482=Jd32482124536<35:D2?Nl3E[D2AS439BT324828@P3IcT2E[D35:D2E[D3CW<2BU83
F]H58@P3>Lh2BU83G_L2E[D58@P3G_L2AS43:DX2Ool00`00Oomoo`08Ool00`00Oom>L`02CW<2=Jd3
:DX2>Lh3?Nl2BU83DY@3BU82?Nl3BU82@Q03<H`2124348@30002JeX3HaP5JeX3G_L2JeX38@P5;F/2
48@6@Q02<H`3:DX2Ool5IcT6Kg/5IcT2E[D5DY@3BU82Ool00`00Oomoo`08Ool000Uoo`03001oofmk
009_N`MW>@ENm`=JeP=F]@9BU0<YBPEF]@9:DPQF]@=JeP8aS0<Li`<DY@8@Q0<DY@8HaP=Nm`ES60<Q
208U:@EW>@EJeP=BU0<icP8@Q0<<H`8@Q0<Q209BU0=JeP9oo`03001oogoo00Qoo`03001ooaBU008D
Y@8<H`<000`8@P<e[@<8@P8e[@<8@P848@D<H`<DY@8mk`=F]@96<@<U:@<8@P8Q20=W>@9F]@<DY@9F
]@=>L`9:DP=JePDQ20<icP9:DP=Nm`9F]@DQ20=Nm`96<@<YBP9oo`03001oogoo00Qoo`03001oodic
009>L`8e[@<YBP8icP<mk`9:DP=BU0=:DP8mk`=:DP9240<aS0848@<@Q0<0009[FP=S60E[FP=Nm`9[
FP<Q20D]J`8@Q0I2408aS0<YBP9oo`EW>@I_N`EW>@9F]@EBU0=:DP9oo`03001oogoo00Qoo`002Goo
00<007ooLi`00W>L1F]J0VLi0f<H1E[F0eJe0U:D0be[1E[F0UJe0e:D0dYB0UJe0be[1AS621BU0QS6
0dYB0Ukg0f<H0bDY0R480be[0UJe0dic0S6<1QBU0PaS1A240dYB1EJe0Woo00<007ooOol027oo00<0
07oo48@00Q240PaS0`@Q0PQ20`aS0PQ20`@Q0PQ20cF]0`@Q0SF]1@Q20`000PQ20cW>0V<H0cW>0Q24
0`Q20`@Q0PQ20dYB0Ukg0acW0Tic0e:D0RDY1U[F1Ekg0U:D0cF]0QBU0`000THa0f<H0R480bDY0Woo
00<007ooOol027oo00<007oo?Nl00Sg_0T8@25:D0U[F0eJe0cW>0Sg_0dYB0T8@0bU:0R480c6<0g_N
1Ekg0V]J0g>L0dHa1cW>0cF]0Re[1T8@0R480aS60P@Q0g>L1Fmk0f]J0Ukg1Dic0e:D0Ukg0d8@0Woo
00<007ooOol027oo0009Ool00`00OomcW002Li`5JeX2IcT3HaP5F]H3E[D2DY@3;F/5F]H2E[D3DY@3
BU82E[D3;F/56<H85:D26<H3BU82G_L3HaP39BT28@P3;F/2E[D3CW<2<H`65:D236<548@3BU85E[D2
Ool00`00Oomoo`08Ool00`00Ool@Q00248@236<31242248336<2248312422483=Jd31242=Jd52483
00022483>Lh2HaP3>Lh248@3248312422483BU82G_L37>L2CW<3DY@29BT6F]H5G_L2DY@3=Jd25:D3
0002AS43HaP28@P39BT2Ool00`00Oomoo`08Ool00`00Oolmk`02?Nl2@Q08DY@2F]H3E[D3>Lh2?Nl3
BU82@Q03:DX28@P3<H`3Nmh5G_L2JeX3Li`3AS47>Lh3=Jd2;F/6@Q028@P36<H21243Li`5Kg/3JeX2
G_L5CW<3DY@2G_L3@Q02Ool00`00Oomoo`08Ool000Uoo`03001oog>L009cW0E[FP9W>@=S60EJeP=F
]@9BU0<]J`EJeP9F]@=BU0=:DP9F]@<]J`DHaPPDY@8HaP=:DP9Nm`=S60<U:@8Q20<]J`9F]@=>L`8a
S0HDY@8<H`D@Q0=:DPEF]@9oo`03001oogoo00Qoo`03001ooa24008@Q08<H`<48@88@P<<H`88@P<4
8@88@P<e[@<48@8e[@D8@P<00088@P<icP9S60<icP8@Q0<8@P<48@88@P=:DP9Nm`<Li`9>L`=BU08U
:@IJePENm`9BU0<e[@8DY@<00096<@=S608Q20<U:@9oo`03001oogoo00Qoo`03001oocg_008mk`92
40QBU09JeP=F]@<icP8mk`=:DP9240<YBP8Q20<aS0=kgPENm`9[FP=cW0=6<@LicP<e[@8]J`I2408Q
20<HaP848@=cW0E_N`=[FP9Nm`E>L`=BU09Nm`=2409oo`03001oogoo00Qoo`002Goo00<007ooKg/0
0Vmk1FLi0V<H0ekg0UJe0e[F1EJe0bU:2UJe0e:D0T8@1@aS0aS62QBU0d8@0V<H0ekg22480QcW0aS6
1ABU1A240`aS0QBU0e[F1EJe0Woo00<007ooOol027oo00<007oo5:D00QBU0PaS0`Q21@aS0PQ20`00
0P@Q0cF]0`@Q0SF]0`Q20P000`Q20QBU0eJe0Tic0aBU0Q240aBU0aS60PQ20cg_0Ukg0b480Tic0e:D
0P000acW0cW>0T8@0c6<0QBU0`@Q0P000aS60Ukg0dic0P@Q0b480Woo00<007ooOol027oo00<007oo
?Nl00Sg_0SW>0dYB0U[F0eJe0U[F0fmk0d8@0Sg_0dYB0Sg_0e:D0SF]0`Q20d8@0Tic0eJe0Q240dYB
0goo0Q240`Q21Cg_0T8@1Sg_0W>L0a240P000gNm0V]J0ekg0eJe0T8@0e[F0Tic0dYB0SW>0cg_0Woo
00<007ooOol027oo0009Ool00`00Oom_N`02Kg/5IcT2HaP3G_L2E[D3F]H5E[D3:DX:E[D3DY@2@Q05
36<36<H:5:D3@Q02HaP3G_L88@P27>L36<H55:D548@336<25:D3F]H5E[D2Ool00`00Oomoo`08Ool0
0`00OolDY@025:D236<3248536<2248300021243=Jd31242=Jd32482000324825:D3E[D2CW<35:D2
48@35:D36<H22483?Nl2G_L38@P2CW<3DY@200037>L3>Lh2@Q03<H`25:D3124200036<H2G_L3CW<2
12438@P2Ool00`00Oomoo`08Ool00`00Oolmk`02?Nl2>Lh3BU82F]H3E[D2F]H3Kg/3@Q02?Nl3BU82
?Nl3DY@2=Jd32483@Q02CW<3E[D248@3BU83Ool248@32485?Nl2@Q06?Nl2Li`348@20003Mkd2JeX3
G_L3E[D2@Q03F]H2CW<3BU82>Lh3?Nl2Ool00`00Oomoo`08Ool000Uoo`03001oog>L009cW09_N`=W
>@9Nm`=JePYF]@<]J`9JeP=F]@9BU0=JeP=F]@8e[@<48@8@Q0<HaP<YBP8]J`<DY@8HaP=6<@ES60<]
J`8Li`<Q208HaP<DY@X@Q0<<H`8mk`=:DPEF]@9oo`03001oogoo00Qoo`03001ooacW008Li`D<H`L8
@P<48@88@P<aS0<8@P8aS0<<H`D48@8aS0=W>@8U:@<e[@9>L`IF]@8mk`<icP9Nm`<HaP8icP=F]@8H
aP<48@P<H`848@<000848@=2409F]@<Q208HaP<U:@9oo`03001oogoo00Qoo`03001oocg_008mk`8e
[@DicP<]J`8HaP<DY@=:DP9240=:DP9240=:DP8<H`<YBPE:DP=6<@9Nm`=_N`=kgP88@P<DY@9>L`E6
<@<icP<aS08YBPE:DP=F]@9Nm`=_N`=cW09_N`EF]@<mk`8@Q0<aS09oo`03001oogoo00Qoo`002Goo
00<007ooLi`00W>L0Vmk0fLi0Ukg0e[F2UJe0be[0U[F0eJe0U:D0e[F0eJe0SF]0`@Q0Q240aS60bU:
0Re[0aBU0QS60dHa1F<H0be[0QcW0b480QS60aBU2Q240`aS0Sg_0dYB1EJe0Woo00<007ooOol027oo
00<007oo7>L00QcW1@aS1`Q20`@Q0PQ20c6<0`Q20S6<0`aS1@@Q0S6<0fLi0RDY0cF]0Tic1UJe0Sg_
0cW>0Ukg0aS60SW>0eJe0QS60`@Q20aS0P@Q0`000P@Q0d8@0UJe0b480QS60bDY0Woo00<007ooOol0
27oo00<007oo?Nl00Sg_0SF]1CW>0be[0QS60aBU0dYB0T8@0dYB0T8@0dYB0PaS0bU:1DYB0dHa0Ukg
0fmk0g_N0PQ20aBU0Tic1DHa0cW>0c6<0RU:1DYB0eJe0Ukg0fmk0g>L0Vmk1EJe0cg_0Q240c6<0Woo
00<007ooOol027oo0009Ool00`00OomcW002Li`2Kg/3IcT2G_L3F]H:E[D3;F/2F]H3E[D2DY@3F]H3
E[D2=Jd3124248@36<H3:DX2;F/35:D26<H3AS45HaP3;F/27>L38@P26<H35:D:48@336<2?Nl3BU85
E[D2Ool00`00Oomoo`08Ool00`00OolLi`027>L536<7248312422483<H`32482<H`336<51242<H`3
IcT29BT3=Jd2CW<6E[D2?Nl3>Lh2G_L36<H2>Lh3E[D26<H3124836<2124300021243@Q02E[D38@P2
6<H39BT2Ool00`00Oomoo`08Ool00`00Oolmk`02?Nl2=Jd5>Lh3;F/26<H35:D3BU82@Q03BU82@Q03
BU8236<3:DX5BU83AS42G_L3Kg/3Nmh224835:D2CW<5AS43>Lh3<H`2:DX5BU83E[D2G_L3Kg/3Li`2
Kg/5E[D3?Nl248@3<H`2Ool00`00Oomoo`08Ool000Uoo`03001oofmk009_N`9[FP=W>@ES60EJeP=F
]@9>L`<aS09JeP=F]@9:DP=BU0=F]@8DY@<8@P8YBP=F]@=JeP9F]@=2408DY@=F]@EJeP=>L`8Li`<Q
208HaP<DY@D<H`D@Q0<Q209JeP<mk`96<@=>L`9oo`03001oogoo00Qoo`03001oobDY008U:@D<H`88
@PP48@8<H`<aS0<@Q08]J`<@Q088@P<@Q09:DP=Nm`8U:@=_N`9F]@He[@9:DP<U:@9Nm`<<H`8HaP=>
L`8mk`<8@PD@Q0<8@P8000<8@P8]J`=Nm`8DY@<Q208U:@<YBP9oo`03001oogoo00Qoo`03001oocF]
008e[@9BU0=6<@9240<e[@DYBPE240<e[@8mk`=6<@9_N`<@Q0=>L`9:DPES60=_N`=oo`8Li`<aS096
<@<mk`DaS0D]J`<icP9>L`=F]@9Nm`=:DP=W>@9S60EJeP=oo`8U:@<e[@9oo`03001oogoo00Qoo`00
2Goo00<007ooKg/00Vmk0V]J0fLi1F<H1E[F0eJe0Tic0c6<0U[F0eJe0TYB0e:D0eJe0QBU0`Q20RU:
0eJe0e[F0UJe0d8@0QBU0eJe1E[F0dic0QcW0b480QS60aBU1@aS1A240b480U[F0cg_0THa0dic0Woo
00<007ooOol027oo00<007oo9BT00RDY1@aS0PQ220@Q0PaS0c6<0a240Re[0a240PQ20a240TYB0ekg
0RDY0fmk0UJe1SF]0TYB0bDY0Ukg0`aS0QS60dic0Sg_0`Q21A240`Q20P000`Q20Re[0ekg0QBU0b48
0RDY0bU:0Woo00<007ooOol027oo00<007oo=Jd00SF]0U:D0dHa0T8@0cF]1BU:1D8@0cF]0Sg_0dHa
0Vmk0a240dic0TYB1F<H0fmk0goo0QcW0c6<0THa0cg_1C6<1Be[0cW>0Tic0eJe0Ukg0dYB0fLi0V<H
1E[F0goo0RDY0cF]0Woo00<007ooOol027oo0009Ool00`00Oom_N`02Kg/5IcT2G_L3F]H2G_L6E[D2
BU83;F/2F]H5DY@3@Q03DY@236<37>L2G_L3F]H3DY@2CW<3;F/25:D3BU82G_L3E[D3HaP2<H`37>L2
6<H536<348@35:D27>L3E[D2BU8348@2E[D3AS42Ool00`00Oomoo`08Ool00`00OolYBP02:DX22485
36<51243248236<3<H`348@2;F/536<31242CW<3>Lh2HaP3E[D21243<H`3E[D2DY@3;F/2HaP348@2
2483=Jd2F]H3>Lh38@P236<300027>L5>Lh38@P2CW<3=Jd2>Lh39BT2Ool00`00Oomoo`08Ool00`00
Oolmk`04?Nl3@Q02BU83IcT2DY@3CW<3AS42@Q05?Nl3>Lh2<H`3Li`3BU82?Nl3E[D2F]H36<H5JeX3
G_L2:DX5>Lh336<58@P37>L2=Jd3AS42Kg/3HaP3Kg/2IcT3;F/2Kg/348@2=Jd3?Nl2Ool00`00Oomo
o`08Ool000Uoo`03001oofmk009_N`EW>@9Nm`=JeP9Nm`IF]@9:DP<]J`9JePEBU0=240=BU08<H`<L
i`9Nm`=JeP=BU09>L`<]J`8DY@=:DP9Nm`=F]@=S608aS0<Li`8HaPD<H`<@Q0<DY@8Li`=F]@9:DP<@
Q09F]@=6<@9oo`03001oogoo00Qoo`03001oobU:008YBP88@PD<H`D48@<8@P8<H`<aS0<@Q08]J`D<
H`<48@9>L`<icP9S60=F]@848@<aS0=F]@9BU0<]J`9S60<@Q088@P<e[@9JeP<icP<Q208<H`<0008L
i`DicP<Q209>L`<e[@8icP<U:@9oo`03001oogoo00Qoo`03001oocg_00@mk`=2409:DP=W>@9BU0=>
L`=6<@9240Dmk`<icP8aS0=cW0=:DP8mk`=F]@9JeP<HaPE[FP=Nm`8YBPDicP<<H`DQ20<Li`8e[@=6
<@9_N`=S60=_N`9W>@<]J`9_N`<@Q08e[@<mk`9oo`03001oogoo00Qoo`002Goo00<007ooKg/00Vmk
1FLi0Ukg0e[F0Ukg1UJe0TYB0be[0U[F1E:D0d8@0e:D0PaS0acW0Ukg0e[F0e:D0Tic0be[0QBU0dYB
0Ukg0eJe0f<H0S6<0acW0QS61@aS0a240aBU0QcW0eJe0TYB0a240UJe0dHa0Woo00<007ooOol027oo
00<007oo:DX00RU:0PQ21@aS1@@Q0`Q20PaS0c6<0a240Re[1@aS0`@Q0Tic0cW>0V<H0eJe0P@Q0c6<
0eJe0U:D0be[0V<H0a240PQ20cF]0U[F0cW>0b480PaS0`000QcW1CW>0b480Tic0cF]0SW>0bDY0Woo
00<007ooOol027oo00<007oo?Nl013g_0d8@0TYB0fLi0U:D0dic0dHa0T8@1Cg_0cW>0S6<0g>L0dYB
0Sg_0eJe0U[F0aS61F]J0ekg0RU:1CW>0`aS1B480acW0SF]0dHa0Vmk0f<H0fmk0VLi0be[0Vmk0a24
0SF]0cg_0Woo00<007ooOol027oo0009Ool00`00Oom_N`02Kg/2JeX3IcT2HaP3F]H2G_L6E[D2DY@3
;F/2F]H3E[D5DY@3@Q0236<3@Q05E[D3>Lh25:D336<25:D3?Nl2HaP6G_L2HaP3AS455:D236<35:D3
?Nl2AS435:D224835:D2DY@3@Q02Ool00`00Oomoo`08Ool00`00OolaS002<H`736<3124200052483
;F/336<2;F/5248336<2E[D38@P2DY@3BU85G_L3CW<2:DX3=Jd2IcT39BT2000348@2?Nl3HaP3G_L2
CW<3=Jd57>L29BT3CW<2@Q03BU82@Q039BT2Ool00`00Oomoo`08Ool00`00Oom24002@Q02<H`8=Jd2
CW<3BU83AS42?Nl3DY@2@Q03=Jd58@P3?Nl2@Q03=Jd236<3Mkd5JeX3Kg/2<H`3>Lh2=Jd336<86<H2
5:D52483HaP3>Lh2Nmh5Li`3<H`5?Nl2Ool00`00Oomoo`08Ool000Uoo`03001oofmk009_N`9[FP=W
>@9S60=JeP9Nm`IF]@9BU0<]J`9JeP=F]@EBU0=2408<H`=240EF]@<icP8DY@<<H`8DY@<mk`9S60IN
m`9S60=6<@DDY@8<H`<DY@<mk`96<@<DY@88@P<DY@9BU0=2409oo`03001oogoo00Qoo`03001ooc6<
008aS0L<H`<48@8000D8@P<]J`<<H`8]J`D8@P<<H`9F]@<Q209BU0=:DPENm`=>L`8YBP<e[@9W>@<U
:@8000<@Q08mk`=S60=Nm`9>L`<e[@DLi`8U:@=>L`9240=:DP9240<U:@9oo`03001oogoo00Qoo`03
001ood8@0092408aS0Pe[@9>L`=:DP=6<@8mk`=BU09240<e[@DQ20<mk`9240<e[@8<H`=g_@E[FP=_
N`8aS0<icP8e[@<<H`PHaP8DY@D8@P=S60<icP9kgPEcW0<aS0Dmk`9oo`03001oogoo00Qoo`002Goo
00<007ooKg/00Vmk0V]J0fLi0V<H0e[F0Ukg1UJe0U:D0be[0U[F0eJe1E:D0d8@0PaS0d8@1EJe0cW>
0QBU0`aS0QBU0cg_0V<H1Ukg0V<H0dHa1ABU0PaS0aBU0cg_0THa0aBU0PQ20aBU0U:D0d8@0Woo00<0
07ooOol027oo00<007oo<H`00S6<1`aS0`@Q0P001@Q20be[0`aS0Re[1@Q20`aS0UJe0b480U:D0dYB
1Ekg0dic0RU:0cF]0VLi0bDY0P000a240Sg_0f<H0ekg0Tic0cF]1AcW0RDY0dic0T8@0dYB0T8@0bDY
0Woo00<007ooOol027oo00<007oo@Q000T8@0S6<23F]0Tic0dYB0dHa0Sg_0e:D0T8@0cF]1B480cg_
0T8@0cF]0PaS0gNm1F]J0fmk0S6<0cW>0SF]0`aS21S60QBU1@Q20f<H0cW>0W_N1G>L0c6<1Cg_0Woo
00<007ooOol027oo0009Ool00`00OomcW002Li`2JeX3IcT2HaP5F]H3E[D5DY@3=Jd2F]H5E[D6DY@2
24838@P55:D:48@3=Jd5F]H3G_L2F]H3HaP2E[D3BU82>Lh37>L348@236<3248236<348@2DY@3@Q02
Ool00`00Oomoo`08Ool00`00Oole[@02=Jd736<32482124336<22483:DX336<2:DX348@536<2G_L3
=Jd2AS43E[D2DY@3=Jd35:D20003<H`2DY@3?Nl26<H3248236<3:DX3;F/77>L3>Lh2?Nl38@P21243
E[D2?Nl3;F/2Ool00`00Oomoo`08Ool00`00Oom24002@Q02<H`3;F/2=Jd3;F/29BT3=Jd3>Lh2?Nl3
DY@2@Q03E[D2Nmh3E[D3@Q02DY@35:D20003Nmh3Kg/2HaP336<2?Nl3=Jd29BT36<H3Mkd2F]H3?Nl5
>Lh2AS43Kg/30002Mkd3IcT29BT3?Nl5>Lh2Ool00`00Oomoo`08Ool000Uoo`03001oog>L009cW09[
FP=W>@9S60EJeP=F]@EBU0<e[@9JePEF]@IBU088@P<Q20DDY@X@Q0<e[@EJeP=Nm`9JeP=S609F]@=:
DP8icP<Li`<@Q08<H`<8@P8<H`<@Q09BU0=2409oo`03001oogoo00Qoo`03001oocF]008e[@L<H`<8
@P848@<<H`88@P<YBP<<H`8YBP<@Q0D<H`9Nm`<e[@96<@=F]@9BU0<e[@<DY@8000<aS09BU0<mk`8H
aP<8@P8<H`<YBP<]J`LLi`<icP8mk`<Q20848@=F]@8mk`<]J`9oo`03001oogoo00Qoo`03001ood8@
0092408aS0<]J`8e[@<]J`8U:@<e[@<icP8mk`=BU09240=F]@9kgP=F]@=2409BU0<DY@8000=kgP=_
N`9S60<<H`8mk`<e[@8U:@<HaP=g_@9JeP<mk`DicP96<@=_N`<0009g_@=W>@8U:@<mk`DicP9oo`03
001oogoo00Qoo`002Goo00<007ooKg/016mk0f]J0V<H1Ekg0e[F0eJe0U:D0cF]0Ukg0dic0T8@0eJe
0cF]1@Q20Q240aBU1A240`aS0QBU0cF]0RU:0ekg1EJe0dHa0RDY0aBU0PaS1PQ21@aS0PQ20a240TYB
0d8@0Woo00<007ooOol027oo00<007oo?Nl00Sg_0PQ21@aS1@@Q0`aS0PQ20b480`aS0QcW0bDY0SF]
0e:D0VLi0cF]0QBU0`Q20P000`@Q0`000PQ20be[0RU:0dHa0U:D0dHa0U:D0f<H0ekg0Tic0cW>0QcW
0`@Q1@000P@Q0e:D0Sg_0c6<0Woo00<007ooOol027oo00<007oo>Lh00SW>1CF]0SW>0be[0SW>0dHa
0dic0Sg_0dYB0T8@0dic0Vmk0gNm0ekg0U[F0aS60QBU0dYB0dic0Woo0eJe0THa0be[0QBU0a240goo
0WNm0g>L0Vmk0g>L1Fmk0f]J1A240S6<0cg_0SW>0cF]0Woo00<007ooOol027oo0009Ool00`00Oom_
N`04Kg/3JeX2HaP5G_L3F]H3E[D2DY@3=Jd2G_L3CW<2@Q03E[D3=Jd5248248@35:D548@336<25:D3
=Jd2:DX3G_L5E[D3AS429BT35:D236<6248536<2248348@2BU83@Q02Ool00`00Oomoo`08Ool00`00
Oolmk`02?Nl2248536<5124336<224838@P336<27>L39BT2=Jd3DY@2IcT3=Jd25:D3248200031243
00022483;F/2:DX3AS42DY@3AS42DY@3HaP3G_L2CW<3>Lh27>L3124500021243DY@2?Nl3<H`2Ool0
0`00Oomoo`08Ool00`00OolicP02>Lh5=Jd2>Lh3;F/2>Lh3AS43CW<2?Nl3BU82@Q03CW<2Kg/3Mkd3
G_L2F]H36<H25:D3BU83CW<2Ool3E[D2AS43;F/25:D348@3Ool2Mkd3Li`2Kg/3Li`5Kg/3JeX548@2
<H`3?Nl2>Lh3=Jd2Ool00`00Oomoo`08Ool000Uoo`03001oofmk00A_N`=[FP9S60ENm`=JeP=F]@9B
U0<e[@9Nm`=>L`9240=F]@<e[@D8@P8@Q0<DY@D@Q0<<H`8DY@<e[@8YBP=Nm`EF]@=6<@8U:@<DY@8<
H`H8@PD<H`88@P<@Q09:DP=2409oo`03001oogoo00Qoo`03001oocg_008mk`88@PD<H`D48@<<H`88
@P<Q20<<H`8Li`<U:@8e[@=BU09W>@<e[@8DY@<8@P8000<48@<00088@P<]J`8YBP=6<@9BU0=6<@9B
U0=S60=Nm`9>L`<icP8Li`<48@D000848@=BU08mk`<aS09oo`03001oogoo00Qoo`03001oocW>008i
cPDe[@8icP<]J`8icP=6<@=>L`8mk`=:DP9240=>L`9_N`=g_@=Nm`9JeP<HaP8DY@=:DP=>L`9oo`=F
]@96<@<]J`8DY@<@Q0=oo`9g_@=cW09_N`=cW0E_N`=[FPD@Q08aS0<mk`8icP<e[@9oo`03001oogoo
00Qoo`002Goo00<007ooKg/016mk0f]J1F<H0U[F0eJe1Dic0d8@1EJe0RU:1PaS1@Q20Q240aBU1@aS
0aBU0QcW0be[1B480bU:0QcW1ABU0a240PaS0`Q20a242PaS0TYB0cF]0Woo00<007ooOol027oo00<0
07ooBU800TYB0P@Q1@aS1@Q20`aS0PQ20aS60`aS0QS60cF]1Dic0SW>0aBU0PQ20`aS0P@Q0aS60cF]
0TYB0cg_0PaS0b480TYB1E:D0d8@0b480Q240`Q21@@Q1`000e:D1C6<0Woo00<007ooOol027oo00<0
07oo?Nl01cg_0SW>0dYB0U:D1Tic0SW>0eJe0T8@0dHa0UJe0fmk0f]J0U[F1D8@0f]J0gNm0W>L0gNm
0W>L0aBU0Woo0`aS0goo1G>L0V]J0dic0SF]0fmk0f]J0PaS0b480V<H0d8@0SW>0cF]0Woo00<007oo
Ool027oo0009Ool00`00Oom_N`04Kg/3JeX5HaP2F]H3E[D5CW<3@Q05E[D2:DX636<5248248@35:D5
36<35:D27>L3;F/58@P3:DX27>L55:D348@236<3248348@:36<2BU83=Jd2Ool00`00Oomoo`08Ool0
0`00Oom:DP02BU82124536<5248336<224836<H336<26<H3=Jd5CW<2>Lh35:D2248336<212436<H3
=Jd2BU83?Nl236<38@P2BU85DY@3@Q038@P248@3248512470003DY@5<H`2Ool00`00Oomoo`08Ool0
0`00Oolmk`07?Nl2>Lh3BU82DY@6CW<2>Lh3E[D2@Q03AS42E[D3Kg/3JeX2F]H5@Q03JeX3Mkd2Li`3
Mkd2Li`35:D2Ool336<3Ool5Li`2JeX3CW<2=Jd3Kg/3JeX236<38@P2HaP3@Q02>Lh3=Jd2Ool00`00
Oomoo`08Ool000Uoo`03001oog>L009cW0E[FP9W>@=Nm`EF]@EBU0=2409JeP=F]@8YBPH<H`D8@P8@
Q0<DY@<Q208icP=6<@9BU0<]J`8Li`<DY@<Li`8DY@P@Q0l<H`<@Q09:DP<YBP9oo`03001oogoo00Qo
o`03001ooeJe009F]@88@P<<H`8@Q0<<H`L8@P<@Q0<8@P8DY@<mk`9Nm`<U:@8000<48@8DY@<aS096
<@=F]@=>L`8aS0<@Q08Li`<HaP88@P<@Q08DY@<48@<000848@<8@P8000D48@<DY@8]J`=BU08DY@<e
[@9oo`03001oogoo00Qoo`03001oocg_008mk`96<@=2408mk`=6<@9:DP=240<e[@8aS0=JeP96<@E2
40=6<@=cW09kgP=Nm`9W>@=cW0Eg_@=kgP8Q20=24096<@<48@=g_@9F]@=[FP9oo`=2408e[@=cW0<@
Q09BU0=_N`9cW0=F]@9BU0<e[@9oo`03001oogoo00Qoo`002Goo00<007ooLi`00W>L1F]J0VLi0ekg
1EJe1E:D0d8@0U[F0eJe0RU:1PaS1@Q20Q240aBU0b480SW>0dHa0U:D0be[0QcW0aBU0acW0QBU2124
3`aS0a240TYB0bU:0Woo00<007ooOol027oo00<007ooE[D00UJe0PQ20`aS0Q240`aS1`Q20a240`Q2
0QBU0cg_0Ukg0bDY0P000`@Q0QBU0c6<0THa0eJe0dic0S6<0a240QcW0aS60PQ20a240QBU0`@Q0`00
0P@Q0`Q20P001@@Q0aBU0Re[0e:D0QBU0cF]0Woo00<007ooOol027oo00<007oo?Nl00Sg_0THa0d8@
0Sg_0dHa0TYB0d8@0cF]0S6<0e[F0THa1D8@0dHa0g>L0W_N0ekg0VLi0g>L1GNm0g_N0R480d8@0THa
0`@Q0gNm0UJe0f]J0Woo0d8@0SF]0g>L0a240U:D0fmk0W>L0eJe0U:D0cF]0Woo00<007ooOol027oo
0009Ool00`00OomcW002Li`5JeX2IcT3G_L5E[D5DY@3@Q02F]H3E[D2:DX636<5248248@35:D38@P2
>Lh3AS42DY@3;F/27>L35:D37>L25:D848@?36<348@2BU83:DX2Ool00`00Oomoo`08Ool00`00OomF
]@02E[D2248336<248@336<7248348@324825:D3?Nl2G_L39BT2000312425:D3<H`2AS43E[D3CW<2
<H`348@27>L36<H2248348@25:D31243000212432482000512435:D2;F/3DY@25:D3=Jd2Ool00`00
Oomoo`08Ool00`00Oolmk`02?Nl2AS43@Q02?Nl3AS42BU83@Q03=Jd2<H`3F]H2AS45@Q03AS43Li`2
Nmh3G_L2IcT3Li`5Mkd3Nmh28@P3@Q02AS431243Mkd2E[D3JeX2Ool3@Q02=Jd3Li`348@2DY@3Kg/2
Li`3E[D2DY@3=Jd2Ool00`00Oomoo`08Ool000Uoo`03001oog>L009cW0E[FP9S60=Nm`EF]@EBU0=:
DP9F]@=BU08YBP<48@<8@P8<H`<@Q08]J`=:DP=BU09>L`<mk`8Li`<YBP8Q20HHaP8DY@<@Q08DY@D@
Q0H8@P8<H`<HaP8]J`=2409:DP<Q209oo`03001oogoo00Qoo`03001oof<H009S6088@PX<H`<8@P84
8@P8@P<mk`9Nm`<U:@8DY@<]J`9:DP=F]@8icP<8@P<YBP9:DP=2408Li`<DY@D48@8<H`H000848@<8
@PD0008Li`=6<@9F]@=6<@8Li`<aS09oo`03001oogoo00Qoo`03001oocg_00@mk`=6<@9240DicP=:
DP=F]@8mk`=>L`8aS0=6<@9240=6<@=F]@E_N`9[FP=cW0<@Q09g_@=cW09g_@=cW0E240=F]@9:DP<a
S09S60<icP9240=>L`<e[@9F]@=W>@9cW0=[FP8YBP<icP9oo`03001oogoo00Qoo`002Goo00<007oo
Li`00W>L1F]J0V<H0ekg1EJe1E:D0dYB0UJe0e:D0RU:0`@Q0`Q20PaS0a240Re[0dYB0e:D0Tic0cg_
0QcW0bU:0R481QS60QBU0a240QBU1A241PQ20PaS0aS60Re[0d8@0TYB0b480Woo00<007ooOol027oo
00<007ooHaP00V<H0PQ22PaS0`Q20P@Q20Q20cg_0Ukg0bDY0QBU0be[0TYB0eJe0SW>0`Q20bU:0TYB
0d8@0QcW0aBU1@@Q0PaS1P000P@Q0`Q21@000QcW0dHa0UJe0dHa0QcW0c6<0Woo00<007ooOol027oo
00<007oo?Nl013g_0dHa0T8@1CW>0dYB0eJe0Sg_0dic0S6<0dHa0T8@0dHa0eJe1Fmk0V]J0g>L0a24
0WNm0g>L0WNm0g>L1D8@0eJe0TYB0c6<0V<H0cW>0T8@0dic0cF]0UJe0fLi0W>L0f]J0RU:0cW>0Woo
00<007ooOol027oo0009Ool00`00OomcW002Li`2Kg/3JeX2IcT5G_L6DY@5CW<2E[D3BU82:DX30003
48@2;F/3@Q05BU83:DX748@39BT28@P35:D36<H248@35:D248@35:D:36<3>Lh2E[D3@Q02DY@37>L2
Ool00`00Oomoo`08Ool00`00OomW>@02IcT2248:36<348@5124324820003>Lh2DY@3;F/2CW<3>Lh2
48@3:DX2@Q03F]H3DY@2>Lh37>L25:D348@2248312422483000336<548@500029BT3@Q02:DX35:D5
<H`2Ool00`00Oomoo`08Ool00`00Oom24002@Q0<<H`3=Jd3AS45BU82HaP3@Q02>Lh336<3Kg/2Li`3
G_L25:D3Nmh3Kg/5Mkd248@3<H`2@Q08>Lh3Li`2JeX35:D2;F/3:DX37>L7=Jd3AS42?Nl3@Q02Ool0
0`00Oomoo`08Ool000Uoo`03001oog>L009cW09_N`=[FP9W>@ENm`IBU0E>L`9F]@=:DP8YBP<000<@
Q08]J`=240E:DP<YBPL@Q0<U:@8Q20<DY@<HaP8@Q0<DY@8@Q0<DY@X<H`<icP9F]@=2409BU0<Li`9o
o`03001oogoo00Qoo`03001oofLi009W>@88@PX<H`<@Q0D48@<8@P8000<icP9BU0<]J`9>L`<icP8@
Q0<YBP9240=JeP=BU08icP<Li`8DY@<@Q088@P<48@88@P<000<<H`D@Q0D0008U:@=2408YBP<DY@Da
S09oo`03001oogoo00Qoo`03001ood8@009240`aS0<e[@=6<@E:DP9S60=2408icP<<H`=_N`9cW0=N
m`8DY@=kgP=_N`Eg_@8@Q0<aS09240PicP=cW09[FP<DY@8]J`<YBP<Li`Le[@=6<@8mk`=2409oo`03
001oogoo00Qoo`002Goo00<007ooLi`00W>L0Vmk0f]J0VLi1Ekg1U:D1Dic0UJe0dYB0RU:0`000a24
0Re[0d8@1DYB0bU:1a240bDY0R480aBU0aS60Q240aBU0Q240aBU2PaS0cW>0UJe0d8@0U:D0acW0Woo
00<007ooOol027oo00<007ooIcT00VLi0PQ22PaS0a241@@Q0`Q20P000cW>0U:D0be[0Tic0cW>0Q24
0bU:0T8@0e[F0e:D0SW>0acW0QBU0a240PQ20`@Q0PQ20`000`aS1A241@000RDY0d8@0RU:0aBU1C6<
0Woo00<007ooOol027oo00<007oo@Q000T8@336<0cF]0dHa1DYB0V<H0d8@0SW>0`aS0fmk0W>L0ekg
0QBU0g_N0fmk1GNm0Q240c6<0T8@23W>0g>L0V]J0aBU0Re[0bU:0acW1cF]0dHa0Sg_0d8@0Woo00<0
07ooOol027oo0009Ool00`00Oom_N`02Kg/2Li`5JeX3HaP2G_L3F]H8CW<2E[D3DY@5:DX3BU82?Nl3
6<H236<35:D348@736<59BT36<H37>L55:D26<H3:DX536<5248336<26<H3DY@2AS439BT2Ool00`00
Oomoo`08Ool00`00OomS6002HaP2124:36<348@236<3000336<21243<H`2AS43>Lh2<H`37>L2AS43
DY@2AS43<H`348@212457>L536<36<H2<H`3AS43?Nl2:DX36<H2000312426<H3@Q02HaP3CW<29BT3
=Jd2Ool00`00Oomoo`08Ool00`00Oom24002@Q02AS43=Jd2<H`3=Jd2>Lh6<H`28@P3CW<2Ool3<H`2
9BT3Ool3JeX2@Q03JeX20003Nmh5JeX348@2?Nl3@Q02;F/348@3Nmh2Ool3Nmh200039BT2@Q03JeX3
G_L27>L85:D2F]H3AS42Ool00`00Oomoo`08Ool000Uoo`03001oofmk009_N`9cW0E[FP=S609Nm`=J
ePQ>L`9F]@=BU0DYBP=:DP8mk`<HaP8<H`<DY@<@Q0L<H`DU:@<HaP<Li`DDY@8HaP<YBPD<H`D8@P<<
H`8HaP=BU096<@<U:@9oo`03001oogoo00Qoo`03001oof<H009S60848@X<H`<@Q08<H`<000<<H`84
8@<aS096<@<icP8aS0<Li`96<@=BU096<@<aS0<@Q0848@DLi`D<H`<HaP8aS0=6<@<mk`8YBP<HaP80
00<48@8HaP=2409S60=>L`8U:@<e[@9oo`03001oogoo00Qoo`03001ood8@00924096<@<e[@8aS0<e
[@8icPHaS08Q20=>L`9oo`<aS08U:@=oo`=[FP9240=[FP8000=kgPE[FP<@Q08mk`=2408]J`<@Q0=k
gP9oo`=kgP8000<U:@9240=[FP=Nm`8Li`PDY@9JeP=6<@9oo`03001oogoo00Qoo`002Goo00<007oo
Kg/00Vmk0W>L1F]J0f<H0Ukg0e[F24ic0UJe0e:D1BU:0dYB0Sg_0aS60PaS0aBU0a241`aS1BDY0aS6
0acW1ABU0QS60bU:1@aS1@Q20`aS0QS60e:D0THa0bDY0Woo00<007ooOol027oo00<007ooHaP00V<H
0P@Q2PaS0a240PaS0`000`aS0P@Q0c6<0THa0cW>0S6<0acW0THa0e:D0THa0c6<0a240P@Q1AcW1@aS
0aS60S6<0dHa0cg_0RU:0aS60P000`@Q0QS60d8@0V<H0dic0RDY0cF]0Woo00<007ooOol027oo00<0
07oo@Q000T8@0THa0cF]0S6<0cF]0SW>1S6<0R480dic0Woo0c6<0RDY0goo0f]J0T8@0f]J0P000g_N
1F]J0a240Sg_0d8@0Re[0a240g_N0Woo0g_N0P000bDY0T8@0f]J0ekg0QcW21BU0U[F0dHa0Woo00<0
07ooOol027oo0009Ool00`00Oom[FP02JeX2Kg/3JeX2IcT3HaP2F]H6E[D2CW<3DY@2F]H3DY@2CW<3
?Nl3;F/2?Nl3000236<3248336<2248336<248@38@P29BT37>L3:DX2>Lh3BU82DY@37>L2248336<:
248336<2?Nl3<H`2Ool00`00Oomoo`08Ool00`00Oom>L`02CW<21245248348@236<3248248@30003
36<200036<H2;F/37>L2=Jd3@Q02>Lh336<21243000348@29BT3<H`2;F/3<H`2AS45CW<3?Nl3;F/2
>Lh36<H700032482:DX3DY@29BT3@Q02Ool00`00Oomoo`08Ool00`00Oom24002@Q02Li`3E[D5AS42
BU83@Q03>Lh20003AS42Kg/3<H`2:DX3CW<30002HaP3DY@25:D336<3@Q05Kg/2JeX3IcT5Ool3Mkd2
Nmh3Ool2;F/3BU82CW<3Li`3BU82Mkd36<H27>L38@P27>L3AS42Ool00`00Oomoo`08Ool000Uoo`03
001oof]J009[FP9_N`=[FP9W>@=S609JePIF]@9>L`=BU09JeP=BU09>L`<mk`<]J`8mk`<0008<H`<8
@P<<H`88@P<<H`8@Q0<Q208U:@<Li`<YBP8icP=:DP9BU0<Li`88@P<<H`X8@P<<H`8mk`<aS09oo`03
001oogoo00Qoo`03001oodic009>L`848@D8@P<@Q08<H`<8@P8@Q0<000<<H`8000<HaP8]J`<Li`8e
[@=2408icP<<H`848@<000<@Q08U:@<aS08]J`<aS096<@E>L`<mk`<]J`8icP<HaPL000<8@P8YBP=B
U08U:@=2409oo`03001oogoo00Qoo`03001ood8@0092409cW0=F]@E6<@9:DP=240<icP8000=6<@9_
N`<aS08YBP=>L`<0009S60=BU08DY@<<H`=240E_N`9[FP=W>@Eoo`=g_@9kgP=oo`8]J`=:DP9>L`=c
W0=:DP9g_@<HaP8Li`<Q208Li`=6<@9oo`03001oogoo00Qoo`002Goo00<007ooJeX016]J0fLi0V]J
0f<H0UJe0e[F0e:D0TYB0eJe0Tic0e:D0TYB0bU:0`Q20QcW1@Q20`aS0a240QBU0bU:0Sg_0c6<0TYB
0e:D0eJe0U:D0dic0RDY0a240PaS0`Q20`aS1@@Q0PaS0a240Re[0d8@0Woo00<007ooOol027oo00<0
07oo>Lh00SW>1@@Q0PQ20a240PaS0`Q20Q240`000`Q20P@Q0`aS0SF]0eJe0S6<1B480a240R481RU:
0SW>0d8@1Cg_0SF]0b480PaS0c6<0eJe0RDY1@aS2P@Q0c6<0T8@0dic0Woo00<007ooOol027oo00<0
07ooAS400THa0U[F0dic0T8@0cg_0SF]0cg_0d8@0Tic0d8@0UJe1Dic0eJe0goo0V]J0dYB0UJe0f]J
0g_N0W>L0fLi0Vmk1G>L0`000gNm0W>L0eJe1E[F1ABU0cW>0Ukg0be[1cg_0dHa0Woo00<007ooOol0
27oo0009Ool00`00Oom[FP04JeX3IcT2JeX3HaP2E[D3F]H3DY@2BU83E[D2CW<3DY@2BU83:DX32482
7>L5248336<348@25:D3:DX2?Nl3<H`2BU83DY@3E[D2DY@3CW<29BT348@236<3248336<5124236<3
48@2;F/3@Q02Ool00`00Oomoo`08Ool00`00OolicP02>Lh51242248348@236<3248248@300032482
124336<2=Jd3E[D2<H`58@P348@28@P6:DX2>Lh3@Q05?Nl2=Jd38@P236<3<H`3E[D29BT536<:1243
<H`2@Q03CW<2Ool00`00Oomoo`08Ool00`00Oom6<@02AS42F]H3CW<2@Q03?Nl2=Jd3?Nl3@Q02CW<3
@Q02E[D5CW<3E[D3Ool2JeX3BU82E[D3JeX3Nmh2Li`3IcT2Kg/5Li`30003Mkd2Li`3E[D5F]H55:D3
>Lh2G_L3;F/7?Nl3AS42Ool00`00Oomoo`08Ool000Uoo`03001oof]J00A[FP=W>@9[FP=S609F]@=J
eP=BU09:DP=F]@9>L`=BU09:DP<YBP<8@P8Li`D8@P<<H`<@Q08DY@<YBP8mk`<aS09:DP=BU0=F]@9B
U0=>L`8U:@<@Q08<H`<8@P<<H`D48@8<H`<@Q08]J`=2409oo`03001oogoo00Qoo`03001oocW>008i
cPD48@88@P<@Q08<H`<8@P8@Q0<000<8@P848@<<H`8e[@=F]@8aS0DQ20<@Q08Q20HYBP8icP=240Dm
k`8e[@<Q208<H`<aS0=F]@8U:@D<H`X48@<aS09240=>L`9oo`03001oogoo00Qoo`03001oodHa0096
<@9JeP=>L`9240<mk`8e[@<mk`=2409>L`=2409F]@E>L`=F]@=oo`9[FP=:DP9F]@=[FP=kgP9cW0=W
>@9_N`EcW0<000=g_@9cW0=F]@EJePDDY@<icP9Nm`<]J`Lmk`=6<@9oo`03001oogoo00Qoo`002Goo
00<007ooJeX01f]J0VLi0f<H0Ukg0eJe0e:D0Tic0e:D0UJe1DYB0`aS0`Q20QS60`@Q0PQ20bDY0c6<
1BU:1DYB1E:D0cW>0U:D0cW>0PaS0a240QcW0aBU0`Q20P@Q1@Q20`aS0Re[0dYB0Woo00<007ooOol0
27oo00<007oo:DX00RU:1`@Q2PaS0`@Q1@Q20a240TYB0e:D0Q240bDY0SF]0c6<0QBU0`@Q0`aS0S6<
0cF]0R480a240QcW0c6<0TYB0e[F0cF]0QS60cW>0THa0cF]0QBU0`@Q0PQ20be[0Tic0e:D0Woo00<0
07ooOol027oo00<007ooAS400THa0Tic0e:D0SW>1Be[0cF]0c6<0W_N0dic0Re[24Ha0dic0WNm0`aS
0WNm0f]J0acW0P@Q0b480RU:0d8@1EJe0fmk0W_N0f<H1E[F0WNm0`Q20aBU0RDY1BU:0cg_0T8@0dHa
0Woo00<007ooOol027oo0009Ool00`00Oom[FP07JeX2IcT3HaP2G_L3E[D3DY@2CW<3DY@2E[D5BU83
36<324826<H3124224839BT3<H`5:DX5BU85DY@3>Lh2DY@3>Lh236<348@27>L35:D3248212452483
36<2;F/3BU82Ool00`00Oomoo`08Ool00`00OolYBP02:DX7124:36<31245248348@2BU83DY@248@3
9BT2=Jd3<H`25:D3124336<2<H`3=Jd28@P348@27>L3<H`2BU83F]H3=Jd26<H3>Lh2AS43=Jd25:D3
12422483;F/2CW<3DY@2Ool00`00Oomoo`08Ool00`00Oom6<@02AS42CW<3DY@2>Lh5;F/3=Jd3<H`2
Nmh3CW<2;F/8AS43CW<2Mkd336<2Mkd3JeX37>L212438@P2:DX3@Q05E[D3Kg/2Nmh3HaP5F]H2Mkd3
24835:D29BT5:DX3?Nl2@Q03AS42Ool00`00Oomoo`08Ool000Uoo`03001oof]J00A[FP=S609[FP=W
>@9Nm`=JeP=F]@9BU0EF]@=>L`9240<DY@<8@P8mk`<aS08icP<DY@<8@P8@Q0<<H`8@Q0=6<@9F]@=:
DP<]J`8@Q0D<H`<DY@9:DPHicPL48@<@Q08YBP=BU09oo`03001oogoo00Qoo`03001oob48008Q2088
@PD000D<H`<8@P8<H`<000<48@88@P<DY@8mk`=:DP9240=6<@8mk`<Li`8Q20<YBP<U:@8aS0EF]@<H
aP8YBP=24096<@<e[@<48@9>L`=6<@9:DP=F]@9:DP<Li`848@<]J`EF]@9oo`03001oogoo00Qoo`03
001ood8@0092409:DP=>L`8DY@<mk`96<@<mk`<icP8000=2409>L`=6<@8icP<YBP=[FP9_N`<DY@8a
S0=[FPEoo`<8@P8Li`<U:@8YBP=240=BU09[FP=_N`8Li`=F]@9[FP<<H`<DY@8HaP<DY@9S60Dmk`=2
409oo`03001oogoo00Qoo`002Goo00<007ooJeX016]J0f<H0V]J0fLi0Ukg0e[F0eJe0U:D1EJe0dic
0T8@0aBU0`Q20Sg_0c6<0SW>0aBU0`Q20Q240`aS0Q240dHa0UJe0dYB0be[0Q241@aS0aBU0TYB1SW>
1`@Q0a240RU:0e:D0Woo00<007ooOol027oo00<007oo8@P00R480PQ21@001@aS0`Q20PaS0`000`@Q
0PQ20aBU0Sg_0dYB0T8@0dHa0Sg_0acW0R480bU:0bDY0S6<1EJe0aS60RU:0d8@0THa0cF]0`@Q0Tic
0dHa0TYB0eJe0TYB0acW0P@Q0be[1EJe0Woo00<007ooOol027oo00<007oo@Q000T8@0TYB0dic0QBU
0cg_0THa0cg_0cW>0P000d8@0Tic0dHa0SW>0bU:0f]J0Vmk0aBU0S6<0f]J1Goo0`Q20QcW0bDY0RU:
0d8@0e:D0V]J0fmk0QcW0eJe0V]J0`aS0aBU0QS60aBU0V<H1Cg_0d8@0Woo00<007ooOol027oo0009
Ool00`00Oom[FP04JeX3HaP2JeX3IcT2G_L3F]H3E[D2DY@5E[D3CW<2@Q035:D32482?Nl3<H`2>Lh3
5:D3248248@336<248@3AS42E[D3BU83;F/248@536<35:D2BU86>Lh7124348@2:DX3DY@2Ool00`00
Oomoo`08Ool00`00OolQ20028@P22485000536<3248236<30003124224835:D2?Nl3BU82@Q03AS42
?Nl37>L28@P3:DX39BT2<H`5E[D36<H2:DX3@Q02AS43=Jd31242CW<3AS42BU83E[D2BU837>L21243
;F/5E[D2Ool00`00Oomoo`08Ool00`00Oom24002@Q02BU83CW<25:D3?Nl2AS43?Nl3>Lh20003@Q02
CW<3AS42>Lh3:DX3JeX2Kg/35:D2<H`3JeX5Ool324827>L39BT2:DX3@Q03DY@2JeX3Kg/27>L3E[D2
JeX336<35:D26<H35:D2HaP5?Nl3@Q02Ool00`00Oomoo`08Ool000Uoo`03001oofmk009_N`M[FP=S
60EJeP=F]@9>L`=F]@E>L`9240<icP<e[@9:DP=240848@<8@PD<H`<8@P8<H`<DY@EF]@<aS0D<H`8@
Q0<aS09BU0=:DP=6<@8icP<DY@88@P<<H`8YBP=>L`9oo`03001oogoo00Qoo`03001ooacW008Li`84
8@D000<@Q08<H`<8@P8<H`H0008<H`<@Q08U:@DicP<DY@E6<@8HaP<48@D000<U:@9S60<mk`8]J`=F
]@8]J`<000<e[@9Nm`<YBP8HaP<]J`9>L`=6<@8U:@<Q209JeP=F]@9oo`03001oogoo00Qoo`03001o
ocg_008mk`8icP=cW08YBP=2408icP<]J`<e[@9S60<Li`9>L`=2408YBP<DY@=_N`9S60=>L`9JeP=_
N`<48@9oo`<<H`8U:@<aS08e[@<icP<mk`9240=S60EBU09S60PLi`<HaP8@Q0=:DP8mk`=2409oo`03
001oogoo00Qoo`002Goo00<007ooKg/00Vmk1f]J0f<H1E[F0eJe0Tic0eJe1Dic0T8@0cW>0cF]0TYB
0d8@0P@Q0`Q21@aS0`Q20PaS0aBU1EJe0c6<1@aS0Q240c6<0U:D0dYB0dHa0SW>0aBU0PQ20`aS0RU:
0dic0Woo00<007ooOol027oo00<007oo7>L00QcW0P@Q1@000a240PaS0`Q20PaS1P000PaS0a240RDY
1CW>0aBU1DHa0QS60`@Q1@000bDY0V<H0cg_0Re[0eJe0Re[0`000cF]0Ukg0bU:0QS60be[0Tic0dHa
0RDY0b480U[F0eJe0Woo00<007ooOol027oo00<007oo?Nl00Sg_0SW>0g>L0RU:0d8@0SW>0be[0cF]
0V<H0acW0Tic0d8@0RU:0aBU0fmk0V<H0dic0U[F0fmk0`@Q0Woo0`aS0RDY0c6<0SF]0cW>0cg_0T8@
0f<H1E:D0V<H21cW0aS60Q240dYB0Sg_0d8@0Woo00<007ooOol027oo0009Ool00`00Oom[FP09JeX3
IcT5G_L3E[D2DY@3E[D2DY@3CW<5AS43?Nl2AS438@P21246248536<224835:D5DY@3=Jd536<248@5
DY@3CW<3AS42@Q03<H`2:DX32482:DX3E[D2Ool00`00Oomoo`08Ool00`00OolaS002<H`26<H37>L2
9BT3:DX2;F/5<H`3:DX38@P236<38@P236<36<H28@P35:D2BU83>Lh2AS43BU83F]H2Mkd3IcT2>Lh3
AS42<H`3AS42;F/39BT5?Nl3:DX2;F/59BT38@P2;F/3DY@2BU83?Nl2Ool00`00Oomoo`08Ool00`00
OolQ20028@P5Nmh2Mkd3Kg/2Li`6Mkd2Ool35:D2IcT3:DX2=Jd6Ool2:DX3=Jd26<H3Nmh3Ool5Nmh2
1243E[D2:DX3IcT3AS42:DX3Nmh2DY@3>Lh21243Mkd3Li`2E[D3=Jd236<3Kg/2G_L3=Jd2Ool00`00
Oomoo`08Ool000Uoo`03001oof]J00U[FP=W>@ENm`=F]@9BU0=F]@9BU0=>L`E6<@<mk`96<@<Q2084
8@H8@PD<H`88@P<DY@EBU0<e[@D<H`8@Q0EBU0=>L`=6<@9240<aS08YBP<8@P8YBP=F]@9oo`03001o
ogoo00Qoo`03001ooc6<008aS08HaP<Li`8U:@<YBP8]J`DaS0<YBP<Q208<H`<Q208<H`<HaP8Q20<D
Y@9:DP<icP96<@=:DP=JeP9g_@=W>@8icP=6<@8aS0=6<@8]J`<U:@Dmk`<YBP8]J`DU:@<Q208]J`=B
U09:DP<mk`9oo`03001oogoo00Qoo`03001oob48008Q20EkgP9g_@=_N`9cW0Ig_@9oo`<DY@9W>@<Y
BP8e[@Ioo`8YBP<e[@8HaP=kgP=oo`EkgP848@=F]@8YBP=W>@=6<@8YBP=kgP9BU0<icP848@=g_@=c
W09F]@<e[@8<H`=_N`9Nm`<e[@9oo`03001oogoo00Qoo`002Goo00<007ooJeX02F]J0fLi1Ekg0eJe
0U:D0eJe0U:D0dic1DHa0cg_0THa0b480P@Q1PQ21@aS0PQ20aBU1E:D0cF]1@aS0Q241E:D0dic0dHa
0T8@0c6<0RU:0`Q20RU:0eJe0Woo00<007ooOol027oo00<007oo<H`00S6<0QS60acW0RDY0bU:0Re[
1C6<0bU:0b480PaS0b480PaS0aS60R480aBU0TYB0cW>0THa0dYB0e[F0WNm0fLi0SW>0dHa0S6<0dHa
0Re[0bDY1Cg_0bU:0Re[1BDY0b480Re[0e:D0TYB0cg_0Woo00<007ooOol027oo00<007oo8@P00R48
1G_N0WNm0fmk0W>L1WNm0Woo0aBU0VLi0bU:0SF]1Woo0RU:0cF]0QS60g_N0goo1G_N0P@Q0eJe0RU:
0fLi0dHa0RU:0g_N0U:D0cW>0P@Q0gNm0g>L0UJe0cF]0PaS0fmk0Ukg0cF]0Woo00<007ooOol027oo
0009Ool00`00Oomoo`1XOol00`00Oomoo`08Ool00`00Oomoo`1WOol00`00Oomoo`08Ool00`00Oomo
o`1XOol00`00Oomoo`08Ool000Uoof`000Yoof/000Yoof`000Yoo`00ogooJgoo003oOom[Ool00001
\
\>"],
  ImageRangeCache->{{{0, 361}, {112.125, 0}} -> {-0.0846572, -0.0234375, 
  0.00877927, 0.00877927}, {{9.625, 116.375}, {109.438, 
  2.625}} -> {-4.60869, -1.91102, 0.390614, 0.390614}, {{127.063, 233.875}, {
  109.438, 2.625}} -> {-50.4522, -1.89816, 0.390385, 0.390385}, {{244.563, 
  351.313}, {109.438, 2.625}} -> {-96.3785, -1.91102, 0.390614, 0.390614}}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["IMAGE SEGMENTATION", "Section"],

Cell["\<\
To recover the edges, the gradient image must be segmented using a global or \
local (i.e. adaptive) threshold operator. The choice of a threshold value \
determines the resulting segmentation and therefore the perceived quality of \
the edge detector. It is useful to consider the histogram (or probabilty \
density function) of the gradient image in selecting an appropriate threshold \
value. If using function Histogram, scale the gradient image to the default \
range {0,255}.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(pdf = 
      Histogram[
        \[ScriptCapitalM] = ContrastModifyScale[\[ScriptCapitalM], {255}]]; \n
    ListPlot[pdf, PlotJoined \[Rule] True, PlotRange \[Rule] All]; \)], 
  "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0200747 0.00373483 0.0147151 0.0178365 [
[.20682 .00222 -6 -9 ]
[.20682 .00222 6 0 ]
[.39356 .00222 -9 -9 ]
[.39356 .00222 9 0 ]
[.5803 .00222 -9 -9 ]
[.5803 .00222 9 0 ]
[.76704 .00222 -9 -9 ]
[.76704 .00222 9 0 ]
[.95378 .00222 -9 -9 ]
[.95378 .00222 9 0 ]
[.00757 .1039 -6 -4.5 ]
[.00757 .1039 0 4.5 ]
[.00757 .19308 -12 -4.5 ]
[.00757 .19308 0 4.5 ]
[.00757 .28226 -12 -4.5 ]
[.00757 .28226 0 4.5 ]
[.00757 .37144 -12 -4.5 ]
[.00757 .37144 0 4.5 ]
[.00757 .46063 -12 -4.5 ]
[.00757 .46063 0 4.5 ]
[.00757 .54981 -12 -4.5 ]
[.00757 .54981 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.20682 .01472 m
.20682 .02097 L
s
[(50)] .20682 .00222 0 1 Mshowa
.39356 .01472 m
.39356 .02097 L
s
[(100)] .39356 .00222 0 1 Mshowa
.5803 .01472 m
.5803 .02097 L
s
[(150)] .5803 .00222 0 1 Mshowa
.76704 .01472 m
.76704 .02097 L
s
[(200)] .76704 .00222 0 1 Mshowa
.95378 .01472 m
.95378 .02097 L
s
[(250)] .95378 .00222 0 1 Mshowa
.125 Mabswid
.05742 .01472 m
.05742 .01847 L
s
.09477 .01472 m
.09477 .01847 L
s
.13212 .01472 m
.13212 .01847 L
s
.16947 .01472 m
.16947 .01847 L
s
.24416 .01472 m
.24416 .01847 L
s
.28151 .01472 m
.28151 .01847 L
s
.31886 .01472 m
.31886 .01847 L
s
.35621 .01472 m
.35621 .01847 L
s
.43091 .01472 m
.43091 .01847 L
s
.46825 .01472 m
.46825 .01847 L
s
.5056 .01472 m
.5056 .01847 L
s
.54295 .01472 m
.54295 .01847 L
s
.61765 .01472 m
.61765 .01847 L
s
.655 .01472 m
.655 .01847 L
s
.69234 .01472 m
.69234 .01847 L
s
.72969 .01472 m
.72969 .01847 L
s
.80439 .01472 m
.80439 .01847 L
s
.84174 .01472 m
.84174 .01847 L
s
.87908 .01472 m
.87908 .01847 L
s
.91643 .01472 m
.91643 .01847 L
s
.99113 .01472 m
.99113 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02007 .1039 m
.02632 .1039 L
s
[(5)] .00757 .1039 1 0 Mshowa
.02007 .19308 m
.02632 .19308 L
s
[(10)] .00757 .19308 1 0 Mshowa
.02007 .28226 m
.02632 .28226 L
s
[(15)] .00757 .28226 1 0 Mshowa
.02007 .37144 m
.02632 .37144 L
s
[(20)] .00757 .37144 1 0 Mshowa
.02007 .46063 m
.02632 .46063 L
s
[(25)] .00757 .46063 1 0 Mshowa
.02007 .54981 m
.02632 .54981 L
s
[(30)] .00757 .54981 1 0 Mshowa
.125 Mabswid
.02007 .03255 m
.02382 .03255 L
s
.02007 .05039 m
.02382 .05039 L
s
.02007 .06822 m
.02382 .06822 L
s
.02007 .08606 m
.02382 .08606 L
s
.02007 .12173 m
.02382 .12173 L
s
.02007 .13957 m
.02382 .13957 L
s
.02007 .15741 m
.02382 .15741 L
s
.02007 .17524 m
.02382 .17524 L
s
.02007 .21092 m
.02382 .21092 L
s
.02007 .22875 m
.02382 .22875 L
s
.02007 .24659 m
.02382 .24659 L
s
.02007 .26443 m
.02382 .26443 L
s
.02007 .3001 m
.02382 .3001 L
s
.02007 .31794 m
.02382 .31794 L
s
.02007 .33577 m
.02382 .33577 L
s
.02007 .35361 m
.02382 .35361 L
s
.02007 .38928 m
.02382 .38928 L
s
.02007 .40712 m
.02382 .40712 L
s
.02007 .42495 m
.02382 .42495 L
s
.02007 .44279 m
.02382 .44279 L
s
.02007 .47846 m
.02382 .47846 L
s
.02007 .4963 m
.02382 .4963 L
s
.02007 .51414 m
.02382 .51414 L
s
.02007 .53197 m
.02382 .53197 L
s
.02007 .56765 m
.02382 .56765 L
s
.02007 .58548 m
.02382 .58548 L
s
.02007 .60332 m
.02382 .60332 L
s
.25 Mabswid
.02007 0 m
.02007 .61803 L
s
.5 Mabswid
.02381 .03255 m
.02754 .01472 L
.03128 .24659 L
.03501 .13957 L
.03875 .31794 L
.04248 .37144 L
.04622 .21092 L
.04995 .46063 L
.05369 .60332 L
.05742 .35361 L
.06116 .47846 L
.06489 .47846 L
.06863 .44279 L
.07236 .15741 L
.0761 .4963 L
.07983 .42495 L
.08357 .60332 L
.0873 .46063 L
.09104 .47846 L
.09477 .47846 L
.09851 .53197 L
.10224 .35361 L
.10598 .44279 L
.10971 .42495 L
.11345 .51414 L
.11718 .47846 L
.12092 .26443 L
.12465 .3001 L
.12838 .31794 L
.13212 .28226 L
.13585 .37144 L
.13959 .40712 L
.14332 .26443 L
.14706 .21092 L
.15079 .15741 L
.15453 .19308 L
.15826 .19308 L
.162 .13957 L
.16573 .08606 L
.16947 .1039 L
.1732 .17524 L
.17694 .13957 L
.18067 .08606 L
.18441 .17524 L
.18814 .1039 L
.19188 .05039 L
.19561 .1039 L
.19935 .08606 L
.20308 .13957 L
.20682 .03255 L
Mistroke
.21055 .08606 L
.21429 .21092 L
.21802 .12173 L
.22176 .13957 L
.22549 .1039 L
.22923 .1039 L
.23296 .1039 L
.23669 .05039 L
.24043 .13957 L
.24416 .08606 L
.2479 .08606 L
.25163 .13957 L
.25537 .08606 L
.2591 .13957 L
.26284 .13957 L
.26657 .17524 L
.27031 .12173 L
.27404 .1039 L
.27778 .12173 L
.28151 .05039 L
.28525 .12173 L
.28898 .15741 L
.29272 .1039 L
.29645 .15741 L
.30019 .12173 L
.30392 .1039 L
.30766 .08606 L
.31139 .12173 L
.31513 .12173 L
.31886 .12173 L
.3226 .06822 L
.32633 .15741 L
.33007 .06822 L
.3338 .12173 L
.33754 .1039 L
.34127 .08606 L
.345 .15741 L
.34874 .1039 L
.35247 .05039 L
.35621 .06822 L
.35994 .08606 L
.36368 .05039 L
.36741 .15741 L
.37115 .06822 L
.37488 .12173 L
.37862 .15741 L
.38235 .1039 L
.38609 .15741 L
.38982 .08606 L
.39356 .1039 L
Mistroke
.39729 .15741 L
.40103 .17524 L
.40476 .17524 L
.4085 .08606 L
.41223 .1039 L
.41597 .12173 L
.4197 .15741 L
.42344 .1039 L
.42717 .13957 L
.43091 .12173 L
.43464 .12173 L
.43838 .17524 L
.44211 .13957 L
.44585 .06822 L
.44958 .08606 L
.45331 .12173 L
.45705 .06822 L
.46078 .1039 L
.46452 .13957 L
.46825 .22875 L
.47199 .06822 L
.47572 .22875 L
.47946 .21092 L
.48319 .05039 L
.48693 .12173 L
.49066 .12173 L
.4944 .1039 L
.49813 .12173 L
.50187 .12173 L
.5056 .12173 L
.50934 .05039 L
.51307 .06822 L
.51681 .13957 L
.52054 .03255 L
.52428 .13957 L
.52801 .03255 L
.53175 .12173 L
.53548 .15741 L
.53922 .08606 L
.54295 .12173 L
.54669 .13957 L
.55042 .13957 L
.55415 .05039 L
.55789 .1039 L
.56162 .06822 L
.56536 .12173 L
.56909 .05039 L
.57283 .05039 L
.57656 .1039 L
.5803 .1039 L
Mistroke
.58403 .15741 L
.58777 .06822 L
.5915 .08606 L
.59524 .08606 L
.59897 .08606 L
.60271 .12173 L
.60644 .12173 L
.61018 .08606 L
.61391 .1039 L
.61765 .08606 L
.62138 .06822 L
.62512 .05039 L
.62885 .08606 L
.63259 .1039 L
.63632 .08606 L
.64006 .17524 L
.64379 .06822 L
.64753 .08606 L
.65126 .1039 L
.655 .21092 L
.65873 .08606 L
.66246 .17524 L
.6662 .06822 L
.66993 .12173 L
.67367 .1039 L
.6774 .05039 L
.68114 .06822 L
.68487 .08606 L
.68861 .08606 L
.69234 .1039 L
.69608 .06822 L
.69981 .1039 L
.70355 .1039 L
.70728 .19308 L
.71102 .1039 L
.71475 .06822 L
.71849 .05039 L
.72222 .1039 L
.72596 .1039 L
.72969 .13957 L
.73343 .19308 L
.73716 .08606 L
.7409 .15741 L
.74463 .01472 L
.74837 .06822 L
.7521 .08606 L
.75584 .05039 L
.75957 .06822 L
.76331 .06822 L
.76704 .08606 L
Mistroke
.77077 .05039 L
.77451 .05039 L
.77824 .08606 L
.78198 .06822 L
.78571 .03255 L
.78945 .08606 L
.79318 .06822 L
.79692 .08606 L
.80065 .01472 L
.80439 .06822 L
.80812 .06822 L
.81186 .03255 L
.81559 .01472 L
.81933 .01472 L
.82306 .03255 L
.8268 .05039 L
.83053 .03255 L
.83427 .01472 L
.838 .03255 L
.84174 .01472 L
.84547 .01472 L
.84921 .03255 L
.85294 .01472 L
.85668 .05039 L
.86041 .01472 L
.86415 .01472 L
.86788 .03255 L
.87162 .05039 L
.87535 .01472 L
.87908 .01472 L
.88282 .01472 L
.88655 .01472 L
.89029 .03255 L
.89402 .01472 L
.89776 .01472 L
.90149 .01472 L
.90523 .01472 L
.90896 .01472 L
.9127 .01472 L
.91643 .05039 L
.92017 .01472 L
.9239 .03255 L
.92764 .01472 L
.93137 .03255 L
.93511 .01472 L
.93884 .01472 L
.94258 .01472 L
.94631 .01472 L
.95005 .01472 L
.95378 .01472 L
Mistroke
.95752 .01472 L
.96125 .01472 L
.96499 .01472 L
.96872 .01472 L
.97246 .01472 L
.97619 .03255 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo0011Ool0
0`00Oomoo`02Ool00`00Oomoo`0VOol50002Ool00`00Oomoo`02Ool00`00Oomoo`0TOol50002Ool0
0`00Oomoo`02Ool00`00Oomoo`0UOol30003Ool00`00Oomoo`02Ool00`00Oomoo`0UOol30003Ool0
0`00Oomoo`02Ool00`00Oomoo`09Ool0041oo`03001oo`00009oo`03001oo`0002Uoo`07001oogoo
Ool007oo00000Woo00<007oo00009goo00L007ooOomoo`00Ool00002Ool00`00Ool0000VOol00`00
Oomoo`02Ool00`00Ool00002Ool00`00Ool0000VOol00`00Oomoo`02Ool00`00Ool00002Ool00`00
Ool0000:Ool0049oo`06001oogoo001oo`00:Goo00L007ooOomoo`00Ool00002Ool00`00Ool0000W
Ool00`00Oomoo`03Ool01P00Oomoo`00Ool002Moo`07001oogooOol007oo00000Woo00<007oo0000
9goo00<007ooOol00goo00H007ooOol007oo000:Ool0041oo`8000=oo`03001oo`0002Uoo`07001o
ogooOol007oo00000Woo00<007oo00009goo00@007ooOomoo`8000=oo`03001oo`0002Moo`07001o
ogooOol007oo00000Woo00<007oo00009goo00@007ooOomoo`8000=oo`03001oo`0000Yoo`00@7oo
00<007ooOol00Woo00<007oo0000:Goo00L007ooOomoo`00Ool00002Ool00`00Ool0000WOol01@00
Oomoogoo000017oo00<007oo00009Woo00<007oo00000Woo00<007oo00000Woo00<007oo00009Woo
00<007oo00000Woo00<007ooOol00Woo00<007oo00002Woo0010Ool30003Ool00`00Oomoo`0WOol2
0004Ool00`00Oomoo`02Ool00`00Oomoo`0UOol20003Ool30003Ool00`00Oomoo`0VOol00`00Oomo
o`02Ool00`00Oomoo`02Ool00`00Oomoo`0VOol01000Oomoogoo0`000goo00<007ooOol02Goo003o
OolQOol0015oo`03001oogoo0?moo`eoo`004Goo00<007ooOol0ogoo3Goo000AOol00`00Oomoo`3o
Ool=Ool0015oo`03001oogoo0?moo`eoo`0037ooo`004P000goo000AOol00`00Ool00007Ool00`00
Oomoo`07Ool00`00Oomoo`08Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00
Oomoo`07Ool00`00Oomoo`08Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00
Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`08Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00
Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`08Ool01@00Oomoogoo00001Goo00<007ooOol01Woo
0P000Woo0P000goo00L007oo000007oo001oo`020002Ool2000017oo001oo`001Goo0`0000Aoo`00
Ool000Aoo`03001oogoo009oo`03001oogoo009oo`03001oogoo00=oo`004Goo00<007oo0000<7oo
00<007ooOol0<7oo00<007ooOol0<7oo00<007ooOol0:Woo00<007ooOol00goo00<007ooOol01Woo
00@007ooOomoo`8000=oo`07001oo`00001oo`00Ool00P000Woo00H007ooOol007oo0005Ool01`00
Ool007oo001oo`0000Aoo`03001oogoo009oo`03001oogoo00Qoo`004Goo0`00`goo00<007ooOol0
37oo00@007ooOol0009oo`05001oo`00Ool00002Ool200001Woo001oo`00Ool000=oo`03001oogoo
00Aoo`06001oo`00001oo`002goo00<007ooOol01goo000AOol30033Ool00`00Oomoo`0<Ool01000
Oomoo`000Woo00D007oo001oo`00009oo`800006Ool007oo001oo`000goo00<007ooOol017oo00H0
07oo000007oo000;Ool00`00Oomoo`07Ool0015oo`<0031oo`03001oogoo05=oo`03001oo`0003Yo
o`03001oogoo00Qoo`05001oogooOol00002Ool02000Oomoo`00Ool007oo0002Ool00`00Ool00002
Ool20004Ool00`00Oomoo`05Ool01@00Ool007oo00002goo00<007ooOol01goo000AOol00`00Ool0
000`Ool00`00Oomoo`1COol00`00Ool0000jOol00`00Oomoo`08Ool01@00Oomoogoo00000Woo00H0
07ooOol007oo0006Ool00`00Oomoo`02000<Ool00`00Oomoo`0GOol0015oo`03001oo`00031oo`03
001oogoo05=oo`03001oo`0003Yoo`03001oogoo00Qoo`05001oogooOol00002Ool01P00Oomoo`00
Ool000Ioo`03001oogoo008000aoo`03001oogoo01Moo`004Goo00<007oo0000<7oo00<007ooOol0
Dgoo00<007oo0000>Woo0P002Goo00@007ooOomoo`800003Ool007oo009oo`03001oogoo00Eoo`05
001oogooOol0000<Ool00`00Oomoo`0GOol0015oo`03001oo`00031oo`03001oogoo05=oo`03001o
o`0003Yoo`8000Uoo`04001oogooOol200000goo001oo`02Ool00`00Oomoo`05Ool01@00Oomoogoo
000037oo00<007ooOol05goo000AOol3000/Ool01@00Oomoogoo00001goo00<007ooOol02Goo00<0
07ooOol04Goo00@007ooOol001moo`03001oogoo00Eoo`06001oogoo001oo`001Woo00@007ooOomo
o`8000eoo`03001oogoo00]oo`03001oogoo00Uoo`03001oogoo00Aoo`800003Ool007oo009oo`80
0003Ool00000009oo`04001oo`000004Ool00`00Oomoo`05Ool01@00Oomoogoo000037oo00<007oo
Ool05goo000AOol00`00Ool0000/Ool01@00Oomoogoo00001goo00<007ooOol02Goo00<007ooOol0
4Goo00@007ooOol001moo`03001oogoo00Eoo`06001oogoo001oo`001Woo00@007ooOomoo`8000eo
o`03001oogoo00]oo`03001oogoo00Uoo`03001oogoo00Aoo`800003Ool007oo009oo`800003Ool0
0000009oo`04001oo`00000gOol0015oo`03001oo`0002aoo`04001oogooOol20006Ool00`00Oomo
o`09Ool00`00Oomoo`0AOol01000Oomoo`007goo00<007ooOol01Goo00H007ooOol007oo0006Ool0
1000Oomoogoo0P003Goo00<007ooOol02goo00<007ooOol02Goo00<007ooOol017oo0P0000=oo`00
Ool00Woo0P0000Moo`00Ool007oo001oo`02000gOol0015oo`03001oo`0002aoo`04001oogooOol2
0006Ool00`00Oomoo`09Ool00`00Oomoo`0AOol200000goo001oo`0NOol00`00Oomoo`05Ool20000
17oo001oo`001Woo00@007ooOomoo`8000aoo`8000eoo`8000Uoo`8000Ioo`800003Ool00000009o
o`800007Ool007oo001oo`00Ool00P00=goo000AOol00`00Ool0000/Ool01000Oomoogoo0P001Woo
00<007ooOol02Goo00<007ooOol04Goo0P0000=oo`00Ool07Woo00<007ooOol01Goo0P0000Aoo`00
Ool000Ioo`04001oogooOol2000<Ool2000=Ool20009Ool20006Ool200000goo00000002Ool20000
1goo001oo`00Ool007oo008003Moo`004Goo0`00;7oo00@007ooOomoo`8000Ioo`03001oogoo00Uo
o`03001oogoo00Uoo`03001oo`0000Eoo`@00003Ool007oo019oo`04001oogoo0003Ool01000Oomo
o`001Woo00L007oo001oo`00Ool00006Ool01000Ool007oo0P000goo00<007ooOol01Woo00<007oo
00000goo00<007ooOol00goo00<007ooOol00P000goo00<007ooOol00goo0P001Woo0`0000Aoo`00
0000009oo`800005Ool00000001oo`02000gOol0015oo`03001oo`0002aoo`04001oogooOol20006
Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Ool00005Ool400000goo001oo`0BOol01000Oomo
o`000goo00@007ooOol000Ioo`07001oo`00Ool007oo00001Woo00@007oo001oo`8000=oo`03001o
ogoo00Ioo`03001oo`0000=oo`03001oogoo00=oo`03001oogoo008000=oo`03001oogoo00=oo`80
00Ioo`<0009oo`80009oo`800004Ool00000000jOol0015oo`03001oo`0002]oo`03001oo`00009o
o`8000Eoo`8000]oo`03001oogoo00Uoo`03001oo`0000Aoo`03001oogoo00800003Ool007oo019o
o`800003Ool007oo009oo`04001oogoo0006Ool01P00Ool007oo001oo`8000Eoo`<00004Ool007oo
0002Ool20006Ool01000Oomoo`000goo0P0017oo00<007oo00000Woo00@007ooOol000Eoo`03001o
o`0000Eoo`03001oo`0000=oo`04001oogoo0002Ool00`00Ool0000jOol0015oo`03001oo`0002]o
o`03001oo`00009oo`8000Eoo`8000]oo`03001oogoo00Uoo`03001oo`0000Aoo`03001oogoo0080
0003Ool007oo019oo`800003Ool007oo009oo`04001oogoo0006Ool01P00Ool007oo001oo`8000Eo
o`<00004Ool007oo0002Ool20006Ool01000Oomoo`000goo0P0017oo00<007oo00000Woo00@007oo
Ool000Eoo`03001oo`0000Eoo`03001oo`0000=oo`04001oogoo0002Ool00`00Ool0000jOol0015o
o`<002Eoo`08001oogooOol007oo001oo`800003Ool0000000Eoo`800005Ool00000Ool00006Ool0
0`00Oomoo`05Ool01`00Oomoogoo001oo`00009oo`03001oo`00009oo`800003Ool007oo00=oo`03
001oogoo009oo`03001oogoo00Moo`800003Ool007oo009oo`04001oogoo0006Ool01P00Ool007oo
001oo`800003Ool007oo009oo`<00004Ool007oo0002Ool40002Ool00`00Ool00002Ool01000Ool0
07oo0P000Woo00D007oo001oo`00009oo`800003Ool007oo00Aoo`03001oo`0000=oo`05001oo`00
Ool00003Ool01000Oomoo`000Woo00<007oo0000>Woo000AOol00`00Ool0000UOol02000Oomoogoo
001oo`00Ool300000goo001oo`04Ool200001Goo000007oo00001Goo00<007oo00001Woo00L007oo
Oomoo`00Ool00002Ool00`00Ool00003Ool00`00Ool00004Ool00`00Oomoo`02Ool00`00Oomoo`07
Ool200000goo00000002Ool00`00Oomoo`020005Ool02P00Ool00000Ool007oo001oo`000goo1000
0Woo00@007ooOol0009oo`06001oogoo001oo`000Woo00@007oo001oo`80009oo`05001oo`00Ool0
0003Ool200000goo001oo`02Ool01000Oomoo`000goo0P00BGoo000AOol00`00Ool0000UOol02000
Oomoogoo001oo`00Ool300000goo001oo`04Ool200001Goo000007oo00001Goo00<007oo00001Goo
0P000goo00<007oo00000Woo00<007oo00000goo00<007oo000017oo00<007ooOol00Woo00<007oo
Ool01goo0P0000=oo`0000000Woo00<007ooOol00P001Goo00X007oo000007oo001oo`00Ool000=o
o`@0009oo`04001oogoo0002Ool01P00Oomoo`00Ool0009oo`04001oo`00Ool20002Ool01@00Ool0
07oo00000goo0P0000=oo`00Ool00Woo00@007ooOol000=oo`8004Uoo`002goo00<007ooOol00goo
00<007oo00009Goo0P000Woo00@007oo001oo`<00003Ool007oo00Aoo`03001oo`0000800003Ool0
07oo00Aoo`03001oo`0000Eoo`80009oo`800003Ool0000000800003Ool007oo009oo`04001oo`00
0003Ool20003Ool20008Ool300001Goo001oogoo00000Woo0P001Goo00X007oo000007oo001oo`00
Ool0009oo`05001oo`00Ool00002Ool01000Oomoo`000Woo00<007ooOol00P0017oo0P0000Moo`00
Ool007oo001oo`030004Ool00`00Ool00003Ool01000Oomoo`000goo0P00BGoo000:Ool00`00Ool0
0004Ool00`00Ool0000UOol20002Ool01000Ool007oo0`0000=oo`00Ool017oo00<007oo00000P00
00=oo`00Ool017oo00<007oo000017oo00<007oo00000Woo0P0000=oo`0000000P0000=oo`00Ool0
0Woo00@007oo000000=oo`8000=oo`8000Qoo`<00005Ool007ooOol00002Ool20005Ool02P00Ool0
0000Ool007oo001oo`000Woo00D007oo001oo`00009oo`04001oogoo0002Ool00`00Oomoo`020004
Ool200001goo001oo`00Ool007oo00<000Aoo`03001oo`0000=oo`04001oogoo0003Ool20019Ool0
00aoo`03001oogoo009oo`<002Eoo`80009oo`04001oo`00Ool300000goo001oo`02Ool300001Woo
00000000Ool000Aoo`800004Ool007oo0002Ool01@00Oomoo`00Ool00P0000=oo`0000000P0000=o
o`00Ool00Woo00L007oo000007oo001oo`020003Ool20002Ool00`00Oomoo`03Ool01@00Ool007oo
00000Woo00<007ooOol00P0000=oo`00Ool00Woo00T007oo000007oo001oo`00Ool00P0000Ioo`00
Ool007oo0002Ool200000goo001oo`02Ool200000goo001oo`03Ool200001goo001oo`00Ool007oo
00<000Aoo`04001oo`000002Ool00`00Oomoo`020002Ool20019Ool000Yoo`8000Eoo`03001oo`00
02Eoo`80009oo`03001oo`00009oo`800003Ool007oo009oo`04001oogooOol300000goo001oo`03
Ool2000017oo001oo`000Woo00D007ooOol007oo00800003Ool0000000800003Ool007oo00=oo`<0
0003Ool007oo008000=oo`80009oo`03001oogoo009oo`06001oogoo001oo`000Woo00<007ooOol0
0P0000Eoo`00Oomoo`0000=oo`06001oo`00Ool007oo0P0000=oo`00Ool00Woo00L007ooOomoo`00
Ool00003Ool20007Ool02000Ool007oo001oo`00Ool30007Ool01000Oomoo`000goo00<007ooOol0
0P00BGoo000:Ool00`00Oomoo`04Ool00`00Ool0000UOol20002Ool00`00Ool00002Ool200000goo
001oo`02Ool01000Oomoogoo0`0000=oo`00Ool00goo0P0000Aoo`00Ool0009oo`05001oogoo001o
o`0200000goo0000000200000goo001oo`03Ool300000goo001oo`020003Ool20002Ool00`00Oomo
o`02Ool01P00Oomoo`00Ool0009oo`03001oogoo00800005Ool007ooOol00003Ool01P00Ool007oo
001oo`800003Ool007oo009oo`07001oogooOol007oo00000goo0P001goo00P007oo001oo`00Ool0
07oo0`001goo00@007ooOol000=oo`03001oogoo008004Uoo`002Woo0`0017oo00<007oo000097oo
00@007oo001oo`800003Ool007oo009oo`03001oo`0000=oo`05001oogooOol00002Ool00`00Ool0
0002Ool02@00Ool007oo001oo`00Ool00003Ool02`00Ool007oo001oo`00Ool007oo000017oo00H0
07oo001oo`00Ool20003Ool01@00Ool007oo000017oo00H007ooOol007oo0002Ool00`00Oomoo`03
000017oo001oo`000goo00H007oo001oo`00Ool200000goo001oo`02Ool01000Oomoogoo0P0017oo
0P001goo00P007oo001oo`00Ool007oo0P0027oo00@007ooOol000=oo`03001oogoo008004Uoo`00
4Goo00<007oo000097oo00@007oo001oo`800003Ool007oo009oo`03001oo`0000=oo`05001oogoo
Ool00002Ool00`00Ool00002Ool02@00Ool007oo001oo`00Ool00003Ool02`00Ool007oo001oo`00
Ool007oo000017oo00H007oo001oo`00Ool20003Ool01@00Ool007oo000017oo00H007ooOol007oo
0002Ool00`00Oomoo`03000017oo001oo`000goo00H007oo001oo`00Ool200000goo001oo`02Ool0
1000Oomoogoo0P0017oo0P001goo00P007oo001oo`00Ool007oo0P0027oo00@007ooOol000=oo`03
001oogoo008004Uoo`004Goo0`0097oo00@007oo001oo`800003Ool007oo009oo`04001oo`00Ool2
0004Ool01P00Oomoo`00Ool0009oo`09001oo`00Ool007oo001oo`0000=oo`<00004Ool007oo0002
Ool20004Ool01000Ool007oo0P0000=oo`00Ool00Woo00@007oo001oo`@00005Ool007ooOol00002
Ool00`00Ool00002Ool3000017oo000000000goo00@007oo001oo`800004Ool007oo0003Ool01000
Oomoogoo0P0017oo0P001goo00P007oo001oo`00Ool007oo0P0027oo00@007ooOol000Aoo`04001o
o`000019Ool0015oo`03001oo`0002Aoo`04001oo`00Ool200000goo001oo`02Ool01000Ool007oo
0P0017oo00H007ooOol007oo0002Ool02@00Oomoogoo001oo`00Ool00007Ool00`00Oomoo`02Ool2
0004Ool01000Ool007oo0P0000=oo`00Ool00Woo00@007oo001oo`@00003Ool007oo00Aoo`03001o
o`00009oo`03001oogoo00Moo`04001oo`00Ool2000017oo001oo`001goo0P003Goo0P000Woo00@0
07oo000000Yoo`04001oogoo0004Ool01000Ool00000BGoo000AOol00`00Ool0000TOol01000Ool0
07oo0P0000=oo`00Ool00Woo00@007oo001oo`8000Aoo`06001oogoo001oo`000Woo00T007ooOomo
o`00Ool007oo00001goo00<007ooOol00Woo0P0017oo00@007oo001oo`800003Ool007oo009oo`04
001oo`00Ool400000goo001oo`04Ool00`00Ool00002Ool00`00Oomoo`07Ool01000Ool007oo0P00
00Aoo`00Ool000Moo`8000eoo`80009oo`04001oo`00000:Ool00`00Ool00005Ool01000Ool00000
BGoo000AOol01000Oomoo`008goo00H007oo001oo`00Ool20003Ool01000Ool007oo0P0017oo00H0
07ooOol007oo0002Ool01000Oomoogoo0P0000=oo`0000001goo00<007ooOol00Woo00<007ooOol0
0goo00H007oo000007oo0002Ool00`00Ool00002Ool200001Woo001oo`00Ool000Eoo`05001oo`00
Ool0000:Ool01000Ool007oo0P000Woo0P0027oo00<007ooOol037oo00D007ooOol007oo008000Yo
o`03001oo`0000Eoo`04001oo`000019Ool0015oo`04001oogoo000SOol01P00Ool007oo001oo`80
00=oo`04001oo`00Ool20004Ool01P00Oomoo`00Ool0009oo`04001oogooOol200000goo00000007
Ool00`00Oomoo`02Ool00`00Oomoo`03Ool01P00Ool00000Ool0009oo`03001oo`00009oo`800006
Ool007oo001oo`001Goo00D007oo001oo`0000Yoo`04001oo`00Ool20002Ool20008Ool00`00Oomo
o`0<Ool01@00Oomoo`00Ool00P002Woo00<007oo00001Goo00@007oo000004Uoo`004Goo0P0000=o
o`0000008Woo00<007ooOol00P0000=oo`00Ool00goo00@007oo001oo`8000Aoo`05001oogoo001o
o`0200000goo001oo`03Ool00`00Ool00008Ool00`00Oomoo`02Ool00`00Oomoo`03Ool01P00Oomo
o`00Ool0009oo`03001oo`0000=oo`07001oo`00Ool007oo00001Goo00D007oo001oo`0000Yoo`03
001oo`00009oo`03001oogoo008000Qoo`03001oogoo00aoo`05001oogoo001oo`02000:Ool00`00
Ool00005Ool200000goo001oo`18Ool0015oo`03001oogoo0080029oo`03001oogoo00800003Ool0
07oo00Eoo`03001oo`0000]oo`03001oo`0000Aoo`03001oo`0000Qoo`03001oogoo009oo`03001o
ogoo00=oo`06001oogoo001oo`000Woo00<007oo00000goo00L007ooOomoo`00Ool00005Ool01@00
Ool007oo00003goo00<007ooOol02Woo00<007ooOol037oo00D007ooOol007oo008000Yoo`03001o
o`0000Eoo`800003Ool007oo04Qoo`004Goo00<007ooOol00P008Woo00<007ooOol00P0000=oo`00
Ool01Woo0P002goo00<007oo000017oo00<007oo000027oo00<007ooOol00Woo00<007ooOol00goo
00H007ooOol007oo0002Ool00`00Ool00003Ool01`00Oomoogoo001oo`0000Eoo`05001oo`00Ool0
000?Ool00`00Oomoo`0:Ool00`00Oomoo`0<Ool00`00Oomoo`0200000goo001oo`09Ool00`00Ool0
0005Ool200000goo001oo`18Ool0015oo`03001oogoo0080029oo`03001oogoo00800003Ool007oo
00Ioo`8000]oo`8000Eoo`03001oo`0000Qoo`03001oogoo009oo`03001oogoo00=oo`06001oogoo
001oo`000Woo00<007oo00000goo00<007ooOol00Woo0P001Goo0P0000=oo`0000003goo00<007oo
Ool02Woo00<007ooOol037oo00<007ooOol00P0000=oo`00Ool02Woo0P001Goo0P0000=oo`00Ool0
B7oo000AOol00`00Oomoo`02000ROol00`00Oomoo`0200000goo001oo`06Ool2000;Ool20005Ool0
0`00Ool00008Ool00`00Oomoo`02Ool00`00Oomoo`03Ool01P00Oomoo`00Ool0009oo`03001oo`00
00=oo`03001oogoo009oo`8000Eoo`800003Ool0000000moo`03001oogoo00Yoo`03001oogoo00ao
o`03001oogoo00800003Ool007oo00Yoo`8000Eoo`800003Ool007oo04Qoo`004Goo0P0000=oo`00
00002Goo00<007ooOol04goo00@007ooOol0009oo`04001oogoo0007Ool2000<Ool00`00Oomoo`03
Ool00`00Ool00008Ool00`00Oomoo`02Ool00`00Oomoo`03Ool01P00Oomoo`00Ool0009oo`03001o
o`0000=oo`03001oogoo009oo`03001oogoo00Aoo`800003Ool0000000moo`03001oogoo00Yoo`03
001oogoo00aoo`07001oogooOol007oo00002goo0P001Goo0P0000=oo`00Ool0B7oo000AOol00`00
Oomoo`020009Ool00`00Oomoo`0COol01000Oomoo`000Woo00@007ooOol000Moo`8000aoo`03001o
ogoo025oo`03001oo`0000Qoo`03001oogoo00Aoo`800003Ool0000002]oo`07001oogooOol007oo
00002goo0P001Goo0P00Bgoo000AOol00`00Oomoo`020009Ool00`00Oomoo`0COol01000Oomoo`00
0Woo00@007ooOol000Moo`03001oogoo00]oo`03001oogoo025oo`03001oo`0000Qoo`03001oogoo
00Aoo`800003Ool0000002]oo`07001oogooOol007oo00002goo0P001Goo0P00Bgoo000AOol00`00
Oomoo`020009Ool00`00Oomoo`0COol00`00Ool00003Ool01000Oomoo`001goo00<007ooOol02goo
00<007ooOol08Woo0P0027oo00<007ooOol017oo0P0000=oo`000000:goo00L007ooOomoo`00Ool0
000;Ool20006Ool00`00Oomoo`19Ool0015oo`03001oogoo008000Uoo`03001oogoo01=oo`03001o
o`0000=oo`04001oogoo0007Ool00`00Oomoo`0;Ool00`00Oomoo`0ROol20008Ool00`00Oomoo`04
Ool200000goo0000000[Ool01`00Oomoogoo001oo`0000]oo`03001oogoo00Eoo`03001oogoo04Uo
o`004Goo0P0000=oo`0000002Goo00<007ooOol04goo0`000goo00@007ooOol000Moo`03001oogoo
00]oo`03001oogoo029oo`8000Qoo`03001oogoo00Aoo`800003Ool0000002]oo`07001oogooOol0
07oo00002goo00<007ooOol01Goo00<007ooOol0BGoo000AOol00`00Oomoo`020009Ool00`00Oomo
o`0COol3000>Ool00`00Oomoo`11Ool200000goo0000000_Ool00`00Oomoo`0;Ool00`00Oomoo`05
Ool00`00Oomoo`19Ool0015oo`03001oogoo008000Uoo`03001oogoo019oo`04001oo`00000>Ool0
0`00Oomoo`12Ool01000Ool00000;goo00<007ooOol02goo00<007ooOol01Goo00<007ooOol0BGoo
0004Ool50002Ool00`00Oomoo`03Ool00`00Oomoo`020009Ool00`00Oomoo`0BOol01000Ool00000
3Woo00<007ooOol0@Woo00@007oo000002moo`03001oogoo00]oo`03001oogoo00Eoo`03001oogoo
04Uoo`001Woo00L007ooOomoo`00Ool00004Ool00`00Oomoo`020009Ool00`00Oomoo`0BOol01000
Ool000003Woo00<007ooOol0@Woo00@007oo000002moo`03001oogoo00]oo`03001oogoo00Eoo`03
001oogoo04Uoo`001Woo00L007ooOomoo`00Ool00004Ool50009Ool00`00Oomoo`0BOol01000Ool0
00003Woo00<007ooOol0@Woo00@007oo000002moo`03001oogoo00]oo`03001oogoo00Eoo`03001o
ogoo04Uoo`001Woo00L007ooOomoo`00Ool00004Ool00`00Oomoo`020009Ool00`00Oomoo`0BOol0
0`00Oomoo`0?Ool00`00Oomoo`12Ool01000Ool00000;goo00<007ooOol0Ggoo0006Ool01`00Oomo
ogoo001oo`0000Aoo`03001oogoo008000Uoo`03001oogoo019oo`03001oogoo00moo`03001oogoo
049oo`04001oo`00000_Ool00`00Oomoo`1OOol000Eoo`8000Aoo`03001oogoo00=oo`03001oogoo
008000Uoo`03001oogoo019oo`03001oogoo00moo`03001oogoo049oo`04001oo`00000_Ool00`00
Oomoo`1OOol0015oo`800003Ool00000009oo`03001oogoo00Aoo`03001oogoo019oo`03001oogoo
00moo`03001oogoo049oo`04001oo`00000_Ool00`00Oomoo`1OOol0015oo`03001oogoo0080009o
o`03001oogoo00Aoo`03001oogoo019oo`03001oogoo05Aoo`04001oo`00002AOol0015oo`03001o
ogoo0080009oo`03001oogoo00Aoo`03001oogoo019oo`03001oogoo05Aoo`04001oo`00002AOol0
015oo`03001oogoo0080009oo`03001oogoo00Aoo`03001oogoo019oo`03001oogoo05Aoo`03001o
o`00099oo`004Goo00<007ooOol00P000Woo00<007ooOol017oo00<007ooOol04Woo00<007ooOol0
E7oo00<007oo0000TWoo000AOol200000goo00000002Ool00`00Oomoo`04Ool00`00Oomoo`0BOol0
0`00Oomoo`1DOol00`00Ool0002BOol0015oo`08001oogoo001oo`00Ool000Ioo`03001oogoo019o
o`03001oogoo0>Uoo`004Goo00P007ooOol007oo001oo`001Woo00<007ooOol04Woo00<007ooOol0
jGoo000AOol02000Oomoo`00Ool007oo0006Ool00`00Oomoo`0AOol00`00Oomoo`3ZOol0015oo`08
001oogoo001oo`00Ool000Ioo`03001oogoo015oo`03001oogoo0>Yoo`004Goo0P0000Ioo`00Ool0
07oo0006Ool00`00Oomoo`0AOol00`00Oomoo`3ZOol0015oo`03001oogoo009oo`03001oo`0000Io
o`03001oogoo015oo`03001oogoo0>Yoo`004Goo00<007ooOol00Woo00<007oo00001Woo00<007oo
Ool04Goo00<007ooOol0jWoo000AOol00`00Oomoo`02Ool00`00Ool00006Ool00`00Oomoo`0AOol0
0`00Oomoo`3ZOol0015oo`03001oogoo009oo`03001oo`0000Ioo`03001oogoo015oo`03001oogoo
0>Yoo`004Goo0P000goo00<007oo00001Woo00<007ooOol02goo00<007ooOol00goo00<007ooOol0
jWoo000AOol00`00Oomoo`02Ool00`00Ool00006Ool00`00Oomoo`0;Ool00`00Oomoo`03Ool00`00
Oomoo`3ZOol0015oo`03001oogoo009oo`03001oo`0000Ioo`03001oogoo00]oo`03001oogoo00=o
o`03001oogoo0>Yoo`0017oo1@000Woo00<007ooOol00goo00<007ooOol00Woo00<007oo00001Woo
00<007ooOol02goo00<007ooOol00goo00<007ooOol0jWoo0006Ool01`00Oomoogoo001oo`0000Ao
o`03001oogoo009oo`03001oo`0000Ioo`03001oogoo00]oo`03001oogoo00=oo`03001oogoo0>Yo
o`001Woo00<007ooOol00goo00<007ooOol00Woo0`000Woo00<007oo00001Woo00<007ooOol02goo
0P0000Eoo`00Oomoo`000>aoo`001Woo00@007ooOomoo`8000Eoo`03001oogoo009oo`03001oo`00
00Ioo`03001oogoo00]oo`800005Ool007ooOol0003/Ool000Ioo`05001oogooOol00006Ool00`00
Oomoo`02Ool30006Ool00`00Oomoo`0;Ool200001Goo001oogoo0000k7oo0005Ool20003Ool30004
Ool00`00Oomoo`02Ool30006Ool00`00Oomoo`0;Ool200001Goo001oogoo0000k7oo000AOol00`00
Oomoo`02Ool30006Ool00`00Oomoo`0;Ool200001Goo001oogoo0000k7oo000AOol20003Ool30005
Ool2000=Ool40002Ool00`00Oomoo`3ZOol0015oo`03001oogoo009oo`<000Eoo`8000eoo`@0009o
o`03001oogoo0>Yoo`004Goo00<007ooOol00Woo0`001Goo0P003Goo10000Woo00<007ooOol0jWoo
000AOol00`00Oomoo`02Ool30005Ool2000=Ool01000Ool000000Woo00<007ooOol0jWoo000AOol0
0`00Oomoo`02Ool30005Ool2000=Ool01000Ool000000Woo00<007ooOol0jWoo000AOol20003Ool3
0005Ool2000=Ool01000Ool000000Woo00<007ooOol0jWoo000AOol00`00Oomoo`02Ool30005Ool2
000=Ool01000Oomoo`000Woo00<007ooOol0jWoo000AOol00`00Oomoo`02Ool30005Ool00`00Ool0
000<Ool01`00Oomoogoo001oo`000>aoo`004Goo00<007ooOol00Woo0`001Goo00<007oo000037oo
00L007ooOomoo`00Ool0003/Ool0015oo`03001oogoo009oo`<000Eoo`03001oo`0000aoo`07001o
ogooOol007oo0000k7oo000AOol20003Ool200000goo001oo`03Ool00`00Ool0000<Ool01000Oomo
ogoo0P00kGoo000AOol00`00Oomoo`02Ool200000goo001oo`03Ool00`00Ool0000<Ool01000Oomo
ogoo0P00kGoo000AOol00`00Oomoo`03Ool00`00Ool00004Ool00`00Ool0000<Ool01000Oomoogoo
0P00kGoo000AOol00`00Oomoo`03Ool00`00Ool00004Ool00`00Ool0000<Ool01000Oomoogoo0P00
kGoo000AOol20004Ool01@00Ool007oo00000Woo00<007oo00001Woo00<007ooOol00goo00@007oo
Oomoo`800>eoo`004Goo00<007ooOol00goo00D007oo001oo`00009oo`03001oo`0000Ioo`03001o
ogoo00=oo`04001oogooOol2003]Ool0015oo`03001oogoo00=oo`05001oo`00Ool00002Ool00`00
Ool00006Ool00`00Oomoo`03Ool01000Oomoogoo0P00kGoo0005Ool30003Ool00`00Oomoo`03Ool0
0`00Oomoo`03Ool01@00Ool007oo00000Woo00<007oo00001Woo00<007ooOol00goo00@007ooOomo
o`800>eoo`001Goo00<007ooOol00Woo00<007oo000017oo00<007ooOol00goo00D007oo001oo`00
009oo`03001oo`0000Ioo`03001oogoo00=oo`04001oogooOol2003]Ool000Ioo`07001oogooOol0
07oo000017oo0`000goo00D007oo001oo`00009oo`03001oo`0000Ioo`03001oogoo009oo`03001o
ogoo009oo`800>eoo`001Woo00L007ooOomoo`00Ool00004Ool00`00Oomoo`05Ool00`00Ool00002
Ool00`00Ool00006Ool00`00Oomoo`02Ool00`00Oomoo`02Ool2003]Ool000Eoo`03001oo`00009o
o`03001oo`0000Aoo`03001oogoo00Eoo`03001oo`00009oo`03001oo`0000Ioo`8000=oo`03001o
ogoo009oo`800>eoo`001Woo00<007ooOol00Woo00<007ooOol00goo00<007ooOol01Goo00<007oo
00000Woo00<007oo00001Woo0P000goo00<007ooOol00Woo0P00kGoo000AOol00`00Oomoo`05Ool0
0`00Ool00002Ool00`00Ool00006Ool20003Ool00`00Oomoo`02Ool2003]Ool0015oo`8000Ioo`03
001oo`00009oo`03001oo`0000Ioo`8000=oo`03001oogoo00=oo`03001oogoo0>]oo`004Goo00<0
07ooOol01Goo00<007oo00000Woo00<007oo00001Woo0P000goo00<007ooOol00goo00<007ooOol0
jgoo000AOol00`00Oomoo`05Ool00`00Ool00002Ool00`00Ool00006Ool20003Ool00`00Oomoo`03
Ool00`00Oomoo`3[Ool0015oo`03001oogoo00Eoo`03001oo`00009oo`03001oo`0000Ioo`8000=o
o`03001oogoo00=oo`03001oogoo0>]oo`004Goo00<007ooOol01Goo00<007oo00000Woo00<007oo
00001Woo0P000goo00<007ooOol00goo00<007ooOol0jgoo000AOol20006Ool00`00Ool00002Ool0
0`00Ool00006Ool20003Ool00`00Oomoo`03Ool00`00Oomoo`3[Ool0015oo`03001oogoo00Eoo`03
001oo`00009oo`03001oo`0000Ioo`8000=oo`03001oogoo0?5oo`004Goo00<007ooOol01Goo00P0
07oo000007oo001oo`001Woo0P000goo00<007ooOol0lGoo000AOol00`00Oomoo`05Ool02000Ool0
0000Ool007oo0006Ool20003Ool00`00Oomoo`3aOol0015oo`03001oogoo00Eoo`08001oo`00001o
o`00Ool000Ioo`03001oo`00009oo`03001oogoo0?5oo`004Goo0P001Woo00L007oo000007oo001o
o`020005Ool01P00Ool00000Ool00?=oo`004Goo00<007ooOol01Goo00L007oo000007oo001oo`02
0005Ool01P00Ool00000Ool00?=oo`004Goo00<007ooOol01Goo00L007oo000007oo001oo`020005
Ool01P00Ool00000Ool00?=oo`004Goo00<007ooOol01Goo00L007oo000007oo001oo`020005Ool0
1P00Ool00000Ool00?=oo`004Goo00<007ooOol01Goo00L007oo000007oo001oo`020005Ool01P00
Ool00000Ool00?=oo`004Goo0P001Woo00L007oo000007oo001oo`020004Ool00`00Oomoo`020000
0goo001oo`3bOol0015oo`03001oogoo00Eoo`07001oo`00001oo`00Ool00P0017oo00L007ooOomo
o`00Ool0003cOol0015oo`03001oogoo00Eoo`07001oo`00001oo`00Ool00P0017oo00L007ooOomo
o`00Ool0003cOol000Eoo`<000=oo`03001oogoo00=oo`03001oogoo00Eoo`07001oo`00001oo`00
Ool00P0017oo00L007ooOomoo`00Ool0003cOol000Eoo`03001oogoo009oo`03001oo`0000Aoo`03
001oogoo00Eoo`07001oo`00001oo`00Ool00P0017oo00L007ooOomoo`00Ool0003cOol000Ioo`03
001oogoo00=oo`03001oogoo009oo`<000Eoo`03001oo`000080009oo`800005Ool007ooOol00003
Ool00`00Ool0003cOol000Ioo`04001oogooOol20005Ool00`00Oomoo`05Ool00`00Ool000020002
Ool200001Goo001oogoo00000goo00<007oo0000lgoo0005Ool00`00Ool00002Ool00`00Oomoo`04
Ool00`00Oomoo`05Ool00`00Ool000020002Ool200001Goo000007oo000017oo0P00lgoo0006Ool0
1000Oomoogoo0`0017oo00<007ooOol01Goo00<007oo00000P000Woo0P0000Eoo`00001oo`0000Ao
o`800?=oo`004Goo0P001Woo0P0000=oo`0000000Woo0P0000=oo`0000000P0017oo0P00lgoo000A
Ool00`00Oomoo`05Ool20005Ool200000goo001oo`020004Ool2003cOol0015oo`03001oogoo00Eo
o`8000Eoo`800003Ool007oo008000Aoo`800?=oo`004Goo00<007ooOol01Goo0P001Goo0P0000=o
o`00Ool00P0017oo0P00lgoo000AOol00`00Oomoo`05Ool20005Ool200000goo001oo`020004Ool2
003cOol0015oo`8000Ioo`8000Eoo`800003Ool007oo008000Aoo`03001oogoo0?9oo`004Goo00<0
07ooOol01Goo0P001Woo00@007oo001oo`8000Aoo`03001oogoo0?9oo`004Goo00<007ooOol01Goo
0P001Woo00@007oo001oo`8000Aoo`03001oogoo0?9oo`004Goo00<007ooOol01Goo0P001Woo00<0
07oo00000Woo00<007ooOol00Woo00<007ooOol0lWoo000AOol00`00Oomoo`05Ool20006Ool00`00
Ool00002Ool00`00Oomoo`02Ool00`00Oomoo`3bOol0015oo`8000Ioo`8000Moo`80009oo`03001o
ogoo009oo`03001oogoo0?9oo`004Goo00<007ooOol01Goo0P001goo0P000Woo00<007ooOol0mgoo
000AOol00`00Oomoo`05Ool20007Ool20002Ool00`00Oomoo`3gOol0015oo`03001oogoo00Eoo`80
00Moo`80009oo`03001oogoo0?Moo`004Goo00<007ooOol01Goo0P001goo0P000Woo00<007ooOol0
mgoo000AOol20007Ool00`00Oomoo`05Ool01@00Oomoogoo0000nGoo000AOol00`00Oomoo`06Ool0
0`00Oomoo`05Ool00`00Oomoo`3kOol0015oo`03001oogoo00Ioo`03001oogoo00Eoo`03001oogoo
0?]oo`001Goo0P0017oo00<007ooOol00goo00<007ooOol01Woo00<007ooOol01Goo00<007ooOol0
ngoo0007Ool01P00Oomoo`00Ool000Aoo`03001oogoo00Ioo`03001oogoo00Eoo`03001oogoo0?]o
o`001Woo00L007ooOomoo`00Ool00004Ool30006Ool00`00Oomoo`05Ool00`00Oomoo`3kOol000Mo
o`06001oogoo001oo`0017oo00<007ooOol01Woo00<007ooOol01Goo00<007ooOol0ngoo0005Ool0
0`00Ool00002Ool00`00Ool00004Ool00`00Oomoo`06Ool00`00Oomoo`05Ool00`00Oomoo`3kOol0
00Ioo`03001oogoo009oo`03001oogoo00=oo`03001oogoo00Ioo`03001oogoo00Eoo`03001oogoo
0?]oo`004Goo00<007ooOol01Woo00<007ooOol01Goo00<007ooOol0ngoo000AOol20007Ool00`00
Oomoo`05Ool00`00Oomoo`3kOol0015oo`03001oogoo00Ioo`03001oogoo00Eoo`03001oogoo0?]o
o`004Goo00<007ooOol01Woo00<007ooOol01Goo00<007ooOol0ngoo000AOol00`00Oomoo`06Ool0
0`00Oomoo`05Ool00`00Oomoo`3kOol0015oo`03001oogoo00Ioo`03001oogoo00Eoo`03001oogoo
0?]oo`004Goo0P001goo00<007ooOol01Goo00<007ooOol0ngoo000AOol00`00Oomoo`06Ool00`00
Oomoo`05Ool00`00Oomoo`3kOol0015oo`03001oogoo00Ioo`03001oogoo00Eoo`03001oogoo0?]o
o`004Goo00<007ooOol01Woo00<007ooOol01Goo00<007ooOol0ngoo000AOol20007Ool00`00Oomo
o`05Ool00`00Oomoo`3kOol0015oo`03001oogoo0?moo`eoo`004Goo00<007ooOol0ogoo3Goo000A
Ool00`00Oomoo`3oOol=Ool0015oo`03001oogoo0?moo`eoo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-17.269, -2.55098, 0.981822, 
  0.205586}}]
}, Open  ]],

Cell["\<\
In a typical approach, the top 10%-20% of the largest gradient values are \
selected as edge points. This is easily done based on an investigation of the \
cumulative histogram. \
\>", "Text"],

Cell[BoxData[
    \(\(cpdf = CumulativeHistogram[pdf]; \)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(ListPlot[cpdf, PlotJoined \[Rule] True, PlotRange \[Rule] All]; 
    \)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0200747 0.00373483 0.014347 0.588972 [
[.20682 .00185 -6 -9 ]
[.20682 .00185 6 0 ]
[.39356 .00185 -9 -9 ]
[.39356 .00185 9 0 ]
[.5803 .00185 -9 -9 ]
[.5803 .00185 9 0 ]
[.76704 .00185 -9 -9 ]
[.76704 .00185 9 0 ]
[.95378 .00185 -9 -9 ]
[.95378 .00185 9 0 ]
[.00757 .13214 -18 -4.5 ]
[.00757 .13214 0 4.5 ]
[.00757 .24994 -18 -4.5 ]
[.00757 .24994 0 4.5 ]
[.00757 .36773 -18 -4.5 ]
[.00757 .36773 0 4.5 ]
[.00757 .48552 -18 -4.5 ]
[.00757 .48552 0 4.5 ]
[.00757 .60332 -6 -4.5 ]
[.00757 .60332 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.20682 .01435 m
.20682 .0206 L
s
[(50)] .20682 .00185 0 1 Mshowa
.39356 .01435 m
.39356 .0206 L
s
[(100)] .39356 .00185 0 1 Mshowa
.5803 .01435 m
.5803 .0206 L
s
[(150)] .5803 .00185 0 1 Mshowa
.76704 .01435 m
.76704 .0206 L
s
[(200)] .76704 .00185 0 1 Mshowa
.95378 .01435 m
.95378 .0206 L
s
[(250)] .95378 .00185 0 1 Mshowa
.125 Mabswid
.05742 .01435 m
.05742 .0181 L
s
.09477 .01435 m
.09477 .0181 L
s
.13212 .01435 m
.13212 .0181 L
s
.16947 .01435 m
.16947 .0181 L
s
.24416 .01435 m
.24416 .0181 L
s
.28151 .01435 m
.28151 .0181 L
s
.31886 .01435 m
.31886 .0181 L
s
.35621 .01435 m
.35621 .0181 L
s
.43091 .01435 m
.43091 .0181 L
s
.46825 .01435 m
.46825 .0181 L
s
.5056 .01435 m
.5056 .0181 L
s
.54295 .01435 m
.54295 .0181 L
s
.61765 .01435 m
.61765 .0181 L
s
.655 .01435 m
.655 .0181 L
s
.69234 .01435 m
.69234 .0181 L
s
.72969 .01435 m
.72969 .0181 L
s
.80439 .01435 m
.80439 .0181 L
s
.84174 .01435 m
.84174 .0181 L
s
.87908 .01435 m
.87908 .0181 L
s
.91643 .01435 m
.91643 .0181 L
s
.99113 .01435 m
.99113 .0181 L
s
.25 Mabswid
0 .01435 m
1 .01435 L
s
.02007 .13214 m
.02632 .13214 L
s
[(0.2)] .00757 .13214 1 0 Mshowa
.02007 .24994 m
.02632 .24994 L
s
[(0.4)] .00757 .24994 1 0 Mshowa
.02007 .36773 m
.02632 .36773 L
s
[(0.6)] .00757 .36773 1 0 Mshowa
.02007 .48552 m
.02632 .48552 L
s
[(0.8)] .00757 .48552 1 0 Mshowa
.02007 .60332 m
.02632 .60332 L
s
[(1)] .00757 .60332 1 0 Mshowa
.125 Mabswid
.02007 .0438 m
.02382 .0438 L
s
.02007 .07324 m
.02382 .07324 L
s
.02007 .10269 m
.02382 .10269 L
s
.02007 .16159 m
.02382 .16159 L
s
.02007 .19104 m
.02382 .19104 L
s
.02007 .22049 m
.02382 .22049 L
s
.02007 .27938 m
.02382 .27938 L
s
.02007 .30883 m
.02382 .30883 L
s
.02007 .33828 m
.02382 .33828 L
s
.02007 .39718 m
.02382 .39718 L
s
.02007 .42663 m
.02382 .42663 L
s
.02007 .45608 m
.02382 .45608 L
s
.02007 .51497 m
.02382 .51497 L
s
.02007 .54442 m
.02382 .54442 L
s
.02007 .57387 m
.02382 .57387 L
s
.25 Mabswid
.02007 0 m
.02007 .61803 L
s
.5 Mabswid
.02381 .01472 m
.02754 .01472 L
.03128 .0195 L
.03501 .02208 L
.03875 .02834 L
.04248 .0357 L
.04622 .03975 L
.04995 .04895 L
.05369 .0611 L
.05742 .06809 L
.06116 .07766 L
.06489 .08723 L
.06863 .09607 L
.07236 .09901 L
.0761 .10895 L
.07983 .11742 L
.08357 .12956 L
.0873 .13877 L
.09104 .14834 L
.09477 .15791 L
.09851 .16858 L
.10224 .17558 L
.10598 .18441 L
.10971 .19288 L
.11345 .20319 L
.11718 .21276 L
.12092 .21791 L
.12465 .2238 L
.12838 .23006 L
.13212 .23558 L
.13585 .24294 L
.13959 .25104 L
.14332 .25619 L
.14706 .26024 L
.15079 .26319 L
.15453 .26687 L
.15826 .27055 L
.162 .27313 L
.16573 .2746 L
.16947 .27644 L
.1732 .27975 L
.17694 .28233 L
.18067 .2838 L
.18441 .28711 L
.18814 .28896 L
.19188 .28969 L
.19561 .29153 L
.19935 .293 L
.20308 .29558 L
.20682 .29595 L
Mistroke
.21055 .29742 L
.21429 .30147 L
.21802 .30368 L
.22176 .30626 L
.22549 .3081 L
.22923 .30994 L
.23296 .31178 L
.23669 .31251 L
.24043 .31509 L
.24416 .31656 L
.2479 .31804 L
.25163 .32061 L
.25537 .32208 L
.2591 .32466 L
.26284 .32724 L
.26657 .33055 L
.27031 .33276 L
.27404 .3346 L
.27778 .33681 L
.28151 .33755 L
.28525 .33975 L
.28898 .3427 L
.29272 .34454 L
.29645 .34748 L
.30019 .34969 L
.30392 .35153 L
.30766 .35301 L
.31139 .35521 L
.31513 .35742 L
.31886 .35963 L
.3226 .36074 L
.32633 .36368 L
.33007 .36479 L
.3338 .36699 L
.33754 .36883 L
.34127 .37031 L
.345 .37325 L
.34874 .37509 L
.35247 .37583 L
.35621 .37693 L
.35994 .37841 L
.36368 .37914 L
.36741 .38209 L
.37115 .38319 L
.37488 .3854 L
.37862 .38834 L
.38235 .39018 L
.38609 .39313 L
.38982 .3946 L
.39356 .39644 L
Mistroke
.39729 .39939 L
.40103 .4027 L
.40476 .40601 L
.4085 .40749 L
.41223 .40933 L
.41597 .41153 L
.4197 .41448 L
.42344 .41632 L
.42717 .4189 L
.43091 .42111 L
.43464 .42331 L
.43838 .42663 L
.44211 .4292 L
.44585 .43031 L
.44958 .43178 L
.45331 .43399 L
.45705 .43509 L
.46078 .43693 L
.46452 .43951 L
.46825 .44393 L
.47199 .44503 L
.47572 .44945 L
.47946 .4535 L
.48319 .45424 L
.48693 .45644 L
.49066 .45865 L
.4944 .46049 L
.49813 .4627 L
.50187 .46491 L
.5056 .46712 L
.50934 .46786 L
.51307 .46896 L
.51681 .47154 L
.52054 .4719 L
.52428 .47448 L
.52801 .47485 L
.53175 .47706 L
.53548 .48 L
.53922 .48148 L
.54295 .48368 L
.54669 .48626 L
.55042 .48884 L
.55415 .48957 L
.55789 .49141 L
.56162 .49252 L
.56536 .49473 L
.56909 .49546 L
.57283 .4962 L
.57656 .49804 L
.5803 .49988 L
Mistroke
.58403 .50283 L
.58777 .50393 L
.5915 .5054 L
.59524 .50687 L
.59897 .50835 L
.60271 .51056 L
.60644 .51276 L
.61018 .51424 L
.61391 .51608 L
.61765 .51755 L
.62138 .51865 L
.62512 .51939 L
.62885 .52086 L
.63259 .5227 L
.63632 .52418 L
.64006 .52749 L
.64379 .52859 L
.64753 .53007 L
.65126 .53191 L
.655 .53596 L
.65873 .53743 L
.66246 .54074 L
.6662 .54184 L
.66993 .54405 L
.67367 .54589 L
.6774 .54663 L
.68114 .54773 L
.68487 .54921 L
.68861 .55068 L
.69234 .55252 L
.69608 .55362 L
.69981 .55546 L
.70355 .55731 L
.70728 .56099 L
.71102 .56283 L
.71475 .56393 L
.71849 .56467 L
.72222 .56651 L
.72596 .56835 L
.72969 .57093 L
.73343 .57461 L
.73716 .57608 L
.7409 .57902 L
.74463 .57902 L
.74837 .58013 L
.7521 .5816 L
.75584 .58234 L
.75957 .58344 L
.76331 .58455 L
.76704 .58602 L
Mistroke
.77077 .58675 L
.77451 .58749 L
.77824 .58896 L
.78198 .59007 L
.78571 .59044 L
.78945 .59191 L
.79318 .59301 L
.79692 .59448 L
.80065 .59448 L
.80439 .59559 L
.80812 .59669 L
.81186 .59706 L
.81559 .59706 L
.81933 .59706 L
.82306 .59743 L
.8268 .59817 L
.83053 .59853 L
.83427 .59853 L
.838 .5989 L
.84174 .5989 L
.84547 .5989 L
.84921 .59927 L
.85294 .59927 L
.85668 .60001 L
.86041 .60001 L
.86415 .60001 L
.86788 .60037 L
.87162 .60111 L
.87535 .60111 L
.87908 .60111 L
.88282 .60111 L
.88655 .60111 L
.89029 .60148 L
.89402 .60148 L
.89776 .60148 L
.90149 .60148 L
.90523 .60148 L
.90896 .60148 L
.9127 .60148 L
.91643 .60221 L
.92017 .60221 L
.9239 .60258 L
.92764 .60258 L
.93137 .60295 L
.93511 .60295 L
.93884 .60295 L
.94258 .60295 L
.94631 .60295 L
.95005 .60295 L
.95378 .60295 L
Mistroke
.95752 .60295 L
.96125 .60295 L
.96499 .60295 L
.96872 .60295 L
.97246 .60295 L
.97619 .60332 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{216, 133.438},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003H0000QA000`40O003h00Of7oo000fOol00`00
Oomoo`02Ool00`00Oomoo`0IOol50002Ool00`00Oomoo`02Ool00`00Oomoo`0FOol50002Ool00`00
Oomoo`02Ool00`00Oomoo`0GOol30003Ool00`00Oomoo`02Ool00`00Oomoo`0FOol30003Ool00`00
Oomoo`02Ool00`00Oomoo`04Ool003Eoo`03001oo`00009oo`03001oo`0001aoo`07001oogooOol0
07oo00000Woo00<007oo00006Goo00L007ooOomoo`00Ool00002Ool00`00Ool0000HOol00`00Oomo
o`02Ool00`00Ool00002Ool00`00Ool0000GOol00`00Oomoo`02Ool00`00Ool00002Ool00`00Ool0
0005Ool003Moo`06001oogoo001oo`0077oo00L007ooOomoo`00Ool00002Ool00`00Ool0000IOol0
0`00Oomoo`03Ool01P00Oomoo`00Ool001Uoo`07001oogooOol007oo00000Woo00<007oo000067oo
00<007ooOol00goo00H007ooOol007oo0005Ool003Eoo`8000=oo`03001oo`0001aoo`07001oogoo
Ool007oo00000Woo00<007oo00006Goo00@007ooOomoo`8000=oo`03001oo`0001Uoo`07001oogoo
Ool007oo00000Woo00<007oo000067oo00@007ooOomoo`8000=oo`03001oo`0000Eoo`00=Goo00<0
07ooOol00Woo00<007oo000077oo00L007ooOomoo`00Ool00002Ool00`00Ool0000IOol01@00Oomo
ogoo000017oo00<007oo000067oo00<007oo00000Woo00<007oo00000Woo00<007oo00005goo00<0
07oo00000Woo00<007ooOol00Woo00<007oo00001Goo000eOol30003Ool00`00Oomoo`0JOol20004
Ool00`00Oomoo`02Ool00`00Oomoo`0GOol20003Ool30003Ool00`00Oomoo`0HOol00`00Oomoo`02
Ool00`00Oomoo`02Ool00`00Oomoo`0GOol01000Oomoogoo0`000goo00<007ooOol017oo003HOol0
0=Qoo`0057oo00<007ooOol0`Goo000DOol00`00Oomoo`31Ool001Aoo`03001oogoo0<5oo`0047oo
a`000Goo000DOol01000Oomoo`008Goo00<007ooOol08Woo00<007ooOol08Woo00<007ooOol08Woo
00<007ooOol08Woo00<007ooOol027oo000DOol01@00Oomoogoo0000_goo000DOol00`00Oomoo`02
Ool00`00Oomoo`2lOol001Aoo`03001oogoo009oo`03001oogoo0;aoo`0057oo0P0017oo00<007oo
Ool0^goo000DOol00`00Oomoo`03Ool00`00Oomoo`2kOol001Aoo`03001oogoo00=oo`03001oogoo
0;]oo`0057oo00<007ooOol017oo00<007ooOol0^Woo000DOol00`00Oomoo`04Ool00`00Oomoo`2j
Ool001Aoo`03001oogoo00Eoo`03001oogoo0;Uoo`0057oo0P001Woo00<007ooOol0^Goo000DOol0
0`00Oomoo`05Ool00`00Oomoo`2iOol001Aoo`03001oogoo00Ioo`03001oogoo0;Qoo`0057oo00<0
07ooOol01Woo00<007ooOol0^7oo000DOol00`00Oomoo`07Ool00`00Oomoo`2gOol001Aoo`03001o
ogoo00Moo`800;Qoo`0057oo0P002Goo00<007ooOol0]Woo000DOol00`00Oomoo`08Ool00`00Oomo
o`2fOol001Aoo`03001oogoo00Uoo`03001oogoo0;Eoo`0057oo00<007ooOol02Goo00<007ooOol0
]Goo0005Ool00`00Oomoo`02Ool01000Oomoogoo0`000goo00<007ooOol02Woo00<007ooOol0]7oo
0004Ool00`00Ool00007Ool00`00Oomoo`03Ool00`00Oomoo`0:Ool00`00Oomoo`2dOol000Aoo`03
001oo`0000Qoo`03001oogoo009oo`<000]oo`03001oogoo0;=oo`0017oo00<007oo000027oo00<0
07ooOol00Woo00<007ooOol02goo00<007ooOol0/goo0004Ool00`00Ool00007Ool00`00Ool00003
Ool00`00Oomoo`0;Ool00`00Oomoo`2cOol000Eoo`03001oogoo00Moo`03001oogoo009oo`03001o
ogoo00]oo`03001oogoo0;=oo`0057oo00<007ooOol037oo00<007ooOol0/Woo000DOol00`00Oomo
o`0<Ool00`00Oomoo`2bOol001Aoo`8000ioo`03001oogoo0;5oo`0057oo00<007ooOol03Goo00<0
07ooOol0/Goo000DOol00`00Oomoo`0>Ool00`00Oomoo`2`Ool001Aoo`03001oogoo00ioo`03001o
ogoo0;1oo`0057oo00<007ooOol03Woo00<007ooOol0/7oo000DOol2000@Ool00`00Oomoo`2_Ool0
01Aoo`03001oogoo00moo`03001oogoo0:moo`0057oo00<007ooOol047oo00<007ooOol0[Woo000D
Ool00`00Oomoo`0@Ool00`00Oomoo`2^Ool001Aoo`03001oogoo015oo`03001oogoo0:eoo`0057oo
00<007ooOol04Goo00<007ooOol0[Goo000DOol2000BOol00`00Oomoo`2]Ool001Aoo`03001oogoo
019oo`03001oogoo0:aoo`0057oo00<007ooOol04goo00<007ooOol0Zgoo000DOol00`00Oomoo`0D
Ool00`00Oomoo`2ZOol000Eoo`03001oogoo009oo`03001oogoo009oo`<0009oo`03001oogoo01Ao
o`03001oogoo0:Yoo`0017oo00<007oo00002Goo00D007ooOomoo`0001Ioo`03001oogoo0:Yoo`00
17oo00<007oo00001goo10000Woo0`005Goo00<007ooOol0ZGoo0004Ool00`00Ool00007Ool00`00
Ool00003Ool00`00Oomoo`0FOol00`00Oomoo`2XOol000Aoo`03001oo`0000Qoo`8000=oo`03001o
ogoo01Ioo`03001oogoo0:Qoo`001Goo00<007ooOol027oo00D007ooOomoo`0001Uoo`800:Qoo`00
57oo00<007ooOol06Goo00<007ooOol0YGoo000DOol00`00Oomoo`0IOol3002UOol001Aoo`8001eo
o`03001oogoo0:9oo`0057oo00<007ooOol077oo0`00XWoo000DOol00`00Oomoo`0OOol2002POol0
01Aoo`03001oogoo025oo`8009ioo`0057oo00<007ooOol08goo0P00W7oo000DOol00`00Oomoo`0T
Ool2002KOol001Aoo`8002Moo`<009Qoo`0057oo00<007ooOol0:Goo0P00UWoo000DOol00`00Oomo
o`0ZOol3002DOol001Aoo`03001oogoo02eoo`03001oogoo095oo`0057oo00<007ooOol0;Woo0P00
TGoo000DOol00`00Oomoo`0`Ool2002?Ool001Aoo`8003=oo`8008eoo`0057oo00<007ooOol0<goo
0P00S7oo000DOol00`00Oomoo`0eOol00`00Oomoo`29Ool000Eoo`03001oogoo009oo`04001oogoo
Ool20004Ool00`00Oomoo`0fOol30028Ool000Aoo`03001oo`0000Moo`03001oo`0000=oo`03001o
ogoo03Qoo`8008Moo`0017oo00<007oo00001goo00<007oo00000goo0`00>Woo0P00QGoo0004Ool0
0`00Ool00007Ool20004Ool00`00Oomoo`0lOol20023Ool000Aoo`03001oo`0000Moo`03001oogoo
00=oo`03001oogoo03ioo`<0081oo`001Goo00<007ooOol01goo0P000goo00<007ooOol0@Goo0`00
OGoo000DOol00`00Oomoo`14Ool00`00Oomoo`1jOol001Aoo`03001oogoo04Eoo`8007Yoo`0057oo
0P00Agoo0P00NGoo000DOol00`00Oomoo`18Ool2001gOol001Aoo`03001oogoo04Uoo`8007Ioo`00
57oo00<007ooOol0Bgoo0P00M7oo000DOol00`00Oomoo`1<Ool2001cOol001Aoo`03001oogoo04io
o`80075oo`0057oo0P00DGoo00<007ooOol0KWoo000DOol00`00Oomoo`1AOol2001^Ool001Aoo`03
001oogoo05=oo`8006aoo`0057oo00<007ooOol0EGoo0P00JWoo000DOol00`00Oomoo`1GOol00`00
Oomoo`1WOol001Aoo`03001oogoo05Moo`8006Qoo`0057oo0P00FWoo0P00IWoo000DOol00`00Oomo
o`1KOol2001TOol001Aoo`03001oogoo05eoo`<0065oo`0057oo00<007ooOol0H7oo00<007ooOol0
GWoo0005Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`1QOol3001M
Ool000Aoo`03001oo`0000Moo`03001oo`0000=oo`03001oogoo06=oo`<005]oo`0017oo00<007oo
00001goo00<007oo00000goo0`00IGoo0P00FWoo0004Ool00`00Ool00008Ool00`00Oomoo`02Ool0
0`00Oomoo`1WOol2001HOol000Aoo`03001oo`0000Moo`03001oo`0000=oo`03001oogoo06Uoo`<0
05Eoo`001Goo00<007ooOol01goo00<007ooOol00Woo00<007ooOol0K7oo0`00DWoo000DOol00`00
Oomoo`1^Ool3001@Ool001Aoo`03001oogoo075oo`8004ioo`0057oo0P00M7oo0`00Bgoo000DOol0
0`00Oomoo`1fOol20019Ool001Aoo`03001oogoo07Qoo`8004Moo`0057oo00<007ooOol0NGoo0P00
AWoo000DOol00`00Oomoo`1kOol20014Ool001Aoo`8007eoo`<0049oo`0057oo00<007ooOol0Ogoo
0`00?goo000DOol00`00Oomoo`22Ool2000mOol001Aoo`03001oogoo08Aoo`8003]oo`0057oo00<0
07ooOol0QGoo0`00>Goo000DOol00`00Oomoo`28Ool2000gOol001Aoo`8008]oo`03001oogoo03Ao
o`0057oo00<007ooOol0Rgoo0`00<goo000DOol00`00Oomoo`2>Ool3000`Ool001Aoo`03001oogoo
095oo`D002]oo`003Goo1@000Woo00<007ooOol0UGoo1000:7oo000?Ool00`00Oomoo`02Ool00`00
Oomoo`2IOol=000KOol000moo`03001oogoo009oo`<00:IooaD000Ioo`003goo00<007ooOol00Woo
00<007ooOol0`Goo000?Ool00`00Oomoo`02Ool00`00Oomoo`31Ool000ioo`8000Aoo`03001oogoo
0<5oo`00f7oo0000\
\>"],
  ImageRangeCache->{{{0, 215}, {132.438, 0}} -> {-28.2313, -0.0984999, 
  1.35403, 0.00858628}}]
}, Open  ]],

Cell["\<\
The threshold can now be estimated visually, or better still calculated from \
cpdf  by setting the threshold at the 80% level.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(t = Length[Select[cpdf, #1 < 0.8&]]\)], "Input"],

Cell[BoxData[
    \(140\)], "Output"]
}, Open  ]],

Cell["Display edge maps for a few selected threshold values.", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[
      GraphicsArray[
        Map[ListDensityPlot[\n\t\t\t\tThreshold[\[ScriptCapitalM], #], 
              FrameTicks \[Rule] None, Mesh \[Rule] False, 
              DisplayFunction \[Rule] Identity]\ &, \n
          \t\t\t{180, 140, 100}]]]; \)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .3125 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.31746 0.00744048 0.31746 [
[ 0 0 0 0 ]
[ 1 .3125 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .3125 L
0 .3125 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.00744048 0.321429 0.30506 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0240385 0.0192308 0.0240385 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
40 string
40 40 8 [40 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
000000000000000000000000000000000000000000FF0000
000000000000000000000000FF000000
0000000000000000000000000000000000000000FF000000
000000000000000000000000FF000000
00000000000000000000000000000000000000FF00000000
000000FFFFFF00FFFF000000FF000000
00000000000000000000000000000000000000FF00000000
00FF000000000000FFFF0000FF000000
000000000000000000000000000000000000FF00000000FF
FF0000000000000000FF000000000000
000000000000000000000000000000000000FF000000FF00
000000000000000000FFFF0000000000
000000000000000000000000000000000000FF000000FF00
000000000000000000FFFF0000000000
000000000000000000000000000000000000000000FF0000
000000000000000000FF000000000000
0000000000000000000000000000000000FFFF00FFFF0000
000000000000FFFFFF00000000000000
0000000000000000000000000000000000FFFF00FFFF0000
0000000000FFFF000000000000000000
0000000000000000000000000000000000FFFF00FFFF0000
000000FFFF0000000000000000000000
0000000000000000000000000000000000FFFF00FFFF0000
000000FF000000000000000000000000
0000000000000000000000000000000000FFFF00FFFF0000
0000FF000000000000000000FF000000
0000000000000000000000000000000000FFFF0000FF0000
000000000000000000FF000000FF0000
000000000000000000000000000000000000FF0000FFFF00
00FF00000000FFFF0000000000FF0000
000000000000000000000000000000000000FF0000000000
00FF000000000000000000FF00FF0000
000000000000000000000000000000000000FF0000FFFF00
00FF00FF000000000000000000FF0000
000000000000000000000000000000000000000000000000
FF0000FF000000000000FF0000000000
0000000000000000000000000000000000FF0000FFFF0000
FF0000000000000000FFFF0000000000
000000000000000000000000000000000000000000FF0000
0000000000000000FF000000FF000000
000000000000000000000000000000FF000000000000FF00
00000000FFFFFF0000000000FF000000
00000000000000000000000000000000000000000000FF00
0000000000000000000000FF00000000
0000000000000000000000000000FF00000000000000FF00
00000000000000000000000000000000
0000000000000000000000000000FF00FF0000000000FF00
00000000000000000000FF0000000000
000000000000000000000000000000FF000000000000FF00
00000000000000000000000000000000
0000000000000000000000000000000000FFFF000000FF00
000000FFFF0000000000000000000000
00000000000000000000000000FF00000000000000000000
00000000000000000000000000000000
00000000000000000000000000FF00000000000000000000
000000FFFF0000000000000000000000
000000000000000000000000000000000000000000000000
00000000000000000000000000000000
0000000000000000000000FF000000000000000000000000
00000000000000000000000000000000
0000000000000000000000FF000000000000000000000000
000000000000000000000000000000FF
000000000000000000000000000000000000FF0000000000
000000000000000000000000000000FF
000000000000000000000000000000000000000000000000
0000000000000000000000FF000000FF
000000000000000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000FF000000000000000000000000
000000000000000000000000000000000000000000000000
00000000000000000000000000000000
00000000000000000000000000000000000000000000FF00
0000000000FF00000000000000000000
0000000000000000000000000000000000000000FFFF0000
00000000000000000000000000000000
00000000000000000000000000000000FFFFFFFFFF000000
000000000000000000000000000000FF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.35119 0.00744048 0.64881 0.30506 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0240385 0.0192308 0.0240385 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
40 string
40 40 8 [40 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
000000000000000000FF0000000000000000000000FF0000
000000000000000000000000FF000000
FFFFFF000000000000FF0000FF0000FF00000000FF000000
00000000FFFFFFFF00000000FF0000FF
000000000000000000FF0000FF00FF00000000FFFF000000
0000FFFFFFFFFFFFFF000000FF000000
000000000000000000FF000000000000000000FF00000000
FFFFFF0000000000FFFF0000FF000000
00000000000000FF00FF0000000000000000FFFF000000FF
FF0000000000000000FF0000FF000000
000000000000000000FF0000000000000000FF000000FFFF
000000000000000000FFFF0000000000
000000000000000000FF0000000000000000FF0000FFFF00
000000000000000000FFFF0000000000
000000000000000000FF00000000000000FFFF0000FF0000
0000000000000000FFFFFF00FF000000
0000000000000000000000000000000000FFFF00FFFF0000
000000000000FFFFFFFF00FF00000000
0000000000000000000000000000000000FFFF00FFFF0000
00000000FFFFFF00000000FF00000000
0000000000000000000000000000000000FFFF00FFFF0000
000000FFFF000000000000FFFF000000
0000000000000000000000000000000000FFFF00FFFF0000
0000FFFF0000000000000000FF000000
0000000000000000000000000000000000FFFF00FFFF0000
0000FF000000000000000000FFFF0000
0000000000000000000000000000000000FFFF0000FF0000
00FFFF0000000000FFFFFF00FFFF0000
0000000000000000000000000000000000FFFF0000FFFF00
00FF00000000FFFFFFFFFFFF00FF0000
000000000000000000000000000000000000FF000000FF00
00FF0000FFFF0000000000FF00FF0000
000000000000000000000000000000000000FF00FFFFFF00
FFFF00FFFF000000000000FF00FF0000
000000000000000000000000000000000000FF0000000000
FFFFFFFF000000000000FF0000FF0000
0000000000000000000000000000000000FFFF00FFFF0000
FFFFFFFF0000000000FFFF00FFFF0000
00000000000000000000000000000000FFFF000000FFFF00
FFFFFFFF000000FFFFFF0000FF000000
000000000000000000000000000000FF0000000000FFFF00
FFFF00FFFFFFFFFF000000FFFF000000
0000000000000000000000000000FFFF000000000000FF00
FFFF000000000000000000FFFF000000
0000000000000000000000000000FF0000FFFFFF0000FF00
00FF000000000000000000FF00000000
00000000000000000000000000FFFF00FFFF0000FF00FF00
00FF0000000000000000FF0000000000
00000000000000000000000000FF00FFFF0000FFFF00FF00
0000FF0000000000000000FF00000000
00000000000000000000000000FF00FFFFFFFFFF0000FF00
000000FFFFFF00000000FF00FF000000
00000000000000000000000000FF00FFFFFF00000000FF00
000000000000000000000000FF000000
000000000000000000000000FFFF00000000000000000000
FFFFFFFFFFFF000000000000FF000000
0000000000000000000000FFFF00000000000000FF000000
FFFFFF000000000000000000FF0000FF
0000000000000000000000FF000000000000FFFF00000000
000000000000000000000000FF0000FF
0000000000000000000000FF000000FFFF000000FF000000
0000000000000000000000FF000000FF
0000000000000000000000FF00FF00000000FFFF00000000
000000000000000000000000000000FF
000000000000000000000000000000FFFFFF000000000000
0000000000000000000000FFFF0000FF
000000000000000000000000000000000000000000000000
00FFFF000000000000000000FF0000FF
000000000000000000000000FF0000000000000000000000
00000000FF000000000000000000FF00
0000000000000000000000FFFF0000000000000000000000
0000FFFF000000000000000000FFFF00
000000000000000000000000FF0000000000000000FFFF00
0000000000FFFFFFFFFF000000FFFF00
000000000000000000000000000000FF000000000000FF00
00FF000000FF000000FFFF0000FFFF00
000000000000000000000000000000FF00FFFFFFFFFF0000
000000000000000000000000FFFF0000
FFFFFF00000000000000000000000000FFFFFFFFFFFF0000
000000000000000000000000FF0000FF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.678571 0.00744048 0.97619 0.30506 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0240385 0.0192308 0.0240385 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
40 string
40 40 8 [40 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
0000000000FFFFFF00FF00FF00FFFFFFFFFFFF00FFFF0000
000000000000000000000000FF00FF00
FFFFFFFF000000FF00FF00FFFF00FFFFFF0000FFFF000000
000000FFFFFFFFFF00000000FF0000FF
00000000000000FF00FF0000FFFFFFFF000000FFFF000000
00FFFFFFFFFFFFFFFFFF0000FF0000FF
00000000000000FF00FF0000000000000000FFFF00000000
FFFFFF0000000000FFFF0000FF0000FF
00000000000000FF00FF0000000000000000FFFF000000FF
FF0000000000000000FFFF00FFFF0000
00000000000000FF00FF0000000000000000FFFF0000FFFF
000000000000000000FFFF00FFFFFF00
00000000000000FF00FF00000000000000FFFF0000FFFF00
000000000000000000FFFF00FFFFFF00
00000000000000FF00FF00000000000000FFFF00FFFF0000
00000000000000FFFFFFFFFFFF00FF00
00000000000000FF00FF00000000000000FFFF00FFFF0000
0000000000FFFFFFFFFF00FFFF00FF00
00000000000000FF00FF00000000000000FFFF00FFFF0000
00000000FFFFFFFF000000FFFF000000
00000000000000FF00FF00000000000000FFFF00FFFF0000
000000FFFFFF0000000000FFFF000000
00000000000000FF00FF00000000000000FFFF00FFFF0000
0000FFFF00000000000000FFFF000000
00000000000000FF00FF00000000000000FFFF00FFFF0000
00FFFFFF0000000000000000FFFF0000
00000000000000FF00FF00000000000000FFFF00FFFFFF00
00FFFF00000000FFFFFFFF00FFFF0000
00000000000000FF00FF00000000000000FFFF0000FFFFFF
FFFF000000FFFFFFFFFFFFFFFFFF0000
00000000000000FF00FF00000000000000FFFF000000FFFF
FFFF0000FFFFFF000000FFFF00FF0000
00000000000000FF00FF00000000000000FFFFFFFFFFFFFF
FFFF00FFFF0000000000FFFFFFFF0000
00000000000000FF00FF00000000000000FFFF0000FF0000
FFFFFFFF000000000000FFFFFFFF0000
00000000000000FF00FF000000000000FFFFFFFFFFFFFF00
FFFFFFFF0000000000FFFF00FFFFFF00
00000000000000FF00FF0000000000FFFFFF000000FFFF00
FFFFFFFF0000FFFFFFFF0000FFFF0000
00000000000000FF00FF00000000FFFFFF00000000FFFF00
FFFF00FFFFFFFFFFFF0000FFFF000000
00000000000000FF00FF00000000FFFF0000000000FFFF00
FFFF0000FFFF0000000000FFFF000000
00000000000000FF00FF000000FFFF00FFFFFFFFFFFFFF00
FFFF0000000000000000FFFF00000000
00000000000000FF0000000000FFFF00FFFFFFFFFF00FF00
00FFFF00000000000000FF0000000000
00000000000000FF0000000000FFFFFFFF00FFFFFF00FF00
00FFFFFF00000000FFFF00FFFFFF0000
00000000000000000000000000FF00FFFFFFFFFF00FFFF00
0000FFFFFFFFFF000000FFFFFFFF0000
00000000000000000000000000FFFFFFFFFFFF0000FFFFFF
0000000000000000FFFF0000FFFF00FF
0000000000000000000000FFFFFFFF0000000000000000FF
FFFFFFFFFFFFFF0000000000FFFF00FF
00000000000000000000FFFFFFFF0000000000FFFFFF0000
FFFFFFFF0000000000000000FFFF00FF
00000000000000000000FFFF0000000000FFFFFF00000000
000000000000000000000000FF00FFFF
00000000000000000000FFFF000000FFFFFF0000FFFF0000
00000000000000000000FFFFFF00FFFF
00000000000000000000FFFF00FFFF0000FFFFFFFF000000
00000000000000000000FF00000000FF
00000000000000000000FFFFFFFF00FFFFFF000000000000
000000FFFF0000000000FFFFFF00FFFF
00000000000000000000000000FFFFFF0000000000FF0000
FFFFFFFF00FF000000000000FF00FFFF
0000000000000000000000FFFF00000000000000FFFFFFFF
FF000000FF00000000000000FFFFFFFF
0000000000000000000000FFFF0000FF0000000000FF0000
00FFFFFFFF00FFFFFF00000000FFFF00
0000000000000000000000FFFFFFFFFF0000000000FFFF00
00FFFFFF00FFFFFFFFFF000000FFFF00
000000000000000000000000FFFF00FFFF0000000000FFFF
00FF0000FFFF000000FFFF0000FFFF00
0000000000FF000000000000000000FFFFFFFFFFFFFFFFFF
FFFF0000FFFF000000000000FFFFFFFF
FFFFFFFF00000000FFFFFF0000000000FFFFFFFFFFFF0000
000000000000FF0000000000FF0000FF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{320, 100},
  ImageMargins->{{44, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000500000I1000`40O003h00Oogoo@Goo003oOom1
Ool00?mood5oo`0027ooG`002GooG`002GooG`002Goo0008Ool00`00Oomoo`1KOol00`00Oomoo`07
Ool00`00Oomoo`1KOol00`00Oomoo`07Ool00`00Oomoo`1KOol00`00Oomoo`07Ool000Qoo`03001o
ogoo05]oo`03001oogoo00Moo`03001oogoo05]oo`03001oogoo00Moo`03001oogoo05]oo`03001o
ogoo00Moo`0027oo00<007oo0000;`000Woo80000Woo1`0000=oo`00Ool027oo00<007oo00004`00
0goo60000goo7`000Woo1`000Woo00<007ooOol01goo30001goo0P000goo0P000Woo0`003Goo0`00
17oo80000Woo0P000goo0P000Woo00<007ooOol01goo0008Ool00`00Ool0000_0002OolP0002Ool7
00000goo001oo`08Ool00`00Ool0000C0003OolH0003OolO0002Ool70002Ool00`00Oomoo`07Ool<
0007Ool20003Ool20002Ool3000=Ool30004OolP0002Ool20003Ool20002Ool00`00Oomoo`07Ool0
00Qoo`03001oo`0002d0009oob80009oo`L00003Ool007oo00Qoo`03001oogoo00Ioo`d000=oo`@0
009oo`D0009oo`T0009ooa0000Uoo`T0009oo`D000Aoo`03001oogoo00Moo`03001oogoo00Moo`L0
009oo`8000=oo`8000Eoo`8000Moo`@000Eoo`d000aoo`T0009oo`D000Aoo`03001oogoo00Moo`00
27oo00<007oo0000;@000Woo8P000Woo1`0000=oo`00Ool027oo00<007ooOol01Woo3@000goo1000
0Woo1@000Woo2@000Woo40002Goo2@000Woo1@0017oo00<007ooOol01goo00<007ooOol01goo1`00
0Woo0P000goo0P001Goo0P001goo10001Goo3@0037oo2@000Woo1@0017oo00<007ooOol01goo0008
Ool00`00Ool0000]0002OolR0002Ool700000goo001oo`08Ool00`00Oomoo`06Ool=0003Ool40002
Ool50002Ool90002Ool@0009Ool90002Ool50004Ool00`00Oomoo`07Ool00`00Oomoo`07Ool70002
Ool20003Ool20005Ool20007Ool40005Ool=000<Ool90002Ool50004Ool00`00Oomoo`07Ool000Qo
o`03001oo`0002X000=oo`l000Moo`<000Aoo`L0009oo`L00003Ool007oo00Qoo`03001oo`0001<0
00=oo`@0009oo`<0009oo`T000Aoo``000moo`L0009oo`L0009oo`03001oogoo00Mooa40009oo`80
00=oo`@000Uoo`L000Eoo`T001Aoo`D0009oo`D000Aoo`03001oogoo00Moo`0027oo00<007oo0000
:P000goo3`001goo0`0017oo1`000Woo1`0000=oo`00Ool027oo00<007oo00004`000goo10000Woo
0`000Woo2@0017oo30003goo1`000Woo1`000Woo00<007ooOol01goo4@000Woo0P000goo10002Goo
1`001Goo2@0057oo1@000Woo1@0017oo00<007ooOol01goo0008Ool00`00Ool0000Z0003Ool;0002
Ool>0004Ool50002Ool700000goo001oo`08Ool00`00Ool0000C0003OolD0002Ool90007Ool;0005
Ool40002Ool70002Ool00`00Oomoo`07OolA0002Ool20003OolB0005Ool90006Ool<0004Ool50002
Ool50004Ool00`00Oomoo`07Ool000Qoo`03001oo`0002X000=oo`/0009oo`h000Aoo`D0009oo`L0
0003Ool007oo00Qoo`03001oo`0001<000=ooa@0009oo`T000Moo`/000Eoo`@0009oo`L0009oo`03
001oogoo00Mooa40009oo`8000=ooa8000Eoo`T000Ioo``000Aoo`D0009oo`D000Aoo`03001oogoo
00Moo`0027oo00<007oo0000:0000Woo2@001Goo4P000Woo3P0000=oo`00Ool027oo00<007oo0000
3`000Woo0P000goo4P0017oo1`0017oo4P000goo10000Woo1`000Woo00<007ooOol01goo4@000Woo
0P000goo4P001Goo1P001Goo4P001Goo0P0017oo1@000Woo00<007ooOol01goo0008Ool00`00Ool0
000X0002Ool90005OolB0002Ool>00000goo001oo`08Ool00`00Ool0000?0002Ool20003OolB0004
Ool70004OolB0003Ool40002Ool70002Ool00`00Oomoo`07OolA0002Ool20003OolB0005Ool60005
OolB0005Ool20004Ool50002Ool00`00Oomoo`07Ool000Qoo`03001oo`0002P0009oo`L0009ooaL0
00Eoo`/00003Ool007oo00Qoo`03001oo`0001<000=ooa80009oo`L000Aooa@000Eoo`/0009oo`03
001oogoo00Mooa40009oo`8000=ooa8000Eoo`@000Eooa@000Eoo`8000Moo`80009oo`03001oogoo
00Moo`0027oo00<007oo0000:0000Woo1`000Woo5`001Goo2`0000=oo`00Ool027oo00<007oo0000
4`000goo4P000Woo1`0017oo50001Goo2`000Woo00<007ooOol01goo4@000Woo0P000goo4P001Goo
10001Goo50001Goo0P001goo0P000Woo00<007ooOol01goo0008Ool00`00Ool0000X0002Ool70002
OolG0005Ool;00000goo001oo`08Ool00`00Ool0000C0003OolB0002Ool70004OolD0005Ool;0002
Ool00`00Oomoo`07OolA0002Ool20003OolB0005Ool40005OolD0005Ool20007Ool20002Ool00`00
Oomoo`07Ool000Qoo`03001oo`0002P0009oo`L0009ooaL000Eoo`/00003Ool007oo00Qoo`03001o
o`0001<000=ooa80009oo`@000EooaH000Eoo`/0009oo`03001oogoo00Mooa40009oo`8000=ooa00
00Aoo`D000AooaL000Eoo`8000Moo`80009oo`03001oogoo00Moo`0027oo00<007oo0000:0000Woo
1`000Woo5`001Goo2`0000=oo`00Ool027oo00<007oo00004`000goo4P000Woo10001Goo5P001Goo
2`000Woo00<007ooOol01goo4@000Woo0P000goo400017oo1@0017oo5`001Goo0P001goo0P000Woo
00<007ooOol01goo0008Ool00`00Ool0000_0002OolI0002Ool>00000goo001oo`08Ool00`00Ool0
000C0003Ool?0005Ool40003OolF0007Ool20002Ool70002Ool00`00Oomoo`07OolA0002Ool20003
Ool@0004Ool30004OolE000=Ool20003Ool20002Ool00`00Oomoo`07Ool000Qoo`03001oo`0002l0
009ooaT0009oo`h00003Ool007oo00Qoo`03001oo`0001<000=oo`l000Eoo`@000=ooaH000Moo`80
009oo`L0009oo`03001oogoo00Mooa40009oo`8000=ooa0000Aoo`<000AooaD000eoo`8000=oo`80
009oo`03001oogoo00Moo`0027oo00<007oo00009P0017oo0`0017oo4P001goo400000=oo`00Ool0
27oo00<007oo00009@001Goo0P001Goo4P002Goo0P000Woo2@000Woo00<007ooOol01goo4@000Woo
0P000goo400017oo0`0017oo40002goo0`0017oo0P000goo0P000Woo00<007ooOol01goo0008Ool0
0`00Ool0000V0004Ool30004OolB0007Ool@00000goo001oo`08Ool00`00Ool0000U0005Ool20005
OolB0009Ool20002Ool90002Ool00`00Oomoo`07OolA0002Ool20003Ool@0004Ool30004Ool@000;
Ool30004Ool20003Ool20002Ool00`00Oomoo`07Ool000Qoo`03001oo`0002H000Aoo`<000Aooa00
00Eooa@00003Ool007oo00Qoo`03001oo`0002D000Eoo`8000Eoo`d000Moo`T0009oo`T0009oo`03
001oogoo00Mooa40009oo`8000=ooa0000Aoo`<000Aoo`h000Uoo`L000Aoo`L0009oo`03001oogoo
00Moo`0027oo00<007oo00009P0017oo0`0017oo40001Goo500000=oo`00Ool027oo00<007oo0000
9@001Goo0P001Goo3@001goo2@000Woo2@000Woo00<007ooOol01goo4@000Woo0P000goo400017oo
0`0017oo3P002Goo1`0017oo1`000Woo00<007ooOol01goo0008Ool00`00Ool0000V0004Ool30004
Ool@0005OolD00000goo001oo`08Ool00`00Ool0000U0005Ool20005Ool=0007Ool90002Ool90002
Ool00`00Oomoo`07OolA0002Ool20003Ool@0004Ool30004Ool>0009Ool70004Ool70002Ool00`00
Oomoo`07Ool000Qoo`03001oo`0002H000Aoo`<000Aoo`/000EooaT00003Ool007oo00Qoo`03001o
o`0002D000Eoo`8000Eoo`/000Aoo`h000Aoo`L0009oo`03001oogoo00Mooa40009oo`8000=ooa00
00Aoo`<000Aoo`/000Moo``000Aoo`L0009oo`03001oogoo00Moo`0027oo00<007oo00009P0017oo
0`0017oo2`001Goo6@0000=oo`00Ool027oo00<007oo00009@001Goo0P001Goo2`0017oo3P0017oo
1`000Woo00<007ooOol01goo4@000Woo0P000goo400017oo0`0017oo2`001goo300017oo1`000Woo
00<007ooOol01goo0008Ool00`00Ool0000V0004Ool30004Ool;0003OolK00000goo001oo`08Ool0
0`00Ool0000U0005Ool20005Ool90004OolB0002Ool70002Ool00`00Oomoo`07OolA0002Ool20003
Ool@0004Ool30004Ool90005Ool@0004Ool70002Ool00`00Oomoo`07Ool000Qoo`03001oo`0002H0
00Aoo`<000Aoo`/000=ooa/00003Ool007oo00Qoo`03001oo`0002D000Eoo`8000Eoo`T000Aooa80
009oo`L0009oo`03001oogoo00Mooa40009oo`8000=ooa0000Aoo`<000Aoo`T000Eooa0000Aoo`L0
009oo`03001oogoo00Moo`0027oo00<007oo00009P0017oo0`0017oo2@000Woo5@000Woo1`0000=o
o`00Ool027oo00<007oo00009@001Goo0P001Goo2@000Woo50001Goo10000Woo00<007ooOol01goo
4@000Woo0P000goo400017oo0`0017oo1`001goo4P0017oo1@000Woo00<007ooOol01goo0008Ool0
0`00Ool0000V0004Ool30004Ool90002OolE0002Ool700000goo001oo`08Ool00`00Ool0000U0005
Ool20005Ool90002OolD0005Ool40002Ool00`00Oomoo`07OolA0002Ool20003Ool@0004Ool30004
Ool70007OolB0004Ool50002Ool00`00Oomoo`07Ool000Qoo`03001oo`0002H000Aoo`D0009ooaT0
009oo`L0009oo`D00003Ool007oo00Qoo`03001oo`0002D000Eoo`@000=oo`H000Eoo`/000Moo`80
00Eoo`@0009oo`03001oogoo00Mooa40009oo`8000=ooa0000Aoo`<000Ioo`D000Aoo`X000Uoo`80
00Aoo`D0009oo`03001oogoo00Moo`0027oo00<007oo00009P0017oo1@000Woo6@000Woo1`000Woo
1@0000=oo`00Ool027oo00<007oo00009@001Goo10000goo1P001Goo2`001goo0P001Goo10000Woo
00<007ooOol01goo4@000Woo0P000goo400017oo0`001Woo1@0017oo2P002Goo0P0017oo1@000Woo
00<007ooOol01goo0008Ool00`00Ool0000V0004Ool50002OolI0002Ool70002Ool500000goo001o
o`08Ool00`00Ool0000U0005Ool40003Ool60005Ool;0007Ool20005Ool40002Ool00`00Oomoo`07
OolA0002Ool20003Ool@0004Ool30006Ool50004Ool:0009Ool20004Ool50002Ool00`00Oomoo`07
Ool000Qoo`03001oo`0002P0009oo`D000Aoo`D0009oo`T000Eoo`/0009oo`D00003Ool007oo00Qo
o`03001oo`0002D000Eoo`@000Eoo`@000=oo`T000eoo`8000=oo`@0009oo`03001oogoo00Mooa40
009oo`8000=ooa0000Aoo`D000]oo`L001Aoo`D0009oo`03001oogoo00Moo`0027oo00<007oo0000
:0000Woo1@0017oo1@000Woo2@001Goo2`000Woo1@0000=oo`00Ool027oo00<007oo00009@001Goo
10001Goo10000goo2@003Goo0P000goo10000Woo00<007ooOol01goo4@000Woo0P000goo400017oo
1@002goo1`0057oo1@000Woo00<007ooOol01goo0008Ool00`00Ool0000X0002Ool>0002OolE0002
Ool20002Ool500000goo001oo`08Ool00`00Ool0000X0002Ool70002Ool40003Ool40005Ool;0002
Ool20003Ool40002Ool00`00Oomoo`07OolA0002Ool20003Ool@0004Ool70009Ool50007Ool60005
Ool20002Ool50002Ool00`00Oomoo`07Ool000Qoo`03001oo`0002P0009oo`h0009ooaD0009oo`80
009oo`D00003Ool007oo00Qoo`03001oo`0002P0009oo`L0009oo`@000=oo`@000Eoo`/0009oo`80
00=oo`@0009oo`03001oogoo00Mooa40009oo`8000=ooa0000Aoo`L000Uoo`D000Moo`H000Eoo`80
009oo`D0009oo`03001oogoo00Moo`0027oo00<007oo0000:0000Woo1@0017oo1@000Woo0P000goo
50000Woo1@0000=oo`00Ool027oo00<007oo0000:0000Woo0P001goo0P001Goo0P0017oo3P000Woo
0P000goo10000Woo00<007ooOol01goo4@000Woo0P000goo400057oo0P001Goo2`002Goo1@000Woo
00<007ooOol01goo0008Ool00`00Ool0000X0002Ool50004Ool50002Ool20003OolD0002Ool50000
0goo001oo`08Ool00`00Ool0000X0002Ool20007Ool20005Ool20004Ool>0002Ool20003Ool40002
Ool00`00Oomoo`07OolA0002Ool20003Ool@000DOol20005Ool;0009Ool50002Ool00`00Oomoo`07
Ool000Qoo`03001oo`0003H0009oo`@000=oo`d000=oo`/00003Ool007oo00Qoo`03001oo`0002P0
009oo`/000Uoo`h0009oo`@000=oo`@0009oo`03001oogoo00Mooa40009oo`8000=ooa0000Aoo`D0
009oo`D000Uoo`d000Uoo`D0009oo`03001oogoo00Moo`0027oo00<007oo0000=P000Woo10000goo
3@000goo2`0000=oo`00Ool027oo00<007oo0000:0000Woo2`002Goo3P000Woo10000goo10000Woo
00<007ooOol01goo4@000Woo0P000goo400017oo1@000Woo1@002Goo3@002Goo1@000Woo00<007oo
Ool01goo0008Ool00`00Ool0000f0002Ool40003Ool=0003Ool;00000goo001oo`08Ool00`00Ool0
000X0002Ool;0009Ool>0002Ool40003Ool40002Ool00`00Oomoo`07OolA0002Ool20003Ool@0004
Ool50002Ool50009Ool=0009Ool50002Ool00`00Oomoo`07Ool000Qoo`03001oo`0002H0009oo`D0
00Aoo`D0009ooa8000Eoo`/00003Ool007oo00Qoo`03001oo`0002D000Eoo`8000Eoo`@000Uoo`/0
00Eoo`8000Eoo`@0009oo`03001oogoo00Mooa40009oo`8000=oo`d0011oo`<000Uoo`/000Eoo`80
00Moo`80009oo`03001oogoo00Moo`0027oo00<007oo00009P000Woo1@0017oo1@000Woo4P001Goo
2`0000=oo`00Ool027oo00<007oo00009@001Goo0P001Goo10002Goo2`001Goo0P001Goo10000Woo
00<007ooOol01goo4@000Woo0P000goo3@0047oo0`002Goo2`001Goo0P001goo0P000Woo00<007oo
Ool01goo0008Ool00`00Ool0000_0002OolG0002Ool70002Ool700000goo001oo`08Ool00`00Ool0
000S0005Ool60005Ool20009Ool70007Ool40002Ool70002Ool00`00Oomoo`07OolA0002Ool20003
Ool;0007Ool70004Ool30009Ool40009Ool50004Ool50002Ool00`00Oomoo`07Ool000Qoo`03001o
o`0002l0009ooaL0009oo`L0009oo`L00003Ool007oo00Qoo`03001oo`0002<000Eoo`H000Eoo`80
00Uoo`L000Moo`@0009oo`L0009oo`03001oogoo00Mooa40009oo`8000=oo`/000Moo`L000Aoo`<0
00Uoo`@000Uoo`D000Aoo`D0009oo`03001oogoo00Moo`0027oo00<007oo00008@000Woo3P000Woo
30001goo2`000Woo1`0000=oo`00Ool027oo00<007oo00008@000Woo2`001Goo0P001Goo0P002goo
1`0017oo1`000Woo00<007ooOol01goo4@000Woo0P000goo2@001goo2@0017oo0`0017oo0P003Woo
1@0017oo1`000Woo00<007ooOol01goo0008Ool00`00Ool0000Q0002Ool>0002Ool<0007Ool;0002
Ool700000goo001oo`08Ool00`00Ool0000Q0002Ool;0005Ool20005Ool2000;Ool70004Ool70002
Ool00`00Oomoo`07OolA0002Ool20003Ool90007Ool90004Ool30004Ool2000>Ool50004Ool70002
Ool00`00Oomoo`07Ool000Qoo`03001oo`000340009ooa`0009oo`T00003Ool007oo00Qoo`03001o
o`0001l000Aoo`h0009oo`8000Eooa@000Aoo`L0009oo`03001oogoo00Mooa40009oo`8000=oo`T0
00Aoo``000Aoo`<000Aoo`D000Aoo``000Aoo`L0009oo`03001oogoo00Moo`0027oo00<007oo0000
<@000Woo70000Woo2@0000=oo`00Ool027oo00<007oo00007`0017oo3P000Woo0P001Goo500017oo
1`000Woo00<007ooOol01goo4@000Woo0P000goo2@0017oo300017oo0`0017oo1@0017oo300017oo
1`000Woo00<007ooOol01goo0008Ool00`00Ool0000a0002OolL0002Ool900000goo001oo`08Ool0
0`00Ool0000O0004Ool>0002Ool20005OolD0004Ool70002Ool00`00Oomoo`07OolA0002Ool20003
Ool90004Ool<0004Ool30004Ool50004Ool<0004Ool70002Ool00`00Oomoo`07Ool000Qoo`03001o
o`0001l0009ooa00009oobL00003Ool007oo00Qoo`03001oo`0001l0009oo`@000Moo`D0009oo`@0
00=ooa@0009oo`T0009oo`03001oogoo00Mooa40009oo`8000=oo`L000Aoo`80011oo`<000Aooa80
00Eoo`T0009oo`03001oogoo00Moo`0027oo00<007oo00007`000Woo40000Woo9`0000=oo`00Ool0
27oo00<007oo00007`000Woo10001goo1@000Woo10000goo50000Woo2@000Woo00<007ooOol01goo
4@000Woo0P000goo1`0017oo0P0047oo0`0017oo4P001Goo2@000Woo00<007ooOol01goo0008Ool0
0`00Ool0000O0002Ool20003Ool;0002OolI0003Ool;00000goo001oo`08Ool00`00Ool0000L0005
Ool20005Ool40002Ool30002Ool40003OolB0002Ool;0002Ool00`00Oomoo`07OolA0002Ool<0004
Ool2000<Ool20002Ool50004Ool@0003Ool;0002Ool00`00Oomoo`07Ool000Qoo`03001oo`0001l0
009oo`8000=oo`/0009ooaT000=oo`/00003Ool007oo00Qoo`03001oo`0001`000Eoo`8000Eoo`@0
009oo`<0009oo`@000=ooa80009oo`/0009oo`03001oogoo00Mooa40009oo``000Aoo`8000aoo`80
009oo`D000Aooa0000=oo`/0009oo`03001oogoo00Moo`0027oo00<007oo00008@000Woo3P000Woo
9`0000=oo`00Ool027oo00<007oo000070000goo0P0017oo1@0017oo0`000Woo1`000Woo4P000Woo
2@000Woo00<007ooOol01goo4@000Woo30002Goo0P001goo0P000Woo1@001goo2@0017oo0`001Woo
1@000Woo00<007ooOol01goo0008Ool00`00Ool0000Q0002Ool>0002OolW00000goo001oo`08Ool0
0`00Ool0000L0003Ool20004Ool50004Ool30002Ool70002OolB0002Ool90002Ool00`00Oomoo`07
OolA0002Ool<0009Ool20007Ool20002Ool50007Ool90004Ool30006Ool50002Ool00`00Oomoo`07
Ool000Qoo`03001oo`0002H000Aoo`L0009oo`T000EooaT00003Ool007oo00Qoo`03001oo`0001`0
00=oo`8000]oo`D0009oo`T000Moo`T0009oo`80009oo`L0009oo`03001oogoo00Mooal0009oo`80
00aoo`8000Aoo`L000aoo`H000Uoo`D0009oo`03001oogoo00Moo`0027oo00<007oo00009P0017oo
1`000Woo2@001Goo6@0000=oo`00Ool027oo00<007oo000070000goo0P002goo1@000Woo2@001goo
2@000Woo0P000Woo1`000Woo00<007ooOol01goo7`000Woo0P0037oo0P0017oo1`0037oo1P002Goo
1@000Woo00<007ooOol01goo0008Ool00`00Ool0000V0004Ool70002Ool90005OolI00000goo001o
o`08Ool00`00Ool0000L0003Ool2000;Ool50002Ool90007Ool90002Ool20002Ool70002Ool00`00
Oomoo`07OolO0002Ool2000<Ool20004Ool7000<Ool60009Ool50002Ool00`00Oomoo`07Ool000Qo
o`03001oo`0001d0009ooc/00003Ool007oo00Qoo`03001oo`0001`000=oo`8000Moo`T0009ooad0
009oo`L0009oo`03001oogoo00Mooal000eoo`D000Mooa8000Aoo`D000Aoo`<000Aoo`03001oogoo
00Moo`0027oo00<007oo00007@000Woo>`0000=oo`00Ool027oo00<007oo000070000goo0P001goo
2@000Woo7@000Woo1`000Woo00<007ooOol01goo7`003Goo1@001goo4P0017oo1@0017oo0`0017oo
00<007ooOol01goo0008Ool00`00Ool0000M0002OolM0005OolI00000goo001oo`08Ool00`00Ool0
000J0005OolF000>Ool=0002Ool70002Ool00`00Oomoo`07OolJ0009OolB000COol;0004Ool30004
Ool00`00Oomoo`07Ool000Qoo`03001oo`0001d0009ooad000EooaT00003Ool007oo00Qoo`03001o
o`0001X000EooaH000ioo`d0009oo`L0009oo`03001oogoo00MooaX000Uooa8001=oo`/000Aoo`<0
00Aoo`03001oogoo00Moo`0027oo00<007oo0000FP0000=oo`00Ool027oo00<007oo0000600017oo
40000Woo1`001goo50000Woo1@0017oo00<007ooOol01goo60002Goo2`001goo1@002Goo4P0017oo
0`0017oo00<007ooOol01goo0008Ool00`00Ool0001J00000goo001oo`08Ool00`00Ool0000H0004
Ool@0002Ool70007OolD0002Ool50004Ool00`00Oomoo`07OolH0009Ool;0007Ool50009OolB0004
Ool30004Ool00`00Oomoo`07Ool000Qoo`03001oo`0001P0009ood000003Ool007oo00Qoo`03001o
o`0001P0009oo`h000Aoob@0009oo`D000Aoo`03001oogoo00MooaP000Aoo``000Moob@0009oo`80
00Moo`03001oogoo00Moo`0027oo00<007oo000060000Woo@00000=oo`00Ool027oo00<007oo0000
60000Woo3P0017oo90000Woo1@0017oo00<007ooOol01goo600017oo30001goo90000Woo0P001goo
00<007ooOol01goo0008Ool00`00Ool0000H0002Oom000000goo001oo`08Ool00`00Ool0000H0002
Ool>0004OolT0002Ool50004Ool00`00Oomoo`07OolH0004Ool<0007OolT0002Ool20007Ool00`00
Oomoo`07Ool000Qoo`03001oo`0001P0009ooch000=oo`03001oogoo00Moo`03001oo`0001P0009o
o`L000Aoo`L0009oob00009oo`L000Aoo`03001oogoo00MooaP000Aoo`L000Moo`D000Aooa/000Mo
o`8000Moo`03001oogoo00Moo`0027oo00<007oo000060000Woo?P000goo00<007ooOol01goo00<0
07oo000060000Woo1`0017oo1`000Woo80000Woo1`0017oo00<007ooOol01goo600017oo1`001goo
1@0017oo6`001goo0P001goo00<007ooOol01goo0008Ool00`00Ool0000X0002Ool^0003Ool00`00
Oomoo`07Ool00`00Ool0000H0002Ool20003Ool90004Ool[0004Ool00`00Oomoo`07OolH0004Ool3
0004Ool50009OolM0003Ool90004Ool00`00Oomoo`07Ool000Qoo`03001oo`0002P0009oobh000=o
o`03001oogoo00Moo`03001oo`0001P0009oo`8000=oo`T000Aoob/000Aoo`03001oogoo00MooaP0
00Aoo`<000Aoo`D000Uooad000=oo`T000Aoo`03001oogoo00Moo`0027oo00<007oo0000C`000Woo
1`000goo00<007ooOol01goo00<007oo00008@001goo9P0017oo1@0017oo00<007ooOol01goo6000
2Goo0P001goo50001Goo2`001goo0P001goo00<007ooOol01goo0008Ool00`00Ool0001?0002Ool7
0003Ool00`00Oomoo`07Ool00`00Ool0000Q0007OolV0004Ool50004Ool00`00Oomoo`07OolH0009
Ool20007OolD0005Ool;0007Ool20007Ool00`00Oomoo`07Ool000Qoo`03001oo`0005X00003Ool0
07oo00Qoo`03001oo`0003L000Eooa@0009oo`D000Aoo`03001oogoo00Mooal000Ioo``0009oo`D0
00Uoo`80009oo`h0009oo`8000Moo`03001oogoo00Moo`0027oo00<007oo0000FP0000=oo`00Ool0
27oo00<007oo0000=`001Goo50000Woo1@0017oo00<007ooOol01goo7`001Woo30000Woo1@002Goo
0P000Woo3P000Woo0P001goo00<007ooOol01goo0008Ool00`00Ool0001J00000goo001oo`08Ool0
0`00Ool0000g0005OolD0002Ool50004Ool00`00Oomoo`07OolO0006Ool<0002Ool50009Ool20002
Ool>0002Ool20007Ool00`00Oomoo`07Ool000Qoo`03001oo`0005X00003Ool007oo00Qoo`03001o
o`0001X0009oob80009ooaD0009oo`80009oo`03001oogoo00MooaX000Eooa0000]oo`L0009ooa00
00]oo`03001oogoo00Moo`0027oo00<007oo0000FP0000=oo`00Ool027oo00<007oo00006P000Woo
8P000Woo5@000Woo0P000Woo00<007ooOol01goo6P001Goo40002goo1`000Woo40002goo00<007oo
Ool01goo0008Ool00`00Ool0000l0003OolK00000goo001oo`08Ool00`00Ool0000H0004OolN0004
OolD0005Ool20002Ool00`00Oomoo`07OolJ0005Ool40002Ool<0002Ool70009Ool20007Ool90005
Ool20002Ool00`00Oomoo`07Ool000Qoo`03001oo`0003`000=ooa/00003Ool007oo00Qoo`03001o
o`0001P000Aooah000Aooa@000Eoo`80009oo`03001oogoo00MooaX000Eoo`@0009oo``0009oo`L0
00Uoo`8000Moo`T000Eoo`80009oo`03001oogoo00Moo`0027oo00<007oo0000FP0000=oo`00Ool0
27oo00<007oo00006P000Woo4P001Goo3@0037oo1P001Goo0P000Woo00<007ooOol01goo6P002goo
300017oo1@001goo0P002goo1`001Goo0P000Woo00<007ooOol01goo0008Ool00`00Ool0001J0000
0goo001oo`08Ool00`00Ool0000J0002OolB0005Ool=000<Ool60005Ool20002Ool00`00Oomoo`07
OolJ000;Ool<0004Ool50007Ool2000;Ool70005Ool20002Ool00`00Oomoo`07Ool000Qoo`03001o
o`000340009oo`h0009ooaL00003Ool007oo00Qoo`03001oo`000240009oo`h0009oo`@000=oo`H0
00=oo`H000Eoo`@000Eoo`80009oo`03001oogoo00Mooa`000Eoo`8000Eoo`/000Eoo`80009oo`D0
00Aoo`L000Eoo`@000Eoo`80009oo`03001oogoo00Moo`0027oo00<007oo0000<@000Woo3P000Woo
5`0000=oo`00Ool027oo00<007oo00008@000Woo3P000Woo10000goo1P000goo1P001Goo10001Goo
0P000Woo00<007ooOol01goo70001Goo0P001Goo2`001Goo0P000Woo1@0017oo1`001Goo10001Goo
0P000Woo00<007ooOol01goo0008Ool00`00Ool0000a0002Ool>0002OolG00000goo001oo`08Ool0
0`00Ool0000Q0002Ool>0002Ool40003Ool60003Ool60005Ool40005Ool20002Ool00`00Oomoo`07
OolL0005Ool20005Ool;0005Ool20002Ool50004Ool70005Ool40005Ool20002Ool00`00Oomoo`07
Ool000Qoo`03001oo`0002d000AoobT00003Ool007oo00Qoo`03001oo`000240009oo`8000aooal0
00Eoo`@0009oo`03001oogoo00Moo``000=ooa@001Uoo`D000Aoo`h000]oo`03001oogoo00Moo`00
27oo00<007oo0000;@0017oo:@0000=oo`00Ool027oo00<007oo00008@000Woo0P0037oo7`001Goo
10000Woo00<007ooOol01goo30000goo50006Goo1@0017oo3P002goo00<007ooOol01goo0008Ool0
0`00Ool0000S000<OolY0003Ool00`00Oomoo`07Ool00`00Oomoo`06OolM000>OolO0002Ool50004
Ool00`00Oomoo`07Ool00`00Oomoo`07Ool90007Ool;000>OolB0003Ool;0002Ool50004Ool00`00
Oomoo`07Ool000Qoo`03001oo`0002<000aoobT000=oo`03001oogoo00Moo`03001oogoo00Iooad0
00iooal0009oo`D000Aoo`03001oogoo00Moo`03001oogoo00Moo`T000Moo`/000iooa8000=oo`/0
009oo`D000Aoo`03001oogoo00Moo`0027oo00<007ooOol0Fgoo00<007ooOol01goo00<007ooOol0
Fgoo00<007ooOol01goo00<007ooOol0Fgoo00<007ooOol01goo0008OomO0009OomO0009OomO0009
Ool00?mood5oo`00ogoo@Goo0000\
\>"],
  ImageRangeCache->{{{0, 319}, {99, 0}} -> {-0.0859534, -0.0234425, 
  0.00994329, 0.00994329}, {{8.625, 102.875}, {96.625, 
  2.3125}} -> {-4.67258, -1.92043, 0.442557, 0.442557}, {{112.313, 206.625}, {
  96.625, 2.3125}} -> {-50.5271, -1.90587, 0.442263, 0.442263}, {{216.063, 
  310.313}, {96.625, 2.3125}} -> {-96.4755, -1.92043, 0.442557, 0.442557}}]
}, Open  ]],

Cell["\<\
Based on visual inspection of the edge maps it seems reasonable to accept the \
threshold value of 140. The total number of edge pixels is easily calculated \
from the histogram by summing the values in the edge histogram array above \
index 140.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Plus@@Drop[pdf, 140]\)], "Input"],

Cell[BoxData[
    \(325\)], "Output"]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"Microsoft Windows 3.0",
ScreenRectangle->{{0, 1280}, {0, 968}},
WindowToolbars->"EditBar",
CellGrouping->Manual,
WindowSize->{574, 616},
WindowMargins->{{48, Automatic}, {57, Automatic}},
PrintingCopies->1,
PrintingPageRange->{Automatic, Automatic},
PrintingOptions->{"PrintingMargins"->{{54, 54}, {72, 72}},
"PrintCellBrackets"->False,
"PrintRegistrationMarks"->False,
"PrintMultipleHorizontalPages"->False},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, -1}},
ShowCellLabel->True,
ShowCellTags->False,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False},
StyleDefinitions -> "ArticleClassic.nb"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1709, 49, 40, 0, 72, "Title"],
Cell[1752, 51, 35, 0, 41, "Author"],
Cell[1790, 53, 112, 4, 55, "Address"],
Cell[1905, 59, 52, 1, 31, "Input"],
Cell[1960, 62, 69, 1, 31, "Input"],

Cell[CellGroupData[{
Cell[2054, 67, 31, 0, 56, "Section"],
Cell[2088, 69, 493, 8, 95, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2618, 82, 42, 0, 56, "Section"],
Cell[2663, 84, 262, 5, 61, "Text"],

Cell[CellGroupData[{
Cell[2950, 93, 41, 0, 43, "Subsection"],
Cell[2994, 95, 139, 3, 44, "Text"],
Cell[3136, 100, 112, 2, 31, "Input"],
Cell[3251, 104, 76, 0, 27, "Text"],

Cell[CellGroupData[{
Cell[3352, 108, 109, 2, 36, "Input"],
Cell[3464, 112, 258, 5, 55, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3759, 122, 222, 5, 71, "Input"],
Cell[3984, 129, 23624, 1041, 111, 11136, 882, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],
Cell[27623, 1173, 76, 0, 27, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[27736, 1178, 38, 0, 43, "Subsection"],
Cell[27777, 1180, 1678, 43, 178, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[29492, 1228, 55, 0, 43, "Subsection"],
Cell[29550, 1230, 64, 0, 27, "Text"],

Cell[CellGroupData[{
Cell[29639, 1234, 61, 1, 31, "Input"],
Cell[29703, 1237, 80, 1, 30, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[29820, 1243, 84, 2, 31, "Input"],
Cell[29907, 1247, 241, 4, 77, "Output"]
}, Open  ]],
Cell[30163, 1254, 222, 4, 44, "Text"],
Cell[30388, 1260, 318, 6, 31, "NumberedEquation"],
Cell[30709, 1268, 24, 0, 27, "Text"],
Cell[30736, 1270, 208, 4, 30, "NumberedEquation"],
Cell[30947, 1276, 660, 22, 62, "Text"],

Cell[CellGroupData[{
Cell[31632, 1302, 374, 8, 120, "Input"],
Cell[32009, 1312, 514, 10, 82, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[32560, 1327, 288, 7, 71, "Input"],
Cell[32851, 1336, 75009, 2223, 120, 50891, 1919, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],
Cell[107875, 3562, 398, 7, 65, "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[108322, 3575, 51, 0, 56, "Section"],
Cell[108376, 3577, 116, 3, 27, "Text"],

Cell[CellGroupData[{
Cell[108517, 3584, 41, 0, 43, "Subsection"],
Cell[108561, 3586, 197, 4, 44, "Text"],

Cell[CellGroupData[{
Cell[108783, 3594, 147, 3, 71, "Input"],
Cell[108933, 3599, 644, 13, 153, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[109626, 3618, 51, 0, 43, "Subsection"],
Cell[109680, 3620, 91, 2, 27, "Text"],

Cell[CellGroupData[{
Cell[109796, 3626, 126, 2, 38, "Input"],
Cell[109925, 3630, 715, 14, 178, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[110677, 3649, 135, 2, 54, "Input"],
Cell[110815, 3653, 5172, 125, 153, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[116024, 3783, 127, 2, 54, "Input"],
Cell[116154, 3787, 5156, 125, 153, "Output"]
}, Open  ]],
Cell[121325, 3915, 693, 12, 146, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[122055, 3932, 40, 0, 43, "Subsection"],
Cell[122098, 3934, 47, 0, 27, "Text"],
Cell[122148, 3936, 144, 2, 51, "Input"],
Cell[122295, 3940, 147, 2, 27, "Text"],
Cell[122445, 3944, 136, 2, 31, "Input"],

Cell[CellGroupData[{
Cell[122606, 3950, 281, 5, 91, "Input"],
Cell[122890, 3957, 66793, 1123, 122, 12663, 450, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[189744, 5087, 37, 0, 56, "Section"],
Cell[189784, 5089, 505, 8, 95, "Text"],

Cell[CellGroupData[{
Cell[190314, 5101, 206, 5, 51, "Input"],
Cell[190523, 5108, 32833, 836, 186, 7675, 521, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],
Cell[223371, 5947, 202, 4, 44, "Text"],
Cell[223576, 5953, 70, 1, 31, "Input"],

Cell[CellGroupData[{
Cell[223671, 5958, 106, 2, 31, "Input"],
Cell[223780, 5962, 13635, 564, 142, 7138, 479, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],
Cell[237430, 6529, 151, 3, 44, "Text"],

Cell[CellGroupData[{
Cell[237606, 6536, 68, 1, 31, "Input"],
Cell[237677, 6539, 37, 1, 30, "Output"]
}, Open  ]],
Cell[237729, 6543, 70, 0, 27, "Text"],

Cell[CellGroupData[{
Cell[237824, 6547, 287, 6, 91, "Input"],
Cell[238114, 6555, 31739, 690, 108, 12663, 450, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],
Cell[269868, 7248, 270, 5, 61, "Text"],

Cell[CellGroupData[{
Cell[270163, 7257, 53, 1, 31, "Input"],
Cell[270219, 7260, 37, 1, 30, "Output"]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

