(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    429428,      11391]*)
(*NotebookOutlinePosition[    430403,      11424]*)
(*  CellTagsIndexPosition[    430359,      11420]*)
(*WindowFrame->Normal*)



Notebook[{
Cell["LAPLACIAN OF GAUSSIAN EDGE OPERATOR", "Title"],

Cell["Mariusz Jankowski", "Author"],

Cell["\<\
Department of Electrical Engineering
University of Southern Maine
mjkcc@usm.maine.edu\
\>", "Address"],

Cell[BoxData[
    \(<< ImageProcessing`\)], "Input"],

Cell[CellGroupData[{

Cell["INTRODUCTION", "Section"],

Cell["\<\
In this document a compound edge operator originally described by Marr and \
Hildreth (1980), the so-called Laplacian of Gaussian, will be presented. It \
has been suggested that in order to detect intensity changes (edges) \
efficiently, the operator needs to have the following two characteristics. \
First, it must be a differential operator, taking either a first or second \
spatial derivative of the image. Second, it should be capable of being tuned \
to act at any desired scale, so that large filters can be used to detect \
blurry shadow edges, and small ones to detect sharply focused fine detail in \
the image. Marr and Hildreth proposed the Laplacian of Gaussian operator.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["SECOND DERIVATIVE OPERATORS", "Section"],

Cell[TextData[{
  "The Laplacian is a second derivative operator. The Laplacian of a 2-D \
function ",
  Cell[BoxData[
      \(TraditionalForm\`f(x, y)\)]],
  " is a second-order derivative defined as "
}], "Text"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm
    \`\[Del]\^2\ \(f(x, y)\)\  = \ \ 
      \[PartialD]\_{x, 2}f\  + \ \[PartialD]\_{y, 2}\ f\)]]], 
  "NumberedEquation"],

Cell["\<\
When the first derivative achieves a maximum (center of edge transition), the \
second derivative is zero. For this reason, edges are detected by looking for \
zero-crossings of the Laplacian.\
\>", "Text"],

Cell[CellGroupData[{

Cell["Laplacian in one-dimension.", "Subsubsection"],

Cell[TextData[{
  "Model the one dimensional step using a hyperbolic tangent. Define a smooth \
edge as ",
  Cell[BoxData[
      \(TraditionalForm\`f = Tanh(\[Alpha]\ t)\)]],
  ". As the \"slope\" parameter \[Alpha] increases the slope of the edge gets \
steeper."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Plot[Evaluate[Table[Tanh[2\^i\ \ t], {i, 0, 2}]], {t, \(-2\), 2}, 
      PlotRange \[Rule] All]; \)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.309017 0.294302 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.7381 .29652 -3 -9 ]
[.7381 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 .01472 -12 -4.5 ]
[.4875 .01472 0 4.5 ]
[.4875 .16187 -24 -4.5 ]
[.4875 .16187 0 4.5 ]
[.4875 .45617 -18 -4.5 ]
[.4875 .45617 0 4.5 ]
[.4875 .60332 -6 -4.5 ]
[.4875 .60332 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.02381 .30902 m
.02381 .31527 L
s
[(-2)] .02381 .29652 0 1 Mshowa
.2619 .30902 m
.2619 .31527 L
s
[(-1)] .2619 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(1)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(2)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 .01472 m
.50625 .01472 L
s
[(-1)] .4875 .01472 1 0 Mshowa
.5 .16187 m
.50625 .16187 L
s
[(-0.5)] .4875 .16187 1 0 Mshowa
.5 .45617 m
.50625 .45617 L
s
[(0.5)] .4875 .45617 1 0 Mshowa
.5 .60332 m
.50625 .60332 L
s
[(1)] .4875 .60332 1 0 Mshowa
.125 Mabswid
.5 .04415 m
.50375 .04415 L
s
.5 .07358 m
.50375 .07358 L
s
.5 .10301 m
.50375 .10301 L
s
.5 .13244 m
.50375 .13244 L
s
.5 .1913 m
.50375 .1913 L
s
.5 .22073 m
.50375 .22073 L
s
.5 .25016 m
.50375 .25016 L
s
.5 .27959 m
.50375 .27959 L
s
.5 .33845 m
.50375 .33845 L
s
.5 .36788 m
.50375 .36788 L
s
.5 .39731 m
.50375 .39731 L
s
.5 .42674 m
.50375 .42674 L
s
.5 .4856 m
.50375 .4856 L
s
.5 .51503 m
.50375 .51503 L
s
.5 .54446 m
.50375 .54446 L
s
.5 .57389 m
.50375 .57389 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
.5 Mabswid
.02381 .0253 m
.06244 .02926 L
.10458 .03522 L
.14415 .04292 L
.18221 .05286 L
.22272 .06694 L
.26171 .08478 L
.30316 .10927 L
.34309 .13899 L
.3815 .17355 L
.42237 .21632 L
.46172 .2621 L
.49955 .30846 L
.53984 .35781 L
.57861 .4028 L
.61984 .44578 L
.65954 .48119 L
.69774 .50936 L
.73838 .5333 L
.77751 .55118 L
.81909 .56557 L
.85916 .57585 L
.89771 .58319 L
.93871 .58891 L
.97619 .59273 L
s
.02381 .01491 m
.04262 .01499 L
.06244 .01509 L
.08255 .01524 L
.09396 .01536 L
.10458 .01548 L
.125 .01579 L
.14357 .01619 L
.16272 .01674 L
.1835 .01759 L
.20334 .01872 L
.22437 .0204 L
.2439 .02258 L
.2622 .02535 L
.28245 .02956 L
.30098 .03479 L
.31996 .04198 L
.34068 .05261 L
.36036 .06615 L
.38133 .08527 L
.40274 .11083 L
.42291 .14126 L
.46146 .21694 L
.50247 .31511 L
.54195 .40864 L
.57993 .48144 L
.59944 .51011 L
.62035 .5345 L
.64159 .5534 L
.66171 .56683 L
.68162 .57673 L
.70004 .58357 L
.7187 .58876 L
.73931 .59294 L
.75865 .59578 L
.77951 .59799 L
.79955 .5995 L
.82065 .60064 L
.84039 .60139 L
.85876 .6019 L
.87922 .60231 L
.8978 .60258 L
.91699 .60279 L
.93779 .60294 L
.95644 .60304 L
.97619 .60312 L
s
.02381 .01472 m
.03279 .01472 L
.04262 .01472 L
.05288 .01472 L
.06244 .01472 L
.0731 .01472 L
.0828 .01472 L
.08817 .01472 L
.094 .01472 L
.10458 .01472 L
.11402 .01472 L
.12442 .01472 L
.12965 .01472 L
.13527 .01472 L
.14545 .01472 L
.15555 .01472 L
.16127 .01472 L
.16658 .01472 L
.1763 .01473 L
.18667 .01473 L
.19696 .01474 L
.20275 .01474 L
.20808 .01475 L
.21789 .01476 L
.22825 .01478 L
.23773 .0148 L
.24789 .01484 L
.25748 .01489 L
.26622 .01494 L
.27614 .01503 L
.28531 .01515 L
.29538 .01532 L
.30607 .01558 L
.31544 .01591 L
.32554 .01639 L
.33508 .01701 L
.34382 .01779 L
.35362 .01899 L
.36274 .0205 L
.37275 .02279 L
.38344 .02621 L
.39369 .0308 L
.40479 .03779 L
.41528 .047 L
.42494 .05847 L
.43464 .07363 L
.44371 .09187 L
.45366 .11716 L
.46435 .15117 L
.50562 .33673 L
Mistroke
.52625 .43101 L
.53629 .4691 L
.54538 .49811 L
.55429 .52153 L
.56391 .54176 L
.57407 .5582 L
.58363 .56989 L
.59316 .57867 L
.60361 .58575 L
.61451 .59103 L
.62468 .59453 L
.63516 .59711 L
.64508 .59886 L
.65398 .6 L
.66364 .60092 L
.67307 .60157 L
.68346 .60208 L
.68868 .60228 L
.69431 .60246 L
.70448 .60271 L
.71407 .60288 L
.72456 .60301 L
.72985 .60306 L
.7355 .6031 L
.74567 .60317 L
.75594 .60321 L
.76173 .60323 L
.76706 .60324 L
.77686 .60327 L
.78722 .60328 L
.79668 .60329 L
.80683 .6033 L
.81642 .6033 L
.82516 .60331 L
.83506 .60331 L
.84422 .60331 L
.85428 .60331 L
.86497 .60332 L
.87433 .60332 L
.88442 .60332 L
.89395 .60332 L
.90269 .60332 L
.91248 .60332 L
.92159 .60332 L
.93159 .60332 L
.94228 .60332 L
.95065 .60332 L
.95972 .60332 L
.96829 .60332 L
.97619 .60332 L
Mistroke
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{216, 133.438},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003H0000QA000`40O003h00Of7oo001/Ool00`00
Oomoo`1YOol006aoo`03001oogoo06Uoo`00I7oo1@000goo00<007ooOol0JGoo001VOol00`00Oomo
o`03Ool00`00Oomoo`1YOol000QoodH0019oo`<000=oo`03001oogoo00=oo`8006Yoo`00<7oo2000
5Woo100057oo00<007ooOol00goo00<007ooOol0JGoo0008Ool4000/Ool4000FOol2000BOol00`00
Oomoo`03Ool00`00Oomoo`1YOol000aoo`T002Moo`@001Aoo`<000ioo`8000Eoo`03001oogoo06Uo
o`005Goo20008goo10004goo0P004goo00<007ooOol0JGoo000MOol6000QOol3000BOol00`00Oomo
o`0@Ool00`00Oomoo`1YOol002=oo`80029oo`03001oogoo011oo`03001oogoo00moo`03001oogoo
06Uoo`009Goo0`0087oo0P004Goo00<007ooOol03Woo00<007ooOol0JGoo000XOol3000OOol00`00
Oomoo`0>Ool00`00Oomoo`0>Ool00`00Oomoo`1YOol002]oo`8001ioo`8000moo`03001oogoo00eo
o`03001oogoo06Uoo`00;Goo0`007Goo0P003Woo00<007ooOol037oo00<007ooOol0JGoo000`Ool3
000LOol00`00Oomoo`0;Ool00`00Oomoo`0<Ool00`00Oomoo`1YOol003=oo`<001Yoo`8000aoo`03
001oogoo00]oo`03001oogoo06Uoo`00=Woo0`006Goo00<007ooOol02Woo00<007ooOol02Woo00<0
07ooOol0JGoo000iOol2000HOol00`00Oomoo`09Ool00`00Oomoo`0:Ool00`00Oomoo`1YOol003]o
o`8001Moo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo06Uoo`00?Goo00<007ooOol057oo
00<007ooOol02Goo00<007ooOol02Goo00<007ooOol0JGoo000nOol2000EOol00`00Oomoo`08Ool0
0`00Oomoo`09Ool00`00Oomoo`1YOol0041oo`8001Aoo`03001oogoo00Qoo`03001oogoo00Qoo`03
001oogoo06Uoo`00@Woo00<007ooOol04Goo00<007ooOol027oo00<007ooOol027oo00<007ooOol0
JGoo0013Ool00`00Oomoo`0AOol00`00Oomoo`08Ool00`00Oomoo`07Ool00`00Oomoo`1YOol004Ao
o`80019oo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo06Uoo`00AWoo00<007ooOol03goo
00<007ooOol01goo00<007ooOol01goo00<007ooOol0JGoo0017Ool00`00Oomoo`0?Ool00`00Oomo
o`07Ool00`00Oomoo`06Ool00`00Oomoo`1YOol004Qoo`80011oo`03001oogoo00Ioo`03001oogoo
00Ioo`03001oogoo06Uoo`00BWoo00<007ooOol03Goo00<007ooOol01Woo00<007ooOol01Woo00<0
07ooOol0JGoo001;Ool00`00Oomoo`0=Ool00`00Oomoo`05Ool00`00Oomoo`06Ool00`00Oomoo`1Y
Ool004aoo`03001oogoo00eoo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo06Uoo`00CGoo
00<007ooOol037oo00<007ooOol00Woo00H007ooOol007oo0005Ool00`00Oomoo`1YOol004ioo`03
001oogoo00Yoo`03001oo`0000Ioo`800003Ool007oo00=oo`03001oogoo06Uoo`00Cgoo0P001Goo
0`000Woo00<007oo00001Woo00@007ooOol000Aoo`8006Yoo`00DGoo00<007ooOol01goo00@007oo
000000Ioo`8000Eoo`03001oogoo06Uoo`00DWoo00<007ooOol01Woo00@007oo000000Ioo`03001o
ogoo00Aoo`03001oogoo06Uoo`00Dgoo00<007ooOol01Woo00@007ooOol000Eoo`<000Aoo`03001o
ogoo06Uoo`00E7oo00<007ooOol027oo00<007ooOol00goo00<007ooOol017oo00<007ooOol0JGoo
001EOol00`00Oomoo`08Ool00`00Oomoo`03Ool00`00Oomoo`03Ool00`00Oomoo`1YOol005Ioo`03
001oogoo00Moo`03001oogoo00=oo`03001oogoo00=oo`03001oogoo06Uoo`00Egoo00<007ooOol0
1goo00<007ooOol00Woo00<007ooOol00goo00<007ooOol0JGoo001GOol00`00Oomoo`07Ool00`00
Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`1YOol005Qoo`03001oogoo00Moo`03001oogoo009o
o`03001oogoo009oo`03001oogoo06Uoo`00FGoo00<007ooOol01Woo00<007ooOol00Woo00<007oo
Ool00Woo00<007ooOol0JGoo001JOol00`00Oomoo`06Ool01@00Oomoogoo000017oo00<007ooOol0
JGoo001KOol00`00Oomoo`05Ool01@00Oomoogoo000017oo00<007ooOol0JGoo001LOol00`00Oomo
o`04Ool01@00Oomoogoo000017oo00<007ooOol0JGoo001MOol00`00Oomoo`04Ool01@00Oomoogoo
00000goo00<007ooOol0JGoo001NOol00`00Oomoo`03Ool01@00Oomoogoo00000goo00<007ooOol0
JGoo001OOol00`00Oomoo`03Ool01000Oomoo`000goo00<007ooOol0JGoo001OOol00`00Oomoo`03
Ool01000Oomoo`000goo00<007ooOol0JGoo001POol00`00Oomoo`03Ool01000Oomoo`000Woo00<0
07ooOol0JGoo001QOol00`00Oomoo`02Ool01000Oomoo`000Woo00<007ooOol0JGoo001ROol01@00
Oomoogoo00000Woo00@007ooOol006]oo`002Goo0`00;Woo1@0097oo00L007ooOomoo`00Ool00002
Ool00`00Oomoo`0/Ool5000^Ool30007Ool000Uoo`03001oogoo031oo`03001oogoo02Eoo`04001o
ogoo0002Ool00`00Ool0000`Ool00`00Oomoo`0^Ool00`00Oomoo`07Ool000Aoo`<000=oo`03001o
ogoo02Uoo`<000=oo`03001oogoo02Ioo`08001oogoo001oo`00Ool0031oo`03001oogoo02moo`03
001oogoo00Ioo`002Woo00<007ooOol0;goo00<007ooOol09Woo00P007ooOol007oo001oo`00<7oo
00<007ooOol0;goo00<007ooOol01Woo0009Ool00`00Ool0000`Ool00`00Oomoo`0WOol00`00Oomo
o`0200000goo001oo`0_Ool00`00Oomoo`0^Ool00`00Ool00007Ool000Yoo`03001oogoo02ioo`80
02Yoo`06001oo`00001oo`00;goo0P00<Goo00<007ooOol01Woo001XOol200000goo0000001[Ool0
06Uoo`@006]oo`00JGoo1000Jgoo001ZOol3001[Ool000=oom8000=oo`0027oo00<007ooOol01goo
00<007ooOol01goo00<007ooOol01goo00<007ooOol01goo00<007ooOol01goo00<007ooOol01goo
00<007ooOol01goo00<007ooOol01goo00<007ooOol01goo00<007ooOol01goo00<007ooOol01Woo
00<007ooOol01goo00<007ooOol01goo00<007ooOol01goo00<007ooOol01goo00<007ooOol01goo
00<007ooOol01goo00<007ooOol01goo00<007ooOol01goo00<007ooOol01goo00<007ooOol01Woo
0008Ool00`00Oomoo`0_Ool00`00Oomoo`0_Ool2000_Ool00`00Oomoo`0_Ool00`00Oomoo`06Ool0
06aoo`8006Yoo`00K7oo0`00JGoo001/Ool200000goo001oo`1WOol006aoo`<00003Ool007oo06Io
o`00K7oo0`000Woo00<007ooOol0I7oo001/Ool200001Goo001oogoo0000IGoo001/Ool01000Ool0
00000Woo00<007ooOol0Hgoo001/Ool01000Ool000000goo00<007ooOol0HWoo001/Ool01@00Ool0
07oo00000goo00<007ooOol0HGoo001/Ool01@00Ool007oo000017oo00<007ooOol0H7oo001/Ool0
0`00Ool00002Ool00`00Oomoo`02Ool00`00Oomoo`1OOol006aoo`06001oogoo001oo`001Goo00<0
07ooOol0GWoo001/Ool01P00Oomoo`00Ool000Ioo`03001oogoo05eoo`00K7oo00@007ooOol0009o
o`03001oogoo00=oo`03001oogoo05eoo`00K7oo00@007ooOol0009oo`03001oogoo00Aoo`03001o
ogoo05aoo`00K7oo00@007ooOol000=oo`03001oogoo00Aoo`03001oogoo05]oo`00K7oo00D007oo
Oomoo`00009oo`03001oogoo00Eoo`03001oogoo05Yoo`00K7oo00D007ooOomoo`0000=oo`03001o
ogoo00Eoo`03001oogoo05Uoo`00K7oo00D007ooOomoo`0000=oo`03001oogoo00Ioo`03001oogoo
05Qoo`00K7oo00D007ooOomoo`0000Aoo`03001oogoo00Ioo`03001oogoo05Moo`00K7oo00D007oo
Oomoo`0000Aoo`03001oogoo00Moo`03001oogoo05Ioo`00K7oo00<007ooOol00Woo00<007ooOol0
0Woo00<007ooOol01goo00<007ooOol0EGoo001/Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00
Oomoo`08Ool00`00Oomoo`1DOol006aoo`03001oogoo009oo`03001oogoo00=oo`03001oogoo00Qo
o`03001oogoo05=oo`00K7oo00<007ooOol00Woo00<007ooOol00goo00<007ooOol02Goo00<007oo
Ool0DWoo001/Ool00`00Oomoo`03Ool00`00Oomoo`03Ool00`00Oomoo`09Ool00`00Oomoo`1AOol0
05aoo`03001oogoo009oo`03001oogoo009oo`03001oogoo00=oo`03001oogoo00=oo`03001oogoo
00=oo`03001oogoo00Yoo`03001oogoo051oo`00Fgoo00<007oo00001goo00<007oo000017oo00<0
07ooOol00goo00<007ooOol017oo00<007ooOol02Woo00<007ooOol0Cgoo001KOol00`00Ool00009
Ool00`00Oomoo`02Ool20004Ool00`00Oomoo`04Ool00`00Oomoo`0;Ool00`00Oomoo`1>Ool005]o
o`03001oo`0000Moo`8000Eoo`03001oogoo00Aoo`03001oogoo00Aoo`03001oogoo00]oo`03001o
ogoo04eoo`00Fgoo00<007oo00001goo00<007ooOol017oo00<007ooOol017oo00<007ooOol017oo
00<007ooOol037oo0P00CGoo001LOol00`00Oomoo`06Ool30004Ool00`00Oomoo`04Ool00`00Oomo
o`05Ool00`00Oomoo`0=Ool00`00Oomoo`1:Ool006aoo`03001oogoo00Aoo`03001oogoo00Eoo`03
001oogoo00ioo`03001oogoo04Uoo`00K7oo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol0
3Woo00<007ooOol0B7oo001/Ool00`00Oomoo`05Ool00`00Oomoo`06Ool00`00Oomoo`0>Ool00`00
Oomoo`17Ool006aoo`03001oogoo00Eoo`03001oogoo00Ioo`03001oogoo00moo`8004Moo`00K7oo
00<007ooOol01Woo00<007ooOol01Woo00<007ooOol047oo00<007ooOol0A7oo001/Ool00`00Oomo
o`06Ool00`00Oomoo`07Ool00`00Oomoo`0@Ool00`00Oomoo`13Ool006aoo`03001oogoo00Ioo`03
001oogoo00Moo`03001oogoo015oo`8004=oo`00K7oo00<007ooOol01goo00<007ooOol01goo00<0
07ooOol04Woo00<007ooOol0@7oo001/Ool00`00Oomoo`07Ool00`00Oomoo`08Ool00`00Oomoo`0B
Ool20010Ool006aoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo01=oo`03001oogoo03eo
o`00K7oo00<007ooOol027oo00<007ooOol02Goo00<007ooOol04goo0P00?Goo001/Ool00`00Oomo
o`09Ool00`00Oomoo`08Ool00`00Oomoo`0EOol2000kOol006aoo`03001oogoo00Uoo`03001oogoo
00Uoo`03001oogoo01Ioo`8003Uoo`00K7oo00<007ooOol02Woo00<007ooOol02Goo00<007ooOol0
5goo0P00=goo001/Ool00`00Oomoo`0:Ool00`00Oomoo`0:Ool00`00Oomoo`0HOol2000eOol006ao
o`03001oogoo00]oo`03001oogoo00Yoo`03001oogoo01Uoo`8003=oo`00K7oo00<007ooOol02goo
00<007ooOol02goo00<007ooOol06Woo0`00<7oo001/Ool00`00Oomoo`0<Ool00`00Oomoo`0;Ool0
0`00Oomoo`0LOol2000^Ool006aoo`03001oogoo00aoo`03001oogoo00aoo`8001ioo`<002]oo`00
K7oo00<007ooOol03Goo00<007ooOol03Goo0`007Woo10009goo001/Ool00`00Oomoo`0>Ool00`00
Oomoo`0?Ool2000POol4000SOol006aoo`03001oogoo00moo`03001oogoo011oo`80029oo`@001mo
o`00K7oo00<007ooOol047oo00<007ooOol04Goo0P0097oo10006goo001/Ool00`00Oomoo`0AOol3
000BOol2000VOol7000DOol006aoo`03001oogoo01Aoo`80019oo`D002Qoo`P000aoo`00I7oo1@00
0goo00<007ooOol05Woo0P005Goo2000:7oo100027oo001VOol00`00Oomoo`03Ool00`00Oomoo`0H
Ool8000EOol=000WOol006Ioo`03001oogoo00=oo`80025ood4000Qoo`00IWoo00<007ooOol00goo
00<007ooOol0JGoo001VOol00`00Oomoo`03Ool00`00Oomoo`1YOol006Eoo`8000Eoo`03001oogoo
06Uoo`00f7oo0000\
\>"],
  ImageRangeCache->{{{0, 215}, {132.438, 0}} -> {-2.16304, -1.0729, 
  0.0200275, 0.0162026}}]
}, Open  ]],

Cell["\<\
Plot the first and second derivatives of our \"step\" function.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[Del]2 = {\[PartialD]\_t Tanh[3\ t], \[PartialD]\_{t, 2}Tanh[3\ t]}; \n
    Plot[Evaluate[\[Del]2], {t, \(-2\), 2}]; \)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.309018 0.0424799 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.7381 .29652 -3 -9 ]
[.7381 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 .05414 -12 -4.5 ]
[.4875 .05414 0 4.5 ]
[.4875 .1391 -12 -4.5 ]
[.4875 .1391 0 4.5 ]
[.4875 .22406 -12 -4.5 ]
[.4875 .22406 0 4.5 ]
[.4875 .39398 -6 -4.5 ]
[.4875 .39398 0 4.5 ]
[.4875 .47894 -6 -4.5 ]
[.4875 .47894 0 4.5 ]
[.4875 .5639 -6 -4.5 ]
[.4875 .5639 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.02381 .30902 m
.02381 .31527 L
s
[(-2)] .02381 .29652 0 1 Mshowa
.2619 .30902 m
.2619 .31527 L
s
[(-1)] .2619 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(1)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(2)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 .05414 m
.50625 .05414 L
s
[(-6)] .4875 .05414 1 0 Mshowa
.5 .1391 m
.50625 .1391 L
s
[(-4)] .4875 .1391 1 0 Mshowa
.5 .22406 m
.50625 .22406 L
s
[(-2)] .4875 .22406 1 0 Mshowa
.5 .39398 m
.50625 .39398 L
s
[(2)] .4875 .39398 1 0 Mshowa
.5 .47894 m
.50625 .47894 L
s
[(4)] .4875 .47894 1 0 Mshowa
.5 .5639 m
.50625 .5639 L
s
[(6)] .4875 .5639 1 0 Mshowa
.125 Mabswid
.5 .07538 m
.50375 .07538 L
s
.5 .09662 m
.50375 .09662 L
s
.5 .11786 m
.50375 .11786 L
s
.5 .16034 m
.50375 .16034 L
s
.5 .18158 m
.50375 .18158 L
s
.5 .20282 m
.50375 .20282 L
s
.5 .2453 m
.50375 .2453 L
s
.5 .26654 m
.50375 .26654 L
s
.5 .28778 m
.50375 .28778 L
s
.5 .33026 m
.50375 .33026 L
s
.5 .3515 m
.50375 .3515 L
s
.5 .37274 m
.50375 .37274 L
s
.5 .41522 m
.50375 .41522 L
s
.5 .43646 m
.50375 .43646 L
s
.5 .4577 m
.50375 .4577 L
s
.5 .50018 m
.50375 .50018 L
s
.5 .52142 m
.50375 .52142 L
s
.5 .54266 m
.50375 .54266 L
s
.5 .0329 m
.50375 .0329 L
s
.5 .01166 m
.50375 .01166 L
s
.5 .58514 m
.50375 .58514 L
s
.5 .60638 m
.50375 .60638 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.03279 .30902 L
.04262 .30902 L
.05288 .30902 L
.06244 .30903 L
.0731 .30903 L
.0828 .30903 L
.094 .30904 L
.10458 .30904 L
.11428 .30905 L
.12455 .30906 L
.13333 .30907 L
.14299 .30908 L
.15313 .3091 L
.1624 .30912 L
.17311 .30915 L
.18328 .30919 L
.19287 .30924 L
.20309 .30931 L
.21273 .30938 L
.22147 .30947 L
.2315 .3096 L
.24072 .30976 L
.25085 .30997 L
.26154 .31026 L
.27102 .3106 L
.28118 .31106 L
.29077 .31161 L
.29951 .31224 L
.30877 .31307 L
.3186 .31418 L
.32938 .31575 L
.33936 .31761 L
.34873 .3198 L
.35883 .32276 L
.37711 .33011 L
.38668 .33524 L
.39715 .34206 L
.41825 .36012 L
.4395 .38386 L
.45881 .40747 L
.46845 .41826 L
.47352 .42326 L
.47889 .42785 L
.48359 .43116 L
.48608 .43262 L
.48876 .43394 L
.49121 .43491 L
.49346 .4356 L
.49454 .43586 L
Mistroke
.49571 .43609 L
.49682 .43625 L
.49785 .43637 L
.49915 .43644 L
.4998 .43646 L
.50051 .43645 L
.50177 .43639 L
.50295 .43628 L
.50366 .43619 L
.50434 .43608 L
.5056 .43582 L
.50845 .43502 L
.51093 .43407 L
.51323 .43298 L
.51842 .42983 L
.52745 .42235 L
.53704 .41229 L
.57484 .36731 L
.59422 .34872 L
.6042 .3411 L
.61509 .33421 L
.63517 .32485 L
.64612 .32123 L
.65629 .31857 L
.66684 .31641 L
.67678 .31481 L
.68565 .31367 L
.69538 .31267 L
.70513 .31189 L
.71544 .31124 L
.72492 .31077 L
.7339 .31042 L
.74409 .3101 L
.75339 .30988 L
.7634 .30968 L
.77429 .30952 L
.78368 .30942 L
.79405 .30933 L
.80487 .30925 L
.81504 .3092 L
.82486 .30916 L
.8352 .30913 L
.84403 .30911 L
.8537 .30909 L
.86396 .30907 L
.87329 .30906 L
.88405 .30905 L
.89423 .30904 L
.90393 .30904 L
.91422 .30903 L
Mistroke
.923 .30903 L
.93266 .30903 L
.94281 .30903 L
.95209 .30902 L
.9628 .30902 L
.97297 .30902 L
.97619 .30902 L
Mfstroke
.02381 .30904 m
.03279 .30904 L
.04262 .30905 L
.05288 .30906 L
.06244 .30907 L
.0731 .30908 L
.0828 .3091 L
.094 .30913 L
.10458 .30916 L
.11428 .3092 L
.12455 .30926 L
.13333 .30932 L
.14299 .3094 L
.15313 .30951 L
.1624 .30964 L
.17311 .30983 L
.18328 .31006 L
.19287 .31035 L
.20309 .31074 L
.21273 .31121 L
.22147 .31175 L
.2315 .31253 L
.24072 .31344 L
.25085 .31471 L
.26154 .31646 L
.27102 .31844 L
.28118 .32114 L
.29077 .32439 L
.29951 .32808 L
.3186 .33938 L
.32938 .34835 L
.33936 .35882 L
.35802 .38549 L
.36865 .40564 L
.37862 .42828 L
.41731 .54344 L
.42769 .57346 L
.43275 .58554 L
.43735 .5943 L
.43986 .59798 L
.44222 .60064 L
.44352 .60174 L
.44472 .6025 L
.44604 .60306 L
.4467 .60323 L
.44743 .60332 L
.44816 .60331 L
.44886 .60321 L
.45017 .60276 L
.45091 .60236 L
Mistroke
.45159 .6019 L
.45312 .60048 L
.45448 .59882 L
.4557 .59697 L
.45845 .59158 L
.46078 .58561 L
.46334 .57757 L
.4685 .55644 L
.47328 .53101 L
.47774 .50244 L
.49857 .32279 L
.51724 .15293 L
.52236 .11493 L
.52779 .08086 L
.53248 .05707 L
.53753 .03754 L
.54026 .0296 L
.54276 .02388 L
.54514 .01975 L
.54634 .01816 L
.54765 .01678 L
.54841 .01615 L
.54912 .01566 L
.54976 .01531 L
.55045 .01502 L
.55121 .01481 L
.55201 .01472 L
.55269 .01473 L
.55344 .01484 L
.55414 .01503 L
.55478 .01529 L
.55552 .01567 L
.55622 .01611 L
.55881 .01846 L
.56124 .02156 L
.56382 .02573 L
.56845 .03517 L
.57894 .06319 L
.61666 .17779 L
.63599 .22167 L
.64686 .24053 L
.65683 .25458 L
.67573 .27422 L
.68645 .28215 L
.69643 .28796 L
.70693 .29275 L
.71686 .29629 L
.7257 .2988 L
.73544 .301 L
.74514 .30272 L
Mistroke
.75543 .30415 L
.76495 .30518 L
.77387 .30595 L
.78426 .30666 L
.79413 .30718 L
.80386 .30758 L
.81266 .30786 L
.82226 .30811 L
.83248 .30832 L
.84196 .30847 L
.85088 .30858 L
.86065 .30867 L
.87097 .30875 L
.87978 .30881 L
.88945 .30885 L
.89966 .30889 L
.90897 .30892 L
.91972 .30894 L
.92989 .30896 L
.93956 .30897 L
.94982 .30898 L
.95858 .30899 L
.96824 .309 L
.97619 .309 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{216, 133.438},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003H0000QA000`40O003h00OJgoo00<007ooOol0
JWoo001[Ool00`00Oomoo`1ZOol006]oo`03001oogoo06Yoo`00Jgoo0P002Goo0P00H7oo001[Ool0
0`00Oomoo`07Ool4001OOol006]oo`03001oogoo00Moo`05001oogooOol0001NOol006]oo`03001o
ogoo00Ioo`03001oogoo009oo`03001oogoo05aoo`00Jgoo0P001Woo00<007ooOol017oo00<007oo
Ool0Fgoo001[Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`1KOol006]oo`03001oogoo
00Eoo`03001oogoo00Aoo`03001oogoo05]oo`00IGoo0P0017oo00<007ooOol017oo00<007ooOol0
1Woo00<007ooOol0FWoo001UOol00`00Ool00003Ool00`00Oomoo`04Ool00`00Oomoo`06Ool00`00
Oomoo`1JOol0061oo`<0009oo`03001oo`0000=oo`<000Aoo`03001oogoo00Ioo`03001oogoo05Yo
o`00IGoo0P0017oo00<007ooOol017oo00<007ooOol01goo00<007ooOol0FGoo001UOol00`00Oomo
o`03Ool00`00Oomoo`04Ool00`00Oomoo`07Ool00`00Oomoo`1IOol006Ioo`8000=oo`03001oogoo
00=oo`03001oogoo00Qoo`03001oogoo05Uoo`00Jgoo0P0017oo00<007ooOol02Goo00<007ooOol0
F7oo001[Ool00`00Oomoo`03Ool00`00Oomoo`09Ool00`00Oomoo`1HOol006]oo`03001oogoo00=o
o`03001oogoo00Uoo`03001oogoo05Qoo`00Jgoo00<007ooOol00goo00<007ooOol02Woo00<007oo
Ool0Egoo001[Ool00`00Oomoo`03Ool00`00Oomoo`0:Ool00`00Oomoo`1GOol006]oo`8000=oo`03
001oogoo00]oo`03001oogoo05Moo`00Jgoo00<007ooOol00Woo00<007ooOol037oo00<007ooOol0
EWoo001[Ool00`00Oomoo`02Ool00`00Oomoo`0<Ool00`00Oomoo`1FOol006]oo`03001oogoo009o
o`03001oogoo00aoo`03001oogoo05Ioo`00Jgoo0P000goo00<007ooOol03Goo00<007ooOol0EGoo
001[Ool00`00Oomoo`02Ool00`00Oomoo`0=Ool00`00Oomoo`1EOol006]oo`03001oogoo009oo`03
001oogoo00eoo`03001oogoo05Eoo`00IWoo0`000Woo00<007ooOol00Woo00<007ooOol03Woo00<0
07ooOol0E7oo001WOol01@00Oomoogoo00000goo00<007ooOol03goo00<007ooOol0E7oo001POol3
0002Ool40002Ool300000goo001oo`0@Ool00`00Oomoo`1DOol006Eoo`03001oo`0000=oo`05001o
ogooOol0000BOol00`00Oomoo`1COol006Ioo`8000=oo`05001oogooOol0000BOol00`00Oomoo`1C
Ool006Moo`05001oogooOol00003Ool00`00Oomoo`0@Ool00`00Oomoo`1COol006]oo`80009oo`03
001oogoo015oo`03001oogoo059oo`00Jgoo00D007ooOomoo`0001=oo`03001oogoo059oo`00Jgoo
00D007ooOomoo`0001=oo`03001oogoo059oo`00Jgoo00D007ooOomoo`0001Aoo`03001oogoo055o
o`00Jgoo00@007ooOol001Eoo`03001oogoo055oo`00Jgoo0P0000=oo`00Ool05Goo00<007ooOol0
D7oo001[Ool01000Oomoo`005Woo00<007ooOol0D7oo001[Ool01000Oomoo`005goo00<007ooOol0
Cgoo001[Ool01000Oomoo`005goo00<007ooOol0Cgoo001[Ool01000Oomoo`0067oo00<007ooOol0
CWoo001[Ool200000goo001oo`0GOol00`00Oomoo`1>Ool006]oo`04001oogoo000IOol00`00Oomo
o`1=Ool006Eoo`<000=oo`04001oogoo000IOol00`00Oomoo`1=Ool006Eoo`03001oogoo00=oo`03
001oo`0001]oo`03001oogoo04aoo`00H7oo0`000goo00<007ooOol00Woo0`006goo00<007ooOol0
C7oo001VOol00`00Oomoo`02Ool00`00Ool0000LOol00`00Oomoo`1;Ool006Eoo`03001oo`0000=o
o`03001oo`0001aoo`03001oogoo04]oo`00IWoo00<007ooOol00Woo00<007oo00007Goo00<007oo
Ool0BWoo001[Ool00`00Ool0000MOol00`00Oomoo`1:Ool006]oo`<001ioo`03001oogoo04Uoo`00
Jgoo00<007oo00007Woo00<007ooOol0BGoo001[Ool00`00Ool0000OOol00`00Oomoo`18Ool000Mo
o`<002ioo`D002ioo`80025oo`03001oogoo00]oo`D002moo`<000Eoo`001goo00<007ooOol0<7oo
00<007ooOol0;Woo0P008Woo00<007ooOol037oo00<007ooOol0;goo00<007ooOol01Goo0002Ool3
0003Ool00`00Oomoo`0YOol30003Ool00`00Oomoo`0^Ool2000SOol00`00Oomoo`0;Ool00`00Oomo
o`0`Ool00`00Oomoo`04Ool000Qoo`03001oogoo02moo`03001oogoo02ioo`8002Aoo`03001oogoo
00Yoo`03001oogoo031oo`03001oogoo00Aoo`001goo00<007oo0000<7oo00<007ooOol0;Woo0P00
9Goo00<007ooOol02Goo00<007ooOol0;goo00<007oo00001Goo0008Ool00`00Oomoo`0^Ool2000`
Ool2000VOol20008Ool2000bOol00`00Oomoo`04Ool006]oo`8002Qoo`80045oo`00Jgoo0P00:Woo
0P00?goo001[Ool2000/Ool4000kOol006]oo`03001oogoo02moo`P003=oo`00f0000006Ool00`00
Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`0O0007Ool00`00Oomoo`07Ool0
0`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`08Ool00`00Oomoo`07Ool00`00Oomoo`07Ool0
0`00Oomoo`06Ool?0007Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomo
o`07Ool00`00Oomoo`04Ool000Ioo`03001oogoo02ioo`D000Yoo`@0025oo`03001oogoo01moo`H0
00]oo`03001oogoo031oo`03001oogoo00Aoo`00?7oo0P0037oo10007Goo00<007ooOol077oo0`00
Bgoo000nOol4000<Ool2000KOol00`00Oomoo`0JOol2001>Ool0049oo`03001oogoo00]oo`8001Uo
o`8001Uoo`80051oo`00@goo0P003Goo0P005goo00<007ooOol05Woo0P00DWoo0015Ool00`00Oomo
o`0<Ool2000EOol00`00Oomoo`0DOol2001DOol004Ioo`03001oogoo00eoo`03001oogoo015oo`80
01Eoo`03001oogoo05Aoo`00Agoo00<007ooOol03Goo0P004Goo0`004goo00<007ooOol0EGoo0018
Ool00`00Oomoo`0>Ool00`00Oomoo`0>Ool2000COol00`00Oomoo`1FOol004Uoo`03001oogoo00io
o`03001oogoo00eoo`80015oo`8005Uoo`00BWoo00<007ooOol03Woo00<007ooOol037oo0P0047oo
00<007ooOol0FGoo001:Ool00`00Oomoo`0?Ool00`00Oomoo`0;Ool2000?Ool00`00Oomoo`1JOol0
04]oo`03001oogoo00moo`03001oogoo00Yoo`<000eoo`03001oogoo05]oo`00C7oo00<007ooOol0
3goo00<007ooOol02Goo0P003Goo00<007ooOol0G7oo001<Ool00`00Oomoo`0@Ool00`00Oomoo`03
Ool30002Ool2000<Ool00`00Oomoo`1MOol004eoo`03001oogoo011oo`03001oogoo009oo`03001o
ogoo009oo`8000]oo`03001oogoo05ioo`00CWoo00<007ooOol047oo00<007ooOol00Woo00D007oo
Ool007oo00<000Uoo`03001oogoo05ioo`00CWoo00<007ooOol047oo00<007ooOol00Woo00H007oo
Ool007oo000:Ool00`00Oomoo`1OOol004moo`03001oogoo011oo`0:001oogoo001oo`00Ool007oo
0009Ool00`00Oomoo`1POol004moo`03001oogoo015oo`04001oogoo0002Ool00`00Ool00008Ool0
0`00Oomoo`1QOol004moo`03001oogoo019oo`03001oogoo009oo`03001oo`0000Moo`03001oogoo
069oo`00D7oo00<007ooOol04Goo00<007ooOol00Woo00@007oo000000Eoo`03001oogoo06=oo`00
D7oo00<007ooOol04Woo00L007ooOomoo`00Ool00006Ool00`00Oomoo`1SOol0055oo`03001oogoo
019oo`06001oogoo001oo`001Goo00<007ooOol0I7oo001AOol00`00Oomoo`0COol300000goo001o
o`02Ool2001WOol0055oo`03001oogoo01Aoo`L006Uoo`00DWoo00<007ooOol04goo00<007ooOol0
0P00Jgoo001BOol00`00Oomoo`0COol01000Oomoo`00K7oo001COol00`00Oomoo`0BOol01000Oomo
o`00K7oo001COol00`00Oomoo`0BOol01000Oomoo`00K7oo001COol00`00Oomoo`0BOol00`00Oomo
o`02001[Ool005Aoo`03001oogoo015oo`04001oogoo001/Ool005Aoo`03001oogoo015oo`04001o
ogoo001/Ool005Aoo`03001oogoo00moo`<0009oo`03001oogoo06Yoo`00EGoo00<007ooOol03goo
0P000Woo00<007ooOol0JWoo001EOol00`00Oomoo`0=Ool40002Ool3001ZOol005Ioo`03001oogoo
00aoo`03001oo`0000=oo`03001oogoo06Yoo`00EWoo00<007ooOol03Goo0P000goo00<007ooOol0
JWoo001FOol00`00Oomoo`0>Ool01@00Oomoogoo0000K7oo001GOol00`00Oomoo`0=Ool01000Oomo
ogoo0P00Jgoo001GOol00`00Oomoo`0=Ool01@00Oomoogoo0000K7oo001GOol00`00Oomoo`0=Ool0
1@00Oomoogoo0000K7oo001HOol00`00Oomoo`0<Ool01@00Oomoogoo0000K7oo001HOol00`00Oomo
o`0;Ool00`00Oomoo`02Ool00`00Oomoo`1ZOol005Uoo`03001oogoo00Yoo`03001oogoo009oo`80
06]oo`00FGoo00<007ooOol02Woo00<007ooOol00Woo00<007ooOol0JWoo001IOol00`00Oomoo`0:
Ool00`00Oomoo`02Ool00`00Oomoo`1ZOol005Yoo`03001oogoo00Uoo`03001oogoo009oo`03001o
ogoo06Yoo`00FWoo00<007ooOol02Goo00<007ooOol00Woo0P00Jgoo001JOol00`00Oomoo`08Ool0
0`00Oomoo`03Ool00`00Oomoo`1ZOol005]oo`03001oogoo00Moo`03001oogoo00=oo`03001oogoo
06Yoo`00Fgoo00<007ooOol01goo0P0017oo00<007ooOol0JWoo001KOol00`00Oomoo`07Ool00`00
Ool00003Ool00`00Oomoo`1ZOol005]oo`03001oogoo00Moo`03001oo`0000=oo`<006Yoo`00G7oo
00<007ooOol01Goo0`0017oo00<007ooOol0JWoo001LOol00`00Oomoo`05Ool20005Ool00`00Oomo
o`1ZOol005eoo`03001oogoo00Aoo`04001oo`000003Ool00`00Oomoo`1ZOol005eoo`03001oogoo
00=oo`03001oogoo00Eoo`8006]oo`00GWoo00<007ooOol00Woo00<007ooOol01Goo00<007ooOol0
JWoo001NOol00`00Oomoo`02Ool00`00Oomoo`05Ool00`00Oomoo`1ZOol005moo`04001oogoo0008
Ool00`00Oomoo`1ZOol005moo`<000Uoo`03001oogoo06Yoo`00Jgoo0P00Jgoo001[Ool00`00Oomo
o`1ZOol006]oo`03001oogoo06Yoo`00\
\>"],
  ImageRangeCache->{{{0, 215}, {132.438, 0}} -> {-2.11773, -7.28105, 
  0.0196174, 0.109953}}]
}, Open  ]],

Cell["\<\
As expected, the result shows that the zero-crossings of the second \
derivative localize the center of an edge. As a second example, consider the \
case of a narrow bright line on a dark background.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Plot[Tanh[3\ t] - Tanh[2\ \((t - 2)\)], {t, \(-2\), 5}, 
      PlotRange \[Rule] All]; \)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.295918 0.136054 0.0147115 0.299089 [
[.02381 .00221 -6 -9 ]
[.02381 .00221 6 0 ]
[.15986 .00221 -6 -9 ]
[.15986 .00221 6 0 ]
[.43197 .00221 -3 -9 ]
[.43197 .00221 3 0 ]
[.56803 .00221 -3 -9 ]
[.56803 .00221 3 0 ]
[.70408 .00221 -3 -9 ]
[.70408 .00221 3 0 ]
[.84014 .00221 -3 -9 ]
[.84014 .00221 3 0 ]
[.97619 .00221 -3 -9 ]
[.97619 .00221 3 0 ]
[.28342 .16426 -18 -4.5 ]
[.28342 .16426 0 4.5 ]
[.28342 .3138 -6 -4.5 ]
[.28342 .3138 0 4.5 ]
[.28342 .46334 -18 -4.5 ]
[.28342 .46334 0 4.5 ]
[.28342 .61289 -6 -4.5 ]
[.28342 .61289 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.02381 .01471 m
.02381 .02096 L
s
[(-2)] .02381 .00221 0 1 Mshowa
.15986 .01471 m
.15986 .02096 L
s
[(-1)] .15986 .00221 0 1 Mshowa
.43197 .01471 m
.43197 .02096 L
s
[(1)] .43197 .00221 0 1 Mshowa
.56803 .01471 m
.56803 .02096 L
s
[(2)] .56803 .00221 0 1 Mshowa
.70408 .01471 m
.70408 .02096 L
s
[(3)] .70408 .00221 0 1 Mshowa
.84014 .01471 m
.84014 .02096 L
s
[(4)] .84014 .00221 0 1 Mshowa
.97619 .01471 m
.97619 .02096 L
s
[(5)] .97619 .00221 0 1 Mshowa
.125 Mabswid
.05102 .01471 m
.05102 .01846 L
s
.07823 .01471 m
.07823 .01846 L
s
.10544 .01471 m
.10544 .01846 L
s
.13265 .01471 m
.13265 .01846 L
s
.18707 .01471 m
.18707 .01846 L
s
.21429 .01471 m
.21429 .01846 L
s
.2415 .01471 m
.2415 .01846 L
s
.26871 .01471 m
.26871 .01846 L
s
.32313 .01471 m
.32313 .01846 L
s
.35034 .01471 m
.35034 .01846 L
s
.37755 .01471 m
.37755 .01846 L
s
.40476 .01471 m
.40476 .01846 L
s
.45918 .01471 m
.45918 .01846 L
s
.48639 .01471 m
.48639 .01846 L
s
.51361 .01471 m
.51361 .01846 L
s
.54082 .01471 m
.54082 .01846 L
s
.59524 .01471 m
.59524 .01846 L
s
.62245 .01471 m
.62245 .01846 L
s
.64966 .01471 m
.64966 .01846 L
s
.67687 .01471 m
.67687 .01846 L
s
.73129 .01471 m
.73129 .01846 L
s
.7585 .01471 m
.7585 .01846 L
s
.78571 .01471 m
.78571 .01846 L
s
.81293 .01471 m
.81293 .01846 L
s
.86735 .01471 m
.86735 .01846 L
s
.89456 .01471 m
.89456 .01846 L
s
.92177 .01471 m
.92177 .01846 L
s
.94898 .01471 m
.94898 .01846 L
s
.25 Mabswid
0 .01471 m
1 .01471 L
s
.29592 .16426 m
.30217 .16426 L
s
[(0.5)] .28342 .16426 1 0 Mshowa
.29592 .3138 m
.30217 .3138 L
s
[(1)] .28342 .3138 1 0 Mshowa
.29592 .46334 m
.30217 .46334 L
s
[(1.5)] .28342 .46334 1 0 Mshowa
.29592 .61289 m
.30217 .61289 L
s
[(2)] .28342 .61289 1 0 Mshowa
.125 Mabswid
.29592 .04462 m
.29967 .04462 L
s
.29592 .07453 m
.29967 .07453 L
s
.29592 .10444 m
.29967 .10444 L
s
.29592 .13435 m
.29967 .13435 L
s
.29592 .19416 m
.29967 .19416 L
s
.29592 .22407 m
.29967 .22407 L
s
.29592 .25398 m
.29967 .25398 L
s
.29592 .28389 m
.29967 .28389 L
s
.29592 .34371 m
.29967 .34371 L
s
.29592 .37362 m
.29967 .37362 L
s
.29592 .40353 m
.29967 .40353 L
s
.29592 .43344 m
.29967 .43344 L
s
.29592 .49325 m
.29967 .49325 L
s
.29592 .52316 m
.29967 .52316 L
s
.29592 .55307 m
.29967 .55307 L
s
.29592 .58298 m
.29967 .58298 L
s
.25 Mabswid
.29592 0 m
.29592 .61803 L
s
.5 Mabswid
.02381 .01472 m
.02846 .01472 L
.03279 .01472 L
.03793 .01472 L
.04262 .01472 L
.0522 .01472 L
.05746 .01473 L
.06244 .01473 L
.06754 .01474 L
.07295 .01474 L
.08265 .01476 L
.08804 .01477 L
.09308 .01479 L
.09862 .01481 L
.10458 .01484 L
.10982 .01487 L
.11468 .01491 L
.12002 .01497 L
.12571 .01504 L
.13114 .01513 L
.13625 .01523 L
.1458 .01551 L
.15046 .01569 L
.15557 .01593 L
.16055 .01623 L
.16588 .01663 L
.17088 .01711 L
.17544 .01764 L
.18435 .01904 L
.18916 .02005 L
.19427 .02139 L
.20344 .02466 L
.20853 .02711 L
.21331 .02995 L
.21851 .03375 L
.2242 .03897 L
.23403 .05133 L
.23939 .06036 L
.24438 .07054 L
.25333 .09397 L
.26289 .12768 L
.27313 .1749 L
.28423 .23826 L
.30439 .36874 L
.32426 .4792 L
.33428 .51923 L
.33994 .53708 L
.3453 .55117 L
.35017 .5618 L
.35547 .57137 L
Mistroke
.36475 .58395 L
.37 .58916 L
.37559 .5935 L
.38087 .59667 L
.38564 .59887 L
.39053 .60059 L
.3932 .60132 L
.39569 .60189 L
.398 .60232 L
.4001 .60264 L
.40243 .60292 L
.40362 .60303 L
.40493 .60313 L
.40622 .60321 L
.40688 .60324 L
.4076 .60327 L
.40887 .60331 L
.41006 .60332 L
.41074 .60332 L
.41148 .60331 L
.41225 .6033 L
.41297 .60328 L
.41426 .60323 L
.41563 .60316 L
.41695 .60306 L
.41837 .60294 L
.42094 .60267 L
.42576 .60195 L
.43067 .60096 L
.43525 .59978 L
.4407 .59805 L
.44568 .59612 L
.45584 .59106 L
.46673 .5836 L
.47663 .57455 L
.48579 .5638 L
.49585 .5488 L
.50655 .52853 L
.52599 .47817 L
.54426 .41421 L
.58292 .24935 L
.60254 .17385 L
.61293 .14081 L
.62403 .11137 L
.63477 .08843 L
.64453 .07179 L
.6538 .05919 L
.66362 .04867 L
.67359 .04041 L
.68278 .03453 L
Mistroke
.69268 .02965 L
.70357 .02563 L
.71372 .02285 L
.72299 .02093 L
.7337 .01926 L
.74388 .01809 L
.75347 .01727 L
.7637 .0166 L
.77335 .01614 L
.78209 .01582 L
.79212 .01553 L
.80135 .01534 L
.81148 .01518 L
.82218 .01505 L
.83166 .01497 L
.84183 .0149 L
.85142 .01486 L
.86017 .01482 L
.87009 .01479 L
.87927 .01477 L
.88934 .01476 L
.90003 .01475 L
.90941 .01474 L
.91952 .01473 L
.92906 .01473 L
.9378 .01472 L
.94731 .01472 L
.95614 .01472 L
.96584 .01472 L
.97619 .01472 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{216, 133.438},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003H0000QA000`40O003h00Of7oo000@Ool3000F
Ool5000^Ool5000FOol3000HOol2000IOol3000HOol00`00Oomoo`0=Ool0011oo`03001oogoo01Qo
o`03001oogoo031oo`03001oogoo01Ioo`03001oogoo01Yoo`03001oogoo01Moo`03001oogoo01Io
o`03001oo`0000ioo`002goo0`000goo00<007ooOol04Goo0`000goo00<007ooOol0<7oo00<007oo
Ool05goo00<007ooOol067oo00<007ooOol05Woo10006Goo00<007ooOol037oo000AOol00`00Oomo
o`0GOol00`00Oomoo`0`Ool00`00Oomoo`0GOol00`00Oomoo`0IOol00`00Oomoo`0EOol00`00Ool0
000HOol2000?Ool0011oo`03001oo`0001Qoo`03001oogoo031oo`03001oogoo01Ioo`03001oo`00
01Qoo`03001oo`0001Qoo`8001Qoo`03001oogoo00ioo`004Goo00<007ooOol05Woo0P00<Goo0P00
6Goo00<007ooOol067oo00<007ooOol067oo00<007ooOol05Woo0`003Woo003HOol00=Qoo`00A7oo
00<007ooOol0TGoo0014Ool00`00Oomoo`2AOol000Yool@000Yoo`003goo00<007ooOol00Woo00<0
07ooOol06@0017oo00<007ooOol00Woo00<007ooOol00goo00<007ooOol00Woo00<007ooOol00Woo
00<007ooOol00goo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol00goo
00<007ooOol00Woo00<007ooOol00Woo00<007ooOol00goo00<007ooOol00Woo00<007ooOol00Woo
00<007ooOol00goo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol00goo
900000=oo`00Ool00goo00<007ooOol00Woo00<007ooOol03Goo000?Ool00`00Oomoo`0GOol00`00
Oomoo`03Ool4000AOol00`00Oomoo`0GOol00`00Oomoo`0HOol00`00Oomoo`0GOol00`00Ool00003
000EOol00`00Oomoo`0GOol00`00Oomoo`0=Ool003=oo`8000moo`03001oogoo04Yoo`@004=oo`00
=Goo00<007ooOol037oo00<007ooOol0B7oo0P00Agoo000fOol00`00Oomoo`0;Ool00`00Oomoo`17
Ool00`00Oomoo`17Ool003Moo`03001oogoo00Yoo`8004Moo`03001oogoo04Qoo`00=goo00<007oo
Ool02Woo00<007ooOol0AGoo00<007ooOol0BGoo000hOol00`00Oomoo`09Ool00`00Oomoo`14Ool0
0`00Oomoo`1:Ool003Uoo`03001oogoo00Qoo`03001oogoo04=oo`03001oogoo04]oo`00>Woo00<0
07ooOol01goo00<007ooOol0@Woo00<007ooOol0C7oo000jOol00`00Oomoo`07Ool00`00Oomoo`12
Ool00`00Oomoo`1<Ool003Yoo`03001oogoo00Moo`80049oo`03001oogoo04eoo`00>goo00<007oo
Ool01Woo00<007ooOol0@7oo00<007ooOol0CWoo000kOol00`00Oomoo`06Ool00`00Oomoo`10Ool0
0`00Oomoo`1>Ool003aoo`03001oogoo00Eoo`03001oogoo03moo`03001oogoo04moo`00?7oo00<0
07ooOol01Goo00<007ooOol0?Woo00<007ooOol0D7oo000lOol00`00Oomoo`05Ool00`00Oomoo`0n
Ool00`00Oomoo`1@Ool003eoo`03001oogoo00Aoo`8003ioo`03001oogoo055oo`00?Goo00<007oo
Ool017oo00<007ooOol0?Goo00<007ooOol0DGoo000mOol00`00Oomoo`04Ool00`00Oomoo`0mOol0
0`00Oomoo`1AOol003ioo`03001oogoo00=oo`03001oogoo03aoo`03001oogoo059oo`00?Woo00<0
07ooOol00goo00<007ooOol0?7oo00<007ooOol0DWoo000nOol00`00Oomoo`03Ool00`00Oomoo`0l
Ool00`00Oomoo`1BOol003ioo`03001oogoo00=oo`8003aoo`03001oogoo05=oo`00?Woo00<007oo
Ool00goo00<007ooOol0>goo00<007ooOol0Dgoo000nOol00`00Oomoo`03Ool00`00Oomoo`0kOol0
0`00Oomoo`1COol003moo`03001oogoo009oo`03001oogoo03Yoo`03001oogoo05Aoo`00=Goo00<0
07ooOol00Woo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol0>Woo00<007ooOol0E7oo000d
Ool00`00Ool00007Ool30003Ool00`00Oomoo`0jOol00`00Oomoo`1DOol003Aoo`03001oo`0000Qo
o`8000=oo`8003Yoo`03001oogoo05Eoo`00=7oo00<007oo00001goo0P0017oo00<007ooOol0>Goo
00<007ooOol0EGoo000dOol00`00Ool00007Ool20004Ool00`00Oomoo`0iOol00`00Oomoo`1EOol0
03Eoo`03001oogoo00Ioo`<000=oo`03001oogoo03Qoo`03001oogoo05Ioo`00@7oo00D007ooOomo
o`0003Yoo`03001oogoo05Ioo`00@7oo00@007ooOomoo`8003Uoo`03001oogoo05Ioo`00@7oo00D0
07ooOomoo`0003Yoo`03001oogoo05Ioo`00@7oo00D007ooOomoo`0003Uoo`03001oogoo05Moo`00
@Goo00@007ooOol003Uoo`03001oogoo05Moo`00@Goo00@007ooOol003Uoo`03001oogoo05Moo`00
@Goo00@007ooOol003Uoo`03001oogoo05Moo`00@Goo00<007ooOol00P00=goo00<007ooOol0F7oo
0012Ool00`00Ool0000hOol00`00Oomoo`1HOol0049oo`03001oo`0003Qoo`03001oogoo05Qoo`00
@Woo00<007oo0000>7oo00<007ooOol0F7oo0012Ool00`00Ool0000gOol00`00Oomoo`1IOol0049o
o`03001oo`0003Moo`03001oogoo05Uoo`00@Woo00@007oo000003Ioo`03001oogoo05Uoo`00@goo
0P00=Woo00<007ooOol0FWoo0013Ool2000fOol00`00Oomoo`1JOol004=oo`8003Ioo`03001oogoo
05Yoo`00@goo0P00=Woo00<007ooOol0FWoo0013Ool2000eOol00`00Oomoo`1KOol004=oo`<003Ao
o`03001oogoo05]oo`00A7oo00<007ooOol0<goo00<007ooOol0Fgoo0014Ool00`00Oomoo`0cOol0
0`00Oomoo`1KOol004Aoo`03001oogoo039oo`03001oogoo05aoo`00?Goo1@000Woo00<007ooOol0
<Woo00<007ooOol0G7oo000oOol00`00Oomoo`02Ool00`00Oomoo`0bOol00`00Oomoo`1LOol003mo
o`03001oogoo009oo`8003=oo`03001oogoo05aoo`00?goo00<007ooOol00Woo0P00<Woo00<007oo
Ool0GGoo000oOol00`00Oomoo`02Ool2000bOol00`00Oomoo`1MOol003ioo`8000Aoo`80039oo`03
001oogoo05eoo`00A7oo0P00<Woo00<007ooOol0GGoo0014Ool2000aOol00`00Oomoo`1NOol004Ao
o`80035oo`03001oogoo05ioo`00A7oo00<007oo0000<7oo00<007ooOol0GWoo0014Ool00`00Ool0
000`Ool00`00Oomoo`1NOol004Aoo`03001oo`0002moo`03001oogoo05moo`00A7oo00<007oo0000
;goo00<007ooOol0Ggoo0014Ool3000_Ool00`00Oomoo`1OOol004Aoo`03001oo`0002moo`03001o
ogoo05moo`00A7oo00<007oo0000;Woo00<007ooOol0H7oo0014Ool01000Oomoo`00;Goo00<007oo
Ool0H7oo0014Ool01000Oomoo`00;Goo00<007ooOol0H7oo0014Ool01000Oomoo`00;Goo00<007oo
Ool0H7oo0014Ool200000goo001oo`0[Ool00`00Oomoo`1QOol004Aoo`04001oogoo000/Ool00`00
Oomoo`1QOol004Aoo`04001oogoo000/Ool00`00Oomoo`1QOol004Aoo`04001oogoo000/Ool00`00
Oomoo`1QOol004Aoo`05001oogooOol0000[Ool00`00Oomoo`1QOol004Aoo`05001oogooOol0000Z
Ool00`00Oomoo`1ROol004Aoo`80009oo`03001oogoo02Qoo`03001oogoo069oo`00A7oo00D007oo
Oomoo`0002Yoo`03001oogoo069oo`00A7oo00D007ooOomoo`0002Yoo`03001oogoo069oo`00A7oo
00D007ooOomoo`0002Uoo`03001oogoo06=oo`00<goo1@000Woo00<007ooOol00Woo00<007ooOol0
0Woo00D007ooOomoo`0002Uoo`03001oogoo06=oo`00=Goo00<007ooOol01Woo00<007oo00000goo
00D007ooOomoo`0002Uoo`03001oogoo06=oo`00=Goo00<007ooOol027oo00@007ooOomoo`8000=o
o`03001oogoo02Ioo`03001oogoo06=oo`00=Goo00<007ooOol01Woo0P0017oo00<007ooOol00Woo
00<007ooOol09Goo00<007ooOol0I7oo000eOol00`00Oomoo`06Ool00`00Oomoo`03Ool00`00Oomo
o`02Ool00`00Oomoo`0UOol00`00Oomoo`1TOol003Aoo`8000Qoo`<000=oo`03001oogoo009oo`03
001oogoo02Eoo`03001oogoo06Aoo`00A7oo00<007ooOol00Woo00<007ooOol09Goo00<007ooOol0
I7oo0014Ool00`00Oomoo`03Ool00`00Oomoo`0SOol00`00Oomoo`1UOol004Aoo`8000Aoo`03001o
ogoo02=oo`03001oogoo06Eoo`00A7oo00<007ooOol00goo00<007ooOol08Woo00<007ooOol0IWoo
0014Ool00`00Oomoo`03Ool00`00Oomoo`0ROol00`00Oomoo`1VOol004Aoo`03001oogoo00Aoo`03
001oogoo025oo`03001oogoo06Ioo`00A7oo00<007ooOol017oo00<007ooOol087oo00<007ooOol0
Igoo0014Ool00`00Oomoo`04Ool00`00Oomoo`0POol00`00Oomoo`1WOol004Aoo`8000Ioo`03001o
ogoo01ioo`03001oogoo06Qoo`00A7oo00<007ooOol01Goo00<007ooOol07Woo00<007ooOol0J7oo
0014Ool00`00Oomoo`06Ool00`00Oomoo`0LOol00`00Oomoo`1YOol004Aoo`03001oogoo00Ioo`03
001oogoo01aoo`03001oogoo06Uoo`00A7oo00<007ooOol01goo00<007ooOol06Woo00<007ooOol0
JWoo0014Ool20008Ool00`00Oomoo`0JOol00`00Oomoo`1ZOol004Aoo`03001oogoo00Qoo`03001o
ogoo01Qoo`03001oogoo06]oo`00A7oo00<007ooOol027oo00<007ooOol05goo00<007ooOol0K7oo
0014Ool00`00Oomoo`09Ool00`00Oomoo`0EOol00`00Oomoo`1]Ool004Aoo`03001oogoo00Uoo`03
001oogoo01Eoo`03001oogoo06eoo`00A7oo00<007ooOol02Woo00<007ooOol04goo00<007ooOol0
KWoo0014Ool2000;Ool00`00Oomoo`0AOol2001aOol004Aoo`03001oogoo00]oo`03001oogoo00mo
o`03001oogoo075oo`00A7oo00<007ooOol037oo00<007ooOol03Goo00<007ooOol0LWoo0014Ool0
0`00Oomoo`0=Ool20009Ool4001eOol003ioo`<000=oo`03001oogoo00moo`T007Uoo`00?Woo00<0
07ooOol00goo00<007ooOol0TGoo000oOol00`00Oomoo`02Ool2002BOol003moo`03001oogoo009o
o`03001oogoo095oo`00?Woo00<007oo0000Ugoo000oOol00`00Oomoo`2FOol00=Qoo`00\
\>"],
  ImageRangeCache->{{{0, 215}, {132.438, 0}} -> {-2.58263, -0.196313, 
  0.0377388, 0.0171672}}]
}, Open  ]],

Cell["\<\
Again calculate and plot the first and second derivates of the example \
signal.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[Del]2 = {\[PartialD]\_t\((Tanh[3\ t] - Tanh[2\ \((t - 2)\)])\), 
        \[PartialD]\_{t, 2}\((Tanh[3\ t] - Tanh[2\ \((t - 2)\)])\)}; \n
    Plot[Evaluate[\[Del]2], {t, \(-2\), 4}]; \)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.15873 0.309662 0.0424144 [
[.02381 .29716 -6 -9 ]
[.02381 .29716 6 0 ]
[.18254 .29716 -6 -9 ]
[.18254 .29716 6 0 ]
[.5 .29716 -3 -9 ]
[.5 .29716 3 0 ]
[.65873 .29716 -3 -9 ]
[.65873 .29716 3 0 ]
[.81746 .29716 -3 -9 ]
[.81746 .29716 3 0 ]
[.97619 .29716 -3 -9 ]
[.97619 .29716 3 0 ]
[.32877 .05518 -12 -4.5 ]
[.32877 .05518 0 4.5 ]
[.32877 .14 -12 -4.5 ]
[.32877 .14 0 4.5 ]
[.32877 .22483 -12 -4.5 ]
[.32877 .22483 0 4.5 ]
[.32877 .39449 -6 -4.5 ]
[.32877 .39449 0 4.5 ]
[.32877 .47932 -6 -4.5 ]
[.32877 .47932 0 4.5 ]
[.32877 .56415 -6 -4.5 ]
[.32877 .56415 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.02381 .30966 m
.02381 .31591 L
s
[(-2)] .02381 .29716 0 1 Mshowa
.18254 .30966 m
.18254 .31591 L
s
[(-1)] .18254 .29716 0 1 Mshowa
.5 .30966 m
.5 .31591 L
s
[(1)] .5 .29716 0 1 Mshowa
.65873 .30966 m
.65873 .31591 L
s
[(2)] .65873 .29716 0 1 Mshowa
.81746 .30966 m
.81746 .31591 L
s
[(3)] .81746 .29716 0 1 Mshowa
.97619 .30966 m
.97619 .31591 L
s
[(4)] .97619 .29716 0 1 Mshowa
.125 Mabswid
.05556 .30966 m
.05556 .31341 L
s
.0873 .30966 m
.0873 .31341 L
s
.11905 .30966 m
.11905 .31341 L
s
.15079 .30966 m
.15079 .31341 L
s
.21429 .30966 m
.21429 .31341 L
s
.24603 .30966 m
.24603 .31341 L
s
.27778 .30966 m
.27778 .31341 L
s
.30952 .30966 m
.30952 .31341 L
s
.37302 .30966 m
.37302 .31341 L
s
.40476 .30966 m
.40476 .31341 L
s
.43651 .30966 m
.43651 .31341 L
s
.46825 .30966 m
.46825 .31341 L
s
.53175 .30966 m
.53175 .31341 L
s
.56349 .30966 m
.56349 .31341 L
s
.59524 .30966 m
.59524 .31341 L
s
.62698 .30966 m
.62698 .31341 L
s
.69048 .30966 m
.69048 .31341 L
s
.72222 .30966 m
.72222 .31341 L
s
.75397 .30966 m
.75397 .31341 L
s
.78571 .30966 m
.78571 .31341 L
s
.84921 .30966 m
.84921 .31341 L
s
.88095 .30966 m
.88095 .31341 L
s
.9127 .30966 m
.9127 .31341 L
s
.94444 .30966 m
.94444 .31341 L
s
.25 Mabswid
0 .30966 m
1 .30966 L
s
.34127 .05518 m
.34752 .05518 L
s
[(-6)] .32877 .05518 1 0 Mshowa
.34127 .14 m
.34752 .14 L
s
[(-4)] .32877 .14 1 0 Mshowa
.34127 .22483 m
.34752 .22483 L
s
[(-2)] .32877 .22483 1 0 Mshowa
.34127 .39449 m
.34752 .39449 L
s
[(2)] .32877 .39449 1 0 Mshowa
.34127 .47932 m
.34752 .47932 L
s
[(4)] .32877 .47932 1 0 Mshowa
.34127 .56415 m
.34752 .56415 L
s
[(6)] .32877 .56415 1 0 Mshowa
.125 Mabswid
.34127 .07638 m
.34502 .07638 L
s
.34127 .09759 m
.34502 .09759 L
s
.34127 .1188 m
.34502 .1188 L
s
.34127 .16121 m
.34502 .16121 L
s
.34127 .18242 m
.34502 .18242 L
s
.34127 .20363 m
.34502 .20363 L
s
.34127 .24604 m
.34502 .24604 L
s
.34127 .26725 m
.34502 .26725 L
s
.34127 .28845 m
.34502 .28845 L
s
.34127 .33087 m
.34502 .33087 L
s
.34127 .35208 m
.34502 .35208 L
s
.34127 .37328 m
.34502 .37328 L
s
.34127 .4157 m
.34502 .4157 L
s
.34127 .4369 m
.34502 .4369 L
s
.34127 .45811 m
.34502 .45811 L
s
.34127 .50053 m
.34502 .50053 L
s
.34127 .52173 m
.34502 .52173 L
s
.34127 .54294 m
.34502 .54294 L
s
.34127 .03397 m
.34502 .03397 L
s
.34127 .01276 m
.34502 .01276 L
s
.34127 .58536 m
.34502 .58536 L
s
.34127 .60656 m
.34502 .60656 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30966 m
.02846 .30967 L
.03279 .30967 L
.03793 .30967 L
.04262 .30967 L
.0522 .30967 L
.05746 .30967 L
.06244 .30968 L
.06754 .30968 L
.07295 .30968 L
.08265 .30969 L
.08804 .3097 L
.09308 .3097 L
.09858 .30971 L
.10458 .30973 L
.10996 .30974 L
.11496 .30976 L
.12013 .30978 L
.12483 .3098 L
.13379 .30986 L
.14335 .30995 L
.14823 .31001 L
.15338 .31008 L
.1626 .31025 L
.16773 .31038 L
.17252 .31052 L
.17774 .31071 L
.18342 .31096 L
.18885 .31125 L
.19387 .31158 L
.20377 .31244 L
.21277 .31355 L
.22233 .31521 L
.2317 .31749 L
.2418 .32097 L
.25133 .32556 L
.26008 .33124 L
.26988 .33972 L
.279 .34997 L
.2997 .38212 L
.31844 .4158 L
.32357 .42359 L
.32638 .42726 L
.329 .43022 L
.33143 .43251 L
.33364 .4342 L
.3361 .4356 L
.33746 .43614 L
.33875 .43651 L
.33944 .43664 L
Mistroke
.34009 .43673 L
.34131 .43679 L
.34263 .4367 L
.34337 .43659 L
.34405 .43643 L
.34519 .43608 L
.34644 .43557 L
.34896 .43412 L
.35174 .4319 L
.35472 .42886 L
.36009 .42189 L
.38024 .38656 L
.40009 .35401 L
.4113 .34045 L
.42166 .331 L
.43087 .32469 L
.44102 .31947 L
.45162 .31546 L
.46156 .31262 L
.48178 .30831 L
.50029 .30487 L
.52086 .30034 L
.53997 .29451 L
.55843 .28656 L
.57813 .27494 L
.59808 .25999 L
.61968 .24247 L
.62981 .23518 L
.63535 .2318 L
.64052 .22915 L
.64494 .22735 L
.6472 .2266 L
.64967 .22593 L
.65107 .22562 L
.65237 .22538 L
.65358 .22519 L
.65492 .22503 L
.65612 .22493 L
.65725 .22487 L
.65843 .22484 L
.65972 .22485 L
.66097 .2249 L
.66211 .22499 L
.66342 .22513 L
.66466 .22531 L
.66687 .22572 L
.66927 .22631 L
.67471 .22818 L
.67973 .23051 L
.68997 .23673 L
Mistroke
.70082 .24484 L
.73868 .27443 L
.7581 .28596 L
.77899 .29475 L
.7891 .29786 L
.80014 .30057 L
.81068 .3026 L
.82023 .30406 L
.82969 .30522 L
.83992 .30621 L
.85072 .30702 L
.8609 .30761 L
.87041 .30804 L
.88085 .30841 L
.89175 .30871 L
.90192 .30893 L
.91238 .3091 L
.92229 .30922 L
.93129 .30931 L
.94085 .30938 L
.94958 .30944 L
.95921 .30949 L
.97619 .30955 L
Mfstroke
.02381 .30968 m
.02846 .30968 L
.03279 .30969 L
.03793 .30969 L
.04262 .3097 L
.0522 .30972 L
.05746 .30973 L
.06244 .30974 L
.06754 .30976 L
.07295 .30978 L
.08265 .30983 L
.08804 .30987 L
.09308 .30992 L
.09858 .30998 L
.10458 .31006 L
.10996 .31015 L
.11496 .31025 L
.12013 .31037 L
.12483 .31051 L
.13379 .31086 L
.14335 .31138 L
.14823 .31172 L
.15338 .31216 L
.1626 .3132 L
.16773 .31396 L
.17252 .3148 L
.17774 .31592 L
.18342 .3174 L
.18885 .31914 L
.19387 .32109 L
.20377 .32617 L
.21277 .33265 L
.22233 .34222 L
.2317 .35519 L
.2418 .37444 L
.25133 .39892 L
.26008 .42767 L
.2806 .51726 L
.29061 .56356 L
.29534 .58193 L
.29742 .58865 L
.2997 .59482 L
.30191 .59935 L
.30312 .60116 L
.30425 .60237 L
.30549 .60315 L
.30663 .60332 L
.30794 .60283 L
.30918 .60167 L
.31025 .60007 L
Mistroke
.3114 .59776 L
.31346 .59194 L
.31591 .5821 L
.31813 .57037 L
.323 .53499 L
.32827 .48258 L
.33781 .35889 L
.34815 .21207 L
.35319 .14816 L
.35779 .0992 L
.36264 .05923 L
.36532 .04277 L
.36784 .03083 L
.36918 .02593 L
.37059 .02174 L
.3718 .01897 L
.37313 .01674 L
.37387 .01586 L
.37455 .01528 L
.3753 .01488 L
.37609 .01472 L
.37678 .01479 L
.37742 .01503 L
.37812 .01548 L
.37887 .01616 L
.3801 .01775 L
.38146 .02009 L
.38421 .02655 L
.38913 .04281 L
.40025 .09188 L
.41079 .14106 L
.42042 .18064 L
.42974 .2118 L
.4399 .23758 L
.44547 .24846 L
.45063 .25675 L
.45553 .26319 L
.46081 .26877 L
.46582 .2729 L
.47042 .2758 L
.47482 .27787 L
.47703 .27867 L
.47945 .27937 L
.48084 .2797 L
.48215 .27995 L
.48334 .28014 L
.4846 .2803 L
.48526 .28037 L
.48598 .28043 L
.48724 .2805 L
Mistroke
.48796 .28052 L
.48873 .28053 L
.48945 .28053 L
.49011 .28051 L
.49138 .28046 L
.49255 .28037 L
.49383 .28023 L
.4952 .28004 L
.49774 .27959 L
.50004 .27905 L
.50492 .27752 L
.51008 .27535 L
.5193 .27011 L
.52923 .26254 L
.54013 .252 L
.56129 .22574 L
.58057 .19918 L
.59015 .18802 L
.59278 .18553 L
.59556 .18324 L
.59797 .18161 L
.59924 .18089 L
.60057 .18025 L
.60173 .17979 L
.60299 .17939 L
.60414 .17913 L
.60521 .17898 L
.60632 .17892 L
.60732 .17896 L
.60848 .1791 L
.60957 .17935 L
.61077 .17974 L
.61205 .18031 L
.61434 .18171 L
.6168 .1838 L
.6195 .18682 L
.62472 .19487 L
.62967 .20527 L
.63896 .23175 L
.65986 .31447 L
.67021 .35739 L
.67995 .39222 L
.68869 .41608 L
.69361 .42592 L
.69813 .43262 L
.7005 .43526 L
.70271 .4372 L
.70513 .43876 L
.70649 .43939 L
.70773 .43981 L
Mistroke
.70902 .4401 L
.71022 .44024 L
.71154 .44025 L
.7122 .4402 L
.71293 .44011 L
.71415 .43986 L
.71547 .43947 L
.71671 .43898 L
.71785 .43844 L
.723 .43501 L
.72861 .4297 L
.73884 .41719 L
.76015 .38732 L
.77948 .36327 L
.78915 .35341 L
.79962 .34443 L
.81859 .33217 L
.82809 .32764 L
.83852 .32367 L
.84941 .32042 L
.85958 .31805 L
.87003 .31614 L
.87993 .31473 L
.88874 .31374 L
.89848 .31286 L
.90813 .31217 L
.91838 .3116 L
.92788 .31119 L
.9368 .31089 L
.94662 .31062 L
.95697 .3104 L
.96581 .31025 L
.97547 .31012 L
.97619 .31012 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{216, 133.438},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003H0000QA000`40O003h00OBGoo00<007ooOol0
S7oo0019Ool00`00Oomoo`2<Ool004Uoo`03001oogoo08aoo`00BGoo0P001Woo00<007ooOol0Q7oo
0019Ool00`00Oomoo`04Ool00`00Ool00025Ool004Uoo`03001oogoo00Aoo`04001oogoo0024Ool0
04Uoo`03001oogoo00=oo`05001oogooOol00024Ool004Uoo`8000Aoo`05001oogooOol00024Ool0
04Uoo`03001oogoo00=oo`03001oogoo009oo`03001oogoo085oo`00BGoo00<007ooOol00goo00<0
07ooOol00Woo00<007ooOol0PGoo0013Ool20004Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00
Oomoo`21Ool004=oo`03001oo`0000=oo`03001oogoo009oo`03001oogoo00=oo`03001oogoo085o
o`00?Woo0`000Woo00<007oo00000goo0`000Woo00<007ooOol017oo00<007ooOol0P7oo0013Ool2
0004Ool00`00Oomoo`02Ool00`00Oomoo`04Ool00`00Oomoo`20Ool004=oo`03001oogoo00=oo`03
001oogoo009oo`03001oogoo00Aoo`03001oogoo081oo`00A7oo0P000goo00<007ooOol00Woo00<0
07ooOol017oo00<007ooOol0P7oo0019Ool20003Ool00`00Oomoo`04Ool00`00Oomoo`20Ool004Uo
o`05001oogooOol00007Ool00`00Oomoo`20Ool004Uoo`05001oogooOol00008Ool00`00Oomoo`1o
Ool004Uoo`05001oogooOol00008Ool00`00Oomoo`1oOol004Uoo`05001oogooOol00008Ool00`00
Oomoo`1oOol004Uoo`80009oo`03001oogoo00Ioo`03001oogoo07moo`00BGoo00D007ooOomoo`00
00Qoo`03001oogoo07moo`00BGoo00D007ooOomoo`0000Uoo`03001oogoo07ioo`00BGoo00D007oo
Oomoo`0000Uoo`03001oogoo07ioo`00BGoo00D007ooOomoo`0000Uoo`03001oogoo07ioo`00BGoo
0P000Woo00<007ooOol01goo00<007ooOol0OWoo0019Ool01000Oomoo`002Woo00<007ooOol0OWoo
0014Ool30002Ool01000Oomoo`002goo00<007ooOol0OGoo0015Ool01@00Oomoogoo00000Woo00<0
07ooOol02Goo00<007ooOol0OGoo000nOol30002Ool40002Ool4000;Ool00`00Oomoo`1mOol004=o
o`03001oo`0000=oo`04001oogoo000;Ool00`00Oomoo`1mOol004Aoo`8000=oo`04001oogoo000;
Ool00`00Oomoo`1mOol004Eoo`05001oogooOol00002Ool00`00Oomoo`0:Ool00`00Oomoo`1lOol0
04Uoo`04001oogoo000<Ool00`00Oomoo`1lOol004Uoo`800003Ool007oo00]oo`03001oogoo07ao
o`00BGoo00@007ooOol000aoo`03001oogoo07aoo`00BGoo00@007ooOol000eoo`03001oogoo07]o
o`00BGoo00@007ooOol000eoo`03001oogoo02Eoo`8005Aoo`00BGoo0`003Woo00<007ooOol08goo
1@00Dgoo0019Ool00`00Ool0000>Ool00`00Oomoo`0ROol00`00Oomoo`03Ool00`00Oomoo`1@Ool0
04Uoo`03001oo`0000moo`03001oogoo021oo`03001oogoo00Eoo`03001oogoo04moo`00BGoo00<0
07oo00003goo00<007ooOol087oo00<007ooOol01Goo00<007ooOol0Cgoo0019Ool00`00Ool0000?
Ool00`00Oomoo`0OOol00`00Oomoo`07Ool00`00Oomoo`1>Ool004Uoo`<0011oo`03001oogoo01eo
o`03001oogoo00Qoo`03001oogoo04ioo`00BGoo00<007oo000047oo00<007ooOol077oo00<007oo
Ool02Goo00<007ooOol0CWoo0013Ool30003Ool00`00Ool0000AOol00`00Oomoo`0KOol00`00Oomo
o`0:Ool00`00Oomoo`1=Ool004=oo`03001oogoo00=oo`03001oo`00015oo`03001oogoo01Yoo`03
001oogoo00]oo`03001oogoo04eoo`00?Woo0`000goo00<007ooOol00Woo0`004Woo00<007ooOol0
67oo00<007ooOol037oo00<007ooOol01@00B7oo0014Ool00`00Oomoo`02Ool00`00Ool0000BOol0
0`00Oomoo`0GOol00`00Oomoo`0>Ool30004Ool30015Ool004=oo`03001oo`0000=oo`03001oo`00
01=oo`03001oogoo01Eoo`03001oogoo00eoo`<000Uoo`03001oogoo049oo`00A7oo00<007ooOol0
0Woo00<007oo00004goo00<007ooOol057oo00<007ooOol03Goo00@007ooOol000Yoo`03001oogoo
045oo`00BGoo00<007oo000057oo00<007ooOol04goo00<007ooOol037oo00<007ooOol00Woo00<0
07ooOol027oo00<007ooOol0@7oo0019Ool3000DOol00`00Oomoo`0BOol00`00Oomoo`0<Ool00`00
Oomoo`03Ool00`00Oomoo`09Ool00`00Oomoo`0oOol004Uoo`8001Ioo`03001oogoo011oo`03001o
ogoo00]oo`8000Ioo`03001oogoo00Yoo`8003moo`00BGoo0P005Woo00<007ooOol03goo00<007oo
Ool02goo00<007ooOol01Woo00<007ooOol037oo00<007ooOol0?7oo0007Ool3000MOol5000MOol2
000GOol00`00Oomoo`04Ool50004Ool00`00Oomoo`0;Ool00`00Oomoo`08Ool4000;Ool2000BOol2
000QOol30004Ool000Moo`03001oogoo01moo`03001oogoo01eoo`8001Qoo`03001oogoo00Eoo`03
001oogoo00=oo`03001oogoo00]oo`03001oogoo00Uoo`8000moo`03001oogoo015oo`03001oogoo
01moo`03001oogoo00=oo`000Woo0`000goo00<007ooOol067oo0`000goo00<007ooOol07Goo0P00
67oo00<007ooOol01Goo00<007ooOol00Woo00<007ooOol02Woo0P0037oo00<007oo00003goo0P00
47oo00<007ooOol07Woo100017oo0008Ool00`00Oomoo`0NOol00`00Oomoo`0MOol2000IOol20005
Ool00`00Oomoo`02000<Ool00`00Oomoo`0=Ool2000AOol00`00Oomoo`0>Ool00`00Oomoo`0MOol0
0`00Ool00005Ool000Moo`03001oo`0001moo`03001oogoo01eoo`8001]oo`P000aoo`80011oo`03
001oo`00015oo`8000aoo`03001oo`00021oo`8000Eoo`0027oo00<007ooOol07Goo0P007goo0P00
7goo0P0037oo0P004Woo0P0057oo0P002goo00<007ooOol087oo00<007ooOol00goo0019Ool2000[
Ool2000EOol00`00Oomoo`0DOol2000bOol004Uoo`8002Qoo`<001Moo`03001oogoo01Ioo`80031o
o`00BGoo0P0097oo10006Woo00<007ooOol067oo1@00:goo0019Ool2000POol4000NOol00`00Oomo
o`0MOol6000UOol00=P000001Woo00<007ooOol00goo00<007ooOol017oo00@007ooOomooaP000Io
o`03001oogoo00Aoo`03001oogoo00Aoo`03001oogoo00=oo`8000Eoo`03001oogoo00Aoo`03001o
ogoo00Aoo`03001oogoo009oo`<000Eoo`03001oogoo00Aoo`03001oogoo00Aoo`03001oogoo00Ao
o`03001oogoo00Aoo`03001oogoo00=oo`8000Eoo`03001oogoo00Aoo`03001oogoo00Aoo`03001o
ogoo00Aoo`03001oogoo00=oo`03001oogoo00Aoo`03001oogoo00Aoo`03001oo`00018000Ioo`00
1Woo00<007ooOol077oo1@001Goo10005Woo0P005Woo0P0027oo00<007ooOol07goo0P0087oo00<0
07ooOol01Woo1`004Woo00<007ooOol017oo000ZOol00`00Oomoo`06Ool2000DOol2000DOol2000]
Ool00`00Oomoo`0SOol4000POol002]oo`8000Qoo`80019oo`03001oogoo015oo`80031oo`03001o
ogoo021oo`8002Aoo`00;Goo0P0027oo0P0047oo0P0047oo0P00<Woo00<007ooOol07Woo0P009Woo
000_Ool00`00Oomoo`07Ool00`00Oomoo`0=Ool00`00Oomoo`0=Ool2000dOol00`00Oomoo`0MOol0
0`00Oomoo`0VOol0031oo`03001oogoo00Moo`03001oogoo00aoo`03001oogoo00aoo`03001oogoo
03Aoo`03001oogoo01]oo`8002Uoo`00<Goo00<007ooOol01goo00<007ooOol02goo00<007ooOol0
2goo00<007ooOol0=Goo00<007ooOol06Woo00<007ooOol0:Goo000aOol00`00Oomoo`08Ool00`00
Oomoo`0:Ool2000<Ool00`00Oomoo`0fOol00`00Oomoo`0GOol2000/Ool0039oo`03001oogoo00Qo
o`03001oogoo00Uoo`03001oogoo00Yoo`03001oogoo03Moo`03001oogoo01Ioo`03001oogoo02ao
o`00<goo00<007ooOol01goo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol0>7oo00<007oo
Ool05Goo00<007ooOol0;Goo000cOol00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`09Ool0
0`00Oomoo`0hOol00`00Oomoo`0DOol00`00Oomoo`0^Ool003Aoo`03001oogoo00Qoo`03001oogoo
00Moo`03001oogoo00Qoo`03001oogoo03Yoo`03001oogoo019oo`03001oogoo02moo`00=7oo00<0
07ooOol02Goo00<007ooOol01Woo0P002Goo00<007ooOol0>Woo00<007ooOol04Goo00<007ooOol0
<7oo000dOol00`00Oomoo`09Ool00`00Oomoo`06Ool00`00Oomoo`07Ool00`00Oomoo`0kOol00`00
Oomoo`0AOol00`00Oomoo`0`Ool003Eoo`03001oogoo00Uoo`03001oogoo00Eoo`03001oogoo00Mo
o`03001oogoo03]oo`03001oogoo011oo`03001oogoo035oo`00=Goo00<007ooOol02Woo10000goo
00<007ooOol01Woo00<007ooOol0?Goo00<007ooOol03Woo00<007ooOol0<Woo000eOol00`00Oomo
o`0:Ool20004Ool20007Ool00`00Oomoo`0nOol00`00Oomoo`0=Ool00`00Oomoo`0cOol003Ioo`03
001oogoo00Yoo`8000=oo`@000Eoo`03001oogoo03ioo`03001oogoo00eoo`03001oogoo03=oo`00
=Woo00<007ooOol02Woo0P000goo0P001Woo00<007ooOol0@7oo00<007ooOol02goo00<007ooOol0
=7oo000fOol00`00Oomoo`0:Ool30002Ool20005Ool00`00Oomoo`11Ool00`00Oomoo`0:Ool00`00
Oomoo`0eOol003Moo`03001oogoo00Yoo`04001oogooOol20004Ool00`00Oomoo`13Ool00`00Oomo
o`09Ool00`00Oomoo`0eOol003Moo`03001oogoo00]oo`03001oogoo00<000=oo`03001oogoo04=o
o`03001oogoo00Qoo`03001oogoo03Ioo`00=goo00<007ooOol037oo00@007oo000000=oo`03001o
ogoo04Eoo`03001oogoo00Ioo`03001oogoo03Moo`00>7oo00<007ooOol02goo00@007oo0000009o
o`03001oogoo04Ioo`03001oogoo00Eoo`03001oogoo03Qoo`00>7oo00<007ooOol02goo10000Woo
00<007ooOol0Agoo00<007ooOol00goo00<007ooOol0>Goo000hOol00`00Oomoo`0<Ool60019Ool0
0`00Oomoo`02Ool00`00Oomoo`0jOol003Qoo`03001oogoo00eoo`<004aoo`@003eoo`00>Goo00<0
07ooOol037oo0P00SWoo000iOol00`00Oomoo`0<Ool2002>Ool003Uoo`03001oogoo00]oo`03001o
o`0008ioo`00>Goo00<007ooOol02goo00@007oo000008eoo`00>Goo00<007ooOol02goo00<007oo
0000SWoo000jOol00`00Oomoo`0:Ool00`00Ool0002>Ool003Yoo`03001oogoo00Moo`@00003Ool0
07oo08eoo`00>Woo00<007ooOol027oo00D007oo001oo`0008ioo`00>Woo00<007ooOol01Woo1@00
00Aoo`00000008aoo`00>goo00<007ooOol01Goo00L007oo001oo`00Ool0002>Ool003]oo`03001o
ogoo00Ioo`800004Ool007oo002>Ool003]oo`03001oogoo00Moo`05001oo`00Ool0002>Ool003]o
o`03001oogoo00Uoo`04001oo`00002=Ool003]oo`03001oogoo00Uoo`03001oo`0008ioo`00?7oo
00<007ooOol01goo00@007ooOol008ioo`00?7oo00<007ooOol01goo00@007ooOol008ioo`00?7oo
00<007ooOol01goo00@007ooOol008ioo`00?7oo00<007ooOol01goo00<007ooOol00P00SGoo000m
Ool00`00Oomoo`06Ool01000Oomoo`00SWoo000mOol00`00Oomoo`06Ool01000Oomoo`00SWoo000m
Ool00`00Oomoo`06Ool01000Oomoo`00SWoo000nOol00`00Oomoo`05Ool00`00Oomoo`02002=Ool0
03ioo`03001oogoo00Eoo`04001oogoo002>Ool003ioo`03001oogoo00Eoo`04001oogoo002>Ool0
03ioo`03001oogoo009oo`<000=oo`03001oogoo08aoo`00?goo00L007ooOomoo`00Ool00003Ool0
0`00Oomoo`2<Ool003moo`07001oogooOol007oo00000goo0`00S7oo000oOol01000Oomoogoo0`00
0goo00<007ooOol0S7oo0010Ool01P00Oomoo`00Ool000=oo`03001oogoo08aoo`00@7oo00@007oo
Oomoo`8000=oo`03001oogoo08aoo`00@7oo00D007ooOomoo`0000Aoo`8008eoo`00@7oo00D007oo
Oomoo`0000Aoo`03001oogoo08aoo`00@Goo00@007ooOol000Aoo`03001oogoo08aoo`00@Goo00<0
07oo00001Goo00<007ooOol0S7oo0011Ool30005Ool00`00Oomoo`2<Ool004Uoo`8008eoo`00BGoo
00<007ooOol0S7oo0019Ool00`00Oomoo`2<Ool00001\
\>"],
  ImageRangeCache->{{{0, 215}, {132.438, 0}} -> {-2.17659, -7.30748, 
  0.0294261, 0.110123}}]
}, Open  ]],

Cell["\<\
The zero-crossings are positioned at the center of our simulated edges. More \
interestingly, the zero-crossing positions are independent of the steepness \
of the edge. This is in contrast to local maxima of first derivatives which \
clearly depend on edge slope.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Laplacian in two-dimensions.", "Subsubsection"],

Cell["\<\
In image processing, the interest is of course in the Laplacian of \
two-dimensional signals. Here we will explore the response of the Laplacian \
derivative operator on a continuous \"box\" function modeled using hyperbolic \
tangents. \
\>", "Text"],

Cell[BoxData[
    \(\(f[x_, y_] := 
      \((Tanh[3 - x] + Tanh[3 + x])\)\ \((Tanh[3 - y] + Tanh[3 + y])\); 
    \)\)], "Input"],

Cell["Directly from (1), we get", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[Del]2 = 
      \[PartialD]\_{x, 2}\ f[x, y]\  + \ \[PartialD]\_{y, 2}\ f[x, y]\)], 
  "Input"],

Cell[BoxData[
    \(\((\(-2\)\ Sech[3 - x]\^2\ Tanh[3 - x] - 2\ Sech[3 + x]\^2\ Tanh[3 + x])
          \)\ \((Tanh[3 - y] + Tanh[3 + y])\) + 
      \((Tanh[3 - x] + Tanh[3 + x])\)\ 
        \((\(-2\)\ Sech[3 - y]\^2\ Tanh[3 - y] - 
            2\ Sech[3 + y]\^2\ Tanh[3 + y])\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[
      GraphicsArray[
        \(DensityPlot[#1, {x, \(-6\), 6}, {y, \(-6\), 6}, Mesh \[Rule] False, 
              DisplayFunction \[Rule] Identity]\ &\)\ /@
          \ {f[x, y], \[Del]2}]]; \)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .47619 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0113379 0.47619 [
[ 0 0 0 0 ]
[ 1 .47619 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .47619 L
0 .47619 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0113379 0.477324 0.464853 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0801282 0.5 0.0801282 [
[.01923 -0.0125 -6 -9 ]
[.01923 -0.0125 6 0 ]
[.17949 -0.0125 -6 -9 ]
[.17949 -0.0125 6 0 ]
[.33974 -0.0125 -6 -9 ]
[.33974 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.66026 -0.0125 -3 -9 ]
[.66026 -0.0125 3 0 ]
[.82051 -0.0125 -3 -9 ]
[.82051 -0.0125 3 0 ]
[.98077 -0.0125 -3 -9 ]
[.98077 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01923 -12 -4.5 ]
[-0.0125 .01923 0 4.5 ]
[-0.0125 .17949 -12 -4.5 ]
[-0.0125 .17949 0 4.5 ]
[-0.0125 .33974 -12 -4.5 ]
[-0.0125 .33974 0 4.5 ]
[-0.0125 .5 -6 -4.5 ]
[-0.0125 .5 0 4.5 ]
[-0.0125 .66026 -6 -4.5 ]
[-0.0125 .66026 0 4.5 ]
[-0.0125 .82051 -6 -4.5 ]
[-0.0125 .82051 0 4.5 ]
[-0.0125 .98077 -6 -4.5 ]
[-0.0125 .98077 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.01923 0 m
.01923 .00625 L
s
[(-6)] .01923 -0.0125 0 1 Mshowa
.17949 0 m
.17949 .00625 L
s
[(-4)] .17949 -0.0125 0 1 Mshowa
.33974 0 m
.33974 .00625 L
s
[(-2)] .33974 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.66026 0 m
.66026 .00625 L
s
[(2)] .66026 -0.0125 0 1 Mshowa
.82051 0 m
.82051 .00625 L
s
[(4)] .82051 -0.0125 0 1 Mshowa
.98077 0 m
.98077 .00625 L
s
[(6)] .98077 -0.0125 0 1 Mshowa
.125 Mabswid
.05929 0 m
.05929 .00375 L
s
.09936 0 m
.09936 .00375 L
s
.13942 0 m
.13942 .00375 L
s
.21955 0 m
.21955 .00375 L
s
.25962 0 m
.25962 .00375 L
s
.29968 0 m
.29968 .00375 L
s
.37981 0 m
.37981 .00375 L
s
.41987 0 m
.41987 .00375 L
s
.45994 0 m
.45994 .00375 L
s
.54006 0 m
.54006 .00375 L
s
.58013 0 m
.58013 .00375 L
s
.62019 0 m
.62019 .00375 L
s
.70032 0 m
.70032 .00375 L
s
.74038 0 m
.74038 .00375 L
s
.78045 0 m
.78045 .00375 L
s
.86058 0 m
.86058 .00375 L
s
.90064 0 m
.90064 .00375 L
s
.94071 0 m
.94071 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01923 m
.00625 .01923 L
s
[(-6)] -0.0125 .01923 1 0 Mshowa
0 .17949 m
.00625 .17949 L
s
[(-4)] -0.0125 .17949 1 0 Mshowa
0 .33974 m
.00625 .33974 L
s
[(-2)] -0.0125 .33974 1 0 Mshowa
0 .5 m
.00625 .5 L
s
[(0)] -0.0125 .5 1 0 Mshowa
0 .66026 m
.00625 .66026 L
s
[(2)] -0.0125 .66026 1 0 Mshowa
0 .82051 m
.00625 .82051 L
s
[(4)] -0.0125 .82051 1 0 Mshowa
0 .98077 m
.00625 .98077 L
s
[(6)] -0.0125 .98077 1 0 Mshowa
.125 Mabswid
0 .05929 m
.00375 .05929 L
s
0 .09936 m
.00375 .09936 L
s
0 .13942 m
.00375 .13942 L
s
0 .21955 m
.00375 .21955 L
s
0 .25962 m
.00375 .25962 L
s
0 .29968 m
.00375 .29968 L
s
0 .37981 m
.00375 .37981 L
s
0 .41987 m
.00375 .41987 L
s
0 .45994 m
.00375 .45994 L
s
0 .54006 m
.00375 .54006 L
s
0 .58013 m
.00375 .58013 L
s
0 .62019 m
.00375 .62019 L
s
0 .70032 m
.00375 .70032 L
s
0 .74038 m
.00375 .74038 L
s
0 .78045 m
.00375 .78045 L
s
0 .86058 m
.00375 .86058 L
s
0 .90064 m
.00375 .90064 L
s
0 .94071 m
.00375 .94071 L
s
.25 Mabswid
0 0 m
0 1 L
s
.01923 .99375 m
.01923 1 L
s
.17949 .99375 m
.17949 1 L
s
.33974 .99375 m
.33974 1 L
s
.5 .99375 m
.5 1 L
s
.66026 .99375 m
.66026 1 L
s
.82051 .99375 m
.82051 1 L
s
.98077 .99375 m
.98077 1 L
s
.125 Mabswid
.05929 .99625 m
.05929 1 L
s
.09936 .99625 m
.09936 1 L
s
.13942 .99625 m
.13942 1 L
s
.21955 .99625 m
.21955 1 L
s
.25962 .99625 m
.25962 1 L
s
.29968 .99625 m
.29968 1 L
s
.37981 .99625 m
.37981 1 L
s
.41987 .99625 m
.41987 1 L
s
.45994 .99625 m
.45994 1 L
s
.54006 .99625 m
.54006 1 L
s
.58013 .99625 m
.58013 1 L
s
.62019 .99625 m
.62019 1 L
s
.70032 .99625 m
.70032 1 L
s
.74038 .99625 m
.74038 1 L
s
.78045 .99625 m
.78045 1 L
s
.86058 .99625 m
.86058 1 L
s
.90064 .99625 m
.90064 1 L
s
.94071 .99625 m
.94071 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .01923 m
1 .01923 L
s
.99375 .17949 m
1 .17949 L
s
.99375 .33974 m
1 .33974 L
s
.99375 .5 m
1 .5 L
s
.99375 .66026 m
1 .66026 L
s
.99375 .82051 m
1 .82051 L
s
.99375 .98077 m
1 .98077 L
s
.125 Mabswid
.99625 .05929 m
1 .05929 L
s
.99625 .09936 m
1 .09936 L
s
.99625 .13942 m
1 .13942 L
s
.99625 .21955 m
1 .21955 L
s
.99625 .25962 m
1 .25962 L
s
.99625 .29968 m
1 .29968 L
s
.99625 .37981 m
1 .37981 L
s
.99625 .41987 m
1 .41987 L
s
.99625 .45994 m
1 .45994 L
s
.99625 .54006 m
1 .54006 L
s
.99625 .58013 m
1 .58013 L
s
.99625 .62019 m
1 .62019 L
s
.99625 .70032 m
1 .70032 L
s
.99625 .74038 m
1 .74038 L
s
.99625 .78045 m
1 .78045 L
s
.99625 .86058 m
1 .86058 L
s
.99625 .90064 m
1 .90064 L
s
.99625 .94071 m
1 .94071 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
15 string
15 15 8 [15 0 0 15 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
000000000000000000000000000000
000000010203030303030201000000
000001050C11121212110C05010000
0001051636474B4C4B473616050100
00020C367FA8B2B4B2A87F360C0200
00031147A8DFECEEECDFA847110300
0003124BB2ECFBFDFBECB24B120300
0003124CB4EEFDFFFDEEB44C120300
0003124BB2ECFBFDFBECB24B120300
00031147A8DFECEEECDFA847110300
00020C367FA8B2B4B2A87F360C0200
0001051636474B4C4B473616050100
000001050C11121212110C05010000
000000010203030303030201000000
000000000000000000000000000000
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0113379 0.97619 0.464853 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0801282 0.5 0.0801282 [
[.01923 -0.0125 -6 -9 ]
[.01923 -0.0125 6 0 ]
[.17949 -0.0125 -6 -9 ]
[.17949 -0.0125 6 0 ]
[.33974 -0.0125 -6 -9 ]
[.33974 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.66026 -0.0125 -3 -9 ]
[.66026 -0.0125 3 0 ]
[.82051 -0.0125 -3 -9 ]
[.82051 -0.0125 3 0 ]
[.98077 -0.0125 -3 -9 ]
[.98077 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01923 -12 -4.5 ]
[-0.0125 .01923 0 4.5 ]
[-0.0125 .17949 -12 -4.5 ]
[-0.0125 .17949 0 4.5 ]
[-0.0125 .33974 -12 -4.5 ]
[-0.0125 .33974 0 4.5 ]
[-0.0125 .5 -6 -4.5 ]
[-0.0125 .5 0 4.5 ]
[-0.0125 .66026 -6 -4.5 ]
[-0.0125 .66026 0 4.5 ]
[-0.0125 .82051 -6 -4.5 ]
[-0.0125 .82051 0 4.5 ]
[-0.0125 .98077 -6 -4.5 ]
[-0.0125 .98077 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.01923 0 m
.01923 .00625 L
s
[(-6)] .01923 -0.0125 0 1 Mshowa
.17949 0 m
.17949 .00625 L
s
[(-4)] .17949 -0.0125 0 1 Mshowa
.33974 0 m
.33974 .00625 L
s
[(-2)] .33974 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.66026 0 m
.66026 .00625 L
s
[(2)] .66026 -0.0125 0 1 Mshowa
.82051 0 m
.82051 .00625 L
s
[(4)] .82051 -0.0125 0 1 Mshowa
.98077 0 m
.98077 .00625 L
s
[(6)] .98077 -0.0125 0 1 Mshowa
.125 Mabswid
.05929 0 m
.05929 .00375 L
s
.09936 0 m
.09936 .00375 L
s
.13942 0 m
.13942 .00375 L
s
.21955 0 m
.21955 .00375 L
s
.25962 0 m
.25962 .00375 L
s
.29968 0 m
.29968 .00375 L
s
.37981 0 m
.37981 .00375 L
s
.41987 0 m
.41987 .00375 L
s
.45994 0 m
.45994 .00375 L
s
.54006 0 m
.54006 .00375 L
s
.58013 0 m
.58013 .00375 L
s
.62019 0 m
.62019 .00375 L
s
.70032 0 m
.70032 .00375 L
s
.74038 0 m
.74038 .00375 L
s
.78045 0 m
.78045 .00375 L
s
.86058 0 m
.86058 .00375 L
s
.90064 0 m
.90064 .00375 L
s
.94071 0 m
.94071 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01923 m
.00625 .01923 L
s
[(-6)] -0.0125 .01923 1 0 Mshowa
0 .17949 m
.00625 .17949 L
s
[(-4)] -0.0125 .17949 1 0 Mshowa
0 .33974 m
.00625 .33974 L
s
[(-2)] -0.0125 .33974 1 0 Mshowa
0 .5 m
.00625 .5 L
s
[(0)] -0.0125 .5 1 0 Mshowa
0 .66026 m
.00625 .66026 L
s
[(2)] -0.0125 .66026 1 0 Mshowa
0 .82051 m
.00625 .82051 L
s
[(4)] -0.0125 .82051 1 0 Mshowa
0 .98077 m
.00625 .98077 L
s
[(6)] -0.0125 .98077 1 0 Mshowa
.125 Mabswid
0 .05929 m
.00375 .05929 L
s
0 .09936 m
.00375 .09936 L
s
0 .13942 m
.00375 .13942 L
s
0 .21955 m
.00375 .21955 L
s
0 .25962 m
.00375 .25962 L
s
0 .29968 m
.00375 .29968 L
s
0 .37981 m
.00375 .37981 L
s
0 .41987 m
.00375 .41987 L
s
0 .45994 m
.00375 .45994 L
s
0 .54006 m
.00375 .54006 L
s
0 .58013 m
.00375 .58013 L
s
0 .62019 m
.00375 .62019 L
s
0 .70032 m
.00375 .70032 L
s
0 .74038 m
.00375 .74038 L
s
0 .78045 m
.00375 .78045 L
s
0 .86058 m
.00375 .86058 L
s
0 .90064 m
.00375 .90064 L
s
0 .94071 m
.00375 .94071 L
s
.25 Mabswid
0 0 m
0 1 L
s
.01923 .99375 m
.01923 1 L
s
.17949 .99375 m
.17949 1 L
s
.33974 .99375 m
.33974 1 L
s
.5 .99375 m
.5 1 L
s
.66026 .99375 m
.66026 1 L
s
.82051 .99375 m
.82051 1 L
s
.98077 .99375 m
.98077 1 L
s
.125 Mabswid
.05929 .99625 m
.05929 1 L
s
.09936 .99625 m
.09936 1 L
s
.13942 .99625 m
.13942 1 L
s
.21955 .99625 m
.21955 1 L
s
.25962 .99625 m
.25962 1 L
s
.29968 .99625 m
.29968 1 L
s
.37981 .99625 m
.37981 1 L
s
.41987 .99625 m
.41987 1 L
s
.45994 .99625 m
.45994 1 L
s
.54006 .99625 m
.54006 1 L
s
.58013 .99625 m
.58013 1 L
s
.62019 .99625 m
.62019 1 L
s
.70032 .99625 m
.70032 1 L
s
.74038 .99625 m
.74038 1 L
s
.78045 .99625 m
.78045 1 L
s
.86058 .99625 m
.86058 1 L
s
.90064 .99625 m
.90064 1 L
s
.94071 .99625 m
.94071 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .01923 m
1 .01923 L
s
.99375 .17949 m
1 .17949 L
s
.99375 .33974 m
1 .33974 L
s
.99375 .5 m
1 .5 L
s
.99375 .66026 m
1 .66026 L
s
.99375 .82051 m
1 .82051 L
s
.99375 .98077 m
1 .98077 L
s
.125 Mabswid
.99625 .05929 m
1 .05929 L
s
.99625 .09936 m
1 .09936 L
s
.99625 .13942 m
1 .13942 L
s
.99625 .21955 m
1 .21955 L
s
.99625 .25962 m
1 .25962 L
s
.99625 .29968 m
1 .29968 L
s
.99625 .37981 m
1 .37981 L
s
.99625 .41987 m
1 .41987 L
s
.99625 .45994 m
1 .45994 L
s
.99625 .54006 m
1 .54006 L
s
.99625 .58013 m
1 .58013 L
s
.99625 .62019 m
1 .62019 L
s
.99625 .70032 m
1 .70032 L
s
.99625 .74038 m
1 .74038 L
s
.99625 .78045 m
1 .78045 L
s
.99625 .86058 m
1 .86058 L
s
.99625 .90064 m
1 .90064 L
s
.99625 .94071 m
1 .94071 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
15 string
15 15 8 [15 0 0 15 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
969797989899999A99999898979796
9797999DA1A5A7A7A7A5A19D999797
9799A1B3C1D4DCDEDCD4C1B3A19997
989DB3D6C2E5FBFFFBE5C2D6B39D98
98A1C1C200002027200000C2C1A198
99A5D4E500113F493F1100E5D4A599
99A7DCFB203F757F753F20FBDCA799
9AA7DEFF27497F8A7F4927FFDEA79A
99A7DCFB203F757F753F20FBDCA799
99A5D4E500113F493F1100E5D4A599
98A1C1C200002027200000C2C1A198
989DB3D6C2E5FBFFFBE5C2D6B39D98
9799A1B3C1D4DCDEDCD4C1B3A19997
9797999DA1A5A7A7A7A5A19D999797
969797989899999A99999898979796
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 137.125},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000RA000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol001Qoo`80015oo`<000moo`<000ioo`03001oogoo00io
o`<0015oo`<000ioo`80021oo`80019oo`<000ioo`<000ioo`03001oogoo00moo`<0011oo`<000mo
o`8000]oo`0067oo00<007oo00004Goo00<007ooOol03Woo00<007ooOol03Goo00<007oo00003goo
00<007ooOol04Woo00<007ooOol03Goo00<007oo00007goo00<007oo00004Woo00<007ooOol03Goo
00<007ooOol03Goo00<007oo000047oo00<007ooOol04Goo00<007ooOol03Woo00<007oo00002Woo
000COol30002Ool00`00Ool0000:Ool30002Ool4000:Ool30003Ool00`00Oomoo`0<Ool00`00Ool0
000@Ool00`00Oomoo`0?Ool4000>Ool00`00Ool0000JOol30002Ool00`00Ool0000;Ool30002Ool4
0009Ool30003Ool00`00Oomoo`0<Ool00`00Ool0000AOol00`00Oomoo`0>Ool4000?Ool00`00Ool0
000:Ool001Qoo`80011oo`03001oo`00015oo`03001oogoo00aoo`03001oo`00011oo`03001oogoo
00moo`03001oo`0000moo`80021oo`80015oo`03001oo`00011oo`03001oogoo00aoo`03001oo`00
015oo`03001oogoo00ioo`03001oo`00011oo`8000]oo`0067oo00<007ooOol047oo0P0047oo00<0
07oo00003Goo00<007oo00003goo00<007oo00004Goo0P003goo00<007ooOol07goo00<007ooOol0
4Goo0P003goo00<007oo00003Goo00<007oo000047oo00<007oo000047oo0P0047oo00<007ooOol0
2Woo000IOol2000AOol00`00Oomoo`0?Ool00`00Oomoo`0=Ool00`00Oomoo`0?Ool00`00Oomoo`0A
Ool00`00Oomoo`0>Ool2000POol2000BOol00`00Oomoo`0>Ool00`00Oomoo`0=Ool00`00Oomoo`0@
Ool00`00Oomoo`0@Ool00`00Oomoo`0?Ool2000:Ool00?moob5oo`00ogoo8Goo003oOolQOol00?mo
ob5oo`003goo0P000gooM@0057oo0P0017ooM0002Goo000?Ool00`00Ool00002Ool01000Oomoo`00
4Goo00<007ooOol047oo00<007ooOol03goo00<007ooOol047oo00<007ooOol03goo00<007ooOol0
47oo00<007oo000057oo00<007oo00000goo00<007oo00004Woo00<007ooOol03goo00<007ooOol0
47oo00<007ooOol03goo00<007ooOol047oo00<007ooOol03goo00<007oo00002Goo000:Ool30002
Ool00`00Ool00002Ool2001aOol2000?Ool30002Ool00`00Ool00003Ool2001aOol00`00Oomoo`07
Ool000moo`8000=oo`03001oogoo06l0009oo`03001oogoo019oo`8000Aoo`03001oodYB01E:DT=>
LaI:DP9oo`03001oogoo00Moo`003goo00<007ooOol00Woo00<007ooOol0K`000Woo00<007ooOol0
4Woo00<007ooOol00goo00<007ooBU805DYB@dic5TYB0Woo00<007ooOol01goo000@Ool20002Ool0
0`00Oomoo`1_0002Ool00`00Oomoo`0COol20003Ool00`00Oom:DP0EBU93CW<FBU82Ool00`00Oomo
o`07Ool001Aoo`03001oogoo06l0009oo`03001oogoo01Qoo`03001oodYB01E:DT=>LaI:DP9oo`03
001oogoo00Moo`0057oo0P0000=oo`000000K@0000=oo`0000006Woo00<007ooBU805DYB@dic5TYB
0Woo00<007ooOol01goo000DOol00`00Oomoo`1_0002Ool00`00Oomoo`0HOol00`00Oom:DP0EBU93
CW<FBU82Ool00`00Oomoo`07Ool001Aoo`03001oogoo06l0009oo`03001oogoo01Qoo`03001oodYB
01E:DT=>LaI:DP9oo`03001oogoo00Moo`0057oo00<007ooOol0K`000Woo00<007ooOol067oo00<0
07ooBU803TYB3dic<e:D3dic3dYB0Woo00<007ooOol01goo000DOol200000goo0000001]00000goo
0000000JOol00`00Oom:DP0>BU8?CW<cDY@?CW<?BU82Ool00`00Oomoo`07Ool001Aoo`03001oogoo
06l0009oo`03001oogoo01Qoo`03001oodYB00i:DPm>Lc=BU0m>L`m:DP9oo`03001oogoo00Moo`00
57oo00<007ooOol0K`000Woo00<007ooOol067oo00<007ooBU803TYB3dic<e:D3dic3dYB0Woo00<0
07ooOol01goo000DOol00`00Oomoo`1_0002Ool00`00Oomoo`0HOol00`00Oom:DP0>BU8?CW<cDY@?
CW<?BU82Ool00`00Oomoo`07Ool001Aoo`03001oogoo06l0009oo`03001oogoo01Qoo`03001oodYB
00i:DPm>Lc=BU0m>L`m:DP9oo`03001oogoo00Moo`0057oo0P0000=oo`000000K@0000=oo`000000
6Woo00<007ooBU803TYB3dic<e:D3dic3dYB0Woo00<007ooOol01goo000DOol00`00Oomoo`1_0002
Ool00`00Oomoo`0HOol00`00Oom:DP0>BU8?CW<cDY@?CW<?BU82Ool00`00Oomoo`07Ool001Aoo`03
001oogoo01h000L48BD8@PL48Ah0009oo`03001oogoo01Qoo`03001oodYB00I:DPQ>L`MBU0QJePMS
60M[FQM_N`M[FPMS60QJePMBU0Q>L`M:DP9oo`03001oogoo00Moo`0047oo0`0000Aoo`00Oomooah0
00L48BD8@PL48Ah0009oo`03001oogoo01=oo`<0009oo`03001oodYB00I:DPQ>L`MBU0QJePMS60M[
FQM_N`M[FPMS60QJePMBU0Q>L`M:DP9oo`03001oogoo00Moo`004Goo00@007ooOol0009ooah000L4
8BD8@PL48Ah0009oo`03001oogoo01Aoo`06001oogooOol007oo1dYB24ic1e:D25[F1f<H1f]J5fmk
1f]J1f<H25[F1e:D24ic1dYB0Woo00<007ooOol01goo000:Ool30002Ool4000017oo000007oo7P00
1`@Q9@Q21`@Q7P0000=oo`0000003goo0`000Woo10000Woo0P001dYB24ic1e:D25[F1f<H1f]J5fmk
1f]J1f<H25[F1e:D24ic1dYB0Woo00<007ooOol01goo000?Ool00`00Ool00002Ool00`00Oomoo`0N
0007124U2487124N0002Ool00`00Oomoo`0BOol00`00Ool00003Ool00`00Oom:DP06BU88CW<7DY@8
F]H7HaP7JeXGKg/7JeX7HaP8F]H7DY@8CW<7BU82Ool00`00Oomoo`07Ool0011oo`80009oo`03001o
ogoo01h000L48BD8@PL48Ah0009oo`03001oogoo01=oo`8000=oo`03001oodYB00I:DPQ>L`MBU0QJ
ePMS60M[FQM_N`M[FPMS60QJePMBU0Q>L`M:DP9oo`03001oogoo00Moo`004Goo00@007ooOol0009o
oah000L48BD8@PL48Ah0009oo`03001oogoo01Aoo`06001oogooOol007oo1dYB24ic1e:D25[F1f<H
1f]J5fmk1f]J1f<H25[F1e:D24ic1dYB0Woo00<007ooOol01goo000DOol200000goo0000000D0008
24876<H78@PG9BT78@P76<H8248F00000goo0000000JOol00`00Oom>L`0>CW<7F]H8JeX7HaP7Li`G
Ool7Li`7HaP8JeX7F]H?CW<2Ool00`00Oomoo`07Ool001Aoo`03001oogoo01H000P8@PLHaPLQ21LU
:@LQ20LHaPP8@QH0009oo`03001oogoo01Qoo`03001oodic00i>L`MJePQ[FPMS60McW1Moo`McW0MS
60Q[FPMJePm>L`9oo`03001oogoo00Moo`0057oo00<007ooOol05P0020Q21aS61b485bDY1b481aS6
20Q25P000Woo00<007ooOol067oo00<007ooCW<03Tic1e[F26]J1f<H1g>L5goo1g>L1f<H26]J1e[F
3dic0Woo00<007ooOol01goo000DOol00`00Oomoo`0F000824876<H78@PG9BT78@P76<H8248F0002
Ool00`00Oomoo`0HOol00`00Oom>L`0>CW<7F]H8JeX7HaP7Li`GOol7Li`7HaP8JeX7F]H?CW<2Ool0
0`00Oomoo`07Ool001Aoo`03001oogoo01H000P8@PLHaPLQ21LU:@LQ20LHaPP8@QH0009oo`03001o
ogoo01Qoo`03001oodic00i>L`MJePQ[FPMS60McW1Moo`McW0MS60Q[FPMJePm>L`9oo`03001oogoo
00Moo`0057oo0P0000=oo`000000500020Q21aS61b485bDY1b481aS620Q25P0000=oo`0000006Woo
00<007ooCW<03Tic1e[F26]J1f<H1g>L5goo1g>L1f<H26]J1e[F3dic0Woo00<007ooOol01goo000D
Ool00`00Oomoo`0F000824876<H78@PG9BT78@P76<H8248F0002Ool00`00Oomoo`0HOol00`00Oom>
L`0>CW<7F]H8JeX7HaP7Li`GOol7Li`7HaP8JeX7F]H?CW<2Ool00`00Oomoo`07Ool001Aoo`03001o
ogoo01H000P8@PLHaPLQ21LU:@LQ20LHaPP8@QH0009oo`03001oogoo01Qoo`03001oodic00i>L`MJ
ePQ[FPMS60McW1Moo`McW0MS60Q[FPMJePm>L`9oo`03001oogoo00Moo`0057oo00<007ooOol03`00
1`@Q21S61cg_1eJe5e[F1eJe1cg_21S61`@Q3`000Woo00<007ooOol067oo00<007ooCW<01Tic25:D
3f<H3P005a243P003f<H25:D1dic0Woo00<007ooOol01goo000DOol200000goo0000000=00071248
6<H7?Nl7E[DGF]H7E[D7?Nl86<H7124?00000goo0000000JOol00`00Oom>L`06CW<8DY@?HaP>000G
48@>000?HaP8DY@7CW<2Ool00`00Oomoo`07Ool001Aoo`03001oogoo00l000L48@PHaPLmk`MF]AMJ
ePMF]@Lmk`PHaPL48@l0009oo`03001oogoo01Qoo`03001oodic00I>L`QBU0mS60h001L@Q0h000mS
60QBU0M>L`9oo`03001oogoo00Moo`0057oo00<007ooOol03`001`@Q21S61cg_1eJe5e[F1eJe1cg_
21S61`@Q3`000Woo00<007ooOol067oo00<007ooCW<01Tic25:D3f<H3P005a243P003f<H25:D1dic
0Woo00<007ooOol01goo000?Ool30002Ool00`00Oomoo`0?000712486<H7?Nl7E[DGF]H7E[D7?Nl8
6<H7124?0002Ool00`00Oomoo`0BOol30003Ool00`00Oom>L`06CW<8DY@?HaP>000G48@>000?HaP8
DY@7CW<2Ool00`00Oomoo`07Ool000moo`03001oogoo009oo`03001oogoo00l000L48@PHaPLmk`MF
]AMJePMF]@Lmk`PHaPL48@l0009oo`03001oogoo019oo`03001oogoo00=oo`03001oodic00I>L`QB
U0mS60h001L@Q0h000mS60QBU0M>L`9oo`03001oogoo00Moo`002Woo0`000goo00@007ooOomoo`80
0003Ool0000000d000L48@PHaPLmk`MF]AMJePMF]@Lmk`PHaPL48@l00003Ool0000000moo`<000=o
o`03001oogoo009oo`8000M>L`QBU0mS60h001L@Q0h000mS60QBU0M>L`9oo`03001oogoo00Moo`00
47oo00D007ooOomoo`00009oo`l000L8@PPQ20MF]@M_NaMg_@M_N`MF]@PQ20L8@Pl0009oo`03001o
ogoo01=oo`03001oogoo009oo`03001oodic00I>L`QBU0M[FPQcW0L000L8@PPLi`LU:@PLi`L8@PL0
00QcW0M[FPQBU0M>L`9oo`03001oogoo00Moo`003goo00<007oo00000Woo00<007ooOol03`001`Q2
22481eJe1fmk5gNm1fmk1eJe22481`Q23`000Woo00<007ooOol04Woo00<007oo00000goo00<007oo
CW<01Tic25:D1f]J27>L1`001`Q221cW1bDY21cW1`Q21`0027>L1f]J25:D1dic0Woo00<007ooOol0
1goo000@Ool01@00Oomoogoo00000Woo3`001`Q222481eJe1fmk5gNm1fmk1eJe22481`Q23`000Woo
00<007ooOol04goo00<007ooOol00Woo00<007ooCW<01Tic25:D1f]J27>L1`001`Q221cW1bDY21cW
1`Q21`0027>L1f]J25:D1dic0Woo00<007ooOol01goo000DOol00`00Oomoo`0?000724888@P7E[D7
Kg/GMkd7Kg/7E[D88@P7248?0002Ool00`00Oomoo`0HOol00`00Oom>L`06CW<8DY@7JeX8Li`70007
24887>L79BT87>L724870008Li`7JeX8DY@7CW<2Ool00`00Oomoo`07Ool001Aoo`800003Ool00000
00d000L8@PPQ20MF]@M_NaMg_@M_N`MF]@PQ20L8@Pl00003Ool0000001Yoo`03001oodic00I>L`QB
U0M[FPQcW0L000L8@PPLi`LU:@PLi`L8@PL000QcW0M[FPQBU0M>L`9oo`03001oogoo00Moo`0057oo
00<007ooOol03`001`Q222481eJe1fmk5gNm1fmk1eJe22481`Q23`000Woo00<007ooOol067oo00<0
07ooCW<01Tic25:D1f]J27>L1`001`Q221cW1bDY21cW1`Q21`0027>L1f]J25:D1dic0Woo00<007oo
Ool01goo000DOol00`00Oomoo`0?000724888@P7E[D7Kg/GMkd7Kg/7E[D88@P7248?0002Ool00`00
Oomoo`0HOol00`00Oom>L`06CW<8DY@7JeX8Li`7000724887>L79BT87>L724870008Li`7JeX8DY@7
CW<2Ool00`00Oomoo`07Ool001Aoo`03001oogoo00l000L8@PPU:@MJePMg_AMoo`Mg_@MJePPU:@L8
@Pl0009oo`03001oogoo01Qoo`03001oodic00I>L`QBU0M_N`Qoo`L@Q0LLi`PicPLmk`PicPLLi`L@
Q0Qoo`M_N`QBU0M>L`9oo`03001oogoo00Moo`0057oo0P0000=oo`0000003@001`Q222DY1e[F1gNm
5goo1gNm1e[F22DY1`Q23`0000=oo`0000006Woo00<007ooCW<01Tic25:D1fmk27oo1a241acW23W>
1cg_23W>1acW1a2427oo1fmk25:D1dic0Woo00<007ooOol01goo000DOol00`00Oomoo`0?00072488
9BT7F]H7MkdGOol7Mkd7F]H89BT7248?0002Ool00`00Oomoo`0HOol00`00Oom>L`06CW<8DY@7Kg/8
Ool748@77>L8>Lh7?Nl8>Lh77>L748@8Ool7Kg/8DY@7CW<2Ool00`00Oomoo`07Ool001Aoo`03001o
ogoo00l000L8@PPU:@MJePMg_AMoo`Mg_@MJePPU:@L8@Pl0009oo`03001oogoo01Qoo`03001oodic
00I>L`QBU0M_N`Qoo`L@Q0LLi`PicPLmk`PicPLLi`L@Q0Qoo`M_N`QBU0M>L`9oo`03001oogoo00Mo
o`0057oo00<007ooOol03`001`Q222DY1e[F1gNm5goo1gNm1e[F22DY1`Q23`000Woo00<007ooOol0
67oo00<007ooCW<01Tic25:D1fmk27oo1a241acW23W>1cg_23W>1acW1a2427oo1fmk25:D1dic0Woo
00<007ooOol01goo000DOol00`00Oomoo`0?000724889BT7F]H7MkdGOol7Mkd7F]H89BT7248?0002
Ool00`00Oomoo`0HOol00`00Oom>L`06CW<8DY@7Kg/8Ool748@77>L8>Lh7?Nl8>Lh77>L748@8Ool7
Kg/8DY@7CW<2Ool00`00Oomoo`07Ool001Aoo`800003Ool0000000d000L8@PPU:@MJePMg_AMoo`Mg
_@MJePPU:@L8@Pl00003Ool0000001Yoo`03001oodic00I>L`QBU0M_N`Qoo`L@Q0LLi`PicPLmk`Pi
cPLLi`L@Q0Qoo`M_N`QBU0M>L`9oo`03001oogoo00Moo`0057oo00<007ooOol03`001`Q222DY1e[F
1gNm5goo1gNm1e[F22DY1`Q23`000Woo00<007ooOol067oo00<007ooCW<01Tic25:D1fmk27oo1a24
1acW23W>1cg_23W>1acW1a2427oo1fmk25:D1dic0Woo00<007ooOol01goo000DOol00`00Oomoo`0?
000724889BT7F]H7MkdGOol7Mkd7F]H89BT7248?0002Ool00`00Oomoo`0HOol00`00Oom>L`06CW<8
DY@7Kg/8Ool748@79BT8?Nl7AS48?Nl79BT748@8Ool7Kg/8DY@7CW<2Ool00`00Oomoo`07Ool0011o
o`05001oogooOol00002Ool?000724889BT7F]H7MkdGOol7Mkd7F]H89BT7248?0002Ool00`00Oomo
o`0COol00`00Oomoo`02Ool00`00Oom>L`06CW<8DY@7Kg/8Ool748@79BT8?Nl7AS48?Nl79BT748@8
Ool7Kg/8DY@7CW<2Ool00`00Oomoo`07Ool000moo`03001oo`00009oo`03001oogoo00l000L8@PPU
:@MJePMg_AMoo`Mg_@MJePPU:@L8@Pl0009oo`03001oogoo019oo`03001oo`0000=oo`03001oodic
00I>L`QBU0M_N`Qoo`L@Q0LU:@Pmk`M6<@Pmk`LU:@L@Q0Qoo`M_N`QBU0M>L`9oo`03001oogoo00Mo
o`003goo00<007oo00000Woo0P0000=oo`0000003@001`Q222DY1e[F1gNm5goo1gNm1e[F22DY1`Q2
3`0000=oo`00000057oo00<007oo00000goo0P001dic25:D1fmk27oo1a241bDY23g_1dHa23g_1bDY
1a2427oo1fmk25:D1dic0Woo00<007ooOol01goo000?Ool00`00Ool00002Ool00`00Oomoo`0?0007
24889BT7F]H7MkdGOol7Mkd7F]H89BT7248?0002Ool00`00Oomoo`0BOol00`00Ool00003Ool00`00
Oom>L`06CW<8DY@7Kg/8Ool748@79BT8?Nl7AS48?Nl79BT748@8Ool7Kg/8DY@7CW<2Ool00`00Oomo
o`07Ool000moo`03001oo`00009oo`03001oogoo00l000L8@PPU:@MJePMg_AMoo`Mg_@MJePPU:@L8
@Pl0009oo`03001oogoo019oo`03001oo`0000=oo`03001oodic00I>L`QBU0M_N`Qoo`L@Q0LU:@Pm
k`M6<@Pmk`LU:@L@Q0Qoo`M_N`QBU0M>L`9oo`03001oogoo00Moo`0047oo00D007ooOomoo`00009o
o`l000L8@PPU:@MJePMg_AMoo`Mg_@MJePPU:@L8@Pl0009oo`03001oogoo01=oo`03001oogoo009o
o`03001oodic00I>L`QBU0M_N`Qoo`L@Q0LU:@Pmk`M6<@Pmk`LU:@L@Q0Qoo`M_N`QBU0M>L`9oo`03
001oogoo00Moo`0057oo0P0000=oo`0000003@001`Q222DY1e[F1gNm5goo1gNm1e[F22DY1`Q23`00
00=oo`0000006Woo00<007ooCW<01Tic25:D1fmk27oo1a241acW23W>1cg_23W>1acW1a2427oo1fmk
25:D1dic0Woo00<007ooOol01goo000DOol00`00Oomoo`0?000724889BT7F]H7MkdGOol7Mkd7F]H8
9BT7248?0002Ool00`00Oomoo`0HOol00`00Oom>L`06CW<8DY@7Kg/8Ool748@77>L8>Lh7?Nl8>Lh7
7>L748@8Ool7Kg/8DY@7CW<2Ool00`00Oomoo`07Ool001Aoo`03001oogoo00l000L8@PPU:@MJePMg
_AMoo`Mg_@MJePPU:@L8@Pl0009oo`03001oogoo01Qoo`03001oodic00I>L`QBU0M_N`Qoo`L@Q0LL
i`PicPLmk`PicPLLi`L@Q0Qoo`M_N`QBU0M>L`9oo`03001oogoo00Moo`0057oo00<007ooOol03`00
1`Q222DY1e[F1gNm5goo1gNm1e[F22DY1`Q23`000Woo00<007ooOol067oo00<007ooCW<01Tic25:D
1fmk27oo1a241acW23W>1cg_23W>1acW1a2427oo1fmk25:D1dic0Woo00<007ooOol01goo000DOol0
0`00Oomoo`0?000724889BT7F]H7MkdGOol7Mkd7F]H89BT7248?0002Ool00`00Oomoo`0HOol00`00
Oom>L`06CW<8DY@7Kg/8Ool748@77>L8>Lh7?Nl8>Lh77>L748@8Ool7Kg/8DY@7CW<2Ool00`00Oomo
o`07Ool001Aoo`800003Ool0000000d000L8@PPU:@MJePMg_AMoo`Mg_@MJePPU:@L8@Pl00003Ool0
000001Yoo`03001oodic00I>L`QBU0M_N`Qoo`L@Q0LLi`PicPLmk`PicPLLi`L@Q0Qoo`M_N`QBU0M>
L`9oo`03001oogoo00Moo`0057oo00<007ooOol03`001`Q222DY1e[F1gNm5goo1gNm1e[F22DY1`Q2
3`000Woo00<007ooOol067oo00<007ooCW<01Tic25:D1fmk27oo1a241acW23W>1cg_23W>1acW1a24
27oo1fmk25:D1dic0Woo00<007ooOol01goo000DOol00`00Oomoo`0?000724889BT7F]H7MkdGOol7
Mkd7F]H89BT7248?0002Ool00`00Oomoo`0HOol00`00Oom>L`06CW<8DY@7Kg/8Ool748@77>L8>Lh7
?Nl8>Lh77>L748@8Ool7Kg/8DY@7CW<2Ool00`00Oomoo`07Ool001Aoo`03001oogoo00l000L8@PPQ
20MF]@M_NaMg_@M_N`MF]@PQ20L8@Pl0009oo`03001oogoo01Qoo`03001oodic00I>L`QBU0M[FPQc
W0L000L8@PPLi`LU:@PLi`L8@PL000QcW0M[FPQBU0M>L`9oo`03001oogoo00Moo`0057oo0P0000=o
o`0000003@001`Q222481eJe1fmk5gNm1fmk1eJe22481`Q23`0000=oo`0000006Woo00<007ooCW<0
1Tic25:D1f]J27>L1`001`Q221cW1bDY21cW1`Q21`0027>L1f]J25:D1dic0Woo00<007ooOol01goo
000DOol00`00Oomoo`0?000724888@P7E[D7Kg/GMkd7Kg/7E[D88@P7248?0002Ool00`00Oomoo`0H
Ool00`00Oom>L`06CW<8DY@7JeX8Li`7000724887>L79BT87>L724870008Li`7JeX8DY@7CW<2Ool0
0`00Oomoo`07Ool001Aoo`03001oogoo00l000L8@PPQ20MF]@M_NaMg_@M_N`MF]@PQ20L8@Pl0009o
o`03001oogoo01Qoo`03001oodic00I>L`QBU0M[FPQcW0L000L8@PPLi`LU:@PLi`L8@PL000QcW0M[
FPQBU0M>L`9oo`03001oogoo00Moo`003goo0`000Woo00<007ooOol03`001`Q222481eJe1fmk5gNm
1fmk1eJe22481`Q23`000Woo00<007ooOol04Woo0`000goo00<007ooCW<01Tic25:D1f]J27>L1`00
1`Q221cW1bDY21cW1`Q21`0027>L1f]J25:D1dic0Woo00<007ooOol01goo000?Ool00`00Oomoo`02
Ool00`00Oomoo`0?000724888@P7E[D7Kg/GMkd7Kg/7E[D88@P7248?0002Ool00`00Oomoo`0BOol0
0`00Oomoo`03Ool00`00Oom>L`06CW<8DY@7JeX8Li`7000724887>L79BT87>L724870008Li`7JeX8
DY@7CW<2Ool00`00Oomoo`07Ool0011oo`04001oogooOol200000goo0000000=000724888@P7E[D7
Kg/GMkd7Kg/7E[D88@P7248?00000goo0000000EOol00`00Oomoo`02Ool20007CW<8DY@7JeX8Li`7
000724887>L79BT87>L724870008Li`7JeX8DY@7CW<2Ool00`00Oomoo`07Ool0011oo`05001oogoo
Ool00002Ool?000712486<H7?Nl7E[DGF]H7E[D7?Nl86<H7124?0002Ool00`00Oomoo`0COol00`00
Oomoo`02Ool00`00Oom>L`06CW<8DY@?HaP>000G48@>000?HaP8DY@7CW<2Ool00`00Oomoo`07Ool0
00moo`03001oo`00009oo`03001oogoo00l000L48@PHaPLmk`MF]AMJePMF]@Lmk`PHaPL48@l0009o
o`03001oogoo019oo`03001oo`0000=oo`03001oodic00I>L`QBU0mS60h001L@Q0h000mS60QBU0M>
L`9oo`03001oogoo00Moo`0047oo00D007ooOomoo`00009oo`l000L48@PHaPLmk`MF]AMJePMF]@Lm
k`PHaPL48@l0009oo`03001oogoo01=oo`03001oogoo009oo`03001oodic00I>L`QBU0mS60h001L@
Q0h000mS60QBU0M>L`9oo`03001oogoo00Moo`0057oo00<007ooOol03`001`@Q21S61cg_1eJe5e[F
1eJe1cg_21S61`@Q3`000Woo00<007ooOol067oo00<007ooCW<01Tic25:D3f<H3P005a243P003f<H
25:D1dic0Woo00<007ooOol01goo000DOol200000goo0000000=000712486<H7?Nl7E[DGF]H7E[D7
?Nl86<H7124?00000goo0000000JOol00`00Oom>L`06CW<8DY@?HaP>000G48@>000?HaP8DY@7CW<2
Ool00`00Oomoo`07Ool001Aoo`03001oogoo00l000L48@PHaPLmk`MF]AMJePMF]@Lmk`PHaPL48@l0
009oo`03001oogoo01Qoo`03001oodic00I>L`QBU0mS60h001L@Q0h000mS60QBU0M>L`9oo`03001o
ogoo00Moo`0057oo00<007ooOol03`001`@Q21S61cg_1eJe5e[F1eJe1cg_21S61`@Q3`000Woo00<0
07ooOol067oo00<007ooCW<01Tic25:D3f<H3P005a243P003f<H25:D1dic0Woo00<007ooOol01goo
000DOol00`00Oomoo`0F000824876<H78@PG9BT78@P76<H8248F0002Ool00`00Oomoo`0HOol00`00
Oom>L`0>CW<7F]H8JeX7HaP7Li`GOol7Li`7HaP8JeX7F]H?CW<2Ool00`00Oomoo`07Ool001Aoo`80
0003Ool0000001@000P8@PLHaPLQ21LU:@LQ20LHaPP8@QH00003Ool0000001Yoo`03001oodic00i>
L`MJePQ[FPMS60McW1Moo`McW0MS60Q[FPMJePm>L`9oo`03001oogoo00Moo`0057oo00<007ooOol0
5P0020Q21aS61b485bDY1b481aS620Q25P000Woo00<007ooOol067oo00<007ooCW<03Tic1e[F26]J
1f<H1g>L5goo1g>L1f<H26]J1e[F3dic0Woo00<007ooOol01goo000DOol00`00Oomoo`0F00082487
6<H78@PG9BT78@P76<H8248F0002Ool00`00Oomoo`0HOol00`00Oom>L`0>CW<7F]H8JeX7HaP7Li`G
Ool7Li`7HaP8JeX7F]H?CW<2Ool00`00Oomoo`07Ool001Aoo`03001oogoo01H000P8@PLHaPLQ21LU
:@LQ20LHaPP8@QH0009oo`03001oogoo01Qoo`03001oodic00i>L`MJePQ[FPMS60McW1Moo`McW0MS
60Q[FPMJePm>L`9oo`03001oogoo00Moo`0057oo00<007ooOol05P0020Q21aS61b485bDY1b481aS6
20Q25P000Woo00<007ooOol067oo00<007ooCW<03Tic1e[F26]J1f<H1g>L5goo1g>L1f<H26]J1e[F
3dic0Woo00<007ooOol01goo000DOol200000goo0000000D000824876<H78@PG9BT78@P76<H8248F
00000goo0000000JOol00`00Oom>L`0>CW<7F]H8JeX7HaP7Li`GOol7Li`7HaP8JeX7F]H?CW<2Ool0
0`00Oomoo`07Ool001Aoo`03001oogoo01H000P8@PLHaPLQ21LU:@LQ20LHaPP8@QH0009oo`03001o
ogoo01Qoo`03001oodic00i>L`MJePQ[FPMS60McW1Moo`McW0MS60Q[FPMJePm>L`9oo`03001oogoo
00Moo`0057oo00<007ooOol07P001`@Q9@Q21`@Q7P000Woo00<007ooOol067oo00<007ooBU801TYB
24ic1e:D25[F1f<H1f]J5fmk1f]J1f<H25[F1e:D24ic1dYB0Woo00<007ooOol01goo000@Ool30000
17oo001oogoo7P001`@Q9@Q21`@Q7P000Woo00<007ooOol04goo0`000Woo00<007ooBU801TYB24ic
1e:D25[F1f<H1f]J5fmk1f]J1f<H25[F1e:D24ic1dYB0Woo00<007ooOol01goo000AOol01000Oomo
o`000Woo7P001`@Q9@Q21`@Q7P000Woo00<007ooOol057oo00H007ooOomoo`00Ool7BU88CW<7DY@8
F]H7HaP7JeXGKg/7JeX7HaP8F]H7DY@8CW<7BU82Ool00`00Oomoo`07Ool000moo`@00004Ool00000
OolN0007124U2487124N00000goo0000000DOol40002Ool20007BU88CW<7DY@8F]H7HaP7JeXGKg/7
JeX7HaP8F]H7DY@8CW<7BU82Ool00`00Oomoo`07Ool000moo`03001oo`00009oo`03001oogoo01h0
00L48BD8@PL48Ah0009oo`03001oogoo019oo`03001oo`0000=oo`03001oodYB00I:DPQ>L`MBU0QJ
ePMS60M[FQM_N`M[FPMS60QJePMBU0Q>L`M:DP9oo`03001oogoo00Moo`0047oo0P000Woo00<007oo
Ool07P001`@Q9@Q21`@Q7P000Woo00<007ooOol04goo0P000goo00<007ooBU801TYB24ic1e:D25[F
1f<H1f]J5fmk1f]J1f<H25[F1e:D24ic1dYB0Woo00<007ooOol01goo000AOol01000Oomoo`000Woo
7P001`@Q9@Q21`@Q7P000Woo00<007ooOol057oo00H007ooOomoo`00Ool7BU88CW<7DY@8F]H7HaP7
JeXGKg/7JeX7HaP8F]H7DY@8CW<7BU82Ool00`00Oomoo`07Ool001Aoo`800003Ool0000006d00003
Ool0000001Yoo`03001oodYB00i:DPm>Lc=BU0m>L`m:DP9oo`03001oogoo00Moo`0057oo00<007oo
Ool0K`000Woo00<007ooOol067oo00<007ooBU803TYB3dic<e:D3dic3dYB0Woo00<007ooOol01goo
000DOol00`00Oomoo`1_0002Ool00`00Oomoo`0HOol00`00Oom:DP0>BU8?CW<cDY@?CW<?BU82Ool0
0`00Oomoo`07Ool001Aoo`03001oogoo06l0009oo`03001oogoo01Qoo`03001oodYB00i:DPm>Lc=B
U0m>L`m:DP9oo`03001oogoo00Moo`0057oo00<007ooOol0K`000Woo00<007ooOol067oo00<007oo
BU803TYB3dic<e:D3dic3dYB0Woo00<007ooOol01goo000DOol200000goo0000001]00000goo0000
000JOol00`00Oom:DP0>BU8?CW<cDY@?CW<?BU82Ool00`00Oomoo`07Ool001Aoo`03001oogoo06l0
009oo`03001oogoo01Qoo`03001oodYB00i:DPm>Lc=BU0m>L`m:DP9oo`03001oogoo00Moo`0057oo
00<007ooOol0K`000Woo00<007ooOol067oo00<007ooBU803TYB3dic<e:D3dic3dYB0Woo00<007oo
Ool01goo000DOol00`00Oomoo`1_0002Ool00`00Oomoo`0HOol00`00Oom:DP0EBU93CW<FBU82Ool0
0`00Oomoo`07Ool001Aoo`800003Ool0000006d00003Ool0000001Yoo`03001oodYB01E:DT=>LaI:
DP9oo`03001oogoo00Moo`0057oo00<007ooOol0K`000Woo00<007ooOol067oo00<007ooBU805DYB
@dic5TYB0Woo00<007ooOol01goo000DOol00`00Oomoo`1_0002Ool00`00Oomoo`0HOol00`00Oom:
DP0EBU93CW<FBU82Ool00`00Oomoo`07Ool000moo`8000=oo`03001oogoo06l0009oo`03001oogoo
019oo`8000Aoo`03001oodYB01E:DT=>LaI:DP9oo`03001oogoo00Moo`003goo00<007oo00000Woo
00<007ooOol0K`000Woo00<007ooOol04Woo00<007oo00000goo00<007ooBU805DYB@dic5TYB0Woo
00<007ooOol01goo000?Ool00`00Ool00002Ool200000goo0000001]00000goo0000000DOol00`00
Ool00003Ool2000FBU93CW<FBU82Ool00`00Oomoo`07Ool000moo`8000=oo`03001oogoo075oo`03
001oogoo019oo`8000Aoo`03001oogoo071oo`03001oogoo00Moo`003goo00<007ooOol00WooM@00
57oo00<007ooOol00gooM0002Goo000@Ool2002<Ool20020Ool00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {136.125, 0}} -> {-0.0541876, -0.0238146, 
  0.00734626, 0.00734626}, {{7.375, 137}, {132.875, 
  3.1875}} -> {-8.49137, -7.80533, 0.108145, 0.108145}, {{149.938, 279.625}, {
  132.875, 3.1875}} -> {-23.8993, -7.80118, 0.108086, 0.108086}}]
}, Open  ]],

Cell[TextData[{
  "where the signal ",
  Cell[BoxData[
      \(TraditionalForm\`f(x, y)\)]],
  " is on the left and the 2D Laplacian of ",
  Cell[BoxData[
      \(TraditionalForm\`f\)]],
  " on the right. Now in 2D, the zero-crossings localize the centers of the ",
  
  StyleBox["edges",
    FontSlant->"Italic"],
  " in the original signal."
}], "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["DIGITAL LAPLACIAN", "Section"],

Cell["\<\
A number of kernel masks are commonly used to calculate the 2-D digital \
Laplacian. Here we use a minimum-variance digital Laplacian (assuming that \
pixel noise is uncorrelated and has uniform variance) [Haralick, 1992]. The \
Laplacian is the lowest order isotropic (i.e. orientation independent) \
operator.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(LaplacianKernel // MatrixForm\)], "Input"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", GridBox[{
            {"2", \(-1\), "2"},
            {\(-1\), \(-4\), \(-1\)},
            {"2", \(-1\), "2"}
            }], ")"}],
      (MatrixForm[ #]&)]], "Output"]
}, Open  ]],

Cell[BoxData[
    \(dat = 
      ReadImage["\<coke.tif\>", "\<TIFF\>", \ ImageOutput -> RawImageData] // 
        Reverse; \nA = dat[\([Range[20, 79], Range[40, 99]]\)]; \n
    \[Del]2 = Edge[A, LaplacianKernel]; \)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[
      GraphicsArray[
        \(ListDensityPlot[#1, Mesh \[Rule] False, FrameTicks \[Rule] None, 
              DisplayFunction \[Rule] Identity]\ &\)\ /@\ {A, \ \[Del]2}]]; 
    \)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .47619 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0113379 0.47619 [
[ 0 0 0 0 ]
[ 1 .47619 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .47619 L
0 .47619 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0113379 0.477324 0.464853 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0160256 0.0192308 0.0160256 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
60 string
60 60 8 [60 0 0 60 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFF1F1E8E5DCD3D3C4C4976E7A8888827D7A6E655C5F564D
504D50565F5C5C656868686B6E8BB8C1C7C1BEC4C4BEC1BE
BEB5BEB8BBC1BBB5B5BBB2B5
DFCAC1BBB2A6A3A09D9D9A9771655F7482979AA9B2B8C4C1
CAD0E5EBF7F1E8E2E2E5D3D9C4C7CAD9BBB8B8B8C7BEBEC4
BBB8B8B8BEBBC1C4BBB8B2BB
ACA9A69DA0A39A979494A6A3AFB2C7CADCE5E5DCDCD9CDBE
BEB8BEC4D0B8B5B8BBB2B8ACAFA96B82B2BEBBC1C1C1BEBB
B8B5BBC1B8B5B8B2B8BBB5B8
ACAFA3A0A39A9D9D94A3ACAFB8B8BEB8A6A3A0AC9A8E8EAC
A6A9AFACAFC1A9A9AFA9A9B2A3A335328EB8BBBEBEBEBBBE
B8BBC1BEBEBEB5B8C4B8B5B5
ACA6A3A3A697A39A6E91A69494886E85946E7D887774A0C1
C4B5B2AFB2B2B5C7B8B2AFB29DA64A388BB8B8BBBEC1B8BB
B8B5B8BBBBB5BEB8BBB8B8BB
AFB2A3A6A0A3979456809D778BA68585A67A8594BBAFA0B5
CAD6BBBEB8B5BBBBDCBBB8BBB2C4653885C4C1BBC1CDBBBB
BEC7C1CAC4BEC1C4BECABBB8
B2A6AC9DA3A09D9D5F80AC77A0A39DACBEC7BBD6BEB8BEBE
B8B8CADCC1C1BBBBBEBEC7B5B5AC7D3B88BBBBB8BBBEC1BB
BEC1C4C1BEBBBEC4C7C4B8BE
ACACA9A39DA39A946574A9A6A6A3A3A6B5B8BBBBC7D6C4BB
BBBBBEBBC4C4AF9794B2BBCDB8AF943E82BEB8BBBBBEBEB8
BEBBC1C4C1BBC1BBC1C4B8C1
AFAFA9A3A3A09A916565A3A0B5B8AFC7B28E85719A74CADF
BBB8B8B25F4D4A47444753B5C4AC9D357AB2B2C1B2B8BBBE
B8C1BEBEBEC1B8C1B8BBB8BE
AFA9A3A3A09A919A6865A37A77565F6E8068656B8EB2C4BE
CAC46253444A4A4D47505044B2A6A63874C4B2BEBBBBBEBB
BECDC1BEBECAC1C1C7BBBEBE
AFAFA6A39A9A9A917456AC744A4D3B5C53A38B7A85BBBBB8
A3474447474A474D3E47474159AC913B68ACAFAFA6A9A397
8B827A6B654747412F2C20A9
B2A9A3A39D9A9794804DA67D4A3E415F597DBB59A9C1B59A
474747444447474A3E323B3E3BA0A33E2F111D232F32444A
5065716E7A828E979D9D8077
91918582745F504A564DAFA3508E917D71596B7471B2B547
47474D41444D4A41444444383888A3414ABBB2B2AFB8B2B8
B5B5B5BBB8C1BBBBB8B8A080
2F4441505668656B6E32A09A6E44324A6EA3A0A6ACBB474A
4747474A504447443B443B322F59B5505CB8B8BBB2BBBBB8
B8BEC1B8BBBBB8B8B5BE9D7D
ACA6A3A09A9A91978841A38E975F293E3EB8ACB8AC624144
4A444A504A444A473E3E3B293238A65C5CB5AFB2B5BBB2B8
AFB8B8B5BBB8B8B5C1C1917A
AFA9A6A3A09A978B85449AA0918553A0A6A6AFB5B23E4747
47474D5691AFAFAFAC4A32292032A96256B5AFB2B5ACB5B2
B2B8AFB5B5B8B8BBB8B88B7A
ACA9A9A3A09A8E918844A0979D9A829D9DA3B2AF5C414747
44509AB5BBD3B5B5AFAF3B26202FAC6853BBACB5AFACB2B5
AFB2B5B2B2B8B5B8B5B28E80
A3A9A3ACA394979A8B3894A0A0979A918EA9A9A93B44474D
62B8B5B5B5B8BBB8A6AF801D2029826E53ACACB2AFBEAFB5
B5A9BBB5BEB5B8BBBBBE8580
ACA9A3A39D979D8E8B3B978B9D9A9A9A9A8EA37D383B3B5F
ACC1B8B5B8B8B2ACB5A69A1A202C5F7D59ACACAFB5B2B2AF
B2B5B5BEB8B8B8B5B8BB807A
ACA6A3A0979D91918B478EA088949D9D9DA0A04D2C3B47B2
B2B8B5CAB5B5ACACA08E94202035778050AFA9AFAFAFB2B2
B8B2B5B8BBBEBBBBB8B8857A
AFA9A3A69A9A9A8B8B41919A9A8B91949D9DA32F354780B2
AFB8B8B5BBC1ACA9A39794261D5C777D4DAFAFACB2ACAFB2
B5B8B5B8BBBEBBB8B8C1916E
B2ACA0ACA3A09A8E914A8B9DA08E977D979D9D263241B8B5
B2B5B2B2AFB2BEA05935291D1D8B6B854DAFA9ACACA9B2B5
B5BBB5B5B8BBBEB5B8BE8874
A9AFA9A6A0A09797914D94979AA39A978894A6262935B2B2
D0B8B2AFAFAF623523231D1A1D80778E47A9ACACA6B2AFB5
ACB5B8B2B8B8B2B8B2B28B68
ACAFA6A3A0A097949144919488A094949A9D911D293BAFA9
B2B2CAB2A947382F26231A1D2094748E41ACA6A6ACA9ACB2
ACAFAFB2B8B5B5B5B5B88865
AFA9A9A6A09794918E418B949A7A949A9A9D97232332ACA9
AFB2AFBB503E382F231D1D201D59808E41ACA6A3A6AFA9AC
B2ACB2AFB5B2B5B5BBBB8E5F
A3A0ACA3979D978B8B3E8E91979A7A8B949DA3172026B2AF
B2A6B274443B352C29231D1A1A2F919144A3A9A99DA3A6AC
A9ACB2ACAFB8AFAFB2B28859
ACA0A6A69D949491854791949197949182A0A02F292C6BBB
B8ACA944414138262326382C141A8E8B38A39DA3A0A6A3A9
ACACA9AFAFB2B2B5B2AF8E4A
A6A9A6A09A91978B884A8E8B8E919D9797A6A3381D263894
AFBE6E41413838567D8B948E3220689141A9A3A9A9A6A6AC
B2ACACAFB5B2B5B5B2B8915C
A9A6A9A99797948E88418B8E88809494949DA353232C2C44
80A6443B3B50949A918E80945617858844A0A3A6A6A6AFA9
ACAFB2B2AFB8B2B5AFBB8B53
ACAFA69D949791948B478E979191719AA3A9A362262C447D
A6B8383B53B29D979A94946E470E828841A3A0A6A0A6A3AC
AFACAFAFBBB2B2B5B2B89450
ACACA9A39A9A948E8541949A948E94748BA09D68658E97AC
A39D38419DA98B91918E8E851A1A687D3EA0A0A3A3ACA9AF
A9A6ACACB2B5B5B5B5B8A047
B2A9A6A39D97978B854A97859194918E8897823E292F82A3
AFA33B4AAC9D9D8E7D91852C1A1D7A85419D9AA0A3A6A6A9
ACA9AFB5B2B2B5B5B5B59A3B
B8A3A6A39A97918E85478B8E7A8B8E8B915335261D23299A
9DA03B41A6A39494856220141A3582943EA09AA3A3ACA3A9
A9ACACACAFAFAFB2B2B2A032
BBACA9A3A094948B885091918B857A8E4A292C2920202F7A
9A9D3B354D8E80562320171D1A7A8E8E4AA0949DA6ACA3A9
ACAFACACACB8B2B2BEB89D41
B5A3A39D9788918E8B478E8E8888856E171729262020296B
9D973835382F2C26231A1A1726918E8E479A9AA0A0ACA6A6
A9ACACACACB2A9AFB2B29D35
B8B5A39A948E8E88884D948885948B5C0E1D2C474A232977
9D9D4D353B2C261D1A1A1A1A68778E8B4D9D9A9DA0A9A6A6
A6ACACACB2ACAFB2B5BB9A35
B5AFA6A0A09797918253978E7D888E2914478B9491712391
979482353B2F261A1A1D1D3894687782569D94A39D9DA6A6
A9A6AFACB2B2B8B5B5B29738
B5A9A99A979A91917D50948588718817329A9182804D237A
9D8BA053322C17171A26358B7D208E77659AA09A9AA6A3A6
A6A3ACA9A9B2B2B8BEC19138
B8ACA3A094978E8B884D948B88856E176E918B5F23172365
A39A9DA07429231A29657426112385716B979D9DA3A3A3A3
A6A6AFACACAFAFB5C1AF9D2C
BBB2A9A394949185825C948B8885881438262020201D2059
94949794A08E7A5F351D17141A20826E719D9AA0A0A0A6A0
A9ACA9ACACAFB8B2B5BBA326
B5B2AFA0979A918E855C9D826E8B5C11141D231A1A1A2359
47978E8E743E23141114171411207A6B7D979D9AA0A0A0A3
A6A6ACACACACBEACB8B8A323
B2B5AF9D9D948B82826B8E8B4A14140E112029171723324D
38384A3223292014111D171714147D59889A9A97A0ACA6A3
ACA6B2A6B5ACB8AFAFB8A920
BBAFAFA6978E91828571918844141414111A23385F77854A
352332231D1D2017171A1417171D7D4A919794979AACA0A3
A6A0ACA9ACB2B8B8BBB2AC1D
BBB2ACA09D918B82857A8E88440E111420507A8580683247
382F2C261A201D1A0E111A2C4D6E7A3B949D979AA0A0A0A0
A0AFAFB2B5B5B2B8B8B2A620
B8B8A9A39797858582808B7A47081D4D717A77441A1A1D3E
35262C20201D201417141A628E71853294948E9DA09DA3A0
A6ACACAFAFB5B8B2B8B5B217
B5BBB2ACA09A948280828E88444A7A682F1A261D171A173E
3E2C3223232C4714171114172C8874419A9A9197979D9DA6
A9AFACACB2C7AFB2B2B8B214
B2B8B2A9A394918B80889485806550650217111411141D3B
413547627A853211141114111117685694979AA0A3979DA9
ACACAFB5B2B8B8B2B5ACB217
B2AFA6A9A09194887D8E82887A47112F0E11141A26446556
7D888B827D3E1D1A0E140E0E171D4D6B91949A9A9DA0A3A6
ACA6B2A9AFB8B2ACAFAFAC14
AFAFACA6A0978E888085917D7D1A142F0E14415344447A7A
85886285621A203229110E0E1117507D8E979A97A39DA9A6
A6ACACB2B2B5AFB5AFAFAC0B
ACACA3ACA99D948E858B91806E261468536223141A142077
8B7A50201714267D625F0B0B0B1D44888E94A0A09AA6A3A6
ACB5ACB2AFB2B5AFAFACA611
B8A9A9B2A091948B8291807D715F597A710B111714111A29
8E8B561A1A1D53857A7462260E174A808E8E979DA0A0A9A9
ACB5ACB2B2ACB5AFB5ACA914
A9ACA9A9A69A9D918288827D77776574380B111114141126
85885917172085827D746B564411478B8B949A9DA3A3A6A9
A9AFB2ACAFAFAFACAFB8B20E
ACACA9A6A9A69A8B888580827D807A5F050B14202317141D
7D8B5317146574743B0B0E0B14563E88889791A0A3A9A6AF
ACA6AFAFB2B5ACB2B5B2B211
B5A6A9A9A9A697918B88828077807D62001420717D5F111A
6B825914298568170B140B0E081174858B889AA6A6ACA0A6
ACACA6A9A9B2AFAFB5AFAF0E
ACACA6A69DA0978E8B88827D627D77440E501D857A7D141A
7D7A5F1465561D0E0B14110811115F828B8B9AA39DA3A0A6
A3A9A6B2A6A6ACB2AFACA611
AFAFB2A69AA09D979185807D74657144236B177D71771729
82825F206211170E11080E0B0E11357A889497A0A0A6A6A3
A6A9AFACACACACACAFA9AF14
A9ACA6A0A6979A9191857D7A6E716E38081D1D7D7A651153
7D805C50170B140B0B080E0B0E111A827D8597A09D9DA3A6
A3A3ACAFACA9ACA9ACAFA30E
AFACAFA6A39D948E97887D77747A745C000E20807A412F77
7A827A4708110E11295C743E080E17808888A09D9DA39DA3
A3A9A9ACACACACACACA9AF11
A6AFA9A0A3A091918B827D77687D776E020B147D744A6E74
74747D14140E1A0E5C7A7A3B200B147D80889A9A9AA9A09D
A3A3A3A6A6A9ACACACAFA60B
A6A3A9A99DA0948E8E857A7465626E713E0E2F62562F1D20
777A6517113E500B7762650B410B1D718265979AA39DA0A3
A9ACA3ACA9ACA9A9A0979D11
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0113379 0.97619 0.464853 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0160256 0.0192308 0.0160256 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
60 string
60 60 8 [60 0 0 60 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
00291F1F252027262E3770848055554658688595B4BAB5F3
DDFFEAF8D9D7BFFFB2EAB5D2706E4516375C406456706A6A
7475767475727A79796E259C
578E8C9B9DA5AD9FA68F819BB5E4EAE4C5A7967B6446302A
0C06000000000000000003102C203D3F6489958A8087817D
7D8D8386847E73757C7C8E95
93A3A09E8D8E8A8B9A8E816F6349311D19031C1A2B355065
7F928A95919CB2A1999AA58EA46AD29F6A6A7F8279838880
8F8C8183878F909387858992
8A7D828A7D8E7F6A8B6B5A7455565D6F7AA7958AA2BFB7A6
A1A795A088899D95979B8C809051FFF9847288818681897E
81817A797C837D8874808C7B
918292817F877E65C27E62A19CABDABD8ECCB5B1BFC59D5C
757E958A9180857F6C978D7EAA39CDDD675F8B8B8A7C9385
918F968D8F8F8A8B8C888B79
85807C8A7A8A866AE5955ECC7F6BA3987BBEBD7D6D7B8981
6B6A807D93878C74627D7B77792793EE6A4F78817A6F8385
7D777772748378807D748779
8F8288858A78824DC5854AB584698376385B4B58697E8A80
8F867A5D74777383687A7D7B9C5B84F876528A8C8E7E8587
828087828A90817F81749472
8E897B8E8481855DBCA035996C89A68A7F70665F326E597F
978A874F62273C5A5B4355416D734BFF6E4D857A877E8088
8A85837E8182898185788D71
8E7C80808278895FB8BA4079353B3131418A9CC4B8CC8469
7D5D6D57B7D3DAD4E4D3C07F377B3DFF90509A7A908C8289
8B828B878A858C8E898D9073
86858D858588876597CA33AAAAB1D78FBFA5BAC17084616B
455E9C9DBE8D85758677B0A0755135FF7F377F687C6A6961
5A3B4041291D19050A005320
667E8480898286688EDC1A9DA2A5AB8F956934C97E72715F
90A0CB8E8B7E877A8D8379BD9B633CF05A0719172A3A4164
8A95B7D5EDFFFFFFFFFFFFAE
6B6874605F554A4553E22680EAA3CA92B35B438E843A4B9A
92BA808A8A82877E959A8D9ACC392AF2FFFFFFFFFFFFFFFF
FFE4CABFA18E6E5149309875
624E6E7098B0D5CE8DFE035586271C2F92C5A2FFB84B818A
B5827F8D84817F7F82767580BC640EE08400060F1B1C222A
3B4043514A4E5A606D507479
FBFFFFEDD4ABA38D6CFF3275BAB3DE9A97326654524A8FBE
7F8B80827D8782898C827C95AD9F00C8CB23807687738575
847377808480878B886585D7
42263D3E52515F5B35FF2C737185FAC5E96E79745FA2C287
848987A5AAD3D6D6B0B489879BD300CBD0348F8584808186
90818687818288827E569180
55848081817A8A7F58FF2A8C6875AB276E47884952AB9281
85B1A7AF7D383F2A4C77BC9995E300B8E12C917E8588897D
8C7E878A8481828381659DC0
5A7E8680828C8A834CFF367C7B66A35F8A7F7D57A5BE8292
C0946A55474D7879515987B490C90095E128887E8B8A8A82
858A808D868989858F61A0AE
628785787C8A7E7747FF3387707B90858F875A44C48C8A9F
805F577B93798A80864C63C091C92F83F2379180807A807F
858B827E8080837D7B52A2B5
5A7D8A7D898381804FFF4B808A807A8292906868C687C57B
82458C7C8D7E887A786427E091C55E69E8328A7D867B8C8A
7E8E79847F8A89898A57B1B4
50868C818E887E8D3FFF3A858690787D75893AB9B7A3A055
617884758480908B89A02DE8A792684BF637888A808A8083
80848C80857D7F828859A3C1
51828C799180848C50FF576E86957A94777F2CDA93A37659
8C7B8C7784757B61554102A3BC5E814EFF2B867F7E8A8488
83818583817F8188854B97C9
437F8E75827A7F8A46FF4F7B7A8D8D9C8C851AF58AB72771
818F888B8C504F4A92C39AC2C3298E47FF2F85868887857A
8579838A837D818086578DD0
517A8A7B8A80848441F74875806F6D908A8515EA8EE51F7F
5F817E8F4F7891BAC69F918EEA19B12DFF2B85828283807D
8F7D8186808786898D6097DA
457F8785857D858049FF4A8985877D80867F27F88AD8199D
7D8970438998B6968A808984B8218537FF2B87858A7E8D7E
8A8A838C7B838683856088E5
3D817C7E8983898843FF487B908796727C7C1AF084E61992
7C96547290B684858B89897FBE707A3AFF2A8586857A857C
83837F888281857F79527EE1
3C957D838A837F8550FF4C83718C978E957122F69CCB2E5D
848E6088B58C8386818D8A8DB0B23D30FF25817B91848D84
848880888480898D896A7AFF
428B7D7D85887C884CFB3F8082758785A0831BDA82BA6A4F
6A635FB0968093B5C4D0BD9CD0DA3F34FF3893868F848B85
848A868A8683868087657FFE
2F8982818F8A808450F5478485836E748A6A2ECBAEA8A758
553384B18FB3A19357342B1885FE4644FF24827780838482
7B838980857D867C895967F8
42827E7784837F8555FF5186958C937C97853FA1AA90D8C0
BF45E2ABBA796855658A7F4579E7372FFF2F8D7D867E8083
81857D887F8684818E5F78FF
2F7F85879784857B46FA44777B938A87676642AADDBAC184
5D04DAB7794D5A7379738752ACF23238FF3185818D8A8C84
808580827D7F8A808D6165FF
2A817F7E857F82845AFF3E7B7D729897A06F446B441F1E48
7534F5AA5054988B8B7B42688DFA4E54FF30887C8576827C
8491898E8286818085624EFF
178B81808780818253F341808A776A90606052A5C6A29B3A
7325DAC22A708E808553657AC6C55135FF3190838E7E907F
84857B7C7D818180837248FF
17948685858C7F8759FB4A939784895273919BB0A0C0BB6B
7234DDA6324B5E475F67A0BEC1A45E3BFF318B7D827A8C84
858688858D858C8E86754AFF
0089767A78857C844FEB41708B83876095AA87828A87C558
7130D8BF70585D8CBAACA68EB2516039FF30948389748E80
807D83858574827A736A35FF
1B948E8A86967F8351F84B858C7B815FD7A7929293A5C371
6A40D2A4A7A8B5A29A838AADAB53684DFF3C8C8087778A84
878085878783909089754DFF
087C828E8697858A5AF045838E71447AD0B6A1A89BA2F558
6553A2AE768B8690898A94B46A6F7747F73C8E7C8A7A8187
8485808782868A847D6641FF
12837F8078797A765EE53689888937C7E4624C2F0E4FC544
5C7069B0857A82858A8BB69121BA5273E14E89808C848981
82867B847C7D7D838C6C56FF
0D8885898A80848067F0458A928D39FA934844625C66E858
658B62B4A0B0919CA9956B491BD94970C64E85848A838085
82917F8F8A8583846D6942FF
088C85858E7F877D63E4468A759632F53F033978A5B8D971
4686466779BFCCAE842A4586B0FF1B93B5608482827F838A
82877C8087858787806F49FF
00808080917F8A8A63E33C818A5036E689BAC1B09D8DB163
6F5F885A20200023739A9AB095C422989F657E8680858186
7D84808685887593787429FF
06817D87867B787E66CA4F7175512EC986927F8E8B90A675
8755344F68A5C2BCB3938A8A8AD419AA886C858787878890
808E7E8C7F906F8D846E29FF
02857B898684879270C6526DC2C9B3B38D7C80ACB7C2AA86
C19EAAB9B1A087908A7A818090D51BC66A738088836E8380
778775877D8D7799857B1AFF
00857A88828B7D8A72AB655092AF7E8AA8AFAFA564243C4A
97A482929A828381877A919DAFD631E6537B8D8F88788688
86928496838B7A7D7C7719FF
008485828681858B789F635587BEA0A9A9752C1F26548A87
7B8F6F8A88867A8C8D8CA68A679718FF3B73867C85808A8B
8580777B7D8083897C8A12FF
007F8A8C8B8A888F7F95785FB5E09B5D3822338FC6B0CA6D
899B808D91967A9E81857131363B4DFF4585957E7E808483
8B7D898890798E80817A0AFF
00747F7A7F798085908E6B79918A4B2BC0B3A69E9A859F67
769C91B7C08B7B8F7D8CAAAB85761FF53A7B928A88908583
817F8985857083907E8300FF
0076837B818D7A849077775768687041BA9B8B97A8AEB2AC
A0C3977525315A9D88838495C5AB78C1508080767C888C80
7D85798089708880818402FF
00858C86818D80819585798E52B0CE5EC9929C97927C5475
5139593F5F90B3988F91858780B5649D6785848C7B8E7F82
848787898F7D8A8C868900FF
007A897E849086889B7E7D7F5EB6E066DB8C693746584559
5F70795749A4BA71B98EB3858BA381687585808886808186
87888481837E83837F7F06FF
008D8F78777E797B8E75718567D5CA473A61719EAECA9A8F
4C72C0C3B1D3963A5C6FA2B39AA8855F76817582808A7F89
85748B7F85857F87858908FF
007C8876859A8888947A84896D79951671A0AA8C808EB7B0
4D5675B086B0754A7C48768D9DBF95568A8D868589828280
8578888082877C85808208FF
018A887E8287758190788C7F847E8C5186B48A8A899091CB
35527CB5B2995D37534116366A8AB44A817B857D83858885
898082878688878F807E00FF
008684857C7E81898F81887B856E7F57DAA2AE99AE9FBAC3
3F4C75C9AE6735779ACBD1BF8896786B85858885857B8579
8287817F7D7985847D8000FF
0084857D7E768286807F8575956D5E57ED71BD1E4136B5D7
4B606FE58A256C9EB2978190AC9E7B4E878A867080759080
81818C858D7C86807F8200FF
008F858990808C8C878485859C84637CE52CE5256D2FD5C7
44606EDD3F6A8DB58A7B7F8585B363617D8B837C91838F87
8887877E8D8A88847D8F05FF
00757780868276807A85867298856078A80AE7328C36EFAD
44607BBC5495988A8288808D81AAA55580807C7A857A807F
857E817A85838084847E01FF
068E868E8585858C7B8A8A858B8B708AF769FA296F63EA87
627572A280B2819BABC1ABB0A094C5458D9982818C858780
898A828084878589808A07FF
0077798578858786737F857B8F6F6854D881CD2470A7CA65
6A6946859C957AAE7152206E9097D52780856F7C8A7D8A85
80807F7D80827F85867C00FF
04847F8A877A8A8C7F8A88808D746B4ED1B8C0334D71514A
5F7B55B5BE9480DA445D1FA56FA8CE3E6C9E618B857A868A
8C8694868E85847C777B00FF
75CDBBBFBAB4C2B3B8A0A09DAAA09F68C9C0D56F9EE2E1DC
756858DFB08870D0688590E9BFF5FFAAC5E0B0A2A19FA09B
89918F90928E9396A5A37AFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{309, 147.063},
  ImageMargins->{{43, 0}, {0, 1}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004e0000Ta000`40O003h00Oogoo=Woo003oOolf
Ool00?moocIoo`00ogoo=Woo0008Oon;000>Oon;0009Ool000Qoo`03001oogoo08Moo`03001oogoo
00aoo`03001oogoo08Moo`03001oogoo00Moo`0027oo00<007ooOol0Qgoo00<007ooOol037oo00<0
07ooOol0Qgoo00<007ooOol01goo0008Ool00`00Oomoo`27Ool00`00Oomoo`0<Ool00`00Oomoo`27
Ool00`00Oomoo`07Ool000Qoo`04001oogooOol5Nmh2Mkd2Li`2Kg/5JeX4HaP3BU82=Jd2?Nl5AS42
@Q04?Nl2=Jd3<H`4;F/2:DX39BT2:DX29BT5:DX6;F/2<H`<=Jd2AS42G_L7HaP2G_L5HaP2G_L2HaP4
G_L3F]H6G_L3HaP2G_L4F]H3G_L4F]H2Ool00`00Oomoo`0<Ool01000Ool000000QBU1@aS2A240QBU
0QS60cW>148@1BU:0R480Re[0SF]0T8@0dYB0U[F0Ukg0U[F0g_N0Vmk0Woo0WNm0goo0Vmk0V]J0Ukg
0Woo0e[F0WNm0U[F0V]J0cW>0SF]0R480PQ20aS60Re[0R480S6<0bU:0SW>13F]3SW>1Sg_0cF]0Q24
0Tic0Woo00<007ooOol01goo0008Ool01000Oomoogoo1G_N0WNm0W>L0Vmk1F]J16<H0dYB0SF]0Sg_
1DHa0T8@13g_0SF]0c6<12e[0RU:0bDY0RU:0RDY1BU:1Re[0S6<33F]0THa0Ukg1f<H0Ukg1F<H0Ukg
0V<H15kg0e[F1Ukg0f<H0Ukg15[F0ekg15[F0Woo00<007ooOol037oo00@007oo0000008DY@D<H`T@
Q08DY@8HaP<icPA240DYBP8Q208]J`8e[@9240=:DP9JeP9Nm`9JeP=kgP9_N`9oo`9g_@=oo`9_N`9[
FP9Nm`9oo`=JeP9g_@9JeP9[FP<icP8e[@8Q2088@P<HaP8]J`8Q208aS0<YBP8icP@e[@hicPHmk`<e
[@8@Q09>L`9oo`03001oogoo00Moo`0027oo00@007ooKg]_N`9W>@=S609Nm`9JePMBU0M>L`9:DP8i
cP8aS0<]J`8icP92409:DP9>L`=F]@9JeP9Nm`ES609W>@9[FP9cW0=g_@AkgP9g_@McW09[FP9_N`ES
609W>@9_N`UNm`=S60ANm`9S60iNm`AS60ENm`9JeP9Nm`9oo`03001oogoo00aoo`04001oobU::DX5
AS44CW<2DY@3E[D2CW<2DY@2AS43@Q02CW<2F]H2Li`3Mkd2Li`2HaP2DY@2BU83?Nl2<H`28@P26<H3
5:D2124F000224835:D248@47>L3<H`2AS42BU82AS47@Q04?Nl3AS46@Q03?Nl4>Lh5?Nl2AS42BU82
Ool00`00Oomoo`07Ool000Qoo`04001oofmkKg/2IcT3HaP2G_L2F]H7DY@7CW<2BU82>Lh2<H`3;F/2
>Lh2@Q02BU82CW<3E[D2F]H2G_L5HaP2IcT2JeX2Li`3Mkd4Nmh2Mkd7Li`2JeX2Kg/5HaP2IcT2Kg/9
G_L3HaP4G_L2HaP>G_L4HaP5G_L2F]H2G_L2Ool00`00Oomoo`0<Ool01000OolYBRU:1DHa14ic0U:D
0eJe0Tic0U:D0THa0d8@0Tic0U[F0W>L0gNm0W>L0V<H0U:D0TYB0cg_0S6<0R480QS60aBU0P@Q5P00
0PQ20aBU0Q2411cW0c6<0THa0TYB0THa1d8@13g_0dHa1T8@0cg_13W>1Cg_0THa0TYB0Woo00<007oo
Ool01goo0008Ool00`00OomF]@03E[D3DY@2CW<4DY@3CW<6BU85DY@2E[D2F]H3HaP2IcT2Kg/4Li`7
Kg/2IcT9G_L3HaP2JeX2G_L2F]H5G_L2F]H2G_L7E[D2=Jd2@Q03F]H4G_L7HaP6G_L3F]H2G_L2HaP2
G_L3F]H2G_L2F]H5G_L2F]H2G_L2Ool00`00Oomoo`0<Ool01000Oom:DTYB1E:D0Tic2DHa0Tic0THa
0d8@0SF]0S6<0RDY0aS610aS0P001@aS0QBU0QS60RU:0c6<0Sg_0TYB0THa1DYB0Tic0U[F0U:D1Dic
0U:D0THa0e:D0SF]0V]J0Tic1CF]0Sg_0T8@0cg_0T8@0THa0T8@1DHa1T8@0dHa14YB1D8@0THa0TYB
0Woo00<007ooOol01goo0008Ool00`00OomF]@03E[D3DY@2CW<4DY@3CW<6BU85DY@2E[D2F]H3HaP2
IcT2Kg/4Li`7Kg/2IcT9G_L3HaP2JeX2G_L2F]H5G_L2F]H2G_L7E[D2=Jd2@Q03F]H4G_L7HaP6G_L3
F]H2G_L2HaP2G_L3F]H2G_L2F]H5G_L2F]H2G_L2Ool00`00Oomoo`0<Ool01000Oom:DTYB1E:D0Tic
2DHa0Tic0THa0d8@0SF]0S6<0RDY0aS610aS0P001@aS0QBU0QS60RU:0c6<0Sg_0TYB0THa1DYB0Tic
0U[F0U:D1Dic0U:D0THa0e:D0SF]0V]J0Tic1CF]0Sg_0T8@0cg_0T8@0THa0T8@1DHa1T8@0dHa14YB
1D8@0THa0TYB0Woo00<007ooOol01goo0008Ool00`00OomF]@03E[D3DY@2CW<4DY@3CW<6BU85DY@2
E[D2F]H3HaP2IcT2Kg/4Li`7Kg/2IcT9G_L3HaP2JeX2G_L2F]H5G_L2F]H2G_L7E[D2=Jd2@Q03F]H4
G_L7HaP6G_L3F]H2G_L2HaP2G_L3F]H2G_L2F]H5G_L2F]H2G_L2Ool00`00Oomoo`0<Ool01000Oom:
DTYB1E:D0Tic2DHa0Tic0THa0d8@0SF]0S6<0RDY0aS610aS0P001@aS0QBU0QS60RU:0c6<0Sg_0TYB
0THa1DYB0Tic0U[F0U:D1Dic0U:D0THa0e:D0SF]0V]J0Tic1CF]0Sg_0T8@0cg_0T8@0THa0T8@1DHa
1T8@0dHa14YB1D8@0THa0TYB0Woo00<007ooOol01goo0008Ool00`00OomF]@03E[D7DY@7CW<2BU82
DY@5E[D9G_L6DY@3E[D2CW<4AS43E[D2DY@9E[D2HaP;E[D2F]H5DY@46<H3AS4DG_L2HaP7G_L2F]H2
G_L2HaP3G_L4F]H2Ool00`00Oomoo`0<Ool01000Oom6<DHa0Sg_0d8@0THa0Sg_0THa0cg_0SF]0THa
0SF]0be[0SW>12U:0be[0SF]0Sg_0U:D0TYB0dHa0U:D0Ukg0U[F1e:D0TYB0e:D14Ha0Tic1DYB0Tic
0THa0T8@0dYB0RU:17oo0d8@0SW>0THa1d8@0THa0Sg_1D8@1Sg_0d8@0Sg_0THa0SW>0d8@0THa0Sg_
0Woo00<007ooOol01goo0008Ool00`00OomF]@03E[D7DY@7CW<2BU82DY@5E[D9G_L6DY@3E[D2CW<4
AS43E[D2DY@9E[D2HaP;E[D2F]H5DY@46<H3AS4DG_L2HaP7G_L2F]H2G_L2HaP3G_L4F]H2Ool00`00
Oomoo`0<Ool01000Oom6<DHa0Sg_0d8@0THa0Sg_0THa0cg_0SF]0THa0SF]0be[0SW>12U:0be[0SF]
0Sg_0U:D0TYB0dHa0U:D0Ukg0U[F1e:D0TYB0e:D14Ha0Tic1DYB0Tic0THa0T8@0dYB0RU:17oo0d8@
0SW>0THa1d8@0THa0Sg_1D8@1Sg_0d8@0Sg_0THa0SW>0d8@0THa0Sg_0Woo00<007ooOol01goo0008
Ool01000OomF]EJe2E:D0TYB0e:D0Tic0SF]0TYB0e:D14YB0THa0cF]0T8@0TYB0SF]0Sg_0dHa13W>
0U:D1F<H15[F0eJe1U[F0V<H0ekg0U[F0UJe0U[F0dic0U:D0RDY0QcW0dHa2Ekg0V<H1Ukg0e[F1Ukg
0e[F3Ekg0Woo00<007ooOol037oo00@007ooBU9:DP9240=:DP92408mk`9240<mk`8aS09S608mk`<a
S09BU09>L`9F]@=_N`9Nm`96<@9W>@EJeP9Nm`9S609>L`<]J`8icP8mk`9:DP=6<@9:DPA2408mk`<e
[@9:DP96<@8mk`=F]@8Li`9W>@9_N`<aS08]J`M6<@8mk`9:DP92409:DP=6<@9:DQ96<@8mk`9oo`03
001oogoo00Moo`0027oo00@007ooE[EF]@UBU09:DP=BU09>L`8e[@9:DP=BU0A:DP96<@<e[@92409:
DP8e[@8mk`=6<@@icP9BU0ES60AJeP=F]@IJeP9S60=Nm`9JeP9F]@9JeP=>L`9BU08U:@8Li`=6<@UN
m`9S60INm`=JePINm`=JePeNm`9oo`03001oogoo00aoo`04001oodYBBU82@Q03BU82@Q02?Nl2@Q03
?Nl2<H`2HaP2?Nl3<H`2DY@2CW<2E[D3Kg/2G_L2AS42IcT5F]H2G_L2HaP2CW<3;F/2>Lh2?Nl2BU83
AS42BU84@Q02?Nl3=Jd2BU82AS42?Nl3E[D27>L2IcT2Kg/3<H`2;F/7AS42?Nl2BU82@Q02BU83AS42
BU8BAS42?Nl2Ool00`00Oomoo`07Ool000Qoo`04001ooeJeE[D2F]H9DY@5BU82:DX2@Q03CW<2>Lh2
AS42DY@5@Q02DY@2?Nl2@Q03BU82G_L2E[D2DY@3F]H2IcT2JeX7G_L2F]H4G_L3Kg/6G_L3F]H2HaP2
<H`27>L3@Q04HaP2G_L3HaP2IcT6G_L5HaP2IcT2HaP3G_L4HaP2G_L3IcT4G_L2Ool00`00Oomoo`0<
Ool00`00Oom24003@Q03?Nl2AS42?Nl2AS43@Q02=Jd2Li`2BU83;F/2IcT2?Nl2=Jd3DY@2CW<2?Nl4
G_L3?Nl2=Jd2?Nl2AS43@Q04=Jd2@Q03?Nl2BU82@Q02AS42>Lh3<H`4?Nl2>Lh3?Nl248@2BU82Mkd3
=Jd29BT2?Nl2@Q03?Nl2=Jd4@Q02?Nl9>Lh3@Q02?Nl2@Q02?Nl3>Lh2@Q02?Nl2Ool00`00Oomoo`07
Ool000Qoo`04001ooeJeE[D2F]H9DY@5BU82:DX2@Q03CW<2>Lh2AS42DY@5@Q02DY@2?Nl2@Q03BU82
G_L2E[D2DY@3F]H2IcT2JeX7G_L2F]H4G_L3Kg/6G_L3F]H2HaP2<H`27>L3@Q04HaP2G_L3HaP2IcT6
G_L5HaP2IcT2HaP3G_L4HaP2G_L3IcT4G_L2Ool00`00Oomoo`0<Ool00`00Oom24003@Q03?Nl2AS42
?Nl2AS43@Q02=Jd2Li`2BU83;F/2IcT2?Nl2=Jd3DY@2CW<2?Nl4G_L3?Nl2=Jd2?Nl2AS43@Q04=Jd2
@Q03?Nl2BU82@Q02AS42>Lh3<H`4?Nl2>Lh3?Nl248@2BU82Mkd3=Jd29BT2?Nl2@Q03?Nl2=Jd4@Q02
?Nl9>Lh3@Q02?Nl2@Q02?Nl3>Lh2@Q02?Nl2Ool00`00Oomoo`07Ool000Qoo`04001ooe[FF]H2DY@3
E[D2CW<4DY@5CW<2;F/2@Q03E[D2>Lh4DY@3CW<2E[D2G_L2HaP2G_L3JeX=G_L2IcT3Kg/4HaP9G_L2
HaP5F]H2E[D2?Nl27>L3AS4;G_L2HaP4G_L7HaP7G_L7HaP4G_L2Ool00`00Oomoo`0<Ool01000Oom6
<DHa0T8@0dHa0T8@0THa0Sg_0d8@0RDY0V<H0T8@0bDY0U[F0T8@0SF]0d8@0SW>0QcW0Re[0RDY0be[
0SF]0Sg_0THa0d8@0THa0T8@0Sg_0be[1SW>0T8@0cF]1Sg_0dic0Re[0T8@0Woo0cW>0RU:1dHa0Sg_
3D8@0THa0dYB0T8@0Sg_0T8@0cW>0TYB0SW>0Woo00<007ooOol01goo0008Ool01000OomJeU[F0U:D
0eJe0Tic15:D1Dic0Re[0T8@0eJe0SW>15:D0dic0UJe0Ukg0V<H0Ukg0f]J3Ekg0VLi0fmk16<H2Ekg
0V<H1E[F0UJe0Sg_0QcW0dHa2ekg0V<H15kg1f<H1ekg1f<H15kg0Woo00<007ooOol037oo00@007oo
AS56<@9240=6<@924096<@8mk`=2408U:@9S609240<U:@9JeP92408e[@=2408icP8Li`8]J`8U:@<]
J`8e[@8mk`96<@=24096<@92408mk`<]J`HicP9240<e[@Hmk`=>L`8]J`92409oo`<icP8YBPM6<@8m
k`e24096<@=:DP92408mk`9240<icP9:DP8icP9oo`03001oogoo00Moo`0027oo00@007ooF]IJeP9B
U0=F]@9>L`ABU0E>L`8]J`9240=F]@8icPABU0=>L`9F]@9Nm`9S609Nm`=[FPeNm`9W>@=_N`AS60UN
m`9S60EJeP9F]@8mk`8Li`=6<@]Nm`9S60ANm`MS60MNm`MS60ANm`9oo`03001oogoo00aoo`04001o
odHaAS42@Q03AS42@Q02AS42?Nl3@Q029BT2HaP2@Q039BT2F]H2@Q02=Jd3@Q02>Lh27>L2;F/29BT3
;F/2=Jd2?Nl2AS43@Q02AS42@Q02?Nl3;F/6>Lh2@Q03=Jd6?Nl3CW<2;F/2@Q02Ool3>Lh2:DX7AS42
?Nl=@Q02AS43BU82@Q02?Nl2@Q03>Lh2BU82>Lh2Ool00`00Oomoo`07Ool000Qoo`03001ooeJe00IF
]@9BU09>L`9BU0=>L`9:DP8aS08icP=F]@]BU09JePMNm`9S609[FP9S60aNm`AS609F]@E:DP9JeP9N
m`9W>@=Nm`9F]@9:DP8Li`=241ANm`IS60=Nm`9S609Nm`ES609Nm`9S609oo`03001oogoo00aoo`03
001oodHa00=6<@<mk`96<@M2408]J`9Nm`9BU0<HaP9>L`8e[@96<@=BU096<@8mk`8icP8aS0<]J`8H
aP8e[@8]J`<mk`9:DP96<@9240<U:@8aS08@Q08Li`D]J`8Q208YBP8Q20<e[@8icP8U:@9oo`<e[@8U
:@92408mk`=2408mk`9240A6<@E2408mk`E24096<@A240<mk`96<@8icP9oo`03001oogoo00Moo`00
27oo00<007ooE[D01UJe0U:D0Tic0U:D0dic0TYB0S6<0SW>0eJe2e:D0U[F1ekg0V<H0V]J0V<H35kg
16<H0UJe1DYB0U[F0Ukg0VLi0ekg0UJe0TYB0QcW0d8@55kg1V<H0ekg0V<H0Ukg1F<H0Ukg0V<H0Woo
00<007ooOol037oo00<007ooAS400dHa0cg_0THa1d8@0Re[0Ukg0U:D0aS60Tic0SF]0THa0e:D0THa
0Sg_0SW>0S6<0be[0QS60SF]0Re[0cg_0TYB0THa0T8@0bDY0S6<0Q240QcW1Be[0R480RU:0R480cF]
0SW>0RDY0Woo0cF]0RDY0T8@0Sg_0d8@0Sg_0T8@14Ha1D8@0Sg_1D8@0THa148@0cg_0THa0SW>0Woo
00<007ooOol01goo0008Ool00`00OomF]@06E[D6DY@3CW<2BU84<H`5DY@2F]H2G_L3E[D2HaP2F]H2
AS42@Q03>Lh2CW<2>Lh2IcT3Kg/6G_L3F]H2;F/49BT78@P2:DX2F]H3HaP2E[D2CW<26<H3?Nl4F]H2
HaP3F]H8G_L3HaP6G_L3HaP2G_L2HaP9G_L2Ool00`00Oomoo`0<Ool01000Oom6<DHa0Sg_1d8@0Sg_
0dHa0Re[15kg0b480Sg_0QS60QcW1AS60R480THa0Tic0f<H0Ukg0VLi0T8@0cF]0Sg_0Re[0SF]0bU:
0U[F0V]J0Vmk0V]J0g>L0V]J0V<H0Sg_0aS60Sg_0QcW0Woo0dYB0RU:0Tic0Sg_0dYB0THa0T8@14Ha
0d8@0THa0T8@0THa0d8@2DHa0TYB0SW>0Woo00<007ooOol01goo0008Ool00`00OomF]@06E[D6DY@3
CW<2BU84<H`5DY@2F]H2G_L3E[D2HaP2F]H2AS42@Q03>Lh2CW<2>Lh2IcT3Kg/6G_L3F]H2;F/49BT7
8@P2:DX2F]H3HaP2E[D2CW<26<H3?Nl4F]H2HaP3F]H8G_L3HaP6G_L3HaP2G_L2HaP9G_L2Ool00`00
Oomoo`0<Ool01000Oom6<DHa0Sg_1d8@0Sg_0dHa0Re[15kg0b480Sg_0QS60QcW1AS60R480THa0Tic
0f<H0Ukg0VLi0T8@0cF]0Sg_0Re[0SF]0bU:0U[F0V]J0Vmk0V]J0g>L0V]J0V<H0Sg_0aS60Sg_0QcW
0Woo0dYB0RU:0Tic0Sg_0dYB0THa0T8@14Ha0d8@0THa0T8@0THa0d8@2DHa0TYB0SW>0Woo00<007oo
Ool01goo0008Ool00`00OomF]@03E[D7DY@2CW<3BU82CW<2=Jd2<H`3DY@2?Nl2>Lh2:DX3;F/2=Jd2
@Q02=Jd2<H`3=Jd2AS42F]H2HaP3G_L2IcT2HaP2<H`3:DX28@P69BT38@P4:DX28@P3F]H4DY@27>L3
>Lh2HaP2F]H=G_L3IcT2HaP4G_L3IcT6HaP7G_L2Ool00`00Oomoo`0<Ool00`00Oom24003@Q03AS44
@Q02AS43@Q02<H`2BU82IcT36<H4E[D2F]H3JeX2AS42G_L2DY@2G_L3HaP2>Lh2@Q02<H`3=Jd28@P2
;F/5CW<2G_L2AS42@Q02>Lh3@Q02>Lh2F]H2DY@3>Lh2:DX26<H2Ool3?Nl26<H2?Nl2=Jd3?Nl4=Jd2
<H`2;F/37>L48@P25:D536<2000212430002:DX248@2Ool00`00Oomoo`07Ool000Qoo`03001ooeJe
00=F]@MBU09>L`=:DP9>L`8e[@8aS0=BU08mk`8icP8YBP<]J`8e[@92408e[@8aS0<e[@96<@9JeP9S
60=Nm`9W>@9S608aS0<YBP8Q20HU:@<Q20@YBP8Q20=JePABU08Li`<icP9S609JePeNm`=W>@9S60AN
m`=W>@IS60MNm`9oo`03001oogoo00aoo`03001ood8@00=240=6<@A24096<@=2408aS09:DP9W>@<H
aPAF]@9JeP=[FP96<@9Nm`9BU09Nm`=S608icP92408aS0<e[@8Q208]J`E>L`9Nm`96<@92408icP=2
408icP9JeP9BU0<icP8YBP8HaP9oo`<mk`8HaP8mk`8e[@<mk`@e[@8aS08]J`<Li`@Q208DY@D<H`80
00848@<0008YBP8@Q09oo`03001oogoo00Moo`0027oo00<007ooE[D00eJe1E:D1dic0TYB0SW>0RU:
0eJe0SW>12DY0acW0Re[0RU:0U:D0THa0cg_0T8@1ekg0U:D2B480RDY0R480RDY0acW1R480be[0UJe
0TYB0QcW0cF]1UJe0e:D0UJe0U:D0TYB0THa0d8@0Sg_0SF]0S6<1b481ABU0Q240UJe0Woo00<007oo
Ool037oo00@007oo<H`aS08mk`E24096<@E2408e[@96<@9_N`<<H`9>L`ABU0=F]@96<@9:DP8e[@8H
aP=W>@8mk`@icP<]J`9:DP9BU09W>@E6<@8mk`92408mk`=6<@92408mk`9Nm`=>L`8aS08Li`9kgP<]
J`80008<H`88@P<DY@8Li`8Q208aS096<@=:DP9JeP9[FP9g_@ioo`9F]@9oo`03001oogoo00Moo`00
27oo00<007ooE[D00eJe1E:D1dic0TYB0SW>0RU:0eJe0SW>12DY0acW0Re[0RU:0U:D0THa0cg_0T8@
1ekg0U:D2B480RDY0R480RDY0acW1R480be[0UJe0TYB0QcW0cF]1UJe0e:D0UJe0U:D0TYB0THa0d8@
0Sg_0SF]0S6<1b481ABU0Q240UJe0Woo00<007ooOol037oo00@007oo<H`aS08mk`E24096<@E2408e
[@96<@9_N`<<H`9>L`ABU0=F]@96<@9:DP8e[@8HaP=W>@8mk`@icP<]J`9:DP9BU09W>@E6<@8mk`92
408mk`=6<@92408mk`9Nm`=>L`8aS08Li`9kgP<]J`80008<H`88@P<DY@8Li`8Q208aS096<@=:DP9J
eP9[FP9g_@ioo`9F]@9oo`03001oogoo00Moo`0027oo00@007ooF]IJeP9F]@EBU0A>L`E:DP92408U
:@=BU08mk`8U:@8Li`<Q20@]J`8mk`9Nm`<]J`9F]@9S609JeP=>L`lQ208U:@<Li`8HaPLLi`ABU08L
i`<DY@88@P8<H`8@Q0<DY@8HaP8Q208U:@8YBP<aS08icP8e[@8mk`=24096<@9:DPE>L`92408icP9o
o`03001oogoo00aoo`03001oocF]00<e[@<icP8aS08]J`8YBP<U:@8Q208YBP9cW0<@Q092409g_@9B
U0=W>@9:DP9JeP8]J`8Q20=6<@92408Li`8U:@=>L`9:DP9Nm`9240E6<@A2408mk`=:DP9>L`96<@9>
L`=W>@8Li`8DY@9kgQAoo`=cW09W>@9Nm`9BU0=6<@8e[@8YBP8U:@<HaP9>L`8icP9oo`03001oogoo
00Moo`0027oo00@007ooF]IJeP9F]@EBU0A>L`E:DP92408U:@=BU08mk`8U:@8Li`<Q20@]J`8mk`9N
m`<]J`9F]@9S609JeP=>L`lQ208U:@<Li`8HaPLLi`ABU08Li`<DY@88@P8<H`8@Q0<DY@8HaP8Q208U
:@8YBP<aS08icP8e[@8mk`=24096<@9:DPE>L`92408icP9oo`03001oogoo00aoo`03001oocF]00<e
[@<icP8aS08]J`8YBP<U:@8Q208YBP9cW0<@Q092409g_@9BU0=W>@9:DP9JeP8]J`8Q20=6<@92408L
i`8U:@=>L`9:DP9Nm`9240E6<@A2408mk`=:DP9>L`96<@9>L`=W>@8Li`8DY@9kgQAoo`=cW09W>@9N
m`9BU0=6<@8e[@8YBP8U:@<HaP9>L`8icP9oo`03001oogoo00Moo`0027oo00@007ooF]IJeP9F]@EB
U0A>L`E:DP92408U:@=BU08mk`8U:@8Li`<Q20@]J`8mk`9Nm`<]J`9F]@9S609JeP=>L`lQ208U:@<L
i`8HaPLLi`ABU08Li`<DY@88@P8<H`8@Q0<DY@8HaP8Q208U:@8YBP<aS08icP8e[@8mk`=24096<@9:
DPE>L`92408icP9oo`03001oogoo00aoo`03001oocF]00<e[@<icP8aS08]J`8YBP<U:@8Q208YBP9c
W0<@Q092409g_@9BU0=W>@9:DP9JeP8]J`8Q20=6<@92408Li`8U:@=>L`9:DP9Nm`9240E6<@A2408m
k`=:DP9>L`96<@9>L`=W>@8Li`8DY@9kgQAoo`=cW09W>@9Nm`9BU0=6<@8e[@8YBP8U:@<HaP9>L`8i
cP9oo`03001oogoo00Moo`0027oo00<007ooBU800dYB1D8@0SW>0Re[0bU:0RDY0RU:0RDY0eJe0U:D
0RU:0THa0dYB0Sg_0SW>0Re[0SF]1CW>15[F1b480RDY1B4812DY2B481AcW0THa0U:D0R480bDY0Ukg
15[F0eJe0Ukg0U[F0Ukg1e[F15kg0f<H2Ekg0U:D0T8@0Woo00<007ooOol037oo00@007oo<H`aS08U
:@<e[@8icP9>L`9JeP=[FP9W>@96<@9oo`<0008YBP92408@Q0<<H`8DY@9:DP9S609BU0=oo`9Nm`8U
:@9240=6<@9JeP92408mk`=6<@A240@mk`=240@icP9240=Nm`8aS0848@9cW0=240@000848@D<H`8@
Q08DY@8Li`DQ208YBPDU:@8]J`8aS08e[@<YBP8icP8mk`9oo`03001oogoo00Moo`0027oo00<007oo
BU800dYB1D8@0SW>0Re[0bU:0RDY0RU:0RDY0eJe0U:D0RU:0THa0dYB0Sg_0SW>0Re[0SF]1CW>15[F
1b480RDY1B4812DY2B481AcW0THa0U:D0R480bDY0Ukg15[F0eJe0Ukg0U[F0Ukg1e[F15kg0f<H2Ekg
0U:D0T8@0Woo00<007ooOol037oo00@007oo<H`aS08U:@<e[@8icP9>L`9JeP=[FP9W>@96<@9oo`<0
008YBP92408@Q0<<H`8DY@9:DP9S609BU0=oo`9Nm`8U:@9240=6<@9JeP92408mk`=6<@A240@mk`=2
40@icP9240=Nm`8aS0848@9cW0=240@000848@D<H`8@Q08DY@8Li`DQ208YBPDU:@8]J`8aS08e[@<Y
BP8icP8mk`9oo`03001oogoo00Moo`0027oo00@007oo5:DDY@DQ20@YBP8e[@<aS0@e[@8HaP=BU09>
L`8e[@8Q20<HaP8U:@8e[@MBU09F]@9Nm`8Q20<U:@HQ20<U:@8YBPHQ20<Li`8Q208Li`8HaP<DY@8]
J`9JeP8YBP<]J`INm`=JeP]Nm`9S60]Nm`9JeP=Nm`9>L`8mk`9oo`03001oogoo00aoo`03001oogoo
00Ioo`9g_@9[FP9F]@=BU096<@8e[@9oo`<HaP8icP9Nm`9JeP=_N`9>L`9:DP8HaP8aS0DYBP8U:@96
<@=Nm`8mk`96<@E2408mk`A240E6<@92408mk`9:DP=F]@9>L`8000EW>@8@Q092408icP=2408icP92
408icP9240DicPU240A6<@<aS092409[FP9oo`03001oogoo00Moo`0027oo00@007oo5:DDY@DQ20@Y
BP8e[@<aS0@e[@8HaP=BU09>L`8e[@8Q20<HaP8U:@8e[@MBU09F]@9Nm`8Q20<U:@HQ20<U:@8YBPHQ
20<Li`8Q208Li`8HaP<DY@8]J`9JeP8YBP<]J`INm`=JeP]Nm`9S60]Nm`9JeP=Nm`9>L`8mk`9oo`03
001oogoo00aoo`03001oogoo00Ioo`9g_@9[FP9F]@=BU096<@8e[@9oo`<HaP8icP9Nm`9JeP=_N`9>
L`9:DP8HaP8aS0DYBP8U:@96<@=Nm`8mk`96<@E2408mk`A240E6<@92408mk`9:DP=F]@9>L`8000EW
>@8@Q092408icP=2408icP92408icP9240DicPU240A6<@<aS092409[FP9oo`03001oogoo00Moo`00
27oo00@007ooE[EF]@MBU0A>L`E:DP96<@8Q20=BU096<@9:DP8]J`<DY@@Li`9Nm`9F]@=Nm`9F]@8a
S0DQ208U:@8Q208U:@<YBP8U:@8Q208U:@8Q20LLi`8DY@<HaP8Li`9BU0D]J`9JeP9F]@EJeP9Nm`9J
eP9Nm`9F]@ENm`9JePMNm`9JePES609:DP8mk`9oo`03001oogoo00aoo`04001oob488@P248@57>L4
:DX5;F/26<H2Ool35:D4>Lh2@Q03Ool2HaP2Mkd2=Jd2?Nl3>Lh2;F/2DY@2HaP5@Q02AS42@Q03DY@2
E[D6JeX5F]H2AS42@Q03CW<2JeX20002IcT3JeX26<H2AS4;@Q02BU8<@Q02AS42@Q02?Nl3:DX2BU82
@Q02Ool00`00Oomoo`07Ool000Qoo`04001ooeJeE[D7DY@4CW<5BU82AS428@P3DY@2AS42BU82;F/3
5:D47>L2G_L2E[D3G_L2E[D2<H`58@P29BT28@P29BT3:DX29BT28@P29BT28@P77>L25:D36<H27>L2
DY@5;F/2F]H2E[D5F]H2G_L2F]H2G_L2E[D5G_L2F]H7G_L2F]H5HaP2BU82?Nl2Ool00`00Oomoo`0<
Ool01000OolQ22480Q241AcW12U:1Be[0QS60Woo0aBU13W>0T8@0goo0V<H0WNm0SF]0Sg_0cW>0Re[
0U:D0V<H1D8@0THa0T8@0e:D0UJe1V]J1E[F0THa0T8@0dic0V]J0P000VLi0f]J0QS60THa2d8@0TYB
348@0THa0T8@0Sg_0bU:0TYB0T8@0Woo00<007ooOol01goo0008Ool00`00OomF]@03E[D7DY@2CW<3
BU82AS42@Q028@P3CW<2DY@2BU82@Q03:DX6DY@2E[D5F]H27>L98@P29BT3:DX2BU89E[D29BT26<H2
5:D348@26<H2E[D2<H`3:DX2F]H2E[D5F]H2E[D6F]H3G_L2E[D4F]H<G_L2AS42?Nl2Ool00`00Oomo
o`0<Ool01000OolYBRU:2D8@0Sg_0dHa0Sg_0Re[0Woo0aBU0THa0SF]0SW>0eJe0Q240SF]0R480THa
0bDY0RU:0UJe0TYB1D8@0U[F0U:D0eJe0Sg_11cW0QBU0bDY0SW>0Ukg0Tic0dYB0W>L0P000Ukg0g>L
0QBU0TYB0Sg_0d8@14Ha0Sg_0THa0cg_0T8@0THa2d8@0c6<0Tic0V<H0Woo00<007ooOol01goo0008
Ool00`00OomF]@03E[D7DY@2CW<3BU82AS42@Q028@P3CW<2DY@2BU82@Q03:DX6DY@2E[D5F]H27>L9
8@P29BT3:DX2BU89E[D29BT26<H25:D348@26<H2E[D2<H`3:DX2F]H2E[D5F]H2E[D6F]H3G_L2E[D4
F]H<G_L2AS42?Nl2Ool00`00Oomoo`0<Ool01000OolYBRU:2D8@0Sg_0dHa0Sg_0Re[0Woo0aBU0THa
0SF]0SW>0eJe0Q240SF]0R480THa0bDY0RU:0UJe0TYB1D8@0U[F0U:D0eJe0Sg_11cW0QBU0bDY0SW>
0Ukg0Tic0dYB0W>L0P000Ukg0g>L0QBU0TYB0Sg_0d8@14Ha0Sg_0THa0cg_0T8@0THa2d8@0c6<0Tic
0V<H0Woo00<007ooOol01goo0008Ool00`00OomF]@06E[D4DY@2CW<3AS42BU82AS428@P3DY@2BU84
CW<3@Q04CW<2DY@2F]H3E[D2;F/98@P2:DX2CW<3F]H2G_L2JeX4F]H5E[D27>L548@25:D2E[D2=Jd3
:DX2G_L2E[D2F]H5E[D4F]H2E[D9F]H3G_L2F]H2G_L5F]H2AS42@Q02Ool00`00Oomoo`0<Ool01000
Ool]Jbe[0Sg_1d8@1DHa0T8@0RDY0Woo0aS613g_0S6<0e:D0Re[0THa13g_0bU:0U:D0Ukg0T8@0dYB
0V<H0TYB0SF]0bU:0R480RDY13g_0bU:0Re[0T8@0U[F0dYB0VLi0P000TYB0g>L0QBU0THa0Sg_1dHa
148@0dHa0T8@0THa0T8@1DHa0T8@0THa0c6<0U:D0UJe0Woo00<007ooOol01goo0008Ool00`00OomF
]@06E[D4DY@2CW<3AS42BU82AS428@P3DY@2BU84CW<3@Q04CW<2DY@2F]H3E[D2;F/98@P2:DX2CW<3
F]H2G_L2JeX4F]H5E[D27>L548@25:D2E[D2=Jd3:DX2G_L2E[D2F]H5E[D4F]H2E[D9F]H3G_L2F]H2
G_L5F]H2AS42@Q02Ool00`00Oomoo`0<Ool01000Ool]Jbe[0Sg_1d8@1DHa0T8@0RDY0Woo0aS613g_
0S6<0e:D0Re[0THa13g_0bU:0U:D0Ukg0T8@0dYB0V<H0TYB0SF]0bU:0R480RDY13g_0bU:0Re[0T8@
0U[F0dYB0VLi0P000TYB0g>L0QBU0THa0Sg_1dHa148@0dHa0T8@0THa0T8@1DHa0T8@0THa0c6<0U:D
0UJe0Woo00<007ooOol01goo0008Ool00`00OomF]@06E[D4DY@2CW<3AS42BU82AS428@P3DY@2BU84
CW<3@Q04CW<2DY@2F]H3E[D2;F/98@P2:DX2CW<3F]H2G_L2JeX4F]H5E[D27>L548@25:D2E[D2=Jd3
:DX2G_L2E[D2F]H5E[D4F]H2E[D9F]H3G_L2F]H2G_L5F]H2AS42@Q02Ool00`00Oomoo`0<Ool01000
Ool]Jbe[0Sg_1d8@1DHa0T8@0RDY0Woo0aS613g_0S6<0e:D0Re[0THa13g_0bU:0U:D0Ukg0T8@0dYB
0V<H0TYB0SF]0bU:0R480RDY13g_0bU:0Re[0T8@0U[F0dYB0VLi0P000TYB0g>L0QBU0THa0Sg_1dHa
148@0dHa0T8@0THa0T8@1DHa0T8@0THa0c6<0U:D0UJe0Woo00<007ooOol01goo0008Ool01000OomB
U5:D0UJe0e:D0UJe0U:D1DYB0Tic0THa0QcW0dYB15:D0TYB0dic0TYB0THa1eJe0QcW12480bDY0S6<
0Ukg1e[F1Ukg0e:D0UJe0T8@0PaS0a240QBU0T8@0SF]0bU:15Je0U[F0eJe0Ukg0UJe15[F0eJe0Ukg
0U[F0Ukg0e[F2Ekg148@0Woo00<007ooOol037oo00@007oo<H`aS0E240@mk`96<@<mk`8icP8Q209o
o`<HaP92408icP8mk`=:DP924096<@92408]J`<Q209S60A6<@=>L`92408]J`8YBP<mk`9:DP8mk`96
<@E2408U:@8aS09S60=:DP9W>@8DY@9240=kgP8HaP9:DPE2408mk`92408mk`9240=6<@92408mk`M2
40@mk`<YBP9BU09JeP9oo`03001oogoo00Moo`0027oo00@007ooDYABU09F]@=BU09F]@9BU0E:DP9>
L`96<@8Li`=:DPABU09:DP=>L`9:DP96<@MF]@8Li`@Q20<U:@8aS09Nm`MJePINm`=BU09F]@92408<
H`<@Q08DY@92408e[@<YBPAF]@9JeP=F]@9Nm`9F]@AJeP=F]@9Nm`9JeP9Nm`=JePUNm`A2409oo`03
001oogoo00aoo`04001ooc6<<H`5@Q04?Nl2AS43?Nl2>Lh28@P2Ool36<H2@Q02>Lh2?Nl3BU82@Q02
AS42@Q02;F/38@P2HaP4AS43CW<2@Q02;F/2:DX3?Nl2BU82?Nl2AS45@Q029BT2<H`2HaP3BU82IcT2
5:D2@Q03Nmh26<H2BU85@Q02?Nl2@Q02?Nl2@Q03AS42@Q02?Nl7@Q04?Nl3:DX2DY@2F]H2Ool00`00
Oomoo`07Ool000Qoo`03001ooeJe00=F]@EBU09>L`9:DP=>L`A6<@8Li`=:DP96<@]>L`96<@9BU0<m
k`HLi`<]J`9F]@9S609Nm`=JePANm`9JeP9F]@=JeP9BU09>L`8<H`<@Q08DY@8]J`8mk`<]J`IF]@MJ
eP9F]@MJePUNm`9JePENm`92408mk`9oo`03001oogoo00aoo`04001oobe[;F/2?Nl3AS42?Nl2AS47
@Q029BT2Ool39BT2@Q02AS42@Q03?Nl2@Q04BU85=Jd2HaP2@Q02HaP3?Nl2@Q028@P2AS43?Nl2AS42
?Nl2AS45?Nl2<H`248@2Li`3BU82HaP2;F/2=Jd3Mkd26<H2AS42?Nl3@Q02?Nl4AS42?Nl3AS42?Nl2
@Q02?Nl9AS43:DX4F]H2Ool00`00Oomoo`07Ool000Qoo`03001ooeJe00=F]@EBU09>L`9:DP=>L`A6
<@8Li`=:DP96<@]>L`96<@9BU0<mk`HLi`<]J`9F]@9S609Nm`=JePANm`9JeP9F]@=JeP9BU09>L`8<
H`<@Q08DY@8]J`8mk`<]J`IF]@MJeP9F]@MJePUNm`9JePENm`92408mk`9oo`03001oogoo00aoo`04
001oobe[;F/2?Nl3AS42?Nl2AS47@Q029BT2Ool39BT2@Q02AS42@Q03?Nl2@Q04BU85=Jd2HaP2@Q02
HaP3?Nl2@Q028@P2AS43?Nl2AS42?Nl2AS45?Nl2<H`248@2Li`3BU82HaP2;F/2=Jd3Mkd26<H2AS42
?Nl3@Q02?Nl4AS42?Nl3AS42?Nl2@Q02?Nl9AS43:DX4F]H2Ool00`00Oomoo`07Ool000Qoo`04001o
oeJeE[D7DY@2BU82CW<5BU82AS428@P3AS42DY@2AS42BU87CW<4DY@39BT25:D27>L28@P5F]H2G_L2
F]H3IcT4F]H4E[D3DY@2AS42BU8548@26<H2>Lh2@Q03:DX;E[D4F]H2G_L5F]H@G_L2@Q02?Nl2Ool0
0`00Oomoo`0<Ool01000OolYBRU:0T8@0dHa0T8@14Ha0cg_0THa0QcW0Woo0acW148@0TYB1Cg_0SW>
0THa0QcW0ekg0U[F15:D0bU:0S6<0Sg_0T8@0cW>148@0TYB1DHa0U:D0QBU0WNm0e:D0TYB0SF]0RDY
0g_N0QS614Ha0d8@0THa2D8@0THa148@1Cg_0T8@0THa0be[0U:D0V<H0Woo00<007ooOol01goo0008
Ool01000OomF]EJe1e:D0TYB0Tic1DYB0THa0R480dHa0U:D0THa0TYB1dic15:D0bDY0QBU0QcW0R48
1E[F0Ukg0U[F0fLi15[F15Je0e:D0THa0TYB1A240QS60SW>0T8@0bU:2eJe15[F0Ukg1E[F45kg0T8@
0Sg_0Woo00<007ooOol037oo00@007oo:DXYBP9240=6<@9240A6<@<mk`96<@8Li`9oo`<Li`A2409:
DPDmk`8icP96<@8Li`=Nm`9JePABU0<YBP8aS08mk`9240<icPA2409:DPE6<@9BU08DY@9g_@=BU09:
DP8e[@8U:@=kgP8HaPA6<@=24096<@U24096<@A240Dmk`924096<@<]J`9BU09S609oo`03001oogoo
00Moo`0027oo00<007ooE[D00eJe1E:D1dic14Ha0R480dYB14ic0THa1DYB14ic0U:D0aBU0QS60R48
0T8@0e[F0UJe15kg0e[F0Ukg0V<H15Je0e:D14YB0Q240`aS0Re[0SW>0Sg_0bDY1UJe0e[F15Je15[F
0ekg0U[F3Ekg0f<H0TYB0SF]0Woo00<007ooOol037oo00@007oo:DXYBP9240=6<@8mk`9:DPE24096
<@8YBP9oo`<YBP8e[@92409:DP<mk`9:DP8icP8mk`8DY@=_N`9:DP9BU08icP<]J`96<@8mk`96<@<i
cP92408icP8mk`8aS0<YBP8Q2080009BU0=Nm`8]J`92408U:@=oo`8DY@9240Dmk`96<@924096<@]2
40<mk`924096<@9240<U:@9:DP9W>@9oo`03001oogoo00Moo`0027oo00<007ooE[D00eJe1E:D1dic
14Ha0R480dYB14ic0THa1DYB14ic0U:D0aBU0QS60R480T8@0e[F0UJe15kg0e[F0Ukg0V<H15Je0e:D
14YB0Q240`aS0Re[0SW>0Sg_0bDY1UJe0e[F15Je15[F0ekg0U[F3Ekg0f<H0TYB0SF]0Woo00<007oo
Ool037oo00@007oo:DXYBP9240=6<@8mk`9:DPE24096<@8YBP9oo`<YBP8e[@92409:DP<mk`9:DP8i
cP8mk`8DY@=_N`9:DP9BU08icP<]J`96<@8mk`96<@<icP92408icP8mk`8aS0<YBP8Q2080009BU0=N
m`8]J`92408U:@=oo`8DY@9240Dmk`96<@924096<@]240<mk`924096<@9240<U:@9:DP9W>@9oo`03
001oogoo00Moo`0027oo00<007ooE[D00eJe1E:D1dic14Ha0R480dYB14ic0THa1DYB14ic0U:D0aBU
0QS60R480T8@0e[F0UJe15kg0e[F0Ukg0V<H15Je0e:D14YB0Q240`aS0Re[0SW>0Sg_0bDY1UJe0e[F
15Je15[F0ekg0U[F3Ekg0f<H0TYB0SF]0Woo00<007ooOol037oo00@007oo:DXYBP9240=6<@8mk`9:
DPE24096<@8YBP9oo`<YBP8e[@92409:DP<mk`9:DP8icP8mk`8DY@=_N`9:DP9BU08icP<]J`96<@8m
k`96<@<icP92408icP8mk`8aS0<YBP8Q2080009BU0=Nm`8]J`92408U:@=oo`8DY@9240Dmk`96<@92
4096<@]240<mk`924096<@9240<U:@9:DP9W>@9oo`03001oogoo00Moo`0027oo00@007ooF]IJeP9F
]@=BU09F]@ABU0=>L`96<@9:DP8U:@=6<@9>L`9BU096<@=:DP8mk`9:DPA>L`<@Q08HaP8Q209Nm`aJ
eP9F]@9JeP9Nm`9BU0<]J`8HaP8DY@D<H`96<@8e[@9240<U:@]F]@IJeP=Nm`AJePMNm`9JePENm`96
<@8icP9oo`03001oogoo00aoo`04001oob488@P2?Nl3AS42>Lh2@Q05?Nl2AS428@P2Ool39BT4?Nl5
AS42CW<2AS42@Q0236<3Nmh2AS42F]H248@3>Lh2@Q09AS42:DX49BT3BU82HaP2CW<5HaP25:D2AS42
8@P3Ool25:D4@Q03AS44@Q02?Nl2@Q03?Nl2@Q02AS42@Q03?Nl6@Q03:DX2AS42JeX2Ool00`00Oomo
o`07Ool000Qoo`04001ooe[FF]H2E[D3DY@2E[D4DY@3CW<2AS42BU829BT3AS42CW<2DY@2AS43BU82
?Nl2BU84CW<348@26<H28@P2G_L<F]H2E[D2F]H2G_L2DY@3;F/26<H25:D536<2AS42=Jd2@Q039BT;
E[D6F]H3G_L4F]H7G_L2F]H5G_L2AS42>Lh2Ool00`00Oomoo`0<Ool01000OolQ22480Sg_0dHa0SW>
0T8@1Cg_0THa0R480Woo0bDY13g_1DHa0Tic0THa0T8@0PaS0g_N0THa0U[F0Q240cW>0T8@2DHa0RU:
12DY0dYB0V<H0Tic1F<H0QBU0THa0R480goo0QBU148@0dHa148@0Sg_0T8@0cg_0T8@0THa0T8@0cg_
1T8@0bU:0THa0V]J0Woo00<007ooOol01goo0008Ool00`00OomF]@06E[D6DY@7BU829BT5BU82CW<2
DY@3CW<2BU82AS42BU82DY@348@25:D26<H5F]H2JeX2G_L2F]H7E[D2<H`26<H548@736<2@Q02>Lh2
AS438@P6E[D3DY@2F]H2E[D2F]H2E[D3F]H2G_L2F]H5G_L2F]H2G_L5F]H2AS42=Jd2Ool00`00Oomo
o`0<Ool01000OolYBRU:0Sg_0dHa0Sg_0THa1d8@0R480W_N0bDY0SW>0T8@1CF]0TYB0THa0T8@0PQ2
0gNm0THa0W>L0PaS0cg_0Re[0T8@0Sg_0dHa0RDY0Sg_0TYB0Ukg0f<H0Tic0TYB0THa0gNm0PaS0U[F
0QBU0goo0QBU2d8@0Sg_0THa0cg_2d8@14Ha0c6<0TYB0Vmk0Woo00<007ooOol01goo0008Ool00`00
OomF]@06E[D6DY@7BU829BT5BU82CW<2DY@3CW<2BU82AS42BU82DY@348@25:D26<H5F]H2JeX2G_L2
F]H7E[D2<H`26<H548@736<2@Q02>Lh2AS438@P6E[D3DY@2F]H2E[D2F]H2E[D3F]H2G_L2F]H5G_L2
F]H2G_L5F]H2AS42=Jd2Ool00`00Oomoo`0<Ool01000OolYBRU:0Sg_0dHa0Sg_0THa1d8@0R480W_N
0bDY0SW>0T8@1CF]0TYB0THa0T8@0PQ20gNm0THa0W>L0PaS0cg_0Re[0T8@0Sg_0dHa0RDY0Sg_0TYB
0Ukg0f<H0Tic0TYB0THa0gNm0PaS0U[F0QBU0goo0QBU2d8@0Sg_0THa0cg_2d8@14Ha0c6<0TYB0Vmk
0Woo00<007ooOol01goo0008Ool00`00OomF]@03E[D9DY@7BU828@P5BU82AS42DY@5BU84CW<2BU83
36<25:D27>L5E[D4F]H2IcT3F]H2E[D28@P27>L25:D548@436<348@2BU82>Lh2AS438@P2E[D4DY@7
E[D2F]H7E[D2F]H2G_L9F]H3G_L2AS42<H`2Ool00`00Oomoo`0<Ool01000OolQ22480Sg_1d8@0Sg_
1D8@0RDY0Woo0bDY0THa148@0cg_148@0Sg_0Q240goo0THa0Vmk0PaS0dic0Sg_0THa0SW>0b480THa
0Tic0U[F0TYB0dHa0T8@0THa0T8@0ekg0Q240T8@0QS60goo0QBU148@0dHa0Sg_0THa0Sg_1DHa0T8@
0THa0Sg_2D8@0c6<0THa0W>L0Woo00<007ooOol01goo0008Ool00`00OomF]@03E[D9DY@7BU828@P5
BU82AS42DY@5BU84CW<2BU8336<25:D27>L5E[D4F]H2IcT3F]H2E[D28@P27>L25:D548@436<348@2
BU82>Lh2AS438@P2E[D4DY@7E[D2F]H7E[D2F]H2G_L9F]H3G_L2AS42<H`2Ool00`00Oomoo`0<Ool0
1000OolQ22480Sg_1d8@0Sg_1D8@0RDY0Woo0bDY0THa148@0cg_148@0Sg_0Q240goo0THa0Vmk0PaS
0dic0Sg_0THa0SW>0b480THa0Tic0U[F0TYB0dHa0T8@0THa0T8@0ekg0Q240T8@0QS60goo0QBU148@
0dHa0Sg_0THa0Sg_1DHa0T8@0THa0Sg_2D8@0c6<0THa0W>L0Woo00<007ooOol01goo0008Ool00`00
OomF]@06E[D4DY@7BU82AS428@P3AS42BU82CW<2?Nl3BU86CW<2BU8548@26<H7E[D2F]H2E[D3G_L2
:DX47>L25:D348@436<248@336<2;F/2@Q02AS438@P2E[D7DY@6E[D2F]H3E[D2F]H2E[D9F]H5G_L2
AS42;F/2Ool00`00Oomoo`0<Ool01000OolLiacW0T8@1Cg_0THa0T8@1DHa0R480Woo0bDY0Sg_0TYB
0T8@0dYB0SW>13g_0PaS0g_N0T8@0W>L0PaS0dYB0Sg_0TYB0RU:0cW>0TYB0U[F148@1dHa0Sg_0ekg
0SW>0Sg_0QcW0goo0QBU1d8@0Sg_0T8@0Sg_1D8@0Sg_0THa1d8@13g_0bU:0Sg_0W>L0Woo00<007oo
Ool01goo0008Ool00`00OomF]@06E[D4DY@7BU82AS428@P3AS42BU82CW<2?Nl3BU86CW<2BU8548@2
6<H7E[D2F]H2E[D3G_L2:DX47>L25:D348@436<248@336<2;F/2@Q02AS438@P2E[D7DY@6E[D2F]H3
E[D2F]H2E[D9F]H5G_L2AS42;F/2Ool00`00Oomoo`0<Ool01000OolLiacW0T8@1Cg_0THa0T8@1DHa
0R480Woo0bDY0Sg_0TYB0T8@0dYB0SW>13g_0PaS0g_N0T8@0W>L0PaS0dYB0Sg_0TYB0RU:0cW>0TYB
0U[F148@1dHa0Sg_0ekg0SW>0Sg_0QcW0goo0QBU1d8@0Sg_0T8@0Sg_1D8@0Sg_0THa1d8@13g_0bU:
0Sg_0W>L0Woo00<007ooOol01goo0008Ool00`00OomBU003DY@3E[D2DY@2BU82CW<3BU84AS427>L3
AS44BU82CW<3?Nl2AS42BU82CW<2DY@3248448@2F]H3E[D2F]H2DY@2F]H3>Lh28@P27>L26<H55:D2
48@736<25:D4BU838@P2DY@4E[D3CW<4DY@7E[D2F]H4E[D3G_L4E[D5F]H2AS42;F/2Ool00`00Oomo
o`0<Ool01000OolLiacW0TYB0cg_0T8@0THa0T8@0cg_0T8@0RU:0Woo0bDY0T8@0SW>0THa0dYB0THa
0TYB0SW>0Q240g_N0Tic0VLi0QBU0be[0T8@0THa0S6<0dHa0U[F0THa1d8@1THa1E[F0QcW0QS60goo
0Q240T8@0Sg_0dYB0T8@0THa148@0dHa0T8@0THa1D8@1THa0cF]0Sg_17oo00<007ooOol01goo0008
Ool00`00OomBU003DY@3E[D2DY@2BU82CW<3BU84AS427>L3AS44BU82CW<3?Nl2AS42BU82CW<2DY@3
248448@2F]H3E[D2F]H2DY@2F]H3>Lh28@P27>L26<H55:D248@736<25:D4BU838@P2DY@4E[D3CW<4
DY@7E[D2F]H4E[D3G_L4E[D5F]H2AS42;F/2Ool00`00Oomoo`0<Ool01000OolLiacW0TYB0cg_0T8@
0THa0T8@0cg_0T8@0RU:0Woo0bDY0T8@0SW>0THa0dYB0THa0TYB0SW>0Q240g_N0Tic0VLi0QBU0be[
0T8@0THa0S6<0dHa0U[F0THa1d8@1THa1E[F0QcW0QS60goo0Q240T8@0Sg_0dYB0T8@0THa148@0dHa
0T8@0THa1D8@1THa0cF]0Sg_17oo00<007ooOol01goo0008Ool00`00OomBU003DY@3E[D2DY@2BU82
CW<3BU84AS427>L3AS44BU82CW<3?Nl2AS42BU82CW<2DY@3248448@2F]H3E[D2F]H2DY@2F]H3>Lh2
8@P27>L26<H55:D248@736<25:D4BU838@P2DY@4E[D3CW<4DY@7E[D2F]H4E[D3G_L4E[D5F]H2AS42
;F/2Ool00`00Oomoo`0<Ool01000OolLiacW0TYB0cg_0T8@0THa0T8@0cg_0T8@0RU:0Woo0bDY0T8@
0SW>0THa0dYB0THa0TYB0SW>0Q240g_N0Tic0VLi0QBU0be[0T8@0THa0S6<0dHa0U[F0THa1d8@1THa
1E[F0QcW0QS60goo0Q240T8@0Sg_0dYB0T8@0THa148@0dHa0T8@0THa1D8@1THa0cF]0Sg_17oo00<0
07ooOol01goo0008Ool01000OomF]EJe1e:D0Tic1dYB0T8@0R483TYB0T8@15:D1aBU0SF]1Ekg15Je
1b480QcW1a240QcW0QBU0`Q20PaS14Ha0acW0U:D0Tic2E:D3EJe2E[F0eJe0THa0RDY0Woo00<007oo
Ool037oo00@007oo8@PQ2096<@Dmk`924096<@<mk`96<@8U:@9oo`<Li`A2408icPE2409BU092408<
H`=_N`92409Nm`8e[@<U:@8e[@8aS08]J`=JeP9:DP92409:DP9JeP=S609[FP9Nm`9>L`=[FP9_N`8L
i`8HaP=oo`8Li`9:DP9240=6<@924096<@A240=6<@924096<@]240<aS08mk`Aoo`03001oogoo00Mo
o`0027oo00@007ooE[EF]@MBU09>L`M:DP92408Q20i:DP9240ABU0LDY@8e[@ENm`AF]@LQ208Li`L@
Q08Li`8DY@<8@P8<H`A6<@<Li`9BU09>L`UBU0eF]@UJeP=F]@96<@8U:@9oo`03001oogoo00aoo`04
001oob488@P2AS45?Nl2@Q02AS43?Nl2AS429BT2Ool37>L4@Q02>Lh5@Q02DY@2@Q0236<3Kg/2@Q02
G_L2=Jd39BT2=Jd2<H`2;F/3F]H2BU82@Q02BU82F]H3HaP2JeX2G_L2CW<3JeX2Kg/27>L26<H3Ool2
7>L2BU82@Q03AS42@Q02AS44@Q03AS42@Q02AS4;@Q03<H`2?Nl4Ool00`00Oomoo`07Ool000Qoo`04
001ooe:DDY@2E[D5DY@2CW<5BU84AS429BT7AS42BU83CW<4BU84DY@37>L236<248@27>L3BU82E[D2
G_L2=Jd58@P47>L2:DX3?Nl2AS42BU82AS436<H248@2=Jd2BU838@P2E[D2DY@5E[D4DY@2E[D2F]H7
E[D;F]H3G_L2BU82;F/2Ool00`00Oomoo`0<Ool01000OolDYABU0THa1D8@14Ha1D8@0RU:0W_N0b48
1T8@0cF]0SW>0THa0SF]0QBU0fLi15Je0U:D0be[0RU:0QS60T8@0e[F0THa0U[F0U:D0TYB0bU:0QS6
0QBU0PaS0d8@0Woo12480goo0Q240T8@0SW>2D8@0Sg_0d8@0THa148@0cg_0T8@0Sg_0THa0be[0S6<
17oo00<007ooOol01goo0008Ool01000OomBU5:D0UJe1E:D0Tic1DYB14Ha0RDY1dHa0TYB0dic14YB
15:D0acW0PaS0Q240QcW0dYB0UJe0Ukg0SF]1B4811cW0RU:0cg_0THa0TYB0THa0aS60Q240SF]0TYB
0b480UJe0U:D1EJe15:D0UJe0U[F1eJe2e[F0ekg0TYB0Re[0Woo00<007ooOol037oo00@007oo5:DD
Y@96<@E240A6<@E2408YBP9kgP<Q20I240<e[@8icP96<@8e[@8DY@=W>@AF]@9BU0<]J`8YBP8HaP92
40=JeP96<@9JeP9BU09:DP<YBP8HaP8DY@8<H`=2409oo`@Q20=oo`8@Q092408icPU2408mk`=24096
<@A240<mk`92408mk`96<@<]J`8aS0Aoo`03001oogoo00Moo`0027oo00@007ooE[EF]@9BU0EF]@M:
DPA6<@8Q20M6<@9240M:DP9>L`9BU0<YBP8@Q0@DY@<Q2092409BU08Q20DLi`8YBP9:DP9>L`=:DP96
<@92409:DP<YBP88@P924096<@<Q20]BU0UF]@AJeP9F]@=Nm`AJeP9F]@=Nm`96<@8YBP9oo`03001o
ogoo00aoo`04001oob488@P2@Q03?Nl2>Lh4@Q03?Nl2@Q02:DX2Ool3:DX2@Q02BU82AS43BU82?Nl2
BU82@Q027>L3DY@2E[D2BU82Kg/3HaP2G_L28@P2Li`3E[D2G_L2?Nl2=Jd2:DX3<H`2AS42?Nl28@P3
?Nl2Li`26<H25:D3Ool25:D2AS42?Nl3@Q02?Nl9@Q02?Nl2AS42?Nl7@Q02AS43;F/2?Nl4Ool00`00
Oomoo`07Ool000Qoo`04001ooeJeE[D2DY@5E[D7BU84AS428@P7AS42@Q07BU82CW<2DY@3:DX248@4
5:D38@P2@Q02DY@28@P57>L2:DX2BU82CW<3BU82AS42@Q02BU83:DX22482@Q02AS438@P;DY@9E[D4
F]H2E[D3G_L4F]H2E[D3G_L2AS42:DX2Ool00`00Oomoo`0<Ool01000OolQ22480T8@0cg_0SW>148@
0cg_0T8@0RU:0Woo0bU:0T8@0TYB0THa0dYB0Sg_0TYB0T8@0QcW0e:D0UJe0TYB0Vmk0f<H0Ukg0R48
0W>L0eJe0Ukg0Sg_0SF]0RU:0c6<0THa0Sg_0R480cg_0W>L0QS60QBU0goo0QBU0THa0Sg_0d8@0Sg_
2D8@0Sg_0THa0Sg_1d8@0THa0be[0Sg_17oo00<007ooOol01goo0008Ool00`00OomF]@03E[D3DY@2
CW<9BU82AS428@P3AS46BU83>Lh2CW<2DY@2E[D2DY@3<H`248@25:D28@P3?Nl2DY@2G_L57>L2:DX2
F]H2CW<2BU83CW<4BU82=Jd38@P21242@Q02AS438@P=DY@;E[D2G_L9F]H3G_L2BU82:DX2Ool00`00
Oomoo`0<Ool01000OolDYABU0Sg_1D8@0TYB1D8@0Sg_0R480Woo0b480SW>0Sg_0TYB0dHa0T8@136<
0R480eJe0Vmk0Ukg0V<H0d8@0Re[0P000Vmk0e[F0Sg_0RDY0Re[0SW>0cg_0SW>0T8@0RU:0eJe0W_N
0QS60QcW0goo0QS6148@1dHa2d8@1Cg_0THa0T8@0THa1C6<17oo00<007ooOol01goo0008Ool00`00
OomF]@03E[D3DY@2CW<9BU82AS428@P3AS46BU83>Lh2CW<2DY@2E[D2DY@3<H`248@25:D28@P3?Nl2
DY@2G_L57>L2:DX2F]H2CW<2BU83CW<4BU82=Jd38@P21242@Q02AS438@P=DY@;E[D2G_L9F]H3G_L2
BU82:DX2Ool00`00Oomoo`0<Ool01000OolDYABU0Sg_1D8@0TYB1D8@0Sg_0R480Woo0b480SW>0Sg_
0TYB0dHa0T8@136<0R480eJe0Vmk0Ukg0V<H0d8@0Re[0P000Vmk0e[F0Sg_0RDY0Re[0SW>0cg_0SW>
0T8@0RU:0eJe0W_N0QS60QcW0goo0QS6148@1dHa2d8@1Cg_0THa0T8@0THa1C6<17oo00<007ooOol0
1goo0008Ool00`00OomF]@03E[D3DY@2CW<9BU82AS428@P3AS46BU83>Lh2CW<2DY@2E[D2DY@3<H`2
48@25:D28@P3?Nl2DY@2G_L57>L2:DX2F]H2CW<2BU83CW<4BU82=Jd38@P21242@Q02AS438@P=DY@;
E[D2G_L9F]H3G_L2BU82:DX2Ool00`00Oomoo`0<Ool01000OolDYABU0Sg_1D8@0TYB1D8@0Sg_0R48
0Woo0b480SW>0Sg_0TYB0dHa0T8@136<0R480eJe0Vmk0Ukg0V<H0d8@0Re[0P000Vmk0e[F0Sg_0RDY
0Re[0SW>0cg_0SW>0T8@0RU:0eJe0W_N0QS60QcW0goo0QS6148@1dHa2d8@1Cg_0THa0T8@0THa1C6<
17oo00<007ooOol01goo0008Ool00`00OomF]@06E[D2DY@4CW<3BU82AS42@Q028@P3BU82CW<2BU82
AS43BU82>Lh2AS42DY@2CW<3=Jd2<H`2AS42BU83E[D2DY@2CW<27>L38@P2CW<2E[D2AS45BU84AS42
@Q0536<2=Jd2?Nl37>L9DY@8E[D3DY@4E[D;F]H3G_L2DY@28@P2Ool00`00Oomoo`0<Ool01000OolD
YABU0T8@1Cg_0T8@0Sg_1D8@0Re[0Woo0acW13g_0SW>0dic0TYB0U:D0SF]0R480cF]0R4810aS0bDY
0SW>0QS60W_N0eJe12U:0Tic1DHa0Sg_0R480SF]0dHa0Woo0RDY0RU:0goo0QS60THa0Sg_0d8@0SW>
0T8@0Sg_0T8@0dYB14Ha2d8@0c6<0RDY17oo00<007ooOol01goo0008Ool00`00OomF]@06E[D2DY@4
CW<3BU82AS42@Q028@P3BU82CW<2BU82AS43BU82>Lh2AS42DY@2CW<3=Jd2<H`2AS42BU83E[D2DY@2
CW<27>L38@P2CW<2E[D2AS45BU84AS42@Q0536<2=Jd2?Nl37>L9DY@8E[D3DY@4E[D;F]H3G_L2DY@2
8@P2Ool00`00Oomoo`0<Ool01000OolDYABU0T8@1Cg_0T8@0Sg_1D8@0Re[0Woo0acW13g_0SW>0dic
0TYB0U:D0SF]0R480cF]0R4810aS0bDY0SW>0QS60W_N0eJe12U:0Tic1DHa0Sg_0R480SF]0dHa0Woo
0RDY0RU:0goo0QS60THa0Sg_0d8@0SW>0T8@0Sg_0T8@0dYB14Ha2d8@0c6<0RDY17oo00<007ooOol0
1goo0008Ool01000OomJeU[F0UJe1E:D0Tic1DYB0THa0T8@0RDY0dYB0T8@1dYB14Ha0TYB0T8@0acW
11BU0T8@0e:D0UJe0U:D0QcW0bDY0UJe14ic0THa0cg_0TYB0T8@0QBU1@aS0Sg_0T8@0b4814ic2E:D
2EJe45[F0Tic0QcW0Woo00<007ooOol037oo00@007oo2488@P96<@i2408YBP9kgP<Q20924096<@8i
cP<e[@9:DP@aS08YBP=BU09S609BU09>L`<Li`8icP8@Q09_N`=S608DY@8icP96<@E2408YBP8aS08m
k`ES608YBP8HaP=oo`8HaP9:DP9240=6<@8mk`9:DP8mk`E240Hmk`U240<icP8U:@Aoo`03001oogoo
00Moo`0027oo00@007ooF]IJeP9F]@EBU09>L`E:DP96<@92408U:@=:DP9240M:DPA6<@9:DP9240<L
i`@DY@9240=BU09F]@9BU08Li`<U:@9F]@A>L`96<@<mk`9:DP92408DY@D<H`8mk`9240<Q20A>L`UB
U0UF]A1JeP9>L`8Li`9oo`03001oogoo00aoo`04001oo`Q22482AS4>@Q02:DX2Nmh38@P2@Q02AS42
>Lh3=Jd2BU84<H`2:DX3DY@2HaP2DY@2CW<37>L2>Lh248@2Kg/3HaP25:D2>Lh2AS45@Q02:DX2<H`2
?Nl5HaP2:DX26<H3Ool26<H2BU82@Q03AS42?Nl2BU82?Nl5@Q06?Nl9@Q03>Lh29BT4Ool00`00Oomo
o`07Ool000Qoo`04001ooekgG_L7DY@2CW<5BU82AS42@Q028@P5AS42?Nl7AS42BU82:DX26<H348@2
36<248@25:D5CW<2DY@27>L38@P4DY@4BU83@Q02<H`248@2248336<26<H2@Q02BU837>L2DY@2CW<5
DY@2E[D2DY@BE[D7F]H2DY@26<H2Ool00`00Oomoo`0<Ool01000Ool8@PQ20TYB1d8@0THa0cg_0T8@
0Re[0Woo0bDY14YB0T8@0dHa0RU:0SW>0TYB0Tic0e[F0U:D0V<H0Ukg0cF]0SW>0QS60Vmk0e:D0QS6
0RDY0Re[0R480be[0S6<0U:D0Ukg0f<H0U:D0Re[0QcW0goo0QS60THa0Sg_0d8@0Sg_0THa1d8@0THa
0T8@0THa0d8@14Ha0T8@0cW>0RDY17oo00<007ooOol01goo0008Ool01000OomNmekg1e:D0Tic1DYB
0THa0T8@0R481DHa0Sg_1dHa0TYB0RU:0QS60a240PaS0Q240QBU1Dic0U:D0QcW0b4815:D14YB0d8@
0S6<0Q240PQ20`aS0QS60T8@0TYB0acW0U:D0Tic1E:D0UJe0U:D4UJe1e[F0U:D0QS60Woo00<007oo
Ool037oo00@007oo2488@P9:DPM24096<@<mk`92408]J`9oo`<U:@A:DP9240=6<@8YBP8icP9:DP9>
L`=JeP9BU09S609Nm`<e[@8icP8HaP9_N`=BU08HaP8U:@8]J`8Q20<]J`8aS09BU09Nm`=S609BU08]
J`8Li`=oo`8HaP96<@8mk`=2408mk`96<@M24096<@924096<@=240A6<@9240<icP8U:@Aoo`03001o
ogoo00Moo`0027oo00@007ooG_MNm`EF]@ABU0E:DPA6<@8YBPE:DP96<@9240<mk`96<@8U:@LDY@@@
Q08DY@<mk`A>L`8Li`<HaP8U:@96<@92408YBPD@Q088@PD<H`8mk`A6<@<U:@9BU09:DP9>L`=BU09F
]@9BU0eF]@=Nm`AJePENm`9>L`8Q209oo`03001oogoo00aoo`04001oo`000002AS43>Lh4?Nl2@Q03
?Nl2@Q029BT2Mkd38@P2>Lh2AS45@Q02<H`2BU82E[D5@Q02AS42@Q02HaP3;F/2>Lh26<H2Kg/3G_L2
>Lh4;F/2AS43G_L2E[D2DY@2AS43F]H2:DX2<H`27>L3Ool26<H2BU82@Q03AS42>Lh2AS44@Q03?Nl6
@Q03>Lh2@Q02?Nl2>Lh3=Jd26<H4Ool00`00Oomoo`07Ool000Qoo`04001ooekgG_L5E[D4DY@5BU84
AS42:DX5BU82AS42@Q03?Nl2AS429BT75:D448@25:D3?Nl4CW<27>L36<H29BT2AS42@Q02:DX548@2
248536<2?Nl4AS439BT2DY@2BU82CW<3DY@2E[D2DY@=E[D3G_L4F]H5G_L2CW<28@P2Ool00`00Oomo
o`0<Ool01000Ool000000THa0cW>13g_0T8@0cg_0T8@0RDY0WNm0b480SW>0THa1D8@0S6<0TYB0UJe
1D8@0THa0T8@0V<H0be[0SW>0QS60Vmk0ekg0SW>12e[0THa0ekg0UJe0U:D0THa0e[F0RU:0S6<0QcW
0goo0QS60TYB0T8@0dHa0SW>0THa148@0cg_1T8@0cW>0T8@0Sg_0SW>0cF]0QS617oo00<007ooOol0
1goo0008Ool01000OomJeU[F1E:D0Tic0TYB0THa0dYB14Ha0R482DHa0d8@0SF]10Q20QBU1a240QBU
0cF]0Tic0TYB0QcW0aS60QcW11BU1A2410aS0PQ20a240TYB14Ha0b4814ic1E:D0UJe15:D2eJe0e[F
15Je1E[F0Tic0QS60Woo00<007ooOol037oo00@007oo36<<H`9:DPE6<@92409:DP<mk`92408YBP9o
o`<U:@924096<@8mk`=2408]J`9[FP9BU0M:DP9BU09S60<icP8e[@8Q209[FPEBU09F]@9JeP9BU0=>
L`924096<@EF]@8YBP8e[@8U:@=oo`8Li`96<@E2408icP96<A1240A:DP96<@<icP8U:@Aoo`03001o
ogoo00Moo`0027oo00@007ooF]IJePEBU09>L`9:DP96<@=:DPA6<@8Q20U6<@=2408e[@@8@P8DY@L@
Q08DY@<e[@9>L`9:DP8Li`<HaP8Li`@DY@D@Q0@<H`88@P<@Q09:DPA6<@<Q20A>L`EBU09F]@ABU0]F
]@=JePAF]@EJeP9>L`8HaP9oo`03001oogoo00aoo`04001oo`aS36<2BU85AS42@Q02BU83?Nl2@Q02
:DX2Ool39BT2@Q02AS42?Nl3@Q02;F/2JeX2DY@7BU82DY@2HaP3>Lh2=Jd28@P2JeX5DY@2E[D2F]H2
DY@3CW<2@Q02AS45E[D2:DX2=Jd29BT3Ool27>L2AS45@Q02>Lh2AS4@@Q04BU82AS43>Lh29BT4Ool0
0`00Oomoo`07Ool000Qoo`04001ooe[FF]H5DY@2CW<2BU82AS43BU84AS428@P9AS43@Q02=Jd42482
5:D748@25:D3=Jd2CW<2BU827>L36<H27>L45:D548@436<2248348@2BU84AS438@P4CW<5DY@2E[D4
DY@;E[D3F]H4E[D5F]H2CW<26<H2Ool00`00Oomoo`0<Ool01000Ool<H`aS0TYB1DHa0T8@0TYB0cg_
0T8@0RU:0Woo0bDY0T8@0THa0Sg_0d8@0Re[0V]J0U:D1dYB0U:D0V<H0cW>0SF]0R480V]J1E:D0UJe
0U[F0U:D0dic0T8@0THa1EJe0RU:0SF]0RDY0goo0QcW0THa1D8@0SW>0THa448@14YB0THa0cW>0RDY
17oo00<007ooOol01goo0008Ool01000OomNmekg0U[F0e:D0Tic0TYB2DHa0RDY0dYB0THa0T8@0TYB
0dHa0Re[0P@Q0PaS0QBU0b480RDY0Q240QBU0cW>14ic0RDY0aS60QcW0QBU0Q242`aS0cF]0SW>14Ha
0bDY1Tic0e:D0UJe1U:D1eJe0U[F1EJe15[F0ekg0Tic0QS60Woo00<007ooOol037oo00@007oo1244
8@8mk`=24096<@92409:DP=24096<@8]J`9kgP<Q20924096<@8icP<Q208mk`9[FP9JeP9BU0=F]@9>
L`9BU09kgP<]J`8aS08YBP9BU0=F]@8icP96<@92409:DPE6<@9:DP9JePDe[@8icP8Q20=kgP8Li`96
<@8mk`=6<@8mka924096<@92408mk`<aS08Q20Aoo`03001oogoo00Moo`0027oo00@007ooG_MNm`9J
eP=BU09>L`9:DPU6<@8U:@=:DP96<@92409:DP=6<@8]J`848@8<H`8DY@<Q208U:@8@Q08DY@<icPA>
L`8U:@<HaP8Li`8DY@8@Q0/<H`<e[@8icPA6<@<U:@I>L`=BU09F]@IBU0MF]@9JePEF]@AJeP=Nm`9>
L`8HaP9oo`03001oogoo00aoo`04001oo`@Q1242?Nl3@Q02AS42@Q02BU83@Q02AS42;F/2Nmh38@P2
@Q02AS42>Lh38@P2?Nl2JeX2F]H2DY@3E[D2CW<2DY@2Nmh3;F/2<H`2:DX2DY@3E[D2>Lh2AS42@Q02
BU85AS42BU82F]H5=Jd2>Lh28@P3Nmh27>L2AS42?Nl3AS42?NlB@Q02AS42@Q02?Nl3<H`28@P4Ool0
0`00Oomoo`07Ool000Qoo`04001ooe[FF]H2E[D7DY@7BU82@Q02:DX3BU82AS42?Nl5AS425:D22482
8@P2AS45BU82>Lh248@7BU82@Q036<H27>L25:D248@936<27>L3BU82=Jd2>Lh2@Q03:DX2CW<2BU82
DY@5CW<4DY@2E[D3DY@4E[D5F]H2G_L7F]H2BU827>L2Ool00`00Oomoo`0<Ool01000Ool8@PQ20T8@
0cg_0T8@1cg_0SW>0Re[0W>L0aS61THa0aS60V<H0W>L0S6<0RDY0aBU0P@Q0RDY0V<H0b480Re[0SW>
0SF]0e[F0T8@0Sg_148@1DHa0U[F0TYB0a240Ukg0RU:0SW>0g>L0RDY0THa0T8@0dHa0T8@0THa1d8@
0Sg_0T8@1cg_0T8@0THa0cF]0RU:17oo00<007ooOol01goo0008Ool01000OomJeU[F0UJe1e:D1dYB
0T8@0RU:0dYB0THa0Sg_1DHa0QBU0PQ20R480THa1DYB0SW>0Q241dYB0T8@0aS60QcW0QBU0Q242@aS
0QcW0dYB0SF]0SW>0T8@0bU:0Tic0TYB0U:D1Dic15:D0UJe0e:D15Je1E[F0Ukg1e[F0TYB0QcW0Woo
00<007ooOol037oo00@007oo2488@P9240<mk`9240Lmk`8icP8]J`9cW0<HaPI6<@<HaP9S609cW08a
S08U:@<DY@848@8U:@9S60<Q208]J`8icP8e[@=JeP92408mk`A240E6<@9JeP9:DP<@Q09Nm`8YBP8i
cP=cW08U:@96<@9240=6<@924096<@M2408mk`9240Lmk`924096<@<e[@8YBPAoo`03001oogoo00Mo
o`0027oo00@007ooF]IJePEF]@9>L`9:DP9>L`E:DP8mk`8YBP=:DP924096<@8icP=6<@88@P8HaP9>
L`9:DPE2408U:@8@Q0<mk`9>L`96<@9BU0<YBP8HaP8DY@@8@P<<H`8@Q08HaP96<@<mk`8@Q096<@8i
cP<aS09>L`9BU0E>L`]BU0IF]@EJePANm`=S609:DP8Li`9oo`03001oogoo00aoo`04001oo`@Q1242
AS43@Q04AS47@Q02<H`2Nmh38@P2AS42BU82AS437>L2Ool2BU829BT28@P3<H`2;F/2<H`2Mkd3;F/2
<H`2AS42<H`3F]H2DY@2F]H2BU82CW<3E[D2BU82=Jd29BT336<2Kg/29BT2>Lh3HaP29BT4@Q03AS48
@Q03BU82?Nl4AS47@Q05=Jd28@P4Ool00`00Oomoo`07Ool000Qoo`04001ooe[FF]H5E[D2CW<2BU82
CW<5BU82?Nl2:DX3BU82@Q02AS42>Lh3AS4224826<H2CW<2BU85@Q029BT248@3?Nl2CW<2AS42DY@3
:DX26<H25:D4248336<248@26<H2AS43?Nl248@2AS42>Lh3<H`2CW<2DY@5CW<;DY@6E[D5F]H4G_L3
HaP2BU827>L2Ool00`00Oomoo`0<Ool01000Ool48@@Q0THa0d8@14Ha1d8@0S6<0W_N0b480THa0TYB
0THa0acW0Woo0TYB0RDY0R480c6<0Re[0S6<0WNm0be[0S6<0THa0S6<0e[F0U:D0U[F0TYB0Tic0eJe
0TYB0SF]0RDY0`aS0Vmk0RDY0SW>0f<H0RDY148@0dHa248@0dYB0Sg_14Ha1d8@1CF]0R4817oo00<0
07ooOol01goo0008Ool01000OomNmekg0UJe1E:D14YB1dHa0RDY0dYB14Ha0T8@0cF]0PQ20SF]0TYB
0THa0be[0Q240PQ20Q240c6<0U:D14ic0e:D0SW>0QBU0Q240PaS0aBU0S6<0SW>0Q240`Q20Q240T8@
0SW>0cF]0TYB14ic3U:D2eJe0U[F0V<H0eJe0Tic0QBU0Woo00<007ooOol037oo00@007oo12448@96
<@E24096<@8mk`=2408mk`8aS09cW0<Q2096<@8icP9:DP<HaP9kgP8Li`80008Li`<mk`9BU09Nm`9_
N`<icP8Q2092408Q20<aS08mk`9Nm`9W>@9F]@=2408DY@8Q209240=JeP9oo`8<H`9:DP=JeP8aS0M2
408mk`924096<@E2408mk`e240<e[@8U:@Aoo`03001oogoo00Moo`0027oo00@007ooG_MNm`9F]@EB
U0A:DPM6<@8U:@=:DPA6<@9240<e[@88@P8e[@9:DP96<@<]J`8@Q088@P8@Q0<aS09BU0A>L`=BU08i
cP8DY@8@Q08<H`<DY@8aS08icP8@Q0<8@P8@Q092408icP<e[@9:DPA>L`iBU0]F]@9JeP9S60=F]@9>
L`8DY@9oo`03001oogoo00aoo`04001oo`@Q1242AS45@Q02AS42?Nl3@Q02?Nl2<H`2Li`38@P2AS42
>Lh2BU836<H2Nmh27>L200027>L3?Nl2DY@2G_L2Kg/3>Lh28@P2@Q028@P3<H`2?Nl2G_L2IcT2E[D3
@Q025:D28@P2@Q03F]H2Ool236<2BU83F]H2<H`7@Q02?Nl2@Q02AS45@Q02?Nl=@Q03=Jd29BT4Ool0
0`00Oomoo`07Ool000Qoo`04001ooekgG_L2F]H3E[D2DY@7BU84@Q02;F/3BU84AS42@Q03AS422482
7>L948@236<248@3;F/9BU82DY@2AS42?Nl2;F/36<H236<4248336<248@2@Q02=Jd3>Lh4CW<;DY@>
E[D2G_L4F]H3G_L2DY@248@2Ool00`00Oomoo`0<Ool01000Ool000001d8@0TYB0Sg_1DHa0S6<0W>L
0acW0T8@0THa0RU:0aS60W>L0THa0Ukg0V<H0e[F0Tic0THa0U[F0c6<0SF]0Re[0THa0be[11240P00
0Q240cW>14ic0U[F0dYB0V<H0Q241Dic0S6<0Sg_2d8@0Sg_2D8@0dHa0SW>0TYB0Sg_0cW>0QBU17oo
00<007ooOol01goo0008Ool01000OomNmekg0U[F0eJe0U:D1dYB148@0Re[0dYB14Ha0T8@0dHa0PQ2
0QcW2A240PaS0Q240be[2DYB0U:D0THa0Sg_0Re[0aS60PaS10Q20`aS0Q240T8@0SF]0cW>14ic2e:D
3UJe0Ukg15[F0ekg0U:D0Q240Woo00<007ooOol037oo00@007oo000000M2409:DP8mk`E6<@8aS09c
W0<Li`924096<@8YBP<HaP9cW096<@9Nm`9S60=JeP9>L`96<@9JeP<aS08e[@8]J`96<@<]J`@@Q080
008@Q0<icPA>L`9JeP=:DP9S608@Q0E>L`8aS08mk`]2408mk`U240=6<@8icP9:DP8mk`<icP8DY@Ao
o`03001oogoo00Moo`0027oo00@007ooG_MNm`9JeP=F]@9BU0M:DPA2408]J`=:DPA6<@9240=6<@88
@P8Li`T@Q08<H`8@Q0<]J`U:DP9BU096<@8mk`8]J`<HaP8<H`@8@P<<H`8@Q092408e[@<icPA>L`]B
U0iF]@9Nm`AJeP=Nm`9BU08@Q09oo`03001oogoo00aoo`04001oo`000007@Q02BU82?Nl5AS42<H`2
Li`37>L2@Q02AS42:DX36<H2Li`2AS42G_L2HaP3F]H2CW<2AS42F]H3<H`2=Jd2;F/2AS43;F/448@2
000248@3>Lh4CW<2F]H3BU82HaP248@5CW<2<H`2?Nl;@Q02?Nl9@Q03AS42>Lh2BU82?Nl3>Lh25:D4
Ool00`00Oomoo`07Ool000Qoo`03001ooe[F00=JeP=F]@9BU09:DP9>L`=:DP96<@92408]J`=>L`92
408e[@96<@<]J`@8@P8<H`8@Q0L<H`8@Q0<]J`8Q209:DPE6<@8icP8Li`8@Q0h8@P8@Q08mk`8e[@<m
k`9:DPA>L`iBU0UF]@9Nm`9F]@ENm`9BU08@Q09oo`03001oogoo00aoo`04001oo`000002@Q03?Nl4
@Q07?Nl2<H`2IcT39BT4>Lh2:DX35:D2IcT2@Q02BU82?Nl5AS42BU82DY@3>Lh2@Q02:DX26<H39BT2
=Jd2DY@2HaP2G_L3F]H2BU87AS42JeX236<2E[D3AS42=Jd9@Q02AS42BU82@Q03AS42?Nl2AS42?Nl3
BU82=Jd2AS42@Q03=Jd25:D4Ool00`00Oomoo`07Ool000Qoo`03001ooe[F00=JeP=F]@9BU09:DP9>
L`=:DP96<@92408]J`=>L`92408e[@96<@<]J`@8@P8<H`8@Q0L<H`8@Q0<]J`8Q209:DPE6<@8icP8L
i`8@Q0h8@P8@Q08mk`8e[@<mk`9:DPA>L`iBU0UF]@9Nm`9F]@ENm`9BU08@Q09oo`03001oogoo00ao
o`04001oo`000002@Q03?Nl4@Q07?Nl2<H`2IcT39BT4>Lh2:DX35:D2IcT2@Q02BU82?Nl5AS42BU82
DY@3>Lh2@Q02:DX26<H39BT2=Jd2DY@2HaP2G_L3F]H2BU87AS42JeX236<2E[D3AS42=Jd9@Q02AS42
BU82@Q03AS42?Nl2AS42?Nl3BU82=Jd2AS42@Q03=Jd25:D4Ool00`00Oomoo`07Ool000Qoo`03001o
oe[F00=JeP=F]@A>L`9:DP=6<@A2408e[@E6<@8U:@D8@P848@88@P8@Q08DY@D8@P8@Q08HaP<U:@@L
i`8U:@<HaP8@Q08DY@8@Q0D8@P8<H`T8@P8mk`8]J`=6<@A>L`9:DP=BU09F]@ABU09F]@=BU09JeP9B
U09JeP=F]@9Nm`AF]@=Nm`9F]@8@Q09oo`03001oogoo00aoo`04001oo`000002@Q03?Nl2AS47@Q02
BU82>Lh2HaP3:DX2=Jd2HaP2IcT5F]H2AS42?Nl2@Q03E[D2F]H2HaP2E[D3@Q02HaP2CW<2E[D3G_L2
F]H2DY@2@Q02BU83AS42?Nl4@Q03BU82JeX236<2HaP3=Jd2>Lh2@Q02AS43@Q02=Jd4@Q02>Lh3@Q02
>Lh2@Q02?Nl3AS42>Lh2CW<2@Q03?Nl236<4Ool00`00Oomoo`07Ool000Qoo`03001ooe[F00=JeP=F
]@A>L`9:DP=6<@A2408e[@E6<@8U:@D8@P848@88@P8@Q08DY@D8@P8@Q08HaP<U:@@Li`8U:@<HaP8@
Q08DY@8@Q0D8@P8<H`T8@P8mk`8]J`=6<@A>L`9:DP=BU09F]@ABU09F]@=BU09JeP9BU09JeP=F]@9N
m`AF]@=Nm`9F]@8@Q09oo`03001oogoo00aoo`04001oo`000002@Q03?Nl2AS47@Q02BU82>Lh2HaP3
:DX2=Jd2HaP2IcT5F]H2AS42?Nl2@Q03E[D2F]H2HaP2E[D3@Q02HaP2CW<2E[D3G_L2F]H2DY@2@Q02
BU83AS42?Nl4@Q03BU82JeX236<2HaP3=Jd2>Lh2@Q02AS43@Q02=Jd4@Q02>Lh3@Q02>Lh2@Q02?Nl3
AS42>Lh2CW<2@Q03?Nl236<4Ool00`00Oomoo`07Ool000Qoo`04001ooekgG_L5E[D2DY@2BU82AS43
BU84@Q02>Lh3BU82AS428@P9248236<248@37>L2;F/2>Lh2@Q039BT26<H248@26<H348@436<248@5
248236<7248236<2?Nl29BT9BU83CW<2E[D9DY@6E[D3F]H6G_L3F]H2E[D236<2Ool00`00Oomoo`0<
Ool01000Ool000000T8@0cg_0THa0T8@0THa0cg_0THa0SW>0UJe0c6<0RU:0TYB0UJe0cg_0THa1UJe
0e:D0S6<0Q240QcW0bDY0TYB0U:D0T8@0dYB0Tic2D8@0Sg_0TYB0Tic0eJe0V]J0QS60W>L0bU:0Sg_
1dHa0Sg_0T8@0THa0T8@0dYB0T8@0TYB0T8@0dHa1Sg_0cW>0PaS17oo00<007ooOol01goo0008Ool0
1000OomNmekg1EJe0U:D0TYB0THa0dYB148@0SW>0dYB0THa0R482@Q20PaS0Q240acW0Re[0SW>0T8@
0bDY0QS60Q240QS60a2410aS0Q241@Q20PaS1`Q20PaS0Sg_0RDY2DYB0dic0UJe2E:D1UJe0e[F1Ukg
0e[F0UJe0PaS0Woo00<007ooOol037oo00@007oo0000009240<mk`96<@924096<@<mk`96<@8icP9F
]@<aS08YBP9:DP9F]@<mk`96<@IF]@=BU08aS08@Q08Li`<U:@9:DP9BU09240=:DP9>L`U2408mk`9:
DP9>L`=F]@9[FP8HaP9cW0<YBP8mk`M6<@8mk`924096<@9240=:DP92409:DP9240=6<@Hmk`<icP8<
H`Aoo`03001oogoo00Moo`0027oo00@007ooG_MNm`9JeP=F]@9BU09>L`9:DP=6<@A2408mk`E6<@8Q
20848@D8@P8@Q08YBP8mk`E2408e[@8HaP<Q208Li`@DY@<@Q08<H`8@Q0@<H`<48@88@P8<H`8DY@<U
:@8e[@8mk`8Li`=:DP9>L`9:DP9>L`]BU0EF]@UJePANm`=JeP9BU08@Q09oo`03001oogoo00aoo`04
001oo`00000>@Q02AS42?Nl2CW<3<H`2:DX2@Q02G_L3DY@4E[D2>Lh25:D336<248@2:DX2AS43@Q02
?Nl2AS42=Jd5AS42@Q02?Nl7AS42DY@2AS43<H`2BU8236<2Ool37>L2>Lh2@Q02?Nl5@Q04AS45@Q02
>Lh4?Nl5@Q02AS42?Nl3AS422484Ool00`00Oomoo`07Ool000Qoo`04001ooekgG_L2F]H3E[D2DY@2
CW<2BU83AS44@Q02?Nl5AS428@P21245248248@2:DX2?Nl5@Q02=Jd26<H38@P27>L45:D348@236<2
48@436<31242248236<25:D39BT2=Jd2?Nl27>L3BU82CW<2BU82CW<;DY@5E[D9F]H4G_L3F]H2DY@2
48@2Ool00`00Oomoo`0<Ool01000Ool000003T8@0THa0Sg_0Tic0c6<0RU:0T8@0Ukg0e:D15Je0SW>
0QBU0`aS0Q240RU:0THa0d8@0Sg_0THa0SF]1DHa0T8@0Sg_1dHa0U:D0THa0c6<0TYB0PaS0Woo0acW
0SW>0T8@0Sg_1D8@14Ha1D8@0SW>13g_1D8@0THa0Sg_0dHa0PQ217oo00<007ooOol01goo0008Ool0
1000OomNmekg0U[F0eJe0U:D0Tic0TYB0dHa148@0Sg_1DHa0R480P@Q1@Q20Q240RU:0Sg_1D8@0SF]
0QS60b480QcW11BU0a240PaS0Q2410aS0`@Q0PQ20PaS0QBU0bDY0SF]0Sg_0QcW0dYB0Tic0TYB0Tic
2e:D1EJe2E[F15kg0e[F0U:D0Q240Woo00<007ooOol037oo00@007oo000000i24096<@8mk`9>L`<a
S08YBP92409Nm`=BU0AF]@8icP8DY@<<H`8@Q08YBP96<@=2408mk`96<@8e[@E6<@92408mk`M6<@9B
U096<@<aS09:DP8<H`9oo`<Li`8icP92408mk`E240A6<@E2408icP@mk`E24096<@8mk`=6<@88@PAo
o`03001oogoo00Moo`0027oo00<007ooG_L00ekg0eJe0U:D14YB2D8@0dHa0Sg_0R480P@Q0`aS0RDY
0SW>0Sg_0SW>0b481PaS0acW0QS60Q240QBU1A240PaS0Q241`Q20PaS0S6<0dHa0SW>0T8@0QS61DYB
0THa0Tic0e:D0Tic1U:D2EJe0e[F0Ukg0U[F0Ukg1E[F0PQ20Woo00<007ooOol037oo00@007oo0000
008mk`i6<@8mk`9:DP<mk`8]J`9JeP9cW0=>L`8]J`8Li`8@Q08HaP=6<@9S609JeP9W>@<e[@96<@9>
L`9240=6<@A:DP8mk`9>L`E2408icPDHaP8Li`8U:@9oo`<Q2092409:DPDmk`I24096<@<mk`A6<@9:
DP<mk`96<@A240<mk`848@Aoo`03001oogoo00Moo`0027oo00<007ooG_L00ekg0eJe0U:D14YB2D8@
0dHa0Sg_0R480P@Q0`aS0RDY0SW>0Sg_0SW>0b481PaS0acW0QS60Q240QBU1A240PaS0Q241`Q20PaS
0S6<0dHa0SW>0T8@0QS61DYB0THa0Tic0e:D0Tic1U:D2EJe0e[F0Ukg0U[F0Ukg1E[F0PQ20Woo00<0
07ooOol037oo00@007oo0000008mk`i6<@8mk`9:DP<mk`8]J`9JeP9cW0=>L`8]J`8Li`8@Q08HaP=6
<@9S609JeP9W>@<e[@96<@9>L`9240=6<@A:DP8mk`9>L`E2408icPDHaP8Li`8U:@9oo`<Q2092409:
DPDmk`I24096<@<mk`A6<@9:DP<mk`96<@A240<mk`848@Aoo`03001oogoo00Moo`0027oo00@007oo
F]IJeP9Nm`=JeP9F]@9BU09>L`=:DPI240E6<@8Q208U:@<mk`8e[@8DY@8<H`8@Q0<<H`88@P8<H`88
@PDLi`8DY@8HaPD@Q08DY@8Q20/8@P<DY@96<@8icP8Q20E>L`M:DPA>L`9BU0UF]@9JeP=S609F]@AJ
eP=Nm`9JeP88@P9oo`03001oogoo00aoo`04001oo`000002>Lh9?Nl5@Q02BU82AS43=Jd2?Nl2BU82
AS439BT25:D2HaP2F]H2DY@5CW<2@Q02CW<3<H`2>Lh2CW<2BU83F]H2HaP2AS42?Nl2AS43?Nl2AS44
E[D3@Q02>Lh236<2Nmh37>L2?Nl2BU85AS42BU86@Q03?Nl2AS44@Q03>Lh2@Q02BU82?Nl3@Q020004
Ool00`00Oomoo`07Ool000Qoo`04001ooe[FF]H2G_L3F]H2E[D2DY@2CW<3BU86@Q05AS428@P29BT3
?Nl2=Jd25:D236<248@336<2248236<224857>L25:D26<H548@25:D28@P;24835:D2AS42>Lh28@P5
CW<7BU84CW<2DY@9E[D2F]H3HaP2E[D4F]H3G_L2F]H22482Ool00`00Oomoo`0<Ool01000Ool00000
0SW>2Cg_1D8@0TYB0THa0cF]0Sg_0TYB0THa0bDY0QBU0V<H0U[F0U:D1Dic0T8@0Tic0c6<0SW>0Tic
0TYB0e[F0V<H0THa0Sg_0THa0cg_0THa15Je0d8@0SW>0PaS0W_N0acW0Sg_0TYB1DHa0TYB1T8@0cg_
0THa148@0cW>0T8@0TYB0Sg_0d8@0P0017oo00<007ooOol01goo0008Ool01000OomJeU[F0Ukg0e[F
0UJe0U:D1DYB0THa0T8@0THa0dYB148@0S6<0bU:0S6<0P002`Q20PaS0acW0R480QS60R480c6<0Sg_
0T8@0QS640Q20SF]0RU:1DYB0Tic1E:D0TYB0Tic2EJe15[F1Ekg15[F0eJe0U[F0PQ20Woo00<007oo
Ool037oo00@007oo0000008icP=2408mk`924096<@<mk`92409:DPDicP8YBP@e[@<icP8Q209Nm`9>
L`96<@=:DPAF]@9JeP=F]@9BU09S609:DP<icP8@Q08HaP8]J`9>L`=6<@A2409:DP=S609F]@8mk`9S
60<YBPA2408icP<mk`A6<@92408mk`=2408mk`924096<@<icP96<@M2408000Aoo`03001oogoo00Mo
o`0027oo00@007ooF]IJeP9Nm`=JeP9F]@9BU0E:DP96<@924096<@=:DPA2408aS0<YBP8aS08000/8
@P8<H`<Li`8Q208HaP8Q20<aS08mk`92408HaQ08@P8e[@8YBPE:DP9>L`EBU09:DP9>L`UF]@AJePEN
m`AJeP=F]@9JeP88@P9oo`03001oogoo00aoo`04001oo`000002>Lh3@Q02?Nl2@Q02AS43?Nl2@Q02
BU85>Lh2:DX4=Jd3>Lh28@P2G_L2CW<2AS43BU84E[D2F]H3E[D2DY@2HaP2BU83>Lh248@26<H2;F/2
CW<3AS44@Q02BU83HaP2E[D2?Nl2HaP3:DX4@Q02>Lh3?Nl4AS42@Q02?Nl3@Q02?Nl2@Q02AS43>Lh2
AS47@Q020004Ool00`00Oomoo`07Ool000Qoo`04001ooe[FF]H2E[D3DY@2E[D2DY@5BU82AS42?Nl2
AS43@Q02AS42?Nl28@P324825:D21244248336<248@28@P2<H`3:DX2?Nl4AS43@Q02?Nl27>L436<3
124224841243248236<29BT2=Jd5BU87CW<6DY@2E[D3DY@2F]H4E[D3G_L2F]H9E[D22482Ool00`00
Oomoo`0<Ool01000Ool000000T8@0dHa148@0THa1D8@0TYB0T8@0cg_0THa0RU:0U[F0fLi0Re[0VLi
0TYB0Tic1DYB0Sg_0RU:0cW>0RU:0QcW0Re[0acW0Re[0TYB0U[F0Tic0dHa0TYB1d8@0U[F0S6<0Tic
0c6<148@0THa0cg_0THa0Sg_2D8@14Ha0cg_14Ha0T8@0dHa0P0017oo00<007ooOol01goo0008Ool0
1000OomJeU[F0UJe0e:D0UJe0U:D1DYB0THa0Sg_0THa0d8@0THa0Sg_0R480`Q20QBU0P@Q10Q20`aS
0Q240R480S6<0bU:0Sg_14Ha0d8@0Sg_0QcW10aS0`@Q0PQ210@Q0`Q20PaS0RDY0SF]1DYB1dic1U:D
0UJe0e:D0U[F15Je0ekg0U[F2EJe0PQ20Woo00<007ooOol037oo00@007oo0000009240=6<@A24096
<@E2409:DP9240<mk`96<@8YBP9JeP=W>@8]J`9W>@9:DP9>L`E:DP8mk`8YBP<icP8YBP8Li`8]J`<L
i`8]J`9:DP9JeP9>L`=6<@9:DPM2409JeP8aS09>L`<aS0A24096<@<mk`96<@8mk`U240A6<@<mk`A6
<@9240=6<@8000Aoo`03001oogoo00Moo`0027oo00<007ooE[D01UJe15:D0TYB1DHa148@0dYB13g_
0PaS0`Q20QBU0P@Q0PQ20R480bU:12481Cg_0T8@0THa0S6<0d8@0S6<0PaS0Q240QS60aBU0PQ210@Q
1@Q20RU:0Sg_0dHa0TYB0Tic0TYB0e:D0Tic0UJe15:D1EJe1e[F0UJe0U[F1eJe0P@Q0Woo00<007oo
Ool037oo00@007oo0000008mk`=6<@8mk`92409:DP=24096<@9>L`Lmk`8]J`9JeP=cW08aS09_N`96
<@8e[@<HaP8Q208]J`8Q20D]J`8icP8mk`<YBP8U:@9BU09Nm`8icP=Nm`96<@9JeP9240=6<@9BU092
408e[@<icPA24096<@]240=6<@I240<mk`A240Dmk`8000Aoo`03001oogoo00Moo`0027oo00<007oo
E[D01UJe15:D0TYB1DHa148@0dYB13g_0PaS0`Q20QBU0P@Q0PQ20R480bU:12481Cg_0T8@0THa0S6<
0d8@0S6<0PaS0Q240QS60aBU0PQ210@Q1@Q20RU:0Sg_0dHa0TYB0Tic0TYB0e:D0Tic0UJe15:D1EJe
1e[F0UJe0U[F1eJe0P@Q0Woo00<007ooOol037oo00@007oo0000008mk`=6<@8mk`92409:DP=24096
<@9>L`Lmk`8]J`9JeP=cW08aS09_N`96<@8e[@<HaP8Q208]J`8Q20D]J`8icP8mk`<YBP8U:@9BU09N
m`8icP=Nm`96<@9JeP9240=6<@9BU092408e[@<icPA24096<@]240=6<@I240<mk`A240Dmk`8000Ao
o`03001oogoo00Moo`0027oo00<007ooE[D01UJe15:D0TYB1DHa148@0dYB13g_0PaS0`Q20QBU0P@Q
0PQ20R480bU:12481Cg_0T8@0THa0S6<0d8@0S6<0PaS0Q240QS60aBU0PQ210@Q1@Q20RU:0Sg_0dHa
0TYB0Tic0TYB0e:D0Tic0UJe15:D1EJe1e[F0UJe0U[F1eJe0P@Q0Woo00<007ooOol037oo00@007oo
0000008mk`=6<@8mk`92409:DP=24096<@9>L`Lmk`8]J`9JeP=cW08aS09_N`96<@8e[@<HaP8Q208]
J`8Q20D]J`8icP8mk`<YBP8U:@9BU09Nm`8icP=Nm`96<@9JeP9240=6<@9BU092408e[@<icPA24096
<@]240=6<@I240<mk`A240Dmk`8000Aoo`03001oogoo00Moo`0027oo00<007ooE[D00eJe0e:D15Je
0Tic0dYB0THa0T8@0THa0dYB0T8@0SF]0Q240`Q20SF]0RU:0S6<0Q240`Q20PaS0PQ20Q240cW>0THa
0Sg_0RU:0a2410Q20Q240Sg_0c6<0Re[1`@Q0PaS0R481DHa0TYB15:D0dic1U:D0UJe0e[F0UJe0U[F
0UJe1E[F1eJe0U:D0PQ20Woo00<007ooOol037oo00@007oo000000E6<@8mk`8icPLmk`96<@DicP92
408aS09[FP=W>@8Q208Li`8aS08icP=>L`9F]@9W>@9>L`=6<@8U:@8icPES609JeP9[FP9:DP8Li`<]
J`8e[@9BU09JeP=>L`9F]@92408]J`<icP92408icPE24096<@8mk`96<@9240<icP96<@8mk`E2408m
k`A240=6<@848@Aoo`03001oogoo00Moo`0027oo00<007ooE[D00eJe0e:D15Je0Tic0dYB0THa0T8@
0THa0dYB0T8@0SF]0Q240`Q20SF]0RU:0S6<0Q240`Q20PaS0PQ20Q240cW>0THa0Sg_0RU:0a2410Q2
0Q240Sg_0c6<0Re[1`@Q0PaS0R481DHa0TYB15:D0dic1U:D0UJe0e[F0UJe0U[F0UJe1E[F1eJe0U:D
0PQ20Woo00<007ooOol037oo00@007oo000000E6<@8mk`8icPLmk`96<@DicP92408aS09[FP=W>@8Q
208Li`8aS08icP=>L`9F]@9W>@9>L`=6<@8U:@8icPES609JeP9[FP9:DP8Li`<]J`8e[@9BU09JeP=>
L`9F]@92408]J`<icP92408icPE24096<@8mk`96<@9240<icP96<@8mk`E2408mk`A240=6<@848@Ao
o`03001oogoo00Moo`0027oo00@007ooG_MNm`EF]@9JeP9BU0E:DP96<@92409:DP=2408mk`8icPD]
J`8mk`8icP848@T8@P8<H`<DY@A6<@8YBPL<H`8YBP9240<mk`8icP8aS08@Q0<48@88@P8U:@9240E6
<@9:DP9>L`EBU0IF]@=JeP9F]@AJeP=F]@9JeP9F]@9JePEF]@88@P9oo`03001oogoo00aoo`04001o
o`000002?Nl3AS42>Lh2@Q02CW<5AS42BU82?Nl3@Q02AS42=Jd2?Nl3BU822482>Lh2DY@2E[D3AS42
@Q02AS45F]H29BT2:DX2>Lh3F]H2@Q02F]H2>Lh29BT3?Nl29BT2>Lh2AS43CW<2G_L2BU82:DX5AS44
@Q03AS48@Q03?Nl2AS47@Q02?Nl7@Q021244Ool00`00Oomoo`07Ool000Qoo`04001ooekgG_L5E[D2
F]H2DY@5BU82AS42@Q02BU83@Q02?Nl2>Lh5;F/2?Nl2>Lh21249248236<35:D4AS42:DX736<2:DX2
@Q03?Nl2>Lh2<H`248@3124224829BT2@Q05AS42BU82CW<5DY@6E[D3F]H2E[D4F]H3E[D2F]H2E[D2
F]H5E[D22482Ool00`00Oomoo`0<Ool01000Ool000000Sg_0dHa0SW>0T8@0Tic1DHa0TYB0Sg_0d8@
0THa0SF]0Sg_0dYB0PQ20SW>0U:D0UJe0dHa0T8@0THa1E[F0RDY0RU:0SW>0e[F0T8@0U[F0SW>0RDY
0cg_0RDY0SW>0THa0dic0Ukg0TYB0RU:1DHa148@0dHa248@0cg_0THa1d8@0Sg_1d8@0P@Q17oo00<0
07ooOol01goo0008Ool00`00OomF]@08E[D2DY@5CW<2BU82@Q02AS43@Q02?Nl4>Lh3<H`2>Lh27>L2
124;248348@2@Q02AS42;F/5248248@4@Q03?Nl2>Lh2=Jd2:DX38@P224828@P5AS42BU84CW<7DY@7
E[D2F]H=E[D3G_L2F]H21242Ool00`00Oomoo`0<Ool01000Ool000001DHa0Sg_148@0cW>0T8@0TYB
0Sg_0dHa0Sg_0T8@0Sg_0dHa0RU:0T8@0U[F1dHa14YB0fLi0QS60RU:0Sg_1E[F0Tic0Re[0QS60bU:
0R480PQ20QS60cF]0THa0U[F0RDY0d8@0Sg_0T8@0Sg_1D8@0THa0T8@0THa2D8@0dHa0T8@0THa0T8@
0cg_0P0017oo00<007ooOol01goo0008Ool00`00OomF]@08E[D2DY@5CW<2BU82@Q02AS43@Q02?Nl4
>Lh3<H`2>Lh27>L2124;248348@2@Q02AS42;F/5248248@4@Q03?Nl2>Lh2=Jd2:DX38@P224828@P5
AS42BU84CW<7DY@7E[D2F]H=E[D3G_L2F]H21242Ool00`00Oomoo`0<Ool01000Ool000001DHa0Sg_
148@0cW>0T8@0TYB0Sg_0dHa0Sg_0T8@0Sg_0dHa0RU:0T8@0U[F1dHa14YB0fLi0QS60RU:0Sg_1E[F
0Tic0Re[0QS60bU:0R480PQ20QS60cF]0THa0U[F0RDY0d8@0Sg_0T8@0Sg_1D8@0THa0T8@0THa2D8@
0dHa0T8@0THa0T8@0cg_0P0017oo00<007ooOol01goo0008Ool00`00OomF]@06E[D2DY@2E[D2DY@3
CW<4AS47@Q02?Nl2@Q03?Nl2;F/200021242248548@4248336<2?Nl2AS42:DX52482<H`4>Lh37>L6
12432482:DX27>L5AS44BU85DY@2E[D2DY@4E[D3DY@4E[D5F]H2E[D9F]H22482Ool00`00Oomoo`0<
Ool01000Ool000001d8@13g_0d8@14Ha0T8@0dHa0Sg_0T8@0SF]0cg_0RU:0Vmk0U:D0UJe0dic0UJe
0Tic0Ukg0f<H0QcW0RDY0SW>0fLi0UJe0S6<0QS60SW>0dic0VLi0V]J0Ukg0dHa0TYB0Sg_0SF]1D8@
0THa1D8@0Sg_0T8@0Sg_1d8@1cg_148@0Sg_0d8@0P0017oo00<007ooOol01goo0008Ool00`00OomF
]@06E[D2DY@2E[D2DY@3CW<4AS47@Q02?Nl2@Q03?Nl2;F/200021242248548@4248336<2?Nl2AS42
:DX52482<H`4>Lh37>L612432482:DX27>L5AS44BU85DY@2E[D2DY@4E[D3DY@4E[D5F]H2E[D9F]H2
2482Ool00`00Oomoo`0<Ool01000Ool000001d8@13g_0d8@14Ha0T8@0dHa0Sg_0T8@0SF]0cg_0RU:
0Vmk0U:D0UJe0dic0UJe0Tic0Ukg0f<H0QcW0RDY0SW>0fLi0UJe0S6<0QS60SW>0dic0VLi0V]J0Ukg
0dHa0TYB0Sg_0SF]1D8@0THa1D8@0Sg_0T8@0Sg_1d8@1cg_148@0Sg_0d8@0P0017oo00<007ooOol0
1goo0008Ool01000OomJeU[F0U:D1eJe0U:D1DYB14Ha1D8@0SW>0T8@0cg_0S6<0P000PQ20Q240cW>
0Sg_0Re[0PQ20`aS0SF]0T8@0Re[0`Q20QBU0T8@0SF]0PQ20`@Q0PQ21`@Q0PQ20SW>0T8@1DHa0Tic
1E:D0UJe15:D1EJe0U:D15Je0e[F15Je0U[F1EJe0P@Q0Woo00<007ooOol037oo00@007oo000000E2
40@mk`8icPM2408mk`=2408icP9:DP8e[@<]J`8YBP9g_@8icP9Nm`<<H`8Q208HaP9JeP=[FP8U:@8a
S08e[@=cW096<@8@Q08e[@9>L`=JeP9:DP92409:DP=F]@9>L`8mk`8U:@=24096<@92408icP=2408i
cP9:DPM24096<@924096<@<mk`A2408mk`=2408000Aoo`03001oogoo00Moo`0027oo00@007ooF]IJ
eP9BU0MF]@9BU0E:DPA6<@E2408icP9240<mk`8aS0800088@P8@Q0<icP8mk`8]J`88@P<<H`8e[@92
408]J`<8@P8DY@92408e[@88@P<48@88@PL48@88@P8icP9240E6<@9>L`EBU09F]@ABU0EF]@9BU0AF
]@=JePAF]@9JePEF]@848@9oo`03001oogoo00aoo`04001oo`000005@Q04?Nl2>Lh7@Q02?Nl3@Q02
>Lh2BU82=Jd3;F/2:DX2Mkd2>Lh2G_L336<28@P26<H2F]H3JeX29BT2<H`2=Jd3Li`2AS4248@2=Jd2
CW<3F]H2BU82@Q02BU83E[D2CW<2?Nl29BT3@Q02AS42@Q02>Lh3@Q02>Lh2BU87@Q02AS42@Q02AS43
?Nl4@Q02?Nl3@Q020004Ool00`00Oomoo`07Ool000Qoo`04001ooe[FF]H2DY@7E[D2DY@5BU84AS45
@Q02>Lh2@Q03?Nl2<H`20002248248@3>Lh2?Nl2;F/2248336<2=Jd2@Q02;F/324825:D2@Q02=Jd2
24831242248712422482>Lh2@Q05AS42CW<5DY@2E[D4DY@5E[D2DY@4E[D3F]H4E[D2F]H5E[D21242
Ool00`00Oomoo`0<Ool01000Ool000001D8@13g_0SW>1d8@0Sg_0d8@0SW>0TYB0SF]0be[0RU:0WNm
0SW>0Ukg0`aS0R480QS60U[F0f]J0RDY0S6<0SF]0g>L0THa0Q240SF]0Tic0e[F0TYB0T8@0TYB0eJe
0Tic0Sg_0RDY0d8@0THa0T8@0SW>0d8@0SW>0TYB1d8@0THa0T8@0THa0cg_148@0Sg_0d8@0P0017oo
00<007ooOol01goo0008Ool00`00OomF]@03E[D5DY@2CW<2DY@3BU86AS43@Q02?Nl2<H`2?Nl3>Lh2
8@P21242:DX236<3@Q04?Nl2248336<4?Nl2;F/32482<H`2:DX236<51244248212452482;F/2@Q05
AS42CW<2DY@3CW<8DY@3E[D2DY@2F]H5DY@2E[D2F]H5E[D2DY@22482Ool00`00Oomoo`0<Ool01000
Ool000000THa0d8@0THa0TYB0T8@1DHa2D8@0Tic0T8@0c6<0Sg_0W>L0QBU0W>L0a240SF]0QBU0V]J
0f<H0R480S6<0SF]0fmk0QcW0SF]0THa0U[F0dHa13g_1D8@0U[F136<0cg_0THa0T8@0Sg_0dYB0T8@
0THa0T8@0THa1D8@0Sg_1dHa0T8@0Sg_0dHa0P0017oo00<007ooOol01goo0008Ool00`00OomF]@03
E[D5DY@2CW<2DY@3BU86AS43@Q02?Nl2<H`2?Nl3>Lh28@P21242:DX236<3@Q04?Nl2248336<4?Nl2
;F/32482<H`2:DX236<51244248212452482;F/2@Q05AS42CW<2DY@3CW<8DY@3E[D2DY@2F]H5DY@2
E[D2F]H5E[D2DY@22482Ool00`00Oomoo`0<Ool01000Ool000000THa0d8@0THa0TYB0T8@1DHa2D8@
0Tic0T8@0c6<0Sg_0W>L0QBU0W>L0a240SF]0QBU0V]J0f<H0R480S6<0SF]0fmk0QcW0SF]0THa0U[F
0dHa13g_1D8@0U[F136<0cg_0THa0T8@0Sg_0dYB0T8@0THa0T8@0THa1D8@0Sg_1dHa0T8@0Sg_0dHa
0P0017oo00<007ooOol01goo0008Ool00`00OomF]@03E[D3F]H2DY@2CW<2DY@3CW<4BU85@Q02?Nl2
>Lh2<H`3>Lh28@P248@2=Jd22483?Nl4>Lh224835:D4@Q02;F/348@2<H`424821243248912422482
6<H2?Nl3AS44BU8=DY@GE[D22482Ool00`00Oomoo`0<Ool01000Ool000001CW>1T8@0cW>0T8@0Sg_
1D8@0SW>0Tic0T8@0c6<0Sg_0UJe0P@Q0W>L0aS60THa0QS60WNm0eJe0R480S6<0Sg_0ekg0RU:0TYB
0Tic0THa0d8@0THa0T8@0THa0d8@0UJe0U:D0RU:1D8@13g_0d8@0Sg_0T8@0Sg_0T8@0cg_0T8@0Sg_
2d8@0cg_0P0017oo00<007ooOol01goo0008Ool00`00OomF]@03E[D3F]H2DY@2CW<2DY@3CW<4BU85
@Q02?Nl2>Lh2<H`3>Lh28@P248@2=Jd22483?Nl4>Lh224835:D4@Q02;F/348@2<H`4248212432489
124224826<H2?Nl3AS44BU8=DY@GE[D22482Ool00`00Oomoo`0<Ool01000Ool000001CW>1T8@0cW>
0T8@0Sg_1D8@0SW>0Tic0T8@0c6<0Sg_0UJe0P@Q0W>L0aS60THa0QS60WNm0eJe0R480S6<0Sg_0ekg
0RU:0TYB0Tic0THa0d8@0THa0T8@0THa0d8@0UJe0U:D0RU:1D8@13g_0d8@0Sg_0T8@0Sg_0T8@0cg_
0T8@0Sg_2d8@0cg_0P0017oo00<007ooOol01goo0008Ool00`00OomF]@03E[D7DY@2BU83CW<4BU82
@Q05?Nl2=Jd2>Lh3=Jd27>L2124436<5?Nl2<H`22483:DX2?Nl2@Q02;F/3:DX224821242248>1242
248236<2@Q03?Nl2@Q02BU82DY@5CW<9DY@BE[D2DY@21242Ool00`00Oomoo`0<Ool01000Ool00000
0THa0d8@0THa1d8@0THa0Sg_1DHa0T8@14Ha0cW>0THa0W_N0SF]0Woo0aBU0SF]0S6<0WNm0d8@0S6<
13W>0e:D0T8@0U[F0T8@0Tic0eJe0V<H0UJe0U[F0e:D0TYB0V<H0R480dHa0Tic148@0dHa1T8@1DHa
2d8@0THa0T8@0dHa0P0017oo00<007ooOol01goo0008Ool00`00OomF]@03E[D7DY@2BU83CW<4BU82
@Q05?Nl2=Jd2>Lh3=Jd27>L2124436<5?Nl2<H`22483:DX2?Nl2@Q02;F/3:DX224821242248>1242
248236<2@Q03?Nl2@Q02BU82DY@5CW<9DY@BE[D2DY@21242Ool00`00Oomoo`0<Ool01000Ool00000
0THa0d8@0THa1d8@0THa0Sg_1DHa0T8@14Ha0cW>0THa0W_N0SF]0Woo0aBU0SF]0S6<0WNm0d8@0S6<
13W>0e:D0T8@0U[F0T8@0Tic0eJe0V<H0UJe0U[F0e:D0TYB0V<H0R480dHa0Tic148@0dHa1T8@1DHa
2d8@0THa0T8@0dHa0P0017oo00<007ooOol01goo0008Ool00`00OomF]@06E[D4DY@2CW<3BU82AS42
BU82AS43?Nl4>Lh2?Nl3>Lh2;F/20002124248@3@Q02?Nl28@P25:D3>Lh2?Nl2@Q02?Nl38@P21242
2482124224835:D2;F/2>Lh27>L512422482@Q05AS42DY@5CW<2DY@2CW<4DY@GE[D22482Ool00`00
Oomoo`0<Ool01000Ool000000SW>0cg_0T8@0Sg_1d8@0SW>0Sg_0d8@0Sg_0THa1CF]0RU:0Vmk0T8@
0VLi0a240SW>0U:D0VLi0c6<13F]0R480d8@0Tic0TYB0Sg_0UJe0cW>0RU:0Q240SF]1DYB0V]J0Q24
1D8@0SF]0Sg_0dHa0Sg_0THa1d8@13g_1D8@0Sg_148@0cg_0P0017oo00<007ooOol01goo0008Ool0
0`00OomF]@06E[D4DY@2CW<3BU82AS42BU82AS43?Nl4>Lh2?Nl3>Lh2;F/20002124248@3@Q02?Nl2
8@P25:D3>Lh2?Nl2@Q02?Nl38@P212422482124224835:D2;F/2>Lh27>L512422482@Q05AS42DY@5
CW<2DY@2CW<4DY@GE[D22482Ool00`00Oomoo`0<Ool01000Ool000000SW>0cg_0T8@0Sg_1d8@0SW>
0Sg_0d8@0Sg_0THa1CF]0RU:0Vmk0T8@0VLi0a240SW>0U:D0VLi0c6<13F]0R480d8@0Tic0TYB0Sg_
0UJe0cW>0RU:0Q240SF]1DYB0V]J0Q241D8@0SF]0Sg_0dHa0Sg_0THa1d8@13g_1D8@0Sg_148@0cg_
0P0017oo00<007ooOol01goo0008Ool00`00OomF]@06E[D4DY@2CW<3BU82AS42BU82AS43?Nl4>Lh2
?Nl3>Lh2;F/20002124248@3@Q02?Nl28@P25:D3>Lh2?Nl2@Q02?Nl38@P212422482124224835:D2
;F/2>Lh27>L512422482@Q05AS42DY@5CW<2DY@2CW<4DY@GE[D22482Ool00`00Oomoo`0<Ool01000
Ool000000SW>0cg_0T8@0Sg_1d8@0SW>0Sg_0d8@0Sg_0THa1CF]0RU:0Vmk0T8@0VLi0a240SW>0U:D
0VLi0c6<13F]0R480d8@0Tic0TYB0Sg_0UJe0cW>0RU:0Q240SF]1DYB0V]J0Q241D8@0SF]0Sg_0dHa
0Sg_0THa1d8@13g_1D8@0Sg_148@0cg_0P0017oo00<007ooOol01goo0008Ool01000OomBU5:D1EJe
1U:D1DYB0THa0T8@0cg_0SW>0SF]0Sg_0cW>0SF]0P000P@Q0PQ20cg_0SW>0RDY0SF]1cW>0Sg_1@Q2
0P@Q0PaS0P@Q0be[13g_0QcW0a240P@Q0PQ20Sg_0d8@0THa1dic0UJe0U:D0Tic2e:D35Je0U:D0P@Q
0Woo00<007ooOol037oo00@007oo0000009240<mk`96<@92408mk`E6<@8mk`E6<@924096<@8icP<e
[@8U:@9[FP9Nm`9S60<HaP8U:@8icP8YBP<U:@8]J`8mk`8YBP=JeP9Nm`9:DP92409_N`<Q208]J`8<
H`9BU0<e[@9F]@9W>@8Li`<e[@9>L`8aS096<@=2408mk`9240A6<@=2409:DP924096<@E2408mk`8i
cP<mk`8000Aoo`03001oogoo00Moo`0027oo00@007ooDYABU0EF]@IBU0E:DP96<@9240<mk`8icP8e
[@8mk`<icP8e[@8000848@88@P<mk`8icP8U:@8e[@LicP8mk`D8@P848@8<H`848@<]J`@mk`8Li`<@
Q0848@88@P8mk`=24096<@M>L`9F]@9BU09>L`]BU0aF]@9BU0848@9oo`03001oogoo00aoo`04001o
o`000002@Q03?Nl2AS42@Q02?Nl5AS42?Nl5AS42@Q02AS42>Lh3=Jd29BT2JeX2G_L2HaP36<H29BT2
>Lh2:DX39BT2;F/2?Nl2:DX3F]H2G_L2BU82@Q02Kg/38@P2;F/236<2DY@3=Jd2E[D2IcT27>L3=Jd2
CW<2<H`2AS43@Q02?Nl2@Q04AS43@Q02BU82@Q02AS45@Q02?Nl2>Lh3?Nl20004Ool00`00Oomoo`07
Ool000Qoo`03001ooe:D00=BU0EF]@9>L`9BU0=:DPA6<@9240<mk`8icP@aS0<e[@8icP8Li`848@8D
Y@<aS08YBP8DY@8<H`<@Q08icP8mk`8aS0D8@P8Li`8YBP848@<icP@aS0848@<Q20848@8<H`8icP=2
408aS09:DP9>L`=BU09>L`ABU0EF]@9BU0]F]@9BU0=:DP9>L`88@P9oo`03001oogoo00aoo`04001o
ocW>>Lh2IcT7G_L2F]H3HaP2F]H2G_L5DY@2CW<2E[D2DY@3CW<2=Jd2IcT2HaP2JeX3=Jd2CW<4Li`3
Kg/2>Lh2=Jd2;F/3Kg/2F]H2AS42>Lh2JeX3=Jd2@Q02BU82Mkd3G_L2Nmh2Ool2E[D3HaP2Li`2F]H5
DY@2CW<2DY@2CW<2AS43BU82AS44BU83AS44BU85DY@2?Nl4Ool00`00Oomoo`07Ool000Qoo`03001o
oe:D00=BU0EF]@9>L`9BU0=:DPA6<@9240<mk`8icP@aS0<e[@8icP8Li`848@8DY@<aS08YBP8DY@8<
H`<@Q08icP8mk`8aS0D8@P8Li`8YBP848@<icP@aS0848@<Q20848@8<H`8icP=2408aS09:DP9>L`=B
U09>L`ABU0EF]@9BU0]F]@9BU0=:DP9>L`88@P9oo`03001oogoo00aoo`04001oocW>>Lh2IcT7G_L2
F]H3HaP2F]H2G_L5DY@2CW<2E[D2DY@3CW<2=Jd2IcT2HaP2JeX3=Jd2CW<4Li`3Kg/2>Lh2=Jd2;F/3
Kg/2F]H2AS42>Lh2JeX3=Jd2@Q02BU82Mkd3G_L2Nmh2Ool2E[D3HaP2Li`2F]H5DY@2CW<2DY@2CW<2
AS43BU82AS44BU83AS44BU85DY@2?Nl4Ool00`00Oomoo`07Ool000Qoo`03001oogoo08Moo`03001o
ogoo00aoo`03001oogoo08Moo`03001oogoo00Moo`0027oo00<007ooOol0Qgoo00<007ooOol037oo
00<007ooOol0Qgoo00<007ooOol01goo0008Oon;000>Oon;0009Ool00?moocIoo`00ogoo=Woo003o
OolfOol00001\
\>"],
  ImageRangeCache->{{{0, 308}, {146.063, 0}} -> {-0.0543527, -0.0238146, 
  0.00684645, 0.00684645}, {{7.9375, 147}, {142.563, 
  3.4375}} -> {-4.82468, -2.84392, 0.449533, 0.449533}, {{160.938, 300.063}, {
  142.563, 3.4375}} -> {-73.5706, -2.82914, 0.449331, 0.449331}}]
}, Open  ]],

Cell["\<\
The zero crossings are clearly visible as they occur at the border between \
bright and dark areas of the Laplacian image. The mid-tones cover areas of \
small responses to the Laplacian operator, which corresponds to uniform \
(flat) brightness areas of the original image.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \({Min[\[Del]2], \ Max[\[Del]2]}\)], "Input"],

Cell[BoxData[
    \({\(-232.999999999999607`\), 326.999999999999779`}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["LAPLACIAN OF GAUSSIAN", "Section"],

Cell["\<\
In order to mitigate the increase in pixel noise due to differentiation, the \
2-D Laplacian needs to be smoothed. This is accomplished by a Gaussian \
smoother. Since convolution is associative and commutative the two step \
sequence can be reduced to one by constructing a compound operator. First we \
take the Laplacian of the bi-variate Gaussian function (LofG), then sample on \
a nxn grid to obtain the impulse response values approximating the desired \
operator.\
\>", "Text"],

Cell[CellGroupData[{

Cell["The bivariate LofG function.", "Subsection"],

Cell[TextData[{
  "Take the Laplacian of the bi-variate Gaussian function g with variance ",
  Cell[BoxData[
      \(TraditionalForm\`\[Sigma]\^2\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm
      \`g = \[ExponentialE]\^\(-
            \(\(x\^2 + y\^2\)\/\(2  \[Sigma]\^2\)\)\)\)]],
  ". Set ",
  Cell[BoxData[
      \(TraditionalForm\`\[Sigma]\)]],
  "=1 and plot the resulting function as a surface and as a cross-section for \
y=0."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(g = Exp[\(-\(\(x\^2 + y\^2\)\/\(2\ \[Sigma]\^2\)\)\)]; \n
    \[Del]g = \[PartialD]\_{x, 2}g + \[PartialD]\_{y, 2}g\  // Simplify\)], 
  "Input"],

Cell[BoxData[
    \(\(E\^\(-\(\(x\^2 + y\^2\)\/\(2\ \[Sigma]\^2\)\)\)\ 
        \((x\^2 + y\^2 - 2\ \[Sigma]\^2)\)\)\/\[Sigma]\^4\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[
      GraphicsArray[{
          Plot3D[Evaluate[\(-\[Del]g\) /. {\[Sigma] \[Rule] 1}], {x, \(-3\), 
              3}, {y, \(-3\), 3}, PlotRange \[Rule] All, 
            DisplayFunction \[Rule] Identity], 
          Plot[Evaluate[\(-\[Del]g\) /. {\[Sigma] \[Rule] 1, y \[Rule] 0}], {
              x, \(-4\), 4}, DisplayFunction \[Rule] Identity]}]]; \)\)], 
  "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .38626 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.00919655 0.47619 [
[ 0 0 0 0 ]
[ 1 .38626 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .38626 L
0 .38626 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.00919655 0.477324 0.377059 MathSubStart
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.11022e-016 1.04977 -0.0679587 1.04977 [
[.12586 .2075 -12 -8.99448 ]
[.12586 .2075 0 .00552 ]
[.3345 .12542 -5.5867 -9 ]
[.3345 .12542 .4133 0 ]
[.56094 .0364 -5.16972 -9 ]
[.56094 .0364 .83028 0 ]
[.75679 .08071 0 -6.17777 ]
[.75679 .08071 12 2.82223 ]
[.8565 .23339 0 -6.03127 ]
[.8565 .23339 6 2.96873 ]
[.9429 .3657 0 -5.9083 ]
[.9429 .3657 6 3.0917 ]
[.02018 .28975 -6 -2.76313 ]
[.02018 .28975 0 6.23687 ]
[.01264 .33703 -18 -2.80317 ]
[.01264 .33703 0 6.19683 ]
[.00486 .38578 -6 -2.84457 ]
[.00486 .38578 0 6.15543 ]
[-0.00316 .43606 -18 -2.88741 ]
[-0.00316 .43606 0 6.11259 ]
[-0.01144 .48795 -6 -2.93176 ]
[-0.01144 .48795 0 6.06824 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.03716 .25514 m
.68874 0 L
s
.13514 .21677 m
.13978 .22141 L
s
[(-2)] .12586 .2075 1 .99877 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.56863 .04703 m
.57247 .05235 L
s
[(2)] .56094 .0364 .72324 1 Mshowa
.125 Mabswid
.18558 .19702 m
.18832 .19985 L
s
.23703 .17687 m
.23971 .17975 L
s
.28951 .15632 m
.29214 .15925 L
s
.39772 .11395 m
.40023 .11699 L
s
.4535 .09211 m
.45595 .0952 L
s
.51046 .06981 m
.51284 .07294 L
s
.08568 .23614 m
.08851 .23887 L
s
.62804 .02377 m
.63027 .02701 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.7445 .0853 m
.73835 .08759 L
s
[(-2)] .75679 .08071 -1 .37284 Mshowa
.84407 .23761 m
.83786 .23973 L
s
[(0)] .8565 .23339 -1 .34028 Mshowa
.93037 .36962 m
.92411 .37158 L
s
[(2)] .9429 .3657 -1 .31296 Mshowa
.125 Mabswid
.7708 .12553 m
.7671 .12688 L
s
.79613 .16428 m
.79242 .1656 L
s
.82054 .20161 m
.81682 .20291 L
s
.86679 .27235 m
.86305 .2736 L
s
.88871 .30589 m
.88497 .30711 L
s
.9099 .3383 m
.90615 .3395 L
s
.71716 .04348 m
.71349 .04489 L
s
.95018 .39992 m
.94642 .40107 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03242 .28502 m
.03854 .28266 L
s
[(0)] .02018 .28975 1 -0.38597 Mshowa
.02492 .3324 m
.03105 .33009 L
s
[(0.5)] .01264 .33703 1 -0.37707 Mshowa
.01717 .38125 m
.02333 .37899 L
s
[(1)] .00486 .38578 1 -0.36787 Mshowa
.00919 .43164 m
.01537 .42942 L
s
[(1.5)] -0.00316 .43606 1 -0.35835 Mshowa
.00095 .48363 m
.00715 .48147 L
s
[(2)] -0.01144 .48795 1 -0.3485 Mshowa
.125 Mabswid
.03094 .29439 m
.03462 .29297 L
s
.02945 .3038 m
.03312 .3024 L
s
.02795 .31328 m
.03163 .31188 L
s
.02644 .32281 m
.03012 .32142 L
s
.02339 .34205 m
.02707 .34067 L
s
.02185 .35176 m
.02554 .35039 L
s
.0203 .36153 m
.02399 .36016 L
s
.01874 .37136 m
.02243 .37 L
s
.0156 .3912 m
.01929 .38985 L
s
.01401 .40122 m
.01771 .39987 L
s
.01241 .41129 m
.01612 .40995 L
s
.01081 .42143 m
.01451 .4201 L
s
.00756 .4419 m
.01127 .44058 L
s
.00593 .45224 m
.00964 .45092 L
s
.00428 .46264 m
.00799 .46133 L
s
.00262 .4731 m
.00633 .4718 L
s
.0339 .27572 m
.03757 .2743 L
s
.03536 .26647 m
.03903 .26504 L
s
.03682 .25727 m
.04049 .25584 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.5 Mabswid
.67 .743 .905 r
.3822 .6055 .40434 .62614 .44135 .61489 .41955 .59345 Metetra
.677 .74 .898 r
.41955 .59345 .44135 .61489 .47887 .60315 .45741 .58043 Metetra
.685 .733 .887 r
.45741 .58043 .47887 .60315 .5169 .59082 .49579 .56629 Metetra
.688 .722 .875 r
.49579 .56629 .5169 .59082 .55544 .57796 .53465 .55136 Metetra
.685 .708 .865 r
.53465 .55136 .55544 .57796 .59448 .56486 .57399 .53639 Metetra
.677 .694 .859 r
.57399 .53639 .59448 .56486 .63406 .55195 .61385 .52215 Metetra
.666 .683 .857 r
.61385 .52215 .63406 .55195 .67422 .53958 .65429 .50911 Metetra
.655 .677 .859 r
.65429 .50911 .67422 .53958 .71498 .52792 .69538 .49741 Metetra
.644 .675 .864 r
.69538 .49741 .71498 .52792 .75641 .51681 .73718 .48694 Metetra
.637 .678 .873 r
.73718 .48694 .75641 .51681 .7985 .50589 .77973 .47724 Metetra
.636 .689 .883 r
.77973 .47724 .7985 .50589 .84124 .49474 .823 .46752 Metetra
.64 .705 .894 r
.823 .46752 .84124 .49474 .88462 .48303 .86696 .45699 Metetra
.648 .721 .902 r
.86696 .45699 .88462 .48303 .92862 .47069 .91153 .44531 Metetra
.655 .733 .907 r
.91153 .44531 .92862 .47069 .97325 .45781 .95673 .4326 Metetra
.679 .742 .898 r
.35951 .584 .3822 .6055 .41955 .59345 .39722 .57065 Metetra
.691 .736 .885 r
.39722 .57065 .41955 .59345 .45741 .58043 .43546 .55558 Metetra
.7 .725 .869 r
.43546 .55558 .45741 .58043 .49579 .56629 .47419 .5389 Metetra
.699 .708 .855 r
.47419 .5389 .49579 .56629 .53465 .55136 .51338 .52171 Metetra
.688 .692 .848 r
.51338 .52171 .53465 .55136 .57399 .53639 .55301 .50554 Metetra
.674 .682 .849 r
.55301 .50554 .57399 .53639 .61385 .52215 .59317 .49108 Metetra
.664 .679 .854 r
.59317 .49108 .61385 .52215 .65429 .50911 .63391 .47791 Metetra
.656 .677 .858 r
.63391 .47791 .65429 .50911 .69538 .49741 .6753 .46562 Metetra
.645 .671 .86 r
.6753 .46562 .69538 .49741 .73718 .48694 .71739 .45462 Metetra
.63 .664 .864 r
.71739 .45462 .73718 .48694 .77973 .47724 .76032 .4454 Metetra
.62 .665 .871 r
.76032 .4454 .77973 .47724 .823 .46752 .8041 .43726 Metetra
.622 .679 .883 r
.8041 .43726 .823 .46752 .86696 .45699 .84866 .42864 Metetra
.633 .702 .895 r
.84866 .42864 .86696 .45699 .91153 .44531 .89388 .41838 Metetra
.646 .722 .904 r
.89388 .41838 .91153 .44531 .95673 .4326 .93969 .40632 Metetra
.692 .741 .889 r
.33625 .56151 .35951 .584 .39722 .57065 .37436 .54634 Metetra
.707 .732 .871 r
.37436 .54634 .39722 .57065 .43546 .55558 .41302 .5287 Metetra
.71 .717 .854 r
.41302 .5287 .43546 .55558 .47419 .5389 .45212 .50976 Metetra
.695 .7 .85 r
.45212 .50976 .47419 .5389 .51338 .52171 .49162 .49249 Metetra
.665 .691 .865 r
.49162 .49249 .51338 .52171 .55301 .50554 .53159 .47937 Metetra
.639 .708 .896 r
.53159 .47937 .55301 .50554 .59317 .49108 .57218 .4693 Metetra
.645 .751 .926 r
.57218 .4693 .59317 .49108 .63391 .47791 .61341 .45804 Metetra
.678 .783 .929 r
.61341 .45804 .63391 .47791 .6753 .46562 .65517 .44314 Metetra
.688 .765 .91 r
.65517 .44314 .6753 .46562 .71739 .45462 .69745 .42701 Metetra
.659 .714 .889 r
.69745 .42701 .71739 .45462 .76032 .4454 .74053 .41393 Metetra
.622 .673 .878 r
.74053 .41393 .76032 .4454 .8041 .43726 .78463 .40511 Metetra
.606 .664 .88 r
.78463 .40511 .8041 .43726 .84866 .42864 .82974 .39806 Metetra
.615 .682 .89 r
.82974 .39806 .84866 .42864 .89388 .41838 .87562 .38972 Metetra
.633 .708 .9 r
.87562 .38972 .89388 .41838 .93969 .40632 .9221 .37882 Metetra
.705 .74 .879 r
.31242 .53807 .33625 .56151 .37436 .54634 .35096 .52079 Metetra
.718 .73 .86 r
.35096 .52079 .37436 .54634 .41302 .5287 .39005 .50086 Metetra
.708 .714 .853 r
.39005 .50086 .41302 .5287 .45212 .50976 .42949 .48182 Metetra
.654 .699 .88 r
.42949 .48182 .45212 .50976 .49162 .49249 .46924 .47 Metetra
.516 .697 .951 r
.46924 .47 .49162 .49249 .53159 .47937 .50954 .46876 Metetra
.228 .682 .951 r
.50954 .46876 .53159 .47937 .57218 .4693 .55078 .47198 Metetra
.093 .648 .704 r
.55078 .47198 .57218 .4693 .61341 .45804 .59289 .46656 Metetra
.376 .823 .696 r
.59289 .46656 .61341 .45804 .65517 .44314 .63531 .44527 Metetra
.715 .987 .874 r
.63531 .44527 .65517 .44314 .69745 .42701 .67777 .41511 Metetra
.765 .899 .936 r
.67777 .41511 .69745 .42701 .74053 .41393 .72072 .38927 Metetra
.672 .753 .911 r
.72072 .38927 .74053 .41393 .78463 .40511 .76484 .37411 Metetra
.607 .678 .891 r
.76484 .37411 .78463 .40511 .82974 .39806 .8103 .36637 Metetra
.597 .671 .892 r
.8103 .36637 .82974 .39806 .87562 .38972 .8568 .35962 Metetra
.618 .696 .9 r
.8568 .35962 .87562 .38972 .9221 .37882 .90397 .35015 Metetra
.716 .742 .872 r
.28797 .51395 .31242 .53807 .35096 .52079 .32697 .49474 Metetra
.724 .732 .857 r
.32697 .49474 .35096 .52079 .39005 .50086 .36647 .47357 Metetra
.686 .717 .872 r
.36647 .47357 .39005 .50086 .42949 .48182 .40615 .4576 Metetra
.498 .677 .945 r
.40615 .4576 .42949 .48182 .46924 .47 .44596 .45768 Metetra
0 .271 .653 r
.44596 .45768 .46924 .47 .50954 .46876 .48647 .47793 Metetra
.641 .129 .01 r
.48647 .47793 .50954 .46876 .55078 .47198 .52845 .50423 Metetra
.493 .062 .148 r
.52845 .50423 .55078 .47198 .59289 .46656 .57181 .50904 Metetra
.143 0 .049 r
.57181 .50904 .59289 .46656 .63531 .44527 .61535 .47717 Metetra
.61535 .47717 .63531 .44527 .67777 .41511 .65819 .42322 Metetra
.817 .993 .749 r
.65819 .42322 .67777 .41511 .72072 .38927 .70094 .37489 Metetra
.778 .885 .923 r
.70094 .37489 .72072 .38927 .76484 .37411 .74485 .34681 Metetra
.636 .726 .913 r
.74485 .34681 .76484 .37411 .8103 .36637 .79047 .33512 Metetra
.587 .676 .901 r
.79047 .33512 .8103 .36637 .8568 .35962 .83747 .32884 Metetra
.603 .69 .904 r
.83747 .32884 .8568 .35962 .90397 .35015 .88529 .32058 Metetra
.723 .746 .87 r
.26285 .48956 .28797 .51395 .32697 .49474 .3023 .46896 Metetra
.725 .739 .863 r
.3023 .46896 .32697 .49474 .36647 .47357 .34219 .44754 Metetra
.647 .72 .902 r
.34219 .44754 .36647 .47357 .40615 .4576 .38203 .43596 Metetra
.14 .52 .916 r
.38203 .43596 .40615 .4576 .44596 .45768 .42172 .44943 Metetra
.735 .208 0 r
.42172 .44943 .44596 .45768 .48647 .47793 .46214 .49289 Metetra
.763 .321 .203 r
.46214 .49289 .48647 .47793 .52845 .50423 .50462 .54419 Metetra
.573 .166 .231 r
.50462 .54419 .52845 .50423 .57181 .50904 .54925 .56023 Metetra
.068 0 .05 r
.54925 .56023 .57181 .50904 .61535 .47717 .59417 .51684 Metetra
.59417 .51684 .61535 .47717 .65819 .42322 .63779 .43717 Metetra
.904 .966 .65 r
.63779 .43717 .65819 .42322 .70094 .37489 .68065 .36459 Metetra
.864 .926 .866 r
.68065 .36459 .70094 .37489 .74485 .34681 .72449 .32206 Metetra
.679 .771 .921 r
.72449 .32206 .74485 .34681 .79047 .33512 .77026 .30503 Metetra
.585 .691 .914 r
.77026 .30503 .79047 .33512 .83747 .32884 .8177 .29817 Metetra
.592 .692 .912 r
.8177 .29817 .83747 .32884 .88529 .32058 .86612 .29052 Metetra
.726 .752 .873 r
.23699 .46526 .26285 .48956 .3023 .46896 .27688 .44392 Metetra
.726 .75 .871 r
.27688 .44392 .3023 .46896 .34219 .44754 .31717 .42232 Metetra
.623 .725 .92 r
.31717 .42232 .34219 .44754 .38203 .43596 .35724 .41266 Metetra
0 .404 .848 r
.35724 .41266 .38203 .43596 .42172 .44943 .39688 .43207 Metetra
.759 .253 0 r
.39688 .43207 .42172 .44943 .46214 .49289 .43708 .48595 Metetra
.815 .335 .047 r
.43708 .48595 .46214 .49289 .50462 .54419 .4796 .54868 Metetra
.535 0 0 r
.4796 .54868 .50462 .54419 .54925 .56023 .52489 .5698 Metetra
.817 .998 .778 r
.52489 .5698 .54925 .56023 .59417 .51684 .57093 .52073 Metetra
.973 .913 .686 r
.57093 .52073 .59417 .51684 .63779 .43717 .61559 .42883 Metetra
.956 .876 .716 r
.61559 .42883 .63779 .43717 .68065 .36459 .65914 .34489 Metetra
.869 .848 .821 r
.65914 .34489 .68065 .36459 .72449 .32206 .70341 .29547 Metetra
.698 .769 .907 r
.70341 .29547 .72449 .32206 .77026 .30503 .74957 .27562 Metetra
.585 .703 .924 r
.74957 .27562 .77026 .30503 .8177 .29817 .79748 .26808 Metetra
.586 .701 .922 r
.79748 .26808 .8177 .29817 .86612 .29052 .84644 .26033 Metetra
.726 .759 .879 r
.21033 .44117 .23699 .46526 .27688 .44392 .25062 .41974 Metetra
.73 .762 .878 r
.25062 .41974 .27688 .44392 .31717 .42232 .29137 .39746 Metetra
.647 .741 .918 r
.29137 .39746 .31717 .42232 .35724 .41266 .33193 .38514 Metetra
.224 .525 .918 r
.33193 .38514 .35724 .41266 .39688 .43207 .37195 .39817 Metetra
0 .045 .591 r
.37195 .39817 .39688 .43207 .43708 .48595 .41227 .44158 Metetra
0 .056 .62 r
.41227 .44158 .43708 .48595 .4796 .54868 .45463 .49298 Metetra
.409 .464 .806 r
.45463 .49298 .4796 .54868 .52489 .5698 .49977 .50862 Metetra
.741 .628 .734 r
.49977 .50862 .52489 .5698 .57093 .52073 .54613 .46392 Metetra
.828 .676 .694 r
.54613 .46392 .57093 .52073 .61559 .42883 .59166 .38244 Metetra
.843 .708 .713 r
.59166 .38244 .61559 .42883 .65914 .34489 .63629 .30821 Metetra
.799 .736 .794 r
.63629 .30821 .65914 .34489 .70341 .29547 .6815 .26443 Metetra
.677 .733 .893 r
.6815 .26443 .70341 .29547 .74957 .27562 .72834 .24643 Metetra
.58 .71 .932 r
.72834 .24643 .74957 .27562 .79748 .26808 .77678 .2387 Metetra
.586 .715 .932 r
.77678 .2387 .79748 .26808 .84644 .26033 .82625 .23014 Metetra
.72 .764 .887 r
.18282 .41714 .21033 .44117 .25062 .41974 .22346 .39629 Metetra
.734 .774 .885 r
.22346 .39629 .25062 .41974 .29137 .39746 .2647 .37341 Metetra
.692 .765 .907 r
.2647 .37341 .29137 .39746 .33193 .38514 .30599 .35583 Metetra
.508 .662 .93 r
.30599 .35583 .33193 .38514 .37195 .39817 .3469 .35467 Metetra
.267 .434 .842 r
.3469 .35467 .37195 .39817 .41227 .44158 .38794 .37418 Metetra
.336 .374 .753 r
.38794 .37418 .41227 .44158 .45463 .49298 .43041 .3999 Metetra
.529 .444 .704 r
.43041 .3999 .45463 .49298 .49977 .50862 .47506 .40352 Metetra
.655 .511 .676 r
.47506 .40352 .49977 .50862 .54613 .46392 .52104 .36942 Metetra
.72 .562 .675 r
.52104 .36942 .54613 .46392 .59166 .38244 .56696 .31264 Metetra
.744 .611 .711 r
.56696 .31264 .59166 .38244 .63629 .30821 .6126 .26165 Metetra
.721 .667 .797 r
.6126 .26165 .63629 .30821 .6815 .26443 .65888 .23141 Metetra
.636 .709 .899 r
.65888 .23141 .6815 .26443 .72834 .24643 .70653 .21789 Metetra
.574 .72 .942 r
.70653 .21789 .72834 .24643 .77678 .2387 .75552 .20987 Metetra
.594 .731 .939 r
.75552 .20987 .77678 .2387 .82625 .23014 .80549 .19977 Metetra
.709 .765 .896 r
.15446 .39278 .18282 .41714 .22346 .39629 .19538 .3731 Metetra
.729 .78 .893 r
.19538 .3731 .22346 .39629 .2647 .37341 .23704 .35062 Metetra
.722 .786 .903 r
.23704 .35062 .2647 .37341 .30599 .35583 .27907 .32904 Metetra
.654 .743 .915 r
.27907 .32904 .30599 .35583 .3469 .35467 .32109 .3149 Metetra
.549 .615 .871 r
.32109 .3149 .3469 .35467 .38794 .37418 .36323 .31167 Metetra
.526 .506 .776 r
.36323 .31167 .38794 .37418 .43041 .3999 .40623 .31304 Metetra
.576 .482 .712 r
.40623 .31304 .43041 .3999 .47506 .40352 .45063 .30539 Metetra
.63 .502 .687 r
.45063 .30539 .47506 .40352 .52104 .36942 .49616 .28121 Metetra
.668 .538 .698 r
.49616 .28121 .52104 .36942 .56696 .31264 .54217 .24778 Metetra
.683 .592 .747 r
.54217 .24778 .56696 .31264 .6126 .26165 .58854 .2188 Metetra
.66 .663 .842 r
.58854 .2188 .6126 .26165 .65888 .23141 .63572 .20083 Metetra
.599 .719 .928 r
.63572 .20083 .65888 .23141 .70653 .21789 .6841 .19047 Metetra
.579 .74 .952 r
.6841 .19047 .70653 .21789 .75552 .20987 .73363 .18107 Metetra
.61 .746 .942 r
.73363 .18107 .75552 .20987 .80549 .19977 .78407 .16878 Metetra
.694 .762 .904 r
.12525 .36761 .15446 .39278 .19538 .3731 .1664 .34932 Metetra
.715 .78 .903 r
.1664 .34932 .19538 .3731 .23704 .35062 .20836 .32837 Metetra
.726 .797 .908 r
.20836 .32837 .23704 .35062 .27907 .32904 .25094 .306 Metetra
.71 .792 .915 r
.25094 .306 .27907 .32904 .32109 .3149 .29387 .28534 Metetra
.668 .735 .901 r
.29387 .28534 .32109 .3149 .36323 .31167 .33709 .26897 Metetra
.631 .643 .844 r
.33709 .26897 .36323 .31167 .40623 .31304 .38085 .25573 Metetra
.625 .582 .785 r
.38085 .25573 .40623 .31304 .45063 .30539 .42545 .24118 Metetra
.638 .569 .761 r
.42545 .24118 .45063 .30539 .49616 .28121 .47093 .22273 Metetra
.65 .594 .779 r
.47093 .22273 .49616 .28121 .54217 .24778 .51712 .20293 Metetra
.648 .65 .839 r
.51712 .20293 .54217 .24778 .58854 .2188 .56406 .18624 Metetra
.617 .715 .916 r
.56406 .18624 .58854 .2188 .63572 .20083 .61196 .17394 Metetra
.587 .752 .957 r
.61196 .17394 .63572 .20083 .6841 .19047 .66095 .1634 Metetra
.6 .761 .956 r
.66095 .1634 .6841 .19047 .73363 .18107 .71098 .15141 Metetra
.629 .756 .939 r
.71098 .15141 .73363 .18107 .78407 .16878 .76191 .13666 Metetra
.68 .756 .909 r
.09519 .34128 .12525 .36761 .1664 .34932 .13656 .32411 Metetra
.695 .771 .91 r
.13656 .32411 .1664 .34932 .20836 .32837 .17874 .30504 Metetra
.71 .792 .915 r
.17874 .30504 .20836 .32837 .25094 .306 .22167 .28418 Metetra
.714 .809 .924 r
.22167 .28418 .25094 .306 .29387 .28534 .26519 .26271 Metetra
.703 .805 .928 r
.26519 .26271 .29387 .28534 .33709 .26897 .30919 .24224 Metetra
.684 .771 .918 r
.30919 .24224 .33709 .26897 .38085 .25573 .35369 .22352 Metetra
.667 .73 .897 r
.35369 .22352 .38085 .25573 .42545 .24118 .39882 .20608 Metetra
.656 .71 .887 r
.39882 .20608 .42545 .24118 .47093 .22273 .44468 .18947 Metetra
.644 .722 .905 r
.44468 .18947 .47093 .22273 .51712 .20293 .49132 .17415 Metetra
.623 .751 .939 r
.49132 .17415 .51712 .20293 .56406 .18624 .53885 .16061 Metetra
.602 .774 .962 r
.53885 .16061 .56406 .18624 .61196 .17394 .58738 .14811 Metetra
.606 .778 .963 r
.58738 .14811 .61196 .17394 .66095 .1634 .63694 .13499 Metetra
.626 .769 .948 r
.63694 .13499 .66095 .1634 .71098 .15141 .68749 .12002 Metetra
.645 .757 .931 r
.68749 .12002 .71098 .15141 .76191 .13666 .73896 .10302 Metetra
.67 .751 .911 r
.06427 .31367 .09519 .34128 .13656 .32411 .10591 .2971 Metetra
.679 .76 .913 r
.10591 .2971 .13656 .32411 .17874 .30504 .14831 .27939 Metetra
.689 .777 .918 r
.14831 .27939 .17874 .30504 .22167 .28418 .19149 .26039 Metetra
.696 .796 .927 r
.19149 .26039 .22167 .28418 .26519 .26271 .23538 .24044 Metetra
.695 .813 .938 r
.23538 .24044 .26519 .26271 .30919 .24224 .2799 .22035 Metetra
.685 .818 .946 r
.2799 .22035 .30919 .24224 .35369 .22352 .32502 .20095 Metetra
.67 .813 .952 r
.32502 .20095 .35369 .22352 .39882 .20608 .37077 .18274 Metetra
.653 .806 .957 r
.37077 .18274 .39882 .20608 .44468 .18947 .41723 .16586 Metetra
.636 .803 .963 r
.41723 .16586 .44468 .18947 .49132 .17415 .46451 .15018 Metetra
.624 .8 .967 r
.46451 .15018 .49132 .17415 .53885 .16061 .51269 .1352 Metetra
.624 .792 .963 r
.51269 .1352 .53885 .16061 .58738 .14811 .56185 .12008 Metetra
.635 .779 .95 r
.56185 .12008 .58738 .14811 .63694 .13499 .612 .10396 Metetra
.647 .764 .935 r
.612 .10396 .63694 .13499 .68749 .12002 .66311 .08647 Metetra
.655 .753 .922 r
.66311 .08647 .68749 .12002 .73896 .10302 .71517 .06773 Metetra
.665 .747 .911 r
.03245 .28484 .06427 .31367 .10591 .2971 .07439 .26833 Metetra
.669 .752 .913 r
.07439 .26833 .10591 .2971 .14831 .27939 .11708 .25119 Metetra
.674 .761 .916 r
.11708 .25119 .14831 .27939 .19149 .26039 .16053 .2333 Metetra
.678 .774 .923 r
.16053 .2333 .19149 .26039 .23538 .24044 .20474 .21471 Metetra
.679 .788 .932 r
.20474 .21471 .23538 .24044 .2799 .22035 .24967 .19574 Metetra
.675 .801 .942 r
.24967 .19574 .2799 .22035 .32502 .20095 .2953 .17686 Metetra
.667 .807 .95 r
.2953 .17686 .32502 .20095 .37077 .18274 .34164 .15846 Metetra
.657 .807 .955 r
.34164 .15846 .37077 .18274 .41723 .16586 .38875 .14067 Metetra
.649 .802 .956 r
.38875 .14067 .41723 .16586 .46451 .15018 .4367 .12336 Metetra
.646 .792 .952 r
.4367 .12336 .46451 .15018 .51269 .1352 .48555 .10612 Metetra
.648 .779 .944 r
.48555 .10612 .51269 .1352 .56185 .12008 .53534 .08847 Metetra
.652 .766 .933 r
.53534 .08847 .56185 .12008 .612 .10396 .5861 .07006 Metetra
.657 .756 .923 r
.5861 .07006 .612 .10396 .66311 .08647 .63782 .05081 Metetra
.66 .749 .916 r
.63782 .05081 .66311 .08647 .71517 .06773 .69053 .03082 Metetra
0 g
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.13514 .21677 m
.13978 .22141 L
s
[(-2)] .12586 .2075 1 .99877 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.56863 .04703 m
.57247 .05235 L
s
[(2)] .56094 .0364 .72324 1 Mshowa
.125 Mabswid
.18558 .19702 m
.18832 .19985 L
s
.23703 .17687 m
.23971 .17975 L
s
.28951 .15632 m
.29214 .15925 L
s
.39772 .11395 m
.40023 .11699 L
s
.4535 .09211 m
.45595 .0952 L
s
.51046 .06981 m
.51284 .07294 L
s
.08568 .23614 m
.08851 .23887 L
s
.62804 .02377 m
.63027 .02701 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.00919655 0.97619 0.377059 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.084878 0.259222 [
[.02381 .07238 -6 -9 ]
[.02381 .07238 6 0 ]
[.2619 .07238 -6 -9 ]
[.2619 .07238 6 0 ]
[.7381 .07238 -3 -9 ]
[.7381 .07238 3 0 ]
[.97619 .07238 -3 -9 ]
[.97619 .07238 3 0 ]
[.4875 .21449 -18 -4.5 ]
[.4875 .21449 0 4.5 ]
[.4875 .3441 -6 -4.5 ]
[.4875 .3441 0 4.5 ]
[.4875 .47371 -18 -4.5 ]
[.4875 .47371 0 4.5 ]
[.4875 .60332 -6 -4.5 ]
[.4875 .60332 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.02381 .08488 m
.02381 .09113 L
s
[(-4)] .02381 .07238 0 1 Mshowa
.2619 .08488 m
.2619 .09113 L
s
[(-2)] .2619 .07238 0 1 Mshowa
.7381 .08488 m
.7381 .09113 L
s
[(2)] .7381 .07238 0 1 Mshowa
.97619 .08488 m
.97619 .09113 L
s
[(4)] .97619 .07238 0 1 Mshowa
.125 Mabswid
.08333 .08488 m
.08333 .08863 L
s
.14286 .08488 m
.14286 .08863 L
s
.20238 .08488 m
.20238 .08863 L
s
.32143 .08488 m
.32143 .08863 L
s
.38095 .08488 m
.38095 .08863 L
s
.44048 .08488 m
.44048 .08863 L
s
.55952 .08488 m
.55952 .08863 L
s
.61905 .08488 m
.61905 .08863 L
s
.67857 .08488 m
.67857 .08863 L
s
.79762 .08488 m
.79762 .08863 L
s
.85714 .08488 m
.85714 .08863 L
s
.91667 .08488 m
.91667 .08863 L
s
.25 Mabswid
0 .08488 m
1 .08488 L
s
.5 .21449 m
.50625 .21449 L
s
[(0.5)] .4875 .21449 1 0 Mshowa
.5 .3441 m
.50625 .3441 L
s
[(1)] .4875 .3441 1 0 Mshowa
.5 .47371 m
.50625 .47371 L
s
[(1.5)] .4875 .47371 1 0 Mshowa
.5 .60332 m
.50625 .60332 L
s
[(2)] .4875 .60332 1 0 Mshowa
.125 Mabswid
.5 .1108 m
.50375 .1108 L
s
.5 .13672 m
.50375 .13672 L
s
.5 .16264 m
.50375 .16264 L
s
.5 .18857 m
.50375 .18857 L
s
.5 .24041 m
.50375 .24041 L
s
.5 .26633 m
.50375 .26633 L
s
.5 .29226 m
.50375 .29226 L
s
.5 .31818 m
.50375 .31818 L
s
.5 .37002 m
.50375 .37002 L
s
.5 .39594 m
.50375 .39594 L
s
.5 .42187 m
.50375 .42187 L
s
.5 .44779 m
.50375 .44779 L
s
.5 .49963 m
.50375 .49963 L
s
.5 .52556 m
.50375 .52556 L
s
.5 .55148 m
.50375 .55148 L
s
.5 .5774 m
.50375 .5774 L
s
.5 .05896 m
.50375 .05896 L
s
.5 .03303 m
.50375 .03303 L
s
.5 .00711 m
.50375 .00711 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .08366 m
.03279 .08331 L
.04262 .08282 L
.05288 .08216 L
.06244 .0814 L
.0828 .07914 L
.09421 .0774 L
.10458 .07546 L
.12373 .07085 L
.14451 .06411 L
.18538 .04556 L
.20569 .03469 L
.22473 .025 L
.23407 .02094 L
.24295 .01781 L
.24785 .01648 L
.25044 .01591 L
.25319 .01542 L
.25451 .01523 L
.25574 .01507 L
.25694 .01495 L
.25805 .01486 L
.25911 .01479 L
.26022 .01474 L
.26134 .01472 L
.26256 .01472 L
.26387 .01475 L
.26507 .01482 L
.2657 .01486 L
.2664 .01492 L
.2678 .01507 L
.27036 .01546 L
.27277 .01597 L
.27724 .0173 L
.28207 .01931 L
.28739 .02229 L
.29298 .02636 L
.30299 .03619 L
.31253 .04888 L
.32273 .06628 L
.34109 .1081 L
.36244 .17328 L
.38259 .24863 L
.42106 .40951 L
.44054 .48546 L
.45088 .52048 L
.46198 .55241 L
.47262 .57643 L
.47766 .5853 L
.48233 .592 L
Mistroke
.48701 .59718 L
.48948 .59928 L
.49211 .60105 L
.49331 .60169 L
.49461 .60226 L
.49584 .60269 L
.49697 .60299 L
.498 .60318 L
.49912 .60329 L
.50029 .60332 L
.50138 .60325 L
.50265 .60307 L
.50329 .60293 L
.50399 .60274 L
.50524 .60232 L
.5064 .60182 L
.50903 .60035 L
.51186 .5982 L
.51703 .59279 L
.52177 .5862 L
.53082 .56943 L
.54034 .54629 L
.56012 .48305 L
.5785 .41132 L
.6176 .24787 L
.63755 .17331 L
.65915 .10745 L
.66928 .08281 L
.67999 .06124 L
.69003 .04515 L
.69918 .03376 L
.70865 .02507 L
.71386 .02152 L
.7188 .0189 L
.72335 .01709 L
.72757 .01589 L
.72977 .01544 L
.7322 .01507 L
.73342 .01494 L
.73474 .01483 L
.73598 .01476 L
.73712 .01472 L
.7384 .01472 L
.7396 .01474 L
.74068 .01478 L
.74185 .01485 L
.74313 .01496 L
.74448 .0151 L
.74691 .01544 L
.75125 .01627 L
Mistroke
.75602 .0175 L
.76671 .02125 L
.77671 .02568 L
.81551 .04602 L
.83523 .05572 L
.85675 .06458 L
.87736 .07115 L
.89648 .07568 L
.90706 .07761 L
.91702 .07911 L
.93563 .08123 L
.9454 .08204 L
.95572 .08272 L
.9742 .08359 L
.97619 .08366 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{216, 83.375},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003H0000Da000`40O003h00Of7oo003HOol00=Qo
o`00f7oo003HOol00=Qoo`00f7oo003HOol003moo`<009Ioo`00?goo00<007ooOol0UWoo0010Ool0
0`00Oomoo`2EOol0041oo`03001oogoo03Eoo`<0019oo`<002Ioo`<001Aoo`<000Qoo`00?goo00<0
07oo0000=goo00<007ooOol04Goo00<007ooOol04Woo00<007ooOol04Goo00<007ooOol05Goo00<0
07ooOol01goo0010Ool00`00Oomoo`09Ool2000TOol30002Ool4000=Ool30003Ool00`00Oomoo`0A
Ool00`00Oomoo`0BOol00`00Oomoo`0BOol40008Ool004Yoo`800003Ool0000002Qoo`03001oo`00
00moo`H001=oo`03001oogoo011oo`H0015oo`03001oo`0000Uoo`00;goo00<007ooOol05Goo0`00
0goo0P002Goo0`007Goo0P003Woo00<007ooOol00Woo0`004Woo00<007ooOol047oo0P0000Aoo`00
Oomoo`80011oo`8000Uoo`00;Woo00<007oo000057oo0P0017oo0`0000=oo`00Ool01goo00<007oo
Ool07Woo00<007ooOol02Woo0P001Woo00<007oo00004Goo00<007ooOol03goo00@007ooOol000Eo
o`8000moo`03001oogoo00Moo`00;Woo00<007oo00004Goo0`000goo0`000U;l10000Woo0`000goo
00<007ooOol09goo0`002Woo00<007ooOol03goo00<007ooOol03Woo00<007ooOol02Goo0P005goo
000^Ool00`00Ool0000?Ool20004Ool20002D_d00`00D_aBo0040008Ool00`00Oomoo`0TOol3000=
Ool00`00Oomoo`0?Ool00`00Oomoo`0=Ool00`00Oomoo`0<Ool3000DOol002ioo`03001oo`0000ao
o`<000=oo`<000ABo@08001Bo000001Bo@00Ool000Ioo`03001oo`00029oo`<0015oo`03001oogoo
00ioo`03001oogoo00eoo`03001oogoo00moo`<0015oo`00;goo00<007ooOol02Goo0P000Woo1000
0e<M00<005;mD_d00`0000ABo@00D_eBo@8000Moo`03001oogoo01Qooed000Moo`007Goo0`0067oo
1`000e<M00@005<MDaeC7@<000=C7@80009Bo@03001oo`0002=oo`03001oogoo009oo`03001oogoo
00=oo`03001oogoo009oo`03001oogoo00=oo`03001oogoo009oo`8000Aoo`03001oogoo009oo`03
001oogoo00=oo`03001oogoo009oo`03001oogoo00=oo`04001oogooOol20005Ool00`00Oomoo`02
Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`07Ool001eoo`03001o
ogoo01Ioo`80009oo`80009C?@06001C7E<MDad005<M0P000TlM00@005<MDaeC7@@00004D_d007oo
000oOol00`00Oomoo`0<Ool00`00Oomoo`0;Ool00`00Oomoo`0UOol001Qoo`<000=oo`03001oogoo
019oo`<0009oo`8000AC?@03001C7E<M00<000A?7@03001C7E<M00@0009Bo@03001oo`0003moo`03
001oogoo00aoo`03001oogoo00]oo`03001oogoo02Eoo`007Woo00<007ooOol047oo0P0000=oo`00
00000P000U<n00<005<mDcd010000dln00<004lMCad010000TlM0P0000IBo@00000007oo000oOol0
0`00Oomoo`0;Ool00`00Oomoo`0:Ool00`00Oomoo`0VOol001eoo`03001oo`0000ioo`H000=C?P03
001C?U<n00<000=??P03001??Tln00@0009;7P03001?7DlM00@000=>o@03001oo`0003ioo`03001o
ogoo00]oo`03001oogoo00Yoo`03001oogoo02Ioo`007Woo00<007ooOol02goo1@000U<m00<005<n
Dch010000Tln00<004lnCch010000d/N00<004/NBah00`000T/N0P000Tkm1000?Woo00<007ooOol0
2goo00<007ooOol02Woo00<007ooOol09Woo000YOol300000goo00000005Dcd20003Dch00`00Cci?
?P030003C_d00`00Bai;7P040002B_h00`00Bai;7P040003C_d20004Ool00`00Oomoo`0gOol00`00
Oomoo`0:Ool00`00Oomoo`09Ool00`00Oomoo`0WOol002Ioo`<00004Ool000000002Ecd200001E<m
000005<m00000U<n10000U;L00<004kmC_d010000dkL00<004[nB_h010000T[m00L004kmC_e>o@00
Ool00002Ool00`00Ool0000hOol00`00Oomoo`0:Ool00`00Oomoo`09Ool00`00Oomoo`0WOol002Ao
o`<00003Ool00000009G7@03001G?ELm00@0009C?@<000=Bf`03001Bg5;L00<000=BVP03001>g4kL
00@0009:g@800003B_d0000000H0009oo`03001oo`0003Qoo`03001oogoo00Yoo`03001oogoo00Uo
o`03001oogoo02Moo`008Woo0P000Woo0P001ELM0P000eLm0`000U;l00@005;KD]]Bf`<0009BF004
001BVU:JDYX30002DYX00`00B]e:g@040002A]d02`00B_e:oD[m001oo`00Ool007oo0000=goo00<0
07oo00000Woo00<007ooOol00Woo00D007ooOomoo`0000Yoo`03001oogoo02Qoo`007Woo10000Woo
0P000ULM0P0000IG7@00001G?@00Ecd20002Ea`01@00D_aBo000D]/00P0000=>=`00DUP00U9H00@0
05:J0000009FE`04001BVU:JDYX20002C]`20003A]d00`00B_d00003000017oo001oo`00=Woo00@0
07oo000000Ioo`03001oo`00009oo`03001oogoo00Qoo`03001oogoo02Qoo`007Goo0P000goo0P00
00AG7000EaeG7@@0009G?@8000AG7003001Bo5;l008000A>=`05001BF59HDUP00004EUL01`00DYX0
0000F[T004kL00P000=:g@800003Ool007oo03Ioo`04001oo`000008Ool01000Oomoo`002Woo00<0
07ooOol0:7oo000KOol20002Ool30004Ea`20004Ecd20002Ecd20002Ea`300000diH001>=`03CSL0
0`00DUQBF0020005EUL00`00F[UJ^@070003B]d00`00B]e:g@04000hOol01000Ool000001Woo0P00
0goo00<007ooOol027oo00<007ooOol0:7oo000JOol50003D_`01@00Ea`00000Ea`00P0000EG?@00
001K?@00009G?@@00003CYX004iH009>F003001>=dhg009>=`80009B5@04001FEeIGEUL40002F[T0
1@00E_aFo000E_`01P000T[M0P00>7oo00D007oo001oo`0000Eoo`03001oogoo009oo`03001oogoo
00Moo`03001oogoo02Uoo`006Woo0P000U;l0P000U;l0P0015LL0P0015/m0P000e;l00@004jJCYX0
009>F004001>=dhgCSL20003DQD00`00EUMFE`02000025if001J^EZi001Vn000E_`200000eLL001:
g@02B]d01000B]e:gD[M0P00>7oo00@007ooOol000Eoo`<0009oo`03001oogoo00Moo`03001oogoo
02Uoo`005Woo00@007ooOomoo`<0009Bo0<0009G7004001G70000002Fc`01P00Fcd00000Fc`000=B
o004001>VTjJ0003CUP300000dge001B5@02DQD30003GWH00`00F[T00003I_P00`00EaaG70020002
B]d600000goo001oo`0iOol00`00Oomoo`08Ool00`00Oomoo`07Ool00`00Oomoo`0YOol001Eoo`03
001oo`00009oo`03001oogoo0080009Bo003001G75LL008000EK?003001K?5/l009K?0/000A=m@<0
0003DQD005if00ANMP04001Vn6KhI_P20002Ea`40002B[`01000B[a:_4Zl0P00>Woo00<007ooOol0
27oo00<007ooOol01goo00<007ooOol0:Goo000EOol00`00Ool00002Ool01@00Oomoogoo00000e;l
0P000ULL0P0000IK?000001K?000Fc`30003AW/01000@OQ1n0000TGf00<004ge00000`000U8E0P00
15if0P000VKh00<006mIKeT00P0000=G7000000014Zl00<004Zl00000`000goo0`00=7oo00<007oo
Ool01goo00<007ooOol01Woo00<007ooOol0:Woo000<Ool00`00Oomoo`02Ool01000Oomoogoo0`00
0Woo00H007ooOomoo`00D_`2000015Kl001G75LL10000U/l0P000e;l00@004IkAW/000=1n0@000==
m@06001B5E8E001J=@000eif00@006[F0000009_F@03001_^`00009G70L0009:_0<0009oo`03001o
ogoo03Aoo`03001oogoo00Moo`03001oogoo00Ioo`03001oogoo02Yoo`002goo00<007oo00001goo
00@007oo001oo`8000Aoo`03001Fo5Kl009Fo08000AK7080009K7004001Bo5;l0003AW/40002AOH0
1`00COE=mDge001B5@00009J=@04001NMUif0002J]H200000fmI001_^`02Kk/200000dkL00000003
B[`00`00B[a:_0030003Ool00`00Oomoo`0cOol00`00Oomoo`07Ool00`00Oomoo`06Ool00`00Oomo
o`0ZOol000]oo`03001oo`0000Qoo`800003Ool0000000Eoo`05001Fo000001G700200001E/L0000
05/L00000U/L20000T7h00@004GfAOH000A=m@80009J=@03001NMP0000=ZeP05001kMP00001_^`03
0002C]`80002C]`20002Ool00`00Oomoo`0cOol00`00Oomoo`07Ool00`00Oomoo`06Ool00`00Oomo
o`0ZOol000]oo`03001oo`0000Moo`80009oo`8000Ioo`8000=G708000AK7080009G70L00005@OP0
04GfAOH00003COD20004FSD20002J]H01P00NgIkMP00Lm@0009SW@<00003B[`0000000=:_003001>
g4kL00<00004Ool007oo000dOol01000Oomoogoo1@0000=oo`00Ool01goo00<007ooOol0:Woo000;
Ool00`00Ool00005Ool500000goo001oo`08Ool30002Fa`01@00Fa`00000Fa/01`0000<Q^P00:GL0
0`000TGf0`0000=B5@00FSD00eXe00X006[FJ]IZeP00NgH007?D001Wm`80009Fo003001:_4Zl0080
0003B[`000000080009>g0800003Ool007oo03Eoo`03001oogoo009oo`05001oogooOol00007Ool0
0`00Oomoo`0[Ool000aoo`03001oogoo00Ioo`<00003Ool007oo00Yoo`03001K75/L00800003Fa/0
000000<0009Bo0<000048KX002Ug:GL40004DQD01000FSEJ=EXe0P0000AZeP00NgIkMP@00004Gid0
05KlE_`60002C[/00`00C]a>g002C]`2000gOol00`00Oomoo`02Ool01@00Oomoogoo00001goo00<0
07ooOol0:goo000EOol01@00Oomoogoo000037oo1@0000EK6`00001K6`00009Bo0D0008YM`040011
]T6f0004DQD02@00FSEJ=@00I[D006[F001kMP030002Gid400000djk001:V`02BY/00`00C[]>^`07
000gOol00`00Oomoo`02Ool01@00Oomoogoo00001goo00<007ooOol0:goo000EOol00`00Oomoo`02
000;Ool30002Fa/30002Fa/30002C]`40002:GL00`00@KH00004DQD01000FSEJ=@000VJe0P0000=k
MP00Fo/00`000U;K00H004jkC[]>^`00BY/40002C]`00`00D]aBg003000fOol00`00Oomoo`02Ool0
1@00Oomoogoo00001goo00<007ooOol0:goo0008Ool50002Ool00`00Oomoo`02Ool20002Ool20008
Ool30003Ool20003Fa/20002F_/00`00C]a>g0040002:GL01000@KI1]P000e8E00<005Xe00000fJe
00<007^E00000P000ULL00H005;KD]]Bf`00C[/30002C[/00`00C]a>g007000fOol01000Oomoogoo
0P000goo00<007ooOol01Goo00<007ooOol0:goo000:Ool00`00Oomoo`06Ool30002Ool20006Ool2
0007Ool01P00Fa/00000F_/0009Jn`<000=Bg0800005:GL0046f@KH00004DQD20002I[D01P00NiD0
0000Ead0009G70H0009>^`03001>^djk00<0009Bg003001Bo5;l008003Moo`03001oogoo00Eoo`03
001oogoo00Aoo`03001oogoo02aoo`002Woo00<007ooOol027oo00@007ooOol000Aoo`<000Yoo`03
001Jne[k009Jn`80009Jn`05001Bg000001Ff`030002@KH00`00DQEB5@02DQD02000I[EV]FJe001k
U@00Ead400000e:k001>V`02CY/00`00C[]>^`030002C]`00`00D]aBg0030002Ool00`00Oomoo`0d
Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`0/Ool000Yoo`03001oogoo00Ioo`8000=o
o`03001oo`00008000ioo`06001Jn`00001Jn`000U[k0P000eKK00H0000c0000046f0002DQD30002
I[D00`00NiD000020002D[X01P00D[]B^e:k001>V`@00004C[/004kLC]`40005Ool00`00Oomoo`0d
Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`0/Ool000Yoo`03001oogoo00Ioo`<0009o
o`80019oo`03001Jne[k009Jn`80009JnP03001Ff`000080000403<00000@KH20003GWH01000I[D0
00000U:j00<005:jD[X01P000Tjk00<004jkC[/00`000Woo00<007ooOol017oo00<007ooOol0=7oo
00<007ooOol01Goo00<007ooOol017oo00<007ooOol0;7oo0009Ool20008Ool30003Ool00`00Oomo
o`0AOol01P00F_/00000F_/0009JnP8000=JfP800003<MT0000000ANMP800004NiD005:jD[X30002
D[X01000D[]B^`000Tjk0`001Woo00<007ooOol00goo00<007ooOol0=Goo00<007ooOol017oo00<0
07ooOol00goo00<007ooOol0;Goo000DOol00`00Oomoo`03Ool2000BOol00`00F_]Jn`02F_/20000
0e[k001JfP0200001E[J0000037I00001Eif1@0000=B^P00D[X00U:j00<005:kD[/00`002Woo00<0
07ooOol00Woo00<007ooOol0=Goo00<007ooOol017oo00<007ooOol00goo00<007ooOol0;Goo000D
Ool00`00Oomoo`05Ool00`00Oomoo`0@Ool00`00F_/000020002F_/20003F]X20002<MT01000GWIN
MUif0`0000=F^P00D[X00U:j00<005:j00000`003Goo00<007ooOol00Woo00<007ooOol0;7oo1@00
0Woo00<007oo00000Woo00D007ooOomoo`0000Eoo`03001oogoo02eoo`004goo00<007oo00001goo
00<007ooOol047oo0P0000AJn`000000009Jn`03001JfU[J00<00004<MT005ifGWH30003E[X00`00
D[X00002000BOol00`00Oomoo`02Ool00`00Oomoo`0]Ool00`00Oomoo`04Ool01@00Ool007oo0000
0Woo00<007ooOol00goo00<007ooOol0;Goo000DOol00`00Oomoo`07Ool00`00Oomoo`0AOol01000
E_]Fn`000U[k0`000UKK1P000UKK00<005Jj00000P005Woo00D007ooOomoo`0002moo`03001oogoo
00Eoo`04001oogoo0002Ool00`00Oomoo`02Ool00`00Oomoo`0^Ool001moo`03001oogoo011oo`03
001FneKk00<0009Fn`03001FfeKK00D0009Ff`<001Yoo`04001oogoo000_Ool00`00Oomoo`05Ool3
0003Ool00`00Oomoo`02Ool00`00Oomoo`0^Ool0021oo`80015oo`80009Fo003001FneKk00<00004
E_/005KKE]/3000MOol01000Oomoo`00;goo00<007ooOol01Goo0P0017oo00<007ooOol00Woo00<0
07ooOol0;Woo000ROol00`00Oomoo`0?Ool00`00E_aFo003000015Kl001FneKk0`008Goo00<007oo
0000;Woo0P0027oo0`000Woo00D007ooOomoo`00035oo`008goo00<007ooOol03goo0P000U;l00<0
05Kl00000P009Goo0P00>7oo00<007ooOol00Woo00D007ooOomoo`00035oo`0097oo00<007ooOol0
47oo1000:Goo0P00=goo00<007ooOol00Woo00D007ooOomoo`00035oo`009Goo00<007ooOol03goo
00<007ooOol0:Woo0P00>7oo00D007ooOomoo`00009oo`03001oogoo031oo`009Woo0P003goo00<0
07ooOol0:Woo0P00>7oo00D007ooOomoo`00009oo`03001oogoo031oo`00:7oo00<007ooOol037oo
00<007ooOol09Woo1000>Woo00D007ooOomoo`00009oo`03001oogoo031oo`00:Goo00<007ooOol0
2goo00<007ooOol08Woo1000?goo00H007ooOol007oo000cOol002Yoo`03001oogoo00Yoo`03001o
ogoo01moo`<0045oo`@00004Ool007oo000cOol002]oo`03001oogoo00Uoo`03001oogoo01]oo`@0
04Aoo`05001oogoo001oo`02000dOol002aoo`8000Qoo`03001oogoo01Uoo`<004Uoo`03001oogoo
00<003Aoo`00;Woo00<007ooOol01Goo00<007ooOol05Goo1000C7oo00D007ooOomoo`0003Eoo`00
;goo00<007ooOol017oo00<007ooOol04Goo1000Cgoo00<007oo0000>7oo000`Ool00`00Oomoo`03
Ool00`00Oomoo`0>Ool3001DOol00`00Oomoo`0gOol0035oo`03001oogoo009oo`03001oogoo00Yo
o`@0095oo`00<Woo0P000Woo00<007ooOol01goo0`00UGoo000dOol00`00Ool00005Ool4002HOol0
03Eoo`800003Ool00000008009aoo`00=Woo0P00X7oo003HOol00=Qoo`00f7oo003HOol00=Qoo`00
f7oo0000\
\>"],
  ImageRangeCache->{{{0, 215}, {82.375, 0}} -> {-0.0585623, -0.0193168, 
  0.0098471, 0.0098471}, {{5.9375, 102.625}, {80.375, 
  1.9375}} -> {-0.299804, -0.0984283, 0.0123985, 0.0123985}, {{112.313, 
  209}, {80.375, 1.9375}} -> {-14.7941, -0.845414, 0.0912336, 0.0418991}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Building the Discrete Operator", "Subsection"],

Cell[TextData[{
  "The values of the LofG kernel are given by the function LofGKernel. The \
argument is a radius specification (in pixels) for the resulting LofG filter. \
It defines the width (i.e variance) of the desired filter. The corresponding \
variance is given by ",
  Cell[BoxData[
      \(TraditionalForm\`\[Sigma]\^2 = \ r\/\(3\ \@2\)\)]],
  ". For a radius ",
  Cell[BoxData[
      \(TraditionalForm\`r\)]],
  ", the filter size is (2r+1)x(2r+1)."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\((K = LofGKernel[7])\)\  // Dimensions\)], "Input"],

Cell[BoxData[
    \({15, 15}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(ListPlot3D[\(-K\), \ PlotRange -> All]; \)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1.04977 -0.0679587 1.04977 [
[.19846 .17893 -5.85476 -9 ]
[.19846 .17893 .14524 0 ]
[.42923 .08816 -10.816 -9 ]
[.42923 .08816 1.18401 0 ]
[.68156 -0.01098 -9.92245 -9 ]
[.68156 -0.01098 2.07755 0 ]
[.79412 .13786 0 -6.12234 ]
[.79412 .13786 6 2.87766 ]
[.89499 .29234 0 -5.97603 ]
[.89499 .29234 12 3.02397 ]
[.98191 .42546 0 -5.85393 ]
[.98191 .42546 12 3.14607 ]
[.02018 .28975 -6 -2.76313 ]
[.02018 .28975 0 6.23687 ]
[.00594 .37899 -24 -2.83879 ]
[.00594 .37899 0 6.16121 ]
[-0.00914 .47351 -24 -2.9194 ]
[-0.00914 .47351 0 6.0806 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.03716 .25514 m
.68874 0 L
s
.20751 .18843 m
.21203 .19319 L
s
[(5)] .19846 .17893 .95159 1 Mshowa
.43745 .0984 m
.44155 .10351 L
s
[(10)] .42923 .08816 .80266 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(15)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.25192 .17104 m
.25459 .17394 L
s
.2971 .15335 m
.29972 .15629 L
s
.34306 .13535 m
.34564 .13834 L
s
.38984 .11704 m
.39236 .12006 L
s
.4859 .07942 m
.48831 .08254 L
s
.53524 .06011 m
.53759 .06327 L
s
.58547 .04044 m
.58776 .04364 L
s
.63663 .0204 m
.63885 .02365 L
s
.16384 .20553 m
.1666 .20834 L
s
.12091 .22234 m
.12371 .22511 L
s
.07869 .23888 m
.08153 .2416 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.78177 .14231 m
.7756 .14454 L
s
[(5)] .79412 .13786 -1 .36052 Mshowa
.88252 .29643 m
.87629 .29847 L
s
[(10)] .89499 .29234 -1 .32801 Mshowa
.96935 .42924 m
.96306 .43113 L
s
[(15)] .98191 .42546 -1 .30087 Mshowa
.125 Mabswid
.8032 .17508 m
.79948 .1764 L
s
.82395 .20683 m
.82023 .20812 L
s
.84407 .23761 m
.84035 .23888 L
s
.86359 .26746 m
.85986 .26871 L
s
.90091 .32455 m
.89716 .32575 L
s
.91876 .35185 m
.915 .35304 L
s
.9361 .37838 m
.93234 .37955 L
s
.95296 .40417 m
.94919 .40532 L
s
.75965 .10848 m
.75596 .10983 L
s
.7368 .07352 m
.73311 .0749 L
s
.71317 .03738 m
.7095 .03879 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03242 .28502 m
.03854 .28266 L
s
[(0)] .02018 .28975 1 -0.38597 Mshowa
.01825 .37444 m
.02441 .37217 L
s
[(0.02)] .00594 .37899 1 -0.36916 Mshowa
.00324 .46916 m
.00943 .46699 L
s
[(0.04)] -0.00914 .47351 1 -0.35124 Mshowa
.125 Mabswid
.02896 .30691 m
.03263 .3055 L
s
.02544 .3291 m
.02912 .32771 L
s
.02187 .35161 m
.02556 .35023 L
s
.01458 .39761 m
.01828 .39626 L
s
.01086 .42111 m
.01456 .41978 L
s
.00708 .44496 m
.01079 .44364 L
s
.03584 .26345 m
.03951 .26201 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.5 Mabswid
.662 .744 .911 r
.38218 .60598 .40433 .62631 .44134 .61536 .41951 .59474 Metetra
.662 .744 .911 r
.41951 .59474 .44134 .61536 .47885 .60426 .45736 .58334 Metetra
.663 .744 .91 r
.45736 .58334 .47885 .60426 .51689 .59299 .49574 .57171 Metetra
.664 .743 .909 r
.49574 .57171 .51689 .59299 .55547 .58156 .53467 .55977 Metetra
.666 .742 .907 r
.53467 .55977 .55547 .58156 .59459 .56993 .57415 .5475 Metetra
.666 .739 .905 r
.57415 .5475 .59459 .56993 .63426 .55814 .61419 .53503 Metetra
.664 .735 .903 r
.61419 .53503 .63426 .55814 .67451 .5462 .65481 .52261 Metetra
.661 .733 .903 r
.65481 .52261 .67451 .5462 .71534 .53415 .69604 .51039 Metetra
.658 .733 .905 r
.69604 .51039 .71534 .53415 .75676 .52195 .7379 .49822 Metetra
.659 .737 .907 r
.7379 .49822 .75676 .52195 .7988 .50957 .78039 .48583 Metetra
.66 .74 .909 r
.78039 .48583 .7988 .50957 .84145 .49698 .82351 .47309 Metetra
.661 .742 .91 r
.82351 .47309 .84145 .49698 .88474 .48418 .86727 .46001 Metetra
.662 .743 .911 r
.86727 .46001 .88474 .48418 .92868 .47118 .91169 .44666 Metetra
.662 .744 .911 r
.91169 .44666 .92868 .47118 .97328 .45799 .9568 .4331 Metetra
.662 .744 .911 r
.35945 .58512 .38218 .60598 .41951 .59474 .39711 .57358 Metetra
.663 .744 .91 r
.39711 .57358 .41951 .59474 .45736 .58334 .4353 .56177 Metetra
.666 .744 .908 r
.4353 .56177 .45736 .58334 .49574 .57171 .47404 .54945 Metetra
.673 .742 .902 r
.47404 .54945 .49574 .57171 .53467 .55977 .51333 .53625 Metetra
.679 .736 .893 r
.51333 .53625 .53467 .55977 .57415 .5475 .55315 .52213 Metetra
.678 .723 .883 r
.55315 .52213 .57415 .5475 .61419 .53503 .59351 .50784 Metetra
.668 .708 .878 r
.59351 .50784 .61419 .53503 .65481 .52261 .63446 .49445 Metetra
.655 .699 .878 r
.63446 .49445 .65481 .52261 .69604 .51039 .67607 .48249 Metetra
.646 .7 .885 r
.67607 .48249 .69604 .51039 .7379 .49822 .71838 .47145 Metetra
.646 .711 .895 r
.71838 .47145 .7379 .49822 .78039 .48583 .76139 .46025 Metetra
.652 .727 .904 r
.76139 .46025 .78039 .48583 .82351 .47309 .80503 .44811 Metetra
.658 .737 .908 r
.80503 .44811 .82351 .47309 .86727 .46001 .8493 .43505 Metetra
.661 .742 .91 r
.8493 .43505 .86727 .46001 .91169 .44666 .89422 .42143 Metetra
.662 .743 .911 r
.89422 .42143 .91169 .44666 .9568 .4331 .93984 .40749 Metetra
.663 .744 .91 r
.33613 .56371 .35945 .58512 .39711 .57358 .37412 .55179 Metetra
.667 .744 .908 r
.37412 .55179 .39711 .57358 .4353 .56177 .41266 .53928 Metetra
.678 .744 .9 r
.41266 .53928 .4353 .56177 .47404 .54945 .45178 .52532 Metetra
.695 .737 .883 r
.45178 .52532 .47404 .54945 .51333 .53625 .49146 .50895 Metetra
.702 .718 .861 r
.49146 .50895 .51333 .53625 .55315 .52213 .53161 .49085 Metetra
.69 .69 .845 r
.53161 .49085 .55315 .52213 .59351 .50784 .57224 .47357 Metetra
.668 .666 .839 r
.57224 .47357 .59351 .50784 .63446 .49445 .61344 .45899 Metetra
.646 .652 .842 r
.61344 .45899 .63446 .49445 .67607 .48249 .65534 .44744 Metetra
.625 .647 .852 r
.65534 .44744 .67607 .48249 .71838 .47145 .69807 .43865 Metetra
.616 .66 .87 r
.69807 .43865 .71838 .47145 .76139 .46025 .74165 .43074 Metetra
.628 .691 .89 r
.74165 .43074 .76139 .46025 .80503 .44811 .78592 .42111 Metetra
.646 .722 .903 r
.78592 .42111 .80503 .44811 .8493 .43505 .83078 .40902 Metetra
.657 .738 .909 r
.83078 .40902 .8493 .43505 .89422 .42143 .87624 .3954 Metetra
.661 .743 .91 r
.87624 .3954 .89422 .42143 .93984 .40749 .92239 .38113 Metetra
.665 .744 .909 r
.31219 .54171 .33613 .56371 .37412 .55179 .35052 .52928 Metetra
.676 .745 .903 r
.35052 .52928 .37412 .55179 .41266 .53928 .38945 .51549 Metetra
.701 .743 .884 r
.38945 .51549 .41266 .53928 .45178 .52532 .42902 .49834 Metetra
.722 .727 .854 r
.42902 .49834 .45178 .52532 .49146 .50895 .46912 .47712 Metetra
.708 .695 .835 r
.46912 .47712 .49146 .50895 .53161 .49085 .5096 .45662 Metetra
.665 .667 .842 r
.5096 .45662 .53161 .49085 .57224 .47357 .55055 .44243 Metetra
.649 .683 .868 r
.55055 .44243 .57224 .47357 .61344 .45899 .59214 .43055 Metetra
.674 .713 .878 r
.59214 .43055 .61344 .45899 .65534 .44744 .6343 .41553 Metetra
.653 .684 .867 r
.6343 .41553 .65534 .44744 .69807 .43865 .67719 .40281 Metetra
.6 .638 .86 r
.67719 .40281 .69807 .43865 .74165 .43074 .72117 .39654 Metetra
.591 .647 .874 r
.72117 .39654 .74165 .43074 .78592 .42111 .76611 .39109 Metetra
.622 .693 .895 r
.76611 .39109 .78592 .42111 .83078 .40902 .81166 .38151 Metetra
.649 .728 .907 r
.81166 .38151 .83078 .40902 .87624 .3954 .85772 .36847 Metetra
.659 .741 .91 r
.85772 .36847 .87624 .3954 .92239 .38113 .90442 .35397 Metetra
.668 .745 .908 r
.28761 .5191 .31219 .54171 .35052 .52928 .3263 .50599 Metetra
.689 .747 .896 r
.3263 .50599 .35052 .52928 .38945 .51549 .36566 .49032 Metetra
.725 .743 .866 r
.36566 .49032 .38945 .51549 .42902 .49834 .40574 .46914 Metetra
.73 .719 .84 r
.40574 .46914 .42902 .49834 .46912 .47712 .44626 .44551 Metetra
.632 .673 .871 r
.44626 .44551 .46912 .47712 .5096 .45662 .48696 .43564 Metetra
.21 .562 .936 r
.48696 .43564 .5096 .45662 .55055 .44243 .52839 .44736 Metetra
.241 0 0 r
.52839 .44736 .55055 .44243 .59214 .43055 .571 .451 Metetra
.571 .451 .59214 .43055 .6343 .41553 .61378 .41989 Metetra
.797 .999 .827 r
.61378 .41989 .6343 .41553 .67719 .40281 .65643 .38034 Metetra
.694 .782 .919 r
.65643 .38034 .67719 .40281 .72117 .39654 .70026 .36247 Metetra
.571 .643 .883 r
.70026 .36247 .72117 .39654 .76611 .39109 .74567 .35867 Metetra
.59 .667 .892 r
.74567 .35867 .76611 .39109 .81166 .38151 .79193 .35244 Metetra
.636 .716 .905 r
.79193 .35244 .81166 .38151 .85772 .36847 .83864 .34056 Metetra
.656 .738 .91 r
.83864 .34056 .85772 .36847 .90442 .35397 .88591 .32598 Metetra
.671 .745 .906 r
.26235 .49586 .28761 .5191 .3263 .50599 .30142 .48203 Metetra
.701 .749 .889 r
.30142 .48203 .3263 .50599 .36566 .49032 .34124 .46449 Metetra
.74 .746 .856 r
.34124 .46449 .36566 .49032 .40574 .46914 .38184 .44027 Metetra
.712 .721 .857 r
.38184 .44027 .40574 .46914 .44626 .44551 .42266 .41972 Metetra
.163 .49 .903 r
.42266 .41972 .44626 .44551 .48696 .43564 .46322 .43584 Metetra
.818 .356 .128 r
.46322 .43584 .48696 .43564 .52839 .44736 .5049 .49757 Metetra
.647 .272 .32 r
.5049 .49757 .52839 .44736 .571 .451 .54903 .53062 Metetra
.134 0 .201 r
.54903 .53062 .571 .451 .61378 .41989 .5932 .46985 Metetra
.5932 .46985 .61378 .41989 .65643 .38034 .63578 .3793 Metetra
.868 .983 .842 r
.63578 .3793 .65643 .38034 .70026 .36247 .67917 .33427 Metetra
.595 .705 .92 r
.67917 .33427 .70026 .36247 .74567 .35867 .72477 .32649 Metetra
.562 .661 .904 r
.72477 .32649 .74567 .35867 .79193 .35244 .77163 .32255 Metetra
.622 .71 .909 r
.77163 .32255 .79193 .35244 .83864 .34056 .81898 .31178 Metetra
.653 .736 .91 r
.81898 .31178 .83864 .34056 .88591 .32598 .86684 .29712 Metetra
.673 .746 .906 r
.2364 .47201 .26235 .49586 .30142 .48203 .27584 .45766 Metetra
.706 .752 .888 r
.27584 .45766 .30142 .48203 .34124 .46449 .3161 .43909 Metetra
.747 .755 .858 r
.3161 .43909 .34124 .46449 .38184 .44027 .35719 .41362 Metetra
.695 .738 .884 r
.35719 .41362 .38184 .44027 .42266 .41972 .39831 .39575 Metetra
0 .158 .653 r
.39831 .39575 .42266 .41972 .46322 .43584 .43863 .42755 Metetra
.88 .453 .174 r
.43863 .42755 .46322 .43584 .5049 .49757 .48 .51897 Metetra
.741 .304 .213 r
.48 .51897 .5049 .49757 .54903 .53062 .52489 .5698 Metetra
.658 .823 .394 r
.52489 .5698 .54903 .53062 .5932 .46985 .57052 .49078 Metetra
.981 .903 .574 r
.57052 .49078 .5932 .46985 .63578 .3793 .61394 .36958 Metetra
.923 .899 .784 r
.61394 .36958 .63578 .3793 .67917 .33427 .65757 .30783 Metetra
.624 .739 .929 r
.65757 .30783 .67917 .33427 .72477 .32649 .70347 .29645 Metetra
.545 .676 .924 r
.70347 .29645 .72477 .32649 .77163 .32255 .75083 .29295 Metetra
.614 .716 .918 r
.75083 .29295 .77163 .32255 .81898 .31178 .79874 .28238 Metetra
.652 .738 .912 r
.79874 .28238 .81898 .31178 .86684 .29712 .84718 .26741 Metetra
.671 .746 .907 r
.20972 .44755 .2364 .47201 .27584 .45766 .2495 .43298 Metetra
.701 .754 .893 r
.2495 .43298 .27584 .45766 .3161 .43909 .29013 .41463 Metetra
.746 .767 .869 r
.29013 .41463 .3161 .43909 .35719 .41362 .33167 .38951 Metetra
.723 .769 .889 r
.33167 .38951 .35719 .41362 .39831 .39575 .37338 .36808 Metetra
.169 .49 .903 r
.37338 .36808 .39831 .39575 .43863 .42755 .41426 .38377 Metetra
0 0 .485 r
.41426 .38377 .43863 .42755 .48 .51897 .45563 .44569 Metetra
.313 .345 .734 r
.45563 .44569 .48 .51897 .52489 .5698 .49999 .47857 Metetra
.734 .575 .676 r
.49999 .47857 .52489 .5698 .57052 .49078 .54582 .41626 Metetra
.811 .636 .665 r
.54582 .41626 .57052 .49078 .61394 .36958 .59043 .32382 Metetra
.781 .688 .761 r
.59043 .32382 .61394 .36958 .65757 .30783 .6352 .27753 Metetra
.596 .702 .917 r
.6352 .27753 .65757 .30783 .70347 .29645 .68172 .26891 Metetra
.543 .704 .945 r
.68172 .26891 .70347 .29645 .75083 .29295 .72951 .26416 Metetra
.619 .732 .927 r
.72951 .26416 .75083 .29295 .79874 .28238 .77791 .25247 Metetra
.653 .741 .914 r
.77791 .25247 .79874 .28238 .84718 .26741 .82691 .23683 Metetra
.668 .746 .908 r
.18227 .42243 .20972 .44755 .2495 .43298 .22238 .40783 Metetra
.689 .753 .9 r
.22238 .40783 .2495 .43298 .29013 .41463 .26331 .39059 Metetra
.732 .773 .886 r
.26331 .39059 .29013 .41463 .33167 .38951 .30517 .36766 Metetra
.751 .797 .889 r
.30517 .36766 .33167 .38951 .37338 .36808 .3476 .3422 Metetra
.628 .739 .927 r
.3476 .3422 .37338 .36808 .41426 .38377 .3898 .33081 Metetra
.439 .486 .811 r
.3898 .33081 .41426 .38377 .45563 .44569 .43212 .34151 Metetra
.536 .432 .683 r
.43212 .34151 .45563 .44569 .49999 .47857 .47598 .34391 Metetra
.632 .471 .647 r
.47598 .34391 .49999 .47857 .54582 .41626 .52112 .31063 Metetra
.674 .521 .669 r
.52112 .31063 .54582 .41626 .59043 .32382 .56637 .2687 Metetra
.658 .603 .782 r
.56637 .2687 .59043 .32382 .6352 .27753 .61224 .24894 Metetra
.549 .702 .941 r
.61224 .24894 .6352 .27753 .68172 .26891 .65941 .24354 Metetra
.566 .742 .959 r
.65941 .24354 .68172 .26891 .72951 .26416 .70759 .23562 Metetra
.633 .747 .931 r
.70759 .23562 .72951 .26416 .77791 .25247 .75644 .22186 Metetra
.656 .745 .915 r
.75644 .22186 .77791 .25247 .82691 .23683 .806 .2053 Metetra
.665 .745 .91 r
.15403 .39657 .18227 .42243 .22238 .40783 .19447 .38192 Metetra
.676 .75 .907 r
.19447 .38192 .22238 .40783 .26331 .39059 .23566 .36581 Metetra
.704 .769 .902 r
.23566 .36581 .26331 .39059 .30517 .36766 .27773 .34618 Metetra
.739 .804 .904 r
.27773 .34618 .30517 .36766 .3476 .3422 .32061 .32228 Metetra
.734 .821 .919 r
.32061 .32228 .3476 .3422 .3898 .33081 .36388 .29909 Metetra
.67 .718 .884 r
.36388 .29909 .3898 .33081 .43212 .34151 .40739 .28239 Metetra
.625 .572 .774 r
.40739 .28239 .43212 .34151 .47598 .34391 .45152 .26803 Metetra
.625 .532 .728 r
.45152 .26803 .47598 .34391 .52112 .31063 .49645 .25037 Metetra
.628 .573 .774 r
.49645 .25037 .52112 .31063 .56637 .2687 .5421 .23504 Metetra
.591 .686 .908 r
.5421 .23504 .56637 .2687 .61224 .24894 .58869 .22633 Metetra
.549 .765 .977 r
.58869 .22633 .61224 .24894 .65941 .24354 .63637 .2184 Metetra
.609 .77 .957 r
.63637 .2184 .65941 .24354 .70759 .23562 .68493 .20614 Metetra
.648 .754 .926 r
.68493 .20614 .70759 .23562 .75644 .22186 .73427 .19022 Metetra
.659 .746 .914 r
.73427 .19022 .75644 .22186 .806 .2053 .78441 .17273 Metetra
.663 .744 .91 r
.12496 .36992 .15403 .39657 .19447 .38192 .16575 .35505 Metetra
.667 .747 .91 r
.16575 .35505 .19447 .38192 .23566 .36581 .20724 .3395 Metetra
.679 .757 .91 r
.20724 .3395 .23566 .36581 .27773 .34618 .24951 .32236 Metetra
.701 .785 .916 r
.24951 .32236 .27773 .34618 .32061 .32228 .29259 .30264 Metetra
.717 .827 .933 r
.29259 .30264 .32061 .32228 .36388 .29909 .33636 .28102 Metetra
.707 .843 .948 r
.33636 .28102 .36388 .29909 .40739 .28239 .38064 .26021 Metetra
.679 .806 .943 r
.38064 .26021 .40739 .28239 .45152 .26803 .42542 .24217 Metetra
.647 .769 .938 r
.42542 .24217 .45152 .26803 .49645 .25037 .47085 .22724 Metetra
.607 .783 .965 r
.47085 .22724 .49645 .25037 .5421 .23504 .51709 .21512 Metetra
.579 .806 .986 r
.51709 .21512 .5421 .23504 .58869 .22633 .56429 .20386 Metetra
.609 .798 .972 r
.56429 .20386 .58869 .22633 .63637 .2184 .61244 .19069 Metetra
.644 .77 .94 r
.61244 .19069 .63637 .2184 .68493 .20614 .66148 .17487 Metetra
.658 .751 .919 r
.66148 .17487 .68493 .20614 .73427 .19022 .71135 .15736 Metetra
.661 .745 .912 r
.71135 .15736 .73427 .19022 .78441 .17273 .7621 .13907 Metetra
.662 .744 .911 r
.09503 .34247 .12496 .36992 .16575 .35505 .13618 .32723 Metetra
.663 .745 .911 r
.13618 .32723 .16575 .35505 .20724 .3395 .17802 .31163 Metetra
.667 .748 .911 r
.17802 .31163 .20724 .3395 .24951 .32236 .22057 .29541 Metetra
.674 .761 .916 r
.22057 .29541 .24951 .32236 .29259 .30264 .26389 .27818 Metetra
.682 .786 .929 r
.26389 .27818 .29259 .30264 .33636 .28102 .30795 .25989 Metetra
.681 .818 .949 r
.30795 .25989 .33636 .28102 .38064 .26021 .35269 .24132 Metetra
.665 .838 .966 r
.35269 .24132 .38064 .26021 .42542 .24217 .39809 .22364 Metetra
.642 .839 .976 r
.39809 .22364 .42542 .24217 .47085 .22724 .4442 .20737 Metetra
.63 .827 .977 r
.4442 .20737 .47085 .22724 .51709 .21512 .49112 .192 Metetra
.637 .805 .964 r
.49112 .192 .51709 .21512 .56429 .20386 .53892 .17635 Metetra
.65 .777 .941 r
.53892 .17635 .56429 .20386 .61244 .19069 .58762 .1596 Metetra
.658 .756 .922 r
.58762 .1596 .61244 .19069 .66148 .17487 .6372 .14178 Metetra
.661 .747 .914 r
.6372 .14178 .66148 .17487 .71135 .15736 .68767 .12325 Metetra
.662 .744 .911 r
.68767 .12325 .71135 .15736 .7621 .13907 .73905 .10427 Metetra
.662 .744 .911 r
.0642 .31418 .09503 .34247 .13618 .32723 .10572 .29849 Metetra
.662 .744 .911 r
.10572 .29849 .13618 .32723 .17802 .31163 .14793 .28253 Metetra
.663 .745 .911 r
.14793 .28253 .17802 .31163 .22057 .29541 .19086 .26623 Metetra
.664 .748 .913 r
.19086 .26623 .22057 .29541 .26389 .27818 .23452 .24951 Metetra
.666 .756 .917 r
.23452 .24951 .26389 .27818 .30795 .25989 .27893 .23232 Metetra
.667 .769 .926 r
.27893 .23232 .30795 .25989 .35269 .24132 .3241 .21481 Metetra
.665 .78 .935 r
.3241 .21481 .35269 .24132 .39809 .22364 .37003 .19726 Metetra
.661 .784 .94 r
.37003 .19726 .39809 .22364 .4442 .20737 .41673 .1798 Metetra
.658 .778 .937 r
.41673 .1798 .4442 .20737 .49112 .192 .46426 .16229 Metetra
.659 .766 .929 r
.46426 .16229 .49112 .192 .53892 .17635 .51265 .14442 Metetra
.66 .754 .92 r
.51265 .14442 .53892 .17635 .58762 .1596 .56192 .12605 Metetra
.661 .747 .914 r
.56192 .12605 .58762 .1596 .6372 .14178 .61209 .10719 Metetra
.662 .744 .911 r
.61209 .10719 .6372 .14178 .68767 .12325 .66318 .08791 Metetra
.662 .744 .911 r
.66318 .08791 .68767 .12325 .73905 .10427 .71521 .06826 Metetra
.662 .744 .911 r
.03242 .28502 .0642 .31418 .10572 .29849 .07432 .26885 Metetra
.662 .744 .911 r
.07432 .26885 .10572 .29849 .14793 .28253 .11692 .25241 Metetra
.662 .744 .911 r
.11692 .25241 .14793 .28253 .19086 .26623 .16025 .23567 Metetra
.662 .744 .911 r
.16025 .23567 .19086 .26623 .23452 .24951 .20432 .21863 Metetra
.663 .746 .912 r
.20432 .21863 .23452 .24951 .27893 .23232 .24916 .20128 Metetra
.663 .749 .914 r
.24916 .20128 .27893 .23232 .3241 .21481 .29478 .18361 Metetra
.663 .751 .916 r
.29478 .18361 .3241 .21481 .37003 .19726 .3412 .16566 Metetra
.662 .753 .917 r
.3412 .16566 .37003 .19726 .41673 .1798 .38844 .14745 Metetra
.662 .751 .916 r
.38844 .14745 .41673 .1798 .46426 .16229 .43653 .12895 Metetra
.662 .748 .914 r
.43653 .12895 .46426 .16229 .51265 .14442 .48549 .11011 Metetra
.662 .746 .912 r
.48549 .11011 .51265 .14442 .56192 .12605 .53535 .0909 Metetra
.662 .744 .911 r
.53535 .0909 .56192 .12605 .61209 .10719 .58612 .07131 Metetra
.662 .744 .911 r
.58612 .07131 .61209 .10719 .66318 .08791 .63785 .05135 Metetra
.662 .744 .911 r
.63785 .05135 .66318 .08791 .71521 .06826 .69054 .03101 Metetra
0 g
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.20751 .18843 m
.21203 .19319 L
s
[(5)] .19846 .17893 .95159 1 Mshowa
.43745 .0984 m
.44155 .10351 L
s
[(10)] .42923 .08816 .80266 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(15)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.25192 .17104 m
.25459 .17394 L
s
.2971 .15335 m
.29972 .15629 L
s
.34306 .13535 m
.34564 .13834 L
s
.38984 .11704 m
.39236 .12006 L
s
.4859 .07942 m
.48831 .08254 L
s
.53524 .06011 m
.53759 .06327 L
s
.58547 .04044 m
.58776 .04364 L
s
.63663 .0204 m
.63885 .02365 L
s
.16384 .20553 m
.1666 .20834 L
s
.12091 .22234 m
.12371 .22511 L
s
.07869 .23888 m
.08153 .2416 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{216, 175.188},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003H0000[a000`40O003h00Of7oo003HOol00=Qo
o`00f7oo003HOol00=Qoo`00f7oo003HOol00=Qoo`00f7oo002<Ool50002Ool00`00Oomoo`12Ool0
08ioo`07001oogooOol007oo0000@goo002>Ool00`00Oomoo`03Ool00`00Oomoo`11Ool008ioo`04
001oogooOol20014Ool008ioo`05001oogooOol00015Ool008eoo`8000=oo`<004=oo`00f7oo003H
Ool00=Qoo`00f7oo002EOol20011Ool009=oo`800003Ool00000041oo`00T7oo0`000goo0P00@7oo
002<Ool01000Ool000001Woo00<007oo0000?goo002;Ool30008Ool01000Oomoo`00?Woo0028Ool3
000:Ool20002Ool00`00Oomoo`0lOol008Ioo`8000]oo`800003D_`00000009oo`03001oogoo03]o
o`00Pgoo0`002Woo0`000e;l0P0000Aoo`00Ool003aoo`00GWoo1@000Woo00<007ooOol06Goo0`00
2Woo0P001U;l00<005;l00000Woo00<007ooOol0>Woo001POol01`00Oomoogoo001oo`0001Moo`<0
00Yoo`<000QBo003001Bo00000=oo`03001oogoo03Uoo`00H7oo00L007ooOomoo`00Ool0000EOol2
000;Ool20002D_`00`00D_aBo006D_`01000D_aBo0000Woo00<007ooOol0>Goo001POol01`00Oomo
ogoo001oo`00019oo`<000]oo`8000ABo003001Bo5;l00MBo003001Bo00000=oo`03001oogoo03Qo
o`00H7oo00L007ooOomoo`00Ool0000?Ool3000<Ool20007D_`00`00D_aBo006D_`01000D_`00000
0goo00<007ooOol0=goo001OOol20004Ool00`00Oomoo`0<Ool2000<Ool3000:D_`00`00D_aBo005
D_`20002D_`01000Oomoo`00>Goo001aOol3000;Ool30002D_`00`00D_aBo009D_`00`00D_aBo002
D_`30004D_`01000Oomoo`00>7oo001_Ool3000:Ool30006D_`00`00D_aBo008D_`00`00D_aBo002
0002D_`00`00D_aBo003D_`01000Oomoo`00=goo001/Ool3000:Ool3000:D_`00`00D_aBo007D_`3
0004D_`00`00D_aBo003D_`01000Oomoo`00=goo001XOol01000Ool000002goo0P000U;l00<005;l
D_`025;l00<005;lD_`015;l0`000U;l00<005;lD_`00U;l00<005;lD_`015;l00@007ooOol003Io
o`00Igoo0`002goo0P001E;l00<005;lD_`025;l00<005;lD_`00`001E;l00<005;lD_`00U;l00<0
05;lD_`015;l0P000Woo00<007ooOol0<goo001TOol3000<Ool20008D_`00`00D_aBo007D_`30009
D_`01@00D_aBo5;l000015;l0P000U;l00<007oo0000=Goo001ROol2000<Ool3000:D_`00`00D_aB
o004D_`30002D_`00`00D_aBo008D_`01@00D_aBo000D_`00`0015;l00@007ooOol000Moo`03001o
ogoo02Yoo`00Ggoo0`002goo0`000U;l00<005;lD_`02E;l00<005;lD_`00`001E;l00<005;lD_`0
25;l00<005;lD_`00P0025;l00@007ooOol000Eoo`03001oo`0002]oo`00GGoo0P002goo0`001U;l
00<005;lD_`025;l0`002E;l00<005;lD_`01e;l10002E;l00@007ooOol000Moo`03001oogoo02Uo
o`00FWoo0`002Woo0`002U;l00<005;lD_`01E;l0P000U;l00<005;lD_`025;l00<005;lD_`00e;l
0`000U;l0P002U;l00@007ooOol000Aoo`8002aoo`00>Woo00<007ooOol06Woo0`002Woo0`000U;l
00<005;lD_`025;l00<005;lD_`00e;l0P0015;l00<005;lD_`025;l00<005;lD_`00`001U;l00<0
05;lD_`025;l00D007ooOomoo`0000=oo`03001oogoo02]oo`00>Goo00<007oo00006Goo100027oo
0`001U;l00<005;lD_`025;l00<005;lD_`00P001e;l00<005;lD_`01e;l0`002E;l0P002E;l0P00
0Woo00@007ooOomoo`<002]oo`00>goo00<007ooOol05Goo0P002Woo0P002U;l00<005;lD_`01e;l
0`002U;l00<005;lD_`00e;l0`000U;m00<005;lD_`01e;l0P001U;l0`000U;l0P0000=oo`00Ool0
;goo000iOol2000DOol4000:Ool200000e;l001Bo009D_`00`00D_aBo004D_`30002Dad00`00D_aB
o008D_`00`00D_aBo0030006D_d00`00D_aBo006D_`00`00D_`00002D_`30005D_`01@00Oomoogoo
0000;goo000iOol00`00Oomoo`0AOol3000;Ool20004D_`00`00D_aBo008D_`00`00D_aBo0030006
Dad00`00D_aBo007D_`3000:D_d00`00D_aBo005D_`00`00D_`000020009D_`01000Oomoo`00;goo
000iOol3000?Ool2000<Ool20007D_`00`00D_aBo007D_`30009Dad00`00D_aBo004D_`30002Dad0
0`00D_eBo@08D_d00`00D_aBo004D_`30002D_`00`00D_aBo008D_`01000Oomoo`00;Woo0018Ool3
000;Ool30009D_`00`00D_aBo004D_`30002Dad00`00DaeC7@08Dad00`00D_aBo0030006Dad00`00
D_eBo@08D_d00`00D_aBo00300000e;l001Bo002D_`00`00D_aBo008D_`01000Oomoo`00;Woo0016
Ool2000;Ool30002D_`00`00D_aBo008D_`00`00D_aBo0030006Dad00`00DaeC7@07Dad3000:Dad0
0`00D_eBo@07D_d30004D_`00`00D_aBo002D_`00`00D_aBo007D_`20002Ool00`00Oomoo`0[Ool0
04=oo`<000Yoo`<000IBo003001Bo5;l00MBo0<000YC7@03001C7E<M00AC7@80009??P03001C7E<M
00QC7@03001BoE;m00ABo@<0009C7@03001Bo5;l009Bo003001Bo5;l00=Bo003001Bo5;l00=Bo0<0
009Bo004001oo`00000/Ool0045oo`8000Yoo`<000YBo003001Bo5;l00ABo080009C7@03001C7E<M
00UC7@03001C7E<M00<000E??P03001C7E<M00QC7@03001BoE;m00<000EC7@03001Bo5;l00=Bo003
001Bo5;l009Bo003001Bo5;l00<000EBo004001oogoo000/Ool003ioo`<000Yoo`80009Bo003001B
o5;l00UBo003001Bo5;l00<000EC7@03001C7E<M00QC7@<000U??P03001C7E<M00IC7@@000UC7@03
001Bo5;l009Bo003001Bo5;l009Bo0<000UBo004001oogoo000[Ool003]oo`<00003Ool007oo00Mo
o`<000EBo003001Bo5;l00QBo0<000UC7@03001C7E<M00AC7@<0009?GP03001??Tln00Q??P04001C
7E<MDad40003Bch00`00DaeC7@08Dad01P00D_aBo5;l001Bo0<0009Bo@03001Bo5;l00QBo004001o
ogoo000ZOol003Uoo`8000Yoo`<000UBo08000IBo080009C7@03001C7E<M00QC7@03001C7E<M00<0
00I?GP8000Q??P@000Q;?P03001C7E<M00MC7@03001Bo5;l00<000EBo@03001Bo5;l00QBo004001o
ogoo000ZOol003Ioo`<000Yoo`80009Bo003001Bo5;l00UBo003001Bo5;l00<000EC7@03001C7E<M
00MC7@<000]?GP04001??TlnCch40002Bcl00`00Bci;?P07Bch00`00DaeC7@06Dad400000e;m001B
o@06D_d00`00D_aBo007D_`200000goo0000000YOol003Aoo`8000Yoo`<000EBo003001Bo5;l00UB
o08000UC7@03001C7E<M00AC7@80009CGP03001?GTmN00U?GP@000M;?`03001;?T/n00M;?P04001C
7E<MDad40003Bah00`00D_d00008D_d00`00D_aBo003D_`30002D_`01000Oomoo`00:7oo000aOol3
0009Ool30009D_`00`00D_aBo006D_`200000e<M001C7@09Dad00`00DaeC7@030005Deh20006Ceh3
0002Bah00`00Bcm;?`06Bcl00`00Bci;?P06Bch50008Bah20008D_d00`00D_aBo0030006D_`00`00
Ool0000XOol002moo`8000Yoo`80009Bo003001Bo5;l00QBo003001Bo5;l00=Bo08000AC7@03001C
7E<M00MC7@<000YCGP03001?GTmN00<000I;7P03001;?d/o00I;?`04001;?T/nBch40003Aah00`00
Bai;7P07Bah20007D_d40009D_`01000Oomoo`009goo000/Ool30009Ool30005D_`00`00D_aBo008
D_`00`00D_aBo0020007Dad00`00DaeC7@04Dad20002Deh20009Deh3000:Bah00`00Bcm;?`03Bcl6
0008Aah00`00Bai;7P07Bah01000D_eBoE;m10000dkm00<005;lD_`025;l00@007ooOol002Ioo`00
:Goo0`002Goo0`002E;l00<005;lD_`01e;l0`002U<M00<005<MDad00`001U=N0P000e=N10000U<M
00<004/NBah024/N1P0014Zl00<004LNAah01dLN00<004/NBah01T/N1@0024km00<005;lD_`01e;l
0P0000=oo`00Ool09Goo000WOol2000:Ool20002D_`00`00D_aBo008D_`00`00D_aBo004D_`20002
D_`00`00DaeC7@09Dad2000;Deh30007Dad20006Bah20002CUP00`00B[a:_006B[`20008Aah01000
Bai;7T/N100000A6oP00A_h000U>o@03001Bo5;l00ABo0<0009Bo0<002Eoo`0097oo0`002Goo0`00
1E;l00<005;lD_`025;l00<005;lD_`00`001E;l00<005<MDad01U<M0P0000=G?@00Deh025=N0P00
00=G?@00Dad02E<M00<004/NBah00`0014iH00<004ZlB[`024Zl00<004LNAah00dLN1P0014Kn0P00
0TKn00<004kmC_d01dkm00<005;lD_`00`001E;l00@007ooOol002Aoo`008Woo0P002Goo0`002E;l
00<005;lD_`01e;l0`002E;l00<005<MDad00e<M0P0015Lm0P001E=N0P0015Lm00<005<MDad01e<M
0`0024iH00<004ZlB[`01dZl1P0014KM00<004KnA_h00`000TKn00<004Kn000024km10002E;l00<0
07oo000097oo000POol20009Ool20002D_`00`00D_aBo008D_`00`00D_aBo004D_`20002D_`00`00
D_aBo008D_`00`00DaeC7@020008Ecd00`00DeiCGP020007Ecd00`00DaeC7@04Dad200000dhF001>
F009CUP00`00B[a:_003B[`30002DWP00`00A]e6g@05A]d30005A_h01000A_i6oP000dkm10000dkm
00<005;lD_`01e;l00@007ooOol002=oo`0087oo0P001goo0P001E;l00<005;lD_`025;l00<005;l
D_`00`001E;l00<005;lD_`01e;l0`002ULm0`002ULm00<005<MDad00`0014hF00<004iHCUP01diH
00<004ZlB[`00`001U9h00@004KMA]e6g@<00096g@030016oTKn00=6oPL000M>o@03001Bo5;l00QB
o004001oogoo000ROol0021oo`03001oo`0000=oo`<000QBo003001Bo5;l00MBo0<000UBo003001B
o5;l00ABo080009G7@8000MG?@80009KG@03001G?ELm00QG?@<000M>5P03001>F4iH00Q>F08000UB
N0040016g@000005A]d60002@]d01000@]e2g@002Dkm00<005;lD_`01U;l0P0000=oo`0000008Woo
000OOol01000Oomoogoo0`000U;l00<005;lD_`01e;l00<005;lD_`015;l0P000U;l00<005;lD_`0
25;l00<005;lD_`00`001ULM0P000ULm0`001E]M0P001ULm0P0000=>F000CQH01dhF00<004iHCUP0
1diH00<005HD0000259h0`000dKM10000T[L00<004;M@]d014;M00<004;M00002Dkm00<005;lD_`0
0e;l0`000U;l00@007ooOol000Aoo`D0009oo`03001oogoo01=oo`007goo00<007oo00000P001E;l
00<005;lD_`01e;l00<005;lD_`00`001E;l00<005;lD_`01e;l0`002eLM0P002U]M00<005LmEcd0
0`0014iH00<004hFCQH01ThF00<004iHCUP01DiH00@005HDEQ@000EBN0<000=BN0<000M:g0030012
gD;M00=2g@040012gD;M0009C_d00`00D_`000020006D_`00`00Ool00006Ool01`00Oomoogoo001o
o`0001Aoo`007goo0P002E;l00<005;lD_`01U;l0`002E;l00<005;lD_`015;l0P000ULL00<005LM
Ead01eLM0P0000=KG@00Fed02E]M0`001diH00<004hFCQH01ThF00<004iHCUP014iH00<005HDEQ@0
0UHD00<0059h00000P001E9h00<006:g000024[L00<004;M@]d014;M00@004;M@]d000M>o@<000UB
o004001oogoo0005Ool01`00Oomoogoo001oo`0001Aoo`006Woo00<007ooOol00Woo0P002E;l00<0
05;lD_`015;l0P000U;l00<005;lD_`025;l00<005;lD_`00`001ELL0P001ELM0P0015]M0P001U]M
0P0000=Bf`00CUP01diH00<004hFCQH01dhF00<004iHCUP00TiH00<005HDEQ@00UHD0`001e9h00D0
06:gH[MR]`0000Q:g0030012gD;M00A2g@030012g@0000=>o@@0009>g003001Bo5;l00QBo004001o
ogoo0004Ool01`00Oomoogoo001oo`0001Aoo`006Goo00<007oo00000goo00<007oo00002E;l00<0
05;lD_`00`001E;l00<005;lD_`01e;l0`002ULL00<005LMEad00P0025]M00<005]MFed00`0015;K
00<004iHCUP01DiH00<004hFCQH01dhF00D004iHCUQ>F000009F50<0009F5003001BN59h00ABN003
001R]f:g009R]`03001:g4[L00I:g0d000M>g003001Bo5;l00MBo0800003Ool0000000=oo`07001o
ogooOol007oo000057oo000IOol00`00Ool00003Ool00`00Oomoo`020007D_`30009D_`00`00D_aB
o004D_`20002D_`00`00EaaG7009Ea`2000;Fed20007D]/00`00CUQ>F006CUP00`00CQI>5P06CQH0
0`00CUQ>F0040005EQ@00`00DWQBN003DWP00`00H[MR]`04H[L01000B]a:g4[L10000Tkm00<004:m
@[d00d:m00@004:m@[d000Q>g003001Bo5;l00ABo0<0009Bo0<0009oo`8000Aoo`03001oogoo01=o
o`006Goo00<007oo00000Woo0P0017oo00<005;lD_`010000U;l00<005;lD_`025;l00<005;lD_`0
0`001E;l00<005LLEa`01ULL0P0000=G7000Fed025]M0P0000=KG000D]/01e;K00<004iHCUP01DiH
00<004hFCQH01dhF0`002EHD00D0059hDWQBN00000QR]`<000I>o@030012_D:m00A2_@040012_D:m
0008C]`00`00D_aBo0030005D_`01000Oomoo`007Goo000IOol00`00Ool00002Ool00`00Oomoo`04
Ool20007D_`00`00D_aBo007D_`30009D_`00`00EaaG7003Ea`20004Ea`20005Fed20004Fe`00`00
D]]Bf`05D]/00`00CUQ>F005CUP00`00CQI>5P04CQH4000;EQ@01000DWQBN00026:g00<007NH0000
24km00<004:m@[d014:m00<004:m000024kL0`002E;l00<007oo00007Goo000JOol01@00Oomoogoo
00001goo00<005;lD_`01U;l0P001E;l0P000U;l00<005;lD_`025;l00<005LLEa`00P0025LL00<0
05]MFed00P001e]L00<005;KD]/015;K00<004iHCUP01TiH00@004hFCQI>5P80009>5P8000aF5080
00UR]`04001gV7NH0008C_d00`00@[e2_@03@[d01000@[e2_@000dkL10000TkL00<005;lD_`01e;l
00@007ooOol001aoo`007Woo00<007ooOol01Woo00<005;lD_`01e;l00<005;lD_`00P001E;l00<0
05;lD_`01e;l0`002eLL0P002U]L00<005;KD]/015;K00<004iHCUP01DiH10000ThF0P000TgD00<0
05HDEQ@02EHD00<006:gH[L01f:g00D007NHMiQgV00000Q>o@030012_D:m00=2_@L000M>g003001B
o5;l00MBo004001oo`00000KOol001ioo`03001oogoo00Moo`03001Bo5;l00IBo0<000QBo08000EB
o080009Fo003001G75LL00MG70800003Gc`0000000UKG0<000ABf`03001>F4iH00=>F0<000A>5P03
001=e4gD009=e003001F55HD00UF508000MR]`03001gV7NH00=gV003001>oDkm00=>o@P00096W004
0016W4JL0008C]`00`00D_aBo006D_`20002Ool00`00Oomoo`0IOol001ioo`03001oogoo00Qoo`04
001Bo5;lD_`40002D_`00`00D_aBo008D_`00`00D_aBo0020005E_`20005Ea`20005Gc`20003Fe`4
00000dkm000en@0400000e;K001>F0030002CUP01@00CQI>5ThF00001DgD00<005HDEQ@025HD00<0
06JD00001V:g00<007NHMiP01GNH1@0014[L00<004JLAY`014JL00<004JL00002DkL00@005;lD_aB
o0@0009Bo004001oogoo000JOol001eoo`03001oogoo00Yoo`<000MBo003001Bo5;l00MBo0<000UF
o003001G75LL008000UO?0<000I>o@03000enCGi008en@D000A>F0<000I=e003001F55HD00QF5004
001VU6JD0005H[L00`00MiQgV004MiP00`00KoX00008B]`00`00AYa6W003AY`01000AYa6W0001dkL
1@001e;l00@007ooOol001Uoo`007Goo00<007ooOol02goo00<005;lD_`01e;l00<005;lD_`015;l
0P000U;l00<005KlE_`025Kl0P002Ell0P0000=O>`00C_d01Tkm00<003Gi00000P0000<en@00@KD0
0T6e1@002DgD00<005HDEQ@01UHD00D006JDIYAVU00000AR]`03001gV7NH00AgV005001_nVojKoX0
0007B]`00`00AYa6W004AY`00`00AY`00003C]`40003C]`00`00D_aBo006D_`01000Oomoo`006Goo
000MOol2000=Ool00`00D_aBo007D_`00`00D_aBo0030005D_`00`00E_aFo005E_`200000e/L001O
?007Gc`00`00Gc]O>`02Gc/00`00C_e>o@03C_d30004=OT00`00@KE1]@05@KD00`00CMA=e007CM@0
0`00EQAF5006EQ@00`00IYAVU002IY@01000H[MR]`001WNH00<006ojKoX00Voj00<004[LB]`01T[L
00<004JLAY`00dJL1P001dkL00<005;lD_`01e;l00@007oo000001Qoo`007Goo00<007ooOol03Goo
0P001e;l0`002E;l00<005KlE_`00UKl0P0015/L0P0015ll0P001Ulk00<004km00000P000Tkm00<0
03Gi=OT00cGi00<0046e@KD0146e00<004gDCM@01dgD00<005HDEQ@01EHD00<006JDIY@00fJD00<0
06:g00001WNH00<006ojKoX016oj00<004[LB]`00d[L20000TZl00<004Zl00002DkL00<005;lD_`0
1E;l0`000Woo00<007ooOol05Goo000MOol00`00Oomoo`0?Ool00`00D_aBo0040002D_`00`00D_aB
o008D_`01000E_`0000025/L00@005ll000000MO>`<000E>o@03000enCGi00<en@030011]D6e00E1
]@03001=e4gD00I=e003001F55HD00EF5003001VU6JD00AVU08000EgV003001_nVoj00E_nPH000A6
V`03001:_4Zl00=:_003001:_00000U>g004001Bo5;lD_`40003D_`00`00Ool0000GOol001eoo`03
001oogoo011oo`8000MBo003001Bo5;l00MBo08000]K7003001O>elk00EO>`8000=O>`8000A>o@03
000enCGi008en@030011]D6e00E1]@03001=e4gD00M=e003001F55HD00=F5003001VU6JD00EVU003
001gV7NH00=gV003001_nVoj00A_nP80009G70030016VdJK00E6V`03001:_4Zl00A:_003001:_000
00Q>g0@000QBo003001oo`0001Ioo`0077oo0`004Woo00<005;lD_`01U;l00<005;lD_`015;l0P00
0UKl00<005/LFa`01U/L0P0000=K6`00Gc/00Ulk0`000elk0P0000AK6`000000009>o@03000enCGi
008en@030011]D6e00E1]@03001=e4gD00M=e003001F55HD00=F5003001VU6JD00EVU0<0009gV003
001_nVoj009_nP<000AG70030016VdJK00I6V`03001:_4Zl00A:_003001:_00000E>g080009Bo003
001Bo5;l00MBo004001oogoo000EOol000Qoo`03001oogoo009oo`03001oogoo009oo`04001oogoo
Ool30003Ool00`00Oomoo`0COol00`00D_aBo006D_`00`00D_aBo0030005E_`20004Fa`20004Fa/3
0004Gc/20004Fa/01P004O`00000C_d000<en@030011]D6e00E1]@03001=e4gD00M=e003001F55HD
009F5003001VU6JD00EVU004001kTG^ANi470008Ea`00`00AY]6V`06AY/00`00B[a:_004B[`20002
C]`30004D_`00`00D_aBo007D_`200000goo001oo`0DOol000Moo`03001oo`0000Moo`03001oo`00
009oo`03001oogoo00=oo`03001oogoo01Aoo`03001Bo5;l00EBo0<000YFo004001K70000003Fa/3
0002Fa/00`00Gc]O>`020006Fa/010004O`Ao17l0P0013Gi00<0046e@KD0146e00<004gDCM@01dgD
00<005HDEQ@00UHD00<006JDIY@01FJD00<007^ANi400W^A100000=Wn@00Ea`01eLL00<004JKAY/0
1TJK00<004ZlB[`00dZl1@0025;l00<005;lD_`00e;l0`000U;l00<007oo000057oo0007Ool00`00
Ool00007Ool00`00Ool00003Ool00`00Oomoo`02Ool00`00Oomoo`0EOol00`00D_aBo0040002D_`0
0`00E_aFo008E_`20002Fa/30006Fa/20009Fa/00`004O`Ao0024O`01@00=OTenCGi00001T6e00<0
04gDCM@024gD00@005HDEQ@000QVU004001kTG^ANi440003IoT00`00EaaG7006Ea`00`00AY]6V`02
AY/90002C[`00`00C[`00008D_`00`00D_aBo0030005D_`00`00Ool0000DOol000Moo`03001oo`00
00Moo`03001oo`0000=oo`03001oogoo009oo`03001oogoo01Ioo`8000MBo08000IFo0800004E_`0
00000007Fa/200000elK001K6`08Fa/200034O`01@00=OTenCGi00001d6e00<004gDCM@01dgD00@0
05HDEQ@000MVU003001kTG^A009kT@<000AWn@03001G75LL00=G70P000E:V`03001>_4jl00A>_080
00QBo0<000UBo003001oo`0001=oo`001goo00<007oo00001goo00<007oo00000Woo00<007oo0000
0goo00<007ooOol05goo00<005;lD_`01e;l00<005KlE_`01P000UKl00<005/KFa/015/K00<005lK
Ga/00UlK0P001E/K0P000UKk00D0017l4O`Ao000008en@030011]D6e00E1]@03001=e4gD00M=e003
001F500000QVU004001kTG^ANi430005IoT60004BY/00`00BY]:V`06BY/00`00C[a>_004C[`00`00
C[`00005D_`20002D_`00`00D_aBo007D_`01000Oomoo`004Woo0008Ool00`00Oomoo`07Ool00`00
Oomoo`02Ool01@00Oomoogoo00006goo00<005;lD_`01U;l1P001UKl00<005/KFa/00U/K00<005lK
Ga/01ElK00<005/KFa/00P001EKk00<0017l4O`00P000SGi00<0046e@KD0146e00<004gDCM@01dgD
00<005HD00001fJD00<007^ANi400W^A00<006OiIoT00fOi0P000U:k00<004ZKBY/01DZK00<004ZK
BY/01dZK00<004jlC[`014jl0P000U;l0`001E;l00<005;lD_`01U;l0P0000=oo`00Ool017oo1@00
0Woo00<007ooOol00goo000KOol00`00Oomoo`0JOol00`00D_aBo003D_`5000:E_`01000Fa/00000
2ElK0P0025Kk0P0000DAo000=OTen@0000I1]@03001=e4gD00Q=e003001VU6JD00IVU005001kTG^A
Ni400004IoT20004D[/00`00BY]:V`06BY/00`00BY]:V`06BY/00`00C[a>_005C[`30008D_`00`00
D_aBo004D_`20002D_`00`00Ool00006Ool01`00Oomoogoo001oo`0000Aoo`006goo0P0077oo00<0
05;lD_`010000e;l00<005KlE_`01eKl0P002ElK0P0000=NnP00E_/025Kk100000<en@00@KD01D6e
00<004gDCM@024gD00<006JDIY@01VJD00@007^ANi5kT@D000MB^`03001:VdZK00I:V`03001:VdZK
00I:V`03001>_4jl00@00003D]`0000000UBo003001Bo5;l00<000ABo004001oogoo0005Ool00`00
Oomoo`03Ool00`00Oomoo`02Ool001]oo`03001oogoo01aoo`@000IBo003001Fo5Kl00AFo080009F
o003001O6elK00EO6`03001NnUkj009NnP03001FneKk00AFn`800006F]X00000000en@001T6e00<0
04gDCM@01dgD0P001fJD00@007^ANi5kT@<0009Ff`03001B^e:k00EB^`03001:VdZK00I:V`03001:
VdZK00=:V`H000EBg003001Bg00000QBo0<000QBo003001oo`0000Eoo`04001oogooOol20005Ool0
01]oo`03001oogoo01Yoo`@000UBo003001Fo5Kl00<000EFo003001O6elK009O6`8000ENnP03001F
neKk009Fn`8000AJfP@000M1]@03001=e4gD00E=e004001JEEYE0006IY@01@00Ni5kTG^A00001EKK
00<005:kD[/01E:k00<004ZKBY/01DZK1P0014jk00<005;LD]`01E;L00<005;L00000e;l10000U;l
00<005;lD_`01U;l00@007oo000000Aoo`05001oogooOol00006Ool001]oo`03001oogoo01Moo`<0
00Aoo`8000MBo0<000UFo004001O6`000008G_X01000E_/000001e[J10001T6e00<004gDCM@01DgD
00@005YEFUD000IVU004001kTG^A0006E]/00`00D[]B^`05D[/01000BY]:VdZK10000TjK00<004jk
C[/01Tjk00<005;LD]`01E;L1@001e;l00<005;lD_`01E;l10000goo0P000goo0`0017oo000JOol0
0`00Oomoo`0EOol30009Ool00`00D_aBo0040002D_`00`00E_aFo007E_`2000;G_X00`00F]YJfP08
F]X30006@KD00`00CMA=e004CM@01@00FUEJEEYE00001FJD00D007^ANi5kT@0000MFf`03001B^e:k
009B^`H000I>V`03001>^djk00I>^`03001Bg5;L00ABg0<00003D_`005;l00MBo004001Bo5;lD_`4
0002D_`2000?Ool001Yoo`8001=oo`<000eoo`8000MBo08000EFo080009Jn`03001NnUkj00INnP80
0003G_X005[J00UJfP8000I1]@03001=e4gD00==e003001JEEYE00=JE@03001VU6JD009VU004001k
TG^A0008E]/50004CYX00`00CY]>V`06CY/00`00C[]>^`06C[/00`00D]aBg0030002D_`00`00D_`0
0008D_`40007D_`00`00Oomoo`0=Ool001Yoo`03001oogoo00moo`<0015oo`03001Bo5;l00MBo003
001Fo5Kl008000EJn`03001NnUkj00ANnP03001NnUkj009NnP03001JfU[J00EJfPD000E1]@03001=
e4gD009=e003001JEEYE00AJE@03001VU6JD009VU003001kTG^A008000EFf`800003DYX004jJ00I>
VP03001>VdjK00M>V`03001>^djk00E>^`<000IBo003001Bo00000EBo080009Bo003001Bo5;l00IB
o08000ioo`006Woo00<007ooOol037oo0`005Goo00<005;lD_`01U;l0`0025[k00<005kjG_X00Ukj
00<005kjG_X00ekj00<005[JF]X00e[J0P000e[J10000d6e00D004gDCMA=e00000MJE@05001VU6JD
IY@00002Ni400`00D[/00002E]/30004DYX00`00CYY>VP05CYX00`00CY]>V`06CY/01000C[]>^djk
10000U;l00<005;lD_`01E;l0P000U;l0`0015;l00<005;lD_`01U;l0P003Woo000JOol00`00Oomo
o`09Ool3000IOol00`00D_aBo003D_`20002E_`00`00F_]Jn`07F_/01000G_X000001ekj00<005[J
F]X00P001E[J0P000REF00L0046e@KE1]@00CM@00008FUD01@00IYAVU6JD00000W^A00<005:k0000
0P001e:J00<004jJCYX01TjJ00<004jKCY/01DjK10001e;l00<005;lD_`015;l100025;l00<005;l
D_`00e;l0P0000=oo`00Ool03Goo000JOol20008Ool2000MOol00`00D_aBo0020005E_`00`00F_]J
n`06F_/2000:G_X20008F]X200029EH01P00@KE1]@00CM@000UJE@03001VU000009kT@<0009B^P03
001BVU:J00IBVP03001>VTjJ00E>VP04001>VdjKCY/40002D]`00`00D_aBo006D_`01000D_aBo5;l
1@0000=Bo000D_`01e;l00<005;lD_`00`000goo00<007ooOol037oo0006Ool00`00Oomoo`02Ool0
0`00Oomoo`02Ool00`00Oomoo`02Ool300000goo001oo`06Ool3000POol20008E_`00`00F_]Jn`03
F_/20002E_/00`00G_YNnP05G_X200000e[k001JfP07F]X200039EH4000:FUD00`00IY@00002Ni40
0`00D[YB^P02D[X00`00DYYBVP06DYX00`00CYY>VP05CYX40007D]`00`00D_aBo005D_`40005D_`0
0`00D_`00007D_`30006Ool00`00Oomoo`0<Ool000Eoo`03001oo`0000Moo`03001oo`0000Aoo`04
001oogoo0004Ool3000TOol00`00E_aFo007E_`00`00F_]Jn`020005E_/00`00G_YNnP02G_X20004
F_/00`00F]YJfP06F]X00`009EHUEP039EH00`00FUEJE@09FUD01@00IY@007^A00001U:j00<005:J
DYX01U:J00<004jJCYX010000U;K00<005;LD]`01U;L00@005;lD_aBo0@0009Bo003001Bo5;l00EB
o08000=Bo0@000Uoo`03001oogoo00aoo`001Goo00<007oo00001goo00<007oo00000Woo100000=o
o`00Ool00`00:7oo0P001eKl0`0025Kk00@005kj000000MJn`03001JfU[J00AJfP<000@UEP03001J
EEYE00YJE@<000QB^P03001BVU:J00ABVP@000IBf`03001Bg5;L00IBg0@000MBo003001Bo5;l00AB
o0D000eoo`03001oogoo00aoo`001Goo00<007oo00001goo00<007oo00000Woo00<007oo00000Woo
0P00;Goo00<005KlE_`010000U;l00<005KkE_/01UKk0P002E[k00<005[JF]X00U[J0P000U[j00<0
02EF9EH00bEF00<005YEFUD02EYE00@005=<000000MB^P03001BVU:J00@0009Bf`03001Bfe;K00IB
f`03001Bg5;L00=Bg080009Bo003001Bo5;l00IBo004001Bo5;lD_`5000AOol00`00Oomoo`0;Ool0
00Eoo`03001oo`0000Moo`03001oo`0000=oo`8000=oo`03001oogoo02aoo`8000MBo003001FneKk
00=Fn`80009Fo003001Jne[k00MJn`04001JfP000004F_X00`009EHUEP039EH00`00FUEJE@08FUD0
1@00Dd`005Jj00001e:j0`001e;K00<005;KD]/01E;K00<005;LD]`00`0015;l00<005;lD_`01U;l
10001Goo00<007ooOol03Woo00<007ooOol02goo0006Ool00`00Oomoo`07Ool00`00Oomoo`03Ool0
0`00Oomoo`02Ool2000]Ool00`00D_aBo006D_`00`00E_]Fn`020005E_`00`00F_]Jn`06F_/20007
F_X00`009EHUEP029EH00`00FUEJE@08FUD20003E[X00`00D[YB^P040002D]/00`00D]]Bf`05D]/0
0`00D]]Bf`05D]/30008D_`00`00D_aBo003D_`2000:Ool00`00Oomoo`0=Ool00`00Oomoo`0;Ool0
01eoo`03001oogoo02]oo`03001Bo5;l00EBo0<000MFo003001Jne[k00AJn`80009Fn`03001JnU[j
00AJnP03000UEREF008UEP03001JEEYE00MJE@8000=F^P@000IBf`03001Bfe;K00IBf`03001Bfe;K
00@0009Bo003001Bo5;l00IBo003001Bo5;l00<000aoo`03001oogoo00eoo`03001oogoo00]oo`00
7Woo00<007ooOol0:goo00<005;lD_`010000U;l00<005KlE_`01UKl00<005[kF_/00`001EKk00<0
05[jF_X015[j00<002EF9EH00REF00<005YEFUD01UYE00<005JjE[X00P000UKK00<005;KD]/01U;K
00<005;KD]/01E;K0`001e;l00<005;lD_`01E;l0`0047oo00<007ooOol037oo00<007ooOol02goo
000OOol00`00Oomoo`0[Ool20007D_`00`00E_aFo005E_`30008E_/00`00F_YJnP03F_X200049EH0
0`00FUEJE@05FUD40005E]/00`00D]]Bf`05D]/01000D]]Bfe;K10000U;l00<005;lD_`01U;l00<0
05;lD_`0100057oo00<007ooOol02goo00<007ooOol02goo000POol2000/Ool00`00D_aBo006D_`0
0`00E_aFo0040002E_`00`00E_]Fn`07E_/00`00F_YJnP020002E_/01@009EHUEREF00001eYE0P00
1eKK00<005;KD]/01E;K10001e;l00<005;lD_`01E;l0`0067oo00<007ooOol02goo00<007ooOol0
2goo000ROol00`00Oomoo`0ZOol20006D_`30007E_`20007E_/30005E_/01@009EHUEREF00001EYE
00<005Kl000025KK00<005;KD]/010000U;l00<005;lD_`01U;l00@005;lD_aBo0@001aoo`03001o
ogoo00]oo`03001oogoo00Yoo`008goo00<007ooOol0:goo00<005;lD_`00`000U;l00<005KlE_`0
1eKl00<005KkE_/010000UKl00<005KkE_/00eKk00D002EF9EHUEP0000EJE@04001Fo5Kl0007E]/3
0007D_`00`00D_aBo005D_`4000QOol00`00Oomoo`0:Ool00`00Oomoo`0:Ool002Aoo`03001oogoo
02]oo`8000IBo08000MFo0<000MFo003001FneKk00=Fn`04000UEREF0004FUD01@00E_aFo5Kl0000
1EKK0P000U;l00<005;lD_`01U;l00<005;lD_`010009Woo00<007ooOol02Goo00<007ooOol02Woo
000UOol2000/Ool00`00D_aBo006D_`00`00E_aFo0040002D_`00`00E_aFo006E_`00`00E_]Fn`02
00001EKl000UEREF00000eYE00<005KlE_`00UKl00<005KKE]/00P001E;l00<005;lD_`01E;l0`00
:Woo00<007ooOol02Goo00<007ooOol02Woo000WOol00`00Oomoo`0ZOol00`00D_aBo005D_`30007
D_`00`00E_aFo005E_`30004E_`00`009EH00002FUD00`00E_aFo003E_`30008D_`00`00D_aBo004
000^Ool00`00Oomoo`08Ool00`00Oomoo`0:Ool002Qoo`03001oogoo02Yoo`03001Bo5;l00@0009B
o003001Bo5;l00IBo003001Fo5Kl00@0009Bo003001Fo5Kl00=Fo080009JE@03001Fo00000<0009B
o003001Bo5;l00IBo0<003=oo`03001oogoo00Moo`03001oogoo00Yoo`00:Goo00<007ooOol0:Woo
0P001e;l00<005;lD_`01E;l0`001e;l00<005KlE_`00UKl0P0000AJE@00000000MBo003001Bo5;l
00=Bo08003Moo`03001oogoo00Moo`03001oogoo00Uoo`00:Woo00<007ooOol0:Woo00<005;lD_`0
1U;l00<005;lD_`010000U;l00<005;lD_`01U;l00<005KlE_`01@0000=Bo000D_`01e;l00<005;l
D_`00P00>Goo00<007ooOol01goo00<007ooOol02Goo000[Ool2000[Ool00`00D_aBo005D_`30007
D_`00`00D_aBo005D_`30003D_`01@00D_aBo5;l00001e;l0`00?7oo00<007ooOol01Woo00<007oo
Ool02Goo000]Ool00`00Oomoo`0YOol00`00D_aBo0040002D_`00`00D_aBo006D_`00`00D_aBo004
0002D_`00`00D_aBo005D_`01000D_aBo5;l1000@7oo00<007ooOol01Goo00<007ooOol02Goo000^
Ool00`00Oomoo`0YOol20007D_`00`00D_aBo005D_`30007D_`00`00D_aBo004D_`40015Ool00`00
Oomoo`04Ool00`00Oomoo`09Ool002moo`03001oogoo02Uoo`03001Bo5;l00IBo003001Bo5;l00@0
009Bo003001Bo5;l00IBo003001Bo5;l00<004Uoo`03001oogoo00Aoo`03001oogoo00Uoo`00<7oo
0P00:Woo00<005;lD_`01E;l0`001e;l00<005;lD_`01E;l0`00CGoo00<007ooOol00goo00<007oo
Ool02Goo000bOol00`00Oomoo`0XOol00`00D_aBo0040002D_`00`00D_aBo006D_`00`00D_aBo004
001AOol00`00Oomoo`03Ool00`00Oomoo`08Ool003=oo`03001oogoo02Qoo`8000MBo003001Bo5;l
00EBo0<005Eoo`03001oogoo00=oo`03001oogoo00Qoo`00=7oo00<007ooOol0:7oo00<005;lD_`0
1U;l00<005;lD_`01000FGoo00<007ooOol00Woo00<007ooOol027oo000eOol2000YOol00`00D_aB
o005D_`3001NOol01@00Oomoogoo00002Woo000gOol00`00Oomoo`0WOol00`00D_aBo004001ROol0
1000Oomoo`002Woo000hOol00`00Oomoo`0WOol2001VOol01000Oomoo`002Woo000iOol00`00Oomo
o`0VOol00`00Oomoo`1VOol00`00Ool0000:Ool003Yoo`8002Ioo`03001oogoo06Moo`03001oo`00
00Uoo`00?7oo00<007ooOol08goo00<007ooOol0J7oo0P002Goo000mOol00`00Oomoo`0ROol00`00
Oomoo`1XOol20009Ool003ioo`03001oogoo025oo`03001oogoo06Qoo`8000Uoo`00?goo0P008Goo
00<007ooOol0I7oo10002goo0011Ool00`00Oomoo`0NOol00`00Oomoo`1POol4000?Ool0049oo`03
001oogoo01eoo`03001oogoo05aoo`@001=oo`00@goo00<007ooOol077oo00<007ooOol0F7oo1000
5goo0014Ool2000LOol00`00Oomoo`1DOol4000KOol004Ioo`03001oogoo01Uoo`03001oogoo051o
o`@001moo`00Agoo00<007ooOol067oo00<007ooOol0C7oo10008goo0018Ool00`00Oomoo`0GOol0
0`00Oomoo`18Ool4000WOol004Uoo`8001Ioo`03001oogoo04Ioo`<002]oo`00Bgoo00<007ooOol0
4goo00<007ooOol0@Woo1000;Woo001<Ool00`00Oomoo`0BOol00`00Oomoo`0nOol4000bOol004eo
o`03001oogoo015oo`03001oogoo03Yoo`@003Ioo`00CWoo00<007ooOol047oo00<007ooOol0=Woo
1000>Woo001?Ool2000@Ool00`00Oomoo`0bOol4000nOol0055oo`03001oogoo00eoo`03001oogoo
02ioo`@0049oo`00DWoo00<007ooOol037oo00<007ooOol0:Woo1000AWoo001COol00`00Oomoo`0;
Ool00`00Oomoo`0VOol4001:Ool005Aoo`8000]oo`03001oogoo029oo`@004ioo`00EWoo00<007oo
Ool027oo00<007ooOol07goo0`00DWoo001GOol00`00Oomoo`07Ool00`00Oomoo`0KOol4001EOol0
05Qoo`03001oogoo00Ioo`03001oogoo01Moo`@005Uoo`00FGoo0P001Woo00<007ooOol04goo1000
GGoo001KOol00`00Oomoo`03Ool00`00Oomoo`0?Ool4001QOol005aoo`03001oogoo009oo`03001o
ogoo00]oo`@006Eoo`00GGoo00D007ooOomoo`0000Uoo`@006Uoo`00GWoo0P0000=oo`00Ool017oo
1000KGoo001POol200000goo00000002001aOol0065oo`8007Eoo`00f7oo003HOol00=Qoo`00f7oo
003HOol00=Qoo`00f7oo003HOol00001\
\>"],
  ImageRangeCache->{{{0, 215}, {174.188, 0}} -> {-0.135291, -0.0372306, 
  0.00527415, 0.00527415}}]
}, Open  ]],

Cell["\<\
Here is a cross-section of the 2-D sequence returned by LoGKernel.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(ListPlot[K[\([7]\)], PlotJoined -> True]; \)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0634921 0.506756 16.8618 [
[.15079 .49426 -3 -9 ]
[.15079 .49426 3 0 ]
[.27778 .49426 -3 -9 ]
[.27778 .49426 3 0 ]
[.40476 .49426 -3 -9 ]
[.40476 .49426 3 0 ]
[.53175 .49426 -3 -9 ]
[.53175 .49426 3 0 ]
[.65873 .49426 -6 -9 ]
[.65873 .49426 6 0 ]
[.78571 .49426 -6 -9 ]
[.78571 .49426 6 0 ]
[.9127 .49426 -6 -9 ]
[.9127 .49426 6 0 ]
[.01131 .0009 -30 -4.5 ]
[.01131 .0009 0 4.5 ]
[.01131 .08521 -36 -4.5 ]
[.01131 .08521 0 4.5 ]
[.01131 .16952 -30 -4.5 ]
[.01131 .16952 0 4.5 ]
[.01131 .25383 -36 -4.5 ]
[.01131 .25383 0 4.5 ]
[.01131 .33814 -30 -4.5 ]
[.01131 .33814 0 4.5 ]
[.01131 .42245 -36 -4.5 ]
[.01131 .42245 0 4.5 ]
[.01131 .59106 -30 -4.5 ]
[.01131 .59106 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.15079 .50676 m
.15079 .51301 L
s
[(2)] .15079 .49426 0 1 Mshowa
.27778 .50676 m
.27778 .51301 L
s
[(4)] .27778 .49426 0 1 Mshowa
.40476 .50676 m
.40476 .51301 L
s
[(6)] .40476 .49426 0 1 Mshowa
.53175 .50676 m
.53175 .51301 L
s
[(8)] .53175 .49426 0 1 Mshowa
.65873 .50676 m
.65873 .51301 L
s
[(10)] .65873 .49426 0 1 Mshowa
.78571 .50676 m
.78571 .51301 L
s
[(12)] .78571 .49426 0 1 Mshowa
.9127 .50676 m
.9127 .51301 L
s
[(14)] .9127 .49426 0 1 Mshowa
.125 Mabswid
.05556 .50676 m
.05556 .51051 L
s
.0873 .50676 m
.0873 .51051 L
s
.11905 .50676 m
.11905 .51051 L
s
.18254 .50676 m
.18254 .51051 L
s
.21429 .50676 m
.21429 .51051 L
s
.24603 .50676 m
.24603 .51051 L
s
.30952 .50676 m
.30952 .51051 L
s
.34127 .50676 m
.34127 .51051 L
s
.37302 .50676 m
.37302 .51051 L
s
.43651 .50676 m
.43651 .51051 L
s
.46825 .50676 m
.46825 .51051 L
s
.5 .50676 m
.5 .51051 L
s
.56349 .50676 m
.56349 .51051 L
s
.59524 .50676 m
.59524 .51051 L
s
.62698 .50676 m
.62698 .51051 L
s
.69048 .50676 m
.69048 .51051 L
s
.72222 .50676 m
.72222 .51051 L
s
.75397 .50676 m
.75397 .51051 L
s
.81746 .50676 m
.81746 .51051 L
s
.84921 .50676 m
.84921 .51051 L
s
.88095 .50676 m
.88095 .51051 L
s
.94444 .50676 m
.94444 .51051 L
s
.97619 .50676 m
.97619 .51051 L
s
.25 Mabswid
0 .50676 m
1 .50676 L
s
.02381 .0009 m
.03006 .0009 L
s
[(-0.03)] .01131 .0009 1 0 Mshowa
.02381 .08521 m
.03006 .08521 L
s
[(-0.025)] .01131 .08521 1 0 Mshowa
.02381 .16952 m
.03006 .16952 L
s
[(-0.02)] .01131 .16952 1 0 Mshowa
.02381 .25383 m
.03006 .25383 L
s
[(-0.015)] .01131 .25383 1 0 Mshowa
.02381 .33814 m
.03006 .33814 L
s
[(-0.01)] .01131 .33814 1 0 Mshowa
.02381 .42245 m
.03006 .42245 L
s
[(-0.005)] .01131 .42245 1 0 Mshowa
.02381 .59106 m
.03006 .59106 L
s
[(0.005)] .01131 .59106 1 0 Mshowa
.125 Mabswid
.02381 .01777 m
.02756 .01777 L
s
.02381 .03463 m
.02756 .03463 L
s
.02381 .05149 m
.02756 .05149 L
s
.02381 .06835 m
.02756 .06835 L
s
.02381 .10207 m
.02756 .10207 L
s
.02381 .11894 m
.02756 .11894 L
s
.02381 .1358 m
.02756 .1358 L
s
.02381 .15266 m
.02756 .15266 L
s
.02381 .18638 m
.02756 .18638 L
s
.02381 .20324 m
.02756 .20324 L
s
.02381 .22011 m
.02756 .22011 L
s
.02381 .23697 m
.02756 .23697 L
s
.02381 .27069 m
.02756 .27069 L
s
.02381 .28755 m
.02756 .28755 L
s
.02381 .30442 m
.02756 .30442 L
s
.02381 .32128 m
.02756 .32128 L
s
.02381 .355 m
.02756 .355 L
s
.02381 .37186 m
.02756 .37186 L
s
.02381 .38872 m
.02756 .38872 L
s
.02381 .40559 m
.02756 .40559 L
s
.02381 .43931 m
.02756 .43931 L
s
.02381 .45617 m
.02756 .45617 L
s
.02381 .47303 m
.02756 .47303 L
s
.02381 .48989 m
.02756 .48989 L
s
.02381 .52362 m
.02756 .52362 L
s
.02381 .54048 m
.02756 .54048 L
s
.02381 .55734 m
.02756 .55734 L
s
.02381 .5742 m
.02756 .5742 L
s
.02381 .60793 m
.02756 .60793 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.0873 .50736 m
.15079 .51145 L
.21429 .52982 L
.27778 .57447 L
.34127 .60332 L
.40476 .48316 L
.46825 .18941 L
.53175 .01472 L
.59524 .18941 L
.65873 .48316 L
.72222 .60332 L
.78571 .57447 L
.84921 .52982 L
.9127 .51145 L
.97619 .50736 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{216, 133.438},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003H0000QA000`40O003h00Of7oo003HOol00=Qo
o`00f7oo003HOol00=Qoo`00f7oo003HOol00=Qoo`00f7oo003HOol0019oo`03001oogoo009oo`03
001oogoo009oo`04001oogooOol2002fOol0015oo`03001oo`0000Moo`03001oo`0000Aoo`03001o
ogoo0;=oo`0037oo0`000Woo00<007oo00001goo00<007oo00000goo00<007ooOol00Woo0P00/7oo
000AOol00`00Ool00007Ool00`00Ool00004Ool01@00Oomoogoo0000/Goo000AOol00`00Ool00007
Ool00`00Ool00002Ool00`00Ool00003Ool00`00Oomoo`1IOol00`00Oomoo`1COol0019oo`03001o
ogoo00Moo`03001oogoo009oo`03001oogoo009oo`03001oogoo05Uoo`03001oogoo05=oo`009Woo
00<007ooOol0F7oo00<007oo0000E7oo000VOol00`00Oomoo`1HOol00`00Ool0001DOol002Ioo`03
001oogoo05Moo`04001oogoo001DOol002Ioo`03001oogoo05Moo`05001oogooOol0001COol002Io
o`03001oogoo05Moo`05001oogooOol0001COol002Ioo`03001oogoo05Ioo`03001oogoo009oo`03
001oogoo055oo`009Woo00<007ooOol0EWoo00<007ooOol00goo00<007ooOol0D7oo000VOol00`00
Oomoo`1FOol00`00Oomoo`03Ool00`00Oomoo`1@Ool002Ioo`03001oogoo05Eoo`03001oogoo00Ao
o`03001oogoo051oo`003Goo00<007ooOol00Woo00<007ooOol00Woo00@007ooOomoo`<000=oo`03
001oogoo009oo`03001oogoo05Eoo`03001oogoo00Eoo`03001oogoo04moo`0037oo00<007oo0000
1goo00<007oo00000Woo00<007ooOol00Woo00<007oo00000goo00<007ooOol0E7oo00<007ooOol0
1Woo00<007ooOol0Cgoo0007Ool30002Ool00`00Ool00007Ool00`00Ool00003Ool00`00Oomoo`03
Ool01000Oomoogoo0P00EGoo00<007ooOol01Woo00<007ooOol0Cgoo000<Ool00`00Ool00007Ool0
0`00Ool00003Ool01000Oomoogoo0P0017oo00<007ooOol0E7oo00<007ooOol01goo00<007ooOol0
CWoo000<Ool00`00Ool00007Ool00`00Ool00002Ool00`00Ool00002Ool00`00Oomoo`03Ool00`00
Oomoo`1COol00`00Oomoo`08Ool00`00Oomoo`1>Ool000eoo`03001oogoo00Moo`03001oogoo009o
o`04001oogooOol30003Ool00`00Oomoo`1COol00`00Oomoo`09Ool00`00Oomoo`1=Ool002Ioo`03
001oogoo05=oo`03001oogoo00Uoo`03001oogoo04eoo`009Woo00<007ooOol0DWoo00<007ooOol0
2Woo00<007ooOol0CGoo000VOol00`00Oomoo`1BOol00`00Oomoo`0;Ool00`00Oomoo`1<Ool002Io
o`03001oogoo055oo`03001oogoo00aoo`03001oogoo04aoo`009Woo00<007ooOol0DGoo00<007oo
Ool037oo00<007ooOol0C7oo000VOol00`00Oomoo`1AOol00`00Oomoo`0=Ool00`00Oomoo`1;Ool0
02Ioo`03001oogoo051oo`03001oogoo00ioo`03001oogoo04]oo`009Woo00<007ooOol0D7oo00<0
07ooOol03Woo00<007ooOol0Bgoo000VOol00`00Oomoo`1@Ool00`00Oomoo`0?Ool00`00Oomoo`1:
Ool0019oo`03001oogoo009oo`03001oogoo009oo`04001oogooOol30003Ool00`00Oomoo`1?Ool0
0`00Oomoo`0@Ool00`00Oomoo`1:Ool0015oo`03001oo`0000Moo`03001oo`00009oo`03001oogoo
00=oo`03001oogoo04moo`03001oogoo011oo`03001oogoo04Yoo`0037oo0`000Woo00<007oo0000
1goo00<007oo00000goo00<007ooOol00Woo0P00Cgoo00<007ooOol04Woo00<007ooOol0BGoo000A
Ool00`00Ool00007Ool00`00Ool00003Ool00`00Oomoo`02Ool00`00Oomoo`1>Ool00`00Oomoo`0B
Ool00`00Oomoo`19Ool0015oo`03001oo`0000Moo`03001oo`00009oo`03001oo`0000=oo`03001o
ogoo04ioo`03001oogoo019oo`03001oogoo04Uoo`004Woo00<007ooOol01goo00<007ooOol00Woo
00<007ooOol00Woo00<007ooOol0CGoo00<007ooOol057oo00<007ooOol0B7oo000VOol00`00Oomo
o`1=Ool00`00Oomoo`0DOol00`00Oomoo`18Ool002Ioo`03001oogoo04eoo`03001oogoo01Aoo`03
001oogoo04Qoo`009Woo00<007ooOol0CGoo00<007ooOol057oo00<007ooOol0B7oo000VOol00`00
Oomoo`1<Ool00`00Oomoo`0FOol00`00Oomoo`17Ool002Ioo`03001oogoo04aoo`03001oogoo01Io
o`03001oogoo04Moo`009Woo00<007ooOol0C7oo00<007ooOol05Woo00<007ooOol0Agoo000VOol0
0`00Oomoo`1<Ool00`00Oomoo`0FOol00`00Oomoo`17Ool002Ioo`03001oogoo04aoo`03001oogoo
01Moo`03001oogoo04Ioo`009Woo00<007ooOol0Bgoo00<007ooOol067oo00<007ooOol0AWoo000=
Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`050002Ool00`00Oomoo`02Ool00`00Oomo
o`1;Ool00`00Oomoo`0HOol00`00Oomoo`16Ool000aoo`03001oo`0000Moo`03001oo`0000=oo`07
001oogooOol007oo00000goo00<007ooOol0Bgoo00<007ooOol067oo00<007ooOol0AWoo0007Ool3
0002Ool00`00Ool00007Ool00`00Ool00003Ool00`00Oomoo`03Ool01000Oomoogoo0P00C7oo00<0
07ooOol067oo00<007ooOol0AWoo000<Ool00`00Ool00007Ool00`00Ool00003Ool01000Oomoogoo
0P0017oo00<007ooOol0Bgoo00<007ooOol06Goo00<007ooOol0AGoo000<Ool00`00Ool00007Ool0
0`00Ool00003Ool01@00Oomoogoo00001Goo00<007ooOol0BWoo00<007ooOol06Woo00<007ooOol0
AGoo000=Ool00`00Oomoo`07Ool01000Oomoogoo0P000goo0`000goo00<007ooOol0BWoo00<007oo
Ool06Woo00<007ooOol0AGoo000VOol00`00Oomoo`1:Ool00`00Oomoo`0JOol00`00Oomoo`15Ool0
02Ioo`03001oogoo04Yoo`03001oogoo01]oo`03001oogoo04Aoo`009Woo00<007ooOol0BGoo00<0
07ooOol077oo00<007ooOol0A7oo000VOol00`00Oomoo`19Ool00`00Oomoo`0LOol00`00Oomoo`14
Ool002Ioo`03001oogoo04Uoo`03001oogoo01aoo`03001oogoo04Aoo`009Woo00<007ooOol0BGoo
00<007ooOol07Goo00<007ooOol0@goo000VOol00`00Oomoo`19Ool00`00Oomoo`0MOol00`00Oomo
o`13Ool002Ioo`03001oogoo04Qoo`03001oogoo01ioo`03001oogoo04=oo`009Woo00<007ooOol0
B7oo00<007ooOol07Woo00<007ooOol0@goo000VOol00`00Oomoo`18Ool00`00Oomoo`0NOol00`00
Oomoo`13Ool0019oo`03001oogoo009oo`03001oogoo009oo`03001oogoo00D0009oo`03001oogoo
04Qoo`03001oogoo01moo`03001oogoo049oo`004Goo00<007oo00001goo00<007oo00000goo00<0
07ooOol00Woo00<007ooOol0B7oo00<007ooOol07goo00<007ooOol0@Woo000<Ool30002Ool00`00
Ool00007Ool00`00Ool00003Ool00`00Oomoo`02Ool20018Ool00`00Oomoo`0POol00`00Oomoo`12
Ool0015oo`03001oo`0000Moo`03001oo`0000=oo`03001oogoo009oo`03001oogoo04Moo`03001o
ogoo021oo`03001oogoo049oo`004Goo00<007oo00001goo00<007oo00000goo00<007ooOol00Woo
00<007ooOol0Agoo00<007ooOol08Goo00<007ooOol0@Goo000BOol00`00Oomoo`07Ool01000Oomo
ogoo0P0017oo00<007ooOol0Agoo00<007ooOol08Goo00<007ooOol0@Goo000VOol00`00Oomoo`17
Ool00`00Oomoo`0QOol00`00Oomoo`11Ool002Ioo`03001oogoo04Ioo`03001oogoo029oo`03001o
ogoo045oo`009Woo00<007ooOol0AWoo00<007ooOol08Woo00<007ooOol0@Goo000VOol00`00Oomo
o`16Ool00`00Oomoo`0SOol00`00Oomoo`10Ool002Ioo`03001oogoo04Ioo`03001oogoo02=oo`03
001oogoo041oo`009Woo00<007ooOol0AWoo00<007ooOol08goo00<007ooOol0@7oo000VOol00`00
Oomoo`15Ool00`00Oomoo`0TOol00`00Oomoo`10Ool002Ioo`03001oogoo04Eoo`03001oogoo02Eo
o`03001oogoo03moo`009Woo00<007ooOol0AGoo00<007ooOol09Goo00<007ooOol0?goo000=Ool0
0`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`02Ool0
0`00Oomoo`15Ool00`00Oomoo`0UOol00`00Oomoo`0oOol000aoo`03001oo`0000Moo`03001oo`00
009oo`03001oo`00009oo`03001oo`0000=oo`03001oogoo04Aoo`03001oogoo02Ioo`03001oogoo
03moo`001goo0`000Woo00<007oo00001goo00<007oo00000Woo00<007oo000017oo00@007ooOomo
o`8004Eoo`03001oogoo02Moo`03001oogoo03ioo`0037oo00<007oo00001goo00<007oo00000Woo
00<007oo00000Woo0P0017oo00<007ooOol0A7oo00<007ooOol09goo00<007ooOol0?Woo000<Ool0
0`00Ool00007Ool00`00Ool00002Ool00`00Ool00002Ool00`00Oomoo`03Ool00`00Oomoo`14Ool0
0`00Oomoo`0WOol00`00Oomoo`0nOol000eoo`03001oogoo00Moo`03001oogoo009oo`04001oogoo
Ool30003Ool00`00Oomoo`14Ool00`00Oomoo`0WOol00`00Oomoo`0nOol002Ioo`03001oogoo04=o
o`03001oogoo02Qoo`03001oogoo03ioo`009Woo00<007ooOol04Woo0`005Goo0`004goo0P0000=o
o`00Ool04goo00<007ooOol047oo1@000Woo00<007ooOol03Goo1@0000Aoo`00000000ioo`D0009o
o`<000aoo`009Woo00<007ooOol04Woo00<007ooOol05Woo00<007ooOol04Woo00@007oo000001=o
o`03001oo`0001=oo`07001oo`00Ool007oo000047oo00D007ooOomoo`00019oo`03001oogoo00=o
o`03001oogoo00]oo`009Woo00<007ooOol04goo00<007ooOol04goo10004goo00@007oo000001=o
o`03001oo`0001=oo`07001oo`00Ool007oo000047oo00<007ooOol00Woo00<007ooOol03goo00@0
07ooOomoo`@000aoo`009Woo00<007ooOol04goo00<007ooOol04goo00<007oo000057oo0P0000=o
o`00Ool04goo00<007ooOol04Woo00L007oo001oo`00Ool0000@Ool00`00Oomoo`02Ool00`00Oomo
o`0?Ool01`00Oomoogoo001oo`0000eoo`009Woo00<007ooOol04Woo00<007oo00005Goo0P0057oo
00<007oo000057oo00<007oo00004goo00<007ooOol00P0000=oo`00Ool03goo00L007ooOomoo`00
Ool0000@Ool00`00Oomoo`02Ool2000=Ool002Ioo`03001oogoo01=oo`03001oogoo01Eoo`03001o
ogoo01=oo`8001Eoo`03001oogoo015oo`80009oo`03001oo`00011oo`8000Aoo`03001oogoo00io
o`8000Eoo`03001oogoo00]oo`009Woo00<007ooOol0@Woo00<007ooOol0:goo00<007ooOol0?7oo
000VOol00`00Oomoo`11Ool00`00Oomoo`0]Ool00`00Oomoo`0kOol002Ioo`03001oogoo045oo`03
001oogoo02eoo`03001oogoo03]oo`009Woo00<007ooOol0@7oo00<007ooOol0;goo00<007ooOol0
>Woo000QOong000002Ioo`03001oogoo00=oo`03001oogoo009oo`03001oogoo00=oo`P000Aoo`03
001oogoo009oo`03001oogoo00=oo`03001oogoo00=oo`03001oogoo009oo`03001oogoo00=oo`03
001oogoo00=oo`04001oogoo0002Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`03Ool0
0`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`03Ool00`00Oomoo`03Ool0
1P00Oomoo`00Ool000Eoo`03001oogoo00=oo`03001oogoo00=oo`03001oogoo009oo`03001oogoo
00=oo`03001oogoo00=oo`03001oogoo009oo`L000Eoo`03001oogoo00=oo`009Woo00<007ooOol0
5Woo10009Goo00<007ooOol0<Goo00<007ooOol08goo10004Woo000VOol00`00Oomoo`0JOol4000P
Ool00`00Oomoo`0cOol00`00Oomoo`0NOol4000FOol002Ioo`03001oogoo01ioo`8001ioo`03001o
ogoo03=oo`03001oogoo01]oo`<001Yoo`009Woo00<007ooOol087oo00<007ooOol06Woo00<007oo
Ool0=Goo00<007ooOol06Goo00<007ooOol06goo000VOol00`00Oomoo`0QOol2000JOol00`00Oomo
o`0eOol00`00Oomoo`0GOol2000NOol002Ioo`03001oogoo02=oo`03001oogoo01Ioo`03001oogoo
03Moo`03001oogoo01Eoo`03001oogoo01ioo`009Woo00<007ooOol097oo00<007ooOol057oo00<0
07ooOol0>7oo00<007ooOol057oo00<007ooOol07goo000VOol00`00Oomoo`0UOol2000DOol00`00
Oomoo`0iOol00`00Oomoo`0BOol00`00Oomoo`0POol002Ioo`03001oogoo02Moo`03001oogoo011o
o`03001oogoo03Yoo`03001oogoo015oo`03001oogoo025oo`009Woo00<007ooOol0:7oo00<007oo
Ool03goo00<007ooOol0>goo00<007ooOol03Woo0P0097oo000VOol00`00Oomoo`0YOol2000>Ool0
0`00Oomoo`0lOol00`00Oomoo`0=Ool00`00Oomoo`0TOol002Ioo`03001oogoo02]oo`8000aoo`03
001oogoo03eoo`03001oogoo00Yoo`8002Moo`003Goo00<007ooOol00Woo00<007ooOol00Woo00<0
07ooOol00Woo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol0;Goo0P002Goo00<007ooOol0
?Woo00<007ooOol027oo0P00:Goo000<Ool00`00Ool00007Ool00`00Ool00002Ool00`00Ool00002
Ool00`00Ool00003Ool00`00Oomoo`0_Ool20007Ool00`00Oomoo`0oOol00`00Oomoo`05Ool2000[
Ool000aoo`03001oo`0000Moo`03001oo`00009oo`03001oo`0000Aoo`04001oogooOol2000bOol2
0004Ool00`00Oomoo`10Ool00`00Oomoo`02Ool3000]Ool000aoo`03001oo`0000Moo`03001oo`00
009oo`03001oo`00009oo`8000Aoo`03001oogoo03=oo`80009oo`03001oogoo045oo`04001oo`00
000`Ool000aoo`03001oo`0000Moo`03001oo`00009oo`03001oo`00009oo`03001oogoo00=oo`03
001oogoo03Eoo`8004Aoo`80039oo`003Goo00<007ooOol01goo00<007ooOol00Woo00@007ooOomo
o`<000=oo`03001oogoo0:moo`009Woo00<007ooOol0[goo003HOol00=Qoo`00f7oo003HOol00=Qo
o`00f7oo003HOol00=Qoo`00\
\>"],
  ImageRangeCache->{{{0, 215}, {132.438, 0}} -> {-3.32875, -0.034129, 
  0.0869945, 0.000327573}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Computing the LofG Image", "Subsection"],

Cell[BoxData[
    \(\(\[Del]g = Edge[A, K]; \)\)], "Input"],

Cell["\<\
Shown below are the results of convolving the example image with the 13x13 \
LofG kernel obtained above (compare with the laplacian of same image in \
earlier section!) and its \"binarized\" version - negative values are shown \
in black and positve values white.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[
      GraphicsArray[
        \(ListDensityPlot[#1, Mesh \[Rule] False, FrameTicks \[Rule] None, 
              DisplayFunction \[Rule] Identity]\ &\)\ /@
          \ {\[Del]g, \ Threshold[\[Del]g, \ 0]}]]; \)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .47619 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0113379 0.47619 [
[ 0 0 0 0 ]
[ 1 .47619 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .47619 L
0 .47619 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0113379 0.477324 0.464853 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0160256 0.0192308 0.0160256 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
60 string
60 60 8 [60 0 0 60 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
573736434F5558595B65798F988E807E8A92887A7E93A29D
8A7C7E86847C766D5B515B6F7A735A413E4E5D64676B6E71
747678767472706F6F78857D
493F47555D6162615F6068767F7A6A584C443D3A404E5A5D
584E43372D2B3034333235393A3D3E3A373E4C575D62676B
70737371706F6E6D6C6D6D60
6468727A7C7B797873685E5D5F5B5040322B282A333C4243
4340382B23252D34373836333A57797F664F4E5861676C71
7677757373757573706F6E69
7D858C8D8984838886766259595B595554575B5F676D685D
57595955505053545455534E5A8BC7D29F67555D676F757A
7C7B7876787B7B7975747678
82898C8A837D808F988A756C70777D80848D919193948975
68676B6C6A67615B585B5A56629AE2F4B870545C6971777C
7D7A7675777B7A777372757A
7B81838079737A92A49A837A7C8286858489898483857F71
645E5C5957555049454645404B81CEEAB46B4E58676E7479
7874706F7274736E69696D73
727A7D7A736C7491A79C7D6B686866605A5D605E5E62635E
564D443E40454949474136282D5DACD3A9644852626A6E71
6F6A6564676966615C5C6169
687277766F686F8BA3956F544D4D4A43424E5D625F574E47
43413F4350606D7574674C2B1D418FBF9F5D3E47575F6263
615D5958595A58545253575E
5E666D6E696369849C906A53565F5E575A6D858E80614232
35455A708799A5ADAEA2824F283579AF9A5A373C4D565A5C
5B59595B5E6060616264615C
5C595F63615C617A938C706B83999A8E8790A3A98F5E362B
40668BA7B7BDBEC1C5C4B08148396DA9A4704F52616B7074
76787C838A8E91959A9A8A6F
6557595F615F657A9089737CA6C6C7B5A19AA1A07F4C2F3D
6897B6C3C1B9B2B1B8C2C1A46B4669ACC1A38B8E9BA2A5A8
AAAAAEB5BBBEBFC1C5C6B28A
7F7071767A7C81919D8C6D74A0C3C7B7A393908968403C64
98BBC6C1B5A9A1A1A7B3BDB2815366ABD0C0ADB0BABEBDBC
B9B6B4B4B5B2AEAAABB1AE9A
A29E9E9FA0A0A2AAAF94686087B0BEB59F87786B55475E90
B8C6C1B7AEA7A4A3A5ACB8B7915E6198B6A0878893969594
908B8683807B746C6A778FA0
B1B1AEAAA6A19EA6AE97675376ABC9C19D725345465D89B4
C8C6BCB3ACA7A5A4A5ACBBC2A46F60818F6D4C4C59616365
64615F5E5C59544B46577DA2
9B908A87837D7A879C956A4F6BA4C8BE8E542D27457CB0CB
CEC3B5A595898281889EBED1BB8465757C59393A4A555A5D
5E5E5F60605E59504A5A7F9A
7D655D5F605F5F719095704E5B87A59A6F3C1C265B9FCBD5
C9B39A7E634E43415077AFD9CF966C747B5F444859656A6C
6F707071706E695E59698791
755850555B5C5D6F919D7A524F687B755835254082C0D9CD
AF8C6A4E37261C171F4891D3DAA778787F68515566717678
7A7B7B7A7977716662749193
7C605A606665647497A6865C505D6866543E3B65AAD9D9B4
845A4135302B23160E2872C4E0B68780826C575A6973787B
7D7E7C79787771676479989B
8469656C716E6A799CAC8F685B6269665747538BCCE4C78D
583A33393F403826121D5EB6DCBB8E84836D585B6973787A
7C7B797675746F66637A9BA0
856B697175716E7C9DAC926E646C7169574B66A9E1DDA563
3C343D4749453C2E1F2860AECEAD8681836E595C6A757979
7878777572706C6361779AA1
8469676F73706D7B9AA98F6D6570776E574B71BCE9CA7E41
303C4B4E463D393B40517EB3BB91717A836F595C6C767877
75757675726F6B63607598A0
8366636B6F6C697795A58C6A616D7670574C77C7ECBC632C
2B414D4B43424E657B92AFC3AB755C7284725B5D6D767775
7475767674716D6461769AA2
85645F686D6A677492A38C6A6069726C544B7ACEF2B95B26
293B43444D6381A0B7C6D2CDA1644E6C85745D5F6D757676
7677787876746F6662779DA5
88645E686E6C697594A58F6E646D72684F477BD3F8BD5D27
263239486A93B5CAD3D8DAD0A3654C6984765F606E767878
797A7B7A7876716661779EA9
8D675F69706F6C7898A992716872786A4E4478D2FAC26025
1E293B5E90BBD2D7D5D3D5D3B47B576982776162717A7B7B
7C7D7D7C7A7872666076A0AE
926B606A72726F7B9AA9927068737A6E504371CBFBCD6D26
13234980B5D2D7D0C6BEC1CCC4976A6D81776263737D7E7D
7C7D7E7E7C7972676178A3B3
946B606A7474707C99A890706771776C4F3F67C0FBE38E3C
172861A5D0D6C7B39E8C8CA7BDA77B7381766162727C7E7C
7B7C7E7D7B7872666178A4B4
91695F6A7574707B98A690726A7275674A3659AFF7F7B864
303E82C4D7BF9B7B5F47476FA2A7857880745F5F6E787B79
787A7B7A787670655F75A1B2
8E655C6A75746F7997A58F726C767766432B4796DEEDBF74
42569ED0C28E5F4129161B4E92A68A7B80725D5D6B767877
7778797875746F645D719DAF
8D635B6A75736E7996A38B6C687477643F243879B4BC9254
355CA7C497542E20150C1B579FB1928083745F5F6C757777
787A797774736E635B6F9CAF
8F635A6872716D7996A28869626B6E5D3F2B3F749C935F26
1953A0AA692712181B1E3B7DBBBE9684877963616C747778
7A7C7B7875736E625A6E9DB2
91635A67706F6D7A97A2896B626360564B4C6895B19E5F1D
0F4C989951130A1E314570AED3BB8A7D877C67636C737779
7B7C7B7977756F63596EA0B5
9163596771716F7B95A08A6E625E595B6B85A4C5DACA8A3B
1C4F989F5F241E3A5B7FADD5D39F6D6E837E6A656B727779
7A7A7A7A79787164596EA0B6
8F615A697575727B939E886C5E585B739DBFD0DCEAE4AF5B
2D529CB58B5C556F93B6D6DEB9754E61817F6C666B717679
79797A7B7B7A7465596EA0B5
8E605B6D7979747C929B856756516292C8DCCDC0CBD6B467
324D98C4B89B95A4BBD0D9C68F513D5E83806D686C717679
7978797B7B7A75665A6EA1B6
8E5F5A6D7A78737B92998263504F6CA6D0C1917486A8A062
2D3D82BBC9C1BCC0C5C6BA9867404065847F6D696F747779
7A7A797A7A797364586FA4B8
8F5E596C7674707B92987F604E5175A8B27D3A254A838E5B
24275E99B9C4C4C0B5A38A6C5348516E837B6B6A7277797A
7B7B7A7A7A776F5F546EA5BA
915E586B7573707C93977B5A484F749B8A450E134C8C965F
21102F5F88A3AEAA977C665F656868737D74686A73787A7B
7C7C7B7B7B786D5C516BA5BD
925E576A7675737E9292744F3D456C90804C314C87B6AE6E
26020621456980877C6C697C93907A72746C656972777A7C
7C7B7B7C7D796E5C516AA6BE
935C53687677767F8E896A493B49729A9D847E9AC1D4BC7D
3B0F0007214463757A7B8AA9BEAB836E6B66636971767A7B
7B7A7A7C7D79705F536BA6C0
945A506575787880897F614E546E96B9C2B7B2BDC8C5AC85
5D3E2D2E3F5872848E96A8C3CFB3876E6661636B7275787A
7B7A7A7C7C797061566BA6C2
955A4E64767B7C8284755C5B7EA9C9D6CFBAA89D958A827E
7D7973767F8A939A9EA2AEBFC3AA8872665F646D7273767A
7C7B7B7C7B786F61566BA6C3
965A4E64777F8184806D58679ED3E4D4B38C6C5A52525D74
8D9EA5A9ACA8A2A09F9E9F9F98897D776B60656F7374787C
7D7C7B7A79766E60546AA6C3
95594E64778084857E68566BA5D4D2AC7D5338344052667C
94A9B4B8B3A79C999A978B755F5968766F62667076787B7E
7E7B797877736C5F5369A4C3
95574B60747E83857D67566693AF9E79594541526F879193
9BA7AEAA9D908C929A97856547425B746F636672797C7E7E
7B79787774706C605367A3C2
9656475C6F7A81857D6752587382756668717C90A7B2AA9A
93938E7F6F6B7A91A0A29781675D68736A6065727A7E7F7C
78777776726F6C625568A3C3
9959485B6E7981857E67504C60757B8295A5A9ABAEA7927B
6C64584640537898A9B0B2AEA1908273615A6370797E7E7A
7777787773706D64586AA5C6
9E5F4D5D6F7A82857E69524F6B91A4A7ACAEA5998F7E6347
352F2D2D3E63879BA4AFBECBCAB6926E58566270787C7C7A
7878797875726F655A6DA8CA
A263505E6F7A82857E6B585C80ACB8A697918B847F72552E
15183151748F92827C8DACCAD6C3956650546370777A7A79
78777878777570655A6EABCD
A364515D6D7880837D6E606785A39D7E6F7A889199967944
1A1F5492B6B0804A364D7DAECAC092614D55657177797977
7675757777767165596DAACD
A264505C6B767D817D73696A777D6D5A6588A3B0BBC3AD6E
2F2C6FBCD5AA5815031E5189B2B38C5F4E58687276777776
74737476777672645568A5CA
A265515C6972797F7E78706A64594E5882ADBCB6BBCDC98E
413274BFC887360A0E2D5581A2A3815A4F5B6A7173747575
74747576777771625263A1C8
A266525D686E767D7E7B746B5C4A496DA6C6B5928CADC59D
51386FADA56531305070889DA99C75524C5C6A6E6F727576
767778797877716150619FC7
A165535F6A6F757A7C7A7770604E5380B4BF93584B7DB3A2
5C3E6895875A4E6D96ADB7BDBCA1724D4A5B686C6E727678
797A7A7B7A7972615163A1C8
A06353626F737678797979766A5A618AB2AD75322360A6A0
5F3E5E837F6F7CA0BBC3C3C9C9B07E544C5A666B6F74797B
7B7B7A7A7B7B73635467A4C8
A26454657479787878797C7B71646C94B8B07631235F9F96
5636527D8F98A9BCBFB6B4C1D0C59765535B676D72777B7D
7D7B78787A7B7565576AA7CB
AA6C5B6C7B80807D7B7D807F7366709FCFCF934A396C9A86
4A2F4F87B0C4CCC5AC9290AFD6DFB77E60626B72787D8081
817E7A797B7B76685A6FADD3
B77966748288898683858887796870A5E5F2B86D5B829F83
4E3C63A6D9EAE3C5956C6FA2E1FAD7987370767B7F848788
8684817F7F7E796D627AB9DF
B47864707C83858382868F93887475A2E4FCD19385A5B99F
73668CCBF5FAE9C38B626DA8E8FFDDA17E7B80818386898A
8887858482807C736E86C0DD
8B594C57636A6D6D6E77899998877E96C4DBC4A19EB9CAB9
988BA2C9DDD7C6AA816674A1C9CEAB7C686E7678797C7F80
808181807E7B78747386ACB7
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0113379 0.97619 0.464853 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0160256 0.0192308 0.0160256 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
60 string
60 60 8 [60 0 0 60 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
0000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000FF0000000000000000000000
00000000000000000000FFFF
000000000000000000000000FFFF00000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000
000000FFFFFF000000000000000000000000000000000000
000000000000000000000000000000FF0000000000000000
000000000000000000000000
FFFFFFFFFFFFFFFFFF000000000000000000000000000000
00000000000000000000000000FFFFFFFF00000000000000
FFFF000000FFFF0000000000
FFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFF00
00000000000000000000000000FFFFFFFF000000000000FF
FFFF000000FFFF00000000FF
FFFFFFFF0000FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFF00
00000000000000000000000000FFFFFFFF00000000000000
000000000000000000000000
0000FFFF000000FFFFFFFF00000000000000000000000000
0000000000000000000000000000FFFFFF00000000000000
000000000000000000000000
00000000000000FFFFFF0000000000000000000000000000
0000000000000000000000000000FFFFFF00000000000000
000000000000000000000000
00000000000000FFFFFF0000000000000000FFFFFF000000
00000000FFFFFFFFFFFFFF00000000FFFF00000000000000
000000000000000000000000
0000000000000000FFFF0000FFFFFFFFFFFFFFFFFF000000
0000FFFFFFFFFFFFFFFFFFFF000000FFFF00000000000000
0000FFFFFFFFFFFFFFFFFF00
00000000000000FFFFFF00FFFFFFFFFFFFFFFFFFFF000000
00FFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FF000000FFFFFFFFFFFF0000FFFFFFFFFFFFFFFF00000000
FFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFF0000000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00000000FFFF
FFFFFFFFFFFFFFFFFFFF000000FFFFFFFF0000000000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF00000000000000
00000000000000000000FFFF
FFFFFFFFFFFFFFFFFFFF000000FFFFFFFF00000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF00000000000000
00000000000000000000FFFF
FF00000000000000FFFF000000FFFFFF0000000000FFFFFF
FFFFFFFF000000000000FFFFFFFF0000FF00000000000000
00000000000000000000FFFF
0000000000000000FFFF00000000FF0000000000FFFFFFFF
FFFF0000000000000000FFFFFFFF0000FF00000000000000
FFFFFF00000000000000FFFF
FF00000000000000FFFFFF000000000000000000FFFFFFFF
FF00000000000000000000FFFFFFFFFFFF000000000000FF
FFFFFF00000000000000FFFF
FF00000000000000FFFFFF0000000000000000FFFFFFFFFF
0000000000000000000000FFFFFFFFFFFF000000000000FF
FFFF0000000000000000FFFF
FF000000000000FFFFFFFF0000000000000000FFFFFFFF00
0000000000000000000000FFFFFFFFFFFF00000000000000
00000000000000000000FFFF
FF000000000000FFFFFFFF0000000000000000FFFFFFFF00
00000000000000000000FFFFFFFF0000FF00000000000000
00000000000000000000FFFF
FF00000000000000FFFFFF0000000000000000FFFFFF0000
0000000000000000FFFFFFFFFF000000FF00000000000000
00000000000000000000FFFF
FF00000000000000FFFFFF00000000000000FFFFFFFF0000
000000000000FFFFFFFFFFFFFF000000FF00000000000000
00000000000000000000FFFF
FF00000000000000FFFFFF00000000000000FFFFFFFF0000
0000000000FFFFFFFFFFFFFFFF000000FF00000000000000
00FFFFFF000000000000FFFF
FF00000000000000FFFFFF0000000000000000FFFFFF0000
00000000FFFFFFFFFFFFFFFFFFFF0000FF0000000000FFFF
FFFFFFFFFF0000000000FFFF
FF000000000000FFFFFFFF000000FF00000000FFFFFF0000
000000FFFFFFFFFFFFFFFFFFFFFF0000FF00000000FFFFFF
FFFFFFFFFF0000000000FFFF
FF000000000000FFFFFFFF0000000000000000FFFFFFFF00
000000FFFFFFFFFFFFFFFFFFFFFFFF00FF00000000FFFFFF
FFFFFFFFFF0000000000FFFF
FF000000000000FFFFFFFF0000000000000000FFFFFFFF00
0000FFFFFFFFFFFF00000000FFFFFF00FF0000000000FF00
0000FFFF000000000000FFFF
FF00000000000000FFFFFF0000000000000000FFFFFFFF00
0000FFFFFFFF000000000000FFFFFFFFFF00000000000000
00000000000000000000FFFF
FF00000000000000FFFFFF000000000000000000FFFFFF00
0000FFFFFF00000000000000FFFFFFFFFF00000000000000
00000000000000000000FFFF
FF00000000000000FFFFFF000000000000000000FFFF0000
0000FFFF00000000000000FFFFFFFFFFFF00000000000000
00FFFF00000000000000FFFF
FF000000000000FFFFFFFF0000000000000000FFFFFF0000
0000FFFF00000000000000FFFFFFFFFFFFFF000000000000
FFFFFF00000000000000FFFF
FF000000000000FFFFFFFF000000000000FFFFFFFFFFFF00
0000FFFF0000000000FFFFFFFFFF0000FFFF000000000000
0000FFFF000000000000FFFF
FF000000000000FFFFFFFF0000000000FFFFFFFFFFFFFF00
0000FFFFFF000000FFFFFFFFFF000000FFFF000000000000
000000FFFF0000000000FFFF
FF000000000000FFFFFFFF00000000FFFFFFFFFFFFFFFF00
0000FFFFFFFFFFFFFFFFFFFFFF000000FFFF000000000000
000000FFFFFF00000000FFFF
FF000000000000FFFFFFFF00000000FFFFFFFF00FFFFFF00
0000FFFFFFFFFFFFFFFFFFFF00000000FFFF000000000000
FF000000000000000000FFFF
FF000000000000FFFFFFFF00000000FFFFFF000000FFFF00
000000FFFFFFFFFFFFFFFF0000000000FFFF0000000000FF
FFFFFFFF000000000000FFFF
FF000000000000FFFFFFFF00000000FFFF00000000FFFF00
00000000FFFFFFFFFFFF000000000000FF000000000000FF
FFFFFFFFFF0000000000FFFF
FF000000000000FFFFFF0000000000FFFF000000FFFFFF00
000000000000FFFFFF0000FFFFFFFF00000000000000FFFF
FFFFFFFFFF0000000000FFFF
FF000000000000FFFFFF0000000000FFFFFFFFFFFFFFFFFF
0000000000000000FFFFFFFFFFFFFF0000000000000000FF
FF00FFFFFF0000000000FFFF
FF000000000000FFFFFF00000000FFFFFFFFFFFFFFFFFFFF
00000000000000FFFFFFFFFFFFFFFF0000000000000000FF
FF00FFFFFF0000000000FFFF
FF00000000FFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFF
FF000000FFFFFFFFFFFFFFFFFFFFFF0000000000000000FF
FFFFFFFFFF0000000000FFFF
FF00000000FFFFFFFF000000FFFFFFFFFFFF000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FF
FFFFFFFF000000000000FFFF
FF00000000FFFFFFFF000000FFFFFFFFFF000000000000FF
FFFFFFFFFFFFFFFFFFFFFF0000000000000000000000FFFF
FFFF0000000000000000FFFF
FF00000000FFFFFFFF000000FFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFF00000000000000000000FFFFFF
FF000000000000000000FFFF
FF00000000FFFFFFFF00000000FF00000000FFFFFFFFFFFF
FFFFFFFF0000FFFFFFFFFFFF0000000000000000FFFFFFFF
00000000000000000000FFFF
FF0000000000FFFFFF0000000000FFFFFFFFFFFFFFFFFFFF
00000000000000FFFFFFFFFFFFFFFF000000000000FFFFFF
00000000000000000000FFFF
FF00000000FFFFFFFF00000000FFFFFFFFFFFFFFFFFF0000
000000000000FFFFFFFFFFFFFFFFFF000000000000FFFF00
00000000000000000000FFFF
FF00000000FFFFFFFF000000FFFFFFFFFFFFFFFFFF000000
0000000000FFFFFFFFFFFFFFFFFFFF000000000000FFFF00
00000000000000000000FFFF
FF0000000000FFFFFF000000FFFFFFFF0000FFFFFFFF0000
000000FFFFFFFF000000FFFFFFFFFF000000000000000000
00000000000000000000FFFF
FF0000000000FFFFFF00000000FF000000FFFFFFFFFFFF00
000000FFFFFF0000000000FFFFFFFF000000000000000000
00000000000000000000FFFF
FF000000000000FFFF00000000000000FFFFFFFFFFFFFFFF
000000FFFFFF0000000000FFFFFFFF000000000000000000
00000000000000000000FFFF
FF000000000000FFFFFF000000000000FFFFFFFFFFFFFFFF
000000FFFF0000000000FFFFFFFF00000000000000000000
00000000000000000000FFFF
FF000000000000FFFFFF0000000000FFFFFFFF0000FFFFFF
000000FFFF000000FFFFFFFFFFFF00000000000000000000
0000FFFFFF0000000000FFFF
FF0000000000000000000000000000FFFFFF00000000FFFF
000000FFFF00FFFFFFFFFFFFFFFFFF0000000000000000FF
FFFF00FFFFFF00000000FFFF
FF000000000000000000FFFF000000FFFFFF00000000FFFF
000000FFFFFFFFFFFFFFFFFFFFFFFF00000000000000FFFF
FFFF0000FFFF00000000FFFF
FF000000FFFFFFFFFFFFFFFF000000FFFFFFFF000000FFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFF
FFFFFF00FFFF00000000FFFF
FF000000FFFFFFFFFFFFFFFF000000FFFFFFFF0000FFFFFF
000000FFFFFFFFFFFF0000FFFFFFFFFF000000FFFFFFFFFF
FFFFFFFFFFFF00000000FFFF
FF000000FFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFF
0000FFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF0000FFFFFF
FF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000FFFFFFFFFF0000000000FFFFFF
FFFFFFFFFFFF000000FFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{281, 133.75},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004I0000QA000`40O003h00Oogoo6Woo003oOolJ
Ool00?mooaYoo`001gooO`0037ooO`0027oo0007Ool00`00Oomoo`1kOol00`00Oomoo`0:Ool00`00
Oomoo`1kOol00`00Oomoo`06Ool000Moo`03001oogoo07]oo`03001oogoo00Yoo`03001oogoo07]o
o`03001oogoo00Ioo`001goo00@007oo:DXYBP@HaP8Q208U:@8YBPH]J`8aS08mk`96<@9>L`96<@=2
408mk`96<@9:DP96<@@mk`9:DP9BU09>L`96<@@mk`A2408mk`8icP8e[@8]J`8YBP8]J`8e[@8mk`8i
cP8]J`8Q208Li`8U:@8]J`DaS0@e[@HicP8mk`PicP@e[@8mk`92408mk`9oo`03001oogoo00Yoo`03
001oo`0001D002Moo``0009oob/000Ioo`03001oogoo00Ioo`001goo00@007oo:DXYBP@HaP8Q208U
:@8YBPH]J`8aS08mk`96<@9>L`96<@=2408mk`96<@9:DP96<@@mk`9:DP9BU09>L`96<@@mk`A2408m
k`8icP8e[@8]J`8YBP8]J`8e[@8mk`8icP8]J`8Q208Li`8U:@8]J`DaS0@e[@HicP8mk`PicP@e[@8m
k`92408mk`9oo`03001oogoo00Yoo`03001oo`0001D002Moo``0009oob/000Ioo`03001oogoo00Io
o`001goo00@007oo9BTU:@8Li`8Q208YBP8]J`HaS08]J`8aS08e[@8icP@mk`<e[@8]J`8U:@8Q20@L
i`8Q208U:@H]J`8U:@8Q208HaP@DY@XHaPXLi`8HaP8Li`8U:@8YBP<]J`@aS08e[@XicP`e[@8aS09o
o`03001oogoo00Yoo`03001oo`0001L000Aooeh0009oo`03001oogoo00Ioo`001goo00@007oo9BTU
:@8Li`8Q208YBP8]J`HaS08]J`8aS08e[@8icP@mk`<e[@8]J`8U:@8Q20@Li`8Q208U:@H]J`8U:@8Q
208HaP@DY@XHaPXLi`8HaP8Li`8U:@8YBP<]J`@aS08e[@XicP`e[@8aS09oo`03001oogoo00Yoo`03
001oo`0001L000Aooeh0009oo`03001oogoo00Ioo`001goo00@007oo<H`aS08e[@8icPXmk`8icP8e
[@P]J`<YBP8Q208HaPHDY@8HaP8Li`PQ208Li`8DY@@@Q08DY@@HaP8Li`@HaP8Li`8YBP@mk`8aS0@U
:@8]J`DaS08e[A@icPHe[@9oo`03001oogoo00Yoo`03001oo`0000D000Iood<0009oobT0009oo`03
001oogoo00Ioo`001goo00@007oo<H`aS08e[@8icPXmk`8icP8e[@P]J`<YBP8Q208HaPHDY@8HaP8L
i`PQ208Li`8DY@@@Q08DY@@HaP8Li`@HaP8Li`8YBP@mk`8aS0@U:@8]J`DaS08e[A@icPHe[@9oo`03
001oogoo00Yoo`03001oo`0000D000Iood<0009oobT0009oo`03001oogoo00Ioo`001goo00@007oo
?Nlmk`9240I6<@A24096<@92408icP8aS0T]J`HYBP@]J`8aS0@e[@8]J`8YBP@]Ja0YBP8U:@8]J`96
<@9S609[FP9>L`8aS08YBP8]J`<aS08e[@8icPPmk`8icPPmk`HicP8mk`9oo`03001oogoo00Yoo`03
001oogoo015oocT000Qoo`l000Aoo`H000Aoo`X0009oo`03001oogoo00Ioo`001goo00@007oo?Nlm
k`9240I6<@A24096<@92408icP8aS0T]J`HYBP@]J`8aS0@e[@8]J`8YBP@]Ja0YBP8U:@8]J`96<@9S
609[FP9>L`8aS08YBP8]J`<aS08e[@8icPPmk`8icPPmk`HicP8mk`9oo`03001oogoo00Yoo`03001o
ogoo015oocT000Qoo`l000Aoo`H000Aoo`X0009oo`03001oogoo00Ioo`001goo00@007oo@Q1240I6
<@92408mk`924096<@9>L`96<@8icP8e[@@icP<mk`A24096<@Q:DP96<@8icP8e[@8aS0He[@@aS0P]
J`8YBP8aS09>L`9cW09kgP9Nm`8icP8YBP8]J`<e[@@icPHmk`HicP@mk`PicP8mk`9oo`03001oogoo
00Yoo`03001oogoo01=oo`P001=ooa`000Qoo`d000Ioo`H000Aoo`P000Aoo`03001oogoo00Ioo`00
1goo00@007oo@Q1240I6<@92408mk`924096<@9>L`96<@8icP8e[@@icP<mk`A24096<@Q:DP96<@8i
cP8e[@8aS0He[@@aS0P]J`8YBP8aS09>L`9cW09kgP9Nm`8icP8YBP8]J`<e[@@icPHmk`HicP@mk`Pi
cP8mk`9oo`03001oogoo00Yoo`03001oogoo01=oo`P001=ooa`000Qoo`d000Ioo`H000Aoo`P000Ao
o`03001oogoo00Ioo`001goo00@007oo?Nlmk`I2408mk`8icP8mk`9:DP9BU09>L`9240@mk`U240A6
<@I2408mk`8icP8aS0H]J`HYBP8U:@PQ208U:@92409W>@9g_@9JeP8e[@8U:@8]J`<aS08e[@8icP@m
k`@icP8e[@HicPPe[@8icP9oo`03001oogoo00Yoo`03001oogoo00Moo`@000Yoo`8001Mooa`000Qo
obL0009oo`03001oogoo00Ioo`001goo00@007oo?Nlmk`I2408mk`8icP8mk`9:DP9BU09>L`9240@m
k`U240A6<@I2408mk`8icP8aS0H]J`HYBP8U:@PQ208U:@92409W>@9g_@9JeP8e[@8U:@8]J`<aS08e
[@8icP@mk`@icP8e[@HicPPe[@8icP9oo`03001oogoo00Yoo`03001oogoo00Moo`@000Yoo`8001Mo
oa`000QoobL0009oo`03001oogoo00Ioo`001goo00@007oo>LhicPHmk`8icP8e[@8icP9:DP9BU09>
L`8mk`He[@DaS0@]J`8aS0@]J`@aS08]J`8YBP8U:@8Q208Li`@Q20@U:@@Q208HaP@DY@8]J`9F]@9[
FP9F]@8aS08U:@8YBP<aS0@e[@8icP@e[@HaS08e[@@aS0@]J`8aS08e[@9oo`03001oogoo00Yoo`03
001oo`0000<000Aoo`H000QoocL000IoobL0009oo`03001oogoo00Ioo`001goo00@007oo>LhicPHm
k`8icP8e[@8icP9:DP9BU09>L`8mk`He[@DaS0@]J`8aS0@]J`@aS08]J`8YBP8U:@8Q208Li`@Q20@U
:@@Q208HaP@DY@8]J`9F]@9[FP9F]@8aS08U:@8YBP<aS0@e[@8icP@e[@HaS08e[@@aS0@]J`8aS08e
[@9oo`03001oogoo00Yoo`03001oo`0000<000Aoo`H000QoocL000IoobL0009oo`03001oogoo00Io
o`001goo00@007oo=Jde[@HicPHe[@96<@9BU09:DP8e[@8YBPLU:@@Q208U:@8]J`8aS08]J`8YBP8U
:@HQ208Li`8Q208YBP8aS08e[@@icP8aS08U:@8DY@8<H`8Q2096<@9Nm`9>L`8]J`8Li`8Q20<YBP8]
J`HaS0`]J`PYBP8]J`9oo`03001oogoo00Yoo`03001oo`0000d000IoocT000IoobL0009oo`03001o
ogoo00Ioo`001goo00@007oo=Jde[@HicPHe[@96<@9BU09:DP8e[@8YBPLU:@@Q208U:@8]J`8aS08]
J`8YBP8U:@HQ208Li`8Q208YBP8aS08e[@@icP8aS08U:@8DY@8<H`8Q2096<@9Nm`9>L`8]J`8Li`8Q
20<YBP8]J`HaS0`]J`PYBP8]J`9oo`03001oogoo00Yoo`03001oo`0000d000IoocT000IoobL0009o
o`03001oogoo00Ioo`001goo00@007oo;F/]J`8aS0He[@8aS08e[@92409>L`9:DP8e[@@YBPD]J`8Y
BP8]J`8e[@924096<@92408aS08Q20@HaP8Q208]J`8icP92409>L`9BU0AF]@9BU092408U:@8DY@8H
aP8mk`9F]@9>L`8]J`8HaP8Li`<U:@8YBPh]J``aS08]J`9oo`03001oogoo00Yoo`03001oo`0000d0
00Iooa4000Ioo`h000ioo`P000AoobL0009oo`03001oogoo00Ioo`001goo00@007oo;F/]J`8aS0He
[@8aS08e[@92409>L`9:DP8e[@@YBPD]J`8YBP8]J`8e[@924096<@92408aS08Q20@HaP8Q208]J`8i
cP92409>L`9BU0AF]@9BU092408U:@8DY@8HaP8mk`9F]@9>L`8]J`8HaP8Li`<U:@8YBPh]J``aS08]
J`9oo`03001oogoo00Yoo`03001oo`0000d000Iooa4000Ioo`h000ioo`P000AoobL0009oo`03001o
ogoo00Ioo`001goo00<007oo;F/01Be[136<0Re[0S6<0Sg_0TYB0THa0SW>0SF]0T8@1Dic0THa0T8@
0TYB0U:D0UJe0THa0Re[0QS60QBU0R480S6<0THa0U:D0U[F15kg1V<H0U[F0T8@0RDY0QcW0SF]0UJe
0U:D0SW>0RDY0RU:0c6<0SF]1SW>13g_0T8@14Ha14YB14ic0THa0SF]0Woo00<007ooOol02Woo00<0
07oo00003`0017oo10004goo2P0057oo1P0017oo4`004Woo0P000Woo00<007ooOol01Woo0007Ool0
0`00Ool]J`05;F/4<H`2;F/2<H`2?Nl2BU82AS42>Lh2=Jd2@Q05CW<2AS42@Q02BU82DY@2E[D2AS42
;F/26<H25:D28@P2<H`2AS42DY@2F]H4G_L6HaP2F]H2@Q029BT27>L2=Jd2E[D2DY@2>Lh29BT2:DX3
<H`2=Jd6>Lh4?Nl2@Q04AS44BU84CW<2AS42=Jd2Ool00`00Oomoo`0:Ool00`00Ool0000?0004Ool4
000COol:000DOol60004OolC000BOol20002Ool00`00Oomoo`06Ool000Moo`04001ooc6<<H`2:DX4
;F/2<H`2;F/2<H`2?Nl2BU82AS42>Lh2?Nl2DY@5HaP2F]H2DY@2CW<4DY@2?Nl29BT25:D27>L2=Jd2
BU82F]H4HaP2G_L4F]H2G_L4HaP2DY@2=Jd28@P2=Jd2E[D2HaP2DY@4AS43CW<4DY@8E[D2F]H6G_L6
HaP2F]H2AS42Ool00`00Oomoo`0:Ool00`00Ool0000=0006Ool2000EOol8000FOol6000]Ool00`00
Oomoo`06Ool000Moo`04001ooc6<<H`2:DX4;F/2<H`2;F/2<H`2?Nl2BU82AS42>Lh2?Nl2DY@5HaP2
F]H2DY@2CW<4DY@2?Nl29BT25:D27>L2=Jd2BU82F]H4HaP2G_L4F]H2G_L4HaP2DY@2=Jd28@P2=Jd2
E[D2HaP2DY@4AS43CW<4DY@8E[D2F]H6G_L6HaP2F]H2AS42Ool00`00Oomoo`0:Ool00`00Ool0000=
0006Ool2000EOol8000FOol6000]Ool00`00Oomoo`06Ool000Moo`04001oocg_?Nl6>Lh4?Nl2@Q02
BU82CW<2AS42=Jd2>Lh2DY@5HaP2F]H2DY@4BU82AS42=Jd28@P27>L2<H`2CW<2G_L4HaP2F]H2E[D6
DY@2F]H2G_L2F]H2@Q02:DX2<H`2E[D2JeX2HaP2E[D2F]H;G_L:F]H6E[D2F]H2E[D2CW<2Ool00`00
Oomoo`0:Ool01000Oomoogoo1P0037oo10004Goo20006Woo1000;Goo00<007ooOol01Woo0007Ool0
1000Oolmkcg_1SW>13g_0T8@0TYB0Tic0THa0SF]0SW>0U:D1F<H0U[F0U:D14YB0THa0SF]0R480QcW
0S6<0Tic0Ukg16<H0U[F0UJe1U:D0U[F0Ukg0U[F0T8@0RU:0S6<0UJe0V]J0V<H0UJe0U[F2ekg2U[F
1UJe0U[F0UJe0Tic0Woo00<007ooOol02Woo00@007ooOomoo`H000aoo`@0015oo`P001Yoo`@002eo
o`03001oogoo00Ioo`001goo00@007ooDYABU0I>L`IBU0AF]@9:DP8e[@8aS092409JeP=Nm`9JeP9>
L`92408mk`8e[@8YBP8Q208]J`9:DP9Nm`AS609JeP9F]@QBU09F]@9Nm`9JeP9:DP8]J`8aS09>L`9J
eP9BU0924096<@]:DP96<@I2408mk`8icP@e[@8icP96<@9BU09oo`03001oogoo00Yoo`03001oogoo
01=oo`@000eoo`X001aoo`@001moo`P000Ioo`03001oogoo00Ioo`001goo00@007ooDYABU0I>L`IB
U0AF]@9:DP8e[@8aS092409JeP=Nm`9JeP9>L`92408mk`8e[@8YBP8Q208]J`9:DP9Nm`AS609JeP9F
]@QBU09F]@9Nm`9JeP9:DP8]J`8aS09>L`9JeP9BU0924096<@]:DP96<@I2408mk`8icP@e[@8icP96
<@9BU09oo`03001oogoo00Yoo`03001oogoo01=oo`@000eoo`X001aoo`@001moo`P000Ioo`03001o
ogoo00Ioo`001goo00<007ooF]H00e[F15Je15:D0Tic0U:D0UJe0TYB0S6<0RU:0SW>0UJe0fLi0V<H
0Tic0SW>0RU:12480Re[0THa0U[F0VLi0V<H0Ukg0U[F0UJe25:D0UJe0Ukg0V<H0U:D0SF]0S6<0T8@
0THa0SF]12DY0be[2S6<22e[0RU:0RDY0R480RU:0Sg_0U:D0Woo00<007ooOol02Woo00<007ooOol0
4goo1P002Goo2P007Woo100017oo8`001Woo00<007ooOol01Woo0007Ool00`00OomJeP03F]H4E[D4
DY@2CW<2DY@2E[D2BU82<H`2:DX2>Lh2E[D3IcT2HaP2CW<2>Lh2:DX48@P2;F/2AS42F]H2IcT2HaP2
G_L2F]H2E[D8DY@2E[D2G_L2HaP2DY@2=Jd2<H`2@Q02AS42=Jd49BT3;F/:<H`8;F/2:DX29BT28@P2
:DX2?Nl2DY@2Ool00`00Oomoo`0:Ool00`00Oomoo`0COol60009Ool:000NOol40004OolS0006Ool0
0`00Oomoo`06Ool000Moo`04001oodicCW<2BU82AS44@Q04?Nl2@Q02CW<2BU82=Jd29BT2=Jd2DY@3
IcT2G_L2AS42:DX25:D248@28@P2?Nl2F]H4IcT2HaP2F]H2DY@2BU82AS44@Q02AS42CW<2G_L2JeX2
G_L2@Q02<H`2>Lh2?Nl2;F/47>L39BT2:DX:;F/4<H`4;F/2:DX29BT2;F/2?Nl2CW<2Ool00`00Oomo
o`0:Ool00`00Oomoo`0COol60009Ool8000ROol40002OolS0006Ool00`00Oomoo`06Ool000Moo`04
001oodicCW<2BU82AS44@Q04?Nl2@Q02CW<2BU82=Jd29BT2=Jd2DY@3IcT2G_L2AS42:DX25:D248@2
8@P2?Nl2F]H4IcT2HaP2F]H2DY@2BU82AS44@Q02AS42CW<2G_L2JeX2G_L2@Q02<H`2>Lh2?Nl2;F/4
7>L39BT2:DX:;F/4<H`4;F/2:DX29BT2;F/2?Nl2CW<2Ool00`00Oomoo`0:Ool00`00Oomoo`0COol6
0009Ool8000ROol40002OolS0006Ool00`00Oomoo`06Ool000Moo`04001oodicCW<2BU82AS44@Q04
?Nl2@Q02CW<2BU82=Jd29BT2=Jd2DY@3IcT2G_L2AS42:DX25:D248@28@P2?Nl2F]H4IcT2HaP2F]H2
DY@2BU82AS44@Q02AS42CW<2G_L2JeX2G_L2@Q02<H`2>Lh2?Nl2;F/47>L39BT2:DX:;F/4<H`4;F/2
:DX29BT2;F/2?Nl2CW<2Ool00`00Oomoo`0:Ool00`00Oomoo`0COol60009Ool8000ROol40002OolS
0006Ool00`00Oomoo`06Ool000Moo`04001oocg_?Nl2<H`4;F/2<H`4;F/2>Lh4BU82>Lh29BT2;F/2
@Q03DY@2CW<2=Jd27>L236<248@2;F/2CW<2IcT2JeX2IcT2F]H2CW<2?Nl2<H`29BT48@P2:DX2>Lh2
E[D2Kg/2IcT2BU82=Jd2>Lh2?Nl2;F/28@P29BT3;F/2<H`6=Jd8>Lh4=Jd4;F/2=Jd2@Q02BU82Ool0
0`00Oomoo`0:Ool01000Oomoogoo3P0017oo1P001goo2P003Woo300027oo10000Woo8`001Woo00<0
07ooOol01Woo0007Ool01000Oolmkcg_0S6<12e[0S6<12e[0SW>14YB0SW>0RDY0Re[0T8@0e:D0Tic
0SF]0QcW0PaS0Q240Re[0Tic0VLi0V]J0VLi0U[F0Tic0Sg_0S6<0RDY12480RU:0SW>0UJe0Vmk0VLi
0TYB0SF]0SW>0Sg_0Re[0R480RDY0be[0S6<1SF]23W>13F]12e[0SF]0T8@0TYB0Woo00<007ooOol0
2Woo00@007ooOomoo`h000Aoo`H000Moo`X000ioo``000Qoo`@0009oob<000Ioo`03001oogoo00Io
o`001goo00@007oo>LhicP8]J`@YBPH]J`8e[@9:DP9>L`8mk`8YBP8U:@8e[@<mk`8icP8]J`8HaP8@
Q08Q2092409S609_N`9W>@9F]@96<@8e[@8U:@8HaP8@Q08<H`88@P8<H`8U:@9:DP9[FP9_N`9BU0Hm
k`8e[@@YBP<aS0@icP`mk`@icP@aS08icPA:DP9oo`03001oogoo00Yoo`03001oo`0000l000Aoo`P0
00=oo`X000aooa0000Qoo`@0009oo`l000Ioo`h000Ioo`03001oogoo00Ioo`001goo00@007oo>Lhi
cP8]J`@YBPH]J`8e[@9:DP9>L`8mk`8YBP8U:@8e[@<mk`8icP8]J`8HaP8@Q08Q2092409S609_N`9W
>@9F]@96<@8e[@8U:@8HaP8@Q08<H`88@P8<H`8U:@9:DP9[FP9_N`9BU0Hmk`8e[@@YBP<aS0@icP`m
k`@icP@aS08icPA:DP9oo`03001oogoo00Yoo`03001oo`0000l000Aoo`P000=oo`X000aooa0000Qo
o`@0009oo`l000Ioo`h000Ioo`03001oogoo00Ioo`001goo00@007oo?Nlmk`8aS08]J`PaS08icP9:
DP9BU092408]J`8YBP8]J`<e[@8aS08YBP@Li`8aS09F]@A_N`9JeP92408]J`8Q20@HaP8DY@8@Q088
@P848@8DY@8icP9S609cW09JePI2408e[@8YBP8]J`<e[@8icPhmk`@icP@aS08mk`A>L`9oo`03001o
ogoo00Yoo`04001oogooOol>0006OolC000:OolD000<Ool=0008Ool>0006Ool00`00Oomoo`06Ool0
00Moo`04001oocg_?Nl2<H`2;F/8<H`2>Lh2BU82DY@2@Q02;F/2:DX2;F/3=Jd2<H`2:DX47>L2<H`2
E[D4Kg/2F]H2@Q02;F/28@P46<H25:D248@2248212425:D2>Lh2HaP2Li`2F]H6@Q02=Jd2:DX2;F/3
=Jd2>Lh>?Nl4>Lh4<H`2?Nl4CW<2Ool00`00Oomoo`0:Ool01000Oomoogoo3P001Woo4`002Woo5000
37oo3@0027oo3P001Woo00<007ooOol01Woo0007Ool01000Oom2448@0SF]0S6<0SF]0SW>13F]0Sg_
0Tic0UJe0THa0SF]0Re[0S6<0cF]0S6<0RU:0R480RU:0THa0VLi0W>L0V<H0THa0Re[0QcW0QS611cW
0R480QcW0Q240PQ20PaS0Re[0U[F0Vmk0Ukg0THa148@0SF]12e[0cF]0SW>2Sg_1SW>0SF]136<0Sg_
0Tic0U:D0Woo00<007ooOol02Woo00@007ooOomoo`h000Iooa4000YooaH000aoo`d000Iooa0000Io
o`03001oogoo00Ioo`001goo00@007oo@Q12408e[@8aS08e[@8icP@e[@8mk`9>L`9F]@96<@8e[@8]
J`8aS0<e[@8aS08YBP8Q208YBP96<@9W>@9cW09S6096<@8]J`8Li`8HaP@Li`8Q208Li`8@Q088@P8<
H`8]J`9JeP9_N`9Nm`96<@A2408e[@@]J`<e[@8icPXmk`HicP8e[@@aS08mk`9>L`9BU09oo`03001o
ogoo00Yoo`04001oogooOol>0006OolA000:OolF000<Ool=0006Ool@0006Ool00`00Oomoo`06Ool0
00Moo`04001ood8@@Q04=Jd6>Lh2=Jd2?Nl2CW<2E[D2BU82=Jd2<H`2=Jd3>Lh2=Jd2:DX29BT2<H`2
E[D2Li`2Kg/2DY@2<H`27>L26<H27>L28@P29BT28@P27>L25:D236<25:D2<H`2E[D2IcT2E[D6@Q02
=Jd4;F/3=Jd2>Lh8?Nl8>Lh2=Jd4<H`2>Lh2CW<2DY@2Ool00`00Oomoo`0:Ool01000Oomoogoo3000
27oo4@0027oo600037oo8`001Woo00<007ooOol01Woo0007Ool01000Oom2448@13F]1SW>0SF]0Sg_
0Tic0UJe0TYB0SF]0S6<0SF]0cW>0SF]0RU:0RDY0S6<0UJe0W>L0Vmk0U:D0S6<0QcW0QS60QcW0R48
0RDY0R480QcW0QBU0PaS0QBU0S6<0UJe0VLi0UJe1T8@0SF]12e[0cF]0SW>23g_23W>0SF]136<0SW>
0Tic0U:D0Woo00<007ooOol02Woo00@007ooOomoo``000Qooa4000QooaP000aoob<000Ioo`03001o
ogoo00Ioo`001goo00@007oo@Q12408e[@8aS08e[@@icP8e[@8mk`9>L`9F]@96<@8e[@8aS0DicP8e
[@8YBP8U:@8icP9Nm`9g_@9W>@8mk`8Q208HaP8Li`@U:@8Q20HLi`8Q208YBP8mk`9JeP9Nm`9:DP8i
cP8mk`92408e[@@]J`<e[@8icP8mk``icP@e[@@aS08icP9>L`9BU09oo`03001oogoo00Yoo`04001o
ogooOol<0008OolA0008OolF0008Ool40002OolS0006Ool00`00Oomoo`06Ool000Moo`04001ood8@
@Q02=Jd2<H`2=Jd4>Lh2=Jd2?Nl2CW<2E[D2AS42=Jd2<H`5>Lh2=Jd2:DX29BT2>Lh2G_L2Mkd2IcT2
?Nl28@P26<H27>L49BT28@P67>L28@P2:DX2?Nl2F]H2G_L2BU82>Lh2?Nl2@Q02=Jd4;F/3=Jd2>Lh2
?Nl<>Lh4=Jd4<H`2>Lh2CW<2DY@2Ool00`00Oomoo`0:Ool01000Oomoogoo300027oo4@0027oo5P00
27oo10000Woo8`001Woo00<007ooOol01Woo0007Ool01000Oom2448@136<23F]0SW>0TYB0U:D0THa
0SF]0S6<0SF]1CW>0RU:0RDY0SW>0V<H0WNm0Ukg0S6<11BU0R4812DY12480RDY0S6<0Sg_0TYB0UJe
0V<H0UJe0SW>0Re[0SW>0T8@0SW>12e[0cF]4SW>0SF]136<0SW>0Tic0U:D0Woo00<007ooOol02Woo
00@007ooOomoo`h000Iooa4000Iooa@000Yoo`H0009oob<000Ioo`03001oogoo00Ioo`001goo00@0
07oo@Q1240@aS0Pe[@8icP9:DP9BU096<@8e[@8aS08e[@DicP8YBP8U:@8icP9S609g_@9Nm`8aS0@D
Y@8Q20@U:@@Q208U:@8aS08mk`9:DP9F]@9S609F]@8icP8]J`8icP92408icP@]J`<e[A8icP8e[@@a
S08icP9>L`9BU09oo`03001oogoo00Yoo`04001oogooOol>0006OolA0006OolD000:Ool60002OolS
0006Ool00`00Oomoo`06Ool000Moo`04001ood8@@Q02<H`2;F/6=Jd2<H`2>Lh2BU82DY@2AS42=Jd2
<H`2=Jd3>Lh2=Jd2:DX29BT2?Nl2IcT2Nmh2G_L2;F/248@25:D27>L48@P29BT2<H`2@Q02DY@2F]H2
HaP2JeX2IcT2DY@2<H`29BT2=Jd2@Q02>Lh4;F/3=Jd:>Lh4?Nl4>Lh2=Jd4<H`2>Lh2CW<2DY@2Ool0
0`00Oomoo`0:Ool01000Oomoogoo3P001Woo3`0027oo40003Woo1P000Woo8`001Woo00<007ooOol0
1Woo0007Ool01000Oom2448@0S6<0Re[1SF]0S6<0SW>0TYB0U:D0THa0SF]0S6<0SF]0cW>0SF]0RU:
0RDY0Sg_0VLi0W_N0Ukg0Re[0Q240QBU0QcW12480RDY0S6<0T8@0U:D0U[F0V<H0V]J0VLi0U:D0S6<
0RDY0SF]0T8@0SW>12e[0cF]2SW>13g_13W>0SF]136<0SW>0Tic0U:D0Woo00<007ooOol02Woo00@0
07ooOomoo`h000Ioo`l000Qooa0000ioo`H0009oob<000Ioo`03001oogoo00Ioo`001goo00@007oo
AS56<@8aS08]J`Pe[@8icP9:DP9BU096<@8e[@8aS08e[@<icP8e[@8U:@8Q208mk`9[FP9oo`9Nm`8]
J`@@Q08HaP8Li`8U:@8e[@9:DP9JeP9W>@9[FPA_N`9[FP9BU08aS08U:@8e[@92408icP8]J`8aS0<e
[@8icPhmk`@icP@aS08icP9>L`9F]@9oo`03001oogoo00Yoo`04001oogooOol>0006Ool?0008Ool>
000@Ool60002OolA0006Ool<0006Ool00`00Oomoo`06Ool000Moo`04001oodHaAS42<H`2;F/8=Jd2
>Lh2BU82DY@2AS42=Jd2<H`2=Jd3>Lh2=Jd29BT28@P2?Nl2JeX2Ool2G_L2;F/448@26<H27>L29BT2
=Jd2BU82F]H2IcT2JeX4Kg/2JeX2DY@2<H`29BT2=Jd2@Q02>Lh2;F/2<H`3=Jd2>Lh>?Nl4>Lh4<H`2
>Lh2CW<2E[D2Ool00`00Oomoo`0:Ool01000Oomoogoo3P001Woo3`0027oo3P0047oo1P000Woo4@00
1Woo30001Woo00<007ooOol01Woo0007Ool01000Oom6<DHa0S6<0Re[0SF]0SW>13F]0Sg_0Tic0UJe
0TYB0SW>0SF]0SW>0cg_0SF]0RDY0R480Sg_0V]J0Woo0V<H0S6<0Q240PaS0QBU0QcW0Re[0TYB0Ukg
36]J0U[F0Sg_0RU:0SF]0T8@0SW>136<0cW>4Sg_0SW>136<0SW>0U:D0UJe0Woo00<007ooOol02Woo
00@007ooOomoo`h000Iooa4000Ioo``001Aoo`@0009oo`/000ioo`X000Ioo`03001oogoo00Ioo`00
1goo00@007ooAS56<@8aS08]J`8e[@8icP@e[@8mk`9>L`9F]@9:DP8icP8e[@8icP<mk`8e[@8U:@8Q
208mk`9[FP9oo`9S608aS08@Q08<H`8DY@8Li`8]J`9:DP9Nm`a[FP9JeP8mk`8YBP8e[@92408icP@a
S0<icQ8mk`8icP@aS08icP9BU09F]@9oo`03001oogoo00Yoo`04001oogooOol>0006OolA0006Ool<
000DOol40002Ool;000>Ool:0006Ool00`00Oomoo`06Ool000Moo`04001oodYBBU82=Jd2<H`2=Jd4
>Lh2=Jd2?Nl2CW<2E[D2BU82>Lh2=Jd2>Lh3?Nl2=Jd2:DX28@P2>Lh2IcT2Ool2IcT2=Jd248@22482
48@29BT2@Q02F]H6JeX2HaP2G_L2HaP2IcT2HaP2BU84=Jd2@Q02>Lh4<H`3>LhB?Nl2>Lh4<H`2?Nl2
DY@2F]H2Ool00`00Oomoo`0:Ool01000Oomoogoo300027oo1P000goo20001Woo2P005Woo10000Woo
2@0047oo2P001Woo00<007ooOol01Woo0007Ool01000Oom:DTYB0SF]0S6<0SF]13W>0SF]0Sg_0Tic
0UJe0TYB0SW>0SF]0SW>0cg_0SF]0RU:0R480SW>0VLi0Woo0VLi0SF]0Q240PQ20Q240RDY0T8@0U[F
1V]J0V<H0Ukg0V<H0VLi0V<H0TYB13F]0T8@0SW>136<0cW>4Sg_0SW>136<0Sg_0U:D0U[F0Woo00<0
07ooOol02Woo00@007ooOomoo``000Qoo`H000=oo`P000Ioo`X001Ioo`@0009oo`T0011oo`X000Io
o`03001oogoo00Ioo`001goo00@007ooBU9:DP8e[@8aS08e[@HicP8mk`9>L`9F]@9:DP8icP8aS0Di
cP8e[@8U:@8Li`8aS09S609oo`9cW096<@8Li`88@P8DY@8aS09BU0A[FP9S609JeP9>L`A6<@9BU09N
m`9BU08mk`8icP92408icP@aS0<icQ8mk`8icP@aS08mk`9BU09JeP9oo`03001oogoo00Yoo`04001o
ogooOol<0008OolA0008Ool8000HOol20002Ool9000@Ool:0006Ool00`00Oomoo`06Ool000Moo`04
001oodYBBU82=Jd2<H`2=Jd6>Lh2?Nl2CW<2E[D2BU82>Lh2<H`5>Lh2=Jd29BT27>L2<H`2HaP2Ool2
Li`2AS427>L224825:D2<H`2DY@4JeX2HaP2F]H2CW<4AS42DY@2G_L2DY@2?Nl2>Lh2@Q02>Lh4<H`3
>LhB?Nl2>Lh4<H`2?Nl2DY@2F]H2Ool00`00Oomoo`0:Ool01000Oomoogoo300027oo4@0027oo2000
67oo0P000Woo2@0047oo2P001Woo00<007ooOol01Woo0007Ool01000Oom:DTYB0SF]0Re[0SF]1SW>
0Sg_0Tic0U:D0TYB0SW>0SF]1CW>0S6<0RDY0QS60Re[0UJe17_N0Ukg0S6<0QS60QcW0T8@0V<H0V]J
0Ukg0Tic0Sg_0Re[12480SF]15:D0T8@0Sg_0T8@0SW>12e[0cF]43g_13W>0S6<0Re[0SW>0U:D0U[F
0Woo00<007ooOol02Woo00@007ooOomoo``000Qooa4000Qoo`H000aoo`P000Ioo`80009oo`/0009o
o`H000Aoo``000Ioo`03001oogoo00Ioo`001goo00@007ooBU9:DP8e[@8]J`8e[@HicP8mk`9>L`9B
U09:DP8icP8e[@DicP8aS08U:@8HaP8]J`9F]@AkgP9Nm`8aS08HaP8Li`92409S609[FP9Nm`9>L`8m
k`8]J`@Q208e[@ABU092408mk`92408icP@]J`<e[A0mk`@icP8aS08]J`8icP9BU09JeP9oo`03001o
ogoo00Yoo`04001oogooOol<0008OolA0008Ool6000<Ool80006Ool20002Ool;0002Ool60004Ool<
0006Ool00`00Oomoo`06Ool000Moo`04001oodHaAS42<H`2;F/2=Jd4>Lh2=Jd2?Nl2BU82DY@2AS42
>Lh2=Jd5>Lh2<H`28@P25:D28@P2BU82Kg/2Mkd2G_L2>Lh28@P2:DX2CW<2JeX2HaP2AS42;F/28@P2
5:D2248236<29BT2BU82DY@2AS42?Nl2@Q02>Lh4;F/3=Jd2>Lh2?Nl4>Lh6?Nl4>Lh2=Jd2<H`2;F/2
>Lh2CW<2E[D2Ool00`00Oomoo`0:Ool01000Oomoogoo3P001Woo4@0027oo1P0027oo30002Woo8`00
1Woo00<007ooOol01Woo0007Ool01000Oom6<DHa0S6<0Re[0SF]13W>0SF]0Sg_0TYB0U:D0THa0SW>
0SF]1CW>0S6<0R480QBU0R480TYB0Vmk0WNm0Ukg0SW>0R480RU:0Tic0V]J0V<H0THa0Re[0R480QBU
0PQ20PaS0RDY0TYB0U:D0THa0Sg_0T8@0SW>12e[0cF]0SW>0Sg_13W>1Sg_13W>0SF]0S6<0Re[0SW>
0Tic0UJe0Woo00<007ooOol02Woo00@007ooOomoo`h000Iooa4000Qoo`H000Qoo``000Yoob<000Io
o`03001oogoo00Ioo`001goo00@007ooAS56<@8aS08]J`8e[@@icP8e[@8mk`9:DP9BU096<@@e[@Di
cP8aS08Li`8@Q08Li`8mk`9JeP9Nm`9:DP8YBP8HaP8]J`9BU09S609:DP8YBP8DY@8@Q088@P848@8<
H`8YBP9>L`9JeP9:DPA2408icP@]J`<e[@HicPHmk`HicP8e[@8aS08]J`8e[@9>L`9F]@9oo`03001o
ogoo00Yoo`04001oogooOol>0006OolC0006Ool60006Ool>000:OolS0006Ool00`00Oomoo`06Ool0
00Moo`04001oodHaAS42<H`2;F/2=Jd4>Lh2=Jd2?Nl2BU82DY@2AS44=Jd5>Lh2<H`27>L248@27>L2
?Nl2F]H2G_L2BU82:DX26<H2;F/2DY@2HaP2BU82:DX25:D248@22482124236<2:DX2CW<2F]H2BU84
@Q02>Lh4;F/3=Jd6>Lh6?Nl6>Lh2=Jd2<H`2;F/2=Jd2CW<2E[D2Ool00`00Oomoo`0:Ool01000Oomo
ogoo3P001Woo4`001Woo1P001Woo3P002Woo8`001Woo00<007ooOol01Woo0007Ool01000Oom6<DHa
0S6<0Re[0SF]13W>0SF]0Sg_0TYB0U:D0THa0SF]0S6<1CF]0Re[0QcW0QBU0QcW0SW>0Tic0TYB0Re[
0Q240PaS0RU:0U:D0UJe0SF]0Q240PQ21PaS0QcW0Sg_15kg0TYB148@0Sg_136<0cF]13W>2Sg_13W>
0SF]0S6<0Re[0SF]0Tic0U[F0Woo00<007ooOol02Woo00@007ooOomoo`h000Iooa<000Aoo`P000Ao
o`h000aooa4000Aoo`h000Ioo`03001oogoo00Ioo`001goo00@007ooAS56<@8aS08]J`8e[@@icP8e
[@8mk`9:DP9BU096<@8e[@8aS0De[@8]J`8Li`8DY@8Li`8icP9>L`9:DP8]J`8@Q08<H`8YBP9BU09F
]@8e[@8@Q088@PH<H`8Li`8mk`ANm`9:DPA2408mk`@aS0<e[@@icPXmk`@icP8e[@8aS08]J`8e[@9>
L`9JeP9oo`03001oogoo00Yoo`04001oogooOol>0006OolC0004Ool80004Ool>000<OolA0004Ool>
0006Ool00`00Oomoo`06Ool000Moo`04001oodYBBU82<H`2;F/2<H`2>Lh4=Jd2?Nl2BU82DY@2AS42
=Jd7<H`2:DX49BT2=Jd2BU82F]H2CW<2;F/236<212429BT4CW<2:DX22482124236<26<H28@P2>Lh2
E[D2JeX2G_L2AS42?Nl2@Q02?Nl4<H`3=Jd4>Lh:?Nl4>Lh2=Jd2<H`2;F/2=Jd2DY@2F]H2Ool00`00
Oomoo`0:Ool01000Oomoogoo300027oo4@001Woo200017oo3P003Woo3@001Woo3P001Woo00<007oo
Ool01Woo0007Ool01000Oom:DTYB0S6<0Re[0S6<0SW>13F]0Sg_0TYB0U:D0THa0SF]1c6<0RU:12DY
0SF]0TYB0U[F0Tic0Re[0PaS0P@Q0RDY14ic0RU:0PQ20P@Q0PaS0QS60R480SW>0UJe0V]J0Ukg0THa
0Sg_0T8@0Sg_136<0cF]13W>2Sg_13W>0SF]0S6<0Re[0SF]0U:D0U[F0Woo00<007ooOol02Woo00@0
07ooOomoo``000Qooa4000Ioo`P000Aoo`h000ioo`d000Ioo`h000Ioo`03001oogoo00Ioo`001goo
00@007ooBU9:DP8aS08]J`8aS0@icP8e[@8mk`9:DP9BU096<@8e[@8aS0L]J`8e[@92409BU09S609_
N`9W>@96<@8Li`8<H`8U:@A>L`8]J`8@Q08<H`8Li`8]J`8mk`9F]@A[FP9>L`@e[@92408mk`8e[@8a
S0<e[@@icPhmk`8icP8aS08]J`8e[@9BU09JeP9oo`03001oogoo00Yoo`04001oogooOol<0008Ool=
000<Ool60004Ool:000:Ool40004OolA0004Ool<0006Ool00`00Oomoo`06Ool000Moo`04001oodYB
BU82<H`2;F/2<H`4>Lh2=Jd2?Nl2BU82DY@2AS42=Jd2<H`7;F/2=Jd2@Q02DY@2HaP2Kg/2IcT2AS42
7>L236<29BT4CW<2;F/248@236<27>L2;F/2?Nl2E[D4JeX2CW<4=Jd2@Q02?Nl2=Jd2<H`3=Jd4>Lh>
?Nl2>Lh2<H`2;F/2=Jd2DY@2F]H2Ool00`00Oomoo`0:Ool01000Oomoogoo300027oo3@0037oo1P00
17oo2P002Woo100017oo4@0017oo30001Woo00<007ooOol01Woo0007Ool01000Oom6<DHa0S6<0Re[
0SF]1SW>0Sg_0TYB0Tic0THa0SF]1be[0SW>0Tic0Ukg0V]J0Vmk0WNm0W>L0UJe0Re[0QBU0RU:0Tic
0U[F0THa0Re[0RU:0SF]0TYB0U[F0V]J0Vmk0Ukg0SW>0RDY0S6<0T8@0Sg_0SF]0S6<0cF]13W>3Sg_
0SW>0S6<0Re[0SF]0U:D0U[F0Woo00<007ooOol02Woo00@007ooOomoo``000Qoo`/000ioo`H000Io
o`H000Yoo`H000Aooa<000Aoo`X000Ioo`03001oogoo00Ioo`001goo00@007ooAS56<@8aS08]J`8e
[@HicP8mk`9:DP9>L`96<@8e[@L]J`8icP9>L`9Nm`9[FP9_N`9g_@9cW09F]@8]J`8DY@8YBP9>L`9J
eP96<@8]J`8YBP8e[@9:DP9JeP9[FP9_N`9Nm`8icP8U:@8aS092408mk`8e[@8aS0<e[@@icPhmk`8i
cP8aS08]J`8e[@9BU09JeP9oo`03001oogoo00Yoo`04001oogooOol<0008Ool;000>Ool60006Ool6
000:Ool60004OolC0004Ool:0006Ool00`00Oomoo`06Ool000Moo`04001oodHaAS42<H`2;F/2=Jd4
?Nl2>Lh2?Nl2BU82CW<2@Q02<H`4:DX3<H`2BU82IcT2Kg/2IcT2HaP2IcT2JeX2F]H2<H`26<H29BT2
CW<2HaP2G_L2CW<2BU82DY@2G_L2JeX2Kg/2HaP2AS42:DX27>L2;F/4@Q07=Jd4>Lh>?Nl2>Lh2<H`2
;F/2=Jd2DY@2F]H2Ool00`00Oomoo`0:Ool01000Oomoogoo300027oo2@0047oo1P005Woo1P0017oo
4`001Woo20001Woo00<007ooOol01Woo0007Ool01000Oom6<DHa0S6<0Re[0SF]13g_0SW>0Sg_0TYB
0Tic0T8@0S6<12U:0c6<0TYB0VLi0Vmk0VLi0V<H0VLi0V]J0U[F0S6<0QS60RDY0Tic0V<H0Ukg0Tic
0TYB0U:D0Ukg0V]J0Vmk0V<H0THa0RU:0QcW0Re[148@1cF]13W>3Sg_0SW>0S6<0Re[0SF]0U:D0U[F
0Woo00<007ooOol02Woo00@007ooOomoo``000Qoo`T0011oo`H001Ioo`H000Aooa<000Ioo`P000Io
o`03001oogoo00Ioo`001goo00@007ooAS56<@@]J`8e[@@mk`8icP8mk`9:DP9>L`92408aS08YBP8U
:@<e[@9BU09[FP9S609:DP8icP92409F]@9BU08aS08DY@8Li`92409Nm`9W>@9S609Nm`IS609Nm`9>
L`8aS0@Q208aS092408mk`Le[@@icPhmk`8icP8aS08]J`8e[@9BU09Nm`9oo`03001oogoo00Yoo`04
001oogooOol<0008Ool90008Ool20006Ool6000DOol80004Ool=0002OolB0006Ool00`00Oomoo`06
Ool000Moo`04001oodHaAS44;F/2=Jd4?Nl2>Lh2?Nl2BU82CW<2@Q02<H`2:DX29BT3=Jd2DY@2JeX2
HaP2BU82>Lh2@Q02E[D2DY@2<H`25:D27>L2@Q02G_L2IcT2HaP2G_L6HaP2G_L2CW<2<H`48@P2<H`2
@Q02?Nl7=Jd4>Lh>?Nl2>Lh2<H`2;F/2=Jd2DY@2G_L2Ool00`00Oomoo`0:Ool01000Oomoogoo3000
27oo2@0027oo0P001Woo1P0057oo200017oo3@000Woo4P001Woo00<007ooOol01Woo0007Ool01000
Oom6<DHa12e[0SF]1SW>0Sg_0TYB0Tic0Sg_0S6<0RDY0RU:0cW>0UJe0U[F0Sg_0QcW0Q240RDY0T8@
0THa0Re[11240Re[0Tic0Ukg1V<H0U[F0U:D0THa0SF]0RU:0RDY0RU:0SF]0T8@0Sg_13F]1CW>3Sg_
0SW>0SF]0Re[0RU:0SF]0U:D0Ukg0Woo00<007ooOol02Woo00@007ooOomoo``000Qoo`T000Ioo`H0
00Aoo`P0011oo`X000Aoo`/000Yoo``000Ioo`03001oogoo00Ioo`001goo00@007ooAS56<@@]J`8e
[@HicP8mk`9:DP9>L`8mk`8aS08U:@8YBP<icP9F]@9JeP8mk`8Li`8@Q08U:@924096<@8]J`@@Q08]
J`9>L`9Nm`IS609JeP9BU096<@8e[@8YBP8U:@8YBP8e[@92408mk`@e[@DicPhmk`8icP8e[@8]J`8Y
BP8e[@9BU09Nm`9oo`03001oogoo00Yoo`04001oogooOol<0008Ool90006Ool60004Ool8000@Ool:
0004Ool;000:Ool<0006Ool00`00Oomoo`06Ool000Moo`04001oodYBBU84;F/2=Jd6>Lh2?Nl4BU82
?Nl2;F/49BT3>Lh2CW<2AS428@P2124224829BT2AS42BU82;F/248@224825:D2;F/2AS42DY@4E[D2
BU82?Nl2<H`2;F/2<H`4=Jd2>Lh2?Nl2>Lh4=Jd3>LhB?Nl2=Jd2;F/2:DX2=Jd2DY@2G_L2Ool00`00
Oomoo`0:Ool01000Oomoogoo300027oo2@0017oo200017oo2P0037oo30000Woo3@0037oo2P001Woo
00<007ooOol01Woo0007Ool01000Oom:DTYB12e[0SF]1SW>0Sg_14YB0Sg_0Re[12DY0cW>0Tic0THa
0R480P@Q0PQ20RDY0THa0TYB0Re[0Q240PQ20QBU0Re[0THa0U:D15Je0TYB0Sg_0S6<0Re[0S6<13F]
0SW>0Sg_0SW>13F]0cW>4Sg_0SF]0Re[0RU:0SF]0U:D0Ukg0Woo00<007ooOol02Woo00@007ooOomo
o``000Qoo`T000Aoo`P000Aoo`X000aoo``0009oo`d000aoo`X000Ioo`03001oogoo00Ioo`001goo
00@007ooBU9:DP8]J`8YBP8e[@HicP8mk`A:DP8icP8U:@8Li`8Q20<e[@9:DP92408U:@8HaP8U:@92
409JeP9F]@8e[@8@Q0@0008@Q08Q208e[@A2408mk`@e[@8mk`A:DP8mk`@icP8e[@8aS08e[@DicQ0m
k`8e[@8]J`8YBP8e[@9BU09Nm`9oo`03001oogoo00Yoo`04001oogooOol<0006Ool;0004Ool60006
Ool>0006Ool40008Ool?000>Ool:0006Ool00`00Oomoo`06Ool000Moo`04001oodYBBU82;F/2:DX2
=Jd6>Lh2?Nl4BU82>Lh29BT27>L28@P3=Jd2BU82@Q029BT26<H29BT2@Q02F]H2E[D2=Jd248@40002
48@28@P2=Jd4@Q02?Nl4=Jd2?Nl4BU82?Nl4>Lh2=Jd2<H`2=Jd5>Lh@?Nl2=Jd2;F/2:DX2=Jd2DY@2
G_L2Ool00`00Oomoo`0:Ool01000Oomoogoo30001Woo2`0017oo1P001Woo3P001Woo100027oo3`00
3Woo2P001Woo00<007ooOol01Woo0007Ool01000Oom:DTYB0Re[0RU:0SF]1SW>0Sg_14Ha0SF]0RDY
0QcW0RDY0cW>14ic0T8@0Sg_0Tic0V<H0V]J0Ukg0Sg_0QcW0P@Q10000Q240R480S6<0SW>13g_0THa
0UJe0Ukg0UJe0T8@13F]136<0SF]1CW>43g_0SW>0Re[0RU:0SF]0U:D0V<H0Woo00<007ooOol02Woo
00@007ooOomoo``000Ioo`/0019ooa0000iooa4000Aoo`8000Ioo`X000Ioo`03001oogoo00Ioo`00
1goo00@007ooBU9:DP8]J`8YBP8e[@HicP8mk`A6<@8e[@8U:@8Li`8U:@<icPA>L`92408mk`9>L`9S
609[FP9Nm`8mk`8Li`848@@0008@Q08Q208aS08icP@mk`96<@9F]@9Nm`9F]@9240@e[@@aS08e[@Di
cQ0mk`8icP8]J`8YBP8e[@9BU09S609oo`03001oogoo00Yoo`04001oogooOol<0006Ool;000BOol@
000>OolA0004Ool20006Ool:0006Ool00`00Oomoo`06Ool000Moo`04001oodYBBU82;F/2:DX2<H`2
>Lh4?Nl2@Q02AS42?Nl2<H`29BT2:DX2=Jd3BU82G_L2HaP4F]H2G_L2IcT2HaP2E[D2@Q02;F/27>L4
5:D27>L2;F/2>Lh2@Q02AS42BU82E[D2HaP2IcT2F]H2@Q02=Jd6<H`2=Jd5>Lh@?Nl2>Lh2<H`2:DX2
=Jd2DY@2HaP2Ool00`00Oomoo`0:Ool01000Oomoogoo30001Woo20005Goo3P0047oo4@0017oo0P00
1Woo2P001Woo00<007ooOol01Woo0007Ool01000Oom:DTYB0Re[0RU:0S6<0SW>13g_0T8@0THa0Sg_
0S6<0RDY0RU:0SF]0dYB0Ukg0V<H15[F0Ukg0VLi0V<H0UJe0T8@0Re[0QcW11BU0QcW0Re[0SW>0T8@
0THa0TYB0UJe0V<H0VLi0U[F0T8@0SF]1S6<0SF]1CW>43g_0SW>0S6<0RU:0SF]0U:D0V<H0Woo00<0
07ooOol02Woo00@007ooOomoo``000Ioo`P001Eoo`h0011ooa4000Aoo`8000Ioo`X000Ioo`03001o
ogoo00Ioo`001goo00@007ooBU9:DP8]J`8U:@8aS08icP@mk`A2408icP@]J`8mk`9F]@=W>@9[FP9W
>@9Nm`9F]@9>L`9:DP96<@9240Hmk`@icP8mk`96<@9:DPA>L`9BU09F]@9Nm`9S609F]@96<@8icP8a
S08]J`8aS08e[@LicPhmk`8e[@8aS08YBP8e[@9BU09S609oo`03001oogoo00Yoo`04001oogooOol8
0008Ool6000KOol6000FOolA000<Ool:0006Ool00`00Oomoo`06Ool000Moo`04001oodYBBU82;F/2
9BT2<H`2>Lh4?Nl4@Q02>Lh4;F/2?Nl2E[D3IcT2JeX2IcT2G_L2E[D2CW<2BU82AS42@Q06?Nl4>Lh2
?Nl2AS42BU84CW<2DY@2E[D2G_L2HaP2E[D2AS42>Lh2<H`2;F/2<H`2=Jd7>Lh>?Nl2=Jd2<H`2:DX2
=Jd2DY@2HaP2Ool00`00Oomoo`0:Ool01000Oomoogoo200027oo1P006goo1P005Woo4@0037oo2P00
1Woo00<007ooOol01Woo0007Ool01000Oom:DTYB0Re[0RDY0S6<0SW>0Sg_1T8@0SF]0Re[0S6<0Tic
0V]J0g>L0V]J0U[F0THa0SF]0Re[12U:0Re[0SW>0THa0Tic0U:D1UJe15:D2Tic0THa0Sg_0SW>0SF]
136<0SF]1CW>3Sg_0SW>0SF]0S6<0RU:0SF]0U:D0V<H0Woo00<007ooOol02Woo00@007ooOomoo`P0
00Qoo`H000eoo``001iooa4000Yoo``000Ioo`03001oogoo00Ioo`001goo00@007ooBU9:DP8]J`8U
:@8aS08icP8mk`I2408e[@8]J`8aS09>L`9[FP=cW09[FP9JeP96<@8e[@8]J`@YBP8]J`8icP96<@9>
L`9BU0IF]@ABU0Y>L`96<@8mk`8icP8e[@@aS08e[@DicPhmk`8icP8e[@8aS08YBP8e[@9BU09S609o
o`03001oogoo00Yoo`04001oogooOol80008Ool6000=Ool<000NOolA000:Ool<0006Ool00`00Oomo
o`06Ool000Moo`04001oodYBBU82;F/29BT2<H`2>Lh6@Q02?Nl2=Jd2:DX2=Jd2DY@5JeX2E[D2?Nl2
:DX27>L26<H28@P2:DX2<H`2?Nl2BU82E[D2F]H2G_L2F]H2DY@6CW<2BU82AS42>Lh4;F/2=Jd2>Lh2
=Jd4<H`5>Lh>?Nl4>Lh2=Jd2;F/2:DX2=Jd2DY@2HaP2Ool00`00Oomoo`0:Ool01000Oomoogoo2000
27oo1P002goo300067oo5`0027oo40001Woo00<007ooOol01Woo0007Ool01000Oom:DTYB0Re[0RDY
0S6<0SW>1T8@0Sg_0SF]0RU:0SF]0U:D1F]J0UJe0Sg_0RU:0QcW0QS60R480RU:0S6<0Sg_0TYB0UJe
0U[F0Ukg0U[F0U:D1Tic0TYB0THa0SW>12e[0SF]0SW>0SF]136<1CW>3Sg_13W>0SF]0Re[0RU:0SF]
0U:D0V<H0Woo00<007ooOol02Woo00@007ooOomoo`P000Qoo`H000]oo``001QooaL000Qooa0000Io
o`03001oogoo00Ioo`001goo00@007ooBU9:DP8YBP8U:@8aS08icP8mk`A2408mk`8aS08YBP8aS09:
DP9F]@=>L`8mk`8]J`@Q208YBP8e[@9240A:DP9>L`9BU0AF]@9>L`9:DP96<@9:DP9>L`9:DP92408a
S0@Q208]J`8icP8e[@@aS08icPlmk`HicP8e[@8aS08YBP8aS09BU09S609oo`03001oogoo00Yoo`04
001oogooOol80008Ool60007Ool<000LOolE0008OolB0006Ool00`00Oomoo`06Ool000Moo`04001o
odYBBU82:DX29BT2<H`2>Lh2?Nl4@Q02?Nl2<H`2:DX2<H`2BU82E[D3CW<2?Nl2;F/48@P2:DX2=Jd2
@Q04BU82CW<2DY@4E[D2CW<2BU82AS42BU82CW<2BU82@Q02<H`48@P2;F/2>Lh2=Jd4<H`2>Lh??Nl6
>Lh2=Jd2<H`2:DX2<H`2DY@2HaP2Ool00`00Oomoo`0:Ool01000Oomoogoo200027oo1P001goo3000
77oo5@0027oo4P001Woo00<007ooOol01Woo0007Ool01000Oom:DTYB0RU:0RDY0S6<0SW>0Sg_148@
0Sg_0S6<0RU:0S6<0TYB0UJe0dic0Sg_0Re[12480RU:0SF]0T8@14YB0Tic0U:D15Je0Tic0TYB0THa
0TYB0Tic0TYB0T8@0S6<12480Re[0SW>0SF]136<0SW>3cg_1SW>0SF]0S6<0RU:0S6<0U:D0V<H0Woo
00<007ooOol02Woo00@007ooOomoo`P000Qoo`H000Moo``001aooaD000Qooa8000Ioo`03001oogoo
00Ioo`001goo00@007ooBU9:DP8YBP8Q208]J`8e[@8mk`A2408mk`8aS08YBP8]J`8icP9240<icP8a
S08e[@8icP8mk`9:DP9BU09JeP9F]@9>L`A:DP96<@8mk`@e[@8mk`9:DPABU09:DP92408aS08]J`8e
[@8icP8e[@@aS08icP/mk`PicP@e[@8aS08YBP8e[@9BU09S609oo`03001oogoo00Yoo`04001oogoo
Ool80008Ool80002Ool9000DOol4000<Ool@0009OolD0006Ool00`00Oomoo`06Ool000Moo`04001o
odYBBU82:DX28@P2;F/2=Jd2?Nl4@Q02?Nl2<H`2:DX2;F/2>Lh2@Q03>Lh2<H`2=Jd2>Lh2?Nl2BU82
DY@2F]H2E[D2CW<4BU82AS42?Nl4=Jd2?Nl2BU84DY@2BU82@Q02<H`2;F/2=Jd2>Lh2=Jd4<H`2>Lh;
?Nl8>Lh4=Jd2<H`2:DX2=Jd2DY@2HaP2Ool00`00Oomoo`0:Ool01000Oomoogoo200027oo20000Woo
2@0057oo100037oo40002Goo50001Woo00<007ooOol01Woo0007Ool01000Oom>Ldic0Re[0RDY0Re[
0SF]0Sg_148@0Sg_0S6<0RU:0RDY0S6<0SW>0cg_0T8@0TYB0U:D1UJe0U:D0TYB0Sg_0SF]0S6<0Re[
12480RU:0Sg_0Tic0UJe15[F0UJe0U:D0TYB0T8@0SW>0S6<0Re[0S6<0SW>2Cg_13W>0Sg_1SW>0SF]
0S6<0Re[0SF]0U:D0V<H0Woo00<007ooOol02Woo00@007ooOomoo`X000Ioo`X001Eoo`h0011oo`d0
00Iooa@000Ioo`03001oogoo00Ioo`001goo00@007ooCW=>L`8]J`8U:@8]J`8e[@8mk`A2408mk`8a
S08YBP8U:@8aS08icP<mk`92409:DP9BU0IF]@9BU09:DP8mk`8e[@8aS08]J`@Q208YBP8mk`9>L`9F
]@AJeP9F]@9BU09:DP92408icP8aS08]J`8aS08icPTmk`@icP8mk`HicP8e[@8aS08]J`8e[@9BU09S
609oo`03001oogoo00Yoo`04001oogooOol:0006Ool:000EOol>000@Ool=0006OolD0006Ool00`00
Oomoo`06Ool000Moo`04001oodicCW<2;F/29BT2;F/2=Jd2?Nl4@Q02?Nl2=Jd2:DX29BT2=Jd2BU85
DY@4E[D2DY@2CW<2AS42?Nl2<H`28@P26<H65:D27>L2<H`2@Q02CW<2DY@2E[D2G_L4IcT2F]H2BU82
=Jd2;F/2:DX2<H`2>LhA?Nl4>Lh2=Jd2<H`2;F/2=Jd2E[D2IcT2Ool00`00Oomoo`0:Ool01000Oomo
ogoo200027oo20004goo40004Woo3@0017oo5P001Woo00<007ooOol01Woo0007Ool01000Oom>Ldic
0Re[0RDY0Re[0SF]0Sg_148@0Sg_0SF]0RU:0RDY0SF]0TYB1E:D15Je0U:D0Tic0THa0Sg_0S6<0R48
0QS61QBU0QcW0S6<0T8@0Tic0U:D0UJe0Ukg16Li0U[F0TYB0SF]0Re[0RU:0S6<0SW>4Cg_13W>0SF]
0S6<0Re[0SF]0UJe0VLi0Woo00<007ooOol02Woo00@007ooOomoo`P000Qoo`P001=ooa00019oo`d0
00AooaH000Ioo`03001oogoo00Ioo`001goo00@007ooDYABU08aS08YBP8]J`8e[@8mk`A2408mk`8e
[@@]J`92409F]@=Nm`9BU0A:DP96<@92408mk`8icP8YBP8DY@88@P8<H`8HaP8YBP8icP96<@9:DP92
408mk`96<@9F]@9W>@9[FP9S609:DP8aS0@YBP8aS0DicPPmk`8icP@mk`HicP8aS08]J`8e[@9F]@9W
>@9oo`03001oogoo00Yoo`04001oogooOol80008Ool6000COol@000DOol=0004OolF0006Ool00`00
Oomoo`06Ool000Moo`04001ooe:DDY@2<H`2:DX2;F/2=Jd2?Nl4@Q02?Nl2=Jd4;F/2@Q02E[D3G_L2
DY@4BU82AS42@Q02?Nl2>Lh2:DX25:D2248236<26<H2:DX2>Lh2AS42BU82@Q02?Nl2AS42E[D2IcT2
JeX2HaP2BU82<H`4:DX2<H`5>Lh8?Nl2>Lh4?Nl6>Lh2<H`2;F/2=Jd2E[D2IcT2Ool00`00Oomoo`0:
Ool01000Oomoogoo200027oo1P004goo400057oo3@0017oo5P001Woo00<007ooOol01Woo0007Ool0
1000OomBU5:D0S6<0RU:0Re[0SF]0Sg_148@0Sg_0SF]136<0T8@0U:D0dic0Sg_0SF]0Sg_0THa0TYB
0Tic0TYB0Sg_0R4810aS0RU:0TYB15[F0T8@0RDY0QS60RDY0Sg_0UJe0VLi0V<H0TYB0S6<0RDY0RU:
0S6<1CW>13g_43W>0S6<0Re[0SF]0UJe0VLi0Woo00<007ooOol02Woo00@007ooOomoo`X000Ioo`H0
00Uoo`@000Qoo`X000Qoo`H000YoobL000Ioo`03001oogoo00Ioo`001goo00@007ooDYABU08aS08Y
BP8]J`8e[@8mk`A2408mk`8e[@@aS092409BU0=>L`8mk`8e[@8mk`96<@9:DP9>L`9:DP8mk`8Q20@<
H`8YBP9:DPAJeP92408U:@8HaP8U:@8mk`9F]@9W>@9S609:DP8aS08U:@8YBP8aS0DicP@mka0icP8a
S08]J`8e[@9F]@9W>@9oo`03001oogoo00Yoo`04001oogooOol:0006Ool60009Ool40008Ool:0008
Ool6000:OolW0006Ool00`00Oomoo`06Ool000Moo`04001ooe:DDY@2<H`2:DX2;F/2=Jd2>Lh2?Nl2
@Q02?Nl2>Lh4=Jd2>Lh2?Nl3=Jd2;F/2<H`2AS42DY@2F]H2G_L2HaP2E[D2=Jd45:D2=Jd2G_L2JeX2
E[D2;F/22482000236<2:DX2AS44F]H2AS42;F/29BT2;F/2=JdI>Lh2<H`2:DX2=Jd2DY@2IcT2Ool0
0`00Oomoo`0:Ool01000Oomoogoo2P001Woo20000Woo1`0037oo20001Woo2P0027oo9`001Woo00<0
07ooOol01Woo0007Ool01000OomBU5:D0S6<0RU:0Re[0SF]0SW>0Sg_0T8@0Sg_0SW>13F]0SW>0Sg_
0cF]0Re[0S6<0THa0U:D0U[F0Ukg0V<H0UJe0SF]11BU0SF]0Ukg0V]J0UJe0Re[0PQ20P000PaS0RU:
0THa15[F0THa0Re[0RDY0Re[0SF]6CW>0S6<0RU:0SF]0U:D0VLi0Woo00<007ooOol02Woo00@007oo
Oomoo`X000Ioo`P0009oo`L000aoo`P000Ioo`X000QoobL000Ioo`03001oogoo00Ioo`001goo00@0
07ooDYABU08aS08YBP8]J`8e[@8icPPmk`8icP8e[@8aS08]J`<U:@8]J`92409F]@9Nm`9JeP9Nm`AW
>@96<@8Q208HaP8icP9Nm`9W>@92408HaP@48@8DY@8YBP9240ABU092408]J`8U:@8]J`8e[ATicP8a
S08YBP8aS09BU09W>@9oo`03001oogoo00Yoo`04001oogooOol<0004Ool?000@Ool60006Ool:0008
OolW0006Ool00`00Oomoo`06Ool000Moo`04001ooe:DDY@2<H`2:DX2;F/2=Jd2>Lh8?Nl2>Lh2=Jd2
<H`2;F/39BT2;F/2@Q02E[D2G_L2F]H2G_L4IcT2AS428@P26<H2>Lh2G_L2IcT2@Q026<H412425:D2
:DX2@Q04DY@2@Q02;F/29BT2;F/2=JdI>Lh2<H`2:DX2<H`2DY@2IcT2Ool00`00Oomoo`0:Ool01000
Oomoogoo300017oo3`0047oo1P001Woo2P0027oo9`001Woo00<007ooOol01Woo0007Ool01000OomB
U5:D0S6<0RU:0Re[13F]0SW>1Sg_0SW>0SF]0Re[1BDY0SF]0U:D0V<H0U[F0TYB0THa0UJe0V<H0Tic
0RU:0QcW0SF]0UJe0U:D0S6<11S60RU:0SW>0THa0Tic0UJe0Tic0SW>0RU:0RDY0Re[1cF]2SW>1Sg_
13W>0S6<0RU:0S6<0Tic0V<H0Woo00<007ooOol02Woo00@007ooOomoo``000Ioo`d0011oo`H000Ao
o`X000QoobT000Ioo`03001oogoo00Ioo`001goo00@007ooDYABU08aS08YBP8]J`@e[@8icPHmk`8i
cP8e[@8]J`DU:@8e[@9BU09S609JeP9:DP96<@9F]@9S609>L`8YBP8Li`8e[@9F]@9BU08aS0@HaP8Y
BP8icP96<@9>L`9F]@9>L`8icP8YBP8U:@8]J`Le[@XicPHmk`@icP8aS08YBP8aS09>L`9S609oo`03
001oogoo00Yoo`04001oogooOol<0006Ool=000@Ool60004Ool:0008OolY0006Ool00`00Oomoo`06
Ool000Moo`04001ooe:DDY@2<H`2:DX2;F/4=Jd2>Lh6?Nl4>Lh2<H`29BT3:DX2@Q02F]H2G_L2BU82
;F/29BT2?Nl2F]H2DY@2;F/27>L2=Jd2BU82@Q02;F/29BT2=Jd2BU82E[D2F]H4G_L2DY@2>Lh49BT2
;F/7=Jd4>Lh>?Nl2>Lh2<H`2:DX2<H`2DY@2IcT2Ool00`00Oomoo`0:Ool01000Oomoogoo30001Woo
2`0027oo10001Woo1P0017oo1P0037oo6@001Woo2P001Woo00<007ooOol01Woo0007Ool01000OomB
U5:D0S6<0RU:0Re[13F]0SW>1Sg_13W>0S6<0RDY0bU:0T8@0U[F0Ukg0TYB0Re[0RDY0Sg_0U[F0U:D
0Re[0QcW0SF]0TYB0T8@0Re[0RDY0SF]0TYB0UJe0U[F15kg0U:D0SW>12DY0Re[1cF]13W>3Sg_0SW>
0S6<0RU:0S6<0U:D0VLi0Woo00<007ooOol02Woo00@007ooOomoo``000Ioo`/000Qoo`@000Ioo`H0
00Aoo`H000aooaT000Ioo`X000Ioo`03001oogoo00Ioo`001goo00@007ooDYABU08aS08YBP8aS08e
[@@icPPmk`8icP8e[@8]J`<aS096<@9JeP9F]@8icP8HaP8@Q08aS0ABU08]J`8Li`8]J`92408mk`8e
[@8mk`9BU09Nm`AS60AW>@9JeP8mk`8YBP8U:@8]J`8aS0De[@8icQ0mk`8icP8aS08YBP8aS09BU09W
>@9oo`03001oogoo00Yoo`04001oogooOolM0006Ool80004Ool60004Ool2000BOolA0006Ool20006
Ool80006Ool00`00Oomoo`06Ool000Moo`04001ooe:DDY@2<H`2:DX2<H`2=Jd4>Lh8?Nl2>Lh2=Jd2
;F/3<H`2AS42F]H2E[D2>Lh26<H248@2<H`4DY@2;F/27>L2;F/2@Q02?Nl2=Jd2?Nl2DY@2G_L4HaP4
IcT2F]H2?Nl2:DX29BT2;F/2<H`5=Jd2>Lh@?Nl2>Lh2<H`2:DX2<H`2DY@2IcT2Ool00`00Oomoo`0:
Ool01000Oomoogoo7@001Woo200017oo1P0017oo0P004Woo4@001Woo0P001Woo20001Woo00<007oo
Ool01Woo0007Ool01000OomBU5:D0S6<0RU:0S6<0SW>3Sg_0SW>0S6<0cF]0TYB0Ukg0U[F0SW>0QS6
0Q240Re[0Tic0TYB0RU:0QS60RU:0Sg_0THa0Tic0UJe15kg15[F0V<H0V]J0V<H0TYB0S6<0RU:0Re[
0S6<0SF]1CW>43g_0SW>0S6<0RU:0SF]0U:D0VLi0Woo00<007ooOol02Woo00@007ooOomooa8000Ao
o`L000Ioo`P000Aoo`H001Qoo`l000Qoo`@000Aoo`P000Ioo`03001oogoo00Ioo`001goo00@007oo
DYABU08aS08YBP8aS08icPhmk`8icP8aS0<e[@9:DP9Nm`9JeP8icP8HaP8@Q08]J`9>L`9:DP8YBP8H
aP8YBP8mk`96<@9>L`9F]@ANm`AJeP9S609[FP9S609:DP8aS08YBP8]J`8aS08e[@DicQ0mk`8icP8a
S08YBP8e[@9BU09W>@9oo`03001oogoo00Yoo`04001oogooOolB0004Ool70006Ool80004Ool6000H
Ool?0008Ool40004Ool80006Ool00`00Oomoo`06Ool000Moo`04001ooeJeE[D2=Jd2;F/2=Jd2?Nl4
@Q06?Nl2@Q02?Nl2>Lh2<H`3>Lh2CW<4IcT2BU829BT27>L2=Jd2CW<2@Q029BT25:D29BT2@Q02F]H2
HaP2IcT2HaP2E[D4BU82E[D2JeX2Kg/2F]H2?Nl4<H`2=Jd2>Lh5?Nl6@Q0:?Nl2>Lh2=Jd2;F/2=Jd2
E[D2JeX2Ool00`00Oomoo`0:Ool01000Oomoogoo1P0047oo1`0027oo1P0017oo1P006Woo2`0037oo
0P0017oo20001Woo00<007ooOol01Woo0007Ool01000OomF]EJe0SF]0Re[0SF]0Sg_148@1Sg_0T8@
0Sg_0SW>0S6<0cW>0Tic16Li0TYB0RDY0QcW0SF]0Tic0T8@0RDY0QBU0RDY0T8@0U[F0V<H0VLi0V<H
0UJe14YB0UJe0V]J0Vmk0U[F0Sg_136<0SF]0SW>1Cg_1T8@2Sg_0SW>0SF]0Re[0SF]0UJe0V]J0Woo
00<007ooOol02Woo00@007ooOomoo`H0011oo`L000Qoo`H000Aoo`H001Yoo`/000aoo`8000Aoo`P0
00Ioo`03001oogoo00Ioo`001goo00@007ooF]IJeP8mk`8aS08icP9240A6<@I24096<@92408mk`8e
[@<icP9BU09cW09kgP9Nm`8e[@8]J`92409>L`92408U:@8Li`8aS09BU09_N`9g_@9cW09S609:DP@e
[@9BU09cW09oo`9[FP9>L`HicPDmk`A24096<@I240Pmk`8e[@8aS08mk`9Nm`9_N`9oo`03001oogoo
00Yoo`04001oogooOol6000@Ool70008Ool40006Ool6000<Ool4000:Ool6000GOol80006Ool00`00
Oomoo`06Ool000Moo`04001ooe[FF]H2?Nl2<H`2>Lh2@Q04AS46@Q02AS42@Q02?Nl2=Jd3>Lh2DY@2
Li`2Nmh2G_L2=Jd2;F/2@Q02CW<2@Q029BT27>L2<H`2DY@2Kg/2Mkd2Li`2HaP2BU84=Jd2DY@2Li`2
Ool2JeX2CW<6>Lh5?Nl4@Q02AS46@Q08?Nl2=Jd2<H`2?Nl2G_L2Kg/2Ool00`00Oomoo`0:Ool01000
Oomoogoo1P0047oo1`0027oo10001Woo1P0037oo10002Woo1P005goo20001Woo00<007ooOol01Woo
0007Ool01000OomJeU[F0Sg_0S6<0SW>0Sg_2T8@0THa0TYB0THa1CW>0U:D0W>L0Woo0V]J0TYB0T8@
0U:D0Ukg0Tic0SW>0S6<0THa0VLi0W_N0Woo0WNm0V<H0THa0S6<0SF]0UJe0WNm0Woo0Vmk0U:D13g_
2D8@1THa2T8@0Sg_0SW>0SF]0T8@0V<H0Vmk0Woo00<007ooOol02Woo00@007ooOomoo`H0019oo`D0
019oo`@000ioo`@002Uoo`@000Qoo`03001oogoo00Ioo`001goo00@007ooF]IJeP8mk`8aS08icP8m
k`Y24096<@9:DP96<@DicP9BU09cW09oo`9[FP9:DP92409BU09Nm`9>L`8icP8aS096<@9W>@9kgP9o
o`9g_@9S6096<@8aS08e[@9F]@9g_@9oo`9_N`9BU0@mk`U240I6<@Y2408mk`8icP8e[@92409S609_
N`9oo`03001oogoo00Yoo`04001oogooOol6000BOol5000BOol4000>Ool4000YOol40008Ool00`00
Oomoo`06Ool000Moo`04001oodHaAS42;F/29BT2:DX2<H`8=Jd2>Lh2AS44CW<2@Q03?Nl2BU82HaP2
Kg/2HaP2DY@2CW<2G_L2IcT2G_L2CW<2AS42DY@2IcT2Kg/2JeX2HaP2E[D2@Q02<H`2>Lh2DY@4IcT2
E[D2?Nl4=Jd2>Lh9?Nl:@Q06?Nl4>Lh2@Q02E[D2F]H2Ool00`00Oomoo`0:Ool01000Oomoogoo4P00
;goo10002Woo2`004Woo1P0027oo00<007ooOol01Woo0007Ool01000Oom6<DHa0Re[0RDY0RU:0S6<
23F]0SW>0THa14ic0T8@0cg_0TYB0V<H0Vmk0V<H0U:D0Tic0Ukg0VLi0Ukg0Tic0THa0U:D0VLi0Vmk
0V]J0V<H0UJe0T8@0S6<0SW>0U:D16Li0UJe0Sg_13F]0SW>2Cg_2T8@1Sg_13W>0T8@0UJe0U[F0Woo
00<007ooOol02Woo00@007ooOomooa8002moo`@000Yoo`/0019oo`H000Qoo`03001oogoo00Ioo`00
1goo00<007ooOol0Ngoo00<007ooOol02Woo00<007ooOol0Ngoo00<007ooOol01Woo0007Oomo000<
Oomo0008Ool00?mooaYoo`00ogoo6Woo003oOolJOol00001\
\>"],
  ImageRangeCache->{{{0, 280}, {132.75, 0}} -> {-0.0546234, -0.0238146, 
  0.00753303, 0.00753303}, {{7.25, 133.625}, {129.563, 
  3.125}} -> {-4.84912, -2.85465, 0.494754, 0.494754}, {{146.313, 272.75}, {
  129.563, 3.125}} -> {-73.6149, -2.83838, 0.494508, 0.494508}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Zero Crossings", "Subsection"],

Cell[TextData[{
  "The remaining step is to localize the zero-crossings of the \[Del]2 image. \
This can be done by tracing the edges of the black regions in the image above \
(right). The function ",
  StyleBox["ZeroCrossing", "Program"],
  " accomplishes this task."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[
      GraphicsArray[
        \(ListDensityPlot[#1, Mesh \[Rule] False, FrameTicks \[Rule] None, 
              DisplayFunction \[Rule] Identity]\ &\)\ /@{\[Del]g, \ 
            ZeroCrossing[\[Del]g]}]]; \)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .47619 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0113379 0.47619 [
[ 0 0 0 0 ]
[ 1 .47619 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .47619 L
0 .47619 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0113379 0.477324 0.464853 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0160256 0.0192308 0.0160256 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
60 string
60 60 8 [60 0 0 60 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
573736434F5558595B65798F988E807E8A92887A7E93A29D
8A7C7E86847C766D5B515B6F7A735A413E4E5D64676B6E71
747678767472706F6F78857D
493F47555D6162615F6068767F7A6A584C443D3A404E5A5D
584E43372D2B3034333235393A3D3E3A373E4C575D62676B
70737371706F6E6D6C6D6D60
6468727A7C7B797873685E5D5F5B5040322B282A333C4243
4340382B23252D34373836333A57797F664F4E5861676C71
7677757373757573706F6E69
7D858C8D8984838886766259595B595554575B5F676D685D
57595955505053545455534E5A8BC7D29F67555D676F757A
7C7B7876787B7B7975747678
82898C8A837D808F988A756C70777D80848D919193948975
68676B6C6A67615B585B5A56629AE2F4B870545C6971777C
7D7A7675777B7A777372757A
7B81838079737A92A49A837A7C8286858489898483857F71
645E5C5957555049454645404B81CEEAB46B4E58676E7479
7874706F7274736E69696D73
727A7D7A736C7491A79C7D6B686866605A5D605E5E62635E
564D443E40454949474136282D5DACD3A9644852626A6E71
6F6A6564676966615C5C6169
687277766F686F8BA3956F544D4D4A43424E5D625F574E47
43413F4350606D7574674C2B1D418FBF9F5D3E47575F6263
615D5958595A58545253575E
5E666D6E696369849C906A53565F5E575A6D858E80614232
35455A708799A5ADAEA2824F283579AF9A5A373C4D565A5C
5B59595B5E6060616264615C
5C595F63615C617A938C706B83999A8E8790A3A98F5E362B
40668BA7B7BDBEC1C5C4B08148396DA9A4704F52616B7074
76787C838A8E91959A9A8A6F
6557595F615F657A9089737CA6C6C7B5A19AA1A07F4C2F3D
6897B6C3C1B9B2B1B8C2C1A46B4669ACC1A38B8E9BA2A5A8
AAAAAEB5BBBEBFC1C5C6B28A
7F7071767A7C81919D8C6D74A0C3C7B7A393908968403C64
98BBC6C1B5A9A1A1A7B3BDB2815366ABD0C0ADB0BABEBDBC
B9B6B4B4B5B2AEAAABB1AE9A
A29E9E9FA0A0A2AAAF94686087B0BEB59F87786B55475E90
B8C6C1B7AEA7A4A3A5ACB8B7915E6198B6A0878893969594
908B8683807B746C6A778FA0
B1B1AEAAA6A19EA6AE97675376ABC9C19D725345465D89B4
C8C6BCB3ACA7A5A4A5ACBBC2A46F60818F6D4C4C59616365
64615F5E5C59544B46577DA2
9B908A87837D7A879C956A4F6BA4C8BE8E542D27457CB0CB
CEC3B5A595898281889EBED1BB8465757C59393A4A555A5D
5E5E5F60605E59504A5A7F9A
7D655D5F605F5F719095704E5B87A59A6F3C1C265B9FCBD5
C9B39A7E634E43415077AFD9CF966C747B5F444859656A6C
6F707071706E695E59698791
755850555B5C5D6F919D7A524F687B755835254082C0D9CD
AF8C6A4E37261C171F4891D3DAA778787F68515566717678
7A7B7B7A7977716662749193
7C605A606665647497A6865C505D6866543E3B65AAD9D9B4
845A4135302B23160E2872C4E0B68780826C575A6973787B
7D7E7C79787771676479989B
8469656C716E6A799CAC8F685B6269665747538BCCE4C78D
583A33393F403826121D5EB6DCBB8E84836D585B6973787A
7C7B797675746F66637A9BA0
856B697175716E7C9DAC926E646C7169574B66A9E1DDA563
3C343D4749453C2E1F2860AECEAD8681836E595C6A757979
7878777572706C6361779AA1
8469676F73706D7B9AA98F6D6570776E574B71BCE9CA7E41
303C4B4E463D393B40517EB3BB91717A836F595C6C767877
75757675726F6B63607598A0
8366636B6F6C697795A58C6A616D7670574C77C7ECBC632C
2B414D4B43424E657B92AFC3AB755C7284725B5D6D767775
7475767674716D6461769AA2
85645F686D6A677492A38C6A6069726C544B7ACEF2B95B26
293B43444D6381A0B7C6D2CDA1644E6C85745D5F6D757676
7677787876746F6662779DA5
88645E686E6C697594A58F6E646D72684F477BD3F8BD5D27
263239486A93B5CAD3D8DAD0A3654C6984765F606E767878
797A7B7A7876716661779EA9
8D675F69706F6C7898A992716872786A4E4478D2FAC26025
1E293B5E90BBD2D7D5D3D5D3B47B576982776162717A7B7B
7C7D7D7C7A7872666076A0AE
926B606A72726F7B9AA9927068737A6E504371CBFBCD6D26
13234980B5D2D7D0C6BEC1CCC4976A6D81776263737D7E7D
7C7D7E7E7C7972676178A3B3
946B606A7474707C99A890706771776C4F3F67C0FBE38E3C
172861A5D0D6C7B39E8C8CA7BDA77B7381766162727C7E7C
7B7C7E7D7B7872666178A4B4
91695F6A7574707B98A690726A7275674A3659AFF7F7B864
303E82C4D7BF9B7B5F47476FA2A7857880745F5F6E787B79
787A7B7A787670655F75A1B2
8E655C6A75746F7997A58F726C767766432B4796DEEDBF74
42569ED0C28E5F4129161B4E92A68A7B80725D5D6B767877
7778797875746F645D719DAF
8D635B6A75736E7996A38B6C687477643F243879B4BC9254
355CA7C497542E20150C1B579FB1928083745F5F6C757777
787A797774736E635B6F9CAF
8F635A6872716D7996A28869626B6E5D3F2B3F749C935F26
1953A0AA692712181B1E3B7DBBBE9684877963616C747778
7A7C7B7875736E625A6E9DB2
91635A67706F6D7A97A2896B626360564B4C6895B19E5F1D
0F4C989951130A1E314570AED3BB8A7D877C67636C737779
7B7C7B7977756F63596EA0B5
9163596771716F7B95A08A6E625E595B6B85A4C5DACA8A3B
1C4F989F5F241E3A5B7FADD5D39F6D6E837E6A656B727779
7A7A7A7A79787164596EA0B6
8F615A697575727B939E886C5E585B739DBFD0DCEAE4AF5B
2D529CB58B5C556F93B6D6DEB9754E61817F6C666B717679
79797A7B7B7A7465596EA0B5
8E605B6D7979747C929B856756516292C8DCCDC0CBD6B467
324D98C4B89B95A4BBD0D9C68F513D5E83806D686C717679
7978797B7B7A75665A6EA1B6
8E5F5A6D7A78737B92998263504F6CA6D0C1917486A8A062
2D3D82BBC9C1BCC0C5C6BA9867404065847F6D696F747779
7A7A797A7A797364586FA4B8
8F5E596C7674707B92987F604E5175A8B27D3A254A838E5B
24275E99B9C4C4C0B5A38A6C5348516E837B6B6A7277797A
7B7B7A7A7A776F5F546EA5BA
915E586B7573707C93977B5A484F749B8A450E134C8C965F
21102F5F88A3AEAA977C665F656868737D74686A73787A7B
7C7C7B7B7B786D5C516BA5BD
925E576A7675737E9292744F3D456C90804C314C87B6AE6E
26020621456980877C6C697C93907A72746C656972777A7C
7C7B7B7C7D796E5C516AA6BE
935C53687677767F8E896A493B49729A9D847E9AC1D4BC7D
3B0F0007214463757A7B8AA9BEAB836E6B66636971767A7B
7B7A7A7C7D79705F536BA6C0
945A506575787880897F614E546E96B9C2B7B2BDC8C5AC85
5D3E2D2E3F5872848E96A8C3CFB3876E6661636B7275787A
7B7A7A7C7C797061566BA6C2
955A4E64767B7C8284755C5B7EA9C9D6CFBAA89D958A827E
7D7973767F8A939A9EA2AEBFC3AA8872665F646D7273767A
7C7B7B7C7B786F61566BA6C3
965A4E64777F8184806D58679ED3E4D4B38C6C5A52525D74
8D9EA5A9ACA8A2A09F9E9F9F98897D776B60656F7374787C
7D7C7B7A79766E60546AA6C3
95594E64778084857E68566BA5D4D2AC7D5338344052667C
94A9B4B8B3A79C999A978B755F5968766F62667076787B7E
7E7B797877736C5F5369A4C3
95574B60747E83857D67566693AF9E79594541526F879193
9BA7AEAA9D908C929A97856547425B746F636672797C7E7E
7B79787774706C605367A3C2
9656475C6F7A81857D6752587382756668717C90A7B2AA9A
93938E7F6F6B7A91A0A29781675D68736A6065727A7E7F7C
78777776726F6C625568A3C3
9959485B6E7981857E67504C60757B8295A5A9ABAEA7927B
6C64584640537898A9B0B2AEA1908273615A6370797E7E7A
7777787773706D64586AA5C6
9E5F4D5D6F7A82857E69524F6B91A4A7ACAEA5998F7E6347
352F2D2D3E63879BA4AFBECBCAB6926E58566270787C7C7A
7878797875726F655A6DA8CA
A263505E6F7A82857E6B585C80ACB8A697918B847F72552E
15183151748F92827C8DACCAD6C3956650546370777A7A79
78777878777570655A6EABCD
A364515D6D7880837D6E606785A39D7E6F7A889199967944
1A1F5492B6B0804A364D7DAECAC092614D55657177797977
7675757777767165596DAACD
A264505C6B767D817D73696A777D6D5A6588A3B0BBC3AD6E
2F2C6FBCD5AA5815031E5189B2B38C5F4E58687276777776
74737476777672645568A5CA
A265515C6972797F7E78706A64594E5882ADBCB6BBCDC98E
413274BFC887360A0E2D5581A2A3815A4F5B6A7173747575
74747576777771625263A1C8
A266525D686E767D7E7B746B5C4A496DA6C6B5928CADC59D
51386FADA56531305070889DA99C75524C5C6A6E6F727576
767778797877716150619FC7
A165535F6A6F757A7C7A7770604E5380B4BF93584B7DB3A2
5C3E6895875A4E6D96ADB7BDBCA1724D4A5B686C6E727678
797A7A7B7A7972615163A1C8
A06353626F737678797979766A5A618AB2AD75322360A6A0
5F3E5E837F6F7CA0BBC3C3C9C9B07E544C5A666B6F74797B
7B7B7A7A7B7B73635467A4C8
A26454657479787878797C7B71646C94B8B07631235F9F96
5636527D8F98A9BCBFB6B4C1D0C59765535B676D72777B7D
7D7B78787A7B7565576AA7CB
AA6C5B6C7B80807D7B7D807F7366709FCFCF934A396C9A86
4A2F4F87B0C4CCC5AC9290AFD6DFB77E60626B72787D8081
817E7A797B7B76685A6FADD3
B77966748288898683858887796870A5E5F2B86D5B829F83
4E3C63A6D9EAE3C5956C6FA2E1FAD7987370767B7F848788
8684817F7F7E796D627AB9DF
B47864707C83858382868F93887475A2E4FCD19385A5B99F
73668CCBF5FAE9C38B626DA8E8FFDDA17E7B80818386898A
8887858482807C736E86C0DD
8B594C57636A6D6D6E77899998877E96C4DBC4A19EB9CAB9
988BA2C9DDD7C6AA816674A1C9CEAB7C686E7678797C7F80
808181807E7B78747386ACB7
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0113379 0.97619 0.464853 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0165782 0.0192308 0.0165782 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
58 string
58 58 8 [58 0 0 58 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
0000000000000000000000FFFF0000000000000000000000
000000000000000000000000000000000000000000000000
00000000000000000000
0000FFFFFF00000000000000000000000000000000000000
0000000000000000000000000000FF000000000000000000
00000000000000000000
FFFFFF00FFFFFFFF00000000000000000000000000000000
000000000000000000000000FFFFFFFF00000000000000FF
FF000000FFFF00000000
0000FFFFFFFF00FFFF00000000FFFFFFFFFFFFFFFFFF0000
000000000000000000000000FF0000FF000000000000FFFF
FF000000FFFF00000000
FFFFFF0000FFFF00FFFF00FFFFFFFFFFFFFFFFFFFFFF0000
000000000000000000000000FFFF00FF0000000000000000
00000000000000000000
00FFFF000000FF00FFFF0000000000000000000000000000
00000000000000000000000000FF00FF0000000000000000
00000000000000000000
000000000000FF00FF000000000000000000000000000000
00000000000000000000000000FFFFFF0000000000000000
00000000000000000000
000000000000FFFFFF0000000000000000FFFFFF00000000
000000FFFFFFFFFFFFFF00000000FFFF0000000000000000
00000000000000000000
00000000000000FFFF0000FFFFFFFFFFFFFF00FF00000000
00FFFFFF0000000000FFFF000000FFFF0000000000000000
00FFFFFFFFFFFFFFFFFF
000000000000FFFFFF00FFFF000000000000FFFF00000000
FFFF0000000000000000FF000000FFFFFFFFFFFFFFFFFFFF
FFFF00000000000000FF
000000FFFFFFFF00FF0000FF00000000FFFFFF00000000FF
FF000000000000000000FFFF0000FF000000000000000000
00000000FFFFFFFFFFFF
FFFFFFFF00000000FF0000FFFF0000FFFF0000000000FFFF
0000000000000000000000FF0000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00000000FF
0000000000000000FF000000FF0000FF0000000000FFFF00
0000000000000000000000FF0000FFFF0000000000000000
000000000000000000FF
FFFFFFFFFFFFFFFFFF000000FF00FFFF00000000FFFF0000
0000FFFFFFFFFFFFFFFF00FFFF0000FF0000000000000000
000000000000000000FF
00000000000000FFFF000000FFFFFF0000000000FF000000
FFFFFF000000000000FF0000FF0000FF0000000000000000
000000000000000000FF
00000000000000FFFF00000000FF0000000000FFFF0000FF
FF0000000000000000FFFF00FF0000FF00000000000000FF
FFFF00000000000000FF
00000000000000FFFFFF000000000000000000FF0000FFFF
00000000000000000000FF00FFFFFFFF000000000000FFFF
FFFF00000000000000FF
00000000000000FF00FF0000000000000000FFFF00FFFF00
00000000000000000000FF00000000FF000000000000FFFF
FF0000000000000000FF
000000000000FFFF00FF0000000000000000FF0000FF0000
00000000000000000000FF00FFFFFFFF0000000000000000
000000000000000000FF
000000000000FFFF00FF0000000000000000FF00FFFF0000
000000000000000000FFFFFFFF0000FF0000000000000000
000000000000000000FF
00000000000000FF00FF0000000000000000FF00FF000000
00000000000000FFFFFF00FF000000FF0000000000000000
000000000000000000FF
00000000000000FF00FF00000000000000FFFF00FF000000
0000000000FFFFFF000000FF000000FF0000000000000000
000000000000000000FF
00000000000000FF00FF00000000000000FFFF00FF000000
00000000FFFF0000000000FF000000FF0000000000000000
FFFFFF000000000000FF
00000000000000FF00FF0000000000000000FF00FF000000
000000FFFF000000000000FFFF0000FF0000000000FFFFFF
FF00FFFF0000000000FF
000000000000FFFF00FF0000000000000000FF00FF000000
0000FFFF0000000000000000FF0000FF00000000FFFF0000
000000FF0000000000FF
000000000000FF0000FF0000000000000000FF00FFFF0000
0000FF000000FFFFFFFFFFFFFFFF00FF00000000FFFFFFFF
FFFFFFFF0000000000FF
000000000000FFFF00FF0000000000000000FF0000FF0000
00FFFF00FFFFFF00000000FF00FF00FF0000000000FF0000
00FFFF000000000000FF
00000000000000FF00FF0000000000000000FFFF00FF0000
00FF00FFFF000000000000FF00FFFFFF0000000000000000
000000000000000000FF
00000000000000FF00FF000000000000000000FFFFFF0000
00FFFFFF00000000000000FF000000FF0000000000000000
000000000000000000FF
00000000000000FF00FF000000000000000000FFFF000000
00FFFF00000000000000FFFF000000FF0000000000000000
FFFF00000000000000FF
000000000000FFFF00FF0000000000000000FFFFFF000000
00FFFF00000000000000FF00FFFFFFFFFF000000000000FF
FFFF00000000000000FF
000000000000FF0000FF000000000000FFFFFF00FFFF0000
00FFFF0000000000FFFFFFFFFF0000FFFF00000000000000
00FFFF000000000000FF
000000000000FF0000FF0000000000FFFF00000000FF0000
00FFFFFF000000FFFF0000FF000000FFFF00000000000000
0000FFFF0000000000FF
000000000000FF0000FF00000000FFFF00FFFFFF00FF0000
00FF00FFFFFFFFFF0000FFFF000000FFFF00000000000000
0000FFFFFF00000000FF
000000000000FF0000FF00000000FF00FFFF00FFFFFF0000
00FFFF000000000000FFFF00000000FFFF000000000000FF
000000000000000000FF
000000000000FF0000FF00000000FFFFFF000000FFFF0000
0000FFFF00000000FFFF0000000000FFFF0000000000FFFF
FFFFFF000000000000FF
000000000000FF00FFFF00000000FFFF00000000FFFF0000
000000FFFFFF00FFFF000000000000FF000000000000FF00
0000FFFF0000000000FF
000000000000FF00FF0000000000FFFF000000FFFFFF0000
0000000000FFFFFF0000FFFFFFFF00000000000000FFFFFF
FFFF00FF0000000000FF
000000000000FF00FF0000000000FFFFFFFFFFFF00FFFF00
00000000000000FFFFFFFF0000FF0000000000000000FFFF
00FF00FF0000000000FF
000000000000FFFFFF00000000FFFF00000000000000FF00
000000000000FFFF0000000000FF0000000000000000FFFF
00FF00FF0000000000FF
00000000FFFFFFFF000000FFFFFF0000FFFFFFFFFFFFFFFF
000000FFFFFFFF000000000000FF0000000000000000FFFF
FFFFFFFF0000000000FF
00000000FF0000FF000000FF000000FFFF000000000000FF
FFFFFFFF0000000000FFFFFFFFFF0000000000000000FF00
FFFFFF000000000000FF
00000000FF0000FF000000FF00FFFFFF000000000000FFFF
000000000000000000FF0000000000000000000000FFFFFF
FF0000000000000000FF
00000000FF0000FF000000FFFFFF000000000000FFFFFF00
0000FFFFFFFF000000FF00000000000000000000FFFFFFFF
000000000000000000FF
00000000FFFF00FF00000000FF00000000FFFFFFFF00FFFF
FFFFFF0000FFFF0000FFFF0000000000000000FFFF00FF00
000000000000000000FF
0000000000FF00FF0000000000FFFFFFFFFF0000FFFFFF00
000000000000FF000000FFFFFFFF000000000000FFFFFF00
000000000000000000FF
00000000FFFF00FF00000000FFFF0000000000FFFF000000
0000000000FFFF000000000000FF000000000000FFFF0000
000000000000000000FF
00000000FFFF00FF000000FFFF00FFFFFFFF00FF00000000
00000000FFFFFFFFFFFF000000FF000000000000FFFF0000
000000000000000000FF
0000000000FF00FF000000FFFFFFFF0000FF00FFFF000000
0000FFFFFFFF000000FFFF0000FF00000000000000000000
000000000000000000FF
0000000000FFFFFF00000000FF000000FFFF0000FFFF0000
0000FF00FF0000000000FF0000FF00000000000000000000
000000000000000000FF
000000000000FFFF00000000000000FFFF00000000FFFF00
0000FFFFFF0000000000FF00FFFF00000000000000000000
000000000000000000FF
000000000000FFFFFF000000000000FF00FFFFFFFF00FF00
0000FFFF0000000000FFFF00FF0000000000000000000000
000000000000000000FF
000000000000FFFFFF0000000000FFFFFFFF0000FFFFFF00
0000FFFF000000FFFFFF0000FF0000000000000000000000
00FFFFFF0000000000FF
0000000000000000000000000000FF00FF00000000FFFF00
0000FFFF00FFFFFF00000000FFFF0000000000000000FFFF
FF00FFFFFF00000000FF
000000000000000000FFFF000000FF00FF00000000FFFF00
0000FFFFFFFF00000000000000FF00000000000000FFFF00
FF0000FFFF00000000FF
000000FFFFFFFFFFFFFFFF000000FF00FFFF000000FFFF00
0000FF00000000FFFFFFFF0000FFFF0000000000FFFF0000
FFFF00FFFF00000000FF
000000FF000000000000FF000000FF0000FF0000FFFFFF00
0000FF00000000FF0000FF000000FF000000FFFFFF000000
00FFFFFFFF00000000FF
000000FFFFFFFFFFFFFFFFFF0000FF0000FFFFFFFF00FF00
00FFFF00000000FF0000FF000000FFFFFFFFFFFFFF000000
00000000FFFF0000FFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 137.125},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000RA000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo0007Oon2000=Oon20008Ool000Moo`03001oogoo07ioo`03001oogoo
00]oo`03001oogoo07ioo`03001oogoo00Ioo`001goo00<007ooOol0OWoo00<007ooOol02goo00<0
07ooOol0OWoo00<007ooOol01Woo0007Ool01000OolYBRU:11S60R480RDY0bU:1Re[0S6<0Sg_0THa
0Tic0THa0T8@0Sg_0THa0dYB0THa13g_0TYB0U:D0Tic0THa13g_148@0cg_0SW>0SF]0Re[0RU:0Re[
0SF]0Sg_0SW>0Re[0R480QcW0bDY0Re[136<13F]1SW>0Sg_2CW>13F]0Sg_0T8@0Sg_0Woo00<007oo
Ool02goo00<007oo00005`0017ooH@000Woo00<007ooOol01Woo0007Ool01000OolYBRU:11S60R48
0RDY0bU:1Re[0S6<0Sg_0THa0Tic0THa0T8@0Sg_0THa0dYB0THa13g_0TYB0U:D0Tic0THa13g_148@
0cg_0SW>0SF]0Re[0RU:0Re[0SF]0Sg_0SW>0Re[0R480QcW0bDY0Re[136<13F]1SW>0Sg_2CW>13F]
0Sg_0T8@0Sg_0Woo00<007ooOol02goo00<007oo00005`0017ooH@000Woo00<007ooOol01Woo0007
Ool01000OolU:BDY0QcW0R480RU:0Re[1c6<0Re[0S6<0SF]0SW>13g_0SF]0Re[0RDY0b4811cW0R48
0RDY1Re[0RDY0R480QS61ABU2QS62QcW0QS60acW0RDY0RU:0Re[136<0SF]2SW>3CF]0S6<0Woo00<0
07ooOol02goo00<007oo00000`001gooA`000Woo:@000Woo00<007ooOol01Woo0007Ool01000OolU
:BDY0QcW0R480RU:0Re[1c6<0Re[0S6<0SF]0SW>13g_0SF]0Re[0RDY0b4811cW0R480RDY1Re[0RDY
0R480QS61ABU2QS62QcW0QS60acW0RDY0RU:0Re[136<0SF]2SW>3CF]0S6<0Woo00<007ooOol02goo
00<007oo00000`001gooA`000Woo:@000Woo00<007ooOol01Woo0007Ool01000OolaS36<0SF]0SW>
2cg_0SW>0SF]22e[0RU:0R480QS61aBU0QS60QcW22480QcW0QBU1A240QBU11S60QcW11S60QcW0RU:
13g_0S6<1BDY0Re[136<0SF]5CW>1SF]0Woo00<007ooOol02goo00<007ooOol01Goo0`0027oo?@00
27oo3`001Goo1P0017oo2@000Woo00<007ooOol01Woo0007Ool01000OolaS36<0SF]0SW>2cg_0SW>
0SF]22e[0RU:0R480QS61aBU0QS60QcW22480QcW0QBU1A240QBU11S60QcW11S60QcW0RU:13g_0S6<
1BDY0Re[136<0SF]5CW>1SF]0Woo00<007ooOol02goo00<007ooOol01Goo0`0027oo?@0027oo3`00
1Goo1P0017oo2@000Woo00<007ooOol01Woo0007Ool01000Oolmkcg_0T8@1THa1D8@0THa0T8@0SW>
0S6<22e[1bU:12e[0S6<13F]0Re[0RU:12e[4BU:0RDY0Re[0THa0V<H0V]J0Tic0c6<0RU:0Re[0S6<
0SF]0SW>23g_0SW>2Cg_1SW>0Sg_0Woo00<007ooOol02goo00<007oo00000`002Goo0P0017oo2@00
4goo7`000Woo10000Woo3@001goo1P0017oo2@000Woo00<007ooOol01Woo0007Ool01000Oolmkcg_
0T8@1THa1D8@0THa0T8@0SW>0S6<22e[1bU:12e[0S6<13F]0Re[0RU:12e[4BU:0RDY0Re[0THa0V<H
0V]J0Tic0c6<0RU:0Re[0S6<0SF]0SW>23g_0SW>2Cg_1SW>0Sg_0Woo00<007ooOol02goo00<007oo
00000`002Goo0P0017oo2@004goo7`000Woo10000Woo3@001goo1P0017oo2@000Woo00<007ooOol0
1Woo0007Ool01000Oom2448@1THa0T8@0cg_0T8@0THa0Tic0THa0SW>0SF]13W>0Sg_148@0dHa24YB
0THa0SW>0SF]0S6<1SF]1C6<22e[0RU:0S6<0Tic0W>L0W_N0Ukg0cW>0RU:0Re[0SF]13W>1Sg_1SW>
1Cg_23W>0Sg_0Woo00<007ooOol02goo00<007oo00000`002Goo0P0017oo2@004goo7`000Woo1000
0Woo3@001goo1P0017oo2@000Woo00<007ooOol01Woo0007Ool01000Oom2448@1THa0T8@0cg_0T8@
0THa0Tic0THa0SW>0SF]13W>0Sg_148@0dHa24YB0THa0SW>0SF]0S6<1SF]1C6<22e[0RU:0S6<0Tic
0W>L0W_N0Ukg0cW>0RU:0Re[0SF]13W>1Sg_1SW>1Cg_23W>0Sg_0Woo00<007ooOol02goo00<007oo
Ool01Goo1@0017oo0P001Goo0P005goo7`0017oo0P000Woo9`000Woo00<007ooOol01Woo0007Ool0
1000Oolmkcg_1T8@0Sg_0cW>0Sg_0TYB0U:D0Tic0T8@13g_248@1DHa1T8@0Sg_0SW>0S6<1Re[1bU:
0RDY22480RDY0T8@0VLi0WNm0U[F0cF]0RDY0Re[0S6<0SF]0SW>13g_13W>0SF]1cW>23F]0SW>0Woo
00<007ooOol02goo00<007ooOol01Goo1@0017oo0P001Goo0P005goo7`0017oo0P000Woo9`000Woo
00<007ooOol01Woo0007Ool01000Oolmkcg_1T8@0Sg_0cW>0Sg_0TYB0U:D0Tic0T8@13g_248@1DHa
1T8@0Sg_0SW>0S6<1Re[1bU:0RDY22480RDY0T8@0VLi0WNm0U[F0cF]0RDY0Re[0S6<0SF]0SW>13g_
13W>0SF]1cW>23F]0SW>0Woo00<007ooOol02goo00@007oo000000Aoo`L0009oo`8000EoocX0009o
o`80009oobL0009oo`03001oogoo00Ioo`001goo00@007oo?Nlmk`I2408mk`<icP8mk`9:DP9BU09>
L`9240@mk`Q240E6<@I2408mk`8icP8aS0H]J`LYBP8U:@PQ208U:@92409W>@9g_@9JeP<e[@8U:@8]
J`8aS08e[@8icP@mk`@icP8e[@LicPPe[@8icP9oo`03001oogoo00]oo`04001oo`000004Ool70002
Ool20005Oolj0002Ool20002OolW0002Ool00`00Oomoo`06Ool000Moo`04001oocW>>Lh6?Nl2>Lh3
=Jd2>Lh2BU82DY@2CW<2?Nl6=Jd4<H`5;F/2<H`4;F/4<H`2;F/2:DX29BT28@P27>L58@P49BT48@P2
6<H45:D2;F/2E[D2JeX2E[D3<H`29BT2:DX2<H`4=Jd2>Lh4=Jd6<H`3=Jd4<H`4;F/2<H`2=Jd2Ool0
0`00Oomoo`0;Ool00`00Ool0000<0002Ool20002Oolm0006OolW0002Ool00`00Oomoo`06Ool000Mo
o`04001oocW>>Lh6?Nl2>Lh3=Jd2>Lh2BU82DY@2CW<2?Nl6=Jd4<H`5;F/2<H`4;F/4<H`2;F/2:DX2
9BT28@P27>L58@P49BT48@P26<H45:D2;F/2E[D2JeX2E[D3<H`29BT2:DX2<H`4=Jd2>Lh4=Jd6<H`3
=Jd4<H`4;F/2<H`2=Jd2Ool00`00Oomoo`0;Ool00`00Ool0000<0002Ool20002Oolm0006OolW0002
Ool00`00Oomoo`06Ool000Moo`04001oocF]=Jd6>Lh7=Jd2AS42DY@2BU82=Jd2:DX69BT48@P39BT2
;F/2<H`2;F/2:DX29BT68@P27>L28@P2:DX3<H`2=Jd4>Lh2<H`29BT25:D236<28@P2AS42G_L2CW<3
;F/27>L28@P2:DX2;F/6<H`=;F/8:DX2;F/2Ool00`00Oomoo`0;Ool00`00Ool0000<0006OolB0006
Ool?000?Ool90004OolW0002Ool00`00Oomoo`06Ool000Moo`04001oocF]=Jd6>Lh7=Jd2AS42DY@2
BU82=Jd2:DX69BT48@P39BT2;F/2<H`2;F/2:DX29BT68@P27>L28@P2:DX3<H`2=Jd4>Lh2<H`29BT2
5:D236<28@P2AS42G_L2CW<3;F/27>L28@P2:DX2;F/6<H`=;F/8:DX2;F/2Ool00`00Oomoo`0;Ool0
0`00Ool0000<0006OolB0006Ool?000?Ool90004OolW0002Ool00`00Oomoo`06Ool000Moo`04001o
obe[;F/2<H`6=Jd3<H`2=Jd2@Q02CW<2BU82=Jd4:DX4;F/2:DX2;F/3=Jd2@Q02AS42@Q02<H`28@P4
6<H28@P2;F/2>Lh2@Q03CW<2DY@4E[D2DY@2@Q029BT25:D26<H2?Nl2E[D2CW<3;F/26<H27>L29BT2
:DX>;F/=<H`2;F/2Ool00`00Oomoo`0;Ool00`00Ool0000>0004Ool5000?Ool20002Ool;0006Ool;
0004Ool70004OolD000EOol00`00Oomoo`06Ool000Moo`04001oobe[;F/2<H`6=Jd3<H`2=Jd2@Q02
CW<2BU82=Jd4:DX4;F/2:DX2;F/3=Jd2@Q02AS42@Q02<H`28@P46<H28@P2;F/2>Lh2@Q03CW<2DY@4
E[D2DY@2@Q029BT25:D26<H2?Nl2E[D2CW<3;F/26<H27>L29BT2:DX>;F/=<H`2;F/2Ool00`00Oomo
o`0;Ool00`00Ool0000>0004Ool5000?Ool20002Ool;0006Ool;0004Ool70004OolD000EOol00`00
Oomoo`06Ool000Moo`03001oobe[00D]J`@aS0<]J`8aS08mk`9:DP96<@8icP8e[@9240A>L`96<@92
40=:DP9BU09F]@96<@8]J`8HaP8DY@8Q208aS096<@9BU09JePENm`IS609JeP92408U:@8Li`8e[@9F
]@9BU0<icP8U:@8YBP8aS08e[@HicP@mk`9240E6<@A:DPA>L`96<@8e[@9oo`03001oogoo00]oo`03
001oo`0000`000Ioo`<000Aoo`d000Aoo`T000Aooa40009oo`L001Yoo`l000Aoo`03001oogoo00Io
o`001goo00<007oo;F/01Be[136<0be[0S6<0Sg_0TYB0THa0SW>0SF]0T8@14ic0THa0T8@0dYB0U:D
0UJe0THa0Re[0QS60QBU0R480S6<0THa0U:D0U[F1Ekg1V<H0U[F0T8@0RDY0QcW0SF]0UJe0U:D0cW>
0RDY0RU:0S6<0SF]1SW>13g_0T8@1DHa14YB14ic0THa0SF]0Woo00<007ooOol02goo00<007oo0000
30001Woo0`0017oo3@0017oo2@0017oo4@000Woo1`006Woo3`0017oo00<007ooOol01Woo0007Ool0
1000OolaS36<0RU:12e[0S6<0be[0S6<0Sg_0TYB0THa0SW>0Sg_0U:D16<H0U[F0U:D0dic15:D0Sg_
0RDY0QBU0QcW0SF]0TYB0U[F16<H0ekg15[F0Ukg16<H0U:D0SF]0R480SF]0UJe0V<H0e:D14Ha0Tic
15:D25Je0U[F1ekg1V<H0U[F0THa0Woo00<007ooOol02goo00<007oo000030001Woo0`0017oo3@00
17oo2@0017oo4@000Woo1`006Woo3`0017oo00<007ooOol01Woo0007Ool01000OolaS36<0RU:12e[
0S6<0be[0S6<0Sg_0TYB0THa0SW>0Sg_0U:D16<H0U[F0U:D0dic15:D0Sg_0RDY0QBU0QcW0SF]0TYB
0U[F16<H0ekg15[F0Ukg16<H0U:D0SF]0R480SF]0UJe0V<H0e:D14Ha0Tic15:D25Je0U[F1ekg1V<H
0U[F0THa0Woo00<007ooOol02goo00<007oo00001@002Goo0P000Woo1@000Woo20001goo2@0017oo
4`001Goo10000Woo70003goo00<007ooOol01Woo0007Ool01000Oolmkcg_1SW>1Cg_0T8@0TYB0Tic
0THa0SF]0SW>0U:D16<H0U[F0U:D1DYB0THa0SF]0R480QcW0S6<0Tic0Ukg16<H0U[F0eJe1U:D0U[F
0Ukg0U[F0T8@0RU:0S6<0UJe0V]J0f<H0UJe0U[F2Ukg2e[F1UJe0U[F0UJe0Tic0Woo00<007ooOol0
2goo00<007oo00001@002Goo0P000Woo1@000Woo20001goo2@0017oo4`001Goo10000Woo70003goo
00<007ooOol01Woo0007Ool01000Oolmkcg_1SW>1Cg_0T8@0TYB0Tic0THa0SF]0SW>0U:D16<H0U[F
0U:D1DYB0THa0SF]0R480QcW0S6<0Tic0Ukg16<H0U[F0eJe1U:D0U[F0Ukg0U[F0T8@0RU:0S6<0UJe
0V]J0f<H0UJe0U[F2Ukg2e[F1UJe0U[F0UJe0Tic0Woo00<007ooOol02goo00<007ooOol027oo2000
0Woo1@0017oo10001Goo2P001Goo5`000goo100087oo2@0017oo00<007ooOol01Woo0007Ool01000
OomBU5:D1Tic1e:D15Je0TYB0SF]0S6<0T8@0U[F0Ukg0U[F0Tic0d8@0Sg_0SF]0RU:0R480Re[0TYB
0Ukg16<H0U[F0UJe2E:D0UJe0Ukg0U[F0TYB0Re[0S6<0Tic0U[F0e:D0T8@0THa2TYB0THa1T8@0cg_
0SW>13F]0SW>0THa0U:D0Woo00<007ooOol02goo00<007ooOol027oo20000Woo1@0017oo10001Goo
2P001Goo5`000goo100087oo2@0017oo00<007ooOol01Woo0007Ool01000OomBU5:D1Tic1e:D15Je
0TYB0SF]0S6<0T8@0U[F0Ukg0U[F0Tic0d8@0Sg_0SF]0RU:0R480Re[0TYB0Ukg16<H0U[F0UJe2E:D
0UJe0Ukg0U[F0TYB0Re[0S6<0Tic0U[F0e:D0T8@0THa2TYB0THa1T8@0cg_0SW>13F]0SW>0THa0U:D
0Woo00<007ooOol02goo00<007oo000040000Woo1`000Woo10000Woo2`001Goo6@000goo100017oo
9@0017oo00<007ooOol01Woo0007Ool00`00OomJeP03F]H4E[D5DY@2CW<2DY@2E[D2BU82<H`2:DX2
>Lh2E[D2IcT2HaP2CW<3>Lh2:DX48@P2;F/2AS42F]H2IcT2HaP2G_L2F]H2E[D9DY@2E[D2G_L2HaP2
DY@2=Jd2<H`2@Q02AS43=Jd49BT2;F/:<H`9;F/2:DX29BT28@P2:DX2?Nl2DY@2Ool00`00Oomoo`0;
Ool00`00Ool0000@0002Ool70002Ool40002Ool;0005OolI0003Ool40004OolU0004Ool00`00Oomo
o`06Ool000Moo`03001ooe[F00=JePAF]@EBU09>L`9BU09F]@9:DP8aS08YBP8icP9F]@9W>@9S609>
L`<icP8YBP@Q208]J`96<@9JeP9W>@9S609Nm`9JeP9F]@UBU09F]@9Nm`9S609BU08e[@8aS0924096
<@<e[@@U:@8]J`XaS0T]J`8YBP8U:@8Q208YBP8mk`9BU09oo`03001oogoo00]oo`03001oogoo019o
o`L0009oo`8000Aoo`T000Aoo`T0015oo`8000Eoo`@0009oobD000Aoo`03001oogoo00Ioo`001goo
00@007ooCW=>L`9:DP96<@A240Dmk`92409>L`9:DP8e[@8U:@8e[@9BU09W>@9Nm`96<@<YBP8DY@8@
Q08Q208mk`9JePAW>@9S609JeP9BU09:DP=6<@A24096<@9>L`9Nm`9[FP9Nm`92408aS08icP8mk`<]
J`@Li`8U:@8YBPX]J`@aS0D]J`8YBP8U:@8]J`8mk`9>L`9oo`03001oogoo00]oo`03001oogoo019o
o`L0009oo`8000Aoo`T000Aoo`T0015oo`8000Eoo`@0009oobD000Aoo`03001oogoo00Ioo`001goo
00@007ooCW=>L`9:DP96<@A240Dmk`92409>L`9:DP8e[@8U:@8e[@9BU09W>@9Nm`96<@<YBP8DY@8@
Q08Q208mk`9JePAW>@9S609JeP9BU09:DP=6<@A24096<@9>L`9Nm`9[FP9Nm`92408aS08icP8mk`<]
J`@Li`8U:@8YBPX]J`@aS0D]J`8YBP8U:@8]J`8mk`9>L`9oo`03001oogoo00]oo`03001oo`0000h0
00Aoo`L000Ioo`/0009oo`L000Ioo`d0009oo`D0009oo`@0009oobD000Aoo`03001oogoo00Ioo`00
1goo00@007oo?Nlmk`8aS0@]J`8aS0D]J`8icPA:DP8icP8U:@8]J`92409BU09>L`8e[@<Li`8<H`8@
Q08]J`9>L`9W>@9[FP9W>@9JeP9>L`8mk`8aS0<U:@@Q208YBP8icP9F]@9_N`9W>@9:DP8e[@8icP8m
k`<]J`8Q208U:@8]J`8aS0He[@PicPDe[@@]J`8e[@92409:DP9oo`03001oogoo00]oo`03001oo`00
00h000Aoo`L000Ioo`/0009oo`L000Ioo`d0009oo`D0009oo`@0009oobD000Aoo`03001oogoo00Io
o`001goo00@007oo?Nlmk`8aS0@]J`8aS0D]J`8icPA:DP8icP8U:@8]J`92409BU09>L`8e[@<Li`8<
H`8@Q08]J`9>L`9W>@9[FP9W>@9JeP9>L`8mk`8aS0<U:@@Q208YBP8icP9F]@9_N`9W>@9:DP8e[@8i
cP8mk`<]J`8Q208U:@8]J`8aS0He[@PicPDe[@@]J`8e[@92409:DP9oo`03001oogoo00]oo`03001o
o`0000h000Aoo`T0009oo`/000Aoo`D000Aooa4000Aoo`<0009oo`@0009oo`l000Moo`l000Aoo`03
001oogoo00Ioo`001goo00@007oo>LhicP8]J`@YBPL]J`8e[@9:DP9>L`8mk`8YBP8U:@8e[@8mk`8i
cP8]J`<HaP8@Q08Q2092409S609_N`9W>@9F]@96<@8e[@8U:@8HaP<@Q08<H`88@P8<H`8U:@9:DP9[
FP9_N`9BU0Hmk`<e[@@YBP8aS0@icP`mk`DicP@aS08icPA:DP9oo`03001oogoo00]oo`03001oo`00
00h000Aoo`T0009oo`/000Aoo`D000Aooa4000Aoo`<0009oo`@0009oo`l000Moo`l000Aoo`03001o
ogoo00Ioo`001goo00@007oo>LhicP8]J`@YBPL]J`8e[@9:DP9>L`8mk`8YBP8U:@8e[@8mk`8icP8]
J`<HaP8@Q08Q2092409S609_N`9W>@9F]@96<@8e[@8U:@8HaP<@Q08<H`88@P8<H`8U:@9:DP9[FP9_
N`9BU0Hmk`<e[@@YBP8aS0@icP`mk`DicP@aS08icPA:DP9oo`03001oogoo00]oo`03001oo`0000h0
00Mooa<0009oo`@000EooaD0009oo`<000Qoo`d000Uoo`l000Aoo`03001oogoo00Ioo`001goo00@0
07oo?Nlmk`8aS08]J`TaS08icP9:DP9BU092408]J`8YBP8]J`8e[@8aS08YBPDLi`8aS09F]@A_N`9J
eP92408]J`8Q20@HaP<DY@8@Q088@P848@8DY@8icP9S609cW09JePI240<e[@8YBP8]J`8e[@8icPhm
k`DicP@aS08mk`A>L`9oo`03001oogoo00]oo`03001oo`0000h000Mooa<0009oo`@000EooaD0009o
o`<000Qoo`d000Uoo`l000Aoo`03001oogoo00Ioo`001goo00@007oo?Nlmk`8aS08]J`TaS08icP9:
DP9BU092408]J`8YBP8]J`8e[@8aS08YBPDLi`8aS09F]@A_N`9JeP92408]J`8Q20@HaP<DY@8@Q088
@P848@8DY@8icP9S609cW09JePI240<e[@8YBP8]J`8e[@8icPhmk`DicP@aS08mk`A>L`9oo`03001o
ogoo00]oo`03001oo`0000h000Mooa<0009oo`@000EooaD0009oo`<000Qoo`d000Uoo`l000Aoo`03
001oogoo00Ioo`001goo00@007oo?Nlmk`8aS08]J`TaS08icP9:DP9BU092408]J`8YBP8]J`8e[@8a
S08YBPDLi`8aS09F]@A_N`9JeP92408]J`8Q20@HaP<DY@8@Q088@P848@8DY@8icP9S609cW09JePI2
40<e[@8YBP8]J`8e[@8icPhmk`DicP@aS08mk`A>L`9oo`03001oogoo00]oo`03001oo`0000h0009o
o`8000=ooa4000Aoo`8000EooaL0009oo`T0009oo`d000Mooa4000Aoo`03001oogoo00Ioo`001goo
00@007oo@Q12408e[@8aS08e[@8icPDe[@8mk`9>L`9F]@96<@8e[@8]J`8aS08e[@8aS08YBP<Q208Y
BP96<@9W>@9cW09S6096<@8]J`8Li`8HaP@Li`<Q208Li`8@Q088@P8<H`8]J`9JeP9_N`9Nm`96<@A2
40<e[@@]J`8e[@8icPXmk`LicP8e[@@aS08mk`9>L`9BU09oo`03001oogoo00]oo`03001oo`0000h0
009oo`8000=ooa4000Aoo`8000EooaL0009oo`T0009oo`d000Mooa4000Aoo`03001oogoo00Ioo`00
1goo00@007oo@Q12408e[@8aS08e[@8icPDe[@8mk`9>L`9F]@96<@8e[@8]J`8aS08e[@8aS08YBP<Q
208YBP96<@9W>@9cW09S6096<@8]J`8Li`8HaP@Li`<Q208Li`8@Q088@P8<H`8]J`9JeP9_N`9Nm`96
<@A240<e[@@]J`8e[@8icPXmk`LicP8e[@@aS08mk`9>L`9BU09oo`03001oogoo00]oo`03001oo`00
00`000Aoo`8000=ooa40009oo`@0009ooaX0009oo`<000QoobD000Aoo`03001oogoo00Ioo`001goo
00@007oo@Q1240@e[@LicP8e[@8mk`9>L`9F]@9:DP8e[@8aS08e[@8icP8e[@8YBP<U:@8aS09F]@9c
W09_N`9BU08aS08Li`8HaP8Li`8Q208U:@<Q208Li`8DY@8<H`8DY@8aS09F]@9W>@9F]@I240<e[@@]
J`8e[@8icPPmk`TicP8e[@@aS08icP9>L`9BU09oo`03001oogoo00]oo`03001oo`0000`000Aoo`80
00=ooa40009oo`@0009ooaX0009oo`<000QoobD000Aoo`03001oogoo00Ioo`001goo00@007oo@Q12
40@e[@LicP8e[@8mk`9>L`9F]@9:DP8e[@8aS08e[@8icP8e[@8YBP<U:@8aS09F]@9cW09_N`9BU08a
S08Li`8HaP8Li`8Q208U:@<Q208Li`8DY@8<H`8DY@8aS09F]@9W>@9F]@I240<e[@@]J`8e[@8icPPm
k`TicP8e[@@aS08icP9>L`9BU09oo`03001oogoo00]oo`03001oo`0000`000Aoo`8000=ooa40009o
o`8000AooaP000Uoo`@0009oobD000Aoo`03001oogoo00Ioo`001goo00@007oo@Q12408e[@8aS08e
[@DicP8e[@8mk`9>L`9F]@96<@8e[@8aS0@icP8e[@8YBP<U:@8icP9Nm`9g_@9W>@8mk`8Q208HaP8L
i`@U:@8Q20LLi`8Q208YBP8mk`9JeP9Nm`9:DP8icP8mk`9240<e[@@]J`8e[@8icP8mk``icPDe[@@a
S08icP9>L`9BU09oo`03001oogoo00]oo`03001oo`0000`000Aoo`8000=ooa40009oo`8000AooaP0
00Uoo`@0009oobD000Aoo`03001oogoo00Ioo`001goo00@007oo@Q12408e[@8aS08e[@DicP8e[@8m
k`9>L`9F]@96<@8e[@8aS0@icP8e[@8YBP<U:@8icP9Nm`9g_@9W>@8mk`8Q208HaP8Li`@U:@8Q20LL
i`8Q208YBP8mk`9JeP9Nm`9:DP8icP8mk`9240<e[@@]J`8e[@8icP8mk``icPDe[@@aS08icP9>L`9B
U09oo`03001oogoo00]oo`03001oo`0000h0009oo`8000=ooa40009oo`80009ooaH000Ioo`8000=o
o`H0009oobD000Aoo`03001oogoo00Ioo`001goo00@007oo@Q1240@aS0Te[@8icP9:DP9BU096<@8e
[@8aS08e[@@icP8YBP<U:@8icP9S609g_@9Nm`8aS0@DY@8Q20@U:@DQ208U:@8aS08mk`9:DP9F]@9S
609F]@8icP8]J`8icP9240<icP@]J`8e[A<icP8e[@@aS08icP9>L`9BU09oo`03001oogoo00]oo`03
001oo`0000h0009oo`8000=ooa40009oo`80009ooaH000Ioo`8000=oo`H0009oobD000Aoo`03001o
ogoo00Ioo`001goo00@007oo@Q1240@aS0Te[@8icP9:DP9BU096<@8e[@8aS08e[@@icP8YBP<U:@8i
cP9S609g_@9Nm`8aS0@DY@8Q20@U:@DQ208U:@8aS08mk`9:DP9F]@9S609F]@8icP8]J`8icP9240<i
cP@]J`8e[A<icP8e[@@aS08icP9>L`9BU09oo`03001oogoo00]oo`03001oo`0000h0009oo`8000=o
o`l000Aoo`80009ooa8000Ioo`H000=oo`H0009oobD000Aoo`03001oogoo00Ioo`001goo00@007oo
@Q12408aS08]J`Le[@8aS08icP9:DP9BU096<@8e[@8aS08e[@8icP8e[@8YBP<U:@8mk`9W>@9kgP9N
m`8]J`8@Q08DY@8Li`@Q208U:@<aS092409BU09JeP9S609[FP9W>@9BU08aS08U:@8e[@9240<icP@]
J`8e[@XicP@mk`DicP8e[@@aS08icP9>L`9BU09oo`03001oogoo00]oo`03001oo`0000h0009oo`80
00=oo`l000Aoo`80009ooa8000Ioo`H000=oo`H0009oobD000Aoo`03001oogoo00Ioo`001goo00@0
07oo@Q12408aS08]J`Le[@8aS08icP9:DP9BU096<@8e[@8aS08e[@8icP8e[@8YBP<U:@8mk`9W>@9k
gP9Nm`8]J`8@Q08DY@8Li`@Q208U:@<aS092409BU09JeP9S609[FP9W>@9BU08aS08U:@8e[@9240<i
cP@]J`8e[@XicP@mk`DicP8e[@@aS08icP9>L`9BU09oo`03001oogoo00]oo`03001oo`0000h0009o
o`8000=oo`l000Aoo`80009oo`l000Eoo`X000=oo`H0009ooa4000Moo`d000Aoo`03001oogoo00Io
o`001goo00@007ooAS56<@8aS08]J`Te[@8icP9:DP9BU096<@8e[@8aS08e[@8icP8e[@8U:@<Q208m
k`9[FP9oo`9Nm`8]J`@@Q08HaP8Li`8U:@8e[@=:DP9JeP9W>@9[FPA_N`9[FP9BU08aS08U:@8e[@92
40<icP8]J`8aS08e[@8icPhmk`DicP@aS08icP9>L`9F]@9oo`03001oogoo00]oo`03001oo`0000h0
009oo`8000=oo`l000Aoo`80009oo`l000Eoo`X000=oo`H0009ooa4000Moo`d000Aoo`03001oogoo
00Ioo`001goo00@007ooAS56<@8aS08]J`Te[@8icP9:DP9BU096<@8e[@8aS08e[@8icP8e[@8U:@<Q
208mk`9[FP9oo`9Nm`8]J`@@Q08HaP8Li`8U:@8e[@=:DP9JeP9W>@9[FPA_N`9[FP9BU08aS08U:@8e
[@9240<icP8]J`8aS08e[@8icPhmk`DicP@aS08icP9>L`9F]@9oo`03001oogoo00]oo`03001oo`00
00h0009oo`8000=oo`l000Aoo`80009oo`l000Eoo`X000=oo`H0009ooa4000Moo`d000Aoo`03001o
ogoo00Ioo`001goo00@007ooAS56<@8aS08]J`8e[@8icPDe[@8mk`9>L`9F]@9:DP8icP8e[@8icP8m
k`8e[@8U:@<Q208mk`9[FP9oo`9S608aS08@Q08<H`8DY@8Li`8]J`9:DP=Nm`a[FP9JeP8mk`8YBP8e
[@9240<icP@aS08icQ<mk`8icP@aS08icP9BU09F]@9oo`03001oogoo00]oo`03001oo`0000h0009o
o`8000=ooa40009oo`80009oo`d000Eoo``000Eoo`@0009oo`/000Uoo`8000Aoo`/000Aoo`03001o
ogoo00Ioo`001goo00@007ooAS56<@8aS08]J`8e[@8icPDe[@8mk`9>L`9F]@9:DP8icP8e[@8icP8m
k`8e[@8U:@<Q208mk`9[FP9oo`9S608aS08@Q08<H`8DY@8Li`8]J`9:DP=Nm`a[FP9JeP8mk`8YBP8e
[@9240<icP@aS08icQ<mk`8icP@aS08icP9BU09F]@9oo`03001oogoo00]oo`03001oo`0000h0009o
o`8000=ooa40009oo`80009oo`d000Eoo``000Eoo`@0009oo`/000Uoo`8000Aoo`/000Aoo`03001o
ogoo00Ioo`001goo00@007ooBU9:DP8e[@8aS08e[@DicP8e[@8mk`9>L`9F]@9:DP8icP8e[@8icP8m
k`8e[@8YBP<Q208icP9W>@9oo`9W>@8e[@8@Q088@P8@Q08U:@92409JePM[FP9S609Nm`9S609W>@9S
609:DP@e[@9240<icP@aS08icQ<mk`8icP@aS08mk`9BU09JeP9oo`03001oogoo00]oo`03001oo`00
00`000Aoo`8000=ooa40009oo`80009oo`/000Aooa80009oo`@0009oo`T000Aoo`/0009oo`/000Ao
o`03001oogoo00Ioo`001goo00@007ooBU9:DP8e[@8aS08e[@DicP8e[@8mk`9>L`9F]@9:DP8icP8e
[@8icP8mk`8e[@8YBP<Q208icP9W>@9oo`9W>@8e[@8@Q088@P8@Q08U:@92409JePM[FP9S609Nm`9S
609W>@9S609:DP@e[@9240<icP@aS08icQ<mk`8icP@aS08mk`9BU09JeP9oo`03001oogoo00]oo`03
001oo`0000`000Aoo`8000=ooa40009oo`80009oo`/000Aooa80009oo`@0009oo`T000Aoo`/0009o
o`/000Aoo`03001oogoo00Ioo`001goo00@007ooBU9:DP8e[@8aS08e[@LicP8mk`9>L`9F]@9:DP8i
cP8aS0@icP8e[@8U:@<Li`8aS09S609oo`9cW096<@8Li`88@P8DY@8aS09BU0E[FP9S609JeP9>L`A6
<@9BU09Nm`9BU08mk`8icP9240<icP@aS08icQ<mk`8icP@aS08mk`9BU09JeP9oo`03001oogoo00]o
o`03001oo`0000`0009oo`@000=ooa40009oo`8000Aoo`T0009oo`L0015oo`80009oo`T0015oo`/0
00Aoo`03001oogoo00Ioo`001goo00@007ooBU9:DP8e[@8aS08e[@LicP8mk`9>L`9F]@9:DP8icP8a
S0@icP8e[@8U:@<Li`8aS09S609oo`9cW096<@8Li`88@P8DY@8aS09BU0E[FP9S609JeP9>L`A6<@9B
U09Nm`9BU08mk`8icP9240<icP@aS08icQ<mk`8icP@aS08mk`9BU09JeP9oo`03001oogoo00]oo`03
001oo`0000`0009oo`@000=ooa40009oo`8000Aoo`T0009oo`L0015oo`80009oo`T0015oo`/000Ao
o`03001oogoo00Ioo`001goo00@007ooBU9:DP8e[@8]J`8e[@LicP8mk`9>L`9BU09:DP8icP8e[@@i
cP8aS08U:@<HaP8]J`9F]@AkgP9Nm`8aS08HaP8Li`92409S609[FP=Nm`9>L`8mk`8]J`@Q208e[@AB
U092408mk`9240<icP@]J`8e[A0mk`DicP8aS08]J`8icP9BU09JeP9oo`03001oogoo00]oo`03001o
o`0000`000Aoo`8000=ooa40009oo`@0009oo`L000Aoo`8000Moo`P000=oo`80009oo`80009oo`/0
009oo`L000Aoo`d000Aoo`03001oogoo00Ioo`001goo00@007ooBU9:DP8e[@8]J`8e[@LicP8mk`9>
L`9BU09:DP8icP8e[@@icP8aS08U:@<HaP8]J`9F]@AkgP9Nm`8aS08HaP8Li`92409S609[FP=Nm`9>
L`8mk`8]J`@Q208e[@ABU092408mk`9240<icP@]J`8e[A0mk`DicP8aS08]J`8icP9BU09JeP9oo`03
001oogoo00]oo`03001oo`0000`000Aoo`8000=ooa40009oo`@0009oo`L000Aoo`8000Moo`P000=o
o`80009oo`80009oo`/0009oo`L000Aoo`d000Aoo`03001oogoo00Ioo`001goo00@007ooAS56<@8a
S08]J`8e[@DicP8e[@8mk`9:DP9BU096<@8icP8e[@@icP8aS08Q20<DY@8Q209:DP9_N`9g_@9Nm`8i
cP8Q208YBP9>L`9[FP9S60=6<@8]J`8Q208DY@88@P8<H`8U:@9:DP9BU096<@8mk`9240<icP@]J`8e
[@8icP8mk`@icPHmk`DicP8e[@8aS08]J`8icP9>L`9F]@9oo`03001oogoo00]oo`03001oo`0000h0
009oo`8000=ooa4000Aoo`80009oo`L0009oo`8000Eoo``000=oo`8000IoobD000Aoo`03001oogoo
00Ioo`001goo00@007ooAS56<@8aS08]J`8e[@DicP8e[@8mk`9:DP9BU096<@8icP8e[@@icP8aS08Q
20<DY@8Q209:DP9_N`9g_@9Nm`8icP8Q208YBP9>L`9[FP9S60=6<@8]J`8Q208DY@88@P8<H`8U:@9:
DP9BU096<@8mk`9240<icP@]J`8e[@8icP8mk`@icPHmk`DicP8e[@8aS08]J`8icP9>L`9F]@9oo`03
001oogoo00]oo`03001oo`0000h0009oo`8000=ooa4000Aoo`80009oo`L0009oo`8000Eoo``000=o
o`8000IoobD000Aoo`03001oogoo00Ioo`001goo00@007ooAS56<@8aS08]J`8e[@DicP8e[@8mk`9:
DP9BU096<@@e[@@icP8aS08Li`<@Q08Li`8mk`9JeP9Nm`9:DP8YBP8HaP8]J`9BU09S609:DP<YBP8D
Y@8@Q088@P848@8<H`8YBP9>L`9JeP9:DPA240<icP@]J`8e[@HicPHmk`LicP8e[@8aS08]J`8e[@9>
L`9F]@9oo`03001oogoo00]oo`03001oo`0000h0009oo`8000=ooa<000Ioo`L000Ioo`l000=oo`H0
009oobD000Aoo`03001oogoo00Ioo`001goo00@007ooAS56<@8aS08]J`8e[@DicP8e[@8mk`9:DP9B
U096<@@e[@@icP8aS08Li`<@Q08Li`8mk`9JeP9Nm`9:DP8YBP8HaP8]J`9BU09S609:DP<YBP8DY@8@
Q088@P848@8<H`8YBP9>L`9JeP9:DPA240<icP@]J`8e[@HicPHmk`LicP8e[@8aS08]J`8e[@9>L`9F
]@9oo`03001oogoo00]oo`03001oo`0000h0009oo`8000=ooa<000Ioo`L000Ioo`l000=oo`H0009o
obD000Aoo`03001oogoo00Ioo`001goo00@007ooAS56<@8aS08]J`8e[@DicP8e[@8mk`9:DP9BU096
<@@e[@@icP8aS08Li`<@Q08Li`8mk`9JeP9Nm`9:DP8YBP8HaP8]J`9BU09S609:DP<YBP8DY@8@Q088
@P848@8<H`8YBP9>L`9JeP9:DPA240<icP@]J`8e[@HicPHmk`LicP8e[@8aS08]J`8e[@9>L`9F]@9o
o`03001oogoo00]oo`03001oo`0000h0009oo`8000=ooa<000Ioo`L000Ioo`l000=oo`H0009oobD0
00Aoo`03001oogoo00Ioo`001goo00@007ooAS56<@8aS08]J`8e[@DicP8e[@8mk`9:DP9BU096<@8e
[@8aS0@e[@8]J`8Li`<DY@8Li`8icP9>L`9:DP8]J`8@Q08<H`8YBP9BU09F]@8e[@<@Q088@PH<H`8L
i`8mk`ANm`9:DPA240<mk`@aS08e[@@icPXmk`DicP8e[@8aS08]J`8e[@9>L`9JeP9oo`03001oogoo
00]oo`03001oo`0000h0009oo`8000=ooa<000Aoo`T000Aoo`l000Eoo`H0009ooa4000Eoo`l000Ao
o`03001oogoo00Ioo`001goo00@007ooAS56<@8aS08]J`8e[@DicP8e[@8mk`9:DP9BU096<@8e[@8a
S0@e[@8]J`8Li`<DY@8Li`8icP9>L`9:DP8]J`8@Q08<H`8YBP9BU09F]@8e[@<@Q088@PH<H`8Li`8m
k`ANm`9:DPA240<mk`@aS08e[@@icPXmk`DicP8e[@8aS08]J`8e[@9>L`9JeP9oo`03001oogoo00]o
o`03001oo`0000h0009oo`8000=ooa<000Aoo`T000Aoo`l000Eoo`H0009ooa4000Eoo`l000Aoo`03
001oogoo00Ioo`001goo00@007ooBU9:DP8aS08]J`8aS08icPDe[@8mk`9:DP9BU096<@8e[@HaS08Y
BPDU:@8e[@9:DP9JeP9>L`8]J`8<H`848@8U:@A>L`8YBP<8@P848@8<H`8HaP8Q208icP9F]@9[FP9N
m`96<@8mk`9240<mk`@aS08e[@@icPXmk`DicP8e[@8aS08]J`8e[@9BU09JeP9oo`03001oogoo00]o
o`03001oo`0000`000Aoo`8000=ooa4000Ioo`T000Aoo`l0009oo`<000Yoo`d000Moo`l000Aoo`03
001oogoo00Ioo`001goo00@007ooBU9:DP8aS08]J`8aS08icPDe[@8mk`9:DP9BU096<@8e[@HaS08Y
BPDU:@8e[@9:DP9JeP9>L`8]J`8<H`848@8U:@A>L`8YBP<8@P848@8<H`8HaP8Q208icP9F]@9[FP9N
m`96<@8mk`9240<mk`@aS08e[@@icPXmk`DicP8e[@8aS08]J`8e[@9BU09JeP9oo`03001oogoo00]o
o`03001oo`0000`000Aoo`8000=ooa4000Ioo`T000Aoo`l0009oo`<000Yoo`d000Moo`l000Aoo`03
001oogoo00Ioo`001goo00@007ooBU9:DP8aS08]J`8aS0DicP8e[@8mk`9:DP9BU096<@8e[@8aS0H]
J`8e[@=2409BU09S609_N`9W>@96<@8Li`8<H`8U:@A>L`8]J`<@Q08<H`8Li`8]J`8mk`9F]@A[FP9>
L`@e[@9240<mk`8e[@8aS08e[@@icPlmk`8icP8aS08]J`8e[@9BU09JeP9oo`03001oogoo00]oo`03
001oo`0000`0009oo`@000=oo``000Moo`8000Aoo`L000Aoo`/000]oo`@000Aooa8000Aoo`d000Ao
o`03001oogoo00Ioo`001goo00@007ooBU9:DP8aS08]J`8aS0DicP8e[@8mk`9:DP9BU096<@8e[@8a
S0H]J`8e[@=2409BU09S609_N`9W>@96<@8Li`8<H`8U:@A>L`8]J`<@Q08<H`8Li`8]J`8mk`9F]@A[
FP9>L`@e[@9240<mk`8e[@8aS08e[@@icPlmk`8icP8aS08]J`8e[@9BU09JeP9oo`03001oogoo00]o
o`03001oo`0000`0009oo`@000=oo``000Moo`8000Aoo`L000Aoo`/000]oo`@000Aooa8000Aoo`d0
00Aoo`03001oogoo00Ioo`001goo00@007ooAS56<@8aS08]J`8e[@LicP8mk`9:DP9>L`96<@8e[@H]
J`8icP9>L`=Nm`9[FP9_N`9g_@9cW09F]@8]J`8DY@8YBP9>L`9JeP96<@<]J`8YBP8e[@9:DP9JeP9[
FP9_N`9Nm`8icP8U:@8aS09240<mk`8e[@8aS08e[@@icPlmk`8icP8aS08]J`8e[@9BU09JeP9oo`03
001oogoo00]oo`03001oo`0000`0009oo`@000=oo`X000Eoo`P0009oo`L000Ioo`L000Aoo`@000=o
o`H000Aooa@000Aoo`/000Aoo`03001oogoo00Ioo`001goo00@007ooAS56<@8aS08]J`8e[@LicP8m
k`9:DP9>L`96<@8e[@H]J`8icP9>L`=Nm`9[FP9_N`9g_@9cW09F]@8]J`8DY@8YBP9>L`9JeP96<@<]
J`8YBP8e[@9:DP9JeP9[FP9_N`9Nm`8icP8U:@8aS09240<mk`8e[@8aS08e[@@icPlmk`8icP8aS08]
J`8e[@9BU09JeP9oo`03001oogoo00]oo`03001oo`0000`0009oo`@000=oo`X000Eoo`P0009oo`L0
00Ioo`L000Aoo`@000=oo`H000Aooa@000Aoo`/000Aoo`03001oogoo00Ioo`001goo00@007ooAS56
<@8aS08]J`8e[@Dmk`8icP8mk`9:DP9>L`92408aS0@YBP8aS09:DP9W>@=_N`9W>@9S609W>@9[FP9J
eP8aS08HaP8U:@9>L`9S609Nm`=>L`9:DP9BU09Nm`9[FP9_N`9S6096<@8YBP8Li`8]J`E240He[@@i
cPlmk`8icP8aS08]J`8e[@9BU09JeP9oo`03001oogoo00]oo`03001oo`0000`0009oo`@000=oo`P0
00Aoo`<000Ioo`80009oo`L0009oo`8000]oo`@000Eoo`H000Aooa@000Ioo`T000Aoo`03001oogoo
00Ioo`001goo00@007ooAS56<@8aS08]J`8e[@Dmk`8icP8mk`9:DP9>L`92408aS0@YBP8aS09:DP9W
>@=_N`9W>@9S609W>@9[FP9JeP8aS08HaP8U:@9>L`9S609Nm`=>L`9:DP9BU09Nm`9[FP9_N`9S6096
<@8YBP8Li`8]J`E240He[@@icPlmk`8icP8aS08]J`8e[@9BU09JeP9oo`03001oogoo00]oo`03001o
o`0000`0009oo`@000=oo`P000Aoo`<000Ioo`80009oo`L0009oo`8000]oo`@000Eoo`H000Aooa@0
00Ioo`T000Aoo`03001oogoo00Ioo`001goo00@007ooAS56<@@]J`8e[@Dmk`8icP8mk`9:DP9>L`92
408aS08YBP8U:@8e[@9BU09[FP=S609:DP8icP92409F]@9BU08aS08DY@8Li`92409Nm`9W>@=S609N
m`IS609Nm`9>L`8aS0@Q208aS09240<mk`He[@@icPlmk`8icP8aS08]J`8e[@9BU09Nm`9oo`03001o
ogoo00]oo`03001oo`0000`0009oo`@000=oo`P0009oo`8000Eoo`8000Ioo`L000Aoo`d000Aoo`T0
00Aoo`d0009ooa@000Aoo`03001oogoo00Ioo`001goo00@007ooAS56<@@]J`8e[@Dmk`8icP8mk`9:
DP9>L`92408aS08YBP8U:@8e[@9BU09[FP=S609:DP8icP92409F]@9BU08aS08DY@8Li`92409Nm`9W
>@=S609Nm`IS609Nm`9>L`8aS0@Q208aS09240<mk`He[@@icPlmk`8icP8aS08]J`8e[@9BU09Nm`9o
o`03001oogoo00]oo`03001oo`0000`0009oo`@000=oo`P0009oo`8000Eoo`8000Ioo`L000Aoo`d0
00Aoo`T000Aoo`d0009ooa@000Aoo`03001oogoo00Ioo`001goo00@007ooAS56<@@]J`8e[@LicP8m
k`9:DP9>L`8mk`8aS08U:@8YBP8icP9F]@9JeP<mk`8Li`8@Q08U:@924096<@8]J`@@Q08]J`9>L`9N
m`MS609JeP9BU096<@8e[@8YBP8U:@8YBP8e[@9240<mk`@e[@@icPhmk`<icP8e[@8]J`8YBP8e[@9B
U09Nm`9oo`03001oogoo00]oo`03001oo`0000`0009oo`@000=oo`P000Moo`H000Aoo`T000Aoo`T0
00Aoo`/000Aoo`/000]oo`d000Aoo`03001oogoo00Ioo`001goo00@007ooAS56<@@]J`8e[@LicP8m
k`9:DP9>L`8mk`8aS08U:@8YBP8icP9F]@9JeP<mk`8Li`8@Q08U:@924096<@8]J`@@Q08]J`9>L`9N
m`MS609JeP9BU096<@8e[@8YBP8U:@8YBP8e[@9240<mk`@e[@@icPhmk`<icP8e[@8]J`8YBP8e[@9B
U09Nm`9oo`03001oogoo00]oo`03001oo`0000`0009oo`@000=oo`P000Moo`H000Aoo`T000Aoo`T0
00Aoo`/000Aoo`/000]oo`d000Aoo`03001oogoo00Ioo`001goo00@007ooBU9:DP@]J`8e[@LicP8m
k`A:DP8mk`8]J`@U:@8icP9>L`96<@<Q20848@88@P8U:@96<@9:DP8]J`8@Q088@P8DY@8]J`96<@=B
U0AF]@9:DP8mk`8aS08]J`8aS0@e[@8icP8mk`<icP@e[@8icQ<mk`8e[@8]J`8YBP8e[@9BU09Nm`9o
o`03001oogoo00]oo`03001oo`0000`0009oo`@000=oo`P000Moo`H000Aoo`T000Aoo`T000Aoo`/0
00Aoo`/000]oo`d000Aoo`03001oogoo00Ioo`001goo00@007ooBU9:DP@]J`8e[@LicP8mk`A:DP8m
k`8]J`@U:@8icP9>L`96<@<Q20848@88@P8U:@96<@9:DP8]J`8@Q088@P8DY@8]J`96<@=BU0AF]@9:
DP8mk`8aS08]J`8aS0@e[@8icP8mk`<icP@e[@8icQ<mk`8e[@8]J`8YBP8e[@9BU09Nm`9oo`03001o
ogoo00]oo`03001oo`0000`0009oo`8000Eoo`P000Aoo`T000Aoo`/000Moo`8000Aoo`d0009oo`d0
009oo`L000Aoo`/000Aoo`03001oogoo00Ioo`001goo00@007ooBU9:DP8]J`8YBP8e[@LicP8mk`A:
DP8icP8U:@8Li`8Q208e[@9:DP9240<U:@8HaP8U:@92409JeP9F]@8e[@8@Q0@0008@Q08Q20<e[@A2
408mk`@e[@8mk`A:DP8mk`@icP<e[@8aS08e[@@icQ4mk`8e[@8]J`8YBP8e[@9BU09Nm`9oo`03001o
ogoo00]oo`03001oo`0000`0009oo`8000Eoo`P000Aoo`T000Aoo`/000Moo`8000Aoo`d0009oo`d0
009oo`L000Aoo`/000Aoo`03001oogoo00Ioo`001goo00@007ooBU9:DP8]J`8YBP8e[@LicP8mk`A:
DP8icP8U:@8Li`8Q208e[@9:DP9240<U:@8HaP8U:@92409JeP9F]@8e[@8@Q0@0008@Q08Q20<e[@A2
408mk`@e[@8mk`A:DP8mk`@icP<e[@8aS08e[@@icQ4mk`8e[@8]J`8YBP8e[@9BU09Nm`9oo`03001o
ogoo00]oo`03001oo`0000`0009oo`80009oo`/000Aoo`L000Iooa0000Ioo`@000Uoo`l000]oo`80
009oo`/000Aoo`03001oogoo00Ioo`001goo00@007ooBU9:DP8]J`8YBP8e[@LicP8mk`A6<@8e[@8U
:@8Li`8U:@8icPA>L`=2408mk`9>L`9S609[FP9Nm`8mk`8Li`848@@0008@Q0<Q208aS08icP@mk`96
<@9F]@9Nm`9F]@9240@e[@DaS08e[@@icQ4mk`8icP8]J`8YBP8e[@9BU09S609oo`03001oogoo00]o
o`03001oo`0000`0009oo`80009oo`/000Aoo`L000Iooa0000Ioo`@000Uoo`l000]oo`80009oo`/0
00Aoo`03001oogoo00Ioo`001goo00@007ooBU9:DP8]J`8YBP8e[@LicP8mk`A6<@8e[@8U:@8Li`8U
:@8icPA>L`=2408mk`9>L`9S609[FP9Nm`8mk`8Li`848@@0008@Q0<Q208aS08icP@mk`96<@9F]@9N
m`9F]@9240@e[@DaS08e[@@icQ4mk`8icP8]J`8YBP8e[@9BU09S609oo`03001oogoo00]oo`03001o
o`0000`0009oo`80009oo`/000eoo`8000Eooa4000Qoo`D0009ooa4000Aoo`<0009oo`80009oo`/0
00Aoo`03001oogoo00Ioo`001goo00@007ooBU9:DP8]J`8YBP8aS08icPDmk`924096<@8mk`8aS08U
:@8YBP8e[@9:DP9Nm`9S60EJeP9Nm`9W>@9S609F]@92408]J`8Li`@DY@8Li`<]J`8icP924096<@9:
DP9F]@9S609W>@9JeP92408e[@LaS08e[@@icQ4mk`8icP8aS08YBP8e[@9BU09S609oo`03001oogoo
00]oo`03001oo`0000`0009oo`80009oo`/000eoo`8000Eooa4000Qoo`D0009ooa4000Aoo`<0009o
o`80009oo`/000Aoo`03001oogoo00Ioo`001goo00@007ooBU9:DP8]J`8YBP8aS08icPDmk`924096
<@8mk`8aS08U:@8YBP8e[@9:DP9Nm`9S60EJeP9Nm`9W>@9S609F]@92408]J`8Li`@DY@8Li`<]J`8i
cP924096<@9:DP9F]@9S609W>@9JeP92408e[@LaS08e[@@icQ4mk`8icP8aS08YBP8e[@9BU09S609o
o`03001oogoo00]oo`03001oo`0000`000Ioo`T000Aoo`l000=oo`l000Aoo`/0009ooa4000Aoo`<0
009oo`80009oo`/000Aoo`03001oogoo00Ioo`001goo00@007ooBU9:DP8]J`8U:@8aS08icPDmk`A2
408icP@]J`8mk`9F]@9W>@9[FP9W>@=Nm`9F]@9>L`9:DP96<@9240Hmk`@icP8mk`=6<@9:DPA>L`9B
U09F]@9Nm`9S609F]@96<@8icP8aS0<]J`8aS08e[@HicPlmk`8e[@8aS08YBP8e[@9BU09S609oo`03
001oogoo00]oo`03001oo`0000`000Ioo`T000Aoo`l000=oo`l000Aoo`/0009ooa4000Aoo`<0009o
o`80009oo`/000Aoo`03001oogoo00Ioo`001goo00@007ooBU9:DP8]J`8U:@8aS08icPDmk`A2408i
cP@]J`8mk`9F]@9W>@9[FP9W>@=Nm`9F]@9>L`9:DP96<@9240Hmk`@icP8mk`=6<@9:DPA>L`9BU09F
]@9Nm`9S609F]@96<@8icP8aS0<]J`8aS08e[@HicPlmk`8e[@8aS08YBP8e[@9BU09S609oo`03001o
ogoo00]oo`03001oo`0000P000Qoo`L000Ioo`@0019oo`H000Uoo`d0009ooa4000eoo`/000Aoo`03
001oogoo00Ioo`001goo00@007ooBU9:DP8]J`8U:@8aS08icPDmk`A2408icP@]J`8mk`9F]@9W>@9[
FP9W>@=Nm`9F]@9>L`9:DP96<@9240Hmk`@icP8mk`=6<@9:DPA>L`9BU09F]@9Nm`9S609F]@96<@8i
cP8aS0<]J`8aS08e[@HicPlmk`8e[@8aS08YBP8e[@9BU09S609oo`03001oogoo00]oo`03001oo`00
00P000Qoo`L000Ioo`@0019oo`H000Uoo`d0009ooa4000eoo`/000Aoo`03001oogoo00Ioo`001goo
00@007ooBU9:DP8]J`8U:@8aS08icP<mk`I2408e[@8]J`8aS09>L`9[FP9cW09[FP9JeP=6<@8e[@8]
J`@YBP8]J`8icP96<@9>L`9BU0MF]@ABU0Y>L`96<@8mk`8icP8e[@DaS08e[@@icPhmk`<icP8e[@8a
S08YBP8e[@9BU09S609oo`03001oogoo00]oo`03001oo`0000P0009oo`@0009oo`L0009oo`H000Eo
o`d000Yoo`/000]ooa40009oo`8000Moo`d000Aoo`03001oogoo00Ioo`001goo00@007ooBU9:DP8]
J`8U:@8aS08icP<mk`I2408e[@8]J`8aS09>L`9[FP9cW09[FP9JeP=6<@8e[@8]J`@YBP8]J`8icP96
<@9>L`9BU0MF]@ABU0Y>L`96<@8mk`8icP8e[@DaS08e[@@icPhmk`<icP8e[@8aS08YBP8e[@9BU09S
609oo`03001oogoo00]oo`03001oo`0000P0009oo`@0009oo`L0009oo`H000Eoo`d000Yoo`/000]o
oa40009oo`8000Moo`d000Aoo`03001oogoo00Ioo`001goo00@007ooBU9:DP8]J`8U:@8aS08icPM2
408mk`8e[@8YBP8e[@9BU0A[FP9F]@8mk`<YBP8Li`8HaP8Q208YBP8aS08mk`9:DP9F]@9JeP9Nm`9J
eP=BU0I>L`9:DP96<@8icP@]J`8e[@8icP8e[@DaS0@icPhmk`DicP8e[@8]J`8YBP8e[@9BU09S609o
o`03001oogoo00]oo`03001oo`0000P0009oo`@0009oo`L0009oo`H000Eoo`d000Yoo`/000]ooa40
009oo`8000Moo`d000Aoo`03001oogoo00Ioo`001goo00@007ooBU9:DP8]J`8U:@8aS08icPM2408m
k`8e[@8YBP8e[@9BU0A[FP9F]@8mk`<YBP8Li`8HaP8Q208YBP8aS08mk`9:DP9F]@9JeP9Nm`9JeP=B
U0I>L`9:DP96<@8icP@]J`8e[@8icP8e[@DaS0@icPhmk`DicP8e[@8]J`8YBP8e[@9BU09S609oo`03
001oogoo00]oo`03001oo`0000P0009oo`@0009oo`L0009oo`8000Ioo`d000Eooa<0009ooaP000Uo
oa4000Aoo`03001oogoo00Ioo`001goo00@007ooBU9:DP8YBP8U:@8aS08icP<mk`A2408mk`8aS08Y
BP8aS09:DP9F]@9>L`8mk`8]J`DQ208YBP8e[@9240A:DP9>L`9BU0AF]@9>L`=:DP96<@9:DP9>L`9:
DP92408aS0@Q208]J`8icP8e[@DaS08icPhmk`LicP8e[@8aS08YBP8aS09BU09S609oo`03001oogoo
00]oo`03001oo`0000P0009oo`@0009oo`L0009oo`8000Ioo`d000Eooa<0009ooaP000Uooa4000Ao
o`03001oogoo00Ioo`001goo00@007ooBU9:DP8YBP8U:@8aS08icP<mk`A2408mk`8aS08YBP8aS09:
DP9F]@9>L`8mk`8]J`DQ208YBP8e[@9240A:DP9>L`9BU0AF]@9>L`=:DP96<@9:DP9>L`9:DP92408a
S0@Q208]J`8icP8e[@DaS08icPhmk`LicP8e[@8aS08YBP8aS09BU09S609oo`03001oogoo00]oo`03
001oo`0000P0009oo`@0009oo`L000Ioo`d000Moo`H000Uoo`H0009ooaH000Qooa@000Aoo`03001o
ogoo00Ioo`001goo00@007ooBU9:DP8YBP8Q208]J`8e[@<mk`A2408mk`8aS08YBP8]J`8icP92408i
cP8aS08e[@<icP8mk`9:DP9BU09JeP9F]@9>L`A:DP96<@8mk`De[@8mk`9:DPABU09:DP92408aS08]
J`8e[@8icP8e[@DaS08icPXmk`PicPDe[@8aS08YBP8e[@9BU09S609oo`03001oogoo00]oo`03001o
o`0000P0009oo`@0009oo`L000Ioo`d000Moo`H000Uoo`H0009ooaH000Qooa@000Aoo`03001oogoo
00Ioo`001goo00@007ooBU9:DP8YBP8Q208]J`8e[@<mk`A2408mk`8aS08YBP8]J`8icP92408icP8a
S08e[@<icP8mk`9:DP9BU09JeP9F]@9>L`A:DP96<@8mk`De[@8mk`9:DPABU09:DP92408aS08]J`8e
[@8icP8e[@DaS08icPXmk`PicPDe[@8aS08YBP8e[@9BU09S609oo`03001oogoo00]oo`03001oo`00
00P000Aoo`80009oo`T0009oo`T000Qoo`8000]oo`D000Aoo`@000Aooa8000Aoo`80009ooaH000Ao
o`03001oogoo00Ioo`001goo00@007ooCW=>L`8]J`8U:@8]J`8e[@<mk`A2408mk`8aS08YBP8U:@8a
S08icP8mk`92409:DP=BU0IF]@9BU09:DP8mk`8e[@8aS08]J`@Q20<YBP8mk`9>L`9F]@AJeP9F]@9B
U09:DP92408icP8aS0<]J`8aS08icPPmk`@icP8mk`LicP8e[@8aS08]J`8e[@9BU09S609oo`03001o
ogoo00]oo`03001oo`0000P000Aoo`80009oo`T0009oo`T000Qoo`8000]oo`D000Aoo`@000Aooa80
00Aoo`80009ooaH000Aoo`03001oogoo00Ioo`001goo00@007ooCW=>L`8]J`8U:@8]J`8e[@<mk`A2
408mk`8aS08YBP8U:@8aS08icP8mk`92409:DP=BU0IF]@9BU09:DP8mk`8e[@8aS08]J`@Q20<YBP8m
k`9>L`9F]@AJeP9F]@9BU09:DP92408icP8aS0<]J`8aS08icPPmk`@icP8mk`LicP8e[@8aS08]J`8e
[@9BU09S609oo`03001oogoo00]oo`03001oo`0000X0009oo`80009oo`/000]oo`@000Moo`l0009o
o`H000Uoo`d000IooaH000Aoo`03001oogoo00Ioo`001goo00@007ooCW=>L`8]J`8U:@8]J`8e[@<m
k`A2408mk`8e[@8YBP8U:@8e[@9:DPABU0EF]@9BU09>L`96<@8mk`8aS08Q208HaPHDY@8Li`<aS092
409>L`9BU09F]@9Nm`AW>@9JeP9:DP8e[@8]J`<YBP8aS08icQ0mk`DicP8e[@8aS08]J`8e[@9F]@9W
>@9oo`03001oogoo00]oo`03001oo`0000X0009oo`80009oo`/000]oo`@000Moo`l0009oo`H000Uo
o`d000IooaH000Aoo`03001oogoo00Ioo`001goo00@007ooCW=>L`8]J`8U:@8]J`8e[@<mk`A2408m
k`8e[@8YBP8U:@8e[@9:DPABU0EF]@9BU09>L`96<@8mk`8aS08Q208HaPHDY@8Li`<aS092409>L`9B
U09F]@9Nm`AW>@9JeP9:DP8e[@8]J`<YBP8aS08icQ0mk`DicP8e[@8aS08]J`8e[@9F]@9W>@9oo`03
001oogoo00]oo`03001oo`0000P000Aoo`80009oo`T000Aoo`/000Aooa8000Aoo`d0009oo`d000Ao
oaP000Aoo`03001oogoo00Ioo`001goo00@007ooDYABU08aS08YBP8]J`8e[@<mk`A2408mk`8e[@@]
J`92409F]@9Nm`9BU0E:DP96<@92408mk`8icP8YBP8DY@88@P8<H`8HaP8YBP8icP=6<@9:DP92408m
k`96<@9F]@9W>@9[FP9S609:DP8aS0DYBP8aS0@icPPmk`8icP@mk`LicP8aS08]J`8e[@9F]@9W>@9o
o`03001oogoo00]oo`03001oo`0000P000Aoo`80009oo`T000Aoo`/000Aooa8000Aoo`d0009oo`d0
00AooaP000Aoo`03001oogoo00Ioo`001goo00@007ooDYABU08aS08YBP8]J`8e[@<mk`A2408mk`8e
[@@]J`92409F]@9Nm`9BU0E:DP96<@92408mk`8icP8YBP8DY@88@P8<H`8HaP8YBP8icP=6<@9:DP92
408mk`96<@9F]@9W>@9[FP9S609:DP8aS0DYBP8aS0@icPPmk`8icP@mk`LicP8aS08]J`8e[@9F]@9W
>@9oo`03001oogoo00]oo`03001oo`0000P000Aoo`80009oo`L000Aoo`8000Uoo`80009ooa4000eo
o`L0009oo`d000AooaP000Aoo`03001oogoo00Ioo`001goo00@007ooDYABU08aS08YBP8]J`8e[@<m
k`A2408mk`8e[@@aS092409BU09>L`8mk`8e[@<mk`96<@9:DP9>L`9:DP8mk`8Q20@<H`8YBP9:DPEJ
eP92408U:@8HaP8U:@8mk`9F]@9W>@9S609:DP8aS08U:@<YBP8aS0@icP@mka4icP8aS08]J`8e[@9F
]@9W>@9oo`03001oogoo00]oo`03001oo`0000P000Aoo`80009oo`L000Aoo`8000Uoo`80009ooa40
00eoo`L0009oo`d000AooaP000Aoo`03001oogoo00Ioo`001goo00@007ooDYABU08aS08YBP8]J`8e
[@<mk`A2408mk`8e[@@aS092409BU09>L`8mk`8e[@<mk`96<@9:DP9>L`9:DP8mk`8Q20@<H`8YBP9:
DPEJeP92408U:@8HaP8U:@8mk`9F]@9W>@9S609:DP8aS08U:@<YBP8aS0@icP@mka4icP8aS08]J`8e
[@9F]@9W>@9oo`03001oogoo00]oo`03001oo`0000X0009oo`80009oo`L000Qoo`D0009oo`8000Ao
o`/000Uoo`H000Aoo`D0009oobT000Aoo`03001oogoo00Ioo`001goo00@007ooDYABU08aS08YBP8]
J`8e[@<icP8mk`92408mk`8icP@e[@8icP8mk`8e[@8]J`8aS0=6<@9BU09JeP9Nm`9S609F]@8e[@@D
Y@8e[@9Nm`9[FP=F]@8]J`88@P80008<H`8YBP96<@AJeP96<@8]J`8U:@<]J`8e[ATicP8aS08YBP8e
[@9BU09W>@9oo`03001oogoo00]oo`03001oo`0000X0009oo`80009oo`L000Qoo`D0009oo`8000Ao
o`/000Uoo`H000Aoo`D0009oobT000Aoo`03001oogoo00Ioo`001goo00@007ooDYABU08aS08YBP8]
J`8e[@<icP8mk`92408mk`8icP@e[@8icP8mk`8e[@8]J`8aS0=6<@9BU09JeP9Nm`9S609F]@8e[@@D
Y@8e[@9Nm`9[FP=F]@8]J`88@P80008<H`8YBP96<@AJeP96<@8]J`8U:@<]J`8e[ATicP8aS08YBP8e
[@9BU09W>@9oo`03001oogoo00]oo`03001oo`0000X0009oo`80009oo`L000Qoo`D0009oo`8000Ao
o`/000Uoo`H000Aoo`D0009oobT000Aoo`03001oogoo00Ioo`001goo00@007ooDYABU08aS08YBP8]
J`8e[@<icPPmk`8icP8e[@8aS08]J`8U:@8]J`9240=F]@9Nm`9JeP9Nm`AW>@96<@8Q208HaP8icP9N
m`9W>@=2408HaP@48@8DY@8YBP9240ABU092408]J`8U:@<]J`8e[ATicP8aS08YBP8aS09BU09W>@9o
o`03001oogoo00]oo`03001oo`0000X000Ioo`T0009oo`H000Eoo`@000Aoo`T0009oo`8000=oo`X0
009oo`D0009oobT000Aoo`03001oogoo00Ioo`001goo00@007ooDYABU08aS08YBP8]J`8e[@<icPPm
k`8icP8e[@8aS08]J`8U:@8]J`9240=F]@9Nm`9JeP9Nm`AW>@96<@8Q208HaP8icP9Nm`9W>@=2408H
aP@48@8DY@8YBP9240ABU092408]J`8U:@<]J`8e[ATicP8aS08YBP8aS09BU09W>@9oo`03001oogoo
00]oo`03001oo`0000X000Ioo`T0009oo`H000Eoo`@000Aoo`T0009oo`8000=oo`X0009oo`D0009o
obT000Aoo`03001oogoo00Ioo`001goo00@007ooDYABU08aS08YBP8]J`De[@8icPHmk`8icP8e[@8]
J`@U:@8e[@9BU0=S609JeP9:DP96<@9F]@9S609>L`8YBP8Li`8e[@9F]@9BU0<aS0@HaP8YBP8icP96
<@9>L`9F]@9>L`8icP8YBP8U:@<]J`He[@XicPHmk`DicP8aS08YBP8aS09>L`9S609oo`03001oogoo
00]oo`03001oo`0000`000Aoo`l000Eoo`P000Eoo`H000Moo`X0009oo`<000AoobT000Aoo`03001o
ogoo00Ioo`001goo00@007ooDYABU08aS08YBP8]J`De[@8icPHmk`8icP8e[@8]J`@U:@8e[@9BU0=S
609JeP9:DP96<@9F]@9S609>L`8YBP8Li`8e[@9F]@9BU0<aS0@HaP8YBP8icP96<@9>L`9F]@9>L`8i
cP8YBP8U:@<]J`He[@XicPHmk`DicP8aS08YBP8aS09>L`9S609oo`03001oogoo00]oo`03001oo`00
00`000Aoo`l000Eoo`P000Eoo`H000Moo`X0009oo`<000AoobT000Aoo`03001oogoo00Ioo`001goo
00@007ooDYABU08aS08YBP8]J`De[@8icPHmk`@icP8aS08U:@8YBP92409JeP=Nm`9:DP8]J`8U:@8m
k`9JeP9BU08]J`8Li`8e[@9:DP9240<]J`8U:@8e[@9:DP9F]@9JePANm`9BU08icP@U:@<]J`He[@@i
cPlmk`8icP8aS08YBP8aS09BU09W>@9oo`03001oogoo00]oo`03001oo`0000`000Ioo`d0009oo`<0
00Qoo`8000=oo`H000Aoo`/000Aoo`<0009oob/000Aoo`03001oogoo00Ioo`001goo00@007ooDYAB
U08aS08YBP8]J`De[@8icPHmk`@icP8aS08U:@8YBP92409JeP=Nm`9:DP8]J`8U:@8mk`9JeP9BU08]
J`8Li`8e[@9:DP9240<]J`8U:@8e[@9:DP9F]@9JePANm`9BU08icP@U:@<]J`He[@@icPlmk`8icP8a
S08YBP8aS09BU09W>@9oo`03001oogoo00]oo`03001oo`0000`000Ioo`d0009oo`<000Qoo`8000=o
o`H000Aoo`/000Aoo`<0009oob/000Aoo`03001oogoo00Ioo`001goo00@007ooDYABU08aS08YBP8]
J`De[@8icPHmk`@icP8aS08U:@8YBP92409JeP=Nm`9:DP8]J`8U:@8mk`9JeP9BU08]J`8Li`8e[@9:
DP9240<]J`8U:@8e[@9:DP9F]@9JePANm`9BU08icP@U:@<]J`He[@@icPlmk`8icP8aS08YBP8aS09B
U09W>@9oo`03001oogoo00]oo`03001oo`0000`000Ioo`/000Uoo`@000Moo`H000Aoo`L000Ioo`D0
009ooaX000Ioo`/000Aoo`03001oogoo00Ioo`001goo00@007ooDYABU08aS08YBP8aS08e[@DicPPm
k`8icP8e[@8]J`8aS096<@9JeP=F]@8icP8HaP8@Q08aS0ABU08]J`8Li`8]J`92408mk`<e[@8mk`9B
U09Nm`AS60AW>@9JeP8mk`8YBP8U:@<]J`8aS0@e[@8icQ4mk`8icP8aS08YBP8aS09BU09W>@9oo`03
001oogoo00]oo`03001oo`0000`000Ioo`/000Uoo`@000Moo`H000Aoo`L000Ioo`D0009ooaX000Io
o`/000Aoo`03001oogoo00Ioo`001goo00@007ooDYABU08aS08YBP8aS08e[@DicPPmk`8icP8e[@8]
J`8aS096<@9JeP=F]@8icP8HaP8@Q08aS0ABU08]J`8Li`8]J`92408mk`<e[@8mk`9BU09Nm`AS60AW
>@9JeP8mk`8YBP8U:@<]J`8aS0@e[@8icQ4mk`8icP8aS08YBP8aS09BU09W>@9oo`03001oogoo00]o
o`03001oo`0001d0009oo`8000=oo`P000Eoo`H000Aoo`<000Ioo`T000Aooa4000Moo`8000Ioo`T0
00Aoo`03001oogoo00Ioo`001goo00@007ooDYABU08aS08YBP8aS08icPlmk`8icP8aS08e[@9:DP9N
m`=JeP8icP8HaP8@Q08]J`9>L`9:DP8YBP8HaP8YBP8mk`96<@=>L`9F]@ANm`AJeP9S609[FP9S609:
DP8aS08YBP<]J`8aS08e[@@icQ4mk`8icP8aS08YBP8e[@9BU09W>@9oo`03001oogoo00]oo`03001o
o`0001d0009oo`8000=oo`P000Eoo`H000Aoo`<000Ioo`T000Aooa4000Moo`8000Ioo`T000Aoo`03
001oogoo00Ioo`001goo00@007ooDYABU08aS08YBP8aS08icPlmk`8icP8aS08e[@9:DP9Nm`=JeP8i
cP8HaP8@Q08]J`9>L`9:DP8YBP8HaP8YBP8mk`96<@=>L`9F]@ANm`AJeP9S609[FP9S609:DP8aS08Y
BP<]J`8aS08e[@@icQ4mk`8icP8aS08YBP8e[@9BU09W>@9oo`03001oogoo00]oo`03001oo`000180
00Eoo`H0009oo`8000=oo`P000Eoo`H000Uoo`l0009oo`l000Aoo`8000=oo`@000Aoo`T000Aoo`03
001oogoo00Ioo`001goo00@007ooE[EF]@8e[@8]J`8e[@8mk`E240Hmk`92408mk`8icP8aS08icP9>
L`EW>@9:DP8U:@8Li`8e[@9>L`92408U:@8DY@8U:@92409JeP=S609W>@9S609F]@A:DP9F]@9[FP9_
N`9JeP8mk`DaS08e[@8icP@mk`I240/mk`8icP8e[@8]J`8e[@9F]@9[FP9oo`03001oogoo00]oo`03
001oo`00018000Eoo`H0009oo`8000=oo`P000Eoo`H000Uoo`l0009oo`l000Aoo`8000=oo`@000Ao
o`T000Aoo`03001oogoo00Ioo`001goo00@007ooE[EF]@8e[@8]J`8e[@8mk`E240Hmk`92408mk`8i
cP8aS08icP9>L`EW>@9:DP8U:@8Li`8e[@9>L`92408U:@8DY@8U:@92409JeP=S609W>@9S609F]@A:
DP9F]@9[FP9_N`9JeP8mk`DaS08e[@8icP@mk`I240/mk`8icP8e[@8]J`8e[@9F]@9[FP9oo`03001o
ogoo00]oo`03001oo`00018000Eoo`H0009oo`8000=oo`P000Eoo`H000Uoo`l0009oo`l000Aoo`80
00=oo`@000Aoo`T000Aoo`03001oogoo00Ioo`001goo00@007ooF]IJeP8mk`8aS08icP9240E6<@I2
4096<@92408mk`8e[@8icP9BU09cW0=kgP9Nm`8e[@8]J`92409>L`92408U:@8Li`8aS09BU09_N`=g
_@9cW09S609:DP@e[@9BU09cW09oo`9[FP9>L`LicP@mk`A24096<@I240Tmk`8e[@8aS08mk`9Nm`9_
N`9oo`03001oogoo00]oo`03001oo`0000D0019oo`H0009oo`8000Eoo`H000Eoo`H0009oo`T000Qo
o`D000Aoo`/000Aoo`@000Eoo`8000Aoo`T000Aoo`03001oogoo00Ioo`001goo00@007ooF]IJeP8m
k`8aS08icP9240E6<@I24096<@92408mk`8e[@8icP9BU09cW0=kgP9Nm`8e[@8]J`92409>L`92408U
:@8Li`8aS09BU09_N`=g_@9cW09S609:DP@e[@9BU09cW09oo`9[FP9>L`LicP@mk`A24096<@I240Tm
k`8e[@8aS08mk`9Nm`9_N`9oo`03001oogoo00]oo`03001oo`0000D0019oo`H0009oo`8000Eoo`H0
00Eoo`H0009oo`T000Qoo`D000Aoo`/000Aoo`@000Eoo`8000Aoo`T000Aoo`03001oogoo00Ioo`00
1goo00@007ooF]IJeP8mk`8aS08icP8mk`]24096<@9:DP96<@@icP9BU09cW0=oo`9[FP9:DP92409B
U09Nm`9>L`8icP8aS096<@9W>@9kgP=oo`9g_@9S6096<@8aS08e[@9F]@9g_@9oo`9_N`9BU0Dmk`Q2
40I6<@]2408mk`8icP8e[@92409S609_N`9oo`03001oogoo00]oo`03001oo`0000D000=oo`d0009o
o`H0009oo`D0009oo`@000Moo`H0009oo`T0009oo`@0009oo`L0009oo`L000Ioo`T000Qoo`T000Ao
o`03001oogoo00Ioo`001goo00@007ooF]IJeP8mk`8aS08icP8mk`]24096<@9:DP96<@@icP9BU09c
W0=oo`9[FP9:DP92409BU09Nm`9>L`8icP8aS096<@9W>@9kgP=oo`9g_@9S6096<@8aS08e[@9F]@9g
_@9oo`9_N`9BU0Dmk`Q240I6<@]2408mk`8icP8e[@92409S609_N`9oo`03001oogoo00]oo`03001o
o`0000D000=oo`d0009oo`H0009oo`D0009oo`@000Moo`H0009oo`T0009oo`@0009oo`L0009oo`L0
00Ioo`T000Qoo`T000Aoo`03001oogoo00Ioo`001goo00@007ooAS56<@8]J`8U:@8YBP8aS0Te[@8i
cP96<@A>L`92408mk`9:DP9S60=_N`9S609BU09>L`9Nm`9W>@9Nm`9>L`96<@9BU09W>@9_N`=[FP9S
609F]@92408aS08icP9BU0AW>@9F]@8mk`De[@8icPPmk`Y240Lmk`@icP92409F]@9JeP9oo`03001o
ogoo00]oo`03001oo`0000D001Aoo`@0009oo`D000Qoo`8000=oo`@000Aoo`T0009oo`@0009oo`L0
00moo`l000Aoo`D000Ioo`03001oogoo00Ioo`001goo00@007ooAS56<@8]J`8U:@8YBP8aS0Te[@8i
cP96<@A>L`92408mk`9:DP9S60=_N`9S609BU09>L`9Nm`9W>@9Nm`9>L`96<@9BU09W>@9_N`=[FP9S
609F]@92408aS08icP9BU0AW>@9F]@8mk`De[@8icPPmk`Y240Lmk`@icP92409F]@9JeP9oo`03001o
ogoo00]oo`03001oo`0000D001Aoo`@0009oo`D000Qoo`8000=oo`@000Aoo`T0009oo`@0009oo`L0
00moo`l000Aoo`D000Ioo`03001oogoo00Ioo`001goo00<007ooOol0OWoo00<007ooOol02goo00<0
07ooOol0OWoo00<007ooOol01Woo0007Oon2000=Oon20008Ool00?moob5oo`00ogoo8Goo003oOolQ
Ool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {136.125, 0}} -> {-0.0541876, -0.0238146, 
  0.00734626, 0.00734626}, {{7.375, 137}, {132.875, 
  3.1875}} -> {-4.81775, -2.84324, 0.482325, 0.482325}, {{149.938, 279.625}, {
  132.875, 3.1875}} -> {-71.0928, -2.73313, 0.466022, 0.466022}}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["OPTIONAL TOPIC: LOCALIZATION OF CLOSELY SPACED EDGES", "Section"],

Cell["\<\
In this section it will be demonstrated that problems with edge localization \
occur in the vicinity of closely spaced lines. The meaning of \"closeness\" \
will be made somewhat more precise shortly. In order to simulate the case of \
narrowly spaced edges, assume an ideal white line on black background. In \
cross-section such a line would look like a narrow pulse. Assume unity \
height. The convolution of the pulse with the lofg function will give the \
ideal response. It is of interest to analyze this response as a function of \
the width of the Gaussian (keeping pulse width fixed). Begin by defining the \
Laplacian-of-Gaussian in one dimension.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(h[x_] := 
      Evaluate[\[PartialD]\_{x, 2}Exp[\(-\(x\^2\/\(2\ \[Sigma]\^2\)\)\)]]; \ 
    h[x]\)], "Input"],

Cell[BoxData[
    \(\(E\^\(-\(x\^2\/\(2\ \[Sigma]\^2\)\)\)\ x\^2\)\/\[Sigma]\^4 - 
      E\^\(-\(x\^2\/\(2\ \[Sigma]\^2\)\)\)\/\[Sigma]\^2\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Convolve the impulse response with a unit pulse of width ",
  Cell[BoxData[
      \(TraditionalForm\`w = 8\)]],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(y[x_] := 
      Evaluate[Integrate[h[x] - h[x - 8], x, \ 
          Assumptions -> \ Re[\[Sigma]\^2] > 0]]; \ y[x]\)], "Input"],

Cell[BoxData[
    \(E\^\(\(8\ x\)\/\[Sigma]\^2 - x\^2\/\(2\ \[Sigma]\^2\)\)\ 
        \((\(-\(\(8\ E\^\(-\(32\/\[Sigma]\^2\)\)\)\/\[Sigma]\^2\)\) + 
            \(E\^\(-\(32\/\[Sigma]\^2\)\)\ x\)\/\[Sigma]\^2)\) - 
      \(E\^\(-\(x\^2\/\(2\ \[Sigma]\^2\)\)\)\ x\)\/\[Sigma]\^2\)], "Output"]
}, Open  ]],

Cell[TextData[
"Now, plot the result for a range of values of the variance \[Sigma]."], 
  "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Plot[Evaluate[y[x] /. \[Sigma] \[Rule] {1, 2, 4}], {x, \(-4\), 12}]; 
    \)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.261905 0.0595238 0.309005 0.485242 [
[.1131 .29651 -12 -9 ]
[.1131 .29651 12 0 ]
[.41071 .29651 -9 -9 ]
[.41071 .29651 9 0 ]
[.55952 .29651 -3 -9 ]
[.55952 .29651 3 0 ]
[.70833 .29651 -9 -9 ]
[.70833 .29651 9 0 ]
[.85714 .29651 -6 -9 ]
[.85714 .29651 6 0 ]
[.2494 .01786 -24 -4.5 ]
[.2494 .01786 0 4.5 ]
[.2494 .11491 -24 -4.5 ]
[.2494 .11491 0 4.5 ]
[.2494 .21196 -24 -4.5 ]
[.2494 .21196 0 4.5 ]
[.2494 .40605 -18 -4.5 ]
[.2494 .40605 0 4.5 ]
[.2494 .5031 -18 -4.5 ]
[.2494 .5031 0 4.5 ]
[.2494 .60015 -18 -4.5 ]
[.2494 .60015 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.1131 .30901 m
.1131 .31526 L
s
[(-2.5)] .1131 .29651 0 1 Mshowa
.41071 .30901 m
.41071 .31526 L
s
[(2.5)] .41071 .29651 0 1 Mshowa
.55952 .30901 m
.55952 .31526 L
s
[(5)] .55952 .29651 0 1 Mshowa
.70833 .30901 m
.70833 .31526 L
s
[(7.5)] .70833 .29651 0 1 Mshowa
.85714 .30901 m
.85714 .31526 L
s
[(10)] .85714 .29651 0 1 Mshowa
.125 Mabswid
.14286 .30901 m
.14286 .31276 L
s
.17262 .30901 m
.17262 .31276 L
s
.20238 .30901 m
.20238 .31276 L
s
.23214 .30901 m
.23214 .31276 L
s
.29167 .30901 m
.29167 .31276 L
s
.32143 .30901 m
.32143 .31276 L
s
.35119 .30901 m
.35119 .31276 L
s
.38095 .30901 m
.38095 .31276 L
s
.44048 .30901 m
.44048 .31276 L
s
.47024 .30901 m
.47024 .31276 L
s
.5 .30901 m
.5 .31276 L
s
.52976 .30901 m
.52976 .31276 L
s
.58929 .30901 m
.58929 .31276 L
s
.61905 .30901 m
.61905 .31276 L
s
.64881 .30901 m
.64881 .31276 L
s
.67857 .30901 m
.67857 .31276 L
s
.7381 .30901 m
.7381 .31276 L
s
.76786 .30901 m
.76786 .31276 L
s
.79762 .30901 m
.79762 .31276 L
s
.82738 .30901 m
.82738 .31276 L
s
.8869 .30901 m
.8869 .31276 L
s
.91667 .30901 m
.91667 .31276 L
s
.94643 .30901 m
.94643 .31276 L
s
.97619 .30901 m
.97619 .31276 L
s
.08333 .30901 m
.08333 .31276 L
s
.05357 .30901 m
.05357 .31276 L
s
.02381 .30901 m
.02381 .31276 L
s
.25 Mabswid
0 .30901 m
1 .30901 L
s
.2619 .01786 m
.26815 .01786 L
s
[(-0.6)] .2494 .01786 1 0 Mshowa
.2619 .11491 m
.26815 .11491 L
s
[(-0.4)] .2494 .11491 1 0 Mshowa
.2619 .21196 m
.26815 .21196 L
s
[(-0.2)] .2494 .21196 1 0 Mshowa
.2619 .40605 m
.26815 .40605 L
s
[(0.2)] .2494 .40605 1 0 Mshowa
.2619 .5031 m
.26815 .5031 L
s
[(0.4)] .2494 .5031 1 0 Mshowa
.2619 .60015 m
.26815 .60015 L
s
[(0.6)] .2494 .60015 1 0 Mshowa
.125 Mabswid
.2619 .04212 m
.26565 .04212 L
s
.2619 .06638 m
.26565 .06638 L
s
.2619 .09065 m
.26565 .09065 L
s
.2619 .13917 m
.26565 .13917 L
s
.2619 .16343 m
.26565 .16343 L
s
.2619 .1877 m
.26565 .1877 L
s
.2619 .23622 m
.26565 .23622 L
s
.2619 .26048 m
.26565 .26048 L
s
.2619 .28474 m
.26565 .28474 L
s
.2619 .33327 m
.26565 .33327 L
s
.2619 .35753 m
.26565 .35753 L
s
.2619 .38179 m
.26565 .38179 L
s
.2619 .43032 m
.26565 .43032 L
s
.2619 .45458 m
.26565 .45458 L
s
.2619 .47884 m
.26565 .47884 L
s
.2619 .52736 m
.26565 .52736 L
s
.2619 .55163 m
.26565 .55163 L
s
.2619 .57589 m
.26565 .57589 L
s
.25 Mabswid
.2619 0 m
.2619 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30966 m
.02846 .30988 L
.03279 .31014 L
.03754 .31051 L
.04262 .31102 L
.04795 .31174 L
.053 .31261 L
.05753 .31359 L
.06244 .31493 L
.06751 .31666 L
.07308 .31905 L
.07851 .32199 L
.08435 .32593 L
.0948 .33548 L
.10458 .34801 L
.11468 .36536 L
.12571 .39004 L
.1458 .45025 L
.16712 .52647 L
.17719 .55984 L
.18645 .58444 L
.19116 .59359 L
.19353 .59716 L
.19613 .60019 L
.1975 .60139 L
.19874 .60224 L
.19943 .60261 L
.20018 .60292 L
.20089 .60314 L
.20154 .60326 L
.20271 .60331 L
.20399 .6031 L
.20464 .60289 L
.20534 .60258 L
.2066 .60181 L
.20779 .60082 L
.2089 .59967 L
.21142 .59623 L
.21388 .59175 L
.2165 .58571 L
.22126 .57145 L
.22558 .55482 L
.23556 .50373 L
.24476 .44306 L
.26556 .27925 L
.27538 .20197 L
.28592 .12854 L
.29102 .0984 L
.29587 .07371 L
.30064 .05348 L
Mistroke
.30496 .0388 L
.30952 .02713 L
.31202 .02238 L
.31437 .01898 L
.31543 .01777 L
.31656 .01671 L
.31752 .01598 L
.31856 .01538 L
.31968 .01495 L
.32072 .01473 L
.32196 .01472 L
.32309 .01492 L
.32432 .01537 L
.32562 .01612 L
.32673 .01695 L
.32796 .01809 L
.33069 .0214 L
.33325 .02542 L
.33787 .03472 L
.34285 .04726 L
.36254 .11251 L
.38404 .18771 L
.39399 .21721 L
.40461 .2433 L
.41463 .2627 L
.42372 .27623 L
.43373 .28728 L
.44294 .29453 L
.44776 .29742 L
.45306 .3 L
.45855 .30213 L
.46375 .30371 L
.46863 .30488 L
.47394 .30586 L
.47877 .30653 L
.48324 .30699 L
.48805 .30735 L
.4908 .3075 L
.49337 .3076 L
.49469 .30764 L
.49608 .30767 L
.49726 .30769 L
.49856 .3077 L
.49929 .3077 L
.49995 .3077 L
.50072 .3077 L
.50145 .3077 L
.50274 .30769 L
.50347 .30767 L
.50415 .30766 L
Mistroke
.5054 .30763 L
.50658 .3076 L
.50881 .30751 L
.51121 .3074 L
.51382 .30723 L
.51852 .30683 L
.52289 .30632 L
.52813 .30551 L
.53287 .30455 L
.53836 .30312 L
.54352 .30139 L
.55329 .29683 L
.55821 .29375 L
.56361 .28963 L
.57317 .28006 L
.58209 .26801 L
.59255 .2493 L
.60246 .22658 L
.62102 .17108 L
.63925 .10604 L
.64963 .07001 L
.65471 .0542 L
.65937 .04138 L
.66392 .03083 L
.66889 .02201 L
.67148 .01869 L
.67272 .01743 L
.67389 .01646 L
.67453 .01601 L
.67523 .0156 L
.67644 .01507 L
.67712 .01486 L
.67785 .01473 L
.67915 .01472 L
.68046 .01499 L
.68165 .01549 L
.68231 .01587 L
.68302 .01638 L
.68433 .01753 L
.68684 .0206 L
.68916 .02448 L
.69196 .03049 L
.69449 .0372 L
.70017 .05662 L
.71023 .10541 L
.71947 .16441 L
.74031 .32702 L
.7502 .40565 L
.76078 .481 L
.77077 .53814 L
Mistroke
.77519 .55802 L
.77987 .5752 L
.78218 .5822 L
.78474 .58873 L
.78709 .59365 L
.78924 .59725 L
.79177 .60039 L
.79317 .60164 L
.79381 .60209 L
.7945 .6025 L
.79572 .60302 L
.79685 .60327 L
.79754 .60332 L
.7982 .60329 L
.79942 .60305 L
.80049 .60265 L
.80167 .60199 L
.8029 .60108 L
.80404 .60002 L
.8083 .59448 L
.81073 .59025 L
.81294 .58578 L
.81791 .57381 L
.8386 .50597 L
.85774 .43837 L
.87632 .38502 L
.8857 .3646 L
.89606 .34707 L
.90615 .33447 L
.9154 .32612 L
.92025 .32275 L
.92555 .31973 L
.93106 .31722 L
.93625 .31534 L
.9411 .31394 L
.94637 .31273 L
.95074 .31194 L
.95556 .31125 L
.96077 .31067 L
.96629 .3102 L
.9714 .30988 L
.97619 .30966 L
Mfstroke
.02381 .37468 m
.06244 .40889 L
.08255 .42651 L
.0932 .43497 L
.10458 .4429 L
.11531 .44898 L
.12507 .45305 L
.12977 .45445 L
.13243 .45506 L
.13488 .45551 L
.13702 .45581 L
.13824 .45594 L
.13938 .45603 L
.14058 .4561 L
.14168 .45614 L
.14295 .45616 L
.14415 .45614 L
.1454 .45609 L
.1461 .45605 L
.14674 .456 L
.14793 .45589 L
.14918 .45573 L
.15135 .45539 L
.15374 .45489 L
.15902 .45333 L
.16396 .4513 L
.17283 .4462 L
.18234 .43868 L
.19252 .4283 L
.20358 .41438 L
.22371 .38286 L
.26449 .30339 L
.30375 .22769 L
.32345 .19731 L
.3415 .17613 L
.35093 .16784 L
.36085 .16117 L
.36601 .15852 L
.37081 .15653 L
.37608 .15486 L
.37903 .15414 L
.38171 .15363 L
.38402 .15329 L
.38656 .15301 L
.38783 .15291 L
.38854 .15287 L
.38921 .15284 L
.3905 .15279 L
.39169 .15277 L
.3928 .15277 L
Mistroke
.39397 .15279 L
.39509 .15282 L
.39609 .15287 L
.39728 .15294 L
.39857 .15304 L
.40089 .15328 L
.40341 .1536 L
.40617 .15405 L
.41173 .15518 L
.42169 .15785 L
.44288 .16506 L
.46217 .17153 L
.47176 .17412 L
.47682 .17525 L
.48219 .17622 L
.48687 .17687 L
.48953 .17716 L
.49203 .17737 L
.49315 .17745 L
.49432 .17752 L
.49533 .17756 L
.49641 .17761 L
.49758 .17764 L
.49867 .17766 L
.49996 .17766 L
.50113 .17766 L
.50233 .17764 L
.50345 .17761 L
.50467 .17756 L
.50599 .1775 L
.50868 .17732 L
.51114 .17709 L
.51587 .17651 L
.52035 .17579 L
.53031 .17361 L
.54116 .1705 L
.56052 .16385 L
.57081 .16025 L
.58191 .1568 L
.58705 .15546 L
.59246 .1543 L
.59708 .15354 L
.5997 .15321 L
.60214 .15299 L
.60333 .1529 L
.60461 .15284 L
.60583 .15279 L
.60695 .15277 L
.60796 .15277 L
.60907 .15278 L
Mistroke
.61024 .15281 L
.61132 .15286 L
.61259 .15294 L
.6138 .15305 L
.61606 .1533 L
.61849 .15366 L
.62115 .15418 L
.62646 .1556 L
.63147 .15742 L
.64083 .16216 L
.65091 .16931 L
.66181 .1795 L
.68176 .20466 L
.70283 .23928 L
.74083 .31427 L
.76199 .35657 L
.78127 .39132 L
.8015 .42109 L
.81039 .4315 L
.8202 .4409 L
.82946 .4477 L
.83454 .45056 L
.8393 .4527 L
.84184 .45363 L
.84451 .45445 L
.84683 .45502 L
.84929 .4555 L
.85069 .45572 L
.85196 .45587 L
.85323 .456 L
.85444 .45608 L
.85512 .45611 L
.85584 .45614 L
.85714 .45616 L
.85786 .45615 L
.85853 .45614 L
.85927 .45611 L
.86006 .45607 L
.8614 .45597 L
.86261 .45585 L
.86533 .45548 L
.86784 .45501 L
.8702 .45446 L
.87552 .45285 L
.88125 .45059 L
.89173 .44516 L
.90136 .43893 L
.94092 .40584 L
.97619 .37468 L
Mfstroke
.02381 .37854 m
.02846 .3783 L
.03279 .37801 L
.04262 .37714 L
.0522 .37599 L
.06244 .37441 L
.08451 .36979 L
.10458 .36408 L
.14451 .34845 L
.18292 .32843 L
.22379 .30276 L
.26314 .27528 L
.30098 .24807 L
.34126 .22034 L
.38004 .1969 L
.39975 .18681 L
.42126 .17751 L
.44185 .1705 L
.45103 .16801 L
.46097 .16578 L
.46647 .16475 L
.47154 .16394 L
.47628 .16331 L
.48149 .16274 L
.48617 .16234 L
.49054 .16208 L
.49295 .16198 L
.49515 .16191 L
.49637 .16188 L
.49706 .16187 L
.49769 .16186 L
.49886 .16185 L
.5001 .16185 L
.50124 .16185 L
.50248 .16186 L
.50378 .16189 L
.50499 .16191 L
.50715 .16198 L
.50947 .16208 L
.51219 .16223 L
.51476 .16241 L
.51957 .16284 L
.52834 .16393 L
.53785 .16554 L
.54731 .1676 L
.55772 .17037 L
.57877 .17752 L
.61911 .19643 L
.65793 .21982 L
.69921 .24821 L
Mistroke
.73897 .2768 L
.77721 .30343 L
.81791 .32891 L
.85709 .34919 L
.87711 .35761 L
.89873 .36512 L
.91964 .37079 L
.92958 .37294 L
.93885 .37463 L
.94817 .37604 L
.95666 .37706 L
.96609 .37793 L
.97128 .37828 L
.97619 .37854 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{216, 133.438},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003H0000QA000`40O003h00Of7oo000iOol00`00
Oomoo`2LOol003Uoo`03001oogoo09aoo`00:Goo00<007ooOol00Woo00@007ooOomoo`8000Eoo`03
001oogoo09aoo`00:7oo00<007oo00001goo00<007oo000017oo00<007ooOol027oo0`00BGoo0`00
AGoo000SOol30002Ool00`00Ool00007Ool00`00Ool00004Ool20009Ool01000Oomoo`00Agoo00D0
07ooOomoo`0004Aoo`00:7oo00<007oo00001goo0P001Goo00<007ooOol01goo00<007ooOol00Woo
00<007ooOol0@goo00<007ooOol00Woo00<007ooOol0@Woo000XOol00`00Ool00007Ool00`00Oomo
o`04Ool00`00Oomoo`07Ool00`00Oomoo`03Ool00`00Oomoo`12Ool00`00Oomoo`03Ool00`00Oomo
o`11Ool002Uoo`03001oogoo00Moo`8000Aoo`03001oogoo00Ioo`03001oogoo00Aoo`03001oogoo
049oo`03001oogoo00=oo`03001oogoo045oo`00>Goo00<007ooOol01Woo00<007ooOol017oo00<0
07ooOol0@Goo00<007ooOol017oo00<007ooOol0@Goo000iOol00`00Oomoo`06Ool00`00Oomoo`05
Ool00`00Oomoo`10Ool00`00Oomoo`04Ool00`00Oomoo`11Ool003Uoo`03001oogoo00Eoo`03001o
ogoo00Ioo`03001oogoo03moo`03001oogoo00Ioo`03001oogoo041oo`00>Goo00<007ooOol01Goo
00<007ooOol01Woo00<007ooOol0?goo00<007ooOol01Woo00<007ooOol0@7oo000iOol00`00Oomo
o`05Ool00`00Oomoo`07Ool00`00Oomoo`0nOol00`00Oomoo`06Ool00`00Oomoo`10Ool003Uoo`03
001oogoo00Aoo`03001oogoo00Qoo`03001oogoo03eoo`03001oogoo00Moo`03001oogoo041oo`00
>Goo00<007ooOol017oo00<007ooOol027oo00<007ooOol0?Goo00<007ooOol027oo00<007ooOol0
?goo000iOol00`00Oomoo`04Ool00`00Oomoo`08Ool00`00Oomoo`0mOol00`00Oomoo`08Ool00`00
Oomoo`0oOol003Uoo`03001oogoo00Aoo`03001oogoo00Uoo`03001oogoo03aoo`03001oogoo00Qo
o`03001oogoo03moo`00>Goo00<007ooOol017oo00<007ooOol02Goo00<007ooOol0>goo00<007oo
Ool02Woo00<007ooOol0?Woo000iOol00`00Oomoo`03Ool00`00Oomoo`0:Ool00`00Oomoo`0kOol0
0`00Oomoo`0:Ool00`00Oomoo`0nOol003Uoo`03001oogoo00=oo`03001oogoo00]oo`03001oogoo
03Yoo`03001oogoo00Yoo`03001oogoo03ioo`00>Goo00<007ooOol00goo00<007ooOol02goo00<0
07ooOol0>Woo00<007ooOol02Woo00<007ooOol0?Woo000iOol00`00Oomoo`03Ool00`00Oomoo`0;
Ool00`00Oomoo`0iOol00`00Oomoo`0<Ool00`00Oomoo`0mOol002Uoo`03001oogoo009oo`03001o
ogoo009oo`<000=oo`03001oogoo00=oo`03001oogoo00]oo`03001oogoo03Uoo`03001oogoo00ao
o`03001oogoo03eoo`00:7oo00<007oo00002Goo00<007ooOol00Woo00<007ooOol00goo00<007oo
Ool037oo00<007ooOol0>7oo00<007ooOol037oo00<007ooOol0?Goo000SOol30002Ool00`00Ool0
0007Ool40003Ool20003Ool00`00Oomoo`0=Ool00`00Oomoo`0gOol00`00Oomoo`0=Ool00`00Oomo
o`0mOol002Qoo`03001oo`0000Moo`03001oo`0000Aoo`03001oogoo009oo`03001oogoo00eoo`03
001oogoo03Moo`03001oogoo00eoo`03001oogoo03eoo`00:7oo00<007oo000027oo0P0017oo00<0
07ooOol00Woo00<007ooOol03Woo00<007ooOol0=Woo00<007ooOol03Woo00<007ooOol0?7oo000Y
Ool00`00Oomoo`08Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`0>Ool00`00Oomoo`0f
Ool00`00Oomoo`0>Ool00`00Oomoo`0lOol003Uoo`03001oogoo009oo`03001oogoo00ioo`03001o
ogoo03Eoo`03001oogoo00moo`03001oogoo03aoo`00>Goo00<007ooOol00Woo00<007ooOol03Woo
00<007ooOol0=Goo00<007ooOol03goo00<007ooOol0?7oo000iOol01@00Oomoogoo00004Woo00<0
07ooOol0=7oo00<007ooOol03goo00<007ooOol0?7oo000iOol01@00Oomoogoo00004Woo00<007oo
Ool0<goo00<007ooOol047oo00<007ooOol0?7oo000iOol01@00Oomoogoo00004Woo20009goo2000
4goo00<007ooOol0>goo000iOol01@00Oomoogoo00004Goo0`001Woo100087oo0`001goo0P004Woo
00<007ooOol0>goo000iOol01@00Oomoogoo00003goo0P000Woo00<007ooOol027oo0P0027oo2P00
2Woo0P002Woo00@007oo0000011oo`03001oogoo03]oo`00>Goo00@007ooOol000ioo`8000Aoo`03
001oogoo00Yoo`P000Yoo`H00004Ool00000000;Ool00`00Oomoo`02Ool00`00Oomoo`0=Ool00`00
Oomoo`0kOol003Uoo`04001oogoo000=Ool00`00Oomoo`04Ool00`00Oomoo`09Ool7000?Ool7000;
Ool00`00Oomoo`03Ool00`00Oomoo`0<Ool00`00Oomoo`0kOol003Uoo`04001oogoo000<Ool00`00
Oomoo`05Ool00`00Oomoo`06Ool30007Ool?0007Ool30008Ool00`00Oomoo`04Ool00`00Oomoo`0;
Ool00`00Oomoo`0kOol003Uoo`04001oogoo000;Ool00`00Oomoo`07Ool00`00Oomoo`03Ool2000S
Ool20005Ool00`00Oomoo`06Ool00`00Oomoo`0:Ool00`00Oomoo`0kOol003Uoo`04001oogoo000;
Ool00`00Oomoo`07Ool01000Oomoogoo0P009goo0P000goo00<007ooOol01goo00<007ooOol02Goo
00<007ooOol0>goo000iOol01000Oomoo`002Woo00<007ooOol027oo00@007ooOol002]oo`800003
Ool007oo00Uoo`03001oogoo00Uoo`03001oogoo03Yoo`00>Goo00<007oo00002goo00<007ooOol0
2Goo0P00;Woo0P002goo00<007ooOol027oo00<007ooOol0>Woo000iOol00`00Ool0000:Ool00`00
Oomoo`08Ool3000_Ool01000Ool000002Woo00<007ooOol01goo00<007ooOol0>Woo000YOol00`00
Oomoo`02Ool01000Oomoogoo0`0017oo00<007oo00002Goo00<007ooOol01goo0P000goo00<007oo
Ool0;7oo00D007ooOomoo`0000Yoo`03001oogoo00Ioo`03001oogoo03Yoo`00:7oo00<007oo0000
1goo00<007ooOol017oo00<007oo000027oo00<007ooOol01Woo0P001Goo00<007ooOol0:goo00<0
07ooOol00goo0P002Goo00<007ooOol01Goo00<007ooOol0>Woo000SOol30002Ool00`00Ool00008
Ool00`00Oomoo`03Ool30007Ool00`00Oomoo`05Ool20008Ool00`00Oomoo`0ZOol00`00Oomoo`05
Ool20007Ool00`00Oomoo`05Ool00`00Oomoo`0jOol002Qoo`03001oo`0000Qoo`03001oogoo00=o
o`03001oo`0000Moo`03001oogoo00=oo`8000Yoo`03001oogoo02Yoo`03001oogoo00Moo`03001o
ogoo00Eoo`03001oogoo00Aoo`03001oogoo03Yoo`00:7oo00<007oo00001goo00<007oo000017oo
0P001goo00<007ooOol00goo00<007ooOol02Woo00<007ooOol0:Goo00<007ooOol02Goo0P001Goo
00<007ooOol017oo00<007ooOol0>Woo000YOol00`00Oomoo`07Ool00`00Oomoo`03Ool20006Ool0
0`00Oomoo`02Ool2000>Ool00`00Oomoo`0XOol00`00Oomoo`0;Ool00`00Oomoo`03Ool00`00Oomo
o`04Ool00`00Oomoo`0iOol003Uoo`8000Eoo`03001oogoo009oo`03001oogoo00ioo`03001oogoo
02Qoo`03001oogoo00aoo`8000=oo`03001oogoo00Aoo`03001oogoo03Uoo`00>Goo0P001Goo00D0
07ooOomoo`00019oo`03001oogoo02Ioo`03001oogoo00moo`05001oogooOol00005Ool00`00Oomo
o`0iOol003Uoo`8000Aoo`03001oogoo008001=oo`03001oogoo02Ioo`03001oogoo011oo`80009o
o`03001oogoo009oo`03001oogoo03Uoo`00>Goo0P0017oo00<007oo00005Woo00<007ooOol097oo
00<007ooOol04goo00<007oo000017oo00<007ooOol0>Goo000iOol20003Ool00`00Ool0000GOol0
0`00Oomoo`0TOol00`00Oomoo`0DOol30003Ool00`00Oomoo`0iOol003Uoo`8000=oo`8001Uoo`03
001oogoo029oo`03001oogoo01Moo`05001oogooOol0000kOol001Eoo`<000=oo`03001oogoo009o
o`03001oogoo01Ioo`05001oogooOol0000DOol30003Ool20003Ool00`00Oomoo`0GOol00`00Oomo
o`03Ool00`00Oomoo`0BOol00`00Oomoo`02Ool01P00Ool00000Ool001Eoo`D0009oo`03001oogoo
01aoo`005Goo00<007ooOol01goo00<007oo00005goo00<007ooOol00P0057oo00<007ooOol01Goo
00D007oo001oo`0001Moo`03001oo`0000Aoo`03001oogoo019oo`03001oogoo00Aoo`03001oo`00
008001Ioo`07001oogooOol007oo00007Goo000@Ool30003Ool00`00Oomoo`08Ool00`00Oomoo`0E
Ool4000FOol00`00Oomoo`04Ool01@00Oomoogoo00006Goo00D007ooOomoo`0001Eoo`03001oogoo
00Eoo`04001oo`00000FOol01`00Oomoogoo001oo`0001eoo`005Woo00<007ooOol01Woo0P0067oo
00@007ooOol001Ioo`03001oogoo00Eoo`<001Qoo`8000=oo`03001oogoo01Eoo`03001oogoo00Ao
o`D001Eoo`07001oogooOol007oo00007Goo000EOol00`00Ool00007Ool00`00Oomoo`0EOol30000
0goo001oo`0EOol00`00Ool00007Ool00`00Oomoo`0GOol00`00Oomoo`02Ool00`00Oomoo`0COol0
0`00Ool00007Ool01@00Ool007oo000057oo00L007ooOomoo`00Ool0000MOol001Ioo`03001oogoo
00Ioo`<001Aoo`06001oogoo001oo`005goo00<007ooOol01Woo0`005goo1@005Woo0`001goo0`00
0Woo0P004Goo0P0017oo00<007ooOol077oo000dOol20003Ool2000ROol00`00Oomoo`0HOol00`00
Oomoo`0QOol20004Ool00`00Oomoo`0cOol003=oo`03001oogoo00=oo`8002=oo`8001Moo`03001o
ogoo029oo`8000Eoo`03001oogoo039oo`00<Goo0P001Woo00<007ooOol097oo0P0057oo00<007oo
Ool097oo00<007ooOol017oo0P00<Woo000`Ool00`00Oomoo`05Ool2000XOol3000=Ool4000WOol0
0`00Oomoo`06Ool00`00Oomoo`0_Ool00003Ool000000=<0009oo`001Woo00<007oo00001@001Goo
00<007ooOol00goo00<007ooOol00goo00<007ooOol017oo00<007ooOol00goo0P0017oo00<007oo
Ool00goo0P001Goo00<007ooOol00goo00<007ooOol00goo00<007ooOol017oo00<007ooOol00goo
00<007ooOol00goo00<007ooOol017oo00<007ooOol00goo00<007ooOol00goo00<007ooOol017oo
00<007ooOol00goo00<007ooOol00goo00<007ooOol017oo00<007ooOol00goo00<007ooOol00goo
00<007ooOol00goo0P001Goo00<007ooOol00Woo0P001Goo00<007ooOol017oo00<007ooOol00goo
00<007ooOol00goo00<007ooOol00goo1P0000=oo`00Ool01Woo000>Ool40007Ool00`00Oomoo`0?
Ool2000:Ool3000NOol00`00Oomoo`0MOol00`00Oomoo`0LOol00`00Oomoo`04Ool2000:Ool2000;
Ool00`00Oomoo`0<Ool3000?Ool0019oo`03001oogoo01Aoo`8000aoo`<006Aoo`8000aoo`8001Io
o`80019oo`004goo00<007ooOol04Woo00<007ooOol02goo00@007oo000006Aoo`03001oo`0000eo
o`03001oogoo019oo`03001oogoo019oo`0057oo00<007ooOol03goo0P003Woo00@007oo000006Ao
o`03001oo`0000ioo`80015oo`03001oogoo01=oo`005Goo00<007ooOol03Goo00<007ooOol03Goo
00<007ooOol00P00I7oo00@007ooOol000moo`8000ioo`03001oogoo01Aoo`005Woo00<007ooOol0
2Woo0P0047oo00<007ooOol00P00I7oo00@007ooOol0015oo`8000]oo`03001oogoo01Eoo`005Woo
00<007ooOol027oo0P004Goo00H007ooOol007oo001TOol01@00Oomoogoo00004Woo0P0027oo00<0
07ooOol05Woo000GOol00`00Oomoo`05Ool2000COol01P00Oomoo`00Ool006Eoo`04001oogoo000D
Ool00`00Oomoo`04Ool00`00Oomoo`0GOol001Qoo`04001oogooOol3000DOol01`00Oomoogoo001o
o`0006Eoo`05001oogooOol0000DOol20004Ool00`00Oomoo`0GOol001Qoo`@001Moo`07001oogoo
Ool007oo0000IGoo00<007ooOol00Woo00<007ooOol04goo10006Woo000FOol4000HOol00`00Oomo
o`02Ool00`00Ool0001UOol00`00Oomoo`02Ool00`00Oomoo`0FOol5000FOol0015oo`D000Aoo`03
001oogoo01Eoo`03001oogoo009oo`03001oo`0006Eoo`03001oogoo00=oo`03001oogoo01Aoo`03
001oogoo00=oo`<001=oo`001Woo00<007ooOol00goo1@002Goo00<007ooOol057oo00<007ooOol0
0goo00<007oo0000IGoo00<007ooOol00goo00<007ooOol057oo00<007ooOol01Woo1P001Goo00<0
07ooOol01Goo0006Ool6000?Ool00`00Oomoo`0COol00`00Oomoo`03Ool00`00Ool0001UOol00`00
Oomoo`04Ool00`00Oomoo`0BOol00`00Oomoo`0=Ool60007Ool000Qoo`03001oogoo011oo`03001o
ogoo019oo`03001oogoo00=oo`04001oogoo001UOol00`00Oomoo`04Ool00`00Oomoo`0BOol00`00
Oomoo`0@Ool00`00Oomoo`07Ool000Uoo`03001oogoo011oo`03001oogoo011oo`03001oogoo00Ao
o`04001oogoo001VOol00`00Oomoo`04Ool00`00Oomoo`0AOol00`00Oomoo`0?Ool00`00Oomoo`08
Ool000Yoo`80011oo`03001oogoo011oo`03001oogoo00Aoo`04001oogoo001VOol00`00Oomoo`04
Ool00`00Oomoo`0@Ool00`00Oomoo`0>Ool2000;Ool000aoo`03001oogoo00ioo`03001oogoo00Uo
o`03001oogoo009oo`04001oogooOol300001Goo001oogoo0000IWoo00<007ooOol01Goo00<007oo
Ool03goo00<007ooOol03Goo00<007ooOol02goo000=Ool00`00Oomoo`0=Ool00`00Oomoo`08Ool0
0`00Ool00003Ool01@00Oomoogoo00000goo00@007ooOol006Ioo`03001oogoo00Eoo`03001oogoo
00moo`03001oogoo00aoo`03001oogoo00aoo`003Woo00<007ooOol037oo00<007ooOol027oo00<0
07oo00000Woo00<007ooOol00goo00@007ooOol0009oo`8006Eoo`03001oogoo00Ioo`03001oogoo
00eoo`03001oogoo00aoo`03001oogoo00eoo`003goo00<007ooOol037oo00<007ooOol01goo00<0
07oo00000Woo00<007ooOol00goo00@007ooOol0009oo`03001oogoo06Aoo`03001oogoo00Moo`03
001oogoo00aoo`03001oogoo00]oo`03001oogoo00ioo`0047oo0P0037oo00<007ooOol01goo00D0
07oo001oo`0000Eoo`05001oo`00Ool00002Ool00`00Oomoo`1TOol00`00Oomoo`07Ool00`00Oomo
o`0<Ool00`00Oomoo`0:Ool00`00Oomoo`0?Ool0019oo`03001oogoo00Uoo`03001oogoo00Qoo`03
001oo`0000Moo`04001oogoo0002Ool00`00Oomoo`1TOol00`00Oomoo`08Ool00`00Oomoo`0:Ool0
0`00Oomoo`0:Ool00`00Oomoo`0@Ool001=oo`03001oogoo00Qoo`03001oogoo00Yoo`03001oogoo
00Moo`05001oogooOol0001WOol00`00Oomoo`08Ool00`00Oomoo`09Ool00`00Oomoo`08Ool2000C
Ool001Aoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`05001oogooOol0001WOol0
0`00Oomoo`09Ool00`00Oomoo`08Ool00`00Oomoo`07Ool00`00Oomoo`0COol001Eoo`03001oogoo
00Moo`03001oogoo00Moo`03001oogoo00Uoo`05001oogooOol0001WOol00`00Oomoo`0:Ool00`00
Oomoo`06Ool00`00Oomoo`07Ool00`00Oomoo`0DOol001Ioo`03001oogoo00Ioo`03001oogoo00Io
o`03001oogoo00Yoo`05001oogooOol0001WOol00`00Oomoo`0;Ool00`00Oomoo`05Ool00`00Oomo
o`06Ool00`00Oomoo`0EOol001Moo`03001oogoo00Ioo`03001oogoo00=oo`8000eoo`05001oogoo
Ool0001WOol00`00Oomoo`0<Ool00`00Oomoo`04Ool00`00Oomoo`04Ool2000HOol001Qoo`<000Eo
o`04001oogooOol2000?Ool01@00Oomoogoo0000Igoo00<007ooOol03Goo0P000goo00<007ooOol0
0goo0P006Woo000KOol9000AOol01@00Oomoogoo0000Igoo00<007ooOol03goo2@0077oo000QOol0
0`00Oomoo`0AOol01@00Oomoogoo0000Igoo00<007ooOol04Woo00<007ooOol07goo000QOol00`00
Oomoo`0@Ool00`00Oomoo`02Ool00`00Oomoo`1VOol00`00Oomoo`0AOol00`00Oomoo`0OOol0025o
o`03001oogoo011oo`03001oogoo009oo`03001oogoo06Ioo`03001oogoo011oo`03001oogoo021o
o`008Goo00<007ooOol047oo00<007ooOol00Woo00<007ooOol0IWoo00<007ooOol047oo00<007oo
Ool087oo000ROol00`00Oomoo`0?Ool00`00Oomoo`02Ool00`00Oomoo`1VOol00`00Oomoo`0@Ool0
0`00Oomoo`0POol0029oo`03001oogoo00moo`03001oogoo009oo`03001oogoo06Ioo`03001oogoo
00moo`03001oogoo025oo`008Woo00<007ooOol03goo00<007ooOol00Woo00<007ooOol0IWoo00<0
07ooOol03goo00<007ooOol08Goo000ROol00`00Oomoo`04Ool00`00Oomoo`02Ool00`00Oomoo`02
Ool30003Ool00`00Oomoo`1VOol00`00Oomoo`0?Ool00`00Oomoo`0QOol002=oo`03001oogoo009o
o`03001oo`0000Qoo`8000Aoo`03001oogoo06Moo`03001oogoo00ioo`03001oogoo025oo`008goo
00<007ooOol00Woo00<007oo00001goo10000goo0P00J7oo00<007ooOol03Goo00<007ooOol08Woo
000SOol00`00Oomoo`02Ool00`00Ool00007Ool30004Ool00`00Oomoo`1WOol00`00Oomoo`0=Ool0
0`00Oomoo`0ROol002=oo`03001oogoo009oo`03001oo`0000Qoo`8000Aoo`03001oogoo06Moo`03
001oogoo00eoo`03001oogoo029oo`0097oo00<007ooOol00Woo00<007ooOol01goo0P0017oo00<0
07ooOol0Igoo00<007ooOol037oo00<007ooOol08goo000TOol00`00Oomoo`0;Ool00`00Oomoo`04
Ool00`00Oomoo`1WOol00`00Oomoo`0<Ool00`00Oomoo`0SOol002Aoo`03001oogoo00]oo`03001o
ogoo00Aoo`03001oogoo06Qoo`03001oogoo00]oo`03001oogoo02=oo`0097oo00<007ooOol02goo
00<007ooOol017oo00<007ooOol0J7oo00<007ooOol02Woo00<007ooOol097oo000UOol00`00Oomo
o`0:Ool00`00Oomoo`04Ool00`00Oomoo`1XOol00`00Oomoo`0:Ool00`00Oomoo`0TOol002Eoo`03
001oogoo00Yoo`03001oogoo00Aoo`03001oogoo06Qoo`03001oogoo00Uoo`03001oogoo02Eoo`00
9Woo00<007ooOol027oo00<007ooOol01Goo00<007ooOol0J7oo00<007ooOol02Goo00<007ooOol0
9Goo000VOol00`00Oomoo`08Ool00`00Oomoo`05Ool00`00Oomoo`1YOol00`00Oomoo`08Ool00`00
Oomoo`0UOol002Moo`03001oogoo00Moo`03001oogoo00Eoo`03001oogoo06Uoo`03001oogoo00Mo
o`03001oogoo02Ioo`009goo00<007ooOol01goo00<007ooOol01Goo00<007ooOol0JGoo00<007oo
Ool01goo00<007ooOol09Woo000WOol00`00Oomoo`06Ool00`00Oomoo`06Ool00`00Oomoo`1YOol0
0`00Oomoo`07Ool00`00Oomoo`0VOol002Qoo`03001oogoo00Eoo`03001oogoo00Ioo`03001oogoo
06Yoo`03001oogoo00Eoo`03001oogoo02Moo`00:7oo00<007ooOol01Goo00<007ooOol01Woo00<0
07ooOol0JWoo00<007ooOol01Goo00<007ooOol09goo000XOol00`00Oomoo`05Ool00`00Oomoo`06
Ool00`00Oomoo`1ZOol00`00Oomoo`05Ool00`00Oomoo`0WOol002Uoo`03001oogoo00=oo`03001o
ogoo00Moo`03001oogoo06]oo`03001oogoo00=oo`03001oogoo02Qoo`00:Goo00<007ooOol00goo
00<007ooOol01goo00<007ooOol0Jgoo00<007ooOol00goo00<007ooOol0:7oo000YOol20003Ool0
1000Oomoogoo0P001Goo00<007ooOol0Jgoo00<007ooOol00goo00<007ooOol0:7oo000XOol00`00
Ool00003Ool01`00Oomoogoo001oo`0000Aoo`03001oogoo06aoo`05001oogooOol0000[Ool002Qo
o`06001oo`00001oo`0017oo00<007oo000017oo0P00KWoo00<007oo0000;7oo000XOol00`00Ool0
00030004Ool20005Ool00`00Oomoo`1^Ool2000/Ool002Qoo`03001oo`0000Moo`03001oogoo00Ao
o`03001oogoo09aoo`00:Goo00<007ooOol01goo0P0017oo00<007ooOol0W7oo000iOol00`00Oomo
o`2LOol00001\
\>"],
  ImageRangeCache->{{{0, 215}, {132.438, 0}} -> {-4.51951, -0.643753, 
  0.0792512, 0.00972161}}]
}, Open  ]],

Cell[TextData[
"Note, that not all of the zero-crossings are at the edge locations. For \
which value of variance \[Sigma] are the zero-crossing locations in error? \
How does \[Sigma] compare to pulse width? \nEdge localization error occurs \
with a LofG operator which has a large region of support as compared to the \
pulse width. Consider the region of support of the impulse response signal \
for 3 values of variance \[Sigma]. It can be verified that LofG kernels of \
dimensions at most twice the width of a line will result in negligible edge \
positioning error."], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Plot[
      Evaluate[h[x - 4] /. \[Sigma] \[Rule] {1, 2, 4}], {x, \(-2\), 12}, 
      PlotRange \[Rule] All]; \)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.159864 0.0680272 0.421698 0.406985 [
[.02381 .4092 -6 -9 ]
[.02381 .4092 6 0 ]
[.29592 .4092 -3 -9 ]
[.29592 .4092 3 0 ]
[.43197 .4092 -3 -9 ]
[.43197 .4092 3 0 ]
[.56803 .4092 -3 -9 ]
[.56803 .4092 3 0 ]
[.70408 .4092 -3 -9 ]
[.70408 .4092 3 0 ]
[.84014 .4092 -6 -9 ]
[.84014 .4092 6 0 ]
[.97619 .4092 -6 -9 ]
[.97619 .4092 6 0 ]
[.14736 .01471 -12 -4.5 ]
[.14736 .01471 0 4.5 ]
[.14736 .09611 -24 -4.5 ]
[.14736 .09611 0 4.5 ]
[.14736 .17751 -24 -4.5 ]
[.14736 .17751 0 4.5 ]
[.14736 .2589 -24 -4.5 ]
[.14736 .2589 0 4.5 ]
[.14736 .3403 -24 -4.5 ]
[.14736 .3403 0 4.5 ]
[.14736 .50309 -18 -4.5 ]
[.14736 .50309 0 4.5 ]
[.14736 .58449 -18 -4.5 ]
[.14736 .58449 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.02381 .4217 m
.02381 .42795 L
s
[(-2)] .02381 .4092 0 1 Mshowa
.29592 .4217 m
.29592 .42795 L
s
[(2)] .29592 .4092 0 1 Mshowa
.43197 .4217 m
.43197 .42795 L
s
[(4)] .43197 .4092 0 1 Mshowa
.56803 .4217 m
.56803 .42795 L
s
[(6)] .56803 .4092 0 1 Mshowa
.70408 .4217 m
.70408 .42795 L
s
[(8)] .70408 .4092 0 1 Mshowa
.84014 .4217 m
.84014 .42795 L
s
[(10)] .84014 .4092 0 1 Mshowa
.97619 .4217 m
.97619 .42795 L
s
[(12)] .97619 .4092 0 1 Mshowa
.125 Mabswid
.05782 .4217 m
.05782 .42545 L
s
.09184 .4217 m
.09184 .42545 L
s
.12585 .4217 m
.12585 .42545 L
s
.19388 .4217 m
.19388 .42545 L
s
.22789 .4217 m
.22789 .42545 L
s
.2619 .4217 m
.2619 .42545 L
s
.32993 .4217 m
.32993 .42545 L
s
.36395 .4217 m
.36395 .42545 L
s
.39796 .4217 m
.39796 .42545 L
s
.46599 .4217 m
.46599 .42545 L
s
.5 .4217 m
.5 .42545 L
s
.53401 .4217 m
.53401 .42545 L
s
.60204 .4217 m
.60204 .42545 L
s
.63605 .4217 m
.63605 .42545 L
s
.67007 .4217 m
.67007 .42545 L
s
.7381 .4217 m
.7381 .42545 L
s
.77211 .4217 m
.77211 .42545 L
s
.80612 .4217 m
.80612 .42545 L
s
.87415 .4217 m
.87415 .42545 L
s
.90816 .4217 m
.90816 .42545 L
s
.94218 .4217 m
.94218 .42545 L
s
.25 Mabswid
0 .4217 m
1 .4217 L
s
.15986 .01471 m
.16611 .01471 L
s
[(-1)] .14736 .01471 1 0 Mshowa
.15986 .09611 m
.16611 .09611 L
s
[(-0.8)] .14736 .09611 1 0 Mshowa
.15986 .17751 m
.16611 .17751 L
s
[(-0.6)] .14736 .17751 1 0 Mshowa
.15986 .2589 m
.16611 .2589 L
s
[(-0.4)] .14736 .2589 1 0 Mshowa
.15986 .3403 m
.16611 .3403 L
s
[(-0.2)] .14736 .3403 1 0 Mshowa
.15986 .50309 m
.16611 .50309 L
s
[(0.2)] .14736 .50309 1 0 Mshowa
.15986 .58449 m
.16611 .58449 L
s
[(0.4)] .14736 .58449 1 0 Mshowa
.125 Mabswid
.15986 .03506 m
.16361 .03506 L
s
.15986 .05541 m
.16361 .05541 L
s
.15986 .07576 m
.16361 .07576 L
s
.15986 .11646 m
.16361 .11646 L
s
.15986 .13681 m
.16361 .13681 L
s
.15986 .15716 m
.16361 .15716 L
s
.15986 .19786 m
.16361 .19786 L
s
.15986 .21821 m
.16361 .21821 L
s
.15986 .23855 m
.16361 .23855 L
s
.15986 .27925 m
.16361 .27925 L
s
.15986 .2996 m
.16361 .2996 L
s
.15986 .31995 m
.16361 .31995 L
s
.15986 .36065 m
.16361 .36065 L
s
.15986 .381 m
.16361 .381 L
s
.15986 .40135 m
.16361 .40135 L
s
.15986 .44205 m
.16361 .44205 L
s
.15986 .4624 m
.16361 .4624 L
s
.15986 .48275 m
.16361 .48275 L
s
.15986 .52344 m
.16361 .52344 L
s
.15986 .54379 m
.16361 .54379 L
s
.15986 .56414 m
.16361 .56414 L
s
.15986 .60484 m
.16361 .60484 L
s
.25 Mabswid
.15986 0 m
.15986 .61803 L
s
.5 Mabswid
.02381 .4217 m
.02605 .4217 L
.02846 .4217 L
.03279 .4217 L
.03543 .4217 L
.03793 .4217 L
.04262 .4217 L
.04502 .4217 L
.04756 .4217 L
.05212 .4217 L
.05704 .4217 L
.05983 .4217 L
.06244 .4217 L
.06504 .4217 L
.06788 .4217 L
.07305 .42171 L
.07807 .42171 L
.08274 .42172 L
.08829 .42173 L
.09331 .42174 L
.09911 .42176 L
.10458 .42178 L
.10923 .42181 L
.11434 .42185 L
.11968 .42191 L
.12466 .42199 L
.12932 .42208 L
.13357 .42219 L
.13848 .42235 L
.14313 .42254 L
.14772 .42278 L
.15278 .42312 L
.15807 .42357 L
.16304 .4241 L
.1719 .42541 L
.17689 .4264 L
.18146 .4275 L
.19126 .43066 L
.20038 .43481 L
.21039 .44113 L
.22108 .45039 L
.23133 .46215 L
.24243 .47845 L
.26258 .51703 L
.28207 .56014 L
.2924 .58089 L
.29809 .59031 L
.3009 .5942 L
.3035 .59727 L
.30617 .59984 L
Mistroke
.30859 .60159 L
.30997 .60233 L
.31128 .60285 L
.31199 .60305 L
.31265 .60319 L
.31338 .60328 L
.31414 .60332 L
.3153 .60324 L
.31654 .60298 L
.31771 .60255 L
.31878 .60201 L
.32003 .60118 L
.32139 .60005 L
.32386 .59733 L
.32614 .59404 L
.32866 .58951 L
.33376 .57735 L
.33848 .56239 L
.3429 .54507 L
.35276 .49522 L
.36313 .42761 L
.38164 .28159 L
.39194 .19795 L
.40165 .12642 L
.41037 .07377 L
.41528 .05056 L
.4198 .03399 L
.42216 .02731 L
.42436 .02233 L
.42677 .01828 L
.42812 .01667 L
.42935 .01562 L
.43064 .01495 L
.43184 .01472 L
.43315 .01489 L
.43381 .01516 L
.43454 .01558 L
.43576 .0166 L
.43707 .01814 L
.43945 .02206 L
.44199 .02784 L
.44478 .03602 L
.45039 .05809 L
.46042 .11398 L
.48164 .27615 L
.50095 .42851 L
.51057 .49161 L
.51564 .51961 L
.52101 .54491 L
.5257 .5632 L
Mistroke
.53086 .5792 L
.53313 .58486 L
.53556 .59005 L
.53787 .59414 L
.53996 .59717 L
.5425 .59999 L
.54389 .60116 L
.54521 .60203 L
.54642 .60263 L
.54754 .60301 L
.54877 .60326 L
.55007 .60331 L
.55139 .60317 L
.55212 .60301 L
.5528 .6028 L
.5541 .60227 L
.55534 .6016 L
.5581 .59956 L
.56111 .59654 L
.56617 .58983 L
.57155 .58089 L
.5812 .56159 L
.60091 .518 L
.61897 .4827 L
.62822 .46815 L
.63834 .45521 L
.6485 .44515 L
.6592 .43732 L
.66449 .43433 L
.66948 .43196 L
.67882 .42854 L
.68406 .4271 L
.68888 .42601 L
.69414 .42506 L
.69978 .42424 L
.70485 .42367 L
.70948 .42325 L
.71419 .42291 L
.71856 .42265 L
.72363 .42242 L
.72915 .42223 L
.73402 .4221 L
.7392 .42199 L
.74458 .42191 L
.74952 .42185 L
.75495 .42181 L
.76067 .42178 L
.76565 .42175 L
.7703 .42174 L
.7754 .42173 L
Mistroke
.77805 .42172 L
.78086 .42172 L
.78616 .42171 L
.79106 .42171 L
.79634 .4217 L
.79934 .4217 L
.80215 .4217 L
.80475 .4217 L
.80722 .4217 L
.81185 .4217 L
.81444 .4217 L
.81684 .4217 L
.81968 .4217 L
.82229 .4217 L
.82736 .4217 L
.83003 .4217 L
.83285 .4217 L
.83759 .4217 L
.84029 .4217 L
.8428 .4217 L
.84521 .4217 L
.8475 .4217 L
.85178 .4217 L
.85417 .4217 L
.85639 .4217 L
.85901 .4217 L
.86141 .4217 L
.86603 .4217 L
.86847 .4217 L
.87103 .4217 L
.87534 .4217 L
.87779 .4217 L
.88006 .4217 L
.88274 .4217 L
.88528 .4217 L
.89002 .4217 L
.89267 .4217 L
.89512 .4217 L
.89781 .4217 L
.90066 .4217 L
.90319 .4217 L
.90559 .4217 L
.91009 .4217 L
.91261 .4217 L
.91494 .4217 L
.9175 .4217 L
.92022 .4217 L
.9226 .4217 L
.92517 .4217 L
.9276 .4217 L
Mistroke
.92983 .4217 L
.93407 .4217 L
.9362 .4217 L
.93853 .4217 L
.94088 .4217 L
.94342 .4217 L
.94583 .4217 L
.94805 .4217 L
.95226 .4217 L
.95438 .4217 L
.95672 .4217 L
.95924 .4217 L
.96156 .4217 L
.9641 .4217 L
.96677 .4217 L
.9691 .4217 L
.97127 .4217 L
.97365 .4217 L
.97619 .4217 L
Mfstroke
.02381 .43074 m
.06244 .43793 L
.10458 .44864 L
.12507 .45437 L
.14415 .45943 L
.16254 .46354 L
.17284 .46528 L
.1773 .46588 L
.18221 .46642 L
.18454 .46662 L
.18704 .4668 L
.18842 .46688 L
.18969 .46695 L
.19097 .467 L
.19216 .46704 L
.19325 .46707 L
.19442 .46709 L
.19571 .4671 L
.19688 .4671 L
.19798 .46709 L
.19918 .46707 L
.20031 .46704 L
.20135 .46701 L
.20385 .46689 L
.20617 .46673 L
.20872 .46651 L
.21146 .46621 L
.21705 .46539 L
.22214 .4644 L
.23205 .46177 L
.24122 .45847 L
.26198 .44785 L
.28065 .43469 L
.30125 .41677 L
.34145 .37625 L
.35993 .35806 L
.38014 .34081 L
.38983 .33402 L
.40018 .3281 L
.40591 .32547 L
.41111 .3235 L
.41634 .32195 L
.41889 .32136 L
.42128 .32089 L
.4237 .32051 L
.42591 .32025 L
.42717 .32014 L
.42836 .32006 L
.42963 .32 L
.43034 .31997 L
Mistroke
.431 .31996 L
.43165 .31995 L
.43235 .31995 L
.43362 .31997 L
.43485 .32002 L
.43599 .32008 L
.43722 .32018 L
.43857 .32031 L
.44129 .32067 L
.44371 .32108 L
.44591 .32154 L
.45084 .32286 L
.45975 .3262 L
.46969 .33131 L
.47887 .33721 L
.49964 .35403 L
.53896 .3932 L
.57677 .42935 L
.59615 .44411 L
.60612 .45033 L
.61702 .45599 L
.62743 .46027 L
.6371 .46327 L
.64246 .46454 L
.64731 .46546 L
.65001 .46588 L
.65292 .46626 L
.65548 .46653 L
.65821 .46676 L
.65953 .46685 L
.66078 .46693 L
.66199 .46698 L
.66312 .46703 L
.66418 .46706 L
.66531 .46708 L
.66645 .4671 L
.6677 .4671 L
.66836 .4671 L
.66905 .4671 L
.67029 .46708 L
.67098 .46706 L
.67162 .46705 L
.67308 .467 L
.67552 .46688 L
.67813 .46672 L
.6838 .46621 L
.68916 .46556 L
.69918 .46395 L
.71917 .45958 L
.73762 .45471 L
Mistroke
.77699 .44388 L
.81484 .43512 L
.83427 .43165 L
.85515 .4287 L
.8763 .42645 L
.8964 .42489 L
.90599 .42432 L
.91622 .4238 L
.93461 .4231 L
.9449 .4228 L
.95602 .42254 L
.97619 .42221 L
Mfstroke
.02381 .43202 m
.04262 .43127 L
.06244 .43024 L
.10458 .42722 L
.14264 .42359 L
.18314 .41895 L
.22214 .41404 L
.26358 .40874 L
.30351 .40401 L
.34193 .40025 L
.36176 .39873 L
.3719 .39808 L
.38279 .39749 L
.39299 .39704 L
.40233 .39671 L
.40681 .39659 L
.41171 .39647 L
.41634 .39639 L
.42063 .39633 L
.42327 .3963 L
.4257 .39628 L
.42698 .39627 L
.42838 .39627 L
.42908 .39627 L
.42983 .39626 L
.43055 .39626 L
.4312 .39626 L
.43247 .39626 L
.43364 .39626 L
.43494 .39627 L
.43559 .39627 L
.43631 .39627 L
.43751 .39628 L
.43881 .39629 L
.44115 .3963 L
.44341 .39633 L
.44588 .39636 L
.45086 .39644 L
.45976 .39666 L
.47003 .397 L
.47937 .3974 L
.50032 .39861 L
.5195 .40004 L
.5403 .40192 L
.58122 .4064 L
.62062 .41131 L
.65851 .41618 L
.69885 .4211 L
.73767 .42525 L
.77895 .42876 L
Mistroke
.79958 .43012 L
.81871 .43115 L
.83724 .43192 L
.85696 .43251 L
.86727 .43273 L
.87269 .43282 L
.87841 .4329 L
.88343 .43295 L
.88608 .43298 L
.88893 .433 L
.89154 .43302 L
.89393 .43303 L
.89632 .43304 L
.89751 .43304 L
.89859 .43304 L
.89974 .43305 L
.90097 .43305 L
.90205 .43305 L
.9032 .43305 L
.90445 .43305 L
.90562 .43305 L
.9069 .43305 L
.90762 .43304 L
.90827 .43304 L
.91081 .43304 L
.91356 .43303 L
.91854 .433 L
.92321 .43296 L
.92814 .43291 L
.93697 .43281 L
.95659 .43247 L
.97491 .43206 L
.97619 .43203 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{216, 133.438},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003H0000QA000`40O003h00Of7oo000SOol00`00
Oomoo`2bOol002=oo`03001oogoo0;9oo`006goo1@000goo00<007ooOol0/Woo000MOol00`00Oomo
o`03Ool00`00Oomoo`2bOol001Moo`<000=oo`03001oogoo00=oo`8003Ioo`@007Uoo`007Goo00<0
07ooOol00goo00<007ooOol0=Goo00@007ooOol007Uoo`007Goo00<007ooOol00goo00<007ooOol0
=7oo00<007ooOol00Woo00<007ooOol0MWoo000LOol20005Ool00`00Oomoo`0dOol00`00Oomoo`02
Ool00`00Oomoo`1fOol002=oo`8003Eoo`03001oogoo009oo`03001oogoo07Ioo`008goo00<007oo
Ool0=7oo00<007ooOol00Woo00<007ooOol0MWoo000SOol00`00Oomoo`0cOol00`00Oomoo`03Ool0
0`00Oomoo`1fOol002=oo`03001oogoo03=oo`03001oogoo00Aoo`03001oogoo07Eoo`008goo0P00
=7oo00<007ooOol017oo00<007ooOol0MGoo000SOol00`00Oomoo`0cOol00`00Oomoo`04Ool00`00
Oomoo`1eOol002=oo`03001oogoo039oo`03001oogoo00Eoo`03001oogoo07Eoo`008goo00<007oo
Ool0<Woo00<007ooOol01Woo00<007ooOol0M7oo000SOol00`00Oomoo`0bOol00`00Oomoo`06Ool0
0`00Oomoo`1dOol002=oo`8003=oo`03001oogoo00Ioo`03001oogoo07Aoo`008goo00<007ooOol0
<Woo00<007ooOol01Woo00<007ooOol0M7oo000COol00`00Oomoo`02Ool00`00Oomoo`02Ool00`00
Oomoo`03Ool00`00Oomoo`0aOol00`00Oomoo`08Ool00`00Oomoo`1cOol0019oo`03001oo`0000Mo
o`03001oo`0000Aoo`03001oogoo035oo`03001oogoo00Qoo`03001oogoo07=oo`003Goo0`000Woo
00<007oo00001goo00<007oo000017oo0P00<Woo00<007ooOol027oo00<007ooOol0Lgoo000BOol0
0`00Ool00008Ool00`00Oomoo`03Ool00`00Oomoo`0aOol00`00Oomoo`08Ool00`00Oomoo`1cOol0
019oo`03001oo`0000Moo`03001oo`0000Aoo`03001oogoo035oo`03001oogoo00Uoo`03001oogoo
079oo`004goo00<007ooOol01goo00<007ooOol00goo00<007ooOol0<Goo00<007ooOol02Goo00<0
07ooOol0LWoo000SOol2000aOol00`00Oomoo`0:Ool00`00Oomoo`1bOol002=oo`03001oogoo031o
o`03001oogoo00Yoo`03001oogoo079oo`008goo00<007ooOol0<7oo00<007ooOol02Woo00<007oo
Ool0LWoo000SOol00`00Oomoo`0`Ool00`00Oomoo`0:Ool00`00Oomoo`1bOol002=oo`80035oo`03
001oogoo00Yoo`03001oogoo079oo`008goo00<007ooOol0<7oo00<007ooOol02goo00<007ooOol0
LGoo000SOol00`00Oomoo`0_Ool00`00Oomoo`0<Ool00`00Oomoo`1aOol002=oo`03001oogoo02mo
o`03001oogoo00aoo`03001oogoo075oo`008goo00<007ooOol0;goo00<007ooOol037oo00<007oo
Ool0LGoo000SOol2000`Ool00`00Oomoo`0<Ool00`00Oomoo`1aOol002=oo`03001oogoo02moo`03
001oogoo00aoo`03001oogoo075oo`004goo00<007ooOol00Woo00@007ooOomoo`8000Eoo`03001o
ogoo02moo`03001oogoo00aoo`03001oogoo075oo`004Woo00<007oo00001goo00<007oo000017oo
00<007ooOol0;goo00<007ooOol037oo00<007ooOol0LGoo000=Ool30002Ool00`00Ool00007Ool0
0`00Ool00004Ool2000`Ool00`00Oomoo`0=Ool00`00Oomoo`1`Ool0019oo`03001oo`0000Moo`80
00Eoo`03001oogoo02ioo`03001oogoo00ioo`03001oogoo071oo`004Woo00<007oo00001goo00<0
07ooOol017oo00<007ooOol0;Woo00<007ooOol03Woo00<007ooOol0L7oo000COol00`00Oomoo`07
Ool20004Ool00`00Oomoo`0^Ool00`00Oomoo`0>Ool00`00Oomoo`1`Ool002=oo`8002moo`03001o
ogoo00ioo`03001oogoo071oo`008goo00<007ooOol0;Woo00<007ooOol03Woo00<007ooOol0L7oo
000SOol00`00Oomoo`0^Ool00`00Oomoo`0>Ool00`00Oomoo`1`Ool002=oo`03001oogoo02ioo`03
001oogoo00ioo`03001oogoo071oo`008goo00<007ooOol0;Woo00<007ooOol03Woo00<007ooOol0
L7oo000SOol2000^Ool00`00Oomoo`0@Ool00`00Oomoo`1_Ool002=oo`03001oogoo02eoo`03001o
ogoo011oo`03001oogoo06moo`008goo00<007ooOol0;Goo00<007ooOol047oo00<007ooOol0Kgoo
000SOol00`00Oomoo`0]Ool00`00Oomoo`0@Ool00`00Oomoo`1_Ool002=oo`8002ioo`03001oogoo
011oo`03001oogoo06moo`008goo00<007ooOol0;Goo00<007ooOol047oo00<007ooOol0Kgoo000C
Ool00`00Oomoo`02Ool00`00Oomoo`02Ool30003Ool00`00Oomoo`0]Ool00`00Oomoo`0@Ool00`00
Oomoo`1_Ool0019oo`03001oo`0000Uoo`03001oogoo009oo`03001oogoo02eoo`03001oogoo011o
o`03001oogoo06moo`003Goo0`000Woo00<007oo00001goo10000goo0P00;Woo00<007ooOol04Goo
00<007ooOol0KWoo000BOol00`00Ool00007Ool00`00Ool00004Ool00`00Oomoo`0/Ool00`00Oomo
o`0BOol00`00Oomoo`1^Ool0019oo`03001oo`0000Qoo`8000Aoo`03001oogoo02aoo`03001oogoo
019oo`03001oogoo06ioo`004goo00<007ooOol027oo00<007ooOol00Woo00<007ooOol0;7oo00<0
07ooOol04Woo00<007ooOol0KWoo000SOol00`00Oomoo`0/Ool00`00Oomoo`0BOol00`00Oomoo`1^
Ool002=oo`8002eoo`03001oogoo019oo`03001oogoo06ioo`008goo00<007ooOol0;7oo00<007oo
Ool04Woo00<007ooOol0KWoo000SOol00`00Oomoo`0/Ool00`00Oomoo`0BOol00`00Oomoo`1^Ool0
02=oo`03001oogoo02aoo`03001oogoo01=oo`03001oogoo06eoo`008goo0P00;7oo00<007ooOol0
57oo00<007ooOol0KGoo000SOol00`00Oomoo`0[Ool00`00Oomoo`0DOol00`00Oomoo`1]Ool002=o
o`03001oogoo02]oo`03001oogoo01Aoo`03001oogoo06eoo`008goo00<007ooOol0:goo00<007oo
Ool057oo00<007ooOol0KGoo000SOol2000/Ool00`00Oomoo`06Ool60008Ool00`00Oomoo`1]Ool0
02=oo`03001oogoo02]oo`03001oogoo00=oo`@000Aoo`<000Ioo`03001oogoo06eoo`008goo00<0
07ooOol0:goo00<007ooOol00Woo00<007ooOol02Goo0P0017oo00<007ooOol0KGoo000COol00`00
Oomoo`02Ool01000Oomoogoo0`0017oo00<007ooOol0:goo00<007ooOol00P003Woo0P000goo00<0
07ooOol0K7oo000BOol00`00Ool00007Ool00`00Oomoo`04Ool00`00Oomoo`0ZOol01000Oomoo`00
4Woo0P0000=oo`00Ool0KGoo000=Ool30002Ool00`00Ool00008Ool00`00Oomoo`03Ool2000[Ool0
0`00Ool0000EOol2001^Ool0019oo`03001oo`0000Qoo`03001oogoo00=oo`03001oogoo02Yoo`80
01Moo`03001oogoo06aoo`004Woo00<007oo00001goo00<007oo000017oo00<007ooOol0:7oo0`00
67oo0P00KGoo000COol00`00Oomoo`07Ool00`00Oomoo`03Ool00`00Oomoo`0WOol01000Oomoo`00
67oo00<007oo0000K7oo000SOol2000WOol01@00Oomoogoo000067oo00@007ooOol006]oo`008goo
00<007ooOol09Goo00<007ooOol00Woo00<007ooOol05Woo00D007ooOomoo`0006Yoo`001goo0`00
6Goo00<007ooOol067oo0`002Goo00<007ooOol00goo00<007ooOol02Goo0`002goo00D007ooOomo
o`0000Uoo`8001aoo`03001oogoo01Eoo`D0009oo`03001oogoo01=oo`D00004Ool000000004Ool0
00Moo`03001oogoo01Uoo`03001oogoo01Qoo`03001oogoo00Qoo`03001oogoo00=oo`03001oogoo
00]oo`03001oogoo00Yoo`03001oogoo009oo`03001oogoo00Ioo`03001oo`0001Yoo`03001oo`00
01Qoo`07001oogooOol007oo00005Woo00D007ooOomoo`0000Ioo`000Woo0`000goo00<007ooOol0
67oo0P006Woo00<007ooOol01Woo00<007ooOol017oo00<007ooOol02Goo10002goo00<007ooOol0
0goo00<007ooOol01Goo00<007oo00006Woo00<007oo000067oo00L007ooOomoo`00Ool0000FOol0
0`00Oomoo`02Ool00`00Oomoo`03Ool000Qoo`03001oogoo01Qoo`03001oogoo01Uoo`03001oogoo
00Eoo`03001oogoo00Eoo`03001oogoo00Uoo`03001oo`0000aoo`03001oogoo00Aoo`03001oogoo
00Aoo`8001aoo`03001oogoo01Moo`07001oogooOol007oo00005Woo00<007ooOol00Woo00<007oo
Ool00goo0007Ool00`00Ool0000IOol00`00Oomoo`0HOol00`00Ool00005Ool00`00Oomoo`06Ool0
0`00Oomoo`0:Ool2000<Ool00`00Oomoo`05Ool00`00Oomoo`03Ool00`00Oomoo`0JOol00`00Ool0
000HOol01`00Oomoogoo001oo`0001Ioo`07001oogooOol007oo000017oo0008Ool00`00Oomoo`0H
Ool00`00Oomoo`0IOol00`00Oomoo`03Ool00`00Oomoo`07Ool00`00Oomoo`07Ool80009Ool00`00
Oomoo`06Ool00`00Oomoo`03Ool2000KOol00`00Oomoo`0FOol20004Ool00`00Oomoo`0DOol20004
Ool00`00Oomoo`03Ool002=oo`03001oogoo01mooa@000Qooa40009oo`03001oogoo065oo`008goo
0P006Goo20002Goo00<007ooOol067oo00<007ooOol01Goo1P00H7oo000SOol00`00Oomoo`0?Ool9
0005Ool00`00Oomoo`09Ool00`00Oomoo`0IOol00`00Oomoo`08Ool00`00Ool00008001GOol002=o
o`03001oogoo00Moo`P000eoo`03001oogoo00Uoo`03001oogoo01Yoo`03001oogoo00Uoo`8000Qo
o`P004moo`008goo2P0057oo00<007ooOol02Woo00<007ooOol06Woo00<007ooOol02goo00<007oo
Ool03Goo2000Agoo00000goo0000003C0002Ool000Ioo`03001oogoo00Aoo`03001oogoo00=oo`X0
00Ioo`03001oo`0000<00003Ool007oo00Eoo`03001oogoo00Eoo`03001oogoo009oo`<000Ioo`03
001oogoo00Aoo`03001oogoo00Aoo`03001oogoo00Eoo`03001oogoo00Aoo`03001oogoo00Aoo`03
001oogoo00Aoo`03001oogoo00Aoo`03001oo`0000Eoo`03001oogoo00Aoo`03001oogoo00Aoo`03
001oo`0000<00004Ool007ooOol@0003Ool00`00Oomoo`04Ool00`00Ool0000;00000goo001oo`05
Ool00`00Oomoo`04Ool00`00Oomoo`05Ool000Ioo`d0011oo`03001oogoo00=oo`80019oo`03001o
ogoo00ioo`03001oogoo01Yoo`03001oogoo00ioo`03001oogoo011oo`8001QoobP000Moo`002Woo
1P004goo00<007ooOol01Goo0P003goo00<007ooOol03goo00<007ooOol06Woo00<007ooOol03goo
00<007ooOol03Goo0P007Woo10009goo000@Ool3000@Ool20008Ool2000;Ool2000BOol00`00Oomo
o`0JOol00`00Oomoo`0@Ool00`00Oomoo`0:Ool2000LOol4000[Ool001=oo`<000eoo`03001oogoo
00Uoo`03001oogoo00Moo`03001oogoo015oo`03001oogoo01aoo`03001oogoo011oo`8000Uoo`03
001oogoo01Moo`D002moo`005Woo0`002Woo00<007ooOol02Woo00<007ooOol017oo0P0057oo00<0
07ooOol077oo00<007ooOol04Woo0P001Woo00<007ooOol057oo1000=7oo000IOol50005Ool00`00
Oomoo`0;Ool01000Oomoogoo0P005Woo00<007ooOol077oo00<007ooOol057oo0P000goo00<007oo
Ool04Goo1000>7oo000NOol400000goo0000000=Ool3000HOol00`00Oomoo`0LOol00`00Oomoo`0F
Ool3000@Ool4000lOol0029ooa000003Ool007oo01Qoo`03001oogoo01aoo`03001oogoo01Qooa40
041oo`008goo00<007ooOol03Goo00<007ooOol05goo00<007ooOol077oo00<007ooOol05goo00<0
07ooOol0Cgoo000SOol00`00Oomoo`0>Ool00`00Oomoo`0FOol00`00Oomoo`0LOol00`00Oomoo`0F
Ool00`00Oomoo`1@Ool002=oo`03001oogoo00ioo`03001oogoo01Eoo`03001oogoo01ioo`03001o
ogoo01Eoo`03001oogoo051oo`008goo0P0047oo00<007ooOol057oo00<007ooOol07Woo00<007oo
Ool057oo00<007ooOol0DGoo000SOol00`00Oomoo`0?Ool00`00Oomoo`0DOol00`00Oomoo`0NOol0
0`00Oomoo`0COol00`00Oomoo`1BOol001=oo`03001oogoo009oo`04001oogooOol30004Ool00`00
Oomoo`0@Ool00`00Oomoo`0COol00`00Oomoo`0NOol00`00Oomoo`0COol00`00Oomoo`1BOol0019o
o`03001oo`0000Moo`03001oogoo00Aoo`03001oogoo015oo`03001oogoo019oo`03001oogoo01io
o`03001oogoo019oo`03001oogoo05=oo`004Woo00<007oo000027oo00<007ooOol00goo0P004Woo
00<007ooOol04Woo00<007ooOol07Woo00<007ooOol04Woo00<007ooOol0Dgoo000BOol00`00Ool0
0008Ool00`00Oomoo`03Ool00`00Oomoo`0BOol00`00Oomoo`0@Ool00`00Oomoo`0POol00`00Oomo
o`0@Ool00`00Oomoo`1DOol0019oo`03001oo`0000Moo`03001oo`0000Aoo`03001oogoo019oo`03
001oogoo011oo`03001oogoo021oo`03001oogoo011oo`03001oogoo05Aoo`004goo00<007ooOol0
1goo00<007ooOol00goo00<007ooOol04goo00<007ooOol03goo00<007ooOol087oo00<007ooOol0
3goo00<007ooOol0EGoo000SOol2000DOol00`00Oomoo`0?Ool00`00Oomoo`0POol00`00Oomoo`0?
Ool00`00Oomoo`1EOol002=oo`03001oogoo01Aoo`03001oogoo00ioo`03001oogoo021oo`03001o
ogoo00ioo`03001oogoo05Ioo`008goo00<007ooOol057oo00<007ooOol03Woo00<007ooOol087oo
00<007ooOol03Woo00<007ooOol0EWoo000SOol00`00Oomoo`0EOol00`00Oomoo`0<Ool00`00Oomo
o`0ROol00`00Oomoo`0<Ool00`00Oomoo`1GOol002=oo`03001oogoo01Eoo`03001oogoo00aoo`03
001oogoo029oo`03001oogoo00aoo`03001oogoo05Moo`008goo0P005goo00<007ooOol02goo00<0
07ooOol08Woo00<007ooOol037oo00<007ooOol0Egoo000SOol00`00Oomoo`0FOol00`00Oomoo`0;
Ool00`00Oomoo`0ROol00`00Oomoo`0;Ool00`00Oomoo`1HOol002=oo`03001oogoo01Moo`03001o
ogoo00Uoo`03001oogoo02Aoo`03001oogoo00Yoo`03001oogoo05Qoo`008goo00<007ooOol05goo
00<007ooOol02Goo00<007ooOol097oo00<007ooOol02Goo00<007ooOol0FGoo000SOol2000HOol0
0`00Oomoo`09Ool00`00Oomoo`0TOol00`00Oomoo`09Ool00`00Oomoo`1IOol002=oo`03001oogoo
01Qoo`03001oogoo00Qoo`03001oogoo02Eoo`03001oogoo00Moo`03001oogoo05Yoo`004goo00<0
07ooOol00Woo00<007ooOol00Woo0`000goo00<007ooOol067oo00<007ooOol01goo00<007ooOol0
9Woo00<007ooOol01goo00<007ooOol0FWoo000BOol00`00Ool00009Ool00`00Oomoo`02Ool00`00
Oomoo`0IOol00`00Oomoo`06Ool00`00Oomoo`0WOol00`00Oomoo`05Ool00`00Oomoo`1KOol0019o
o`03001oo`0000Moo`@000=oo`8001Yoo`03001oogoo00Eoo`03001oogoo02Qoo`03001oogoo00Eo
o`03001oogoo05]oo`004Woo00<007oo00001goo00<007oo000017oo00<007ooOol06Woo00<007oo
Ool017oo00<007ooOol0:Goo00<007ooOol00goo00<007ooOol0G7oo000BOol00`00Ool00008Ool2
0004Ool00`00Oomoo`0JOol20004Ool00`00Oomoo`0ZOol00`00Oomoo`03Ool00`00Oomoo`1LOol0
01=oo`03001oogoo00Qoo`03001oogoo009oo`03001oogoo01]oo`03001oogoo009oo`03001oogoo
02Yoo`03001oogoo009oo`03001oogoo05eoo`008goo00<007ooOol077oo1000;Woo1000H7oo000S
Ool2002cOol002=oo`03001oogoo0;9oo`008goo00<007ooOol0/Woo0000\
\>"],
  ImageRangeCache->{{{0, 215}, {132.438, 0}} -> {-2.45212, -1.05216, 
  0.0693221, 0.0115871}}]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"Microsoft Windows 3.0",
ScreenRectangle->{{0, 1280}, {0, 968}},
WindowToolbars->"EditBar",
CellGrouping->Manual,
WindowSize->{567, 457},
WindowMargins->{{66, Automatic}, {178, Automatic}},
PrintingCopies->1,
PrintingPageRange->{Automatic, Automatic},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, -1}},
ShowCellLabel->True,
ShowCellTags->False,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False},
StyleDefinitions -> "ArticleClassic.nb"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1709, 49, 52, 0, 111, "Title"],
Cell[1764, 51, 35, 0, 41, "Author"],
Cell[1802, 53, 112, 4, 55, "Address"],
Cell[1917, 59, 52, 1, 31, "Input"],

Cell[CellGroupData[{
Cell[1994, 64, 31, 0, 56, "Section"],
Cell[2028, 66, 710, 10, 129, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2775, 81, 46, 0, 56, "Section"],
Cell[2824, 83, 214, 6, 44, "Text"],
Cell[3041, 91, 172, 4, 27, "NumberedEquation"],
Cell[3216, 97, 216, 4, 44, "Text"],

Cell[CellGroupData[{
Cell[3457, 105, 52, 0, 33, "Subsubsection"],
Cell[3512, 107, 276, 7, 44, "Text"],

Cell[CellGroupData[{
Cell[3813, 118, 134, 2, 53, "Input"],
Cell[3950, 122, 13844, 479, 142, 5324, 369, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],
Cell[17809, 604, 87, 2, 27, "Text"],

Cell[CellGroupData[{
Cell[17921, 610, 151, 2, 51, "Input"],
Cell[18075, 614, 14071, 556, 142, 6669, 460, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],
Cell[32161, 1173, 223, 4, 44, "Text"],

Cell[CellGroupData[{
Cell[32409, 1181, 124, 2, 31, "Input"],
Cell[32536, 1185, 12799, 474, 142, 5517, 380, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],
Cell[45350, 1662, 104, 3, 27, "Text"],

Cell[CellGroupData[{
Cell[45479, 1669, 217, 3, 51, "Input"],
Cell[45699, 1674, 17356, 687, 142, 8484, 573, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],
Cell[63070, 2364, 288, 5, 61, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[63395, 2374, 53, 0, 33, "Subsubsection"],
Cell[63451, 2376, 261, 5, 61, "Text"],
Cell[63715, 2383, 128, 3, 31, "Input"],
Cell[63846, 2388, 41, 0, 27, "Text"],

Cell[CellGroupData[{
Cell[63912, 2392, 116, 3, 31, "Input"],
Cell[64031, 2397, 291, 5, 68, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[64359, 2407, 234, 5, 71, "Input"],
Cell[64596, 2414, 30293, 1123, 146, 11136, 882, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],
Cell[94904, 3540, 355, 12, 44, "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[95308, 3558, 36, 0, 56, "Section"],
Cell[95347, 3560, 335, 6, 61, "Text"],

Cell[CellGroupData[{
Cell[95707, 3570, 62, 1, 31, "Input"],
Cell[95772, 3573, 215, 7, 57, "Output"]
}, Open  ]],
Cell[96002, 3583, 226, 4, 91, "Input"],

Cell[CellGroupData[{
Cell[96253, 3591, 221, 5, 71, "Input"],
Cell[96477, 3598, 75596, 1242, 157, 16844, 512, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],
Cell[172088, 4843, 298, 5, 61, "Text"],

Cell[CellGroupData[{
Cell[172411, 4852, 63, 1, 31, "Input"],
Cell[172477, 4855, 83, 1, 30, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[172609, 4862, 40, 0, 56, "Section"],
Cell[172652, 4864, 495, 8, 95, "Text"],

Cell[CellGroupData[{
Cell[173172, 4876, 50, 0, 43, "Subsection"],
Cell[173225, 4878, 455, 14, 59, "Text"],

Cell[CellGroupData[{
Cell[173705, 4896, 165, 3, 67, "Input"],
Cell[173873, 4901, 143, 2, 59, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[174053, 4908, 397, 8, 91, "Input"],
Cell[174453, 4918, 35943, 1195, 92, 24821, 1053, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[210445, 6119, 52, 0, 43, "Subsection"],
Cell[210500, 6121, 472, 11, 71, "Text"],

Cell[CellGroupData[{
Cell[210997, 6136, 72, 1, 31, "Input"],
Cell[211072, 6139, 42, 1, 30, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[211151, 6145, 77, 1, 31, "Input"],
Cell[211231, 6148, 44196, 1013, 184, 19859, 708, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],
Cell[255442, 7164, 90, 2, 27, "Text"],

Cell[CellGroupData[{
Cell[255557, 7170, 79, 1, 31, "Input"],
Cell[255639, 7173, 14373, 434, 142, 4302, 305, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[270061, 7613, 46, 0, 43, "Subsection"],
Cell[270110, 7615, 59, 1, 31, "Input"],
Cell[270172, 7618, 287, 5, 61, "Text"],

Cell[CellGroupData[{
Cell[270484, 7627, 249, 5, 71, "Input"],
Cell[270736, 7634, 53273, 966, 142, 16844, 512, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[324058, 8606, 36, 0, 43, "Subsection"],
Cell[324097, 8608, 280, 6, 44, "Text"],

Cell[CellGroupData[{
Cell[324402, 8618, 247, 5, 71, "Input"],
Cell[324652, 8625, 56320, 1004, 146, 16366, 506, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[381033, 9636, 71, 0, 78, "Section"],
Cell[381107, 9638, 681, 10, 112, "Text"],

Cell[CellGroupData[{
Cell[381813, 9652, 129, 3, 45, "Input"],
Cell[381945, 9657, 152, 2, 58, "Output"]
}, Open  ]],
Cell[382112, 9662, 148, 5, 27, "Text"],

Cell[CellGroupData[{
Cell[382285, 9671, 147, 3, 72, "Input"],
Cell[382435, 9676, 291, 4, 68, "Output"]
}, Open  ]],
Cell[382741, 9683, 98, 2, 27, "Text"],

Cell[CellGroupData[{
Cell[382864, 9689, 111, 2, 31, "Input"],
Cell[382978, 9693, 24261, 846, 142, 9910, 664, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],
Cell[407254, 10542, 583, 8, 112, "Text"],

Cell[CellGroupData[{
Cell[407862, 10554, 147, 3, 31, "Input"],
Cell[408012, 10559, 21388, 828, 142, 10231, 686, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

